(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   6173993,     137419]*)
(*NotebookOutlinePosition[   6174690,     137443]*)
(*  CellTagsIndexPosition[   6174646,     137439]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Two objects classification examples", "Title"],

Cell[TextData[{
  "This notebook  assumes that the definitions in the notebook \"",
  StyleBox["statistical_modeling.nb",
    FontColor->RGBColor[1, 0, 0]],
  "\" have already been evaluated."
}], "Text"],

Cell[CellGroupData[{

Cell["Global variables", "Section"],

Cell[CellGroupData[{

Cell["File information", "Subsection"],

Cell[BoxData[
    \(\(dir = \
"\</Users/nechyba/public_html/eel6825/lectures/lecture6/data\>";\)\)], "Input",\

  Background->RGBColor[1, 1, 0]],

Cell[BoxData[{
    \(\(segmentedFile1 = "\<kellogs1_segmented.ppm\>";\)\), "\
\[IndentingNewLine]", 
    \(\(segmentedFile2 = "\<tide1_segmented.ppm\>";\)\), \
"\[IndentingNewLine]", 
    \(\(imageType = "\<JPEG\>";\)\)}], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(\(SetDirectory[dir];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Replacement color", "Subsection"],

Cell[BoxData[
    \(\(replacementColor = {0, 255, 0};\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting options", "Subsection"],

Cell[BoxData[{
    \(\(pointStyle1\  = \ {Orange, \ 
          PointSize[ .01]};\)\), "\[IndentingNewLine]", 
    \(\(pointStyle2\  = \ {Purple, \ PointSize[ .01]};\)\)}], "Input"],

Cell[CellGroupData[{

Cell["Classification region colors", "Subsubsection"],

Cell[BoxData[{
    \(\(classColor1\  = \ RGBColor[ .5, 1, 1];\)\), "\[IndentingNewLine]", 
    \(classColor2\  = \ RGBColor[1, 1,  .5]; 
    classColors\  = \ {classColor1, \ classColor2};\)}], "Input"],

Cell[BoxData[
    \(\(pr = {{0, 255}, {0, 255}};\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local definitions", "Section"],

Cell[CellGroupData[{

Cell["Segment loaded image", "Subsection"],

Cell[BoxData[
    \(\(SegmentObject[img_, thresh_:  245, \ 
          color_:  
            replacementColor] := \[IndentingNewLine]Module[{img2}, \
\[IndentingNewLine]img2\  = \ 
            Map[If[#[\([1]\)]\  > \ thresh\  && \ #[\([2]\)]\  > \ 
                      thresh\  && \ #[\([3]\)]\  > \ thresh, \ 
                  replacementColor, #] &\ , 
              img[\([1, 1]\)], {2}]; \[IndentingNewLine]ReplacePart[img, 
            img2, {1, 1}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Segment file image", "Subsection"],

Cell[BoxData[
    \(\(ConvertImage[outFile_, inFile_, \ type_, \ thresh_:  245, 
          color_:  
            replacementColor] := \[IndentingNewLine]Module[{img}, \
\[IndentingNewLine]img = Import[inFile, type]; \[IndentingNewLine]img2 = 
            SegmentObject[img, thresh, color]; \[IndentingNewLine]Export[
            outFile, img2, "\<PPM\>"];\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extract RGB data from segmented images", "Subsection"],

Cell[BoxData[
    \(\(ExtractRGB[img_, 
          color_:  
            replacementColor] := \[IndentingNewLine]Module[{rgb}, \
\[IndentingNewLine]rgb = 
            Partition[Flatten[img[\([1, 1]\)]], 
              3]; \[IndentingNewLine]DeleteCases[rgb, 
            color]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Get representative sample of data", "Subsection"],

Cell[BoxData[
    \(\(RepresentativeSample[dat_, \ 
          n_] := \[IndentingNewLine]Module[{d2, 
            m}, \[IndentingNewLine]m\  = \ 
            Ceiling[Length[dat]/n]; \[IndentingNewLine]d2\  = \ 
            First\  /@ \ Partition[dat, \ m]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data plotting routines", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
Plot representative sample data (columns a and b from dat ) from a \
larger data set in 2d\
\>", "Subsubsection"],

Cell[BoxData[
    \(\(PlotRepresentativeSample2D[dat_, \ n_, {a_, b_}, \ 
          opt___] := \[IndentingNewLine]Module[{d2, m, 
            rgblabel}, \[IndentingNewLine]rgblabel\  = \ {"\<Red\>", \ \
"\<Green\>", \ "\<Blue\>"}; \[IndentingNewLine]m\  = \ 
            Ceiling[Length[dat]/n]; \[IndentingNewLine]d2\  = \ 
            First\  /@ \ Partition[dat, \ m]; \[IndentingNewLine]Show[
            Graphics[
              Join[opt, \(Point[{#[\([a]\)], #[\([b]\)]}] &\) /@ \ d2]], \ 
            Frame \[Rule] True, AspectRatio \[Rule] Automatic, \ 
            FrameLabel \[Rule] {rgblabel[\([a]\)], \ rgblabel[\([b]\)]}, \ 
            DisplayFunction \[Rule] Identity, \ 
            PlotRange \[Rule] {{0, 255}, {0, 255}}]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot representative sample data  from a larger data set in 3d\
\>", \
"Subsubsection"],

Cell[BoxData[
    \(\(PlotRepresentativeSample3D[dat_, \ n_, \ 
          opt___] := \[IndentingNewLine]Module[{d2, 
            m}, \[IndentingNewLine]m\  = \ 
            Ceiling[Length[dat]/n]; \[IndentingNewLine]d2\  = \ 
            First\  /@ \ Partition[dat, \ m]; \[IndentingNewLine]Show[
            Graphics3D[Join[opt, Point /@ \ d2]], \ 
            DisplayFunction \[Rule] Identity, 
            PlotRange -> {{0, 255}, {0, 255}, {0, 255}}]];\)\)], "Input"],

Cell[BoxData[
    \(data2pixel[{r_, g_, b_, x_, y_}] := {RGBColor[r/255. , g/255. , 
          b/255. ], \ Rectangle[{x, \(-y\) - 1}, {x + 1, \(-y\)}]}\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot multiple results for mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(EMAllPlot[{\[Mu]_, \[CapitalSigma]_, priors_}, \ 
          gin_] := \[IndentingNewLine]Module[{pr, g2, g4, 
            g5}, \[IndentingNewLine]pr\  = \ {{0, 1}, {0, 
                1}}; \[IndentingNewLine]g2\  = \ 
            PlotMeans[{\[Mu], \[CapitalSigma], priors}, \ pr, \ Blue, \ nS, \ 
              FrameTicks \[Rule] None]; \[IndentingNewLine]g4\  = \ 
            PlotContourPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nS, \ 
              FrameTicks \[Rule] None]; \[IndentingNewLine]g5\  = \ 
            PlotPDF[{\[Mu], \[CapitalSigma], priors}, \ pr, 50, nS, \ 
              Axes \[Rule] None]; \[IndentingNewLine]Show[
            GraphicsArray[{{g2, gin}, {g4, g5}}], yS, \ 
            imSize]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify image (2d)", "Subsection"],

Cell[BoxData[
    \(\(ClassifyImage2DAugmented[im_, pdf1_, pdf2_, \ 
          which_: {Red, \ Green}, \ 
          scale_:  1] := \[IndentingNewLine]Module[{class, colors, pos1, 
            pos2, lpdf, gr, 
            bl}, \[IndentingNewLine]gr = \((List @@ \((pointStyle1\  // \ 
                      First)\))\)*255; \[IndentingNewLine]bl = \((List @@ \
\((pointStyle2 // First)\))\)*255; \[IndentingNewLine]colors = {Red, Green, 
              Blue}; \[IndentingNewLine]pos1 = \(Position[colors, 
                  which[\([1]\)]] // Flatten\)\  // 
              First; \[IndentingNewLine]pos2 = \(Position[colors, 
                  which[\([2]\)]] // Flatten\)\  // 
              First; \[IndentingNewLine]lpdf\  = \ \((Log[pdf1]\  // 
                  PowerExpand)\)\  - \ \((Log[pdf2]\  // \ 
                  PowerExpand)\); \[IndentingNewLine]class\  = \ 
            Map[If[# \[Equal] replacementColor, replacementColor, 
                  If[\((lpdf\  /. \ {x \[Rule] #[\([pos1]\)]/scale\  // \ N, 
                            y \[Rule] #[\([pos2]\)]/scale\  // \ N})\)\  > \ 
                      0, \ gr, \ bl]] &, \ 
              im[\([1, 1]\)], {2}]; \[IndentingNewLine]ReplacePart[im, 
            class, {1, 1}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classify image (3d)", "Subsection"],

Cell[BoxData[
    \(\(ClassifyImage3DAugmented[im_, lpdf1_, lpdf2_, \ 
          scale_:  1] := \[IndentingNewLine]Module[{class, colors, lpdf, gr, 
            bl}, \[IndentingNewLine]gr = \((List @@ \((pointStyle1\  // \ 
                      First)\))\)*255; \[IndentingNewLine]bl = \((List @@ \
\((pointStyle2 // First)\))\)*255; \[IndentingNewLine]colors = {Red, Green, 
              Blue}; \[IndentingNewLine]lpdf\  = \ \((lpdf1\  - \ 
                lpdf2)\); \[IndentingNewLine]class\  = \ 
            Map[If[# \[Equal] replacementColor, replacementColor, 
                  If[\((lpdf\  /. \ {x \[Rule] #[\([1]\)]/scale\  // \ N, 
                            y \[Rule] #[\([2]\)]/scale\  // \ N, \ 
                            z \[Rule] #[\([3]\)]/scale\  // \ N})\)\  > \ 
                      0, \ gr, \ bl]] &, \ 
              im[\([1, 1]\)], {2}]; \[IndentingNewLine]ReplacePart[im, 
            class, {1, 1}]\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Count pixels in classified images", "Subsection"],

Cell[BoxData[
    \(\(CountPixels[classim_, 
          color1_: \((List\  @@ \ \((pointStyle1\  // \ First)\))\)*255, \ 
          color2_: \((List\  @@ \ \((pointStyle2\  // \ First)\))\)*255, 
          backgroundColor_:  
            replacementColor] := \[IndentingNewLine]Module[{cnts, n1, n2, 
            n3}, \[IndentingNewLine]cnts = 
            Frequencies[
              Partition[Flatten[classim[\([1, 1]\)]], 
                3]]; \[IndentingNewLine]n1 = 
            cnts[\([\(Position[cnts, color1]\  // \ Flatten\)\  // \ First, 
                1]\)]; \[IndentingNewLine]n2 = 
            cnts[\([\(Position[cnts, color2]\  // \ Flatten\)\  // \ First, 
                1]\)]; \[IndentingNewLine]n3 = 
            cnts[\([\(Position[cnts, backgroundColor]\  // \ Flatten\)\  // \ 
                  First, 1]\)]; \[IndentingNewLine]{100*n1/\((n1 + n2)\), \ 
              100*n2/\((n1 + n2)\)}\  // \ 
            N\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normalized log-likelihood for each object (2d)", "Subsection"],

Cell[BoxData[
    \(\(AggregateLogLikelihood2D[data1_, \ data2_, \ 
          which_] := \[IndentingNewLine]Module[{d1, 
            d2, \[Mu]1, \ \[CapitalSigma]1, \ 
            gauss1, \ \[Mu]2, \ \[CapitalSigma]2, \ gauss2, \ a11, a12, a21, 
            a22}, \[IndentingNewLine]d1 = \({#[\([which[\([1]\)]]\)], \
#[\([which[\([2]\)]]\)]} &\)\  /@ \ \((data1/255)\)\  // \ 
              N; \[IndentingNewLine]d2 = \({#[\([which[\([1]\)]]\)], \
#[\([which[\([2]\)]]\)]} &\)\  /@ \ \((data2/255)\)\  // \ 
              N; \[IndentingNewLine]\[Mu]1 = Mean[d1]; \[CapitalSigma]1 = 
            CovarianceMatrix[d1]; 
          gauss1 = {{\[Mu]1}, {\[CapitalSigma]1}, {1. }}; \[IndentingNewLine]\
\[Mu]2 = Mean[d2]; \[CapitalSigma]2 = CovarianceMatrix[d2]; 
          gauss2 = {{\[Mu]2}, {\[CapitalSigma]2}, {1. }}; \
\[IndentingNewLine]a11 = 
            LogLikelihoodMixtureDataSet[d1, gauss1]/
              Length[d1]; \[IndentingNewLine]a12 = 
            LogLikelihoodMixtureDataSet[d1, gauss2]/
              Length[d1]; \[IndentingNewLine]a21 = 
            LogLikelihoodMixtureDataSet[d2, gauss1]/
              Length[d2]; \[IndentingNewLine]a22 = 
            LogLikelihoodMixtureDataSet[d2, gauss2]/
              Length[d2]; \[IndentingNewLine]{{a11, a12}, {a21, 
              a22}}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Normalized log-likelihood for each object (2d) (mixture \
model)\
\>", "Subsection"],

Cell[BoxData[
    \(\(AggregateLogLikelihood2DEM[data1_, \ data2_, \ model1_, \ model2_, 
          which_] := \[IndentingNewLine]Module[{d1, d2, \ a11, a12, a21, 
            a22}, \[IndentingNewLine]d1 = \({#[\([which[\([1]\)]]\)], \
#[\([which[\([2]\)]]\)]} &\)\  /@ \ \((data1/255)\)\  // \ 
              N; \[IndentingNewLine]d2 = \({#[\([which[\([1]\)]]\)], \
#[\([which[\([2]\)]]\)]} &\)\  /@ \ \((data2/255)\)\  // \ 
              N; \[IndentingNewLine]a11 = 
            LogLikelihoodMixtureDataSet[d1, model1]/
              Length[d1]; \[IndentingNewLine]a12 = 
            LogLikelihoodMixtureDataSet[d1, model2]/
              Length[d1]; \[IndentingNewLine]a21 = 
            LogLikelihoodMixtureDataSet[d2, model1]/
              Length[d2]; \[IndentingNewLine]a22 = 
            LogLikelihoodMixtureDataSet[d2, model2]/
              Length[d2]; \[IndentingNewLine]{{a11, a12}, {a21, 
              a22}}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normalized log-likelihood for each object (3d)", "Subsection"],

Cell[BoxData[
    \(\(AggregateLogLikelihood3D[data1_, \ 
          data2_] := \[IndentingNewLine]Module[{d1, 
            d2, \[Mu]1, \ \[CapitalSigma]1, \ 
            gauss1, \ \[Mu]2, \ \[CapitalSigma]2, \ gauss2, \ a11, a12, a21, 
            a22}, \[IndentingNewLine]d1 = \((data1/255)\)\  // \ 
              N; \[IndentingNewLine]d2 = \((data2/255)\)\  // \ 
              N; \[IndentingNewLine]\[Mu]1 = Mean[d1]; \[CapitalSigma]1 = 
            CovarianceMatrix[d1]; 
          gauss1 = {{\[Mu]1}, {\[CapitalSigma]1}, {1. }}; \[IndentingNewLine]\
\[Mu]2 = Mean[d2]; \[CapitalSigma]2 = CovarianceMatrix[d2]; 
          gauss2 = {{\[Mu]2}, {\[CapitalSigma]2}, {1. }}; \
\[IndentingNewLine]a11 = 
            LogLikelihoodMixtureDataSet[d1, gauss1]/
              Length[d1]; \[IndentingNewLine]a12 = 
            LogLikelihoodMixtureDataSet[d1, gauss2]/
              Length[d1]; \[IndentingNewLine]a21 = 
            LogLikelihoodMixtureDataSet[d2, gauss1]/
              Length[d2]; \[IndentingNewLine]a22 = 
            LogLikelihoodMixtureDataSet[d2, gauss2]/
              Length[d2]; \[IndentingNewLine]{{a11, a12}, {a21, 
              a22}}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Normalized log-likelihood for each object (3d) (mixture \
model)\
\>", "Subsection"],

Cell[BoxData[
    \(\(AggregateLogLikelihood3DEM[data1_, \ data2_, model1_, 
          model2_] := \[IndentingNewLine]Module[{d1, d2, a11, a12, a21, 
            a22}, \[IndentingNewLine]d1 = \((data1/255)\)\  // \ 
              N; \[IndentingNewLine]d2 = \((data2/255)\)\  // \ 
              N; \[IndentingNewLine]a11 = 
            LogLikelihoodMixtureDataSet[d1, model1]/
              Length[d1]; \[IndentingNewLine]a12 = 
            LogLikelihoodMixtureDataSet[d1, model2]/
              Length[d1]; \[IndentingNewLine]a21 = 
            LogLikelihoodMixtureDataSet[d2, model1]/
              Length[d2]; \[IndentingNewLine]a22 = 
            LogLikelihoodMixtureDataSet[d2, model2]/
              Length[d2]; \[IndentingNewLine]{{a11, a12}, {a21, 
              a22}}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3d EM initialization function", "Subsection"],

Cell[CellGroupData[{

Cell["Scalar covariance initialization 3d", "Subsubsection"],

Cell[BoxData[
    \(\(EMInitializationScalar3D[x_, \ k_] := 
        Module[{n, \ rl, \ \[Mu], \ \[Sigma], \ priors, \ sm, \ del2}, \n\t
          n\  = \ Length[x]; \n\t
          rl\  = \ Table[{Random[Integer, {1, n}]}, \ {k}]; \n\t\[Mu]\  = \ 
            Partition[Flatten[\(Take[x, \ #] &\)\  /@ \ rl], \ 3]; \n\t
          sm\  = \ 
            Table[\(dist[#, \ \[Mu][\([i]\)]] &\)\  /@ \ \[Mu], \ {i, \ 1, \ 
                k}]; \n\t
          del2\  = \ 
            Table[{i, i}\ \ , \ {i, \ 1, 
                k}]; \n\t\[Sigma]\  = \ \(\((#*#)\) &\)\  /@ \ \((Min\  /@ \ 
                  Delete[sm, \ del2])\); \n\t
          priors\  = \ Table[1/k, \ {k}]\  // \ N; \n\t{\[Mu], \ \[Sigma], \ 
            priors}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Full covariance initialization 3d", "Subsubsection"],

Cell[BoxData[
    \(\(EMInitializationFull3D[x_, 
          k_] := \[IndentingNewLine]Module[{\[Mu], \[Sigma], priors, 
            dim}, \[IndentingNewLine]{\[Mu], \[Sigma], priors}\  = \ 
            EMInitializationScalar3D[x, \ k]; \[IndentingNewLine]dim\  = \ 
            Length[First[\[Mu]]]; \[IndentingNewLine]{\[Mu], \(\((#\ \
IdentityMatrix[dim])\) &\)\  /@ \ \[Sigma], 
            priors}\[IndentingNewLine]];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Load and visualize data", "Section"],

Cell[CellGroupData[{

Cell["Load segmented images", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(obj1 = Import[segmentedFile1, "\<PPM\>"];\)\), "\n", 
    \(\(obj2 = Import[segmentedFile2, "\<PPM\>"];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1}, {obj2}}], \ 
        ImageSize \[Rule] 288];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.16538 
%%ImageSize: 288 335.631 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0277473 0.952381 [
[ 0 0 0 0 ]
[ 1 1.16538 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.16538 L
0 1.16538 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0277473 0.97619 0.556266 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7E7E5CBCCC7D1D2CDECECEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F8F7F3DCDBD7B2B1AF7E7D7B4C4B472E2D2935343053524E
777672A5A6A1CCCCCAE9E9E700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00DCD8D59C999466635C3F3C3527241F2D2A25282421302C29322F2A2F2C27
2926212827222E2F274748428B8C86EDEEE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F6F7F2AEADA943403B221D17211E15302D243C3731433E3A443F3B4C4441524B45554E48
544F494D4A4137342B2222181B1B135E5F59D0D1CC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E0E1DC
7D7C7734312A1D181228241B353128413D3440393339312E3D3532423836473E3949403B
4D443D50493F494238433F363532291D1D153E3D39ADACAA00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3E3E15F5E59
28251E2521181F1B1237332A403C333B372E37302A342C293F3533403634433834443933
3F342E3F362D483F364A43394B473C3C39302825202A2925A5A5A300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F4F4F27B7A7525251D
2C2920242017322B21463F353B342A4740363D342D342B26362F29352E283C332E393029
3B322B4A41384F473C423A2F433F334A483C37342D1F1E193C3D38D6D6D400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3A09B28251E26231C
2F2A24261F17342B244A4138372E253F362D494039393029302722382F2A3D342F362D26
433A31534A414F453B40362C403A2E4A463B46433A2827221E1D196E6E6CF4F4F400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFF5F4FFF6F3FFF4F0FFF4F0FFF5F2FFF5F2FFF6F2FFF8F3CBBEB83C332C2017122A231D
312A242A231D2D221E463B37392E2A2E231D4237333F34303227213B302A443933382D27
3E342B4F453C493C343A30273A3128453E34514D442B2A2523221E21211FABA9AA00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFEEE8E8D1CBE1C9C5D8C3C0D4C2C0D5C3C1DBC9C7D2BDBCD5BBBCDEBEBFD1AAABC09495
CC9A99CB9894C48F89B9847EB7857EAF7E77A0756E92706760453C27150B251812312823
2E24222A201E291E1C382D2B4136322F2420372C283A2F2B3A2F29423731514640433832
3F362D4A4037362C2330261D372E25474038443F392B282326221F1B1716484242E7DEDF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDEDEDAFAFAF6A6A68
6565636566616565636667626768636A6B668E8E8CBBBBB9D3D3D1E8E8E600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FCD5CE
BF897F894D42A47065A97C76825D5783625DA4817FA27A78A47474B37978A55D5E8F3E3D
A34A46A64741A6453C9F3F33A34539953D3186382B7A3C2F5F332633150B28150E352724
3329272E24222A201E2C2220342A28372D2B382D293D322E393029443B34534A414F463D
4740363E372D302720281F1841383148413B372F2C2D2523251C1D271B1B251214887473
DCCAC6E0D1CAE6D9D1E9DFD6F1E7DDF8EFE6FFF6EFFFFDF500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEECACAEAB5959572525231A1917
1716121918131B1A161E1D181718120F100A1A1B1623241F2C2E29474944646663878986
AEB0ADE2E4E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFEAE7E5AEA9B26960
9C493B903D2DD08B7CBD83789867608E635D9467629A6764A96C6BC37978C86E6DA9413E
BB4A44BE473FC84D45C54B40C54D3FBD4C3EA33F2FAB584881433442180C2C0F0934211D
3729263328263126242E24222B211F2F2523382D293A2F2B3A312C3F362F423932403931
3F3B3239352C37302A3F383238302D362E2B312927281E1D2D1F1F3420222B0E1040211E
513329593C2E6D5241644E396D5941745F4A7B6955806D5C897665917E6DA18C7BAE988A
BAA496C8B2A5D5BDB3DBC4BCE0CBC6E6D3CFECDAD6F1E2DFF4E9E5FAF0EE00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00F2F2F0AFAFAD5757551E201B1516111F1E1A201F1B
1C1B161C1B162926212828201D1D151D1E161D1E18181913161711161912151712161815
1719164E504DD6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F5FFCECAD0837DB64F46BA4A3E
B045359C3D2BE29585C6887BB48075976860A3736FB27C7AAD6D6BCA7C7ADC7E7CB44845
C34E47C24740D3544DCE4E45CF5145CA5043AE3E30BE5D4D964A3C50160A360E06391D19
3723223424243A2C2B2F24222F2420302521342623332824372E29372E2938312B3A332D
3E393336312B362E2B372F2C2B23212B23212B2122302222352123381B1D320A0B552521
6A392B6B3B257A4D305E36125F391258350B5B350E5B3510552F0A59330E5C3410693E1C
5C2D1168341E672E1B632A19672F226E3A2F73473E734C4576554E7A5D578265618D6F6D
957673A58683AF908DB99A95C4A7A3CFB3AFD9C0BCDDC8C5E2CFCBE7D5D1EDDEDBF3E4E1
F9EBEAFEF3F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00C6C6C465666123241F171813151611191A15201F1B21201B
2F2C27302D26342F2937342D37342D39392F33332B26271F1C1D15181911151811131510
1217131015114A4C4BD2D4D300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F4DBAFACB4615BB6463BCB473BD04B3C
BF4635A83F2CE89583CB8878B97F73AB756BAF766FAA6D689D5652B6615EDB7873BF4E48
C94E47CC4B45D24D46D55047D14C43D04D43BC4034C25143BB5B4D6D1F124307003F120D
3F1D1B3A201F3723223523213A2B283A2B283D2E2B3B2D2A3328263026242E24222F2724
332B282C24212A222029211F2920212B21222D1F1F331F213E2123381112390605652A24
7D3F307C4026915B37794A1E794D1E754B197E5221805423764A197446157545177F4A1E
6F330E77351585391F873B247E35247A362970372C5A2A20542C244B261E4A231E4A2220
502723542B27542B25572E28532C254F2A224C2B24563732593C3660453E684C496F5652
745C587D6561866E6A937B779C8782A9948FB5A09DC1ACA9C9B4B1D7C2BFDEC9C6E5D0CD
EAD7D3F0DDD9F6E7E2FBEEE8FEF5EEFFFDF2FFFFF4FFFFF3FFFEF500FF0000FF0000FF00
00FF0000FF00E2E2E08888863435301C1D181A1B161C1D18191A151617122A2924393631
403B3538332D322D27322D2734312A38352C33302731312734342A2E2F2722231D13160F
171914161815181A19505251D6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FCD3CFA15650BC4A40D24A3ED44537D24635
C64736AC3D2AE68E7AC77C69B97465A76356904A40A65B559D4843C0615BE87B74C14840
CE4D47D14A44D64D47DB5049D84D46D54B41CB4136C94539D55D4FAE4436731910540B04
49120D451C183C1D1A381F1B3A25203C292542302E40312E3A2F2D3E33313429272D2321
342A2933292831272833292A302426312323341E203A1C1E441C1D3E0B0A480806753128
8A46338D4D32AB775294673D855C2E845E2D8A653198703D926A37956C389567369C693A
975C309B57308D3E1D8F3F249247308C4A3A6731275A2F288A685E85645B7C5953835D5A
8259555C302D643933653D35522C23542F2657352C59382F502F26502F264D2A264C2925
4F2C2848251F4E29234E2923502922532C25502922522923562924602D29682E2A6F342E
773E377D493E805044825B4A7F634E7F6B508D8262948E6C9D987AA7A58CADAC9ABBBBAF
C2C3BBA8A9A34D4E491D1E191C1D1721221C1D1C181E1D191F1E1A26252143403B312E29
2C2723302B2728231F2B26202F2A24312C2628231D28231D302D2633332B31302B23241E
1718131516111C1C1A191917505050E0E0E000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF6F3DCA098A7453AD04C40D64234D74132D54433
C74231B13928E27B68EB907DCC7466B75F53B55B52C5645DD16A63F0817ADF645DCA473F
D54C44D84B44D74840DD4E46DE4F47DD4D44D7443ACC3C31DD5346D25245BA453B8C271D
5F0F0653130A4B1610461914411C16401F1A3B1D1B3B212039211F3C2726372322362221
3A2828362424301C1D372123391F223C1C1F3E16174715164D0F104E040365120C903C31
9746339E563DAE76538F5F3782572D7852256B4518724C1D744C1B895F2D865A2B8E5B2C
884F229E5D33A45834974A2C954D358A4B3A55231A835D54AD8C83A1837BA88581B8928F
976E6C59302E633A36502922805B5298766C97756B916F658D685F8C655E8A615B875C56
865D577D544E774F47734B436C443C663B326539305B2A23692F2B6B27247C2E2A802D27
7D2A227B2D20722B19682E165227055C3F1567562260551F5A52235B562E5D5A3B5F5E49
3D3E301011091516101E1F1920211B1F201A201F1B1F1E1A1A19153A39353A3732292621
29262127241F25201C322D292F2A242B26202C24212B26222C272326231C2B282335342F
23241F191A151C1C1A1D1D1B16161689898900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFE7E3B76861BE4C41D3493CD64031D73F31D03D2D
D44736C23D2CDD6453FD8A78F38176E8736AE66D65DD605AD85952D8534CCD443CD3463D
D84A40D7473EDC4941DD4841E14C45DD493FDA433AD74035D94539DF5042DE5447CF5143
B1413389271A6B140A570D0453120C511713481512491917441B194921213A13143C181A
3E1A1A3C181841191A4115164715184B1012530D0F5807066607057A110D9F322BAD4336
AA4B379E4C34B26F5299614083512E885A387448255E340E6F451B7D52276D40177A4920
743E12995B32A86240944D3195533D7B41336C3D35B08B83B19089AE9088B59290BE9798
724A4B5B3435512E2C674641B3928BAC8E84AE8D84AA887FB68D87B58883A77672A77671
AB7E78A98179A38178A080759A7C7199796E96746A976C65A7726E7B37347B2725963934
97342E94342689341F8039196C380988642A856C29786721766B2B79723B817C528E8D6F
65645208080016160E23221D24231E21201B27241F201D181A171243403B2B2A25201F1A
2625201E1D18231E184B443E35302A25201A2D28242B26222A2521231E1A2A252135322D
3C3B361B1C171616141D1D1B181A1740423FE4E4E400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECC3BFAC4F47C84A3ED94B3DD64031D94133D43E2F
DE4B3BD84B3ACC4434DE594AD85247D95048DA4F48D4473ED4453DD24239D6433BD8443A
D64238D9453BD94239DC453CDF463EDA4237DA4139D84035DC4236E0483AE95345E45746
D85344CB5040AF3D328F291D72140C610C075B0C08570D0A5912105612114E0C0D501011
4D0D0E521011520E0F52080959090C5F06086C080A8212119F2522B4352EC5453CBE4638
B04734A54A35B86C54AE6C52A1654BA56D549761478350338B5A3A885736804E2D8C5634
7F4422B57655B372549151388E5341632F228F645DC8A39DBD9A94C09D99CDA6A7AB8286
62393D663F424D2B2A997A77B79893B1938BB4918BBE958FC796928D5653854A46864C48
8150497B50497D5B52A5897EA58A7FA4897EA4867CAC857EBD8785702C2B7D27269E3C39
9A332C9D392A943A22883C18793F0D9B72328D71278170227E712B8B8247948D5F9E9B7A
7978640E0E0217170F26252025241F221F1A27241F23201B201D18403D3835342F1E1D18
20211B191813231E1859544E35302A241F192A252126211D241F1B26211D25201C2C2924
41403B23241E191A151B1B191F211E20221FAFAFAF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF4F2C68F8CAE4740CE4940D64739DC4638DA4235DB4335
DE4839D84436DA483BDD4B3EDE4C3FDF4C42D9453BDA463CD9453BDC453AD94136D94136
D84035D94136DB4338D84035DA4036D83E32D93F35DC4236D93F33E2483CEB5346E55143
E05141DE5243DE584CD8584DCC5046B53E36A3322C8E211C8317147B120F78100F740C0B
700A08740C0B7D13138115158D1A1D9E2627AE2E2DC8413ED24440D84B42CF463CC84A3C
B74837AC4B3AC57260AC6352A05B4BA461519B59499F5E4CA46651B1735E9F5E4AA96854
A3614BB1705CAC6D5B995E4E774336603129966D67AF8A84AF8986B6908FCAA0A4895C63
673C4360373B664242C19F9DC1A09BC09D97C29995DDABAAB2757477312F944A4797524D
8D544D6839316B443DB0928AAC8F87AB8E86AE8D86C39A949F69676622218E3A389C3F3A
9C3B329D402F98442A863E1886511DA1793B8E732C8A7830807533968D549B9468A8A383
89867316140817140D29262125221D25221D26221F24211C21201B33322D3E3D3921201C
1C1B1712110C27241D57524C433F361F1A14211E1724211C26231E221F1A1E1B142D2A23
45453D22231D22231E1D1D1B1B1D1A17191668686600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FEDBD7A45F58BA4941D2483ED9473ADC4638DF4539DE4438
DB4335E0483BE1493CE1493EE2483CDE4639DE463BDE463BDF473ADD4538DD4337D93F33
DB4135DF4539DB4137DA4036DB4135D93F33DD4337D93F33DC4335E1483AE85042E95143
E85243EE5B4BE85649E9594EE95D50EE6459EA6459E46157E15E56D34F4ACF4E48CC4B46
C2423FBE3E3BC44443D95757D75253DA5050E15150E34F4BE74F4ADE4942D7493FC94739
B74636AC4B3AC87565B86F60A15C4D9B594B854335884638935143A56355955345975547
955647985A4D885043B17F745A2E257E5750B8938DAD8A86B28C8BB99192AD8085693C43
70464A50292C866262AB8987A88782B08B85BB8B8BD096958E46478333329E4D4A9D524D
91544F5F2E27916A63C2A19AB99C94BA9D95BF9E97CEA7A2794645713433934747994844
9A483D9548368F472F804422916234A8854D977D408F7D3F8C7F489C9463A19972ACA789
9996831F1D1113100928252027241F26231E27232021201C25241F23221D33322E393836
1918140B0A05312E274C494249453C1F1B121D1A13211E17221F1A1E1B161D1A133A3A32
3E3F3721221C21221D1B1B1919191713131130302EBABAB800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF7F5DFAAA49F483FC44B40D64A3DD84637DD4738DF4539E3493D
E95144E85043E3493DDC4236E2463ADE4438E0463AE2483CDE4438E3493DE4483CE2483C
E04739DF4739E2483CDE4438E1473BDF4539DF4638DE4537E04737E14838E64D3DE64F3E
EB5544ED5746F15E4EED5B4CED5B4CEE5C4DEB5C4EEE6052ED5F51ED6154EE6157F3665D
EC615ADE554FE55E5BF66E6EF16767E55658EB5757EB5350E54D48E04B44D44439CA4639
B74636AB4C3AAE614FA36250995E4C9C65519A634F9F6756955D4E9961549860539B6559
9561548E5E527F534AA67E7663403AA98883C19F9DBB9997C6A09FD8B0B18D636763393D
623B3C563433B49592B69794B79691B8908ECD9797BB76797E2D2C9B43429F4A479B504B
7E433D62332BAB867EB08F86B0928AB4968EBE9D98A8827F6D3F3F875453905654915650
965C51925A4B8F5C4983573C9672509D8058947D51917E538F82589C936CAAA18298927A
B6B3A2413F330C0B0623221E28272324231F24231F22211D2524201F201B22222033342F
34332E24241C2F2C2535322B3C3930221F161E1B1217140B19191120201832312C3B3C36
2728221F201A201F1B21201C1C1B171A19151716122C2D28858583A4A6A3D1D3D0EBEDEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF0ECB9766EAA453BCE5044D44638DC483ADA4435E85043F0584B
EA5245E44C3FDB4336DE4639E0483BE1493CE24C3EDE483AE34B40E1493CE0483DE34B3E
DF493BE14B3DE0483DE34B40E1493EE1493CE1493BDF4837E34C39E14C38E24F3BDE4E36
DE5136E85C41EE6249EE6249EC6047EA5E45EE624BE95E47EE624BEB5E4AEB5E4CEC5F4E
EB5C4EE95B4FEB5E55F96B67FA6B67EB5A57ED5854EB534EE74E48DD463FD44137CB4539
BD4A38AF4E3B8A3C268F4E38894F378B553D834F378A583F8E5C458757418556428A5D4A
8F66548B665484635487675C6C4F47B29591BFA09DC09E9CCDA6A7C9A1A2683F456D4649
4E2C2B896A67C6A9A5BC9D9ABD9B99CB9F9EE5A9AB974C50832B2AA64B4AA14B4A9B514E
5D2621865B54BD9890B19089B89790B89591CCA4A27C525367373782504F65322F703D39
68382E75473A693F2F623C297250375B3D21684D2F58412279664887785B7F7359948C77
BAB5A299978A1C1C1416151022211D25242027262221201C22211D1D1C1822211F282723
28272233332B3A37323C393239362F312E25312E2527271D33332B3837323A3B35262721
22231E1F201B22211D2625231D1C1A201F1B1716141313115F5F5D6163606C6E69858681
A3A49FC9CAC5E7E7E500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00EECDC8A05248BF5045D14D41D94A3CDB4739E44E40EB5547ED5749
E54F41DD493BDE4A3CE14F40DB4C3EDA4B3DDD4E40DC4D3FE14E44E35144DE4B41DE4C3F
E04E41E04E41E14D43DF4B41E14A41DD463BE04A3CE04A39DF4E39E0543BD44D2FCD4D2A
CF512BD1562DDC6138E1653FE86C46E46844DF6341E06442E16241E56444E76446EE664C
EC614AEC5F4BEE5F4FF26355FA675DE9564CE8514AE75049E14A41DD463DD6433BCD4539
C74D3EAC45328A341DAC6247AF6C4FA96C4D8C543395603E8C5A3981533181563485613F
7F5E3D674D2C6F5638725A42593F309E8277C3A29DC4A19FD9B2B39F7778633C41633F43
4E2E2FB69896C2A4A2BE9F9CC29C9BD8A6A7D08E907C2C2F95393AAB4D4DA25150823E3B
5B2824AF8682BE9B97B69590BC9995C9A09EC191915C282A763B3DAA706E8C524E97605B
9E6C659869618E6257865C508D66577F5A4894715D664631846853A2897375634DA89C86
B7B09DCDCAB98583771C1C141516101F201B29282425242025211E25221D211D1A1D1C17
1F1E1A2625202C2B272F2E2931302B32322A32322A34342C34332E2B2C2626272221221D
1F1F1D1A1A182624252624251B1B1B20201E1515151313116E6E6C6F706B6B6C6677776F
77776F75776C7E7F77999C93BCBDB7E1E2DCF5F6F100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FFF7F5C1948F9B4339C84F44D1493DD7483AE24E40EC5647EF594AE85244
E24E40E65445E05141DC5041D54C3CE1594BEB6154E85C4FEB5D51ED5F53E85A4EE4564A
E6584CE5574BE5554CE5554CE45449E35046E65447DF503FE45944D85539DE6342E7734C
D56639D96D3ED5693AD86C3EE27648E4774CE07348D86B40EC7D50D7633AE16B43E76D48
E76646E86245DF573DE45942E25541DE4F3EE14F40DF4B3FE34C41DD463DDC483ED2453B
CC4C3FC04C3DAD4834CC7258C06C50BC7050AE6544AB69469B5F3BA16B45986842906942
8D6D477F6540836C4C806B5069503C94766BCAA7A3CCA5A6D7AFB0734A4E6F484D502D31
7A5C5CCCAEACBFA19FC5A3A2CAA2A2E0AEAFA66468752629A54C4EA650519F5554612524
805350CBA5A2B99795BE9B99C29997D9A9A99C61656624268E4848C27B79B26F69BB7A74
AB706AA56C65A26B64B58078BD8880B17F74AF7D729C6E5FA98271A3826F937A66B2A18D
B6AE99D1CEBBE2E0D366665E1415101515131D1C1A2625232C28252D2A2526231E1F1C17
1D1C1822211D26252122211D26252024251F25251D23231B1F201A21221D25252321211F
1D1D1B1919171F1D20211F221D1D1F2626281212141F1F218787877A7A7871706B808076
84847876766A74766977796E727469777870909189B4B5AFD7D8D3EEEEEC00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FCE0DD9C635CA44237CD4F41D2483BDA4839E6503FF15A49EB5544E65041
E95646E65747E25645E96453FA786AFC7D6EFC786BF0685AEE6457F26657F4685BF3675A
F56B60F2685DF3665CF2655BF1645AEE6157EE6255E96050E5604DD2563EE17052F98E6A
DA754BF49265F39164ED8C5FF19264EC905FF59968F39562F69864DC7C49E5814FDE7546
E5764BE5714AD55D38D85C3AD25332D65337D74C35E25140E14B3DE34C41E04C42D8483F
D54B41D65447DA5F50D5624FCC5F4ACC664DCA684DC76C51CB7A5DC37C5EAB6E4FAD7A5B
A9826387684B9E8368987E678366569F7F74CDA7A4DEB6B7BB919562373E6F484D522E32
AF8F90CCAEACC5A7A5C7A8A5D6AFB0D4A3A67B3E438A4347A15559A0585B894D4D562624
AD8784CBA9A7BF9D9BC49E9DD1A0A3D89DA17B3239873539A34D4CC8706CB05D55BD6F65
A55B529A514A9C564EB8726AC68078A25E55A25E55995B50905B4B8D6251A3826FBEA996
B9AE9ACBC6B3F3F1E4AEAEA631312F454547282629171518201F1D322E2B332F2C2D2926
27232027232024201D231F1C22211C1F1E1924251D23241C1B1C161D1E19222220222220
1E1E1C1E1E1C1F1D202220231F1F211F20240D0E135B5C61A2A1A67C7C7C7A797486867C
8A8A7E8182748384768082757E80737A7C6F75776A7173686B6D6286877FA2A39BC7C8C2
E5E6E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00E4C1BD8A473FB1493ECF4D40D84A3CDA4737EE5847F05946E95342E54F3E
EA5747E65746E15544F26D5CFB7969F07162F97568EC6758EE6656EB6252F3675AF3675A
EE6459F46A5FF3665CF66A5DF46A5FF46A5DF2685BF36B5DF36E5DEF715BEA765DF68769
E87D59F48C65FA926BF79169FC9B71F49569FC9D71F99A6CEA8E5DED8F5CEA8A58EB8756
F98E62ED7E53E7734CF9835DEA724FFD8060E9634AD64834E24E40E34C41E04C42DF4C42
DC4C43E3564CDD5348DF5A4BE05E4ED45A45D45D47CE6049CE6A52C97159C0765DAF735B
87574198725DC8A592C0A091B39187B48F89D6AEAFE8BBC093646C71444B663D436E4A4C
D2B0B1CEB0AEC8ABA7CCAFABD9B7B6BD9395562427743C3F884D4F854F4F603232613B38
CAABA8C6A9A5C2A09FCBA1A3E7B0B5BD777F772229A14246AF4D4AA7463F993F369E473E
A7544CA4544BA75750A95A53A859529D4E47AC5D56A25950A2635493604FA6816FC4AA99
BAAD9AC3BDADE6E2D7E4E3DE3C3A3B3F3E435B585F58555C3C3A3D1A1917181715272322
302C2B403C3B29232328242127262223221D23241E23241F1A1A181C1C1A222222242424
2121212121232422272221261213180C0C140F0F1783838BABAAB0838383807F7A8C8C82
8C8C808B8C7E88887C898B7E888A7D8A8C7F888A7D83857877796C797B7075776C6F7166
7B7C74989993BABBB6DEDFDAF5F5F300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00DAB1AB8F463DBC4D42D44E42D94A3CE65041EF5948EF5948E74F41E54F40
F15B4CE85545EA5B4AED604FED6454E75F4FE96151EA6252E86050EC6353F06455F16558
F1645AF5675DF6665BF06153F36559F26456EF6354EF6354EE6253F16A57EC6754EE6D57
EB6D54E66A4EEE7256EB7255EE7759EB7859ED7A5BF0825FF0865FFF9870FF956EED8059
F4825DED7753EA7250EF7455EA6E52FF8468F46D57D94C3AE35142DE4A3EDF4B41E24E44
DC493FDE4E43E15146DC4D3FE35645DE5241DB5441D95A47CF5C49CB6654BC6957A66152
72392EBB8C84D6ADA7D0A9A4C8A0A0CBA1A3E4B7BEDCAAB378445083515C5F343BA57E81
DCBCBDD2B4B2CCB3AFCDB4B0D5B7B5C8A9A7866262734F4F734D4C674442674845AB8F8B
CCB3AFC7ABA8CDA9ABDAABB1ECADB69747528E2F35B54E51AF4945A6433DB3564EB45B53
B56059A4514BAE5D59994844B86861AF5F58AA5A539F524A995548793F31946958CBAE9C
BEAD9BC2BBABD8D1C7F4F1EC7F7D801E1B223D3A4559565F615F64838184575558262425
2725262422231511122521202D2C2A2928262323212426252021231E1F2128292D292A2E
1B1C2018191E21202815131E30303C4D4F5B23232F666670B1B0B68B8B8B8988838A8A80
8E8E8291938690928781847964675E7E7F7783837B85857D7A7A728B8B818C8C82838377
8183787A7C716E6F67707169878882A8A9A4D2D2D0F0F0EE00FF0000FF0000FF0000FF00
00FF0000FF00
00FF00FFF9F3D1A59C96483CC05044D24C40DB4C3EE75143F25C4DEA5443E54D3FEB5345
EB5546ED5748EC5949F36152E85B4AEC604FEE6555E75F4FE25A4ADA5244E1594BE1574A
E1574CE95D50EA5C50EE6052EF6153EE6253F06455EE6253F16556F06455F16556F36756
EE6552F06955EF6653EF6854EC6853E96751E76650E46850E16A4CE26D4CEC7555EB7253
EA6F50EF7256EF6F54EB6B52E86A53EC6B55ED6653E45B49E95B4DE15146E5554AE25247
DF4F44E15146DF4D40E14F42E24E40E14F40E25345D95040D65748CD5C4CC964589F483F
904540E6A5A3EAAEAEE5AAAEE8ADB3EEB3B9FEBFC8C5838D7F3B468F4D576D343BDAA7AC
EDC1C2E1B9B9E2BCBBDEBABADCB8B8D9B5B5CEAAAACEACABC8A6A5C1A2A0C9ABA9D2B4B2
D3B5B3D4B2B3D9AFB3F3BAC3E294A1862934B4474DBE4C4CBF524DC45C53C5625CCB6C66
C26762AA514BBD6561B35E59BE6964B9645DD27E74B06154AC6354834633A57861CFB199
C4B29CC4BCA9CAC4B8E6E3DECAC8C92B282F36333E413E493E3B44B0ADB4D3D2D76C6C6E
7472754D4B4E5856574442433636361C1D1F23262B24292F1F232C1D212A1E212A191C25
2D2D3712121C201F2D21202E373946555764595B6873737DA9A8AD908F8D928F888F8D81
9192849193869B9D927B7E7540433C5B5C565B5A554E4D484F4E4957574F606056727268
83857A797B708183787C7E7372736B696A6261605C7776728D8C88CECDC900FF0000FF00
00FF0000FF00
00FF00FFF7F2C9998FA04E42C05042D24D3EDB4C3EEF5B4DEE5849EB5546E54D3FEF5749
EC5648EE584AF55F51EE5A4CE75848ED604FF56C5CFE7668F87465F77366F57164F26E61
EE6A5DE56152E76253E96153E25A4CE25A4EE45C50E75F53E95F52ED6152ED6152EE6251
EE6553ED6452F26655F16554F26655F26957EF6654F36C58EC6851EC6851EA664FEB6750
E96550E8644FF06C57F06C57EE6956EE6958F0685AF76F61F46C5EF3695CF06457EC6053
E65A4DE25649E6584CE15146E04D43E24F45E04D43E05246D85042D85649D25950B3433F
A94140B65658B75B60B85D64BC626BC76D76D27780AA4D57A0434BAE535A87353BD2858B
EBA4AAE7A6ACE7AAAFE9AEB4EBB2B8ECB5BAEAB6BAF0BEC1EABCBEEBBFC0EBC1C2E8BEC0
E9BCC1EBBAC0F0B7C0FFB9C4BC5F6A9B2C35CA4F52CC4F4DC94F4AC44F48D96965DA716D
CD6763B1504AC66763CD7069BF655DC1695FEE9688B1604BB3694E925634B78B66CFB18D
CDBD9CCBC4A8C3BDADD3D0C7EAEAE85A595E2E2D353E3C4733313C78777FEDECF25E5D62
383639484649BBB9BABBBBBD5D5E63565A63555B69484F61464E61424A5D21283A2C2F40
A6A8B72D2F3C2C2D3F3031433235442125313133405656609D9D9FA1A09C97948D979589
9495879395889EA0957C7D75555650767570706F6B4C4B474E4F4A4F504A2526205D5E56
484941393B307E807584867B7D7F747F7F777F7C757974704C4741524F4AE4E3E100FF00
00FF0000FF00
00FF00FFF5F1C18B81A75144C55144D24D3EE35446EF5B4DF05A4BE65041EA5445EE5849
ED5749F15B4DF35C51F15A4FEE5C4DEF6050EB5F50ED6356EF6A5BEB6758EF6B5EF36F62
F27060F57461F47360F67562F57260F16D5EF47061F16C5DEC6454E86050ED6452EA614F
E85F4DE75E4CE95D4EE95D4EE75B4CEA5E4DED6150F36756F26754F26754F16653F26655
F26655F36A58F36A58F76E5CF26959F16959F2685BF46C60F56D61F1695DF2685BF46A5D
EF6558F46A5DEE6457F4685BED5F55E85A50E6584EE15349E2544ADB5146D9534ACD4C47
C94D4BC24B4DBD4A4FBE4F55BA4D52B3464CAF4047AD3E44BF5154C85B5EB24B4EAA4A4C
AA4E53AA5359B25D64B05F65AF6066B3666CBA6F74BE767AC47F82CC8A8CD39193D69599
DD9AA1EAA3ABF1A1ACD1767F9F3037C24549D24D4ED24B47D8554DC3443DCF544FD25C58
D3605BCC5D56E27570DA7269D67165D17260D17A5FB56540C37F50925B25A98048CAAF7A
D6C89BD4CEAACFCDB6CCCCC0E7E8E38E8F9124232B4947523C3A4746444FDCDBE1B0AEB3
5C5A5D4F4D509F9D9EEBEBED6D6E73262A3321273720283B253044343F553A4058373C52
BFC2D33D405125263A292C3F9FA5B56A6D7C191B28292933706E71B3AFACA6A39CA19F93
9E9E92A2A296ABADA272736B61605B878681807F7B8485808A8B868C8D8876777182837D
55544F4F50488989818C8C8484847C807D76827974857A767C716B3D342FC3BEBB00FF00
00FF0000FF00
00FF00FFF5EFB97D73AC4E42CC5446D74D40E75548F25C4EE85243E75142ED5748E95646
EE5A4CF35D4FF35C51ED564BF35D4FF35F51ED5E4EEF6251EE6251EF6654E96151E96453
E76450E3624DE86751E4664FEB6A54E86751EE6D57EE6D57EF6D57F2705AF16D58F36F5A
F26D5AF26D5AF06858ED6454E96050E55C4CE55C4CE55C4AE45847EA5D4CE95B4DEA5C4E
EF6153EC6051F16554F26655F46857F36A5AF5695CF06659EF6558F3675AF26659F4685B
F1675AF66C5FF46B5BF1695BF06A5EEC665AEC6359E75F53E05349E6584EE15349E1544B
DD5650D95853DA5E5CDB6362D86464D46060D35D5DD25C5CD1595AD25C5ACF5B5BC95756
C45655C25656C3595BBA5052B44C4DB74F50B44D4EAC4848AD494BAF4D4EAD4A4DAC494E
AE494FAD454CB2434AAF383EC13F41D64E4ED84D48D84B44D94F45D64D45D24B45D5504B
D7544CDA5A51E2665CE26A5CDB6B57D16A4BC26A3CBF7538A66C23805506B39442C0AD61
DAD093DDD9ACD7D6BAD0D2C4E0E2DDBFC3C427272F54525F4B495735313FABA8AFF0EBF1
E3DEE2D6D2D3CCC7CBEBE9ECDAD9DE888B9060646D444A562831421E263D3D425F4E526D
A7ACBF70768615182B262B3E8B91A1787B8A1A1C2925252F38363B928E8DB0ADA8A6A39A
A5A59BA4A69BA9ABA072736B77787262635D6465606A6A686667627475708988849B9A96
9A969383827D8A8782999691999490988E8C988888927E7D998481614E4A988D8B00FF00
00FF0000FF00
00FF00FFEEEAB26F67B55046CD4F43DE5245EE5A4EEF594BE85244E54F40F05D4DEA5747
EF5B4DF66254ED564BF35D4FF05C4EF26150F16251EE614FEC644EEB644EE8664EE7674E
E76B4FE0694BE06B4ADD6B49E06E4CDD6B49E16E4FDE6B4CE16B4FE1694EE66D52E5694F
E66A52E96B55EE6D5AF26D5CF36B5DF66E5EFA7161F46B5BF46756F36655F06254EA5C4E
E95B4DEA5C4EE55847EB5F4EE35746E75B4CEA5E51E85C4FEB5F52EB5F52EC6053EF6356
EE6459EE665AED6859EE6A5DE66659E9695CFB796CF77166ED6056EB5B50E9564CE35348
DC5248DA574FDB625AE1706ADD706BDD716EDF726FDB6E6BDD6D6BDA6867D96663DB6865
D96864D96965D76765D56362D36160D2605FD56561D0605ED0605ECF5F5ED05D60CB585B
C95558C85153C94C50D45254D95350D64D47DA4F48D64C42DB5147D3493FDD5049DF5249
DC4F45DD5348DA5246DB5949D25A42C85E37B55C24CF8B40D5A448BF9D3BC7AF4BC2B356
D8D087E2DFAADEDDBED9DACADCDDD8E8E9EB515159363441555361484452807D86F2F0F5
F3EEF29994986D686CB2ADB1EEECEFE5E6EADFE2E7D5D9E2CFD5E3596073313550545571
84879ACCCFDE434655181B2A23273325273319192521202819171C64605FB9B5B2ACA9A2
AAAAA2A8AA9FA9AAA283847C74736E6667618F8E8A72736E50514C51504C5756526B6764
74706D5C5855696562A098969A8E8EAB9798B99B9DBF9B9DCEA8A7A684827B635FF9EBE8
00FF0000FF00
00FF00FEE5E0AF665FB84D43D24F45E5554AF15D51EF574AE24C3EEF594BEC584AED594B
F36251F05F4EEF5B4DF15F50ED5E4DEF624EEA624CEA664DE7674AE16849E26D4ADF724B
E0764CDA7549DD7D4DDA7B4BD67A49D37748D97C51DA7A52DA7853DC7854DE7555DE7353
E17256DF6D52E46C54E56751E86553ED6555EE6555F46857EF6251F36454F56857F7695B
F66A5BF36758F36756F16554F26657F26959EC6255EC6255EA6053E55B4EE55B50E75F53
E55F54DF5B4FE36358E36559DE6459E1675CFA7A71F26D64F0665BED5D52EC5A4DE25446
D65245CF594BB95146AD5048B35E59B4635FB5615FBD6766C56B6ACA6C6CCD6B6AD67270
DE7874DB7571E07A76DE7673E07974DC7570DD7470DA716DD86C69DA6D6ADB6B6ADB6968
DC6868DC6664DE6463DC605EDC5D57D95852DC5C53D9564CD8534ADD574EDD524BE05349
E05045DF5143E05447DB5643D3573DCA5E37AF591ECC8A3CE9BD5ADABE50D4C252D1C65D
D9D37FE8E4A7E8E5C2E1E0CEE0DFDAF4F4F69A99A1201E2B454351555361595762DDDCE2
D8D6DB57555A656368838186EBEBEDEDEDEFE6E7EBE3E6EBF5F9FF979AA9232439484860
69687AE7E6F4C8C6D18281895A595F4443482A292E1A181D29272892918FBEBAB7B3B0AB
B0B0A8AEAEA6ABABA3A8A8A0A29F989E9E96ABA8A1A0A09896968E8F8E89807F7B61605C
4E4D484D4C475E59569D91919E8588AB878BDBA6ACEFB3B5F6B9B8C38C89714842E7CEC9
00FF0000FF00
00FF00F8DCD8AE635DC05148D65148E5554AF25E54E85146E65042EF594BEA5648EF5B4D
F36251EC5D4CEB5C4CF06351EC644EE6644AE56A4BE16C49DE724CD8754CD2754CD27B50
CF7E51CC7F51C87E4FD18959CA8355C27E51C67E56C67D5AC77C5CC67758C87458C77156
CB7159CB6C56CF6855DE6F5CE56D5CE86958E96453EB6451F06552ED604EF16453F16453
EF6153EE6253EF6352F26655F06455F26657F4685BF5695CF86C5FF46A5DF46A5FF36D61
EC6A5DE4685EE06B61DD6D62C4584EB7483FD7605AEA6B64ED675EE95C52EC5D4FE55C4C
D95A4BCF604F8F33247226197131286C312D6A2E2D7032337A38397A34348A403F924442
9B4C489F504CA04F4CA95854B05D57B4615BBE6964C46C68CA716DCF746FD27371D16F6C
DA7772DF7975DC7370DE726FDA6F69DD7069E3746DDD6C64DF6862E46761E96560E75E56
E05349E25649DB5144DA5848D35C44CE6842BD6C37BA7B34EEC367E3C85FD7C559D8CC68
E0D988D1CD90D7D3B0E0DDCEE1E0DCF0EFF4DEDCE7403E4B3330414744554D4957B7B4BD
D8D5DC3F3D4238333A8E898FF2F0F3EAE8EBE6E6E8E2E3E5EEF1F6C5C8D127283A403E54
454255BFBDCBE9E6EFD5D3D6C8C6C7BBB9BAAAA8AB989697A8A7A5C2C1BFBFBBB8BBB7B4
B4B3AEB7B6B1B6B3AEB3B0ABB1AEA7AEABA4AAA7A0A8A59EA9A9A1A6A69EA8A7A29C9B97
91908B8887827D7573978486AA878DB68189CC838AD88388CE7879AB5D598A4F49CEA9A1
00FF0000FF00
00FF00F1D4D0AA5D55C25348D75249E7574CF25E54E85448E85446EB5749EF5B4DF15D4F
F46253E65948ED6451E46049E66A4EDC6A46DD7349D8794BCC7A4AC88251C18458BE8760
C18F6CC08F6FC29473C49577CD9E82DAAC92E4B49EE3B39FDBAA99E7B3A5EAB1A6ECB0A6
EDADA4EFABA2E79E97D58176CD6959DF705DEA715CE96B54E7634CED654FF06351F06352
F16453EC5F4EF16355EF6052F26355F16254F16355F16355EF6153EF6354EE6255EA6458
E4695ADD6D61D57368CB7169A24B447C211E9B3332C75353E76862ED645CE95C52E86054
E16354CC6151822F1F5A1B0C56261C4C251E4A27254A26264F2829542A2C5A2C2E5E2E2E
5A2A285F2F2B61302C612E2B6B383464312D743F39733C37763B377D403B82413F823E3B
8E4745944A47984D4A994B47994B47A2534FAF5B59B05655B65755C75E5BD35D5BDB5B58
D6514CD6514AD05148CA5446C55C49C66C51BF754EB07440E1B671E7C876DDC771D9CA77
F0E7A2B1AB797E7A5F88867A969696ACACB4BFBFCB5655653D3C4E423F52453E508B8593
F5EFF9BBB6BDA69FA6E2DBE2F1EBEFEBE6EAE6E4E5E1E1E3E7E8ECE5E8EF41435228293D
2B293E797687E9E6EFD9D4D8D1CFD0D3D2D0CBC9CACCCACBCCCBC9CAC9C7C8C4C3C9C5C2
C3BFBCC2BEBBC0BCB9BDB9B6BAB7B2B8B5B0B3B0ABB4B1AAB1AEA7ADAAA3ACA9A4A3A29D
ADACA7B5B2ADB8AEADB89FA2B58A91CA8991AB5059B74E55C35757BE5D57A75D54B08179
FFF2ED00FF00
00FF00E7C8C5A3544DC35348DB574BEA5A4FEE5C4FE85446EE5A4CEB5749F05E4FEF604F
EA5F4CE7604AE7674EE06949DC7147D47442D17F47D08A4FC99158BF915FD3AD86E7C5A9
E8C9B4E6C9B7EACDBFEFD2C4EFD1C6D2B4A9C5A79FC2A39EF2D3D0BFA09EAF8B8DB1888C
B2888CAD7F82CE9A9CFDC0BBDC8F7FCA6E57E1785BE67354EA7152E8684BEC654FED624F
F26655F06352EF6153F26355F16254F16254F26355EE5F51F26456ED6152EF6558E76557
E06C5DDF7A6EA35146D18D8494534F5D17156716158F2D2EC65453E66965E8615BE55F56
E16355D9695B9D4434611E0E48180C411F163A211C372221351F213B25273A2222402627
4026254229254A2C2A452725503230492C2850312C4B2A254F2C284F2926552C2A592D2C
5D302D5F2F2D62312D67363263302D67312F662C2B723232772B2D893032932B2CC14D4D
CB4F4DC94E49BF4C45BF594DB55D4F934A377A3E246F411D886434846A317D692C807136
8B835279755058554255544F56555A5C5C665756643D3C4C3F3E503E3C51413E515D596A
A8A4B2ACA9B4C3BDC9D4CED8DFD7E2E6DFE7E7E2E8E4E2E7E1E2E6F1F4F9848692111320
14132142404DD7D4DBE1DFE2D8D6D7D7D6D4D5D3D4D4D2D3D3D2D0D4D3D1D5D1D0D2CECD
D0CCCBCFCBC8CDC9C8CAC6C5C6C2BFC5C1BEC4C0BDBFBCB7BDBAB5BAB7B2B6B3AEAEABA6
B1B0ACBBB6B3C5B9B9CDB4B7C99AA2D48D95B34F59B23F46C85052C15451B05C52915B4F
EED9D400FF00
00FF00E3C2BDA3534AC35146DC564AED5E50EA5849E55242EB5A49F46352EE5F4EE9614B
E56349DE6546DE6E48D57140D68045D28945CE9249CE9E56C9A567DABF90F0DBBEDFCCBD
BEADA6B3A19FF0DDDFDBC7C9907C7E6F595C5843486D585FD5C1CA6B576268525F6A5262
6C505F6747545E3940C49895FAC2B1C27D5ED07B52DB7A4DE0764CE7764EEA6F4EE7654B
EC6551EB624FF16453F16453F16453F16453F06352F06352ED604FF26657EC6758E36859
E2786AC66E6279362D89574EA47973A67974703634631C1A842928C35554E46866E76660
E46157E1675ACE6353933A2A5F1D0F4315083A1C14301D172E1E1E2D21212D1F1F2E2020
2B1D1D2E201F39272733211F463432392723402F283A27214B36313924213A25223B2623
402826422A28402723482C29402423482A2A442221512728511A1D611B1D691012B34B4C
CA5A58C95955CB6560BB645B9B584F5F2E20441F0F452A154731194435163F35123A3414
3433172A2B193C3C3440404044454A45454F3A39472F2E3E3130423132463A3C5146495C
5455674D4E60535166615F7474718284808F9B95A1DBD8E1E1E0E5E7E8ECC8C9CE7E7F84
65646A545358B8B8BAE5E5E5DBDBDBDBDBDBDADADADADADAD9D9D9D6D6D6D7D5D6D7D6D4
D6D5D3D4D3D1D4D2D3D2D1CFCECDCBCDCCCACBCAC8C9C8C6C5C4C2C5C4C0C2C1BDBCBBB7
ABAAA8A8A4A3B8AEAFC1ABAEC499A2DD9AA3B2535BA33238C24A4CC65652B75D5483473C
CAB1AA00FF00
00FF00E1BEBAA7544CC45247DF594DED5E4EEA5849E04F3EE65746EA5D49E65F49DF5F42
DB6442DB7046CF6F3CD27E40D18941D19646D7A858DBB76DCDB579E7D8AFD8CBB8E3D8D4
C6BBBFBCB2BAE8DCE68175816759665D4F5C392C36B3A5B2988C9A574A5B56495B4E3F54
564359675062452A33957270FFDAC5DCA47FD48E5BD28149DA7F48DE7A48E7784DEC7451
E9694CEB644EED624FF16453F06352F06352F36655EF6251F26554EE6555EA6858E26E5F
D9796BA2584B6430254F2A2272554FB59892B6918B6C393657110F862E2CC35B5ADF6967
E36660E0645ADB6559CB6153913E2E5B1C0D3F130832170E2C1A16271D1B271F1D261D1E
241B1C261D1E312726291F1E3A302F2E2422352C273229243A2F2B3025212E2422342A28
332927372D2B3628272F21202E201F423232352122472A2C4117195C1E21640F12AD4949
CA5A58CC5C58C8655FB161588E554C48231A30180E30221731271B362E21322C1E2C2A1D
2D2D231F201A2929272B2C2E32313735343C36343F2C2A372C2B392A2C392124331A1D2C
2326353235443437483C3D51474658484556464250BCB9C2E6E5EADADADCDDDDDFDBDBDB
DADADAD1D1D1D5D5D5DEDEDEDDDDDDDEDEDEDEDEDEDDDDDDDEDEDEDBDBDBDCDADBDDDBDC
DDDCDADCDBD9DCDADBDBD9DAD8D8D6D6D6D4D7D5D6D4D2D3CFCFCDCFCFCDCFCECCCBCAC8
B7B6B4A09C9BA69DA0AD9A9EC5A0A7E5A8B0BA5F689A2B32C54D4FC65551B85C5188483C
A0857CFFF8EF
00FF00E1BAB5AA574FC7554AE25C50F16252E75546E45544E65B46E35F48DE6143D3613C
E77E4FD77A41D48341CD8539D1933EE2AE58EDC06FD7B470D5BF8DE0D1B2CDC1B5E1D8D9
BCB6BAE8E1E9C0B8C5645C6B5C5461423745706671D4CAD56E6373453C4D5F5667706478
4739506350633B212CB18E8AFFD3BCECB58CF7BA81E7A261D18440D37E3DE08046E67A4B
ED7751E76848ED654FEF6250EF6251F06151F26355F16355ED6150EA6554E26958E37969
C473626F342653281F4A2D2544302959443F9F8681BF9E996E3E3A521512823432B45656
D76A67DD6763E36861DB655BCB6153984032601E103D110630150E291A15271D1B241C1A
292323241E1E29232325201D3C34322A221F352D2A2D26202B241E2A231D362E2B2F2725
322D2928231F271D1B2E2422251B19352A283123223D2427370D1158171B6A1012B54947
D55B56CB5249C05649B4615390584B3F1D132A1710261D1626211B27241F24231E1F1E19
2626241F1F1D1C1C1A1E1E1E211F222321262C272D2621282522291411183F3E43636267
4A4B4F363A3D1E23271F222B2424301D1B281D1A2584818AE9E8EDDBDBDDDAD8D9DBD9DA
DDDBDCE0DFDDE2E0E1E1DFE0E1E1E1E1E1E1E1E1E1DEDEDEDEDEDCE0E0DEE0E0E0E0E0E0
E2E2E2E3E3E3DFDFDFE0E0E0DFDFDFDFDFDFDEDEDEDDDDDDDCDCDCDBDBDBDCDCDCD9D9D9
D3D3D3C9C7C8C5BFC1D2C2C5E2C5CAF6C3CABE6B7391282DC34C4EC4534DBC5E548D4B3F
8C7065FFF6EC
00FF00DDB4B0AC584ECC574DE35D51ED604FE45545E15442E4604BDF634BDA6B4DD26F46
E18755DE8E4FD68E44D99846E5AC55F2C06BE2B86EA8884DDBC59EDBCFB9E3DAD5C1BBBF
CBC6CCEBE5EF777382524E5F413D4EA7A0B0F3EBFA958D9C453C4F3E3749D4CCE1D1C9DE
50445A4C3D50422B35E1BEBCCE9B88BC7D5AF2B07CFFBC7BF1AB63D98C44D6813EE08044
E27645EF7850E96849ED654DEF6250F26353F26355EE6052EF6654E56653DF6E5CD87B69
9E59495C2C1E45271C3D2922402E2A3E2F2A4C3935A9918DC4A5A0683F3B521A19772F30
AD5554CF6766E16B67DF665EDF695DCE64569F493A5F20113C11083017102D1B17261C1A
27221F262221221E1D272322332E2B26211E322D2925201C2A252126211D312C282A2521
2A2722282520221D1A352D2B2A221F342C29312525361D203B11155715196F1014C24E4E
D4554ED15347C65849BB64539157493D1D1026150D211C181D1C181F1F1D1D1D1B1F1F1F
2020201A1A1A1B1A181F1B1A1D1918211D1C251F2121181B140E103E3838B0ACABDCD8D7
C7C7C5B8BAB7A2A6A59094957E7F8466656D4B484F646168DCDBE0DFDFE1E0DEE3DFDDE2
E2E0E3E6E4E7E5E3E6E3E1E2E1E1E1E1E1E1DFDFDFDDDDDDDFDFDDE2E2E0E2E2E2E1E1E1
E5E5E5E6E6E6E0E0E0E2E2E2E4E4E4E1E1E1E0E0E0E2E2E2E2E2E2DFDFDFDFDFE1DFDFE1
DFDFDFE0DEDFE1DBDDE6D7DAF0D7DDFFD7DEC87B83852227BC4849C04F4BBD5F55914F41
8D6F64FFF5EC
FFF7F4DAAFA9AD564CCC584BE76253EA5D4CE25544E45B49DE614DD96B52D07155C87450
D28857DA9659DC9C54EAAD5DF5BA6AE9B5699E7537BD9E70E6D5B9DDD3C7DFD6D7A7A0A7
EAE5ECBFBCC7595669504D62403D52948FA3AAA5B95850654840584F475FA39AB57C748C
50445A352738816B77F6D2D6AD7169B56854CE7A55E3905CFFB672F9B469DF9347D9873D
E28343E67B45ED734CEB684AEF674FEF6250EE6150F06455EB6353E46957DD7461C57461
79402F4C281A3C261B382922382A273527243D2E294E3B35937B77BEA29E8E686550201E
692929A35251CD6765DE6D69E26960DC685BD0695AA34D3E5D1F103C1206331811291A15
251B19231E1B272320282421302C29221E1B312D2A25221D2E2B262C2924322D292D2824
27241F2C292225201C312C2827221F372F2D25191B3A1F244114195A1319761316C54D4E
D8544FD25245CA5B4ABC63518C53423C1C0D23120A221D191D1D1B1618171A1A1A202020
1E1C1D1D1918211C191C17131F1A16241C191C1210251A18746A68CFC7C4DAD5D1D7D3D0
DBDAD6D8D8D6DBDBD9DCDCDCDDDDDFDEDCDFD3D1D4CBC9CCDEDDE2E1E0E6E5E2EDE7E3F1
D9D7E4BDBBC6B7B6BCD9D9DBE0E0E0DEDEDCDCDCDCDDDDDDDFDFDDDEDEDCDFDFDDDEDEDC
DEDEDEE0E0E0DFDFDDDFDFDDDFDFDDDEDEDCE0E0E0E0E0E0E0E0E0E0E0E0E1E1E1E0E0E0
DEDEE0DFDDDEE1DBDDE6DADCF2DBE1FDD4DAC17A82B25359B24143BE4E4ABC5B52975346
937368FFF4E9
FFF7F2D5AAA3A65247CD5C4CE56152E95D4CE25645DB5A47D86854CB6B55CB7B64DD987B
E1A37CE0A470E5A869F5B973F2B771B38041A07847E3C9A8DDCCBAE3DAD3C9C0C3CCC5CC
F9F4FB88828E4E495D504D624D485E5A55695C5469574F64544C64534B635D536C574D65
4237482F2130D1BDC8FFE0E7E9B1B2BE756EBC6A55BD6945D88F58FDB873FBB669DC9346
D58139E58344E77747F1754FE76448EB634DEF6352EE6555E86553DF6A58DB7A67AB6251
5E2F1F40231536251B31262031262231262440322F3D2E2942302C83706AC1A9A5987674
5427246D302F954441C5645EE06F67E16C62DE6D5FCC6657A14E3E62231445160C381710
2A120E2C1A163224212B201E332927271D1B362E2B2C24213029232D26203029232E2721
241F192E2923241F1B2D282429242130282627181B3E212543121860171E7A1317CC5251
D9544DD45245C85745BF67538A513E3D1D0E25140C211C181C1C1A1717171D1B1C201C1B
201B18231B18251A161D130A1D13071910014B3F33A99C93DCD2C9C5BEB88C8783B0ACA9
E2E1DDDDDCDADDDCDAE0DFDDE2E0E1E4E2E3E8E6E9E8E7ECE9E9F1E5E4F2D1CFE4A7A5BB
6E6C814F4E5E514F5AB1B0B5EFEFEFE2E2E2DEDEDEDDDDDDDEDEDCDFDFDDDFDFDDDFDFDD
DFDDDEDFDFDFDEDEDEDCDCDADBDBD9DBDBD9DDDDDDDADADADCDCDCDBDBDBDBDBDBDCDCDC
DCDCDEDDDBDCDFD9DBE3D7D9EED9DEF5CDD5CD878FDC7F87A33538BD4D4BBB5A519D574B
99776DFFF5EA
FFF8F2CFA79FA65448CA5A4CE56355E35B4BDD5847DD6453CC6657CA7769C17F73AF7567
D09881ECB491F8BB8CF8BC86D89C68A87546C7A582EFD9C4EBDAD2DCD1CFC4BABBE0D5D9
EEE5EA918790362D3E40374A443D4F484151463D4E443B4C443B4C43374B3F324436293A
3426338D7D87F8E3ECFDDFE7FFDCE4FDCBCED59691A35B4CB26845D38C58FCB877FBB76E
E1954ADC8540E67F45EC794CF07150EF6950ED6452ED6857E06351DE715DD47B69914E3D
5126163E241738271F2C211B2E25202F2523372E293D322C42352F473831705D57A68F89
8667646F43406B302C8F443EBE6058DC7167E37166DA685DCD6558A84C3F6F2115511108
3C09053B120E43211F361A173D25212E1B1533221B35261F32251F2D201A32251F362B27
281F1A332C2628201D362E2B261E1B3227252E1B1D4324294510185F12187D1418CE5250
DA544BD25042C75844BC6551874E3B3E1E11291810211C181D19181B1718231A1B231918
2A1C192B1C1528160C1F0E002B1D02706343CCC1A3C9BFA67973638F8B82AAA7A2D0CCCB
DFDEDCDEDDDBE1E0DEE3E2E0E7E5E6EAE8EBEAE9EFE1E1EDBEBFD38C8EA7606180565678
6667855E5E76343341747379F0F0F2E6E6E6E1E1E1DFDFDFE0E0DEE1E1DFE3E1E2E4E2E3
E9E4E8E8E6E7E4E2E3E3E1E2E2E2E2E2E2E2E1E3E2DEE0DFDFDFDFDDDDDDDEDEDEDDDDDD
DBDDDCDDDDDDE0DCDDE4D9DDEDDADEFCD4DCD8929ACB6E76A03235C0504EBB5A519B5549
9C7A70FFF3EB
FFF8F2CDA59DA6574ACD5F50E36556DE5B49DA5D4BD46554C26A5ECA847C9F686562312C
8C584DE3AC97F9BD9BDBA078B67F58B28663F2D3BEE6D4C8F1E3E0CABEC0E0D4D8B5A9AD
BFB2BBDED2DC817485605566514958534B5A5E5363625765675C6A655A686C5E6D817380
C3B3BDF5E4ECF9E4EDF9DFEAFBDDE9FFDBE6FFD0D6E2A8A6D69382B56C4BD6905CFFBC79
F9B469DE9046DF8342E87E4AED764EEB6C4CEA6651E76653E36B5ADD7663C1705F773C2C
4C2619422A1E3829222D241F2C24212D2522332C26362D28352A244237314435305A4942
6E59549A7D79A37A747E47408B4138B95F56D87067E5756ADD6B60D16356B853478F352A
6717105E1711662521511612541F1947160F4F231A471F17421D153A180F43201A43241F
371A143F231F3418154024213118143E22213B191A491C2154161B630E138B1A1CD65653
D94F45D65142C95643C469548745353F13082E110B2A15122812142C1316301413331612
381A123114042E1400523C159E8C5AB3A6719086558179529A967DDEDACEE4E1DCE3DFE0
E2DEDFE2E0E3E9E5E6EEEAEBE5E3E6CBCAD0A1A1AD696A7C464861464968595C7F6D7093
5B5C7A3E3C542C293A4E4B54E3E1E6E9E7EAE1E1E3E0E0E0E0E0E0DFDDDEDFDBDCE3DEE2
EAE4E8E7E2E6E6E2E3E1DFE0E1E1E1E2E2E2E1E3E2E0E2E1E2E2E2DFDFDFDFDFDFE0E0E0
DEE0DFDEDEDEDFDDDEE5DCDFEBDBDEFFDBE2C9868FC3666EAD3E44BC4A4ABD5A549D544B
9E7C73FFF3EB
FFF6EFC59D95A8594CCA5F4DE36856DD5E4BD35B4ACF695AB96D60B77E77C6989AB98F91
814F4ED29990F0B29DC08367946345CAA68CE3CDBFDFD2CCE7DBDBC4B7BEF2E2ECDCCCD6
DCCCD9F0E2F1E4D7E8D6CBDCC9C0D1C7BFCEC9BECEC8BDCBC1B6C4BFB5C0D2C4D1CEC1CB
C9B9C3C5B4BEC6B2BDB8A0ADBBA1AEB496A294737EEEC5CBEFB8B5AC6956BA6F48E3985F
FFBF78F2AD60E9974EE18144EA7C4BEC744FE8684DE66955DE6E5ADB7C68A75E4D622E20
4E2C203E2A213528203229243028252D28242C272129241E302923332C263E332F473A34
4C3D3865524C9E827EC7A29AA8736DA55E58B75E58D7726AE7786FDF6A60DA6659CF5E50
BC4C41A73B319B30288D261F88261D7B1D13721A0E6D190E6012065E140B5D140D5F1A13
55120C61221B50110C591C195217135B1F1E5416195E191C610F156E0B0E991E21DB5451
DC4D45D84E41D35848C861508F3D2F4E0B02450B09420F0E3F080B480D0F490C0B4B0F07
4B1302582A08926E34C6AB64B19E52887A31938A49CEC793E9E4C4E9E3D3E9E4E0E8E4E5
EAE5EBE7E2E8D6D1D8ACA9B077767E50505A4042513C3F5243485E4B4F6A656986686985
3F3D552E293D261F2F342C39C9C4CBF0EBEFE2E0E3E1E1E3E0DEE1DFDADEE6E0E4F0E9F0
AAA0A88D878BE9E5E6E5E3E4E0E0DEE0E0DEE1E1E1E1E1E1E1E1E1E0E0E0DFDFDFDFDFDF
DDDFDCDDDFDCDFDDDEE5DCDFEADBE0FFDFE6B87680BA5F68BB4951B94649BC5954A15851
9A786FFFF5EC
FFF6EFC19991AB5C4DCE6351E16654DA5D49D46450C46756C17D7292615DDDB4B89E767E
68353AD49A98DD9D93AB7060A17663EBD0BFCABBB4D5CBCAC4BBBED6CBD3EDDFEC9F91A0
9A8D9E988D9E8E8296898093847D8F867F917C75877E7787716B79716B7779717E7A707B
7A6E7A887A878C7C8987737F8C7683745E6A7D6773F6D8E0FFD8DAC88D85BB6F55C57749
F1AD6EFEBC72EEA459E58E49E68149EA794FEA7152E06850DD725ED47B69995A4B4C2013
452A1F3B2A22372C262F2822332B282E292527221C25201A2A251F2A251F342D2739302B
4439354A3C3955443D806762BC9590CE9794C57C76C86D68C9605AED7B71E47063D76153
D15B4DD15B4DD1584DCD5449C34A3FC14B3FB14032A6382B9E3427912B1F8F2A2089281F
7E20187E211A791F17741B156E17106D18136C14136F13146F0B0D770608A02021DC5250
DB4C44DD5144D25344CF5B4C9A34286A0D065E09065E0A08630B0A660C0B6D1009792012
7C2F15A06233E8BC73EED07AAB953F645502A49C54EEE7B0F3EDC9F1ECD9EDE8E4DFDADE
B7B2B98380895C566047444D46464E454851474B573F425344495C52576A5A5B6F3F3D52
322E3F2B24342D22322B202EA79DA6F4EFF5E3E1E4E0E0E2E2E0E3E3DEE2F5EFF3D4CBD0
261F262B2529D7D1D3F0ECEDE3E2E0E1E0DEE2E0E1E1DFE0E1E1E1E0E0E0E0E0E0DFE1E0
DEE0DFDDDFDEE0DEDFE2DCDEE9DADFFFDEE5BA7B84AF555FBE4F58B54247C05D58A25952
99776EFFF5EC
FFF4EFBB938BA65446D06553E16654D85E49D36652C06958BE7F76906360D8B1B68F666E
A67177CC9092C687829C665CD8B3AAE2CEC7DCD0D0CEC8CCB0ABB1F2ECF6B7AFBE635C6C
6B667A615E735C596E57556B5A586E5C5A705D5B71615F746263776364766B6A7C6F6C7D
6E6A797872807D72827B6F7D736670544750BDADB7FCE7EEFFDFE4EDBDBBBF7A6AC77B59
D89560FFC17FFCB86FF2A55FF19356F48859ED7857DC6A52D7725ED382719C64574E2920
39251C352A242E27212E2623332C262F28222E26232A25212C27232C27232D2522352D2A
3C3431413833463B37523F3B6B4C499F726FC88888ED9E9ACC6D67C05950E68072EF8B7B
E3826FD77461D06555CA5A4CCF5B4CD35D4FCF594BD35D4FD25C4ED35D4FD05A4ECB554B
C44F45BF4D43BC4A40B34338B14237A93A31A33631A1312D9F2C299C2221B63230D54E4A
D64D45D74F43D34F42D05043BE4439A32C249E2721A02923A12A24AC332AB0372CBF4F39
BD5B38B16430F2C175F7D782A9903E8E7E31D7CE8BECE6B2DFDABAC4C1B094908F67646B
4B485145444C4A47504B4A5247474F3F42493C3F463B3E47393C45393C4533313C2C2934
322C382D25322F23312719288F858EF6EFF6E5E0E4E2E2E4E2E2E2EBE9EAE3DFE06A6466
6560643D393AB7B1B3F4EEF0EBE5E5E9E3E3E6E2E1E5E1E0E3E1E2DFDFDFDFDFDFDDDFDE
DFE1E0DEE0DFDFDDDEE2DCDEEADBE2FFDEE7BE808BA9535CBC5159B8474BBD5C56A35A51
9A786FFFF3EB
FFF3EFB78C85A75547D26755E26956D85F4CD26755C06A5BC0847AAB7E7BC29B9EBD9299
C69197C3888AAA706EAA7A76F0D3CFDCCDCAD3CACFBAB5BCD3D0D7ECE9F47D7988636073
615E734D4B603E3C51323045312F452F2D4337354B43445952536855586B424355373948
343341403C4A4B45514C444F3F353D685F64EADFE3F4E5E8F8DFE5FFD8D8CF9186C47D61
C78352FABA7AFFC277F3AE63E78D4EF18956EC7C57D5694FD67765C175679F6B607F5E55
5948403E352E312A242A251F2F2822312A242F2724352D2A2A25212C27232E2623312926
302B27322D294036344738355238375E34357E4242BA6C6CB85955BB544BE88274FD9C8B
FFAF9DFFA894FC9584ED7F6EED7E6DE87765DB6A5AD56454DC6957DA6554E1695BE1695B
E46C5EE86F64E16B5FE26E61DD6C5ED56557D56559CE5E53D05E54CF5A51D35650DB5C55
DF5C52E36154DD594DE05A4FD9534AD9534AE25951E45B53E1584EE05A4EDA5647D65E46
D06946B36332E5B271EDCC85C8B16DBAAA6EAFA57089865D6C6A5158564A4745464B484F
4A49514241494241473C3B4137363B2F303433323726252A27282A2727292B2A2F2C2A2F
2F2A312F252E2C1E2D2315248B7F89F8EEF6E5E0E4E3E1E4E2E2E2F5F5F5A19D9E706A6C
E8E4E57A7677ADA7A9BAB4B6B6ADB0DFD6D7E9E3E3EBE5E7E8E4E5E3E1E2DFDFDFDCDEDD
DDDEE0DDDEE0DDDDDDE2DCDEE9DAE1FFDEE7C38A939A4952CA6168AE4043BD5C55A0584C
9A786FFFF4EC
FFF1ECB1867FAB594DD26757E36A57D9604DD06553C56F60B77B70B98C87C69C9EE2B8BC
C79397B683829D6D6BE1BBB8E4CFCEDED2D4CEC4CCB7B1BBF2EFF8B3AFBD5653645C596C
4440517C78879F9BAA94909E8F8B99908C9BA5A2B35F5C6F535065403D504A4856A9A7B2
A19EA5A6A1A7AFA9ADB5AFB1B8B2B4D2C9CAF1E9E7F0E4E4F4E1E3FFE2E0E3AFA4B27257
BA7846EAAB68FFC778F9BA6ADA8542DA7740E0744DD97156CE7662AD65576F3D347A5952
86756E7E756E5E574F3F3832342F292D2822292420302B272D2522322A273028262B2321
312C28302B27382E2C3D2D2D482E2F5A30326725297D2426A43B38E37069F48277F9897B
FE9484FF9787FF9281FB8D7CFF9583FF9C89FF9E8BFF9E8BF5927FE88371E47A6ADF7565
DD7363DC7264DC7566DA7666DC7D6BDE816FE68978E98979E78676E98575E67A6DF18175
F47C6EF5796DF9796EF57067E75E56EF645DFD7069F1675DE95F55E66255DC6151D66753
CA7153B5714CB3875A977B4C6E5B315D502D4E492C44422D4E4E424B4A46464646424146
37353A3432373634372823272823272B262A2A28292321222929272727252929292A2A2C
2E292F2A232B3024322A1C2B827680F4EAF2E7E1E5E4DFE3E8E6E7E9E7E8928E8DA39D9D
877E7F867D7EC7BEC182797C433D3F585254857F81ABA5A9C6C0C4D8D3D7E1DFE0DEDEDE
DDDFDEDCDEDDDDDDDDE2DCDEE9D8DEFEDDE6CC949F8A3D47D46C75AC3F42B857509D5549
9B7970FFF5EC
FFF1ECAA7F78A8564BD46959E36A59D65D4AD36554C26957C68476E0AEA3AB7E79C39794
B88B86A97E78AA8781EFD3D0E0CECED6CACEBEB3BBE1D7E0EEE6F17E78865B5768524D61
3B3748C2BBCBF1E9F8E7DFECE6E0ECF0EAF8D7D3E26763744B465A242031A8A5B0F8F3FA
EBE6EAECE8E9ECE6E6EDE7E7EFE9E9F0E8E6EFE7E5F2E6E6F7E7E8FFE3E2F7CBC2B27A61
B37343D59653FEC775FCBF6EDC8C45CC6C32DE774ED77254CD7662AB655965352B52312A
594640776C66918881857C756A635D453E38342C2929211E28201D332B282F27252F2A27
2D2824312C28352B2A3E2C2C44272957262A63181D7C1C1EC75554E86D66E96D63EC7265
E87264EB7567E97161EE7968EB7A68F08573F48D7AF5927FFF9A88FF9887FE9484FF9484
FB9181FD9383FB9684FC9986F99A86FDA18CFFA694FFA694FFA290FF9B8BFD9687F98B7C
F37D6FF07468E9695EEF6960EC635BEC6258F2655CE95F55E86257DF6455D76759BF6250
A159438A573C6C482E513C2142361E463F2C433F333A3A323E3E3C383A39323234333237
28272C27252A2C2A2F262125292428292428292526292524262521282924252523232321
262427251E262E22302C1E2D796D77F5EBF3E6E0E4E4DFE3EEECEDDBD9DA9791917D7777
89817F83797ACDC4C7D3CACDD2CCCEBBB5B78882842C26283E383A9B9597E8E4E5E2E2E2
DEE0DFDEE0DFDEDEDEE2DCDEE8D7DDFEDDE6D29DA7853842D9717AAC3F42BB5C56995349
9F7E75FFF5EC
FFF2EEB28780A65449D5675AE66B5BDD604ED86552CF6F59D08570BD84718455457C5544
A88474AD9080D3BBAFDBC8C2EAD8D8CEBEC1CCBBC1F8E9F0CCC1C95E566160596B524D61
49445A736E82827B8D7D7688857E908B84967770825B5466393242453F4DE4DFE6EDE7EB
E9E3E5EAE4E4ECE3E4ECE3E4EDE4E5F1E6EAF3E8ECF6E7ECFAE7EBFCE2E3FFDAD3BC8A73
B6774BC48444FBC474FBC16FE1934BCD7033DD784CD77455CE7763A6615265342D54332E
4D38354D3E3B5B4D4A786D699186829085816E65604F4842362F292A251F27221E2B2622
2C27232F2724352A283E282A462226551C2265101793292DDD6362EE6A65ED685FF26E62
EF6D60EC6A5DEE6A5DED695CED6B5DED6F60EA7160EC7463EE7666ED7364F07669F47A6D
F47C6EEE786AF27F6DF38270F48675F88D7BF88A79F78978F98B7AF9897BFA8679F67D72
F2766AF37368F57165F56C62F3695FF2685EEE645AEC665BE36557DD6D5FBE6255873F31
6231224F2F204734263D3327332F242F2C2531302C2F2F2F2B2C2E25292C26272B2A2B30
26262E26263027242F28252E27242B2A282D2D282C2C2827272622242520242520252523
2725282A232A291D292A1C2B827680F5EBF3E6E1E5E3E1E4F0EEEFCFCECCA09A9A4D4747
6F67657F7775C8BFC0918889B0A7A8B0A8A6C7BFBDB1A9A7C3BABBDBD5D5E4E0E1E0E0E0
DDDFDEDDDFDEDFDFDFE2DCDEE9D8DEFDDEE6D39EA8833640DA727BAF4245BB5C5697534A
A6857CFFF6EE
FFF7F3C59E97A25249D4685BE66859DE5D4ADB624DD46C53DD896FC17F6588553A795439
BD9F85DAC5B0DCCCBDDCCDC6E4D4D5CBB8BCE9D4D9D1BEC4D6C5CD594D574A4251514A5C
4F475C5850675D556A5D5668625B6D645B6E5C53664E4556261E2BA9A1ACF4EDF4EAE4E8
EBE5E7ECE6E6EDE4E5EFE6E7F0E7ECECE1E9EFE4ECF1E1EBECD8E1F5DCDFFFE0DAC89A83
B97C50BA7A3CF6BE71FFC473E5974DC96F31DB794CD17050D07B669E5A4D63342C50312E
4B36334D3E3B4537344C3E3B594B4872676391868291888379726C55504A3B33302E2925
2A25212D25223628273E2626461C205413196A0E13AE3D3FE96966ED6660F1675DF46A5F
F3695EF2685DF2655BF5685EF1675AF0685AF16C5DF26E5FF36F62ED695CEE6A5DED695C
EC6A5DEF7061E96A5BF07263EB7061EB7162ED7263ED7263EC7064EB6F63F17367F27267
EF6C62F56F64F36A60F46A60F3665DF2655BEF6258E76155E16657D76D5FB9655A6E3227
4520173A261D2E231D2C29242B2A2826262627262B292A2F22252C20242D20242F242833
242736292B3A2726362C2A382D2D392C2B332A282D2A2829292728262523272725272727
2A25292E272E2A1E2A2D1F2C8F838DF7EDF5E5E0E4E4E2E3F2F1EFC1BDBC959190464040
655D5B958D8BD0C7C8675E5F534B49342C2A7C7472ADA5A3C3BBB9DED8D8E4E0DFDFDFDF
DEDEDEDEE0DFE0DEDFE1DBDDE9D8DEFDDEE6D4A0AC823640DA757DA83B3EB0534E98554C
B0928AFFF5EF
00FF00D9B8B39E544BCE6457E7695BE05D4BDC5F49DC6D52DB7E5FC77C5CAA724FBC9672
D1B698E5D5BCDCD0C2E5DAD6CBBBBCD9C4CBD3BAC0886F75E0C9D1B8A7AF504450382D3D
312839382F423F3649403748413948423747403543443A458C828BF0E6EEF3EAEFF1E8ED
EFE6E9EEE5E8EDE7E9F6F0F4C8C1C98E8693A497A897899883717DEBD4DAFFE4DFCC9F8A
BB7E51B57434F3BA6BFFC473E7994FD07638D8774ACE7150C97B65925447562B244C302C
483632483D37483D39453A36473C3A4136345449476C6260887F7A948D87847B76655E58
463E3B372D2B3020203B2122481B1E56111478181ACB5456EA6662EE635CF3665DF1645A
F2685DEF655AF26659F4685BF4685BF06659F36A5AF46A5DEF675BF26A5EF0665BEE6457
EF655AF1695DEE665AF0685CEF695DEC665AEB6559EE685CEB655AEA6459EF665CEF655B
EC6258EF6259F06159EE6056EE5E55EB5B50EB5D51E86054DF6153DA6F5FC06A5D6A2E23
3D181034211B2F2724292826262628292A2E26262E21232F2127331D243421283B2B3348
292F4532374D393B52373A4D36384725273323232B26252A2B2A2F26262827272929292B
2B262C29222A30232D2C1F29988C96F6EFF6E5E0E4E4E2E3F5F1F0ABA7A68884835A5454
706866A39B99E7E1E1D9D3D3DBD6D3BCB7B475706D332D2D5F5959C3BFBEE7E6E4E0E0DE
DFDFDFDCDEDDDEDCDFE2DCE0E9DAE1FBDDE5D8A6B1863E49D4737A9E3637AD524D97574E
B89B95FFF7F3
00FF00E6C9C59F5951CD675BE66A5EE25D4EE05F4ADF694FDD7959CB7B58BC825CC9A27B
E0C7A8DBCBB2EADED0DED1CBC6B6B7EBD6DDD8BDC6CBAFBBE2CBD5F8E4EFDDCDDAB5A8B9
A59AABA299ACA097AAA398A9A095A5ABA0AEBCB0BCCEC2CCEFE4ECF3E8F0E0D5DDE1D6DE
F0E7ECF3EAEFF2EBF2F6F1F89C96A4736C7C7E72865F5063948393FBE4ECFFE0DCCA9A84
BC7D51B67535F3B86AFFC171E89A50D1783CDA7B4FCA7151C67E68834B3E4B261E48302C
483934443B364B423D4138333F3533403634433937483E3C4B423D675E59817873958C87
8C8280786D6B5B49474F3131522021550D0E882122D95F5EEF6A65F0635AF06258F16359
F1645AF1675CEF6258F4675DF2655BF06359F3665CF2655BF4675EF1645BF3655BF3655B
F1645AF4675DF2655BF1645AF1645AF4675DF4675DF06359F4675EEF6259F2635BF06159
EF5F57F16159EE5E55F25F57EF5C52EF5C52ED5D52E95F52E26255D7695AC56F626D3126
3D1B123624202F272529292B27282D2F2F37292B37292D39272D3D293043373F563D445E
3B425C3C425C3B3F583E435732354625273424242E22212929282E25242A21202529272C
211C23241A23281B2530232DA0949EF4EDF4E4DFE3E5E3E4F3EFEE9D9998938F8E585252
8D8787B0A7A8CEC8C8B9B3B3D2CAC8C9C1BFC1B8B9BCB6B6DAD4D4E3DFDEE4E0DFE2E1DF
E0E0E0DDDDDDDDDBDEE2DCE0E9DAE1FBDDE5D6A7B1823C46D6777D9A3636A9544D91554B
C1A5A100FF00
00FF00F1D9D5AA6963C6655CE2675FE05C4FDF5B4CE16853DA7257D27F5FB17752CDA783
D7BE9FD3C3AAE5D5C6C9BAB3E1CFCFEAD5DCCFB7C4A890A0AB94A6A893A6A18FA5A092A9
998DA5998DA593879D988AA1978A9E9D90A27F7381988C98F2E6F0B0A4AE837582847884
B2A8B1F0E9F1FAF4FEC9C6D1716D7E726D81675E73504357D7C4D7FEE3ECFFD7D6C88F7B
C27E51BF7A39FABF71FDBE6EE19148DA8044D3764BCA7558BC796677453A4D2C2548352F
3F3430433B3849413E443C393F37343C3431413936453D3A3E3731433C36443A38594F4D
6E605D8C7A78977F7D926F6D8C54537F312FA33B38E56A65EB655CF1645AEE6056F26458
F3675AED6056F3655BF2635BF3645CF1625CF1625EF36460F1625EF46561EF605AF1625A
F5665EF06159F4655DF1625AF2635BF2635BF1625AF2635BF1625AF2635BF16159F06058
F15E56EF5C54F25F57EF5A53EF5B51F05C52EF5C52E85E51DF5F52D86A5BC9736673372D
3D1A143826242D27292E2D332D2D352C2C362F313E3134433A3F5241465A454962434760
4347603F445A3D42584042572E2F412224311C1A271C1A251E1C2723222A1F1C232C272E
3E373E5349526D606A60535D9F939DF3E9F1E3E1E6E2E2E4F2F0F17E7A79BBB5B7C5BFC1
837D7FCFC9C9A49E9EA79E9FD4CACBD7CBCDD9CACDDFD3D5CCC2C1D6CECCE6E2E1E1DFE0
DFDFDFDEDEDEDFDDE0E3DDE1E8D9DEFADFE6D3A1AC7E3840D2787A983B36A6584C8B5549
C4ADA700FF00
00FF00FEEBE7B17670BC6259DD685FE16156DE5F50E26B57D87259CB7C5EB87F61E4BD9E
E7CDB2E0CEB8E5D4C4E6D5CDDCCAC8EFDCE07D69755C47585C495C5443565041564C3E55
4C3E55473B5146384F493C504D40524F42532B1F2DACA0ACF6EAF47D717B6153606A5E6A
594F5ADCD4DFF3F0FB908C9B63607366617740364E8F8095F8E3F4FDDEE6F6C3C0C4836D
BE7749CC8746FFC277FBB96BD98640E2854CCF734AC57457B778666B3F344C2F29493733
3C32303D38343F3A36403B37433E3A3E39353934303A35313C37314039333D3532433836
4436334C3935674B48885C5BAA6A68AD5855C75C56E46860EC665BED6154F16357F06256
EF6356EF655AED6359EE655FEA6560E76563E76768E56468E86869E96769EC6667EA6262
EB615FEE6360EC615EEE6360EE6261EC6260ED6361EB615EEE6360EA5F5CF06260EC5E5C
EB5D5BEB5D5BEB5B5AEE5F5BED5C59EA5954ED5E58E75D53E16156D6665ACA7369783C32
3D1A163E2C2C322C302D2C3230303830303A3434403032413A3D4E373A4D303146323348
34374A282B3E2526381E1F31201F2D24222F2E2B36423F485A57606B686F716C73756E75
777077746A72645761382B35A296A0F3ECF3E3E1E6E3E3E5F6F4F57C7B795A5657544E50
8B8788F6F2F386808062595A5F53555F5053605053635356443838BAB2B0EDE7E7E1DFE0
DEDEDEDEDEDEE0DEE1E2DCDEE8D9DEFADFE4D09FA5813C41CB7274933C35A560517F5142
CDBAB400FF00
00FF00FFF4F2BB8680B46257D76B5FE66C5FD75D4EDF705DDC7E65BF755CBD876FD4AE97
D9BDA8DFC8B8F2DFD1CFBEB4C7B8B3E5D7D782737A7A6D77766875746675726674756879
7467786F62736E6071695B6A695B6A4F414E71656FF1E6EEFBF1F9C1B7BF6D626A544852
746D75ECE6F0C4C0CE696677676278574F663D3147D6C5D7F9E1EFFFDBE0E6A7A0C67E65
B87241E4A061FFC37AF9B36BD37B3CDE7E4BCE724DC7775CAF7561643C30482F28443530
4036343E3634403836423A37473F3C443D373D35323B33303C34313B333039312E403634
42333047322F52302F5B2928691F1E8A2C2AD4615CEA6A61EA6458F26657F16355EF6153
F16558ED6559E8655DE56A65DB6B69BD5556B24F54B15059B2515ABC545DD25E6BDC606B
E4626CE6636BE6636BE15F67E3616BE3616BE3616BE36169E36066E66067E66069E45E67
E45E67E45E67E7616AE65F66E85F67E75C63E75C5FE8615EDF5E58D7675CCB746A80443A
3D1A163F2F2F322C3026252B2A2A3228283026263024242E272733232230201F2D2B2A38
3434403C3C484A48555A586367646D6F6A717D767E827B827A737A6C676B5751554D474B
3B3539362C342E242D291F28B6AFB7F1ECF2E3E1E4E3E3E3F2F2F2B8B8B82826275B595A
D0CFCDEEEDEBD3CFCEDBD5D5857B7AB0A4A6D1C2C5CEBFC2A89C9CD6CECCE8E4E3E1DFE0
DEDEDEDDDFDEDFDFDFE2DCDEE8D9DEFDE0E4CB989D843F42C16D6B924239995E4E795444
D6C7C000FF00
00FF00FFF7F4CB9E98AD6358CE685CE06F5FE37463D26D5BD27F6DA1604EE3B5A6DFBFB4
DFC4BDDDC9C2E5D4CDE0D2CFE4D8D8E7DCE0DFD5DDE0D6E1DED4DFDCD1DFDFD4E4DCD1E1
DED3E3DED3E3DDD0E1DCD0DED8CBDCCABECCD0C6D1E5DBE6DFD8E0E6DFE7DBD1DCCFC7D2
E9E3EDEEEBF6888495635E72665E7534283E857487FFE7F7FFDEE7FBC9C8CE8979C97D5B
BD7743FAB977FFBF78F0A561D97A42D67445D17452C4785EA66F5B5F392C4B342E443532
4238374038363E36343F3734453D3A453E38453C373F36313D35323D35323A322F3C3230
40312E472F2D522B2C5B2324691719993331DE6761ED6A60EF6759F06455F06453EF6354
ED6557E9695EDE675FE27975A44C4AA5595BD8929AC37F8AB56E7CB26472C5687BB34C5F
D36776D76B78B74F5AAC4651A94551A3424DAA4652A94551AD4752AC444FAF4752B9505E
B64D5BB74E5CB54C5ABC505FBE4E5CC04C59C95059D75A5EDF6361D4655ECF786F82463C
3D1A162F1F1F27212523222826262E33333B36343F403E494E4C595D5B68615F6D6F6D7B
7775827D7B8673707B6B6871615C62524D514741453C3638322C2E312B2D2C26282E282A
2E282C2C262A2E242C362F36CBC6CCEEECEFE2E2E2E2E2E2E5E5E5E5E5E5B0B0B0C2C2C2
E5E5E3E4E3E1ECE8E7FDF5F3786E6D685C5C7F7073786C6E6E6465DCD3D4E9E5E6DEDEDE
DEE0DFDCDEDDDEDEDEE1DDDEE8D9DCFFE0E5C59195894544B8676392483D915C4C856556
ECE2D900FF00
00FF0000FF00DAB3ACA76559C86B5CD86F5CEC8775D17868A35F54BC8B84E8C8C97E696E
83727A8578818D818B877D86978F9A958D9A827C8A817D8C7C78897F788A7D758A786F84
7A71867D74897B72877A7184766E83766F817F788A8B8496867F918780928F88989891A1
A5A1B29893A76E667D6B61795749603C293DD7BED3FFDFEDFFD0D5DD9D93CF8467BF7244
D8985AFFC178FAB46CE18E4CDB7743DC774DD07556C97E679863515B392D4E3632463837
3E3232473D3E3C3231403634413936463F39453E38433C34413A343E37313B312F3B302E
40312E492F3051282C5F212672191BAA3E3CE56864EF6960EE6457EF6354F06455EB6355
EA685ADF695FD9736EC77371713433CD9FA1FFDEE4FCD4DDFAD0DEFFD4E5E8A5B7964B5F
C175828B434F9E626AD6A1A9DFAEB4CFA0A6C997A0C3919ABF8C93B27F86A9747CAA757F
A06B759B636E9A606C965865A25B6BA95867B45664AE444ED05E5ED66A67C570698A4E46
5C39355C4A4A5E585A605F6566666E6D707971717D6F6E7C6E6D7D6E6D7F5C5B6D525163
434051403E4C34303E302D362E292F2F2B2C2B27282A2625322E2D2D29282E2A292B2726
2C28292924282620243E383CD9D7DAECECECE1E1E1E3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
E4E3E1E6E2E1E1D9D7EFE3E3CCBEBDB4A4A4B1A3A3AB9FA192898AE3DDDDE4E2E3DFDFDF
DEE0DFDEE0DFE0E0E0E3DDDFE9DADDFFE1E3B98184964F4DA85851A0584C8757499C8275
FEF5F000FF00
00FF0000FF00E9C8C1A1675CC7705FCF6A58EA8B79BA6B5CA97067F7D1CEB1989E685863
6A5C6B685D6D6D6272675F6E6E66756C66745E5A68605C6B615D6E615D6E5E566B60576C
60576C61586D635A6D5F586A5C55675D5668615A6C665F716A6677666273635F70656275
68657A676279675D766A5A74402A3F937486FFD8E8FBC6CCDD9A92CD836ACA7D53C47C42
F9BA73FFC076EFA159D4773ADF7646E07853D67B5EC77F6795645355352A4B3631453736
413535453B3C403635423837413936403933453E384A433B40393137302A3F36313E332F
40312E462C2B53262B5F1E22791D20BE4E4CEC6D67EB625AF16558EF6354F06757EA6659
E46A5DD76F66CD7875995959885E5FF9DCDEF5DCE0F2D8E1F9DAE9FFD9EB99647892596A
885260956771FAD9E0FADFE6F8DFE5F7DEE4F8DDE4FBDDE5FFDEE7FEDDE6FBDCE4F7D9E1
F2D7DEF1D6DFF0D2DCF5D1DFF7CBDCFFC8DAFFBDCDA74753C25457D06764C8736C8E4F48
623F3B6C5A5A5F595D53535B4C4F584345514042514142563D3E5238394D3A3B4F3C3B4D
3A374838364434313C302D34332E322B27262F2B2A2F2B2A2D29262C28252F2B2A2C2827
2925262B2527211B1F544F53E5E3E4E8E8E8E1E1DFE3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
EDECEAD9D3D36F6566C1B3B37E6E6E8A7A7A8C7C7D8377778E8586EDE9E8E2E0E1E1E1E1
DEE0DFDFDFDFE0DEDFE5DCDFEBDBDEFFE0E3A96E70A55B5AAA5D559E5E527D5647C5B1A6
00FF0000FF00
00FF0000FF00F6DAD6A47269C06D5FCC6B5ADD806EA05444CB9B8FD1B2AD52373C66515A
5C4C575F525C5C505A5B515A5A50595C555D58515958505B59515C5A525D5B505E5B505E
594F5A594F5A5E545F5B535E574F5C564E5B5A525F5B53605B5561595661585664585566
5D59706058706757715A425A513043E7B9C4EFAEB2DA9087D6866BCE7F54C88247F3B06A
FAB86CF6AC63EC9253DB7640E17449DF7452D4795CCD856D956654513328493630473938
463A3A403635453B3A443A39423A373F37343F3A36423D37443F393C37313C352F39302B
3E2F2C4529285325285A15187C1E1FD05E5DEA6964EF665EEE6255F16858ED6557E7695B
DE6F64CF756DBC7877724144CCAFB3FCE7ECF1DAE0F3D9E2FEDFEEE2BCCB8350619C6978
6D4550DFC0C8FEE7EDF2DDE4F4DDE7F5D9E5FDD7E6FACEDDF2C2CEF4C6D1F3CBD6F3D4DC
F6DFE7F1DDE6F0DBE4F5D9E7F8D6E6FFD4E5F6ACBB963642C95B5ED56967CB736F81423D
4C292740303338333A31313D333542383B4C3B3D5242445B494B6245475C414256414050
3C3A473130382E2B322E2C2F2E2A292925222F2A272E29262B27242A26232925242E2828
2A24242C2626211B1D615D5EECEAEBE4E4E4E2E2E2E2E2E2E2E4E3E0E2E1E1E1E1E2E2E2
E8E6E7DDD9DAB3AAADD6CACCAA9A9BAA9A9BA898998C80809A9494F2EEEDE1DFE0DFDFDF
E0E0E0E0DEDFE1DDDEE5DADEEDDAE0FEDBE193585CAA6462A46055965E4F856558E8DACF
00FF0000FF00
00FF0000FF00FEEBE7A1766FB1675ACD7260C76A58AB5846FEC2B7CD9E989E72738E676C
664349614247583B3F51373A4A31344F36394C37364935343E2B27412F2B46332F49342F
4B332F4E36324E36324C3432483030452C2F442E3148343647373A44393D48424C4D4B59
544F655E526A67546A4125349F777FEDB7B5C37A6BD28163CF7E4FC87E41FAB771FFBE74
F6AC63F5A05DED8850F38456EC7A55DA6F4FCF7459CB846EA97C69573B2D3C292240322F
433836403634473D3C3D33314238363F37343D3834413C38433E3A3F3A343B342E39302B
3F302D4529285726295A1416862725D86560EC6B65ED645AEF6558ED6557EB695BE36D61
D27067CF827C925C5C815E62F7E2E7F1E0E6F0DBE4F6DAE6FFDDED9E75858C5D6D7C505D
8C6E76FAE5EAF3E0E6F1DCE5F5DBE8FFDAEBF2BBCEB57586A46270AB6D78A16F7A94707A
E8D1D9F1E0E8EEDAE5F0D8E5F7D7E6FFD4E3BF6E7D9A343FDA676AD36663CE76727F403B
5531314130363F39433635433638473A3D503B3D523D3F564A4C63424459444557373743
2D2C342E2D322624272725262C28272A26232C28252D29262A2623282421251F1F2B2525
2B2223342B2C201A1C6E6A6BF2F0F1E4E4E4E2E2E2E2E2E2E2E4E3E1E3E2E1E1E1E1E1E1
E2E0E1E5E1E2F6F0F2CEC3C77C6D7095878794888A7B7172B1ABABEEEDEBE0E0E0E0E0E0
E0E0E0DEDCDDE3DDDFE6DADEF1DCE3F4D1D791595AB2716D9C6055895B4C968073FCF3EC
00FF0000FF00
00FF0000FF00FFF7F5C1A29D9D5F54C87263CB6757BB5546EC9486FDADA2F4A7A1F2A8A5
EFAEAAE8ABA8E2A7A3DDA49DD9A29BDAA69BD7A799D2A794CAA58BC6A387CBA689CAA384
CC9F80D0A183D29E86D29E89D49F8FD19D8FD1A092D4A89DD2B0A6CCB5AFD7CBCD8E8691
5044586051665A42524F2F34ECC2B6D19B81BE7950C27942D09049F7B86BFEBA6FF3A960
F49F5EF18E55F28355F27C56E66F4FDD6F54CF735AC67F69AE816E896D5F67554B42352F
3328243D322E433836403533413634433937423A38453D3A433B38473F3C3D33313E332F
43312F462A29552427601A1A8E2F2BDB6861E96960F1695DEC6456EC6859E4685CDB6F65
CF7871BB7B796F4748CAB1B5F9E6ECEEDDE5F1DBE7FDE1EFEBC4D6865B6C976D7B613D49
D0B9C1F6E5EBF0DBE4F3D9E6F9D8E9FFD0E5B3667AA95062CB717DC97982AC70786C434B
DCC2CBF6E2EBEFD9E5F1D5E3FED8E7F8BBCA963944C35258DD6765D66964CA756E7B3E3B
532F314231393C3441383745393B4A393C4D36394C40415545465A3F3E4E3838442C2B33
28272C2C2A2B252422252422282723282723282725282725282725282423251F1F292021
3026273128291D1719817D7EF5F3F4E5E3E4E2E2E2E1E1E1E2E2E2E2E2E2E2E2E2E2E2E2
E4E3E1E8E7E5F7F3F4D8D2D45E53576A60617D74775D5757B3B2B0EAEAE8DFDFDFE0E0E0
DEE0DFE0DEDFE6DDE0E8D9DEF5DEE4E6C3C7824C4CB479738C5B4D825E50B8A79F00FF00
00FF0000FF00
00FF0000FF0000FF00FAE7E3B1827AB46C60CF6F61C5594CD96F61E57B6ED26A5FD87369
DF7E75E0837BDC8279DF877BDE8879E59481E29780E4A184EAAE89F7C195FBC797EFBA88
D99F6DCC8E5DCA875CD38E67D28C68D79271D89578D49A82BE917EB4968BF3E1E17B6F79
53465863506343293297746EE2B69B9A6438C68649E7A45DFFC172FFBE6EF1A75EEC9756
F18E57F18254F17954EE7153E56951E0705AD57964C5816C885B48674D3E88766C8D807A
6459553D322E362B273C312D403533483D3B443A38443C39443C3948403D413735413634
412F2D4729295220216019179F3E38E16F64E9695CEB6657EC6758EA685AE26C60D47269
CE837E8C59587B5D5FF5E2E6EFDEE4F0DCE5F5DDEAFBDCEBA77C8D90647377515E8B6D77
F9E6ECEFDEE4F1DCE5F6D7E6FFD7EAE0A1B6A14457D66D7CDA7680D48288A0636A885F67
F6DCE5F1DDE6EFD5E2F6D4E4FFD6E6C17987A33840DE6366DC655FD46961C6736B723834
502E2F402F373B333E3A38453A3C4B3436453334463D3C4C403F4D3A38452D2C34262429
2624252827232726222524202726222827232928262625232322202A2625282222281F20
2D23242F2428271E21A29C9EF3F1F2E3E1E2E3E3E3E1E1E1E2E2E2E3E3E3E3E3E3E2E2E2
E4E3E1DFDBDAF7F1F19E9596867C7DF8EEEFF4EBECE1DBDBDEDDDBE2E2E0E0E0E0E0E0E0
DEE0DFE0DEDFE6DBDFE9D9DCFAE1E5D1ADAF73403DB38178855E4F7D6656DDD2CC00FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E7CEC7A37369BA6A5FC66054DD685EF2766CEA6C60E86A5E
EB7166E76E63E87062E77163DF6E5CE37661DB755CDB7E5DDB865DE39766EEA970F8B679
F7B676E5A462D48E50C98146C47940C47844C57D4DBD7F588B5D43D6B6A9C5B1B2574A54
5F51624A3844503B38F0D1BDD0A47DCF9B62FCBF7CFFC076FBB367F0A059EC9253ED8852
F38457F07855F17156EB6953E86956E3705DD27563C985728557484E3427513E376B5E58
877C788C817D70655F4A3D37372C283C312D433834443B36433A35463D38463C3A413332
412D2E49292A552221671D1AAB4940E57164E66758EF6A59EB6657E96B5CDE7063D2786F
BB7C776D4442D2B9BCF8E7EDEDDCE2F0DBE4FCE0EEE0BECC8051619C707D63424BD7C0C6
F7E6ECEEDDE5F4DAE7FBD5E4FFC9DBAE5D6EBC5161DE6E7AD47478C77B7F7E4C4FCCACB1
FCE5EDF0DAE6F1D5E4FFD4E7FCBBCF9C4150C55056E46765DC655DD56F63BC6F6567322A
4C2D2B3B2B2E362F3635343C3C3A473939453838443D3B483D3C443431382E2C31262223
26221F2A27222F2C2724211C26231E26231E2A262326221F231F1C2A25222D24252B2223
2D22262A1F252D2228C0BABEEEECEDE2E2E2E2E2E2E2E2E2E2E2E0E2E2E2E3E3E3E7E7E7
E8E7E5746F6C887E7D564A4A736564998B8A8B807E827876DFDAD7E6E5E1DFDFDDE0E0DE
DEE0DFE0DEDFE6DBDFEBD8DCFCE2E5AF8B8B72433DAE8476775C498D806FF4F0E700FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF8F4C7A9A1995B50B85E53D9675DEF6C62F2695FEE6459
F76D62F56D5FF36B5DF57061F3705EF1725FE76F57E47557E37B56E28355E48F59E9995C
F4A968FDB470FFB571FFB874F9AC68EDA261E49E63BD8353B88D6DF5D8C88A7574634F58
6A56613520259E8378FEDBBFEEBB8CF9BD81F6B36FEA9F5BEA9554E6884BEA824FF28157
EF7453F17156EE6A55F16C5BE76555E06D5BD57866C6826F855A4A51372A493830493E38
4D443F6B625D887D799186827B706C5348443E332F392E2A3E35304239344238363C2E2D
412D2E4F2D2E561E1F702220B14C44E56F63EA6B5AEC6957EB695BE16B5FD9746AD0817A
8A55518D6B6AFAE6E8F1E2E7F1DEE4F3DCE6FFDFECA6808F9264717B515D8F747BFBE8EE
F2E1E7F2DDE6F4D8E6FFD7E7E69DAE923442D86972D96A71D87E809E5A5B895F61F8DDE2
F3DEE5F0D8E5F4D5E5FFD5E8CF7E91982F3DE3666AE2615CDB665CD06F5FB87062633128
4628263A2A2B3329312D2A31322F383B39443A38433E3D453D3A413432352F2B2C282423
26221F2926212B282324211C2A27222A27222A252227221F25201D28222230272831262A
2D2027291C23382D33D7CED3EEECEDE2E2E2E2E2E2E2E2E2E3E3E1E2E2E0E3E3E3E6E6E6
E8E7E59D9895968C8B948685A0918E9687848C7E7B908583EBE6E3E7E3E0E1E0DEDFDFDD
DDDFDEE1DFE0E8DCE0EED9DEFEDFE4926C6B9469629E786B6B5945A7A28FFFFCF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F9E6E0A57970A1584FCA6259E66A60F06A61ED6056
F4675DF96D60F86C5FF46B5BF56D5FF67263EF6E5BEC725BE67356E47756E78159E58658
E78D5BE58E58F09C60F3A263F6AB6AF9B473F6BA7EDFAF7EF8D8B2AF9680472E29533A3D
462E2E553832EFC9B6E9B796E29E71EA9A65E8915BE88A54E6804FEF8355EE7854F27557
EF6D55F06C57F26A5AED6859E96757DE6B59D47765CB877483584750392B46382F49423C
4C4441473F3D4B43405F5651827773988D89847975655A56463D3838312B362C2A3B2D2C
3F2B2C4E2A2C581D1F762625BB544DE86F64EA685BEB695BDF6558DB6F65D27975B97876
683C3DCCB2B3F9E5E7EFDEE4F0DDE3FCE2EDE1BBCA7F54659E727F603A45CEB7BFF6E5EB
F0DDE3F4DAE5F9D9E8FFD0E0BA6373B54B55DF6E74DB7276C77778794142CAA7ABFBE4EA
EFDAE3F2D8E5FCD7E9FFC4D8A34756C34E57E76567E4635DD56456D27564AB68585E2F25
432724392B2B372C34342D3537313B39363F3B3843403D463B383F2B292C2824252D2928
2B272429262128232027221F2C27242C27242C2324281F20251C1D2E252632272B30252B
2B1E27271A234B4048E1D8DDEDE9EAE0E0E0E2E2E2E2E4E3E0E0DEE2E2E0E3E3E3E2E2E2
E1E1DFEAE9E5E4DFDC8C8280998E8A9688859B908EA39997A49C9A7F7B7AE1DFE0E3E3E3
DFDFDDE3DFDEE7DBDDF1DBDEF5D5D886605FB0857E846256665647CECABE00FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E5C8C298635BB8645AD16559E86C62EA665A
EA6256F2685BF3675AF56C5CF56B5EF46C5EF46C5EF06D5BEE705AE66C54EA775AE77958
E67C55E68155E58352E68854E18A54E1925AD7925BDAA273FFDDB7D1AC92B88E82B1867F
AB8079DDAD9FFAC0A8D58E6EE58D67EB8A5FED8359EB7E55EF7B56EF7657EF6F54F16D58
F16A57F46C5CF1675AF0685AEB6758DF6A59D57662CC85718E614E543A2B473930443D37
47423F45403D48403E473F3C453B39584E4C796F6D9389879088857068654E44423A2C2B
301A1C4521235B1F217A2928C05753E66F67E86A5EE3695EDE6F66D0736EC88081824E50
927275F9E5E7F1DEE2F1DEE4F3DEE7FDDFEBA97E8F93677681596496777FFAE7EDF1E0E8
F1DCE3F7D9E3FFD9E7E2A4B3983844D6676EDB6E71D67878A25E5D835557F4D9DEF2DEE7
F1DAE4F5D5E2FFD6E7D18A9C9A303CE2636AE86261E16158D66658D178689A5B4A4F271B
41292535292B372D35352D383A343E3B35413D3A453B3841302D3429272A232122272624
2925222622212824252C28292D27292C26282920232920232E25282E252831282D31262E
2C202A1E121C5B5159EAE4E8EAE5E9E1E1E1E2E2E2E1E3E2E3E3E1E4E4E2E3E3E3E2E2E2
E1E1DFEEEDEBCDC9C8696461877D7B796E6C817674635958847E7E6F6B6AE8E6E7E4E4E4
E0DFDDE1DDDCE8DCDEF5E1E3DEC0C264413FBF9A916F53477D7367ECE9E000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF7F4C5A6A1995F54B96759D26C5DE06A5C
E7695BE45E52E96153E95F52EC6255F06457F4685BF3695CF36B5BF3705CF1705BEB6D56
EC7358EC7557EA7854E87852E97D56E88359DB7B53DA855EF1A686F1AA8EF0A892F3A797
F2A998F8AA96E18971E07E63EB7F62EE7B5CE97254EF7357EB6D54EF6D57ED6855F16A57
F16858F16858F76B5EF1675AED675BE16959D97865CE8572916250573A2A49382E463D36
49413E443F3C443F3C46413E453D3B463E3C4139374E46446B6361867E7B958B898A7C7B
6B565550292A531719701F1EC05656E6706CE16A62DE6F66D67972AF65628F5B5D5C3A3B
D3BDC0F6E7ECEEDDE3F1DCE5FCE2EFD8B6C675495AA074835E3D46D4BBC1FAE7EDF1DEE4
F5DBE6FBD7E3FFD1DEB56B78AF4954DB6E74D57173C87776794343C8A6A7FCE5EBEEDAE3
F2D8E5FAD4E3FFC7D6A85161C04B54E86165E7605CE4665AD36858D17E6C89503F472519
37261F3128293932393B353F37343F3A3742413B47322C362D2A312C2A2F282629252525
26242527252828262B28252C2A252C2D262E2B212A2A20282A2126251F23251F232B2129
3329322D262E736E74F0EBEFE6E4E7E2E2E2E0E0E0E3E3E3E4E4E4E2E2E2E1E3E0E1E3E0
E3E3E3F2F0F1B6B2B3736D6DD9CFD0D9CFCE9F9594A69D9EEDE9E8DBDAD8E2E2E2E1DFE0
E2DEDDE3DDDDE8DCDEFAE7E9B89E9D5A3E3AB59D91635346A8A19900FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F8E9E499786F8D594CB0685AC56D5F
D26D61DA6C5FDC665AE56B5CE06053E26052EB6559EF6759EF6759EE6656F16959EE6958
F16E5AF2715BED6F58EF7359EF7357EB7456EA775AE5785BE37E62DF7D62E07C64DD7962
DA7762E07A64E4765FE8745DEC725BEE705AF06F5AEF6C58F16C59F06858F16858F66D5D
F16858F2685BF4685BF2685BEE685CDF6556DA7563D1836FAB73645E382B4D342D4A3B36
483E3C423D3A433E3B443F3C423D3A453F3F423C3C413B3B473E3F48403E58504E7B6D6C
9F8689A87F83A264678D3B3DBF5756E2726EDB6E67D7766FBC716C753D3CC8A4A6D2B9BD
F1E1E4EFE0E5F0DCE5F8DEEBFFDFEEA982948F60727B515F95777FFAE5EAF3E2E8F0DDE3
F5DBE6FFD8E6E0A3B28C3C49C8646ED87077D57C7EA05A5C835659F6D9DDF6DFE7F1D9E6
F5D6E5FFD5E5E096A5932F3BE16367E95F5DE66057DF6558D46D5EC97A6B7A4638402217
31221D2B25252E2B32322F3A3632403834423C3642302A3429262D26242928272C28282A
28272C26252A1F1E24201D261E1B241F1923251D28302931302A2E3832364D464D5F585F
726B735550568A888DF3F1F4E4E4E4E3E3E3E2E2E2E3E3E3E3E3E3E2E2E2E1E3E0E0E2DF
E3E3E3EAEAEADDD9DA7872725B5253574E4F746B6CD3CDCDEDE9E8E4E3E1E0E0E0E2E0E1
E1DDDCE5DCDDE8DCDEFCEAEA8B7371776058A69687655B4FDEDBD600FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3D6D0C0A9A1B29087AD7E74
AF756AB97367BF6D61C96D5ED36D5EDC6E5DE16C5BEA6F5FEB695BE86455EC6758EB6655
EA6552E96451ED6857EF6A57F06C57EF6D57F06F59F47660F17762EF7661EE7763EF7864
E8705FEC7362F17462F1705DEF6C5AF06B5AF06B5AF36B5BF06858F2685BEF6558F66A5D
F1675AF2685DF4675DF1645AF26A5EE46658DF7162DA7E6FB672676E3C335635304E3938
493B3A443C3A413B3B423C3C423E3D413D3E423E3F423E3D453F3F45403D433E3B463A3A
533A3E774E54A86A6FB9676BC76363DA716DD3706AD7847E7B3F3E9D7575FFE7EAF2DFE3
F0DDE3F2DDE4F3DCE6FFE1F0DBB2C48152669C6D7F633D4AD6BFC7F5E6EBEFE0E7F0DCE5
F5DDEAFCD3E1A1616FA04E5CD0757ECE757BC4797D743C3FBF9CA0FDE4EAF1DAE4F3D7E5
F8D6E6FFCFDDB65C68B9464DEA6465EB605BE35E55E0685ACF6D60C2786B6A3A30351A13
2B201E2B262A29262D29273232303D3634413733412A27322E2B3428252C252229262429
1A171E1F1C232A273035323B413E475C575E6E69706E696F726D716F6B6C696367565054
443F452C272DA09EA3F3F1F4E3E3E3E2E2E2E2E2E2E3E3E3E3E5E4E2E4E3E2E4E3E1E3E2
E2E2E4E9E9E9F2EEEDA49F9C473F3D534B49C4BCBAF1ECE9E3DFDEE1E0DEE0E0E0E1DFE0
E1DBDBE4DADBEFE1E1F0DEDC614A44AB998D84786A8B877BF9F8F300FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF4F0F6E5DE
ECD1CADAB5ACCC9D93C0867ABA7669BF7164C46C5EC96959D66F60DB6B5DE36F60E66E5E
E56A58E66957E46254E76354E86352E45F4EEE6656EB6353F26D5CF16C5BF36E5DF4715F
F36E5DF67160F46C5EF66E5EF16959F06858F56B5EEE6457F3695CF1675AF4685BF3675A
F1675AF1675CF5685EF3665CF1695DE8695AE26C5EDE786CC8766B793A335D312E543837
4E3C3C473D3C483F40423C3C403A3A3F3B3A433D3F453F3F433D3D403A3A464040473B3B
4F363A5A313762232B823036C76363DB7370D97872B665618A4E4DF4CACBFFE2E5F8DBE0
F8DAE2F8D9E1FEDAE6FFD7E5A66F82975E6F81515F9B7580FDE6EEEEDFE4EFDEE6F0DCE5
F9E2ECF0CFDA743C498A46519F58609D5A617541458D6468F5DADFF2DDE4F3D9E4F5D5E4
FFD7E8DB99A799313ADF6164EA605DEB6258E46457D56557CF7668AD6B5F582D27311917
2B21202523262B282F2A2931302D382E2B362A27322F2C35302D342D2A313533384B464C
5A555B6F6A70807D84838087807E837573786560644843473C3839363233302A2E2D262D
27202739343AD3D1D4EDEBEEE2E2E2E2E2E2E2E2E2E2E2E2E2E4E3E1E3E2E3E5E4E2E4E3
E5E5E7EEECEDB2AEAD888481A39E9B918C898B8683E2DEDDE6E5E3E1E0DEE0E0E0E0DEDF
E3DDDDE6DADAF4E4E5C9B7B35E4C42B1A1946B6557D1CEC500FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF5F0FBE6E1EED3CCD8B6ADC79C93B9877CB5776AB87061BE6F60C76E5C
D06F5CD66D5AE06F5FE46C5CE86D5DEB695BE96455EA6252EA6151EB6250EE6553EC6351
F26655F06453F46859F86C5DF66A5BF36A58F66A5BF66A5BF26657F46859F26959F16858
F36A5AF1675AF5695CF4685BF0685AEA6657E6685AE47468DC7B728C4239531E1A4F2C2A
432E2B413332463C3B3E3838443E3E3F3A37453C3D443B3C443B3C433A3D413B3D413537
493336593237602129752329C35F61DE7572DA726FAB4E49B56969FFC3C4FEC6C9FECBD2
FFCDD6FFCDD9FFD3E1E4A7B6914957B06A75804B55E9C1C9FEE3EAF3DEE3F1DEE4F2DDE4
F4DFE6F6DDE3C6A3AAB28A92AC858A967377A08689E0CCCEF7E4E8F0DBE2F3D9E4FDD7E6
FFCBDCA55361BC4851EB6566E9605AE76357DF6757D26C5DC97B6E91584F44211B321E1D
281F202321222E2C2F363437413C424D484E534E546560646E696D7A76777D797A807C7D
777374676364585357474246383637302E2F29282624232122211F2824252922292E242C
2319216B646BF1EFF2E4E4E4E1E1E1E4E4E4E2E2E2E2E2E2E4E4E4E3E3E3E3E3E3E4E4E4
E9E7E8E6E4E58A8687D0CCCBD7D1D1C8C2C28B8786D6D5D3E6E5E3E1E1DFDFDFDDE1E0DE
E6DDDEE8DCDCF9E9EA93817D8072678D8377827E75F7F6F100FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F0FAE6DFEFD1C7D9B3A8C6988BB77F72
AF6D5DB96D5DBD6A5AC96D5ED0695ADC6B5DE66B5CEE6A5BF36B5BF46B59F56A57F46956
F26752EC614CEC5F4DF06351EF6352ED6150EF6354F36758F36758F66A5BF5695AF36A5A
F16858F36A5AF26659F66A5DF06757EF6759EE6A5DEA7063EB7F72AF574B5D1A11501F18
401F18321A16372825382D2B3B313038302E403635433938443A3B433A3D42393C433739
4C383A542F365D212974252BC15F60E17573DE6E6ACD615EC46561CA7270C97779D28388
D78A90E1949CED9DA8B05D67B45761BE676DA55E64FFCACDFFD1D4FCD3D9FCD5DAFED6DE
FDD9DDFDD9DDFFDCE1FFDEE2FFDDE1FCDDE2FBE1E4FDE2E7FBDEE3FBDAE3FFD7E2FFD4E2
DF93A09B3743DE6064EE6261EC6258E46254D96858CB705EBD796C825349654A43695B58
6A6464706E6F7975767E7A7B807C7D7C78797571726A66675B57564C484744403F3C3837
2A26252E2A292E2A292B2726322E2D2C2B272A29252A2925252422262223261F262C222B
2319219F999DF4F2F5E4E4E4E3E3E3E5E5E5E2E2E2E3E3E3E3E3E3E3E3E3E3E3E3E3E3E3
E5E3E4F0ECEDCECACB938D8F544E4E6D6767AEAAABE9E7E8E1E1DFE2E2E0E1E1DFE3DFDE
E5DCDDEBDFDFF4E4E462534E9C90847F796BBDBCB700FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FFF1EDF5E1DA
E6C9C1D1AFA5BB9389B48073B16C5DBF6759D06658E06858E36451EC6A54EB6750EC684F
F06D51EF694EF56B51F46952F16450EE614FEE6150ED5F51EE6150F06352EC5F4EEA5E4D
EB5F4EED6152F16558F06457F26659F2685BEE6457F16F5FEA7564D66F5E863021611D10
532214431F133A1F182C19132A1C192D22202F25242E2423352C2D3B32333A3132403436
4B37395330365D262C74292EBF5F60DF726DE36E67E46B63E9726AE9766FE3746DDF7370
DC6E6DD86A69CF6162C85759DE6C6CDB6F6DBF5D5EDB8181DC8A8CDF9093E0959AE39B9F
E29BA1E8A3A8EFADB1F1B0B6F6B9BEF7BEC4FDC6CCFDC8D0FFC7D0FFC8D1FFC3CFEF9FAC
A43F47C54E52EB6564ED6059EC6458E26455D46B58C87563AB73627854466E5A516D645F
635E5B585453575153464243403C3B3433312F2D2E2725262A29272625232D2C2A2C2827
2C2825312D2A2F2B282A26232F2B282A272226231E2B27242C28272521222822262A2028
332C33CDC8CCEEECEFE3E3E3E3E3E1E3E3E1E4E4E2E1E1DFE2E2E2E3E3E3E3E3E3E3E3E3
E6E4E5F1EDEEC5BCBF70676A685F60A49E9EE8E4E5E5E3E4E1E1DFE0E0DEE1E0DEE3DFDE
E5DDDBF2E6E6D1C1C1463835B9B1A69E9C8FEBEAE600FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF4EEF9E2DACCA49AA2685AB86B5BC86957D66C56E47059E87057F07458
EF7455EC6D4DE46143F06A4FEE664EEF6751F46956F36A58F46B58F26B57F16C59F16C5B
ED6A58F16E5CE96556E66253E35E4FE56051E76253E36151DF6653E87965BD5A47913A29
6E26175F24165323174721183C1B162F1612331B19301C1B2C1C1C2A1C1B302021332022
3C23264824285922286E2327B15250E3746DE66B63EB6B60F16F62EF6D60F17367F2736A
F07168F17168EB6A64EE6D67E96A64E86D66E9736FE2726EDE726FD66E6DD46D6EC96567
C26263BF6162C06263C06668BA6467C06B6EC9747BC6747AC6747ACC757DC76A74B64E55
CB5355EA6664E95E59ED6057EB6559DF6556CF6B5BC67D6C9D6E5E52382B40312A3A3531
34302D2B2726302C2D2A26272C28272F2E2C2726242827252B2A282B2A282726242C2B27
2B27242E2A27292522282421342F2B2C272328231F2723202F2B2A2C28292A24281F181F
615A61EFEAEEE6E4E5E4E4E2E3E3E1E3E3E1E3E3E1E3E3E1E2E2E2E3E3E3E4E4E4E3E1E2
F0ECEDCFC6C77A70719E9495C2B8B9A39D9DAEAAA9EBEAE8DFDFDDE1E0DEE2DEDDE4DFDC
E6DEDCF7EDEB998E8A574E47BCB8ADD0D0C600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFF0E9B3988D89604EA96F5BBB7059CD735BD06A53E6785D
E17052F07A5CF37A5BF57A5BF06F52EF6D53EC6851E9674FE86A53E76D56E56E58E6715D
E67360E5725FEA7764E97462E76F5EEA7261E86F5EE16A56DA6551DB6B57DB6E5AD36A57
AA49368E35237C2A1C722A1C6E3025511D124B1C16441D183A1B1634181533191835181A
3414173F15194F1219621318A74544E5746EE76B61ED6B5DEC6859F06C5DEF6B5EF16D60
EF6B5EEE685CEF695EEF6B5FED685FEE6B61EF7067EC7066ED726AEF766DEA7169EA736D
EB746EE6706CE7716DE16E6BE16E6BDF6C69E36F70E16D6EDC6869DF6969DC6163E26563
EB6562EF645FEF6259EA6055E96559DD6759CD7162C684767E564A432F263C332E373330
373634312F302B292A2E2A2B2925242B272426221F29242126211E2D2825292522282520
292621292621262520272621332F2C2D28252924212C26262A26252D292A2A2529221D21
989699F5F3F4E2E2E2E3E3E1E5E5E3E4E4E2E2E2E0E3E3E3E4E4E4E3E3E3E4E2E3E7E3E4
F7EEEFB4AAA9A09292D0C2C2CBC1C095908DB8B4B1EBEAE8E0E0DEE2E1DFE4E0DDE4DFDC
EAE2DFEDE6E07F7B709492869A9A90E9EAE400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00EEE7DFA391838A6D5B946754A76D59B56D57C16F57
BE674BD07256DE7C5FDC7759DE7558D76B4FD86E54CF674ECF6D54C0644DC26A56C6715D
C26F5DC3705EC56F5EC6705FCB7260D17663D07361CD715CD0745FCC7059D2735DD37762
C56954C16953B15C48A65544944B3A7E3B2B692B1E581F144C1A1144150D3E110C3E0E0C
400D0C480C0C52070B5D0305A23936E8716BEB6D61EB695BE86553ED6857EF6759EF6759
F26A5AF06858EF6759EE695AEE685CED695DF26E62EF6B5FEE6C5FF27063EF6D60F06D63
F06D63F26F65F06D63F26F67EF6C64F26F67F5706BF26D68F26D68EE6763F16862EF645F
ED6059F3665DEE6157EA6256E66659DB6B5DD07A6DB97D725F3D343D2C253B3330343331
3433312C2A2B2927282A26252824212925222B262327221F2D25232E29262E292528231F
28252026231E27241F27241F2723202824212822222F29292822222E2A2B2F2A2E2E292D
C6C4C5EFEFEFE3E3E1E2E2E0E4E4E2E5E5E3E3E3E3E3E3E3E3E3E3E4E2E3E7E3E4E5DFDF
F4EBECE6DADAA59796726463675D5B8F8A87E6E5E1E5E4E0DFDFDDE1E0DEE2DEDBE3DEDB
F2EDE9CBC8BF8587797B7F719EA19800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F2EEE2D9D2C3B2A89F887A92715E946B55
9E6F55AA745AB1735AB07055B67359AE6D51AE6E53B1755DB27F6ABD8F7FBE9486B89084
B28C7FAE887BA98175A47A6CA37868A67868A0715FA1715DA27059A6745BA47058A77157
A86E56AA6E54B2745DB3725CB26F5CB06C599A51408940317D3425772D206D201667190F
67170E69120B6D0E0A72060397201AE0645CEE6E63FB796BF4715FF4715DEF6A59EF6A59
F06B5CEB6657EE695AEB6657ED695AEB695BEA685AED6B5DEE6A5DEF6B5EED695CED695C
ED695CEE6A5DEF6B5EED695CEE685DF16B60F36A62F56C64F0655EF0665CF2655EF0635A
F2655CEF6258F06359EB6559E26859D66F60CD7F72A36D614D2F2741322F3E3634353130
302C2B332F2E2D29282B27242A26232925222C26262A252227221F2B26222C24222D2523
2C27232A252128232026221F1F1B1825211E2723222925242721232B25292620244C474B
E5E3E4E8E8E8E3E3E3E3E3E3E2E4E3E3E5E4E2E2E2E3E3E3E4E2E3E7E5E6EFEBEC908A8A
968D8E998F8E9F9492978C889A938D97948FDAD9D5E7E8E3E1E1DFE1E0DEE1DDDCE4E0DD
EFEEE9B1B3A88E94866B7366D7DCD500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F5ECE4DACEC4B4A4
AD9887B39A86BA9B89BC9B8AC3A08DBE9E89C0A18DD8BDACF1DED0FFF2E8FFF6EDFDF3EA
F8EEE5F2E9E0F2E5DDEDE0D8EBDDD2EADACDDDCBBDCFBCADC3AE9DB8A390AA947FA28772
95796391715C8E68559166539665549B6654A36858A76857AB6858A86353A155479C4E41
9C4A3EA24A3EAB4D43AC453CB6463BD86457DF6759E56B5CE96E5CEE715DED6E5DEF705F
F07160F17261F47262F57363F27060EF705FF27062F16F61F36F60EE6A5BED6859F06B5C
EE6A5BED695AEC6756ED6859EF6759EE665AF2695FEA6056EF655AF06359F06359F16359
EF6157F26659EE6255EC6859E06657D77061CB7D708F564B4F2A22472F2B40312E3B302E
342A28352D2A2F2A272E29262D2926302C292C28272925242E2A272D28252C23242B2223
27221F2D28252C27242B26232824232622212624252725262722262B242B1C151C928D93
F3F1F4E5E5E5E3E3E3E4E4E4E4E4E4E5E5E5E3E3E3E4E4E4E4E2E3E9E7E8EAE8E9979392
817B7B7D75737E767381797679767163625DDCDDD8E5E5E3E2E2E0E1E0DEE2DEDDE9E5E2
EBEBE3A0A398626A5D8E968BF6FBF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFBF5FFFBF5FFFBF5FFFAF5FFFBF4FFFAF300FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDF6EEF5EEE6
EDE4DBE7DDD3DDD0C7D0BFB5C1AFA3B4A193AB9387A4887C9F7F729E786B9A6F5F9D6C5D
AB7364AA6D5BB57061BC6E61C06A5BC76A59CC6858D06958D36854D76855D86755DE6B59
E36B5AE16857E46959E56758E96C5AEA6D5BEE6F60F37463F3725FF47360F26F5DF87563
F67361F77462F77364F67263F67162F67162F16B5FF36B5FF0685CF66E62F4675DF4665A
F36559EF6153F16556E96455E06556DC7063CC76697E3A2F521D154B231B3F21173A2218
3320192F221A2E272128242124231F2726242523242422232625232A26252C26282C2628
2E282A2B25272C23262B25252C2829201E1F211F2228262B2621282520273E3940D9D4DA
EEECEFE5E3E6E4E2E3E5E3E4E4E3E1E4E3E1E4E3E1E4E3E1E2E2E0E3E3E1E1E1DFE3E3E1
E5E4E2E5E4E2E7E3E2E7E3E2E4E3DFDADAD8E3E3E1E2E2E0E2E1DFE1E0DEE4DFDCF2EDE9
C1BEB5787A6F646A60CFD4CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFFAF4FBF2EBF5E8E0EFDED4EAD6CBE3C9BC
DDBDB0D0AC9ECCA093C79688C68E81C38576C27F6FBE7566BF7363C07160C16E5EC46C5E
C76B5CC76A59CC6B5BD06C5DCD6758CF6857D46959D46657D76855D56452DB6A58DB6856
DA6554E16C5BE06858E36B5BE26859E56A5BE56A5BE76C5DEB6D5FED6D60EC6A5CEB675A
E76253E56051E66152E46252DD6354DC6E5FC165567325185E1C0C511C0A461C063E1E07
361D07291806190F03100C030B0A050B0C070C0A0B0D0B0C110F10100C0D100B0F171216
1B1519161014120C0E140E101D1B1C2A282B2F2E342F2E36302F373E3D4598979FDEDDE3
D7D6DBE0E0E2E4E2E5E7E5E6E7E5E6E6E5E3E5E4E2E2E1DFE0E0DEE1E2DDE0E0DEE2E2E0
E3E3E1E3E3E1E2E2E0E3E3E1E1E1DFE2E2E0DFDFDDDFDFDDE0DFDDE1DDDAE9E1DEF3ECE6
6E6A5F64645894978EF6F8F300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFAF5
FFF9F5FFF9F5FFF7F2FFF3EFFFEEE8FAE3DDF6DDD6F2D5CDEBCDC3E3C1B7D9B3A8D0A59C
C79890C09086BF8B7EBB8678B67B6DB47566B87467B76F61BA6E5EBB6E5CBC6B5ABF6C5C
C26B5AC16654C26554C1604FC66252C86152CB6455CD6355CA5F4FD16153CE5D4DD25E4F
D25D4CD5604FD76250D76251D2614FCE6351BE5D4AA551399C5537894D2977471F6E4B21
61451D4F3D19797053837E6A7D7B6F75746F807C7B7975767975767874757772766D6B6E
7672737F7B7C858182908C8DA6A4A7A1A0A672727C4B4D59474B564A4E576D717A74797F
787D838F94989DA0A5B0B1B5C0C1C3CACACADAD9D7E9E8E4E4E3DFE4E3DEE5E4E0E4E3DF
E5E4E0E4E5E0E3E4DEE2E3DDE3E4DEDFE1DCE1E3DEE0E1DCE1E0DCE3E0DBF1EAE2DED8CC
423F30807E71D2D3CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3FFF9F3
FFF6F2FFF0EAFDE9E2F9E1D7F5D8D0F2D1C8F0CBC2EEC6BCE8BEB2E6B8ABDEAEA2DBAA9C
D9A397D49A8ED59A8CD29286D18D80CD877BCD8579C77D72C87C6FC5776ABE6F62C16F61
BD6A5CC46E5FBD6758C0685ABA6455B66353B26553AE684FA76A4BB3825AD0AA7BC5A775
C0AC7AC7BA8EE9E0BFEBE7CEE7E3D7E9E6E1EAE6E5E6E1E5E5E0E4E7E5E8E6E4E9E2E0E3
E4E2E5E7E5E6C2C0C19B999A757678393D4022272D2F363C3740453A4446424C4E485254
4C56584D5758535B5D51565952585850545370726FE3E4DFEEEDE8E6E5E0E5E4DFE3E3DB
E4E3DEE4E5DDE3E4DCE0E3DAE3E6DFE2E5DEE1E4DDE0E3DCE0E1DBE7E4DDE4E0D7A39F93
484536A2A094F6F5F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F5
FFF8F4FFF8F4FFF8F4FFF2EFFFEEEAFFE9E4FFE6E1FDE1DDFCDFDBF9DAD5F4D5D0F3D2CB
EECCC3ECC7BEE3BDB4E0BAB1D5AFA6D1ABA0C9A599C09F8EA98D75B09979A8966EC6B98D
D1C89DA09B75A6A285D7D4C1CCC9C0A6A5A1B4B2B3DFDDE2D1CFD4B0AEB3B8B5BCBEBBC2
E7E5E8E7E5E89A98997577767379777F88854C5753333F3B45524B45524946534A48554E
48554E4A56524F5A564C575349545047524C495049ACAEA9D2D3CDC8C9C1C6C7BFCCCEC3
C9CAC2C8CBC0CACDC2C9CFC3C7CDC3C9CFC5C8CDC6C4C9C2C5C8BFC1C4BB9B9C947A7A70
8B8B81D3D2CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFBF500FF00FFFAF4FFFAF4FFFBF1FCF3E4DBD5BF9F9A7D9A9778
908F70616145373923A4A698BDC0B7414340404143A0A1A5C0C1C53034374142475B5C60
9C9D9F9698977C7E7D646867737975B8C1BCABB4AF89948C909C92939F959FABA19FABA1
A0ABA3ACB7B1B0BBB5AFBAB4B7C2BCBCC7C1BFC5C1D1D6D0DFE2DBDFE0DADEDFD7E3E4DC
E0E3DAE0E3DAE4E7DEE4EAE0E5E8E1E7ECE5EAECE7E7ECE6EDF0E9F0F3ECEEF1EAF4F7F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8F8F0DDDFD4
ACB0A1838A7A5860515A6459657167303B35333C39505B57C2CDC939444035413F3D4945
47524C4C5550464C48797E7AC9CBCAF5F7F600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00E8EFE8CED5CEBAC4BCA5B0A895A09A87928E76817D9FAAA458655E4B575348554E
5D6A639EA9A3D5DBD700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00ECF0EFE3E9E7DAE0DCD2D8D4
DAE0DC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.609118 0.97619 1.13764 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F5F5DCDCDABEBEBC959593767674
898B86B6B8B3D7D9D6F0F0EE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEECD3D2D0AEADAB8786845D5C5A3E3F3A2425201E1F1A1C1D18
23261F23261F3A3C375355507C7D77A9AAA4E0E1DC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00D4D3D15D5C5834332F1F1E1A24201D1D1C181D1C171B1A15201F1A20211B
22231D1C1D151B1E17181B1421221C22231D54554FC6C7C200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00F3F2F0726E6B211E1923221D25241F27262125241F22211C221F1826231C292621
23201B23221D201F1B22211C26272123241E22251E3D3F3AA7A9A6F6F8F500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A5A4A02F2C2725221D29262126252024231E2926212D2A2535302C3A3531393430
35302C37322E36312E2C282529282323221D2627211E211A2527227D7F7CE8EAE900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D0D0CE41403C23221D27241F25221D23201B2A272238332F3B3632423A38433B3939312F
3C3431433B38423A374139363C37332F2A262926211E1D181E201B1A1C19797B7AF5F7F6
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E8DAD9D1BFBDD8C6C4DDCBC9E5D3D1EAD8D6
EEDFDCF6E7E4FBEBEBFFF1F0FFF7F5FFF6F4FFF7F500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F0F0EE
6C6D681D1E1922211C25241F211E19211E193B36323D383435302D39312F393031332B29
372D2B3B312F3F35333E3432443C39423D393D383425241F1D1E191B1D18323431CDCFCE
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECD7D47C5751582B2561302C6534306D3C376E3F39
784B467F544E865D598D6661916B6892716C987974A68985AB8D8BB59996BB9F9CC5ACA8
CCB3AFD7BFBBDBC3BFE1C9C5E4CFCCE8D6D2ECDDDAF2E4E3F4EAE8F7EFEDFAF6F5A6A5A3
2F2E2A25241F24231F22211D1C1B162B2A25413D3A2F2B28312D2A2F2A272F2A27312C29
37302A342D273C332E3B322D3B342E3D383245403A35352D24251F23241F232321878785
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F7DFDD8D64606B302A75302973292670262370292369241D
6A272164251E6A2D287E433D733C376C3A336A3934683B366236336438355B322E5C332D
5B342D5A332C5530285D3832623F3963423D6B4E4A6C534F6D5A565E504D554D4B37322F
26221F272621262521231F1C19161137342F423D3A27221F2C28252B2724282320302B27
332C262F2822382F2A3B322D362F2939352C38332D43403938373221221C23241F40403E
DCDCDA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAE6E59D706D75312E873633872D2C862D29832A26812927812C29
7F2C287A2B267729257D33307A372F7B3C357136306B322B68312C713C3667322C6D3830
6D3B327242386F3E376C3B3471403974453F673A34562D2753352D2F1812130502211916
2E292625211E26221F221D1A221A173A322F463C3B261E1C36312D312C2827241F292621
2A25212D2522332927372D2B362F2938332D2D28243F3C3740403828292323221D21201C
91918F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFEFEDA88281702F2D87322F8829278C282896302E8925238E2C2B8F312F
882D2A882E2D832E2B81302D7A2F297C362E77342C692A237539317A3F376F342C70372E
69332969352A6E373070393278413A8F564F7C433C622D276F443D47261F1F0A05271C18
2E262326211E28232025201D221816352B29493E3C2F252338312B39342E29241E27221E
26211D2B23202E2624352D2A342D2739342E26211D34312C44443C30302823221D1F1E1A
424240D8D8D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5BC9693692E2A8938359B3C3AB34B4AC65C5C9D3534932D2B9836359E3E3F
993B3B9C4241933B3989363280312C7F362F8C474073332A7C40388449417F463F763F38
7C473F744239713C366C37316F3531753833793A356D302B7D48406237302E110B2D1B17
2F24202E26232A252227221F271D1B2F262144393540352F382F2838312930292329211E
2B2320261E1C2A221F2E2623342D27453E382A252138332F4B48432F2E29252420272622
26262480807E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00C6AAA7662F2A732521A14341B74F4EBC5252B94F4FA03837A94543A64445943435
943636903534943A398F3A378637327C312B742F2875362F6A2F297039327A453F7A453F
84524B814F48723D37753E39743734712D2A762F2B752E2A8946407C433C4C1F1A3A1914
361E1A3526232E23212B23202D23212B221D3027223C332C443B343E352E312A242F2822
322A27271F1C231B18302923413A34423D372F2A26423F3A413E392A292424231F292824
2A29272F2E2C706C6DA6A0A0CFC9C9F0EBE800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D2B9B4693C3669201A89302CAB4541AA413EA8403DA33D399634318E2F2B8A2C2C882A2A
892B298A2F2C8D32318A32308736326D241E8A49439A5F59753E3979464285544F895853
8A5753925D5987504D8B4F4E904F4D843A3981302D83302C8C3935984944813E38561F1A
3B120C3A1D1735221E2E231F2B211F2A231D2A231D2B241E4138334A413C49403B3D342F
3D3630332C26322D2739342E3D38323D3A33423F3A3E3B3634302D2A29252524222A2927
242321201A1A1E14151D0D10422E2F715B5D877173B6A4A4D9C9C9F4E9E700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7D5D1
7249435F20197D28239B3735A63E3BA23A379C363293302B8A2B27842624882A2A8B2B2C
8C2D2B8B2C2A89292A872C2B822D286C211B92514BC58B87AB767094635E92615D93625E
A3706CA5706C9A6261935757945253863C3D8A3636862C2B8E302EA04240A149478B3D39
5E221A4819133D1A16361E1A2F201D2E252029221C2B241E2D241F382F2A453C3747403A
47403A47403A47423C46413B423F3843403943403B2F2E292A29252A29252B2A28262221
261D1E271B1D230E1326090E3F1F225E3C3D5737384A2C2C4C332F65504B897871B8ABA3
DBD0CAF5ECE700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B19591
622B2671241E9132309F3937A33D3B9F3937932F2D8F2D2A8F2D2C8E2C2B8C2A2B8D292B
922A2B8C242591292A8D2B2A8E332E8030296D28218A4D48BB867EBC8A8394615D895653
B07D799C6763AA72719A5E5E7F41426F2B2C7526297C26278F2F30A23E3EAB4543AA4B47
9B433F762D27551B174519163C1E1C3724203325222E23212C22203228262C2421322D29
312C283B3632403B373C373339363136332E2C2B262A29242928242726222B2623291F1E
2A1A1B341B1F2D0C133910184C1F245F32358E6465916B687D5B5265453A5639294D3221
5B41306F5848957F72C1AFA5E3D2CAFCEFE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FBE9E5835E58
65221C842B279F3937A2383898302F9D3735993331952F2D902A288C2425942A2C972A2D
962829962527962829992F2F922F2A8A312B7C312B81403A8D564FBC8A83C79491875451
A26F6CC18E8BB67E7F9A5F61A66A6CAA6A6BA75F629242458933348E32339D3D3E973939
933B39984A4882413F5C29263B15143D211E4028283A26273323233325242D2220312725
352B292F25232F2523362C2A2F2724332B282A25212D28252E26242A201F2D1D1E2C1618
38191E38101834050D4D1A215A252D5C282C7141419A6F69AB83799A756397745E907155
8265476E51335A3F2450361F573E2A6E5948938175BFB1A8E2D5CDFAEFEB00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DBC2BD653630
70221E90312DA13835A537369C3030992F2F9C302E982A299729289A2A29A02C2DA32C2E
A22B2D9E2729A52E30A43031A133328B282395403BEDA6A0C88D87915F58D29F9CAB7978
703E3FDBA7A9D49DA26E353BB77F82DB9FA1C8878BB16F71AB696A894546B97375D99395
BE7C7D8E5051793F3E734140653D3D4927264E2C2D48282B45282A43292C3D27293B2729
3523233422223323233626263424253222232E1E1F311E22311C21361B2039141B390E15
410E15430C12561A226B2E36682C34652E33643032764642A27A6EA27F6B937457937752
9880529A7F509D805495784E80623C6F512F5D3E2253351D593C2A725849978176C3B1A7
E3D4CDFAEFE9FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE8D88602622
7D2A269C3836A33735A13130992B2C99282A9D2A2DA12D2EA83435A42D2FA62E30A92E30
A92E30AA2F31AE3336AB3335A733349F3130842221B86561F2ADA8CD928EA06966D7A4A3
926063D6A3A8F1BCC26B363C935A60DFA4A8B07378BB8082905A5AAF787BF0B9BCF8C1C4
F0BCBEDDABAC916161CCA09FF0CAC9BC98985D3639553133502D3140202548282D523237
4525284022243E2123381E213C21263B1E233A1B2334131C3B152043152048101B4C0D18
53101964212A7330396D2E36894D5570393E6935375727237B5349A98672A5876B8E744F
8D7545917A44957C449D824BA1834FA384559D7C5193714B8463426A4B2E593D254A311B
543F2C716050948477C2B5ACE3D8D2FAF2EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8EAE7825B5663241F
883231A23B3CA336399D2C2E99262BA02C2FB94246B94045BD4449BE4648B73F41B1393B
A93133AB3335BA3F44AF3437B2373AAE3739A431348C2624A44C4AEBA29CCC8C8AC08887
D5A3A6BC8B8FEBB9C2925F685E272DCB9298AB7076CC9497AD797B875556F0BEC1EAB9BC
956769BE9495EBC3C3F9D6D4F8D9D7E8CAC8856566D0B0B3D8B8BDA8858B5C333B5C2D35
602F3557292C471E223D161B4118204B202A481826440F1F511628591627681B2B792636
7E2E397D313B78353C70353BA77278916064774649693B3B5D342E7E5A4CB1917CA68B6D
90794F8B7543917B42968044947E42957D41997E47A28752A78D5AA38958A2875A927950
8167426E5433583E234D351D5A4331705D4FA18F85C9BAB3E8DAD7FEF4F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D9C6C26B3C36722B27
9439389D34389D2F32AA393D9B2A2EAC3B41B7484EA9383EBB484DC45156DA6669E67273
E36C70D2595ED55A5FCA4F54CC4F55C3464ABD4245B541429F39379E4541D58783E7A6A4
FBC5C5C49397A27379EDBBC4AC79807B444AB57C83E3AAB0EDB5B8804C4EDAA9ACEEC2C3
D4AAAB855F5EC09E9CFFE3E1E9CDCA9D817E856968F2D4D6F8DBDFFDDCE3E2B9C1976870
79464D6F3E429B7175C79EA69A6F79623441834E60C1869CA36278BD74888F3A4F9C4153
98404E86353E833C42A96C71A87174A37174966666956767986C697A544B967264B99A85
A58B6A8C754B8069378A743B927940967C419B7E449B7E469E844B997F469E834CA58A55
AA8E5CAB8F60A78A609476507D6040654B305B422C4D36245946386F5D539E9087C9BFB6
E8DDD7FEF5F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE918D6B302C85312F
9B37399E31349D2E34A6373D9D3438B55255BC6166B85D62AF4C51AB4447AE4144BE5051
D66368D96268DF666DEC7176E3666CD95A61D6595DD2575AC65253B64D4AA54644BF6E6B
F1B1B1FFCBCD98676A96696CF7C8CED29FA4935A61A4656DCA878E7C3E43C79598EAC0C1
C39D9CCAA9A4977873ECD0CCFEE5E1DFC7C5A98C8EE7CACEFADFE4B6999EDDBEC4E4C1C7
654145AE8A8ED0B0B5DDBEC6F4D3DEBC98A6906377EEBAD1DCA2BAD38FA6C16F86A0475B
A74C5D822C37B0636BCE8C8EA46868AE7675A06A6A996766A3736F996C66986D66A98376
B99984B193777D613C583B11714F22815D2D8C6335976F3E9E7A489F7E4B9F804A9E8149
9E844B9F864D9F864DA58C54A58E5AA58D5DA0875E957B587B604362462E4C311C472D1C
573D2E735D50A08C83CCBBB3EADDD7FDF4EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAE8E6845C5A77302E943636
9A2D30AE3B40B64147BE4F55A43D41AA4E51EE9FA4FFBABFEB9296DB7C80CD6A6DBB595A
A94448AA4146AD4046BA494FC45158CD5860D96268DA6166DA6365D56363D16563BB5C5A
BE6E6DF7B3B2FBBFBF8C5656B17D7FFFD1D5F4BDC3995C638A474E88464A8C5457F6C8C8
BB9592B1928DBA9B96B39793F9E1DDF2DAD8E1C4C6D4B7BBFFE2E6CFB2B6A88B8FF3D4D9
997B7DE2C5C7FFE5EADFC4CBECCED8FFDEECC79DB1B2859AD8A4BBEAAFC5E69EB49E4C62
A750618E3845A3525BC87D829D595AB87878B07372AE7271AB716FA26B6897625C7E4E44
A97F71CCA794AF8B717B583869411D7C50297F52298051277F5429875E30936D3C9B7743
A3844DA4874D9D8346A38B4DA28A4CA28C52AA915BAB9160A88D62A48861977A5A826448
694B31563A24452C163D26145441327563579F9089C9BEB8E9E0DBFDF5F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E1C5C2753F3D832E319E3438
A42F35B93E43BA3F44B84349B0464A95393ED98C92F6ABB0C0696FC56A6FD98384DB8B8C
E3979BD08186C56E74B55860A2454D9E3D44AB4249BC4D54C55458C75457D05E5ED26463
D36B6AD77977FAA6A4DE9292AD6664D39695FFD9DCFCCBCFB77C82A26467884849BA807F
F3C8C2A3807ACBACA7BCA09CE2CAC8D2BABAD9BBBDE6C6C9E4C4C7FFDFE3DEBBBFF0CDD1
D5B7B7CFB2B4FFE7EAC4A7ACC2A3A9FFDCE6D1ABBAAD8496BA8FA2D5A4B7FCC1D5B36E81
88394C8C384886323F903F4686373A8D3E41AC6062AF6566B3696ABF7876B6716CA3625C
7A4136BE8F7FC99F89A880667D553270462083532B87562E84532B87562E84502B86552D
885B31976E40AC8854AC8D54A58B4EA58D4FA48F50A28E51A08D559B8A56A08B5EA18B62
A38B659E8660957D5979613F664D2E4E34193D220D3E2413533D2F78665AAA9C93D0C6BD
EDE4DDFFFAF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E9E8E4D4D3CFC3C2BEA7A6A28B8A886C6B67
65616063625E69686465645F62635D767771B7B8B3E9E9E700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BA94917232328F3034A43138
B63A42C24048B43338B93E43B14449983C3FE19A9EE1A0A48F474AA65C5D914B4B935655
FFCACACE9697C18182D79295D79096E99CA4CE737CCA656DBB4E54B54448BD4B4BB84645
C14F4EC55957CC6868C96B6BC66E6CAE605EDEA3A5FFD9DBFFC9CCBD7D7EAC6263A15A58
D99F9BE6B7B1DAB5AFE8C9C6C0A2A0EBCDCDB99798E4C0C4D4ADB2D0A6AAF4C1C6F1BDC1
FDCCCFEDBFC1FFD8D9E0B8B981585CDFB6BEE0B6C0A37985F6CCDAE2B4C1DCA7B7DC9FAF
9952647E31417B2D3A7E2E37792A2F7B2C2F9141448331359D4B4DA55053AA5656A25450
6F2A238C5246C39482C79D84A47D5C7E583173491F774A20794A207E4D25854F2B854F2D
844F2D784621805028906538A27D49A98A51AA9053A49053A39459A69B63A195639D9063
998A5F9E8D629E8B619E885FA28A649A805D8B7150785D40664C33472E1835200D362513
5040307A6C5FA89B92D3C9C0EFE6E100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00EAEAE874757048474232312C2625212F2B28322E2B302C29
312C2939353239363137342F32322A2C2C242F2E294D4C4890908ED4D4D200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F9E7E58F625F782E2D983337B13A40
BF4047C03A43BC363FC14249B7494C893130EFB3B2F1C4C1AB7A767D4A4661322CC79C95
FFDDD7ECC9C37C504D704242DEB1B4FFD3D9D58892E48791F28A91EF8285E27676D26463
C65857BC4E4DBD5053BF5557C86061AD4D4E934143E8A0A3FFD0D4FCB8B9D37F7FC66E6C
B2635ED7948CFECBC7FFD9D3C39C97D2AAA8E5BDBEB48A8EEABDC4C28B91D98E95E48F96
EA959AD98789CF8584EEADABDFA5A4C08C8EFBCAD0B4858DC6949FF6C2CEBE8895D9A1AC
E6AAB6A7697472333CA3626AAB696D934C527B2E348332388D363C92373C8F3034903636
883734702C23925D4DD0A68EBB9878A181588E6F408665327C58267C542376471D75411C
824A29854A2C82462A8247297E48248C5D339E7847AA8F5AA3925CAFA570A39D6D959267
9A96709C96729C946F9A916A9C8E679C8D649D8B63A08D659F8C64947E57806947664F2F
50391A452D11381F093B241258423478665AA99A93D2C7C1EEE7E1FCF9F400FF0000FF00
00FF0000FF0000FF0000FF00898A85191A141D1C1723201B2825203B36323E39363A3532
3F3734473F3C473F3C453D3A403B353C37313B3831312E291D1C1731302B8E8F8AF4F5F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DCC4C277403D843330A1373BB73E45
C1444CBB3C45BF4049BD464CB44D50742521D2A099FBD7CBFED9C9BC9785A7826FF3D3BC
BDA18BF4D8C2C0A18DBB9B8CF7D6CFFFD9D8C27B83AA4F58CB6068D8656CE57275EF7C7F
F58182F27E7FE67275D86467C75457BB4F4FA23E409C4443D6878AEE9E9FCD6D6ED16D6B
D77874D07D77DD9A94FFC7C3DAA5A1925F5CE2B2B2DDAFB1F8C7CDEBAEB6BB646DC65E67
C55A60BE5559A24444CA7473F6AAAAE39FA0E5A7AAE8ABB09C5D65E6A7AFC1848C8A4F55
E7AAB1C68990A96B70DB9DA2DD9FA2D29195C47F848F424A852E3690333B902C34903034
8F35357B2C276F2F25C79783DEB99CB99C74A68A5A957A457B5C26906A3997683C905A34
85482B803C2589402F8E4534813D287C3F2378441F90693EA28A5AAA9C6B9D996A68693F
6365407A7B598A8A689895729B95719C946DA1956D9E9167998A5F9D8C619E885F927B52
93775087694574533461422654361E3B200B2C15053A2719544437766A5EA9A097D0CCC3
EFECE500FF0000FF00B6B7B22A2B251B1A152E2B2627241F39343045403C3C343239312E
3C34313B33304E44424D443F3B322D3D342D433C36433C343431281C1C12212119979892
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B59693793937913736A93C3FB84147
B94248B23F46A3363C9532379945455B1812C5998CD0AD97BC997BEFCCA6FBD9ACD0B081
AE8E5DD2B281FCDDB1ECCEA8B8987FFBCDC0E39D9DAD5058CB5561D04E5ACC4951D55258
D45358E16367EE7175F2777AF37C7EEB7979E17372C25A59AE4C4BC15D5DB64C4EC45858
BA5050B65451B25D5ACA7C7ACE8785B87775AF7372EBB5B5FFD5D8FFC6CCC77079C95F69
D36268D05F63C65C5EDF7B7DDD7F80C86E70B76164E28D92A65156AD5B61EBA0A5B87074
BE7679EEA6A9A75C60DD9598D391927D3F40D09297CD878F8A3942AF545DB14D57922D33
8E2B2E892F2F6F241F854A3CD0A38CCDAA8AAF8F66AB8C5D7B59295E330679451D8D512F
A35D439548347D2B1F8B372D8B392E873A2A7C3823763F21805A339C8657A69B6D8F8E60
50552D4B532E555A3A5E61446C6B4F817C5F938A6B998E6E9D9370A3967394855E947E57
9A7E5686663F7C5A3484613B83613E81603F7152355E4026492F1638220A311F093B2E1B
544D3D7B776CA29F984948431F1F1725251D2A27222C272345403A403B35362E2B372F2C
3A302E332A255449454E433F382D273B312845383242382F4841373D392E27241B32322A
B0B1AC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9EAE78C64627B3432983637B64549B43D43
AD3C40A73E42B85E60A85A5AA8635E854D40D7AD95D7B391C7A172D6AF76D5AF6EC6A059
EBC57CCCA760D5B771C8AB6FA98A5BE5BC9EF9BBB0A85454C1535CCE525DD1525DD04E58
D14D58CE4B53D24F57D45358D5575BDF6466E97172EE7A7AEE7E7DF18382EA7E7EDC7272
CB6765C16361AE5A58A35956A35F5CAD706DB07473A3686AE1AAADFFC8CCDE838CCA5C65
CE5961D05B61C95B5ECB6364C9696ABB5F60BB6264BA6467B65D61A44B4FA65458D18184
DA888AE69496BF6D6F954747DB9796A26564A1666AF4B5BDA0505B9A404AA23C4790272E
972E35912C30872D2D691E18925948CDA188BF9B79AC8B62A58258693E1466300A7C3B1B
893D258A37277F251D8D302B8D322D8D342E86372A803C276D3A1B68451D907B50A8A173
83845A484E28424727676A4F7D79606B634C6B5F4770604676674A8677568474509A875F
947B5281643A7F603477562B73522785643B75532D71512B785832745833614A28534224
372B13231C0A1912081C1912201D1625221D26211D27221E4A453F39342E3028252F2724
2C251F332A254C433E473C382F241E372C2641342E3D332A433A314541363E3A2F24241A
3B3C36C0C0BE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00DAC5C27747457E2E2DA63D41B84147B53C43
A6353999393AEDA3A0FFCCC4F4BFB1ECBCA5F4C8A5C49A68D4A869EDBF74E4B460DEAC53
E1B457F2CA6BBD9C3FDDBE6BCBAE68C9A873FFD6BAA466598C38369F3E45A9414CB44452
C54B58D04D5BD54D59D54C54D64D54D24B51CB484DD05255CE5858CF6160CF6B69C86F6B
BA6B64BD7A72B67D76B1827CAF8682BA8E8BC89697B2777BA56367D7868CC25D65C45359
C64F55C14C52AE4446BA5C5CCC7B78B9726EB57170B06C6DB3686CB7686DB35E63A85157
BD6267B15759AF595A803031894343BD7F80D4999FFFC1C9A85C68872F3BA139449D2E37
9F2D37982930942B2F852A276A2118A56C5BDAAE95B4906EAC89639E744C6C3813773618
893B258A32248E2F298F2D2C9331309132308E342C88392C7B392366331464421C8D7A4F
ACA5777F805440401A535031A1977E93816B7A5F4C866A54775C41705738604A25746137
7C673C7D683B826C3D7D6537816639937748795A2C70512378592B7E6233604A1B655228
746544574D3421190C1B140C27221E27221E27221E221A17433E3839342E201B17211C18
241F19362F293B33303B312F3128232E2520332824382F283B342C3A362D454138282820
1C1F165B5D58F2F2F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00B19391703837872E30AC3F44BB3F47B6393F
B5424592302F904943FAC4B8D5A692BC9171DBAF80CB9D61E7B76FDEAC57DCAA4BCA9932
BC9025DCB347CBA93DDBBB56E3C56DB5974FFFDAA9EEC09FD59A88CB867FBB6C71BA5E6B
C65767C84A58D34B57D54851D44950D44D53CF4E52C85153C85C5CB55755A554509A574F
A97369C09489B9978EBB9E96B39A95AA8D89AE8887BD8B8EBC7B7FAD5B61C25D63C15056
C24B51C04C4FAF45479C4140B46963B67A72AD7874A87773AB7374AF7174BD767ABB7074
B9686EAE5E61A95D5F7933359E6262A87073B0757BFEBDC5DB8F99A349559F3541A93540
A32B35A42C359D2A2F9830317A221E732D23C18978DBAF96B7906FAF8763A573506F3213
782D168C392990332B8F302C8E2F2D8E302E913830873529823B27753D2258300D61481F
9C8E5DABA573706D403C38126E6347A8937E77584665422E815D457C5B3C7456326F562D
664F236D5829725D2E76602F7E68378A73419379468E733E876C37866D37614A165F4A1B
8071486E6345271E0D1910072E27212B2622261E1B271F1C362F2945403A2F2A26211C16
25201A2F2A243D36303B342E342C29241D172C231E2D241F39322A39352C49463F33332B
1E211843463FE5E5E300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F7ECEA8F6968763636933438B23F46B3343BB8373C
BE4346B14747802D29AC6E61F2C4ACCAA37CE6BB86EEBE7CEFC072BC8D35B58926C59C30
D2AC3DC5A22EB3901CB69524EDCC65C9A74ED6B46AE4C084F0C69CF2C6ADFECCC5FFCBD2
F08E9BC04756D34C5AD44851D44B52CE4D51C85558BB5958A6575395564FA4736CBA948B
BB9D93AF978DAC988FB3A099A5948C9D8A84A18884A78383C28E92C37C82B95E65C1565C
BD484EC14A4EC251539C3A37944741AA6E66A1746E97746E9876749B77779F7778A67A7B
AF7D80AC7A7BA47275956467F1C7C9F4C7CC93575FB8727AF3A3ACD47982A3353EB03841
A93037A92E33A72E339F2E30932D2B7A221E874338DFA796D4A88FB28969B18560A06C47
6A2B0C7E331C8936268B3329893229822E247D2F2277301C76361B754021653C1E422400
8B7A46A69C61ABA8715D5B2B3D3413827259B0958266432F774E388C6045825A3775522A
6243175B4011674F1F523C0B564210634F1C705B2677622B786229836D347C672E776330
8173466F624021190621190E2F281E2F28202D241F261F192A231D3B342E453E38332C26
27201A2E271F403931463F37372E29261D16281F18292019362F273A362D48453E33332B
24251F3C3D38D9D9D700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00DBC9C77345457D3536A23F44B03B43B4353CB93B3F
BB4748AC464480312A6E3323EBBFA2E7C194C29659E6B86DB0822DB78B2CEBC259F1CB5C
F1CE5AF3D058F0CC54D1AC37BC982ADBB955D0B157DDC074CCAF75A5855EF7D2C2FFC5C7
BE616CC44E5ECC4957CD4A52CB4E52C55456B25454974E4897605BB08A81BEA199A9958C
9E8D859B8D84A1948CA59890AB9E96AEA199AB9995A58B8AB08889CC9195C27379BC5B62
C6575EC14C52BD494CB64C4C933E399A5A51A4756F95776F8C756F8D7A768C7474907677
957978997B7B967677957779CFB2B6F7D3D7BD8890A36069B86871BB6067B74C54B34047
AF3A40AC373DA9363BA436399D353695373571221DA9695FE8B8A4CDA488AF8763BA8E67
97633C6C2D0C82381F8A39268736257425147A2F1C8B473079391D70391A5D30114E2B05
997E479F8D4FADA567AFAA73534E24483D1F947E67AF8E7B6136238858429F6D52956746
7F552F724D238562385C3D115034055D43125D4310634A145D440C5A410870581C89733A
76643261532C221800231C0A2A2414312B1F332A212E251E271E172C231E3A312C49403B
40393130292139322A342D252F261F2B221B2A211A2B241C38342B3F3C353E3E362D2C27
1F1E19343530CFCECC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00BFA7A76C3636883839A63D42B13A40B1363BB74344
A33F3F81312AA3675CDAAB97E8BD9AC9A16ED8AD69E2B564A37619EBBE57F3C95DF3C959
E5BE47D0A930F5D157F8D35ED3AD40A7841ED9BB5BF2D683AF9451D2B385FFD6C3C28081
B95561CF5667C94B59C54C55BA5052AF5554924F49A06F68C8A7A0BCA59DA291899A8B84
988B83998F869B908A9A8F899D928CA49993AFA19EB3A09CAA8C8CBB8E91D19096C06A73
C45C65C8545DBE474DBC4B4DAA4847863732A46B64A37C759178718A79728977758A7A7A
897A77897A778B7977897576877374A4878BAC8188B97D87CA7E88C06971B34F57B0474C
AE474BB14C50B04D52A64348A24244A145468935336F2A23D7A195EBC2ACC09E7BB49167
BC9262925F326A2B0880391B8B3E227E2E13792B14994F36A560439D5E3D935B38996A40
A9824BA185449F8D4DB6AC6F8C895648431B53452AA98F7E956E5F8A594B98604F8F5541
9A61469D6647A671518D5D397F522B7F552B6C471A6947175C3B086E4D17866727866828
674E15635121312402221B01251E0B302A1A332B20372E25342B222D241D2A211A2D261E
433A3349403941383339302B322B25332C2638312B3C3731413C363E3B36302F2A282722
1D1C172C2B26C7C3C000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A88C8B7137368F393CAB3E43B43B40B63B3EAF3B3C
A13F3CE2938CFFD6CAE2B49DB38865DDB381F6CA8BCEA052B18427E7BA53D9AD44B28717
D6AC36E1B93FDFB73EECC550F8D265B59028D5B352DDBF69AB9147FEE0ACF3CBB1965954
AC4F59C75868C3505DBF545CA74F4E96514CA6756EBB9A91C8B4ABA79A919B8E86988D87
978C869A8F899B928D99908B998E889B908A9B908CA69794B19C99B59394C9969BD18A92
C36772C15660BD4952B9464BBD535599403C914C47A3726B977971907C758B7C778A7F7B
877D7B837977827775867A7A8373748D74789C747CA7727AC37A83B15B64A3484D9B4143
9C474AB96A6DB4686CAC6064A4555A9F50539B51526829249A6A60F9D4C2E0C3A5B89B73
BD9C67C59E677D4D1D652A007C390F8139137E33147F3518843A1D8039198442208E532B
96612FA1773D9C7E42A18E53B0A7707F784A3D3212594731AE8E81A67C70915D50814739
8B503E7C3F2A824832A0684FA76F549462418D5D3990643D8B62368B66319B78388A6C24
6348018C7937796C37271E00241D0028210E312A1A3D33293F352B42382F362D262F261F
281F183027203C332E463C3A4038353E39353E39353F3A363733302C282526221F24201D
201B172E26239F9892F2EBE5FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF5F3937472793C3B973E40AD3E44B3363CBA393EBE4244
A0302EBA5D56EBA299FDC5B4E7BA9DD6AC84DDAE7AD3A25FB2842FF9CD6EDAAF499C7003
E8BB46E0B43BB58811CFA433F5CC62CDA742AE8728E9C56FC9A95ED7B87FFCDBBAE4B4A8
A35B5FA24A56B65661AD545A96504EAA7871B08E85AE968CBCABA1B4A79EA89B93A1948E
9D928C9C918D9A8F8B9B908C9A8F8B988D89998C869D8E89A59391B59B9AC29B9ECF989E
CB7F89BE616BB84D57BD4B53C05356B2504F9445419A5D589E756F977C75907F788C817B
877E79897F7D867C7B84787887777A8F767C987079A46F77B86F789F4E549C4A4C8A3E3E
9C5F5CAA7774A77777A37577A67477A16F709E6C6D855855714C46E7CABCFFE5CED6BE9A
BCA06ECCAE72B49253764E116B3A02672F006628016D2B097730107E33147C2F117D3212
7B360F76390D71421491713EB19D68B1A573695D374436196C5A46927668906C5E8C6053
8C5C4E774335764133824A3B8E564589503D8A533E925F44865834926A39A27F3F987B2D
967E24B7A448BFAF5A70631F281C00251B022E2311332A1B392F234B41374E443B443B34
3B322B2B221D2B211F291F1E2B232127221F2923232B2726251F1F221C1C241E1E2C2422
2C222032251F37261F6B594FB5A399DBCAC2F7EAE400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00F4E5E286605D7F3B3A9E3F43AE3B42B13239BF3940C13C3F
B83E3DA338328B372DB67768E9B9A3F5CCACCEA275E0AF75B4843ADBAD57FDD170D2A63D
EBBD4DCFA02CB68715E9BB4CF8CF65C69F3AB68F32EFC974ECCC83AE8F58C3A281FFDBCE
F7B9BCA65D68A5555E91494DA16C68BA958DA48980A08E84A89A8FBDB0A7CDC0B8BEB1A9
ABA09AA0958F9E938D9E938D9D928C9D928C9F928CA0938D9E8F8CA4908FAF9392C2999D
CB8F97CD818BBA5F68B64E57C4595FC35C5FA74D4C8D4340A16F68A07E75957E768E7F78
877C78897F7D877D7C877B7B8676798F747B986F77AE757EAC636A98494E954B4C854543
A3736F97747093757394787796787A9779799878799576747F6662B69F97ECD7C6EBD6BB
CDB78ECAB37FCAB276C5A96AB79558A67D459464347843176F3408702F05702C0776300C
77330C7A3C13602F06633D109A804DB6A672A89C6C5F562D3E33155141287158427B5C47
8B685498725D986D5A8D604D895A488B5A498956437F4F385E3112906A3DAB8949A08431
A68F29BAA636C6B446C4B6557A6D272F2300281E002E24092E26133B3223463C3252483F
564C434D443D3E332F342A282E26242A22202620202C2626281F202920212D2322352B29
3628252B1C1528160C5E483B8D76688972649A8479B5A29BDACBC4F1E6E000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E4CFCC764A478B3D3DA63F43AD353EB5323AC1383FC23A3E
C24040BC4642A8473E863C2F6B3825E0BBA0C9A27BDDB27FC59555B07F32F2C36BE6B856
D5A63CD4A637C39526E2B649F6CB62B18A25DAB356D2AF5DBE9F5CD5B584E1BCA2FFD2CA
FFCACFE29EA99552598D5254B58D8BA58A839C8A809E90879A8D84A39990BBAEA6CABDB5
CFC2BAC0B3ABAEA199A4978F9E948BA297919E918B9F918E9F918E9F908DA18D8CAF9294
B89194C38E94C47D85B35E65C05C64C15A5EB5555697444092534CA77B729C7E76948079
8C7F798B807E8A7E7E8A7C7C8C777C94757BA1727AB778819C51569B4C518741438B5352
A079748F736F8C77748B77768C7A7A8C7A788D79788E7A798876748876729D8C84A79587
A6947EB29F7FBFAC82CAB684CEB87FD3B97ED0B276C6A669BA9658A67E408F652B754811
6537035E32015E35074E2C005D43129F8E56B0A468877E435F5927514A1E60522B614F29
59431A745B337A5D3B8164448D6E4F96775A916F54936F558461419B7A4DAA8C4CA38932
A99123BBA72ACAB935D8C948D2C7539B91324B42002B2300302708322A15372B1B3A2E20
44382C4E443A54473F4E433D4136323F34303E3432403634372D2B332927332824352724
352822271910301E127B6859987E6F8C71608E71619474678E7065997D71AE938AD2BEB5
F2E0DCFFF6F200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00D7BBB774413E933F3FA83B40AC3038BB353EC53C43C4393E
C64041BC403EB64B45A04E43622D1FDEB8A3C09B7EE5BB93DFAF7FC08E51C39349DAAC56
E0B254F3C661F2C761E4B953C09634BB9437E4C06CD0AE66C4A56EFFE0BAEFC6B4B58480
B3767DA86972894E54AA797CAF908D9A87809B8D849B8E86998F869C9289A3968EAC9F97
BEB1A9D1C4BBD3C6BDBDB0A7ABA198A59B92A0938DA0928F9E938F9E938F9D8E8B9E8C8A
A58D8DAF8C90C59096C27C84B55E66B6565ABA5559B459589244409C6159A67B74A0837D
98857F90827F8D7F7E907D7F92797D99747BAB737CB06D76914549994F507E4041966664
9B79778C77728D7B798A7C7B857A78887D7B857A78847977867877817372887A77887974
8A7C718E7E6E9080679C8C6BAD9B73BCAA7AC7B380D1BC85D4BE84D1B97BCDB378C2A56B
B798619F804A8767346A4C18412B00665416ADA35BB5AE66A2A063706F396C663684794C
67562A6C572A70592F533C12644D236750266D542C7D643C8B6F48907442A58A45A38A2E
A9931CBEAA23D2C22FD7C934DBD13EDFD653C3BC546A6514322C00251E002C220031260A
352A143B301E3E32224234273F31263B2D243D30273A2D2435281F2E211833261D36281D
25180824140442311D7A68529F8974937865917260916D5D9974649B76668E6A5C866659
8E7368A18D84CDBCB4EDE3DAFFF7F200FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00C3A29D8045419D4142AD3C40AB2E36C03A43C23940C93E43
C43E3FBF4240BF4F4D903932834A41EEC6BAAA8372D9AF97D6A98CDEAE86D2A36FCC9C5C
C6964AB88B38C89F47B08831C09A47E8C277D8B573E6C38DA4845DDBB9A0F6CEC48D5B5C
8E5055A160689B646AAE8486A188849C8D869C8F87998E889A8F899B908A9B908A9F948E
A29791ACA299BCB2A9C8BEB5CCC2B9BDB3AAA99F969E938DA19690A196909B908C9F918E
9F8F8FA48E90B69296C28F94C37E83B25D64B45458B95659A94E4D984A46A16763AD847E
A387839A8783928080917B7E98777EA1747BB4757EA1585F9045498E4A4986504E9E7674
9379788977758A7C7B8A7E7E867A7A887C7C857979857B7A877B7B817575897E7C8B7D7C
8779768578728779708A7C6F8C7C6C8E7F6A93836A9F9073AD9D7BB9A77FC7B48ACEB98A
D6C08ED2BB85CDB77DC5B071A28F4A83752AA39B48BDBA69D2D38D8F93585E5C2C817952
80714A6D57307D62377C61327F6630776127614B116D591E69521C5941038E7525AB942E
AD981BB8A616D5C62BDAD030D4CC2BDBD63ADED949D3CF51A39F346E68123E37002B2100
231A00261D002F240835270D34251032231038271535241232231031220D30210C281A00
1F110037280770623F76674675654C8A756293796A9B7E6EA18071926E5E95705E96715F
94715E8766538367528B705DA08B7AC8B6A8ECDFD6FFF9F400FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF6F5AF89868645419F3F41AB363CB2333AC23C45C13840C94047
C33B3FC44244BC4445922C2AC67874FFCAC3F2B6AEF7BDB1F5BCABF7BFA8E0AE8BD3A478
E2B57EC99D60D9B26FDEB877E8C486B6915CCDA67BE7BE9ECA9D86D9A99DFFDFDBE8B1B4
9654588E5055B07D828B6767604B468B7E769E938D9B908A9A8F89988D87988D879B908A
9D928CA29992A2988FA99F96B5ABA2C5BBB2CEC4BBBAB0A7ADA29CA297919E95909E9590
9D9391A19191A58D8DB18D8FC99297BA7379BB616ABA575CB95659A34948974D4AAE7772
A7807BA48783977F7F997C7EA0777DAA757DB67078974A50984E4F7F3F3D9366619D7E7B
8E79768C7C7C8A7C7C897D7D857979867A7A857B7A877D7C887E7D837978857979867A7A
887C7C837777897B7B887A79867875887B7585787084766B897C6B8B7C679183699B8C6D
AE9E7AB7A67BC7B585D4C38BD4C486CCC078C5BC6DB9B667D1D58BC3C98B5E603158542E
918464B39F7E8A6E4984653792753B8B702B7D671C8673267D6A1E604B00897212AC9724
B09C15AF9E08C9BB1CDBD22BDFD82FD8D42ADFDC37DEDE42DEDD51D8D65BBCB75397913D
6C651D524D0D3B3200372C002F23002B1D002E20002D1F002D1F00322400382B004A3D06
6B5F239A8E527C6F3A75673A6C5B3D705E4A725B4B81675A886B5D9B7A6BA480709F7C69
9070598C6C538F70549D7F6390775976614672604C867667BCB2A8E9E2DAFDFAF500FF00
00FF0000FF00
00FF0000FF0000FF00FEEEEE9C706F853F3DA43F43AF383EAF3037C23C45C0373FCC434B
C63D44C53C43C74046B4363AC55255D56D6CD77371DA7D78D8847AD38B7DF4BDA9D4A88D
E4B999D2AA86B6936DCEAC87DBB898AC876DFCD1C1F5C0B8EFABA8F5AEACFCB8B9FFC6C7
BB797A884E4DB9908EA789876C5953554842716660968D869D938A998F869C8F879B908A
9C918B9C918B9E938D9F948EA49993ABA09AB9ACA4CEC4BBD2C8BFB7AEA5A9A099A19891
9D948F9E938FA2938EA8908EB79091C99297BD7078BB6069BC575DB654559B43419F5650
AE7770AB827CA17E7CA17A7BA9767BB97B80AB606796474C904849854A46A07773957975
8D7B77897B7A877B7B897D7D847A79857B7A897E7C877C7A867C7B857B7A857979857979
877B7D82767885797B857979867A7A857979857A78877976887B7582756D86797085776C
897C6C8C7C6C93846D9D8E71AD9E77C2B483C9BE80C5BE7AC6C781E6ECAC9CA37043451E
6D684BDBCBB2AA8C726E4A26B9945DBD9B51957A219D87248B7714705D00A28F19B5A21F
B6A414B1A106BDAF0ED0C51EDDD52CE0DC32E6E43AE4E541E3E546E4E44EE6E559E2E260
D9D95FCECD59B6B244A7A33897922C8B862289811F8B812090862499902BA89B35B5A840
BEB14BC4B759A494476C5C21624E2968523B816758866A5F7F635787695E7D6153987E6D
87715A8C785D8C7959937F5AA08D63A9936A9E88637C674858442B625340867C70C4C0B7
00FF0000FF00
00FF0000FF0000FF00F0DEDE906060883C3CA63F43AC353BB8363EC13B42C43E47C64049
C03A43C33B45CA3E47CC4049BA3339B02D32B23638AF3B3BA33A367D241EBC7E73EEBEB0
AB8070CBA191F2CDBBF3CEBEA27C71C19892FFD5D7BF7C839A4147A8484CAB5254C17371
A15D5A9B6662B5908AA68F899D8E897F746E584D47574E477D726C9C9289A1948E9E918B
9E938D9B908A9F948E9E938D9F948EA0958FA2958DA99F96C2B8AFCBC2B9BEB5AEB0A7A0
A59C95A09790A19690A69490A88E8DBC9397CE8F97BC6C75BE5F67BB565AB4545599413F
A66058B47971AF7C78AF7979B77778C27A7DA351579B4B4E853F3F915C58A4817D937B77
8B7C79887D7B897D7D897D7D867C7B857B7A887C7C877D7C867C7B867C7B877B7B877B7B
84787A85797B877B7D84787A867A7C867A7C85797B85797B867A7A867A7A837876857A78
877978897B7885766F8676678B7B6196875E9F9059A39A55BDBE72DCE29AE1EAB36C7148
3D3C1EB4A892EBD0BD65422498703CE3BD72CBAE4AC3AE3BB9A930AB9C1DB8A821C3B322
BFB019C1B314BBAE0ABFB40CD3CB20DDDA2DE6E439E7E63CE2E43BE2E53EE7E946EAEC4D
EAEB51F0F05AEEEE5CE9E85ADDDE54DADA54DAD756D6D151D6D151D6CD4CD7CD49D5C845
CEC043C4B745B09F47927D3C5E471D5A3E266E51417A5C518362598A6C6281675A836D5F
705F4B897D63978C6E9D906D9C8F6599885CA18F61AF9970A5916E7362443B301C746E60
FAF9F500FF00
00FF0000FF0000FF00E2CDCC8451508B3D3DA73E43AC333AB7393DBF3E43BC3D44BB3E46
B73D48B23641C53F4AC73E48C93D46C93E45CD4549C94749C54D4CAC4441843731EFB4AE
D8A9A3FDD2CBF5C6C0ECBDB7DBAFAEE9B8BBFFC7D0B4616BB84952C54E54B44848B05250
954E48B27D77AE8D869E8A839B8E889D928E988D89726763514642574C468274719D8F8C
A39894A0958F9F948E9F958C9F958C9D938A9E938D9E938DA49A91ACA299B7ACA6BEB3AD
C1B7AEB6ACA3A89B95A2938EA38F8EAB8F8EC3949ACD8E96BA6970B5595EB75457B65453
A04743A3534CBD6F6BC47674CA7978C77172A74E50A05051834240A1706CA0817C907D77
8C7E7B867C7A8A807F897F7E8C817F877B7B877D7C8B81808A807F867C7B887C7C8B7F7F
857B7A867C7B887C7C887C7C867A7A877B7B897D7D857979857979877B7B867A7A867A7A
8579798C7E7D8C7D788B7B6E907F659584588B7B3D94893AC4C369CDD27EEAF3B0B4BA8A
53523379715CF4E2CEB7997D744F1BD9B569E0C85ED4C244C9BD35C9C130C7BB27CABF25
CBC124C8BE1EC6BD18C6BE15C9C317D6D324E2E033E8E83AE0E236DDDF34E3E53CE2E43B
E2E33DE1E23CE5E640E5E843DBE03EDCE045DBDD4BE7E658DEDB4ED8D246D8CD40D3C73D
D0C340C1B23DAF9C4098813D71542860412584614E7A564A643E357A584E7E60567D6559
77675868604D736D57A09A80AEA888A59D769B9063998C5FA89B6FB9AD856760436E6C57
F9F8F300FF00
00FF0000FF0000FF00D0B8B87C4644903E40A93E44B0373EB93B3FBD3F43B63B40B13942
F68790E77481BB3D49C9414DC93D48CA3D45CB3E46C73F43C54345BE4A4B852624C77977
FFD1D1F9BCBBA66060874143E8ACAEFFCED4FAAAB5AD4955CB4F59CA494EC14B4BAE4C49
9A534DB98881A688809D8A849C8F89968D889A8F8B9C918D958A866A5F5B4E403D5A4F4B
8075719A8F8BA297919D938A9D938A9E948B9C918B9D928CA39990A39990A79C96A99E98
B8AEA5C7BDB4D1C4BEC1B4AEAE9F9CAD9897AF8B8DCD989EE39AA1B55E66BD5D61BE5A5A
C96A66C56863AD524FB25756CA6A6BC06061B557579D4746964F4DAD7673A37C77997D79
927D7A8F7D7B9384818E807F8F81808D7F7E8C80808D8382897F7E877D7C8A7E7E8C8080
8B7F7F897F7E867A7A897D7D877B7B8A7E7E8B7F7F877B7B8A7E7E887D7B8B7D7C8B7D7A
8C7F798E807790807190806796845C9281498D7D32ADA14BCDCA6DC3C571DCE19FE1E4B7
7473576F6856D6C6B7EED6BE7E5D32B79651F5DD7BE3D35ADDD14BDBD344DAD03DDBD13C
D3CC35D2CC30D1CB2DD2CC2CD2CD29CDCA23DAD730E2E139E3E43EE2E33DE0E239E1E338
E1E337DFE233DEE132DFE334DEE236DBE139DDE142E6E74DE3E24ADAD440D1C732D6CA3A
CEC137BEAE34B5A13E7E671B6B4D196D4C29947056754F3C7D564775514367473A5C4235
6150405F5241675F486A644A827D5DAFAA84B6AF83A59D6E9B9364ACA5799B997386866E
F9F9F100FF00
00FF0000FF0000FF00B89C9B814745903C3CAC3F44B0373EB73A3EBE4145B43B40AD3A41
F78D97EC828EB23A46C4414FC8414FC83F49C43B45CA4149C94248C7464AAB373AA73D3F
F79497BA575AB44A4E9D3438973B3EFFA6ABE9848CB9474FCD4F53C7494ABE4C4BA24742
9F5F56BA8F88A286829C8A869E908D9A8F8B9B908E9A8F8DA09591A196928D8280695E5C
4A3F3D59504B867D78978E87A0958F9D928C9D928C9E938D9B908A9D928C9F948E9F948E
A59A94ACA19BC5BAB6D9CBC8D4C5C2CEB9B8BD9B9CC69599E39EA3BF6D73D77B7EC56566
C76967D27772C96B69AF504EB85454B75051BF5859A64846AA5654BA736FB07571A97975
A47D789A7B769A7E7B99817F927F7B917F7D91827F9082818F81808C817F8F81808A7F7D
8E83818C817F877D7C897F7E897F7E897F7E8A7F7D8B807E8D7F7E8B7D7A8E7F7A8F8178
92817195846A97855F94834F948240928234AB9D44C3BA5DCCC86FC9C77CDBDBA7E0E0BE
918C798B8279B3A29AE8D1C1876A4AAA8A57FAE093F2DB7BEFDD6DEEDE65EBDE5EEAE05C
E4DC55E1DB51E0DA4ED6D443D8D645DAD943D7D63EDAD940DBDC42E6E74BE1E344DEE13C
E2E63ADFE334DCE031DFE334DEE235E1E539DCDF3AE3E441EBE748E0DA3CD7CE33D2C72F
CCC02EBDAF2ABAA83A78630A573E008163317C5C33603D1D8A664C6A473193725F7F634E
6047315540255D4A2A6F613E695D3770693D9E9769B7B384B2AE7F949367AAAA84A9AC91
F8F9F100FF00
00FF0000FF00FFF6F49C7E7C844744953F3EA93C41AD3439B83D40BB4045BB444AAF4248
D5717BDD7985A93B48B74252BB4251C04351BE404CC3444FC2404AC2434AC2474CAB3239
BC474DBC434ACC4D54CC4F559D282EC55259D45B62C94C52CF4E52C44A49BE524F99443D
AE736BB590889D8581998A879A8C89998E8A9A8F8D9A8F8D9A8F8B9D928E9F9492A19795
897F7D5E545248413B58514B847B769F948EA196909D928C9B908A9C918B9A8F899F948E
A39892A29791A89D99B1A3A0C3B1AFE3CBCBEBC4C7E3AFB3CD868CB25D62CE7275CF6F70
DB807DE58A87F09290DA7B79C86464C35C5DC0595AB85454A94B49A85350AA5C5AA96361
AF726FAF7875A97874A87C79A37D7A9E7C7AA18480997D7A99807C977F7B95807D927F7B
93817F9283808D7F7E9385858C817F8E83818E807D8F827A95847A90807197867494846A
98866294825490804492843DA59547B0A450C7BD68D2CB7BDDD894D7D49DC5C29FABA994
9C958DA29897A39594C3B0AA6D5342694F2EA58957BFA260DEC171F0D57AF4DA79F3DE75
F0DE70EFE36DEDE36AEBE366E9E162E7E05EE3DF59DFDB53D7D449EBEA5AE7E753E0E147
E1E340E2E53CE1E539DFE337DEE235DDE135DFE138E0DF39E6E33EDFDA36D5CD2CD3C92A
CCBF25C9BA2BBEAF30A99729806B107D6618836A27785E239F8353775A308266419A805D
745A37765F36816B3C6A562362521E6A5E2A766C3B847E4EABA778A6A579A8AA83B3B69B
F8F9F100FF00
00FF0000FF00F7ECEA8A6B688144419B4341A53B3DAA3337B63E40BA4347BA494FAA4249
9A3B43B0545FA44654A84758AF4A5CAD4657B04555B14554B2424EB7454FB94550B8434C
BE454EC4454ECD4750CA444DC9434CC23C45CF4751D04950CB484DC04A4AAE4A48974843
B9847EAC8B849E8984978A84978C889A8F8B988D899A8F8B9C8E8B9A8F8B9A8F8B99908B
9D948F9D96908C8481574F4C483E3C665B578C817DA39592A49791A396909E948B9D938A
9E938DA29791A49693A79895B09B9ABC9C9DDEADB1F4B3B9C17077B2555DAB4B4FB55255
DE8080FA9F9CF79C99F29794F69B9AE58787D17270D37170BF5B5BB35150AA4A4BA24746
9D45449F4B49A65554A95D5DB16B69B0706EB57B79AD7A77AD7C78A77B78A27C79A0817C
9D807C9B818097828199858693817F907E7A93827A9C8C7C9A896F9886629A875C94834D
8F7D3D94833BA09344B1A656C0B76AD5CC87E0D79CD8D0A1C1BB97AAA68D9F9B8F9D9A95
9F999BA09A9EA399A1B3A7AB8D7B795138316546346B462B875B34B18352DAAC71E8BB77
EFCA7AF4D57BF4DA79F9E37DF4E178F4E475F2E573F3E872EEE66AEDE868E8E65FE5E456
E0E34CDCE043E4E643E2E540DEE13AE2E53CDDDF36DCDE35DBDA32D6D32CD4CD27D5CC29
D0C325D3C62CCFC331CBBE34B9AC2CAA9B26A08F259C8C2D9C8A368E7C34715D1E7A672D
77642A766225B09E56B8A65A8B792F5E4D0866551D756736797142C3C095B0B28DADAF97
F8F9F100FF00
00FF0000FF00E5D7D47B5A55864742953D3BA53B3DAB3438B84042B84447B04348A03B41
AE535CB15B66B46471B66876A65969A254649342517F2D3B8F3B488B333F983B46A13D49
B3434FBB434FC64450CE4650CD414ACC3F48CD3D47CF434CC8454ABE4A4BA849479D5650
BD8E88A2857F9E8B859B8E889B908C9A8F8B978C88998E8A9E908D9B908C9A8F8B99908B
99908B9B948EA099939E9791897F7D5E55504A3F3B685A578B7D7AA2958FA398929E938D
9C918BA29791A49693AA9695AF9294B98F93D4959DD5858EC86770C75E65AE41479C3236
9B3435BD5B5AD47573D97B79E08282E48686E68785EA8684E7817FE47C7BD87071CA6364
B85152B65252A541439F3F40A14343A24848A85452AB5B5AB26867B26E6BB67976B27B78
AD7C78AB7D7DA88081A17D7D9E817D9980799A84769E8A719A886092814D917E439D8C46
A69649B6A95AC5BC6FD8D189DAD496D2CC9AB8B290A8A28CA19B8FA09B97A09C9DA09BA1
A19CA39F9AA1A199A4A89EA7B7AAB36F5C6046292B65423E71473B71422EA7785AB0835C
A37947BB975DC9A767DABC74E9CE81EED583F1D983EFDA7FF0DC7BF0DF77ECDF6FEFE56C
EAE160E4DE54E3DC4DE4E049E3E047E2DF42E1DE41DFDD3DDAD838D9D536D7D133D8CF34
D3CA31D5CA32D2C832D5CB35D0C633C7BF30C8BE38BAB034A99E2B9E932A8E832782771E
7A6B166E6008A49635E1D26DE8D974C0B1547B6B1E635516786F38BBB788B2B28CADB095
F8F9F100FF00
00FF0000FF00DBCDCA73524D844540973F3DA73A3DAE373BB94045B94248AD3E44A23D43
B35C64B66973AC6873965D66935F6BAF7D89B5838EB2808BCC9AA5AC7884B87E8ABD7986
903C4B9E3947BD4753C6444ECC454CCD4048CD3D46CE434AC7464ABE4C4C9E4443A96864
B38A849F867F9D8C85968B859B908A9A8F899B8E889A8D879B908C998E8A9A8F8B99908B
9B928B9B928B9E958E9D948DA198939F96918279745C514D4638356557549183809F9490
A0958FA0958FA3948FA8908EB58E91C38A90DD8D96C2616ACA565FDB5F67CD5056C74A50
B0393DA63336A03434A93F3FB95351D46E6CDD7775E07A78E47E7CE8827EE98381E27C7A
E47E7CE47C7BDF7778C55D5EBA4D50BF5154B24548B14749B24B4EA64445A74B4CAE5655
B26160B76B6DBA7677B67A79B2817CA781769C7D69977F5D927E4CA09052A99B54BBAF65
D1C57DDAD190DAD39DC6C197B2AD8DA09E899D998DA19E99A09C9DA09BA19F9CA39E9BA2
9C99A29A97A09F99A39F97A2B7ABB597879139262C402A2D4026253A1E1A957A6FEFD5C6
CBB09DBA9E88A98970A07F60AE8E68B6956AC7A373D4AF78E2BC7EEAC57FF2CE80F2D27B
F2D673F0D86CEDD863ECDA5EEADC59EADE58E4DB52E4DD51E3DD51DFD94FE0D851D8D049
DAD24BD4CC43D4CD3ED5CF3BD4CF37D5CE35D5CE37D2CC38CAC335C5BE39B6AE31A59C25
A097228B820D9E9419D3CA49EAE15EEAE065E3D86E8E842B605915BBB883B1B288ADB093
F8F9F100FF00
00FF0000FF00E9DBD87B5C577F444096403FA73D3FAC3539BA4146B63F45B5444AA13C42
AD565EB96E759A5D6498676DE3BBC4EDCAD1E0BFC8E6C5CEF1D2DACDADB8E6C2CEAF7F8D
7C3A48842D3DB24854C44A55CA444DCF434CCC3F47CB4249C6484BB7494A9E4A48B27570
AE8983A18A849D8E879A8F899A8F899C918B9E918B9D8F8C988D899B908C9E938F9A8F8B
988F889C938C9A918A9B928B9E958E9D948FA097929C938E857A765D524E4B403E645955
897E7AA0958FA99795AC908FB7898CD39097D57984B84854CA4D55D44E55D64D54D75056
D04D52C84A4DBC4144B13A3CA63233AB3B3AAB3B3ABE504FD06462D96D6BE07676DB7171
D96F6FE47A7AE87E7EEB7D7EE37073E16A6ED2595EC75054C75457BF4E50B34649B04849
A94547A54748A04847A3555394554EB08072D3B09ABDA583B39E6FBDAE75CEC385DDD396
D6CC97C0B78CAAA4849F9A86A19D929D9A959D999A9D9BA09C99A09F9CA5A09AA4A09AA4
A09BA29D989F9F9AA19F98A0AAA0A9B3A8B04B3E472E1F262A1B1E2F21214B3D3CF1E3E0
F8E9E4FAE7E1F7DFDBEDD4CDDFC3B7C8AB99B79780AF8C70A67F5EA88359BB9566C3A068
D5B272DBBB70E3C471E9CC70ECD06FEED56EF2DA70F0DA6DEFDB6BEFDB6BEFDD6FF2E072
F4E473E5D65FDBD054DCD24ED9D043D8D03DDDD640D8D13BD6D03CD5D040C5BF33BFB931
C8C13CBBB52DBCB529B6AF20CCC634E5DE52EFE76BE2DB73726B1DABA96EB1B384A9AC8F
F8F9F100FF00
00FF0000FF00EEE3E17E625E79423D934440A03C3EA73439B63D42BA4148B7444BA83F44
A1464DB96C729D5F6488575BF3CBD3F0D0D58F6E758A6B71C3A5ADBFA4ADCAAAB7A27987
A76D7C984B5BA34150BC4855C74853C8404AC94048CA444BC2474AB34B4A964844B78079
AA87819C88819D8E899E938F9A8F8B9A8F8B9C8E8B9B8D8A988D899A918C9A8F8BA09591
958C879B928D9A8F8B9B908C9C918D9C918D9B928D9E9590A39A959B928D857C775E534F
4C413D685A57917B7DB08E8FC18A90DC8F97C5616BC14C55CD4B53D44B52D5484EDA4E51
D74C51D54D51D44B52CE494ED14E53CB4A4EBC3E41B5393BAE3637AE3838B33F40C15150
CF6361D86C6AD66A68DA6C6BD76766DA6868D56164CD5A5DCF5F5ED66867D86E6ED36B6A
C96162C0595AC35F5FB25955934A41A97464FDDAC6F2DAC0D6C6A4D1C3A0CCBF9DBAAF93
A89D879F9685A49B92A29A97A19B9BA49EA0A09A9EA29DA3A09BA2A39EA59E979FA29BA3
A29BA29E979EA19AA1A099A09E979EB8AFB45C5358291E222D23242E24232B2622D8D3CF
F1ECE6ECE4E1EEE4E2F0E6E4F1E8E3F2E7E1F3E4DDEDDCD2E3CFC4D6C0B2C3AD98B29A82
AD9072A48360A38056AC8453B48952C99D60CEA15EE4B56FEEBF77F1C57AFBD283FFDA89
FFE089FFE286F9E17FF3DE75EBDA68E4D45AE1D452DBD14BD8D047D3CD43D8D049CEC63F
D0C83FC7C032CEC836C4BE2ACBC330E5DE50E2DB59F4EE808C8534A09E61B2B483A5A889
F9FBF000FF00
00FF0000FF0000FF00B8A39E73484281403A933A3CA0373BB34045B74046BA454BB4474C
A14145B16164A66569804E51E1B8BCF9D9DCA38386371A1E80656AD7BCC59F818DBC96A3
E1ACBC924E5D953D4DAD4453BF4753C44550C7434EC3444BBF4B4CAC4846944B45B7857E
A688809D8A849A8B869A8F8B9B928D9A908E9B908E998E8C9A8F8B99908B9B908C9B908C
99908B9C938E9C918D9A8F8B9C918D9C918D9A918A9990899F98929C958F9E95909D948F
8E83816F5F5F684E51795054B1727AD57F88B84E58C95057CA4C4FCE4A48D24C49D34E49
D34C49D54B49D44A4AD74D4DD4494CD64E50D54D51D14C4FCC4A4CBF4142BD3F42B3383A
AF3939AC3839B03C3DC24E4FD56162D15F5FD25E61D05E5ED06261D06462DC7370E8807F
EC8483DF7774CC6461B85953B2645A995E50EFCAB8ECD6C1C5B4A0AA9D8CA09486A59B92
A69D98A19997A79EA1A2999EA29CA0A39DA1A19B9FA49EA2A19CA2A19AA19F98A0A1979F
9E989C9D979B9E989C9C969A999397AFA9AD736D712C2628362D2E2A2522201D18C5C4BF
F2F1ECE6E5E1EAE6E5EAE6E5EAE6E5ECE7E4EDE5E3EEE4E2F1E6E4F2E7E3F5E6E1F7E6DE
F1DDD2EAD3C5E1C4B4D0AD99BD987EB48B6BA0745195653FA7764DA6754AB18352C79C67
D5AB71E4BC7EEDC786F6D18AF8D584F4D57BF6D876EFD76BE8D360E9D65EEBDB61E1D452
DBD249CCC336DDD546D0C839D2C63CE1D754DAD057F2EB819992418D8C4BB3B583A4A887
F8FAEF00FF00
00FF0000FF0000FF00E7DCD879625A7E534A904C4B913739B04349BD4850BC454BBC494E
A84144A85253B26E6F8D5757A17778F6D4D3E7C9C9674D4EA68D91F9DEE5A88792B68C98
A773807A3A4ABA6C7CA84C5BAC4351BB4754C44853C1484FBE4D4FA8494598534CBA8B85
A586819D8A869A8B88998E8C9A908E9B918F9C918F9A8F8B9B908C9B908C9C918F9B908E
9A8F8B9A8F8B9E938F988D899D928C9F948E9B928B9C938C9E95909B928D9D95929E9693
A59B99A49494A285878C5D63B16A70C1666DB84950C85153C04B42B94536B2412FBF4C39
CC5342D05243D25043D14B42D44A47D64A49D5494AD74D4DD44C4CD64E4ED64E50CE4849
C84648BF3E42BF3E43AE3034B73C3FB33B3DB84143C14F4FCB5E5BCE6561D46C69D6706C
D56F6BDC7672D06A66BA5B55CA7A71AE6E64C59B8FBA9E93A6938CA598929E9492A2999A
A09A9A9F999BA59FA39F999D9F999DA09A9E9D989C9F9A9EA09A9E9D979B9C959C9C969A
9B95999C969A9E999F9C979D99949AABA6AA847F833531322E2828282421161510B3B2AD
F5F1EEE8E4E1EAE5E2ECE4E2EEE3E1F0E2DFF2E3E0F3E4DFF2E5DFF0E5DFF1E6E0F1E6E0
F1E8E1F1E6E0F3E8E2F5E8E0F6E5DDF0DED2EAD7C9DDC6B8D0B3A3BE9D8CA4816E8E6853
8B5F469061459E694AAB7350C48B60CE9462DBA368E5B06CE8B768ECC369EBCB64E3CC58
E3D453CBBD38DACC45E0CE4EDDC7579A87209D902AFAF194AAA353848340B7BA85A2A685
F9FBF000FF00
00FF0000FF0000FF0000FF009C928963483F9A6964A258599E3E42B8464EC0494FBA454B
B24A4BA34748AD6364A26666835150C89E9FD2AFADC6A6A7BEA0A2E1C1C6A07B83C398A2
A7737F894C5B8C4555DD8A9A9A3A48AA3E4BB33D49BC454BBE5051A04540A15E56AE817B
9477739B8884988A87988D8B988E8D988E8C9B908C988D899B908C9D928E9C918F9B908C
998E8A9A8F8B9C918D978C889F948E9C918B9B928B9D948D9C938E9C938E9E94929C9290
9E9391A59192B08D91C28B91D88891B7535BC14E53C7514FB7493CAC4830B55B39984018
9A3D14B04D26B94E2CC65439CB523FCF5142CF4D40D24D44D55047D34C46D54C46D84D4A
D34949D34B4DD44C50D24B51CB484DC24146BF4145B4393BB23C3CAB3938C75756CF6160
CF6160D86C6AD56966C3605BB560599C584F906159AD8E89A59190A39797A09599A0979C
A09A9E9B969A9993979E989C9C96989B95979B969A9E999D9E989C9C969A9F989F9F999D
9E979E9B969C9A959B9D989F98969BA5A3A89893993C373B2A262726222114100DA4A09D
F6F1EEEDE3E2EFE3E3F1E1E1F4E1DDF8E0DCEBD2CDECD3CEF6E2DBF6E3DCF7E6DEF4E7DF
EEE7E1EBE8E3ECE8E7EBE9EAEEEAE9F0EBE8F2EAE8F5EAE6F6E7E4FAE7E3F9E1DDF2D5D1
EBC8C2D7AFA7BF9088B07F71A16C5A89513A84482C763C168149168B5A17BD9840DEC358
E3CF56CFBD3DDAC64BE6D060AE9435594100948327FBF096B7B05F7E7E38B3B67FA2A683
F8FAED00FF00
00FF0000FF0000FF0000FF00D3CEC8594B4274534CD39C999C474AB0484FBB484FB9464B
B54B4DA9494BA35155AF696B7E40415820218C5958EDBFBFEBC1C2D7AFB07A4D52B28389
D7A5AE9C6771874853E69AA7AF5360B94F5BA02B34B33C40BB4F4DA54B43A15E56B98D84
6E514B705F58948582998E8C9A8F8D988D8B9B908C9B8E889C8F899E918B9D8F8CA19390
988D899B908A9D928C9B908A9B928B9990899D928E9E938F9D928E9C918D9F94929D9290
9D8F8EAA9194B1868DCD8E97D57B87BC4E59C84F54C9524EAF48399F4A2BF8B682E7B270
C59044A1651C8D490893460EA0491CB1512BBB5232C65439CB533ACC4F39D34F40D24A3E
D44942D64B48D5494AD5494CD84B51D54A51D3484FCF464DD14A50C74247C23F45BD3C41
B93D3FAA2F31AC3636AF43419B403B89403A8D5A56B2908EA28E8FA19597A0959BA0969E
9C969AA09A9E9A94969D97999C979B9893979B969C9D989E9691979B969C9B969D9B969C
9E99A09B969D9D97A19E9BA49A979EABA9AE9792982E282C2C26282A2426161010A19899
FCF0F0F1E1E2F4DEE0F9DFE0FFDDDCC8A29F744B47B8918AFFDBD3E9C8BFB7998FBCA39C
F2E3DCEEE6E3EDE9E8ECEAEBE7E6E4E8E4E1EAE5E2EFE8E2F4EBE6F4E9E3F1E6E0F2E5DF
F2E5DFF4E5E0F9E6E2F8E3DEF2D9D4EDCEC9E0BAB1C89D8CCDA1847C5423B8944AEDD16E
E5CE5AD5C148E2CB5BA48B277C620E5B4200AC9C3DF8EE8DBEB95E7C7D31B0B57B9EA480
F9FBEE00FF00
00FF0000FF0000FF0000FF00F5F6F17F787055423BD1AAA39753529D4448B34A4FB8494F
B3494BB34F51A1484C9342489145496D25298D494AC88888E5A9A9C08587692B2E8D5055
E7ACB2E8ABB2D6959DA85B658F333EA13741A22A33B53E42BE514EA34941A36058BE9289
A0837D725F595A4B487769689486859C918F9B8D8A9C8F899C8F89A0938D9F918E9F918E
9D928C9E938D9E938D9F948E9A918A9D948D9D928E9C918D9D928E9C918D9E93919F9190
A59393A98B8DB9888ED78F9AC86371BF4955CE4D52CA4D4BC3574A7C2708CE955EFBD185
F0CD71F1CF6DE3BA5ECB9B47B1792E93520E954B0C9B4911AA4E1BB55024C35731C55233
CC523BD14F3FCF4B3FD34A44D74948DC4B50D9484FD7464DDA4A53D6464FD94952D2454D
D1484FCC474AC24447BA4646AE4C49924440915A57B69391A59192A095999E959A9E979E
9A94989C969A9B95999A95999E999D9B969C9C979D9893999C979E9E99A09C979E9D989F
9F9AA19F99A399969F9C99A2A09DA4B6B1B7918A912923272C26282E2528180F129F9395
FCECEDF3DADDFBDDDDFDD7D6B98D8C7B4B47B2817CEDBEB8BD908A704840542F26856860
F6E5DEF3EAE5F0EAEAD3CFCE8F8B8A716D6A625D5A76716D9B948ED3CCC6EFEAE6ECE7E3
EAE5E2ECE8E5ECE7E4ECE7E4F0E8E6F4E4E5F8DEDFFFDED9FFE2D286623EBD9C59F3D678
E6CF5BE5D059BDA83F715A00796109846F14E1D36AEBE378CBC766797B28ABB1759CA27C
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF00BEBDB84D453A9E887D895A54843E3E9C4244AC4548
AC4445B14A4DA44448983B43963C459C424B8B32387B22267C26297A2427852A2F792326
A15154DA8B90B8696E8732398E2A34BA4B54C1484FC3484DBE4C4CA849459E5751BE8D86
A68782A48F8C8775736052515143427668679687849F908D9D8F8C9C8E8B9E908D9F918E
A398949E938F9C918D9A8F8B9B928D9A918C9C918D9A8F8B9D928E9C918D9E908FA19191
A5908FAD898DC1888FDA8A95BE525FC84A56D14A51CD4849CE574F94341CA15D2EFFCF8C
EFCC70EACF64EFD868F3DC6AF1D769DDBE54D8B551BE9335A2701B925709924C0799490E
AB4F20B34B24C55233D0523CD54D41DA4C48D74649DB484ED9464ED94650DA444FDA474F
DA474FD6474BD44C50C84E4DBF5754A4534F97605DB59191A69294A095999B95999F989F
9C959C9C959C9C979D9C979D9F9AA09B989F99969D99969D9F99A39D97A19A979E9B989F
9D9AA3A09DA69C99A29C99A0A7A2A9B5AEB5857F81292023342B2E32272B1C1012A19194
FAE6E8F8DBDDF8CFCDA97874905D59F3BEB8E1AEAAA3746E784D46A17A73CFB1A7F2DBD3
FBECE7E5DBD97A72706F676598938F9A959189848177726F46413E56514EA8A09EEBE6E3
E8E3E0CDC8C4D8D5D0E5E2DDE8E3E0EDE3E2F5E1E2FADEDBFFE1D6795837B99A59EDD374
E5D059EDDD63A0912A625400938518D3C751E6DE61E4DF67D7D26A7F7F29AAAF6F969A75
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF00F0F1EC89867D655B516A4F467A4B45914D4C974645
9B403F9838399F3C3F98353A98333BBE565FA83F46A4393F972A3094272DA6373EA83B41
9D363AA0404286272DD26E76A33840B13C44C64951C6474EBD494CAC48489F5451BD8884
A5827E9F8A85A3918F9A8C8B7668674F41405446457F716E998B88A19390A193909F918E
9F9490A196929E938F9B928D9B928D988F8A9E938F9B908C9D928E9C918D9E908FA89696
AB9192B38A8EC88992D57F8AB54551CC4A56D2474ED3484BCF504AB34433923718E29A68
F5BD73F6CA71F3D06AF5D769EED465ECD563F3DC6CF3D96AEFD368E5C45DD4A94AC49138
B172259F510FAA4C18C0522DD1533CD54B40D54544D84649DC464FD9434ED63F48DE4750
DD464DD8454BD24649CA4C4DBB524FA4534F955E5BB39190A69294A2979B9D979BA39EA4
A099A0A19AA19F9AA19E99A09D9AA19C99A09D9AA199969DA09AA49C96A09C99A29F9CA3
A19EA79F9CA39D9AA1A6A1A7A59EA5B5AFB3746B6E261D1E342A2B332729231314B7A4A6
FFEAECE3C5C58357545D2A26AA756FD09B95C28D89DBA8A4F2C3BDF5CCC6F7D9D1FBE4DC
FEF1EBB6ACAA1B110F887E7CF7F0EAF3ECE6F4ECE9EFEAE7DFDAD7938A8B3F3637B0A8A6
C1B9B78A858187827E8E8B8686827FB8B0AEFAE7E9F6DEDEFEE2D77C5D40B7975AF1D67B
E4D15BEBE062877B0B887E0BDBD251DCD64CDCD94EE7E463DAD86B81812BA6AB6B91966E
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF00EEEDE9C6C3BC958B8277635A744F497E4943
914E489E4D4A9D42419C35389D3035AE3B42B13A40BC434ABD4149BD4048C2434EC2444F
C0474EC24D53B13D46C14D569C242DB2353DC94550CA4852C1484FB34A4E9D4C4BC08483
A9817F9E86829E8F8A9B908C9E938F9388866C615F4B3D3C594B4A857776988D899F9490
9E938D9F948E9D948D9B928B9D948D99928A9D948F9B928D9C938E9E938F9E908FA59393
AF9294B18489D28F98C86E78BA4852D04D55D1464DD6474BD44A48D04C47B3392EA33420
AC4A27C87241E89E61FABC73FDC975FCD173F7D46EF2D466EDD460EBD55DEED85EF0D65D
F0CF5EF3C361E19F53A04611CA5836D44F3ED54642DC474BDA474FD9464ED64049DA444D
DA454BD54449D4494EC94D4DBD55529F504B96635FB29391A59393A4999DA09A9EA29BA2
9E979E9F989F9E999F9D9BA09D9AA19C99A09D9AA39A97A09F9CA79E9BA4A09AA4A39DA7
A49FA6A49FA6A39EA5A19CA2A59EA5B1ABAF645B5E2B21203125252C1E1D301E1EDCC8C7
FFEDEAC5A9A6AD8784DAAEABE9BCB9C99894AE7473B478778E57547948438B6960AF968F
FAEBE4E6DDD8BAAFABDFD4D0D4C9C3BFB6AFC8BFB8E0D9D3FFF7F4D0C8C62016158F8584
A39998CCC2C1877F7DA49F9CCAC4C4CDC3C4F7E4E8F5DDDDFFE3DB917357AD8E57F2D883
E1CF5FDFD552A69E19CEC73BD6D03AD8D53CDCDA47E2E25CDEDE707D7F2B9FA5678A906A
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F8F3E3DCD4B6A59E8D706A
815650905652944A47A14B4AAD4B4CAB4145AB383DB43B40BD4046BF3D45C8444FC9434E
CA4651CD4B55C4454EBE3F48B6343EC33F4ACB434FCB4752C64951B94B4E9F4545B67271
B285829E827EA08F88978C869A8F8B9C918DA095938D81816759584C413F5F5450847975
9D928E9F948EA196909D948D9C938C9A938B9D948F9B928D9C938EA196929D8F8E978281
AF8F92B6858BD68E99BE616BC04C55CF4C52D4474DD44348D44547D04443D54B49C94540
B73F2FA63A209A39169D491AB46D2FD2944BE7B35FF4C96BF3D36CEAD35FE3D550E4D74B
EBD953F1D45CFFD175AC6621B94F27D1533DD84B42D94748DA474DD7444CD7414AD7414A
D9444AD7464BCF4449CA4E50BD5755984A469C6B67B39593A39394A39A9DA19AA1A49DA4
A099A0A19AA1A09BA1A09EA39E9BA29D9AA39C99A29C99A49D9AA59A97A29B95A198929C
948E988D888F8681887873796D676B7C767A4C43462D21213626262C1817503836F2D8D7
FBE2DEFADDD9EECCCABA9795A27A7AE5B7B7E2AAABCB8F8FCD9391C49490C1A0997B6760
F0E5DFD6CFC9968B87887D796C635C685F585049434E4741857D7AA59D9A857B7AC7BDBC
948A89A89E9DA9A19FD3CDCDE8E2E4F0E5E9F0DFE5F2DCDEFFE5DEB3947F937344F4D88E
E0CD66DCD153C0B92DE1DB45D0CC2DD5D333DEDD45E0E05AE2E1776D711D8E94568C926C
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6EBE7
D2C0BCA88C8887605B834E4A96524FA45551AC5150AE4647B24143B83F44BB3C43C03C47
C6404BC9434EC8404CCF4753CF4753CD454FD04751CD4750CA4850C24E51A54143AC5E5C
BC8783A07F7A98847D9A8D87998E8A9B908C9A8F8D9D9290A196948D82805F545249403B
665B578B807C9E938DA0958F9C938C9E958E9E958E9D948D9D948DA0958FA3918FA3898A
B28B90BF868DD88B95B7565FC34E56CD4A50D3484DD44549D64548D64749CF4543D04C47
C94F44C45542B74F36A14321983F138C3A0892470EA06324B08139E2C164EBD75CE3D649
E8D94CE9D250FFDF74C98E40A54714D25A3FD34E3FD44642D54344D9464CD8424BD9434C
DA474FD8474ED1464BCA4E50BD5755994B499D6C68B294929F8F909F9699989198958E96
928B928C858C878289817C837C768077717B6E6B766864725F5B6A5D59685A54624F4955
47444D423F464B464D4A454B4F4A4E5C565A382D313626293B2225321414826361E8C6C4
C2A09E916F6D694A488A6A6BEBC7C7F1C7C8EBB9B8D9A3A1AD7C78C29B96FFE8E4F1E4DE
E8E0DD44413C3E36339D9592B0ABA5BCB7B1AFAAA68D8884615C5967625FBCB4B1F6EEEB
A199967F7A77847F7C6B6766747071F3EAEDF0E1E6F2DEE0FDE5E1D9BCAC795531E8C689
EED47DDECE5DC2B834DFD947C6C326D5D235DCDB43E0E05AE4E57F5C61117D85498E966F
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF5F3E7D5D1BDA19D966F6A824F4B8E4F4A954A45A44E4DA94B4BAB4447992C31
A53039B93D48BD3946CB434FCB434DCB434DD04751CC444ECC464DC74C51B94C4F9F4746
BD7D7BAB807A957A7397867F978A849B908C9A8F8D988D8B9C918FA398969F9492857A78
594E4A473C38655754897E789F9490A39A93A198919D948D9C938C9F928CA69291A98B8D
B5888DC5868ED7818CB74F5AC54C55CF4950D3484FD3444AD5464AD14747C94843C85248
C05744A5472B8C37108939088E41098841037F3B00753C005327009E7F25F1DF63E3D747
E6DA46E7D54BF3DA64ECBD619A480EC35733D2513CD2483ED64645D64447D84349DA444D
D6434BD6474DCF474BC84D4FB85454974C49A27270947877685A5A5953575750574E474E
474047443D4446414746414848434A4A444E4D475354505E595563635F6D66606E6A6470
74717A7C7980837E858B868CA29DA1928C8E352A2E3C2C2F41282C3214167858597F605D
5D3B397F5D5BCCAEACFFE2E0D2AFAD956C6AEEBCBBBF8E8A8B5F5C805F5AFBE8E4F9F0EB
E3DEDA34312C615C58D9D4D0EDE8E4F0EDE8F0EBE8EFEAE7EBE6E3807B787E7975F6F1ED
F8F3EFF1ECE8FAF6F38A8685878384F4EEF0ECE1E5EFDFE2F6E2E1F8DDD489654DB28D63
F7D895E3CB71C0B03FDCD350CFCA3BD6D441DFDD4CDFDF5BE5E8815F66187880448D956E
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F0E5E1CDBCB599807B75544D7E534C895851834945C58180
AB565B99353DAF3945B93A45BF3B46C43E47CA424CCC444ECE474ECC4B50C24E51AB4747
AC5E5CBF85819C7771937C7693817D958784968B87988D89998E8A998E8A9D928EA09591
9D928E847975564B47423733685D5B918682A196929F94909D928EA39592A4908FAD8D90
B6838ACE8691D47684B84856CA4C57D34B55D4474FD4454BD14649CD4D4AC35348B65741
7B360F7B470EAB8032C29D42CBA844C7A43CBD9D36AF922C88700E7B6900DDD14BE8DE4B
E4DA44E2D646ECD958FDD66DAB6621AE4D22D0573CD64E40D54743D84647D84349D9444A
D7444AD34448D1494DC1494AB95A5889443F9F73709A82807C7070756F737C757C7D787E
827B828781858B868A8D888E918A919792989A959C9F99A39C96A09C96A09D97A19E99A0
A29DA49C979D9D969D979195ABA5A9837D7F31282B362A2C36272A322020CFBBBAD7C2BF
DEC5C0FCE0DCFFE6E2FFE3DFE3B7B4C49490EBB8B5E6B6B2A47F79C8ACA8F9E7E3F0E5E1
FEF7EFC3BFB65750483F383257504A97928CD8D0CDCCC7C39B96933A35326A6762E9E6E1
E1DCD6E1DCD6D7D2CEB0ADA8D6D5D1EDECEAE9E3E5EBE0E4EFDFE2FCE4E4CBA8A26A4431
D2AC85EDCD90CAB15DE6D770DCD35ED3CE4EDAD650DEDF5FE6E982666E1B777F43848C65
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9F4F0DBD2CBB1A29B8E7A71644942C7A29C
FCC6C6B06569B15057BE4F56BB434CB93C44BE3C44C13B44C63F46C9464CC74A4EBE4D4F
A14343BA706DB47F7B997672937A76907E7A938582928783988D89998E8A9C8E8B9C8E8B
9C918DA59A969F94927F7472584D4B473C3A6C615D908581A09591A49693A28D8CB08D91
BA828BD98B98D26C7ABD4755CA4653D24651D6464FD2454BCE4849C64F49C25E4F7D3213
8F6028E3C676F0DD74E9DE62E9DC59EBDF59EEE15EEEE161EADB64D7C94FE2D552E7DA4E
E4D74AE6D94FE9D656FFDE73D99F55984211CC593CD34E3FD84A46D34343D84347DA454B
D8454BD7484CCF484CC34D4DB055528B4A44A57E79AB9894A298979D979999949A9E999F
9E989CA29CA09D979B9C969AA09A9E9C959CA19CA29E999F9C979D9B969C9C979D9B969C
989399959094979195979193AFA9AB635D5F292021362C2D271D1E4E4242F4E4E4FEE9E6
FFE6E2FADBD6E0BDB7D8AFA9EAB9B4D29F9BC08D89996C678E6D66FBE4DEF4E5E0F1E8E3
C7C0B8C9C2BACFC8C298918B5E5751615A5499908B81787349413E817976E1DCD677726C
3D393089857C4A453F9A9792EBEAE5E8E9E4E5E3E4E8E2E4EBE0E4F2DFE3FDE0E4A68580
67422FBA9873D0B27CD8C47D998A35979028D9D55AE1E167E4E7806C741F7A8445838B64
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDE8E4BBB2AD93827B
B396908E5E5A8A4645A65051B75054C25157C44B52BF4047BA373FC44149C34247C84D50
B44647A94B4BC17774B47F7B9A77738F777392807C8E817B8E837D938882988D89998E8A
998E8A9B908CA196949F94929E94927E74725D52504D42406D6260908080A38A8DB28B90
BD7F8ADE8A99CA5E6EC54858D24C57D2464FD4444DD3484DCC4A4AC5524BB45849672502
D4B066F0DD76E6DB5BE2DC4AE1DB45E5E048E4DD47E8DD4FE8DA55ECDA5CE9D55AE9D55C
EAD65DE7D25BECD261F7D571FCCB7F9E5522BA4E31D25043D54A47D64548D84349DC474D
D74548D34748D04B4CC14F4EA8514A884C44AB8884A3918F9E95969F9B9C95909699949A
9994989D979B97919598929699929999949A9D989E96919799949A989397999498999498
948F93969195958F939B9597ACA6A84842422C2324352B2C211515827272FBE7E6F8DCD9
D2AAA8AF827DCB9C96E2B1AAE9B4AE996662B4857F956C66694C44F5E1DAF4E9E5E8E0DD
494440423D3956514D51494659524C5F56516D625C968983C4B7B1DDD2CCF9F0E7C1B9AE
8A81788780763A352FC1BEB9F1F0ECE6E6E4E4E4E4E5E3E4E8E4E5E6DDDEEEDEE1F9E0E3
A487837E615394765C6149233625006E6218E2DB71E0DD6ADEE37C6B731E7682427A855B
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F0EC
DACDC7B097928A615F894F4E8D4344A1484AAF4D4EBB4E51C24D53C1464BC2434ABE4044
BD4547B14545AE5352BF7876AE7B779976709279748E7B758C7D788D827C928783958A86
978C889A8F8B9C918D9A908E9F9593A29896A095938479775F5452554545775D60A1767D
BE7C88E28A98C55565C64655D04854D2454ED3434CCF4449CF4D4DC3524AAD544475350F
ECC978EBDB6AE4DD51E2DF44E3E13FE3DF3EE5DC41E3D445EFD658F6D466F3C965F3C669
F7C971F7C971F8CA74FAC778FFD394CB7E52A2351ECE4E45D54B49D34247DB484EDB484E
D34245D34949CB4B4CC45655A4514B8A514AB0918EA191919F96979C979B97929699949A
9B969A9994989892969892969691979893999A959B9792989792969A9599979296969195
969195969195958F91A7A1A3A09A9A3930312E2425362A2A221414B4A2A2FFEDEDBB9998
5A2A26BB847FEAB1AAD09790CE9490E6B1ADFCCBC788615CAB9089FAE9E2FCF3EECCC7C3
2C2825B5B1AED1CCC9BEB6B3524A47261D186356505E514B56494170635BD7CDC3BBB3A8
C8BFB6C9C2BA827D799D9C98F1F0EEE6E6E4E4E4E4E4E4E4E4E4E2E4E0E1E4D9DDF6E3E9
FFE7EBA98D8A5C4034381E07352300776C2EE3DB78DEDC6DDEE37D717B2471803F758257
F7FBED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5EBDBDBC9AFAEA07A77885552834240924241A54748B54B4FC0494DC6494F
C74A50C0474CAE4144A94D4EBC7573B8837D99746C90756E8C79738C7F798D827E8E8580
918883958C87988F8A988F8A9D948F99918E9E9492A096959C92918A7A7B785B606F414B
995260E38796C55062CB4858D24855D44750D1414AD0454ACF494AC8514BB75749742F08
E4BD70EBD969E0D74CE3DE44E3DF40E4DB3EE6D843EFD655F2C663CA8F43B36729B55F2C
BE6638C86F43D98354E18F60FCAD86FDA486AD392ACB4743D54A4DD7484ED5424AD9464E
D54449CE464ACA4C4FBD53539F4F4E945C5BB09091A191929D92969A94989A94989A9498
9B969A9A95999C979B9893979893999A959B979298989399959094948F93959094999498
969293959192979394AAA4A687818333282C36272A382829342123E3CECDFFE9E8E5C2BE
C08F8BD19692BD7E79CC8C8AD19191C58B8A9A64628B625EF6DDD8F4E7DFF6EFE9E7E4DF
6A65615D5854978F8C9B9390322A27251B19A09593DBD0CCD2C7C1D2C9C2E4DBD4736C64
221B155D5854807C79BBBAB8EDECEAE5E5E3E5E5E5E4E4E4E3E3E3E9E5E6ECE1E5EFDFE2
FEE8EB9C837F543A2D442C123A2800837838DED876E1E171DDE47D6F7C2469793874835A
F7FBEC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBECE9E1C8C4B6938F8E5D5981403E91403F9D3A3DAC3F44
C14952C74F58C35057B64F52A65252B4736FA7787295726C9175718C77728B7C778E817B
8C817B8D827C8E857E938A8398918B9A938D9B918F988E8D9E9493A59596A78A8EA6777F
AA626ED87A8ABE495BD14C5DD24857D34551D64650D0434BD1494BC64B46C55B4E792908
BD8A48F6DA77E3D453E7DF4CE6DF46E5DC43E8DA46FCE365BB8C32833F00AA4F22AA4121
A6361EA6331EA0301A9E311AA03A24BA4F3FA52921C74140D64B4ED5464CD6454CD8474E
D4454BD0494FC24A4CBA5356964A4C9C686AAF91939F8F929D92969B95999D979BA09A9E
999498948F939C979B9893979A959B9B969C969197999498989397938E92969195989397
959192979394979394ADA9AA6A64662A20213D2D302B181A624E50F6DEDEF6D6D7DBB3B1
CD9D99D19A97E4A8A7DFA2A1844647AC7271B37D7D633A38E4CCC8F6E9E3EDE5E2EFEAE6
DFDAD688807D5C534E4C433E7C736E7B726D453A384A403E978E89E4DBD4958E88716A64
514C49696461D3CFCEE7E6E4E5E5E3E5E5E3E4E4E4E4E4E4E4E4E4E8E4E5EBE1E2EFDFE0
FCE8E98F7773503627472F13382700887D3BDFD977DBDD6FDEE4806D79255261267D8B67
F8FCEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEDBD7C4A5A29A6D6AA665639F4D4F
96353C9A303AB0424BB44C53B3595B9C5251975F5EA579789B75749778758D74708F7A75
8D7C75897C768B807A8C837E8E8781968F8998908D9A908E9A908EA09090A98C8EB5868C
C8808BDC7C8AC0495CCE495AD14756D24450D4444ED3464ECF4449CA4848CA534BA34029
8A4315EABC6FF1D769E2D650E4DC49E5DE47E2D843FCE966C19D3C783F00AF5D2DC05C3A
C4553AC74E3BCC4E3FCA4C40BC4036BA3933CA4340D24647D4484BD6474DD3444AD4454B
D1464BCA494DC14E51B355568E484AA57477B19395A090939E93999D939B9A939A9C959C
9C969A9993979B949B9B949B9A94989A9498999498969195948E92948E90969092999395
959094948F93989697A7A5A6453F3F2D23243B2B2E271416978385E9CFD28F6B6F7E5657
D0A4A3D4A6A6D3A3A3D2A09FE3ADABFFCDCBE7B5B4B99191F2DAD8F8EAE9E5DDDA645F5B
7A726F978E89A19690BEB1A9D7CDC4E8DDD7D6CBC78C82804A413CA7A09AA29994D8D1CB
E7E2DFA39E9B918D8CEAE8E9E7E7E7E6E6E6E3E3E3E4E4E4E5E4E2E7E3E2EBE1E2F0E0E1
F7E3E2866D68523829452D113425008C8340DEDA79DCDF74DEE586606C204F5B2BBCC6AB
FBFEF500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F4AD9893A6817BB27D79
D48E909D4B4F973C4393383D9B46497B3132B87D7FE9B9B9A6787A926667A07878967472
8F726E8C74708E7B778B7C778A7F798D847F918883938987988D8B9E8F8CA78D8CB4878A
CC8690D67886BC495ACB4B5ACF4755D24450D1444DD2454DD1444ACD4547CE4C4AC65547
8A2F149A5723F2C572F2D669E9D757E6DB4EE2D749EDDF5AF6DC6EB68D358C4D08954510
B15127BE5333C7553BCA533FCA4F40CD4F43D14E46D04B46D44A48D04646D24649D04548
CE474BC74B4DBE5154AC56578A4C4DAB8383AB92959F90959E93999C959C9D969D9C959C
9A939A9B949B9A939A9C959C9C969A9892969893979691959690929690929A9194958F91
989296959192A19FA09C9B99353130302826372B2B261617C6B6B7D1BBBE6F51538D6B6C
BA9897BE9B99E7BFBFDCB0AFB585819665619A6D6ADDB7B6FBE3E1F5E7E6EDE3E1726A68
352D2A1A100E1F1410312620483D37524743685E5C7E74728D8680A099936D645F5F5852
7B76727E7A77989795F2F0F1E4E4E4E4E4E4E4E4E4E4E4E4E5E4E2E6E2E1ECE2E3F1E3E3
F2DDDC7B625B4A301F432C0D35270089823CE2DF7EDDE077D8E1884D58147A845FF1F8E6
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C1BAB277695E786153
DAB5ACD09F98D29695A36162985455642424976161FFD4D5E6B4B78A565A8D5558AA7376
A0727298706E9273708F76718F7C768E7F7A90837D9186829287839D8E8BA58B8AB08688
CA8C91CF7982B74B58C94C5ACE4A57CF4650D1444DD54850D1444AD2454BCD4547CE4F49
C2504585250CA35B29F0BC73FBD776F2D963E7D857E6DA54E9DA59F6E16ADDBC55A97B25
90560C8741039A4A17A2491FB0502ABD5635C25538C45039CD503ECF4D40CF4844D04848
CF4A4DC44C4EBA5658A05252885655AC8E8EA390949F949A9A939A9A939B9D969E9F98A0
99929A9891989F959D9F959D9D969D999299999397969094958F91979191989292958F8F
988F92958C8FAEA8AA8783822E2828312C29342C2A2D2522DDD5D2F1E7E5E9DBDAEAD8D8
F3DEDDFFE5E2D5B2AE99706CC59C96BC938D522B26B79593FDE8E5F7E8E5E1D6D4D5CBCA
D3CDCD8F89893D393A272324514849968D8E9E9493756B698B827D8C837CC3BAB57F7872
A9A4A055514E8C8B89F2F1EFE4E4E2E5E5E3E4E4E4E4E4E4E4E4E4E6E2E3EBE1E2F0E2E2
ECD7D46F564F482F1B412A0A362900979147E1DF7ADEE47AD0DA84555F23C7CDB300FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DDDED8716F624E4737
766656C8B1A1F6D1C8D1A49EC18E8AB17B79835150BA8889F3BFC3DAA1A7884B507E4146
8F57589A68679E70709C7472937471927672947D77917E7890817A9885819C8281A98182
C2878BCA7B81B54F5AC6505CC84954CF4751D1454ED2454DD2454BD2454BD4474DCF4749
CF4D4DC5504796321B94421ADB9B5BFACA76F7D470ECD263E6D259EBD85FF0DB68F4D96E
ECCA68D4AB51B58533A1691E9554108D460694430B973C0DAF4722C65338CE5041CE4E45
C64947C25050B35758914D4E936B6BAA95949B8F939C959C99949A99949B9C959D9D969E
9891999B949B9F959D9B949B9C959C9992999993979D979B948E90979193979193948E90
958C8F999091B3AAAB635D5D302B28332E2B1E19155C5753F0EDE8EBE8E3EDE5E3F0E4E4
F4E4E4F9E1DFD3ADACE2B6B3E3B8B2A87F799A756FF5D6D1FDE6E0FFEFE8A697944C4240
5B5555716D6E4846492523262924284E484A9C9394D6CCCBF3E9E7ADA49FA09694CEC6C3
E8E3DF85817ECCCBC9ECEBE9E5E5E3E5E5E3E5E5E5E5E5E5E4E4E4E7E3E4E8DEDFF5E5E5
E4CFCC664E42452C16422E093B3100A5A251DFE277DFE67EC1C97C969E6DF6FAE900FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F8F3B1B2AA636456
4D4A37887D69CEB9A8CDB0A2B38D84D8ADA7BC8F8CA77777AE7C7FDBA7ABC89196B37A80
B57D80A86D718E53599C6467A26F6EA0736E9C776F95776F927972967F79997C78A37B7B
BA8187C3787FB4535EC2505AD25660CB4850D04950D1464DD2474ED4474FD2454DD1464B
D4494ED24D4ECE514DA83729922C13B55D37E49D67FBC27DFACD78F1CF6DEED368EDD666
EBD661F4DF6AF4DD69EFD866E5C95CD9B851D1A94ADDA656B4692F9F4217C9573CCB5241
C64F47BA514EAB5A57814948A0817FA69898988F9298939999949A9B969C99949A979298
9992999A94989A94989A9498999299948F9596919799949A969195969195948F93918D8E
948E90A09A9AA79E9F3C3432332B29342C2A1813109D9895F7F4EFE9E6E1EBE3E1F0E2E2
F5E3E3F3D7D6A97D7EDBA8A7D19B9BD9A9A7FED7D2F9DBD3E0C5BCA79088B7A69FC7BCBA
9F99998C8889716C704E494D3A34382822241B1517473E3F7D75735A5250534B498D8583
CEC9C66B6764E9E8E6E8E7E5E4E4E2E4E6E3E4E4E4E3E3E3E5E3E4E6E0E2E8DEDFF9E9E9
D8C4BD5D463848321A3D2C014B4200C8C86ED9DF73E2EA87C6CF90E1E7C5FDFFF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D5D6CE
7E80725C59487165557968585D4539D0B2A895706ACCA39FC19594BE9293D7A9ABDCABAE
EDBBBCC08C8EAC71779D62668751517E4D498D625B9D7B71987A70987C71987770A07773
B67B7DBE7378A94A52C0525BC44F57C94C52CD4C51D04B50D14A50D0494FD1484FD3484F
D5484ED64B50D34B4FD55053C34745A12F24922E17AC5732D48B58EFB26FFAC776F8CF73
F4D16BF2D668EFD662EDD863EFDC66EFDA67F4D86DFFDC7FEFB66F914511C05936C6563E
C35548B5574F9F5854885856A98F8E9E94959B959996919799949A9A959B99949A9D989E
9B949B9B95999891989C959C9A959B979298969197959096959097989399938E94908B8F
8A86879E9A998C86862B2321372F2D30282626211ED2CECBF1EDEAE8E4E1EDE3E4EFDFE2
F7E1E4EFCFD2A17074D1999CAF7375BF8786F9CEC8B5948BC5A8A0705951B8A7A0FCF2F0
F0EAEAEDEBECECEAEBE5E1E2D5D1D2C7C3C4A39FA08C8889888284ACA6A6C0BABA443E3E
6864636C6865EEEDEBE7E7E5E3E5E2E3E5E2E4E4E4E5E3E4E6E2E3E7DEE1EADBDEFDEBE9
C8B2A7523B29442F123A2C00787224D9DB7AD7DE76E4ED94E1E7B7FBFEE900FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
ECEDE7BCBCB496928780786D50443888766CA78F85B89D94F2D5CDAD8F8795706AD5B0AA
FAD7D3CCA6A3916564A07473A17876A8817C86615970504582625598786BA17B70A87770
B77A77C274748D2E32A0373BBB4A4EC34F52C44C4EC6494DC7494CCA494DD04E50D34C50
D1494DD1494DD24950D14A50D0494DD14F4FC84D48AE392F952A169D3A1DB35934D68454
EBA368F9BA75FCC477FCCC77F8D071F5CF6CF3CB69F9CD74FFD38BA56630A34924BF5B41
BC5B4AAF5B5090534E946C6AAE99989F95969F999D9E989C9A94989992999790989C959D
979098928B928F8A918E8990847F86837E85807B8278737A68656E67646B625D645E5960
4341447571726C66683C36365A51522920214F4949EEEAE9E9E5E4EAE4E4EEE2E4F3DEE3
FCDFE4CAA2AA926167DBA0A4A76567A56867B786818D6860A98E85B7A69EE8DDD7EDE8E4
E7E6E4E6E6E4E6E6E4E6E6E4E8E8E6E8E8E6E9E7E8EAE8E9E6E4E5E8E6E7E9E7E89C9B99
8E8D8BDBDAD8ECECECE5E5E5E3E5E4E3E5E4E3E5E4E5E3E4E9E0E3ECDDE2EEDEE1FEEBE7
A08A7D49331C402D0C3E3300B9B85ED9DE77DCE384E6EEA5F3F6D7FBFCF400FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEE6D4D0C7A89F96A1948BB0A297D2C1B7BAA89E563E349D857B
E1CAC2E1CAC4B79B97B59996D1B5B2F3DAD6DCC3BEA58C85846C6270554A7D5D5290655C
AF7873C6827F954441913635A03C3CAF4545B34546B94747BE4A4BC24A4BC74B4DCA4C4D
CC4B4FCF4C51CC494FD14B52CE494ED24B51D55055D25052CB4E4CC04641AF3A309E311D
9A3519A24420B45D30C97944D38C4CE8A55FF3B36BF8B976FFC78EECA87B9A4121B85842
B65D4DA75D52895450A2807F96848483787C7E787C7872766D676B6861686059615A535B
4A434B4C454C4F48504A454B4B464C544F5558535A58535A5752595F5A61635E65676268
7A787B908C8D423E3F3F3939625C5C241E1E918B8BF5F1F0E6E2E1EAE4E4EEDFE2F8E1E7
F2D3D9C49BA1E9B8BCDEA6A7A366659055519E6F69C39E96D8BDB6F9E6DFF2E4E1ECE2E0
EBE3E0EBE4DEECE3DEEBE4DEE8E3DDE8E5E0E7E3E0E6E5E3E7E5E6E5E5E5ECECECDDDDDD
C7C7C5E9E9E7E5E5E5E3E3E3E3E5E4E3E5E4E5E5E5E7E3E4EADEE2ECDCDFF4E0E1F0DBD6
6E5747453013382900756E2ADDDF7CD0D770E4EB9BEDF4C0FBFEEB00FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F4EFE4DFD9D0C9C3AAA39B857C738E847A
A89F96BBB2ABD2C9C4EFE5E3FFF6F500FF0000FF0000FF00F6EDE8DBD0CABAA9A2977E79
8D6C658F625C8A514A8B463F9647429A413DA2403DA8403DA73E3BB44645B64444BF4949
C54E50C34B4DC44C4ECA4F52CB4E52C94B4ECE4D51D04F53D15152D05051CD4D4CCC4F4B
C2473FB73E33B1392B9F2C199D2D179F3319A1391CB75437C2644BDD7E68A33D2EB65145
B65F569A5550906360987C7B6C5E5E5B55575D575B5B565A5C565A5E585C6258606B6169
695F67756C717C727A7F797D8781858983878982898D868D918B8F948F93959192918D8E
ACA8A78A86852D29282824212A26232C2825D5D1CEF1EDEAE7E3E0E9E4E1EFE1E1FAE4E6
EFD1D3AC8586A97C79C1908BA5746DA4786FF9D2CBF7D6CFE3C4BFF1D8D4F4E1DDF5E2DE
F7E0DAF6DED4FAE0D3FBE1D4F6E3D5F0E2D7ECE3DAE9E4DEE9E6E1E6E5E1F1F1EFC2C2C0
9D9D9DECECECE5E5E7E4E4E6E2E4E3E4E4E4E6E4E5E9E0E3ECDDE0EEDCDCFBE6E3BBA29B
4A311D402C07483E01C5C370D9E078DDE786EBF3B7F8FDDDFBFDF200FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEE6D7D7CF
E6E6DEFAF9F400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F2
F1E0D9D8C1B9BB9A93A1766F945F598A4D4887403C90413C97423F9D423F9D3B38A53F3D
AE4444B14543B64645BC4A4ABD494AC24B4DC74F50C84D4FCC5052CA4C4FCE4D51CF4C51
CE4C4ED14C4FD14C4DD04B4CCD4B4BC44441BB3E3CB13734A7342FA2322EB64944B95852
AE5D5A894D4C977170A58F9194888A928C8E918C90979296989296958F93988F949E959A
A1989D9B92979A91969B95979C9698969092958F939A9496958F91948E8E928E8D999594
ABA7A458545124201D312D2A16120F64605DF1F0ECEAE6E3E9E4E1EBE1E0F0E0E0F8E0E0
F8D8D9E1B9B9DCACA8CF9E97DDB1A8FDD5CDD5B0AAC5A49F674543B29391FFE2E2FBD9D7
F8CBC6E7B2AAD29C90CF9E8FE3BCADF5D9CBF6E4D8F0E6DCEAE6DBE7E4DDE8E7E2DEDFDA
DDDDDBE6E6E4E4E4E4E4E4E4E3E5E4E4E4E4E7E1E3E9DFE0EBDBDBF3E0DCF7E0D87B6454
432B113929008D8638E2E385D6DE79E6EF9CF1F6CDFBFDEF00FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAECE9E9D6D2CAB1ADA78681926963814F48874B438D443E923F3B
9C413EA13F3CA43E3AA63D3AAD413FB24443BC4C4BBF4D4DBE4C4CC45051C34C4EC95153
CA4F51C94D4FCF4E53CF4E53D14E54D04D52CE4D52CF5155CC4F53C44D4FC15457B95D5E
9A5351814F4EA587879D8B8B958B8C938D8F928C8E948E90948E90938D8F938D8F958F91
988F92948B8E948E90958F91948E90928E8D918B8D948E90918B8D918B8B8F8989A29D9A
948F8C3934312C2724322D2A181413A5A1A0F5F1F0E8E2E2EBE3E1EFE1E1F6E2E3F5DBDA
D5B3B2AF8382B7817F743D3AC59490C59895AC8482D2ACABA6807FE1BABBFFE1E2E5AFAF
A052509A413D91383087372C8B4D409F7162CAAD9DE9D8C8EBE2D1E6E3D4E9E7DBE8E8DE
E7E8E0E4E5DFE5E6E1E3E3E1E3E5E4E4E2E3E8DFE0EBDDDCEFDED7FEEADFC2AD9C432E13
3A2800594E10CFCA6CDBDC76DDE38BF1F7B9FAFCE400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF8F3F5E6E1DEC7C1C6A59EA97C77915A57
8645419046438B3E3896433D9B433F9D423DA44541A4423FA94341B04646B44846B94948
BE4A4BC44D4FCA4F54CB4E54CB4C53CB4C55CD4E57CD5058CA4E56C45158BC575BB15F61
824646956D6DA58D8D948686948B8C8F898B908A8C908A8C908A8C8F898B938D8D928C8C
958C8F91888B948B8E938D8F918B8B908C8B8E888A8C86868E8888908B888F8A87A6A19E
615C592B2623362E2C251D1B3B3535DFD9D9EFE9E9EBE1E0EFE1E1F4E2E2F8E2E4BCA09F
C19E9CECC0BFE7B4B3915E5DA173737D5354AD8687D3ABACDDAFB1FFD4D6F2B6B88B4142
A74949C35F5DC36961B2655B905648673E2C604530615339797258BDBCA0EFF1D9E8EBD6
E6EBD7E4E8D9E3E7D9E3E6DBE3E4DCE7E4DDEADFD9EDDCD2F3E2D0F7E6CC826F4F3A2900
3A2F00A49F4DE5E47ADCDE79E9EFA9F6FBD2FBFDEF00FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF3F2EFDBDA
D9BDBAB695909E756F8B5C54814B4184453C8A443C954641A04844A24540A6433EA83F3C
AC3E3DB64645B94649B84349BB444AC04851C34B55C24D56C04E56BE565DB55F62975354
805252A4868698888993898A92898C8E888A908A8C908A8C8F868991888B91888B948B8E
938A8D90878A92878B94898D928C8E8C86888C86868D8787908A8A8E8986A199978E8683
372F2D3129273B32331C1314756C6FF6EDEEEEE2E4F1DEE0F4DEE0FAE0E3F9DFE2DFC1C3
CBA9A8C29C9B9B7270865E5EC8A8A9E9CBCDFFDFE6DCB1B875373CDE8F92C1686A9C3E3E
CC6F6ABF6C6495574C885E4E9F8672A99D85A09B7D858561B2B48CD7DEB2C4CDA2C6D1A7
DBE7C1DFEAC8E3ECCFE6EBD4E4E7D2E7E5D0EBDECBEEDEC4FBEBC7C6B88B433300403600
797418D5D76AD8DF6FE5EC8FF1F5C3FAFDE8FBFCF400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FCEDE8E8D4CDCAADA5AB867E986B658A554F8C4F4A86413C8E403C984541
9C4241A04240A03C3CA63F40A63C40A93C41AB3E44AD4248B34C50AB51539B53547C4644
96736F9D8883938582938B899088868E89868E88888E88888F868791888B8F86898E8588
90878A91888B93888C8F8488948B8E8B85878D87878C86868C878496918EA29A98564E4C
2B2321372E2F32292A22191CBDB7B9F7ECF0F2E3E6F1DDDFA88B8FAE8F94E9CACFFDDDE0
EFCBCBD3B0AE967472EDCFCDFFEAEAFAE4E7FFE8EFBE939C7C333AB2565BA94245C35D5B
C77067924E439F7567E8D3C2AEA8928080647879577A7B518C8C5A8C8F5663682E5F682F
6E7B45869461B7C499C1CCA4CFD0AEE1DDBAEEE0BDF7E6BAE4D59A7C7028817722A7A23E
D3D25CDDE369DDE47AEAF3A4F8FCDBFBFCF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF4F3F7E5E3E7D2CFD5B9B6B79691A07974976763
8D56538847438D423D923F3B9A413D9E403EA34142A24243A048469146415F2420875C55
A0857C9A8A7D90867A8E867B8D847B8D867E8C857F8E86838C87848F89898D87878B8585
8C838690878A91868A8E83878E85868E858692898A8A8182908B88A5A09D706866302728
33282C352A2E1A1114595357E9E4E8EDE7EBF4E8ECF0DBE294767E95747BE9C5C9EAC3C6
BD9697D2AFAD7F615F927877F3DFE0F5E2E4FFE9EFD2A7B08B4249CA6B71C65D61C76562
B5685E8F5A4CE4C9B8867B696B6650918D728E8662786B3E65591F635816766F27797931
6B753067763566783E5966315F612F756D3C9B895799854894842FACA137D4CC50D5D24D
DDE156D4DD60E3EC91ECF4BBFBFFE800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF5F2F9E4E1
EFD2CEDCB7B1C89993AD7671A0635E96524F924B478D48437C3D3669342C785046AF9387
9887759388728C866C8B856B8D876F8C86708C87748A84748A867A8D897E89847E898480
8883808C84828D83848E84838D83818A807E8D847F948B86A49B967A736D362C2A372D2C
3A3031241B1E393033D0CACCECEAEBE6E1E5EBE0E6F0DFE7F6DFE7F5D7DFB49499806063
C6A8A8E5C9C8957D7D705C5DF0E0E1F3E0E4F9E0E6FFD5DFAB5F69AF5058CB6468C86A68
A35D55A6786BB19B8D564F3DDFDAC6D7D0B671613F644F20CAB576A692499C8C3FC2BB6D
93954A6C76316D7738686E306D692A6B601E6B5911695701B1A434DAD14ECDCB38DBDE47
D6DD4FE1EA77E6EDA7F7FDD9FCFEF100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFF5F3FBE6E3EBD2CED8B9B6BB9C998A6F68AF998EE7D7C8E9DECA
C4BFA19D9B7599976E9291638E8D5F8B8A5E87845B88866086876586866A85826F858273
8A867D837F768B827D8B807A8E81788F8176988A7DA89C8E82766A392C23392C243C312D
221A17423D3ABEBAB9F1F0EEE6E5E3E5E3E4E9E3E7EDE2E8FAEDF4B09FA5826F73BBA8AA
B7A7A8AB9D9DB8ACACE3D7D9F5E6EBF5E0E7D8B9C1E2AEBAFDAFBDB05260BC5661C06467
A15B59A77A749A837B645A4E847D6B867A6256422194794AEED390DEC77B9D8A3BB8AC60
E5DE9A7B7738666024776F307C6E257A6A15968722CCC04AD6CE45C8C731D6DA3FDAE04C
DDE665E5EF8FEFF5C7FAFEEDF9FCF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3F9F5ECF7F3E7F0EFDD
D8D8BEC1C2A0B8B892AFB086ACAD81A3A4789E9D7198996F8F946C84886583866B85846F
8584727F796B8B7F719585759A88729B876EAC987D88775B3E2E143D2D1445342031220F
38301DCDC6B4FAF4E4EBE8D9E7E5D9E9E6DDECE4E1EBE3E0F0E8E6D8D0CEE5DBDAF7EDEC
ECE7E4EAE6E5F1EBEBEEE8EAEEE3E7FAE9EFD0B2BC6B3D48A86171B46070BC626EBE6B73
A569698C6663AF9C96574E45BFB7AAD2C7B35C492BA1895DECD297ECD58FA5924DB8A966
B7AB717467307F6E3682712C72600CB1A038DFD156D4CD41CCC831CECF33DBE247D8E057
E4ED82DFE6A0F9FDE200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F9FAF2F7F9ECECEDDDE3E5D0D4D8C1C0C4A9B4B79AACAF90A6AD8C99A07FA2A88CA7AB92
797961736B56AA9A83D4BCA0CCB08BAC8F638368394E38063F2A004B36094E390C3C2A00
A99D6DFEF3C5F4EBC2F0E8C4F0E9CCEFE7D0EFE7D4EFE6D5EDE5D8EDE7DBEFE8E0EAE5DF
E9E6E1E5E4E0E8E4E1E7E3E0E9E3E3EEE3E7F9E6ECAB8B96804C599F5F6DB06C79AF727A
8C6264745A59E8DDDB999490928E85867E7151452F746443D4C196F1DFAD897948918354
7362379582578D78436B540EB3A13DE0D257D0C73AC8C52CCCCC30DCE147D7E051E2EB76
D7DF94ECF1C8FBFDEF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBFEF5FAFEF0F7F9EBEAEDDADDE2CCC7CFB8B6BEA7A6AB95
71705C827B68D3C3ACBCA78A967C57A28758B7A06AB39F649D8A4F8E7C3E82702E7D6C27
C9BD73E7DB93EADD99EFE1A4F3E3AFF2E4B5F4E5BAF5E7C0F6E9C6F3E8CAF2E6CCF0E5CF
EDE4D3ECE5D5ECE5D5EAE4D4ECE6DAECE3DAF3E5E2FBE6E5D2AEB295686D8053587E5559
715554AD9E9BF7EFEDECE8E5C9C6C1B2AEA3B8AFA0AEA38DBAAC8FCBBC9BA0926FDECEAC
E6D4B0ECD7AC887034B19B46E5D460CFC63BC9C62DC9CB2CD5DB3DD9E14ED8E363DEE888
D6DDAAFBFEE900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F7F1
E8E8E0E1DED5DDD5CAB4A89894886EAEA17FCEC396DBD29BDED793DCD68AD0CA76BFB85E
BCB253BEB250B9A949AB983AAD9742BEA759C9B266D5BF76E1CC89EED89CF3DDA4F5DEAC
F6E0B7F5E1BCF7E5BFF4E6C1F3E6C4F1E6C8F0E4CCF5E6D3FFE9DBF2DCCFDCC6BBD1BDB4
DED1C8F0E9E1EAE7E2E7E6E1E9E8E3ECE9E2F3ECE4F6EEE3BEB2A4948774D4C6ACCCBD9E
E3D1AD9A86519E8936E7D567CFC33BD0CB33C6C628D2D83AD6DF48D5E15BDFEA82C7D18A
EFF4D6FCFDF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFDF4FFFCEDF7F2DEEDEACBDEDCB3D5D49ED8D898D7D78FDCD98A
DAD480DFD67BDDCF6ED1BF5BC5AF4CBAA23EAD962EA58E269F8926A089299F862CAF9541
B89E54C3AC68C9B570DDCA88E8D89AEFDEA6F1DFAFF2E1B5F5E6BFF8E8C6F9EAC9F9ECCC
F7ECD0F3E9D0EDE5D0EDE5D2EDE4D3EFE6D5F0E8D5FCF1DDD8CBB87C6D56EEDFC2E4D4B0
AA986884712CE6D470D5C848CAC334C7C62DCBCF34D8E04CD1DD55DEEC7AB7C475CBD3A4
FCFFEE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FDFDF5FEFEF4FCFDEFFDFCEAF9F9E1EFF0D1EAEAC6
E0DFB3D9D8A0D0CB87D3CB78E0D470E7DA68E8DA5DEADC59E4D651E0CF4BD4C341CAB83C
BBAA38AA982AA39125A4912A9B87289F8731AB9240BCA257BFA864CBB675DAC582E7D291
EFDB9EF3DEA7F4DEADF6DFB3F6DFB6F8E2B9F8E3B8FCE7BAF4DFB2E3D1A1FCECBBDFCE96
796421CBB760D8C956CAC23BC5C233C9CB39D8DF51D3DE5BDCED7BC3D37B9FA977F2F7E0
FBFCF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4
FCFFEEFCFFE4F1EFC6C1BF84C1BC6ACEC75FD1C851D8D04BD5CC3FDFD444E3D745EBDF4F
EBDF55ECE058ECDE59E8D95AE4D159DAC656CFB850C2AC49A9963A9E8D359F8E369D8B35
9C8736B29C50AB934DB29957C0A669C5AB6ECFB674D4BD7ADCC784E2CF8DE4D5947F702B
968638DDD070C4BD4BBFBE40CCCF4ED2DB5AD1DC62DAEA7FD1E38D829254CDD6B9FCFFF4
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FCFEF3FFFFF2EDEDD1B3B181B2AF6AC9C56CD2CE63C9C349C9C13CC8BF34CBC334
D3CB3AD9D140DDD244DED548DCD24CDFD655E1D95DE3DC68E3DC71DED973DDD777D8D274
D2C96ECFC46AC5B75FB8A853B3A250AA9844A3913B9886309787329C8D3C988C408F8639
DBD483C5C46AB3B756C6CE69CDD973CADA78C2D57BACC1746E824797A581F7FEEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00E7E6D19FA0789D9C63B9B76DCCC86DD5D26BD3D05DCCCA4F
CECB4ACCC946CAC746CDC94CC8C34BC0BF4BC5C458C0C05CBDC163C0C36CC4C577C1C276
C8C578CDCA7DD6CE83D9D186DED58ADFD689DED286DDD185D7CE83D6CE86D3CB8AD8D494
BFBE7D8487427B823E8B965288975491A16280915A697A4D798869E2EBD800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FDFDF5F5F6E8DFDFC7CFD0AEC1C296C1C289BEC17CC0C573
C5CA70C6CB6DC4C76EC9CB78CCCD81CCCD89D1D298CBCF9CC9CC9FD8DDB5E2E3C1DFE0BE
DEE0BBE4E6C1E9E6C3ECEAC4F0ECC7F1EDC7F0ECC6F3EFCAF3EFCAF2EFCCF0EDCEECEBCD
DEDFC0CACDAEC8CDAFCDD3B7D3D9BFD9E1C9E1E9D4EBF2E2F5FBF100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAFDECF1F5DCE3E7C4CCD2A6
AFB682B5BD84CFD3A0E6E9BCEFF1CAF2F6D5F7FBE2FBFEE9FAFEEFFBFEF300FF0000FF00
00FF00FDFFF2FDFFF2FEFEF2FDFEF0FDFEF0FDFDF1FDFDF1FDFDF1FDFDF1FDFDF3FDFDF3
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4FCFEF1
FAFDECF9FCEBFCFDEDFDFEF0FCFEF1FDFFF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 335.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001Cb000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`003Ooooooo
003o00D00?l03oooool000gooooo?`00o`00103WinD0blc70<_<a`3Ad/d20>c/j[l00?l03oooool0
00gooooo?`00o`00103WinD0blc70<_<a`3Ad/d20>c/j[l00?l03oooool000gooooo>@00o`020?Sg
l`050=cKe`2b/Jl0OWek07imN`1<BdL00P0^;BT01@0e=300De9>05=BCP1gMW80YJJQ0080c<c:00<0
jNWW003o0000o`00^000o`0?ooooo`003Ooooolf003o0080g=SE00D0W9VD06ISG01VHe`0?c`e02LT
7`0202dZ9@0402PT8@0`;2T0<2`Y038_:P80;b`W00D0:BHQ02PW8P0^;bL0;RlW04M8@P0208^<QP03
0>g^j@00o`000?l00;D00?l03oooool000gooooo=P00o`020=cHe@0509bIU01VHe`0IV=L03ll=@0W
91l00P0]:RD0100X9240<2`Y030/:@0b;bX202l/9`0502TV8@0X9b80;RlW02h_9`17B4800P2;S8H0
0`3]k^T00?l0003o002e003o00oooooo000=oooooc<00?l00P3fmo80102^[JT0@d0k04=0>`0R7AL2
024N5@05030]900l=c40@chj04<n>P14?c/00P1<A4401@1BBdD0EDi805E>B01DCdT0CDY10080=c@[
00@08R8H01/K4`0K6a<0GUmI0P3@dLbe003o00oooooo000=oooooc800?l000@0h>7L07elM`1mO7L0
=34Z0P0M61801@0X91/0=C4X03Da:011?C@0@3Tc0080>C4^00@0?CDb048h=P12>3H0Achi0P19@3/0
1@1=A3d0D4To04U2>019@SP0@clf0080=C8Y00@07AdE03hm>@0n?CT0[JbZ]000o`0?ooooo`003Ooo
oolb003o00040>3Qg01mO7L0OGag03@a:P807APB00D0:2@K03Da:00e<BP0@Cdd040i<`0203Ta;P04
03de<P12>3H0@SPf04Ln>@80BD0k00D0CD@m0519?`19@SP0BD8h04<o=P0203Db:@0401dM5@0n?CT0
?Sdi0:f/Z[@00?l03oooool000gooooo<@00o`001@3Shn40GeiI02PU7P0X9Ah09B4H00807a/B00D0
=c<Z040l<`10?3<0>cL^03L`:P0203@/:@0403le<`10=S@0@3Hd04<h=080A3Tc00D0?c@^03lf;@18
?cH0B3lf04Y3>@0204]7?00503`i<00X9B00:2DP02XY9@2UYJ<0/`00o`0?ooooo`003Oooool_003o
0080m?Cb00D0NgYe02DU7@0/:B00;2TP02@P5`02038[8@0504Ho=@0k=2X0>c@Z04M0=P0m=2d00P0d
:bH0100f;bT0=BhX03D^:00l<bh203T`:@0503/b:`1:@CP0CdLl04m7?012>Rl00P13?c<01@1:B3`0
=c@]03Ld;@0O7QT0?3dh0080e]KD/@00o`0?ooooo`003Oooool_003o0080Xj2K00D0:2DN02HS700_
:R@0;bXT02HO5`0203@[900504Y1>00g;RD0=bhU03lf;@19@3T00P0i<2T0100`9b80>2lZ03P_:P0m
=2l203H]9P0504<j<@1CBT40CdDk04m5>`10=R`00P10>Rh01@1:AS/0AT<j04I3>P0X9b807QdI0080
KVi/00<0m?Cd003o0000o`00[P00o`0?ooooo`003Oooool_003o0080Xj2K00D0:2DN02HS700_:R@0
;bXT02HO5`0203@[900504Y1>00g;RD0=bhU03lf;@19@3T00P0i<2T0100`9b80>2lZ03P_:P0m=2l2
03H]9P0504<j<@1CBT40CdDk04m5>`10=R`00P10>Rh01@1:AS/0AT<j04I3>P0X9b807QdI0080KVi/
00<0m?Cd003o0000o`00[P00o`0?ooooo`003OoooolR003o0080ooGd00@0ooKc0?odl03om?00ooC`
0`3omO80103om_80ooSc0?ohl`3;_[P203`c;005020G4P0Z8ad0<BXT034Z900Z8ad00P0]8Qh01@16
>cL0>BhZ03T^:P0^8ad0@SLc0080?c@`00@0<RLQ03/`:P0k<2X0A3Tc0P0h;BL01@0n=2/0CdDl04Tl
=019?3@0>S0W0080>S4X00D0AChd055=A01ACD@0:bXU02<R7P02024Q7`030:^YZP00o`000?l00:h0
0?l03oooool000gooooo4@00o`020?o^j0050>SAb`3QbLD0f<?00=S3`03D`/000P3E`l401@3KbLL0
d[fl0=:m_03E^k`0g[jo0080dJZ[00@0`9BE0<bJV@3<VYT0biRD0P34ShT01@2iQ7h0]hEn0:mnM`2_
OWL0X7E^0080TW1W00D0H4Dl02LE2`0W5@/09APB034X8`0202hT8P0402XP7P0Y7Q`0:AhL03P]:`80
@CHb00D0;b@P03L/:00j;b/0>Rl[03X_:@02048g<@050556@013>380@cPb03lf;@1:@3L00P0f;2<0
100`9Qd0=bhU03L^9@17@3P204@o>@0502/X8`0V8Ql06aLF01/G5P18@T800P3Wg]mR003o0080kNg]
00D0[jn_06YZJ01ZJVP0IFES06EVH@0206EUH`0406IWHP1WJ6<0IfQS06Y[IP80SXj<00@0^k^i0=?C
d@3Xj>H0j>SV>@00o`0?ooooo`003OoooolA003o0080onkX00D0j=7;0>79a@3H`l00f<?00=C2`002
0=G3`@050=_9a`3B_K`0d[fl0=Fk_03N_[l00P3AZZ/01030U9D0c9ZI0<bJV@3;V9@20<B?R@050;V4
OP2gQGh0[gig0:mnM`2PMFh00P2BL6L01@1PAC`09aD;02LE2`0U6180<BPS0080;R@R00@0:R0N02TN
700Y7Q`0>2d[0P11=S801@0_9200=b`X03X_:`0j;b/0>RlY0080@SLa00D0DDI004<h<P13>380?cH]
04Y0=`0203H/8`04030V7@0g;RD0=bhU04M0>080A3li00D0:bPS02HR7`0K5aH06aLF04Q2@P020>ON
gf800?l00P3]kNd01@2_[jl0JVYX06YZJ01UIF<0IFIQ0080IFES00@0IVMR06MXH`1WJ6<0JV]V0P2>
SX`0102k^kT0dm?A0>SXiP3Xj>Hi003o00oooooo000=ooooo`h00?l00P3on?D01@3leLh0_hUo0;n9
O`29CD80Y71U0080ZGaf00@0PUeG08=RG@23HUd0Y85o0P2RNWP01@2TM7@0/gUh0:EMGP2UGEh0Schm
0080XdY600D0YTM10:I5?02VAC`0Wclc0:=5>@0209Dm<@0408Hh:`1j?2l0NS`_05lc9P80<aD;00D0
:1D>03DW900c:BL0<bTW02hT8P0202XP7P0502`R800d:RP0=2XX03L]:`0h;BT00P0m<Rh0100i<2T0
A3/d04@k=01CBT4204m6?@0504M0=P0n=bd0<2LP030W800X7aP00P11>3401@18@C/0=bl/03L_;00]
9B<09A`M00809a/K00@09A8D08QdL`28M7<0g<[60P3PdLX01@3VfM40jMoF0?7Wg@3aimd0n>oV0080
ooK_00<0ooge003o0000o`00DP00o`020>k^k0040:b^Z`1IFEL0FEUG02DU8`806QTG00D05aHB01TH
4`0K6QH06aXF01hM600201LH4P0500l@2P0J6aH06Q/F02<T7`0/;RT00P17BD@0101TIV<0QhV608N9
QP2^/:d20>;ThC<00?l03oooool000gooooo3@00o`00103oj^L0iJjY0>F^Z@2bJF0209a9>`05090m
;@3@Rg`0_H=h0;f3N02HIf000P2>Hed01@2DIf80VVMT09YWI02YK6/0`gUh0080b6i]00@0ZD4n0;]:
A02kBT@0_TLo0P38CDD01@35Bd00aDdo0;e<?P2mC3h0Xcl_0080ZeQ800D0PD<d048H301260`0;0l9
03@Q7@0203LY9P0403<X9P0a9R@0<BHT02hT8P80:b4O00D0;bDS03P]:@0j;b/0>Rl[03Xa;00203lf
;`05048i<P10>C40@3Ta03lk<P0i=B`00P0g<2X0100o>380>30]03P`;@0f;R/2034Y9`0502PN7@0]
7al0=20R03@P8P0[3Q000P108Ah01@1A<bT0FC`^05Tl;P1]DT40I4hi0080KEU100@0M5m:07]YE@1k
JED0P6eL0P29MVD01@2AOVd0XHak0:jHRP2^V8X0^ZBF0080b;:U00D0eKfc0=_4_03Ka;`0h<_60>KC
c`020>cJeP040?7Rg`3djND0m>WU0?[`kSh00?l000D0l_;`0:n_[@1GEeD0EeME01hP6`0201DF4@03
01lN6P0P7a/081lK008071/F0P0Y9R40100X:2007AdE01dM5@0M7QH201dN600501PI4`0F5a405QTB
01HI4P0E5a800P0F61D0100G6AH0CU1=04i@C@3Fe]Hb003o00oooooo000=ooooo`d00?l000@0on[W
0>F^Z@3U[ZT0/VUP0P2LBC/01@2@?Bd0d8]l0;f3N02mPgP0V6MP0080SV=M00D0U6MR09YWI02JIf@0
ZFa[0<=iN0020<Q^K@040:U1?P2kBT@0^dY40;i7?`80b4e500D0aD]00<E=?`2mC3h0_D`n0:<o;`02
0:]HB0050853=01260`0@QP<02`?2@0d8Ad00P0g:BH0100c:2H0<BHT034V900^928202/Q7`0502lU
8`0h;BT0>Rl[03X_:`0j<B`00P0o=Rl01@12>C80@3Ta040i<@0o>c80>CD/0080=c0Z00@0?cPb03P`
;@0h<2d0=Rh[0P0a:BL01@0X7Qd0;AlO03@P8P0d8280:`h@0080@24N00D0DC<Y05Tl;P1I?2h0KE91
06A>>@0206eI@@0407AOBP1kJED0NfUE081]G080RGIU00D0TGi]0:6<N`2^V8X0[YR:0;ZTUP020<Rb
Y@050=Fm/`3Ka;`0flBl0>3;aP3Vdll00P3/f]H0103ah]l0m>WU0?CYi@3jl>hn003o00050?;bl02_
[jd0EeME05MGE@0N81/00P0E5Q400`0O7QX081lK020O6`0201`K5P80:BHQ00@0:2PP01dM5@0M7AD0
7AhF0P0M7QP01@0H6A<05QLA01HI4P0F6A805ALB00805QPE00@05aTF04i@C@1>D4d0e]KF<P00o`0?
ooooo`003Oooool:003o00040?ofm@3oc/X0olk:0=23O@80]Tm600D0^TXn0;15=@2`ACD0W3d[0>:E
Q@020<J8N`040;B0M@2GJ600UfQP0:=cK`80/Waj00D0[Fe[0<YlNP3LOW`0g7il0;A8A@020<=>A`05
0<97@03CE4d0deA=0<i>A@3?DDD00P3:D4<0102^?S00_Ue=0;iMC@2FBS`2050F2P0503H>1P0i7AT0
=b<R03LS8P0d92@00P0j;2/01@0_9280;b@P02lT800`9B40=2HS0080<bPT0`0g;RT01@0h<B/0>S<]
03Xc;@0n>C<0=S4[0080=Rh[00@0=bl/02/S8@0[8b40:b<Q0P0[8B801@0`8R80=B4S03PK7@0h6ad0
<PX;0080EBDQ00D0JST[06/k9@1[>bD0NTd`05hf4P0205li4P0405Pe2`1K=@h0FcD>05/e4080EBl:
00D0FC<>05`d401Y?Q`0JChL05`]4@0206Pd7P0506L^6`1S:QT0HbXI06L_8P1^>Rl00P1cAch0101c
C4D0MUE>07IECP1jGEL2089UH@0508e_K@2EMW<0YHJ30:F6P`2_T8d00P2iVYD01@34Yj<0ck>_0<nc
[`3I`;`0gLS50080h/o;00@0imGA0>gNf`3]g]/0lnCQ0P3ijnX00`3nlo400?l0003o000S003o0080
a/K400D0IFIQ02<T7`0G61<05aPC01DF4@0201TJ5@05020O6`0Q81/08B0K02l/9`0`;BH00P0d;bT3
03Ld;@0503Ti;`0c<b/0<c<[02HW7`0L7AD00P0H6A40100E61404aD@01<E400B5a<2010E4@0304Y<
B`3Be=<00?l003000?l03oooool000gooooo2@00o`001@3omO@0fjn/0;AQF`2dHE/0]THk0080bdLk
00D0d4/l0;m6=@2oASD0Z3l/0>REP`020<^8N0040;UoL`2[MF/0ZgE[0:mfK`80ZVeX00D0WEIB0;IQ
GP3KN7<0fgQc0;m>B0020<U>A`050<a;A@3BCDH0dTe60=E@A`3AC4<00P3@CD<0102l@3@0`U530<9A
@`2kFdd206dO4P0504<7000o4Pd0?adK03lM6`0j81l00P0g8b801@0e8b40>R/X03X[:00j:bP0?Bh[
0080>bdZ00@0<bPV030V900`9R@0;R@R0P0_9b@01@0c:bP0;2@Q02XR800Z8R00:B4O0080:B0Q00D0
:b4R02dO7`0]7al0<alQ03hQ8`0203PA4P0403T61@1U:R@0IBXT07do<080O40V00D0TE/g07U:7P1i
CAh0NDdN07E;6@0207iB8@05081D8`1fBQT0MTXI07A65@1eAAL00P1oBQh0101_<`h0McDE07Le5@25
>Al208Lk900507he901j=RT0L3L/070g;01J:R000P1D;2@01@1;9Qh0BR<N04XS7P1:8R00D2LS0080
E2/W00@0E2/U05L^:01G;RP0Db`U0P1?:R801@1<:b@0ESLb05Tl=P1I?3H0H4Dn0080J4a900D0KeIB
07ALF01dG5P0OFEQ08I^JP0209=kM`0409b7PP2YU8l0ZIB?0;FPW@80`JbY00D0bKBa0=O2_`3NbLH0
g/W60>G@c@020>[Gd`050?3Mf@3fin80m^OR0?_^j03nmNh00P3ooO80103ooo@0oooc0?ool`3oo_D7
003o0080h^;P00D0R8R603@e<00d=C0071dH01XK5P0201`M600401TJ5@0F5a805QLB02XY9080>CHa
00<0@3/e03Pc;@0b;BL00P0b;BL203@a:P0503Pe;00c<2L0<c0W034a9`0d=2X00P0^;bL0100R8ad0
4aH?01<F3`0G6A@201HH5@0401PJ6@1@DU40e]KF0=KFeRl00?l03oooool000gooooo2@00o`001@3l
dll0XEI@0;a:@02lBT00dTXn0080e4Dg00D0dTHe0<I7=P36AcH0[3dZ0>J>NP020<MlJ@040;UdI@2W
HeH0Yf=F091:@080YU]E00D0WDQ30<1QF`3XNg@0j7]d0<58@0020<i=A`050=5:A03FCDL0eTe70=]@
B@3HCDH00P3EBd40103;@CH0bDDi0<U5>@3EGDl20:i4=P0507<I401D2`@0BA8=04TB3@1571P00P0l
7AX01@0h7a/0>RDP03XU800l:BD0@S0^0080@34^00@0>Rl]03hc<@0n<c40=2TW0P0]8b401@0d:RT0
<bTX034W:00a9bP0<bTZ0080<2@V00D0<B<S03@N800d7R00>Q`N04@L7@0203h;2P0404P81P1e<BP0
MC4X08Y6<`80SDdb00D0ZgMB09AW?@25G2h0QE`^08AN;@0208YU<@0509Q`?@2BJSL0TVXg09E/>02E
IcH00P2LJCX0102GG300VeL`09]G<02=?Qd208lo90050997<02<BSX0Ic4W06La9`1J;bP00P2:J5h0
1@25I5/0O5UC07aID`23GEX0PUUE0080G30]00@0I3Tc06Dm=@1U?CD0DR`S0P1D;bH00`1G=B`0FCP_
050_9P02050_9P80CBXV00@0C2TU04l/:01?;2P0B2DO0`1>:B<0101@:B80Db`U05</9@1@:B82058Y
8`0505HY901P;BT0J2hZ06P^:P1_=2h00P1g?SL01@1mBCh0P514081@A022FdX0Of=>0080Of]@00@0
SH9R09B>K02DSV`0WIQj0P2WYH`01@2][9X0^k^_0<;3^`32`k/0Z:VS0080CDi900D07AhI01`M5`0L
7AL08B8L01dL600201hM6@0401lN6P0V9B409RDQ04=0>`80<BhY00D0;2LS030[9`0X8al0:2<O02/V
800202lZ9005034/9P0X8ad0:2<M02PS7@0`;BH00P0c<b/0100a<2/08b@N02<T7P0G61<201DF4@05
01`L6P0I6AL0D51@051@D03Ph>00;P00o`0?ooooo`003Oooool9003o00050?cCc`2QEU00_4Y00;a:
@03BBSh00P3DACL01@3BASD0aTLf0<I7=P2/?BX0iXij0080agaY00@0^GAU0:MSEP2WHeH0T4Y00P2V
FeD01@2MB4<0`65K0>QkM03XNg@0`DQ00080cTe700D0dDY40=I=A`3FCDL0fe190=Q=AP020=E;@@04
0<]1=P39ACT0bDDi0=EMC`80[T@f00D0LaT@05@;10194Pd0BA8=04DL600203`M6P0503PO6`0j9B00
>RDP03`Y9@12<2h00P10<Bh0100j;bd0?S<a03hc<@0d:BL202dS8@0503@Z:@0c:BP0<BLX034W:00c
:BX00P0`92H01@0a8b<0=1hP03@N800j71h0A1`M0080?P/:00@0B0P607Da:01e<BP0RTHc0P2=CC80
1@2[Me80U6Lm08EL;P25G2h0Q5h]0080RVDa00D0V70m099Z=`2BJSL0UF`h09EW=P0209aY>P0409ML
<02KEc00VeL`08dn7@80SclT00D0TTL`08a:>P1W<BL0Ic4W05X_:00208YXGP0508ETF`1lFE<0O5UC
08=MFP22FED00P1L<2d0101T>C<0ICde06Dm=@1B;2<205@_9P0305Le;01I>2l0D2lV0080D2lV0P1=
:RH0101<:BD0Cb`X04l/:0189Al304hY8`04050Y8P1C;2D0Db`U050Y8P80DRTS00D0ERTT060]:@1X
;RX0J2hZ06ld;P0207Ln=`0507e9?P20D4@0P514089KBP1oHdh00P1oJe00102=PV80U8i/09B>K02M
V7X20:NUS0050:f/VP2k^jl0`/>k0<;3^`2XZJ<00P1=CTT01@0M7QT071dG01`M5`0Q8Q`07A`H0080
7QdI00@07ahJ02HU8@0V9B40@d0k0P0a;RT01@0/9b<0<2/W02PS7`0X8al0:bHP0080;bXT00D0<B`V
02PS7@0X8ad0:2<M030]9P0203<c:`04034`:`0S91h08b@N01LH4`805AHA00D071`J01TI5`1@D500
D51@0>3Ph00^003o00oooooo000=ooooo`L00?l00P3om_<01@3LX9P0YdDj0=1<@03@C400eT8d0080
ed4b00D0eD@c0<M2<@37@S40/CTX0>9kJ0020>^@O@040<adIP2gGe<0]emC0;EKDP80aFAM00D0dFYS
0?21NP3OI5d0gfAM0<Y7?`020=E<A0050=Q;A03GB400edQ00=e>AP3NCdL00P3MCD@0103GA3X0c3`a
0<`l<@3MDdH20=9BA@050;Y5>`2<9ad0G`l605l?1P1C4`X00P1;5Q001@166A@0@A`F044L5P107aX0
>adK0080>b4P00@0>B4O03`W9P0l9bH0=b<R0P0f8R401@0j:2P0=R@T030L7@0`71d0=b4S0080>AlR
00D0?1`O03hF5`0n5QL0AaDF04d?400204h40`0406DB302@?340T3`a09M6<`80WUHm00D0[WIC08mO
=`22Ebd0PUL]07QB9@0206]56005079<7@1dC1/0M4`K08UO;@26FR/00P2>Fb`01028Cb80WUdc09iM
<`2TF3@209M:;00509E==@2:BcX0EB<J05DS6P23GE@00P2]S8<01@2QPg/0Z8F10:R5P@2hTXl0Ufi/
0080FC0^00@0HcXf050Y8P1@:B80P5]B0P2HMV`01@2GMF/0TFmU08eXG`2=J5l0S6EN0080RV5K00D0
QeaF08IME`26GEL0OEA>07M?A`0207=;@`0406a4?01V>c80IS/b06Di<080FbXS00D0JBl[06/W901l
;RX0O2hZ080]9`0207dZ8P0507/]801b:aT0LR/I06P^5P1B9`D00P1L?aD0101WER80H5DO061E7`1J
DR<205]F;P0505eJ>`1OGTT0?Ch`03dn<00@4@T00P0E5Q001@0N7aT0824K020Q6`0O81X081lK0080
7ahJ00@06QTE03Xi=@0j>CD0>SLb0`0Y9R40100W91l09B0L02DP700b;BT202lZ900502/V800/9240
;2@Q02/V8P0/9b<00P0V8a`0100[:2<0=C@_03Dd;`0S91l201TJ5@0501`L6P0M7A/05QHF01HF5P29
RHT0;P00o`0?ooooo`003Oooool7003o0080onOS00D0]fQQ0;i<@@3CBC`0ddTl0=I0<@020=Lo<@05
0=0m;@3DAcH0e4Lf0<8m;03MI5<00P3mRWP0103cPGH0j7=Z0>QcJP3VKFD20=ePFP050=QIDP3HDd`0
cD@l0<e4?03CASd00P3HBT001@3GAch0g4U10=a9@@3MB440hDa50080gDTo00@0fT<j0=M0=@3G@3D0
fDDi0P3OD4801@3NE4L0ce530;51<`2a@C<0RBLJ0080Ja@:00D0E`d405<B301C4P`0DALC04PE4P02
04TI5`0404@K6@198B40BB4Q03XC5080?1PJ00D0?QXJ03`H60116AX0@ATJ044E5P0204LE600504/@
4P1C3@l0D`d?05P71P1V1`D00P1j4@d0102O<R/0[D<f0:e3=P2ZBcL209i<=0050;9_DP2IHD00Pe4^
08=A;P28FSP00P1dB2D01@1N=0h0KdDK06m56`1mDRL0KD0G0080NTTP00@0M3hB09UK<P2IFc80Z690
0P2DCC401@2EDcd0Nd4c06`m=@1/?CD0/8^30080/I2900D0[Y280;FBT02eTY00_YNH079:B`0205/d
=@04054^;01WAT40IdI10;>BR`80[8j400D0[Xf40:Z8O`2fSHL0]Xf70;F8P`020:MfLP050:MfL@2[
OWP0Zgih0:V1N@2SPGP00P2PP7D0102JO740VGU^09UiKP2FM6X209M/I@050:MbKP1k=c@0NbLU07/W
9@2F>C@00P2G=2h01@2D=2H0RC@O08Td7`20>AT0K3P90080R6@Z00@0QF`Y07QW8@1hIb40MV/[0P1i
LS/01@21O580SXe_06ETDP1UI58020P000805QH>00D08b8M02@S7P0T8ah08B0K02LT7`02020M6004
01XG4P13@3/0@d0k02/Z9@8081lJ00D09RDP01hM600S7QP08ahH04]4?P0203D`:P0502DP6P0]:2@0
;BPT02/V8P0Z9B400P0S7QX0100Z9B40=C8]03Db;@0l>cH201/L5`0501HF500M7A/061XG01PJ5`10
@Sl00P3Ti>@/003o00oooooo000=ooooo`L00?l00P3oin<01@2gJ640_Ta10==9?03CBC`0eT0a0080
ecla00D0d3d]0=A7=P3DAcH0`Sd/0=eTD`020?f:N0040?>1MP3XLfX0j7=Z0>I]I@80gF1J00D0f5UB
0=QCC03=A3`0cD@l0==6?@020=Q:@0050=M7?P3LBD40g4U10=e8@@3QC4D00P3MBCl0103J@cX0ed0e
0=M0=@3IACT20=m@@P050=iDA`3?DD<0/D4c0;51<`299aX00P1[50X01@1G3@@0Da8<05<B301A5a<0
B1DB0080BATG00@0A1/I04TQ8@198B40>Q<D0P0l61X01@0n6QX0?1PH044I6P116AX0@ADF0080AaDH
00D0Ba0B05<=3`1C3@l0F0L606H71@0207XA3@0409lb:`2]@cH0[D<f0:Y;=`80WT`d00D0/VmB09UQ
@023DBh0Pe4^08QJ>00207A89@0505hd3P1_AA/0KdDK07eB9`1]@1L00P1jBB00101d?Q80VE/b09UK
<P2XHT0209A=<@0509EC?@1k@C<0K3de06`m=@2`Rh<00P2aT8T01@2^T8P0]I:@0;FBT02nUiP0LTY;
0080Fc@e00@0DBh/06M6@@1WAT40/i:;0P2/SX@01@2^SH@0ZXQo0;J=Q`2fSHL0]HR30080YgIb00D0
YgIa0:]nN02[OWP0ZH5i0:>1N0020:20M@0409YlL@2INFh0VGU^09IdJP80UfaU00D0Yg9^07/g=01k
9bD0NbLU09Hi=00209Ld;P0509@d9P29=1l0RC@O080i6@1/>0T00P28I2X01025K2T0N6LQ07QW8@1f
Jb/207Ub>`05085lDP2>SFl0IFAB06ETDP0820000P0F5Ph01@0S8Qd092<N02@S7P0Q81/09b@O0080
81dH00@06QLB04=0>`13@3/0:bXU0P0P7aX01@0V9B007QdH02<N600S7QP0Bd@n0080=C0Z00D09B0J
02dX900]:2@0:bHR02XU8@0202<N6P0402XU8@0e<Rd0=C8]03`k=P806a`G00D05QHD01dM6`0H6QL0
61XG0412?`020>CTi2`00?l03oooool000gooooo1`00o`020>c3_`050:a?A`38BSh0fD/m0=U;?@3F
@3400P3I@C<01@3D?Rl0gT/k0=i;>`3HBcX0c4@d0080gUU:00@0f5970=U@B03ID4P0fTm80P3DAch0
1@3DACd0dT8i0=I3>`3F@c/0f4@j0080eT8h00D0fDDk0=U2>@3I@ST0g4Dl0=m6?P020=Y2=`040=Y1
>@3H@3D0f40e0=a2=P80h4Pj00D0jE=50>AGAP3HDd@0f5=40<]@@0020:lm<P0508lY7@1b50`0LQ@<
064<1`1K30P00P1G3@X0101I4Q00EQ8A05HB4@1>30d2050@4@0504d=3P1B4140DPh?058>3`1B20T0
0P1I2@`01@1O1PP0K0P:06`82P224Q40WbDR0080]3D^00@0aDDl0;i6>02nASP0/4Ld0P2UBSD01@2h
K5@0[VaB0:5UB`2QID/0YFeD0080Uf5700D0Pe0c08]J>P2;FSX0R5Lf081>;@0208aF=00407m48P2e
MUD0]GIE0;=bE080TE4h00D0SU=106<_8P2?I5d0SfAM0<RSW@020;fJU0050<2MV@3=YZL0cJJW0:^2
QP1R>Cd00P1V?d80101=:bX0VGYg09UjM`2gV9<20;6CR`050;BAR`2nUHl0aiJB0<NFTP2=EU<00P25
BTH01@26C4P0PE19085@B@1kD4T0OE]B0080YHUn00@0YHYo0:B9OP2TRGh0Y8Il0P2/QGh01@2mQhD0
L2`[07dW9P1m9bH0WS`i0080VS</00D0WCTZ09@j8P2D>R80R3`H07To3@0209]b<P0408ea9`21L280
PG0R07ia:`80Rh9700D0U8eO09jKNP1iN6@0NGQT00h>0P0201LG3`0502HU800U91l09B@O028O6P0W
91l00P0S81/0100P7AP0@3dh040m>00e=2l201hM6005020Q6`0I61<08ahH02<N601IE4h00P0e<2X0
1@0T7aT0:RDQ02XU8@0V8Ad091lK00809R4M00@09B0L02`Y900/:B@0@D0k0P0S91h01@0I6QD06a/I
01lQ7P0O8Ah0828O0080[jn_;000o`0?ooooo`003Oooool6003o00050?odlP36Sh`0aXn<0:i7@03>
BD000P3FAcT0103LASP0fT8e0=Y2=@3K@cD20=i8>@050=Q4=P3JB3/0gD/n0=e;?P3NC3l00P3OC480
1@3IAC/0fTHl0=Y6?03IAC/0g4Dj00<0fD4f0P3H@3D01@3I@CH0fd<h0=]3>03H@3D0fT0f0080f3hb
00@0fCle0=a2=P3L@SH0fClc0P3RB3`01@3[DdH0iE530>1A@@3PDD40gU930080gUQ<00D0f5Q=0<a@
AP3<D4H0]Chf0:<b;00208hQ700408<G501k4Pl0Na8?07P@3`80M0`;00D0L0X807@<2`1m4a<0OA<C
084E5@0208dJ7@0509hV9`2^;Rd0[Rh]0<Q1?P3BA4000P3HBd80103?AS`0b4Xl0<Q:?02gB3L20:a;
>P050<EbH02/He80X5];0:1KB`2THE400P2KFDT01@2OGT`0Y6IA0:AVD@2aLeh0Wei:0080ZFQD00@0
Xf5;0;5`G02aL5`0[6eK0P2IGTh01@1g@cH0H34Y09I]I`2FKFL0[hZ40080[hV600D0]Y2?0<ZPY03:
X:@0REaS06Ll@`02060g>`0406I2@P31Wid0`InM0<6PV`80`9fG00D0`YVE0=f[ZP2bMG@0/WEd07La
;`0209A:A`0509MBC@2=E4d0SEA=06Pi<@1[A3d00P2`TXX0102/ShL0Zhj60:^>QP2^SHH20<>JU005
09mYI`1V8R40SSXh08hj>02L?cX00P2L>c801@2M@2l0V4@Z09Q4:P26?QP0QU4M0080XGTk00@0SW</
08Yh<02:N300P7Dc0P2FSE@01@2KU6P0Z:>308V6L`29QW<05Q@800805a@=00D0:BHQ02DR7@0U8Qd0
9B8M02HR7`0202@Q7004024P6`0c<Rd0<c8]03hm>@808B0L00D071/G018A300W91d09b@M05MBC002
04<o=P0501lJ500Q7QL08AhG02@Q700V8ah00P0R7aX0100N6a@0;BXS02dZ8`15ACd2028S7@05028S
7P0M7A/06adJ01/M6P0G6AH00P1XJ6H/003o00oooooo000=ooooo`H00?l000D0ooCb0<J?S036Sh`0
[TM00<i9@0020=I7>@040=a6>03J@SD0fT8e0=]3=@80gTPi00D0f4@f0=Y8>`3MBch0gD/n0=i<?`02
0=m<@P050=U5>`3JAS`0fTHl0=U5>`3LACX00`3I@CH20=Q0=@050=U1=P3K@cP0fd<h0=Q0=@3J@3H0
0P3H?S80103I?cD0g48f0=a2=P3I?c<20>98?0050>]CAP3UDD<0h5510>1A@@3NDT<00P3NF4`01@3H
F4d0c5160<a@AP2e?SH0Xc8/0080SR4L00@0PaLD07/B3`1k4Pl0N10?0P1d30/01@1`2PP0M0`;07dC
4`1m4a<0PADE0080SAXM00D0WRHW0:h^;@2^;Rd0b44n0=94@0020=Q;@P040<m6?038BS`0b4Xl0;M8
=`80[4/j00D0aG9P0:aSDP2PFd/0X5];0:AQD@0209]IB@0509mNC02TIU40Y6IA0;5cGP2OGTX00P2Y
J5@0102SHD/0/G1L0;5`G02/KE/209UNCP0507M3=P1P<BT0UVeW09I]I`2_RX@00P2_RHH01@2fT8l0
bZ2T0<ZPY029G6<0Ica30080H3Lk00@0IT920<6OW@31Wid0`J2K0P30WIL01@32VID0gJ^Z0;9eM02b
MG@0Mc4_0080U4Y700D0Ue9=08eDC@2=E4d0J3Ta06]4?@020;2BRP040:b?Q`2[SXH0Zhj60:j=QP80
`iZD00D0WfUW06HR8@2>>SP0SSXh09`o>P0209`k<P0509e0;`2HA2X0V4@Z08Hn6026DAd00P2QNC/0
102>Lb`0RWP`08Yh<020MC<209J=E00509^DJ02XXh<0RHIc08V6L`0F50P00P0G50d01@0Y9R409B8M
02DR7@0U8Qd09R8O0080924L00@08B0K03<b;@0c<Rd0?Sdi0P0Q81`01@0L6aL04Q4<02LT7@0W91d0
Ee9<0080@clf00D07aXD024N5`0Q7QL0924L02HS7P02028O6P0401hK500]:R<0;BXS04E5?@808R<M
00D08R<N01dM6`0K7AX06adJ01LI5P0206QXIR`00?l03oooool000gooooo1P00o`001@3nfmL0Y5mH
0:AOF02jBD40dTPn0080fDLj00@0g4Hh0=m5>@3OACT0gT@h0P3K@cD01@3PB3/0hDTl0>59?P3QBCh0
hTPl0080gTHi0`3NAS/01@3OAcX0gDDh0=e3=`3M@cL0fClc0080fd4e00D0gdDi0=]1=`3K@CL0fT0f
0=]1=@020=To<`040=e3=`3I?c<0fClc0=a3=@80hDPj00D0j5120>UA@`3XDT<0j5930>iKB`020>QF
B@050>UICP3YGE00jEe@0>iTF@3ZI5T00P3THEL0103QGUH0ddm:0==?BP3?CTP20<a;AP050<92?`2n
?S/0a4A30<A4@`3IEeL00P3GDU<01@3JD500hE5@0>5AD03SCd/0idm:0080gTU200@0edTo0<U7>@39
AcT0]dHf0P2/BcX01@38MFD0^6mP0:5LC@2QG4d0VeU;0080QD<e00D0R4Hh09=A@`2CDD<0YF=E09EC
A@0209MEA`0409EFA`2HFTd0V5Y=08Q@@`80/Gmd00D0FRhU07iGD02hThd0^9>=0:f:QP020;:<R`05
0;VATP2]P8D0[H2506Tl@`1`ATX00P1@:B`01026HV80ZhV70:^9Q`2XQh820;2;Q@050;^;R`3@UYD0
STI708i6A`23<c800P2NCDX01@2MDTd0TEA?095DC`1O;RL0TFYS0080`Z6J00@0^IbD0;ZMU@2jWID0
_ijG0P3>Yj801@1iATD0LC@c09=7A`2CAdL0VDQ40080VTPm00D0UDPf08m7;`2?Abl0P4@R095R=002
0:R5C@0409Mm@02?OCl0Sgdo08aoB080W9AS00D0XIUb0:bWR@2IUX<0VIJ301lM4@0201<@2@0502PU
800W91l09b@O02HS7P0W8b000P0Q81`0100U91l08b8M02<R7@0c<Rh203Th=P0501TH500;2PD0<BhW
034^9`1<BD800P19AC`01@0O6a807AXC01dJ4`0Q7QL08QlJ00807Q/F00@07AXC03Xj<P0j>S80?Slg
0P0Q8Q`01@0Q8Qd06a/I01TI5`0I6AL04a<A0080<30^00<0^[Zh003o0000o`00:@00o`0?ooooo`00
3Oooool4003o0080ooOe00D0gjZT09m8?`2OB3l0a4]00=I:?@020=Q6=`040=e7>03OACT0gdDi0>=9
?@80jE5400D0j5130>=9?@3L@SH0g48f0>96>P020=i4>0050>16>P3RB3`0hTPl0=i4>03SBCd00P3T
B3`0103RB3`0h4Li0>17>@3OAcT20>98?0050=i4>03QAc/0gdDi0=m5>@3OASP00P3NACL01@3PAcL0
hDPh0>58>03VCCd0iTln0080jeE400<0kEM60?5NCP3aGTh00`3]Fd`01@3^G4d0jea>0>iPDP3^H580
kEmA0080kF5D00D0kV5G0?=VG@3cIUd0k65J0=iEC`020>ENF`040?I^KP3aIfL0lFMW0>EFF080jeMG
00D0je=@0>E=B03PBd@0h4]40=A4>@020<Y6>@050;M6=P2[C3X0Zd`j0:iQC`2SHU000P2IGT`0102L
IE40VV=?09YSC`2OIeH209EMCP0509UQE02HH5<0VfEI09]UF@2EHE@00P2>GU801@1oDdX0YWif0:In
MP1S@3X0ZHR30080`InM00@0^iVG0<JPW`36X9l0f;2a0P2=HfL01@1S>Cd0HS/l05Hd<`1F=3<0]9FB
0080]YND00D0]iJA0;R@SP2hT8h0cING0;]fN@0207h];00409]3@P2OBTL0WdY709]@B`80OT<m00D0
HS<[0:^6OP2`ShH0/8n60;2BRP020;BFSP050;jMV02XPWl0Z89o06do?`27E5<00P2@EU@0102AEU00
UUaA09ILD@2BFT/208mLB@0508=G?02FLU00WH1H09f0F02DOE400P2AOU<01@2?PUP0W9=/09bCK02Z
XH80V99j0080][>R00@0@Clc00`;1P0<2`H08b8N0P0X9b<202@S7`808R4M00@09B@P01lP6`0O81/0
8R8P0P0c=2l01@0d<bh092@L02l/9@0_;2D0=C8[0080?3T`00D08QlF01hK4P0N6a805a@;01TI4@02
020P6004038a;00k?3H0>c`f02LX8P807b0J00D081lK024P700L6aL071/G01XI5@0201LF4P0502`]
:025QH<0QHF30:BVX`3Adm000P3[kNXU003o00oooooo000=ooooo`@00?l00P3ol>`01@2iMVh0ZTDk
0:Y5>`3>D4@0e4Hh0080g4Pj00@0fT@e0>Q@@`3XD4<0l5Q;0P3ZDTD01@3TC3l0fd<f0=i6>@3NAST0
h4Pk0080hDTl00D0hT`n0=i8>P3NB3X0hd]00>59?0020>18?@040>=;?P3OBC/0gdTk0>5;?@80h4Pm
00D0hd]00>59?P3QBC`0hDTl0>59>`020=m8=`050>=<>@3QC3P0hD`h0>9?>`3NCSH00P3NDCH0103X
G440kV990>iRB@3^HTT20>aPA`050>YNA@3^HT/0jEi70>UNA`3^HT/00P3[GTX01@3[GT`0k5m>0>aO
CP3[G4h0jE]?0080jeiE00@0nF]W0?Y[I`3jJfL0jeYG0P3]F5@01@3[Ddh0idi80=e6?`3MASl0e44g
0080bdDi00D0_DXh0:m>>`2_CS/0RS`V08m>>00208U?=`0408]E?@23CcL0Pdlg08YH?`80SUa500D0
QeM108EF@P2:GDX0RUe:08mVE00208]VE00508ASE027Ie`0QfML06a?A`2bUI400P2oX9d01030WY`0
cJJW0<fVY`39XJ8206PoA@0506e6B@1>;2/0RFYW08UZI`36ZJD00P2lWIX01@2mViT0binN0<^OWP3U
ZJ/0Uda@0080Pb/Z00@0YT]:0:5;BP2QBdX0Ve5>0P1M9R401@26Fe@0_IR@0;6@R@2aT8T0^9N@0080
^9FA00D0c:BR07aBD`1lDU<0IcLg089@C`0206Db;`04070m>@1X>2h0J3P^07E7>P80JCl_00D0HS`Y
079@=`1K?B40FcdQ06Q=;`0205Q18P0507UVB027N5/0QgQK07mcF@2DS7L00P2j]J80102IUhX071`D
01`L500F5A02028Q7@0502DT800W9R808B0L024P700R8Ad00P0M71P01@0R8Al0:2LS02PW8`0X9b80
<c<[0080>SLb00<0?3Tb03Tf;`0i=Rl00`0a;RD01@0W9ad0<c<[03Pg<P0h=c80>S/e00809RLQ00D0
8R<N01lP6`0O81/08R4M02HU8`0201dL6P04020O6`0G5Q@05aHD01<C4@80GemM00D0HF=P06a^J@25
QX40QHJ10:>TW`020<W:a@030>OWi@00o`000?l001l00?l03oooool000gooooo1000o`020?o`k005
0;UfKP2ZAC/0ZTDk0<i@A03DASP00P3LB3X0103JA3D0j5130>Q@@`3`F4/20>YBA@050>A<?`3K@cH0
gTHi0=i6>@3PB3/00P3QBC`01@3RC3h0gTPj0=i8>P3SBd00hDTl0080h4Pm00@0hd/n0=m9>`3OBC/0
hD/m0P3PB3d01@3SBd00hDTn0>59?03QBC`0hDTk0080gdPg00D0hd`i0>5<>03QC3P0hTlk0=i>=P02
0=iA=P040>QL@@3^HTT0kV990>iRB@80k61700D0jUi50>iRB`3YGTL0jEi70>iRB`020>]NBP050>]N
C03/Gdh0k5m>0>]LCP3YFdl00P3[GUD0103iJfL0nV]W0?Y[I`3[FUL20>eHE0050>]CCP3WCTP0gDHo
0=e6?`3D@CL00P3;ACT01@2mBSP0[dhk0:m>>`2:?2H0Sdhh0080RDlg00@0ReDm08=?=`23CcL0RUPo
0P2>G4D01@27Ed40QEI208YMBP2:GDX0SfID0080RfID00D0Q6=D08MWG027Ie`0K4m70;:ET@020;nP
W@040<2NW03=YZL0cJJW0<VQXP80J3m500D0KDI904h/:`29JVL0RFYW0<JYY@020;bMVP050;fKV@3;
Wih0binN0>FYZ`2GC5000P23:bX0102VBdX0XD]:0:5;BP2KDDh205dV8@0508IKE02mV900/I290;6@
R@2hUi000P2hUI401@3<Y:80O59C07aBD`1W=cL0PU1?0080IC8_00@0L3di06Ph;P1X>2h0MDLj0P1Y
?bl01@1R?2T0LU0g05/m8@1K?B40J4d_0080F44R00D0NFI808MhF`27N5/0Og=I09B<M`020;ZeXP04
09VGRP0L71@071`D01HE40808R4M00D09B@P02LV8P0Q81`08B0L028Q7@0201dL6005028Q7`0X9b<0
:2LS02PW8P0c<b/00P0j=c800`0l>C80>CH_03Tf;`03034^9@0502LW7@0c<b/0>3Lb03Pg<P0j>cD0
0P0V9b401@0R8ah07b0K01lP6`0R8Ad09RDS00807A`J00@081lK01LF500G5Q@04a<A0P1OGed01@1Q
Hf00K6iY08F6P@25QX40XjBO0080bL[500<0inOU003o0000o`007`00o`0?ooooo`003Oooool4003o
0080k/g800D0X5980;m@A@2oD4D0dDe10=U:?0020=]7>@040>A>@03[EDL0jeE70>eGB@80iDm100D0
gDTk0=i:?03QCd00hDm00=]<?P020=Y;?@050=e>@03LCCl0g4do0>5>A03SDD@00P3NBd40103NC3l0
h4i10>1>@@3PCT420>5=@`050=m;@@3QBT40gDHk0=e6>`3PBS`00P3PBST01@3OCST0h5@k0>1D>`3D
CBl0cDdZ0080ce4[00@0dEH]0=aQ>03LHCP0hFDo0P3XK4H01@3TJ4@0gf=10>1T@P3PI480hF910080
iFA400D0ifA60>iVC03^IT`0k65:0>aOB`020>iOC`040?9SE@3jIed0nVMM0>UFC080j55:00D0ie19
0>5:@@3MASd0gDHm0=I3>`020<e5>@050<M=?P2/AC80[4Db08Xd7@2/HTL00P2_K4l0102YK4d0S5@c
08aD<`2EH3h208aJ>@05085C<@21ES@0QF4o08EQ?`1oGSd00P1WCB`01@1_ESP0LUY2079J@P1I?c00
WX9g0080`j:M00@0a:6O0=Vb/`3I/[<0WgMh0P1S?4401@1S?d<0CRh_0;JHUP2fV9H0`ZBR0080_YnL
00D0`YbK0=RVY`3HYZL0d8j@07`/;`0209Di>P040:]=C@2RDE00XU5@088n>`80FbPT00D0[hJ20;jK
U`2fUI00]YF@0;bIU@020<VPWP050<6AT@1L:2X0G2PZ07Hk?@2ZL6h00P2<DTh0102GH5/0WVaU09i/
I@2HJF4208iRE`0508ILD02=IUL0OeY807mJB02DLEd00P1VAS401@24J5<0XXUc0::9L`1eHdd0Z9b6
0080]k2M00@0cLZi08F3M`25PgL071`D0P0E5Q001@0O81/0:BPT02DT800U92009B4N00809B8M00D0
8AdJ01dL5`0M71L07ahJ02HU800202`[9`0302l^:@0a<2/0<C0[00<0<S8Z00D0=3@/03@c;P0[;2H0
:b`V02HW8P02024R7@0301lO7@0J6QP06QXH00809R@U0P0K6a/0100P81h05ADE01DE5@0C4a4206i^
K00306m`J`1[K6H0MgM_0080MgM_0P1eMf`01@1nOgL0VIbC09VLT`2l_KL0hN;L0080mOKa6`00o`0?
ooooo`003Oooool3003o00040?ogm@31U8l0`IB?09]3>@80b4m400D0dDTm0=M8>P3RCT00hTi00>aF
A`020>mIBP050>QBA03RCT00hTi00>IDA@3PDD400P3LD440103EC3`0hEU;0>5IB`3[HE@20>QLC`05
0>]MD@3]Ge<0j5Y>0>QJCP3TETX00P3VF4`01@3UEd/0iEE<0>EEC03UED`0i5A90080he1600@0iUA7
0=m@?`3OD3l0i5U40P3HECT01@3NHd80ig=<0=EV>@3EIST0fFdn0080eFTj00D0f6`n0>9fB03RMTP0
i7M<0>1cB0020=Q[@0040>amD03GHcX0ef<j0>5[@`80ife800D0ifI60>QRA@3OEcd0geLm0>AI@P02
0>9E@@050=i??P3QCd00hDm00=m;?`3SC4400P3MASd0103LB3h0dTDk0=95>`3<C3l20<1<?@050:e8
=03<LUP0`6a@0<1/D02lL5000P2^ID@01@2[JDH0Velk09]O>`2QJdD0V6Q20080T6U200@0SFe707mU
@01oID00Pfa<0P20Je001@1YD3`0U7I[0<ZWX`3:Yj<0c:FV0080ejn`00D0LdY>06m8C@1_B4d0D2da
07YLG0020<b^[0040;nQW`35Xj80aJ>R0<ZRXP80h:j_00D0YVAX07DV:@2UC4h0YDa>0:I@D@0209mE
E005064U9020De00P5=@0<^UXP2iUiD00P2nViT01032VIL0fJVY0=VYZ@2LHFD206HT9P0508i8B032
NgT0/VmY0;9_J@2kNW@00P2[L6X01@2UK6D0XV]T0:9[I02eP7P0_HR00080/Gmd00@0[geb09a^G`2L
KUl0ZH9a0P2SPVl01@2CNVH0/Z6=0;J^V@2f[YT0dLjk0080h^3C00D0IVIN01@E400D5A005ADC01dL
6P0202HU8`0402`X9@0]:RD0;BXU02HS7P807a`G00D07A`H028Q7@0V9B409RDQ028Q7@0202HU8005
02@U7`0U9Ad09BDM02<S6`0O81X00P0Q8Qd0100U9B<08B4O024Q7`0M7A/201TI5`0501lM800Q7b80
7AdO01dM7`0V9RP00P0B4Q@01@0O7b40QhN708N7Q`1jNWP0LG1[0080P81f00@0Q8Ah07IfJP1fMVX0
M7IY0P1gNFh01@1bM6T0MgQ`092AR@2@THT0];F_0080emSC00<0k^k/003o0000o`005@00o`0?oooo
o`003Oooool3003o00040?ogm@31U8l0`IB?09]3>@80b4m400D0dDTm0=M8>P3RCT00hTi00>aFA`02
0>mIBP050>QBA03RCT00hTi00>IDA@3PDD400P3LD440103EC3`0hEU;0>5IB`3[HE@20>QLC`050>]M
D@3]Ge<0j5Y>0>QJCP3TETX00P3VF4`01@3UEd/0iEE<0>EEC03UED`0i5A90080he1600@0iUA70=m@
?`3OD3l0i5U40P3HECT01@3NHd80ig=<0=EV>@3EIST0fFdn0080eFTj00D0f6`n0>9fB03RMTP0i7M<
0>1cB0020=Q[@0040>amD03GHcX0ef<j0>5[@`80ife800D0ifI60>QRA@3OEcd0geLm0>AI@P020>9E
@@050=i??P3QCd00hDm00=m;?`3SC4400P3MASd0103LB3h0dTDk0=95>`3<C3l20<1<?@050:e8=03<
LUP0`6a@0<1/D02lL5000P2^ID@01@2[JDH0Velk09]O>`2QJdD0V6Q20080T6U200@0SFe707mU@01o
ID00Pfa<0P20Je001@1YD3`0U7I[0<ZWX`3:Yj<0c:FV0080ejn`00D0LdY>06m8C@1_B4d0D2da07YL
G0020<b^[0040;nQW`35Xj80aJ>R0<ZRXP80h:j_00D0YVAX07DV:@2UC4h0YDa>0:I@D@0209mEE005
064U9020De00P5=@0<^UXP2iUiD00P2nViT01032VIL0fJVY0=VYZ@2LHFD206HT9P0508i8B032NgT0
/VmY0;9_J@2kNW@00P2[L6X01@2UK6D0XV]T0:9[I02eP7P0_HR00080/Gmd00@0[geb09a^G`2LKUl0
ZH9a0P2SPVl01@2CNVH0/Z6=0;J^V@2f[YT0dLjk0080h^3C00D0IVIN01@E400D5A005ADC01dL6P02
02HU8`0402`X9@0]:RD0;BXU02HS7P807a`G00D07A`H028Q7@0V9B409RDQ028Q7@0202HU800502@U
7`0U9Ad09BDM02<S6`0O81X00P0Q8Qd0100U9B<08B4O024Q7`0M7A/201TI5`0501lM800Q7b807AdO
01dM7`0V9RP00P0B4Q@01@0O7b40QhN708N7Q`1jNWP0LG1[0080P81f00@0Q8Ah07IfJP1fMVX0M7IY
0P1gNFh01@1bM6T0MgQ`092AR@2@THT0];F_0080emSC00<0k^k/003o0000o`005@00o`0?ooooo`00
3Oooool3003o00040?cPg@2LHe`0W6=L0:A2=`80cDm100D0dTPk0=Y8>@3VD3l0iU0o0?5JB@020>]E
A0050>I@@@3YETH0jEI60>IGA`3RETD00P3YI5<0103jN6X0o7e^0?amKP3lN6/20?1XFP050>iTE`3b
IUL0m6QK0?AXF`3cIeX00P3eJf001@3bJ5d0lfIL0?=VG03bIE/0lFAJ0080kV5G00@0kV9E0>UPD03Y
H500iF1=0P3BESh01@3QL580nHiZ0=YeB`3JMD/0m99U0080li5T00D0kHaO0?6BI03aTV@0k91O0?FI
J0020?>EHP040?JHI03LO4T0g7a90>F1C`80gWE600D0iGI;0>EaBP3EGCP0eEdh0=QL>P020=9C<P05
0=IC=`3GC3D0ed`e0>9A@03QBcd00P3SC440103PC480f4Po0=Q8?`3EBd420=IDA`050=YOD03EHTl0
c5m:0<aOBP3<ITd00P3:J4d01@37K540bgYM0<]jG@33O5h0Zfi?0080[GYK00@0ZH9S08MXB`27J4/0
WX=X0P2HOVL01@23IUH0Wgmd0<fWY03=Yj@0g[Jg0080^i6E00D0HSLn06m8C@1_B4d0DRhb0:n?T002
0<b^[0040<FWY@37Z:D0ajRU0=J_/080e:>V00D0Nci308Y3A`2QEET0XEEI0:1HF`0208U=C@0505HV
902]Qh@0[HN40<^YY`2oWI/00P34WYd0103AX:<0f9fQ0=RMX@1k<ST208Le>@050:==C038L6`0/5eE
0;1ME@2mKfD00P2UFe801@2JDDX0W5I>09aFCP2hLVX0aX1h00<0XUiE0P2IFe001@2@Fd/0SF9A08eR
D@2SPVl0_ZVF0080^JjJ00@0blJc0??ai03clN@0[ZjV0P0a<Bl01@15ADL0:2HY01LE600G5AP081lM
0080<Rh[00<0<bl/02dY9P0]:BH00P0W8b0202@P7@0402<O700R8A`08R4L01lN6@8092DM00@08b@L
01/L5P0M7QT07AhI0`0R8R0301hN700501lM800R82<07alQ01lO8@0O82@00P0=3Q<01@1KG640XZ6V
0::QYP1lO7`0NWUd0080QXIl00@0RXYn0862M021PW@0PhAf0P20PWD01@1nP7<0NWa_07EgJP1eMfX0
LG=X0080JfeR00D0QXMo0::SV`2RXi/0alS20>GVh@0C003o00oooooo000=ooooo`<00?l000@0i<6m
08Y7?`2:Acl0/DTn0P3?CD001@3HBS`0fTLg0>iHA`3^F4L0l5U60080jE=200D0iDln0>YGA`3ZEdL0
iUM60>5EA0020?9]G0040?]iJ@3`LF80l75R0?UeJ080k6MH00<0kVIF0>]RDP3cIeX00P3cIeX20>iT
F@050?AZG`3cIU`0lfIL0?IZG@3dJUl00P3dJUd0103bJ5/0lf]M0?=[G@3cKUd20>maF`050>YfG@3f
QfT0j7eI0>QmF@3dS6D00P3jTV/01@3gTFT0o9]a0?bKL@3dUFT0o9ea0080nIY/00@0jXiM0>f?G03]
Se`0jXYH0P3[QeH01@3iSV80kGiC0>McC03WLd`0nH=M0080jW9?00D0oH1P0>USBP3YHdX0eTPd0>9>
@0020>=<@@040>1<@P3OC480gda20=a<@`80heI<00D0gE=80=mJB`3PGTh0h5i>0=AJA@020=AMA`05
0<iPB@3>JU80cVYB0<UaF@30MUd00P2_Le/01027Ed40V79M09QbG@38YI820<2PT@050;>AQ`2dShT0
eZj_0=J^[`3X^l000P2CI6`01@1aA4/0ISe306Hm@`1^BT`0d[2a0080c[2^00@0b:^W0<b_Z`3<[j/0
fKNf0P2mTiD01@1F92L0M3`o08Q=C`28CDl0QDm?0080H38b00D0HC/h0<Z[Z03:ZjP0aZVU0<:PW`02
0<^QX`040>N`]@2mMgl0_GMo07LR:@80XD9600D0[de:0:M6?`2I?cH0VClf09i7?P020:MDC0050:AD
B`2WEe00YeM@0:UJD`2XFE800P2MCTL0102/GEH0XUU@0:9ID02RHe@209=PC`050:J1K`34ZYT0^ZfJ
0;Z]VP33_Jd00P3Vh]L01@3Thmh0?3Xk03`j>`0o?T<0FeQO0080F5EL00@0?3Xm01XI5`0J6AL061LE
0P0W8b801@0`;2/0@3`k02TS8`0Y8b<0:2@Q00809bHR00D08b8M02<T7P0S91h08b@O01XJ600201`L
6P04028R8P0T92@092@T024Q8@808B4S00D0928W028Q9P0B4aP04Q<H00`<500200l?5`0508>3R`2[
Z[00ZjZ`08>3P`20OgX00P2<S880102<S800Rhan08^<OP28R7`208V;OP0508R:O@2:S7l0R8Ym08R:
O@23QGP00P1gNF`01@1iNg00MGM/07EgK01_LFH0Ngad0080V9VC00@0^[^f0=kOfP3NgmX0mOGc3@00
o`0?ooooo`003Oooool3003o00040>C1_@2:Acl0RTLo0;59?P80cde000D0f4Xl0=Y7=`3^F4L0kUQ7
0?1IAP020>UC@P050>E??P3ZEdL0jUM70>IGAP3QED@00P3bKE`0103kNFT0l75R0?1aHP3iMFP20>aW
F0030>iVEP3[HU80lfMJ0080lfMJ0P3^I5T01@3dJUl0lfIL0?=VG03fJUd0m6YO0080m6YM00@0lVQK
0?=[G@3cJed0lfiM0P3_LE/01@3ZMUd0mXMY0>QmF@3XOET0m8aU0080nY9[00D0mi5Y0?bKL@3lVg40
m9EY0?bML@020?VJK0040>Z>G@3]Se`0kHmL0>Z:F080jhMF00D0nHiR0>enD`3WLd`0ig=<0?V3G@02
0>YbC`050?f0H03YHdX0jF=:0=I8=03RCT000P3SC440103PC480gda20=m<@P3LC4<20>=FC0050=eC
B03OFT/0h5i>0>1NCP3DFTD00P3DGDL01@3>H4T0cVYB0<iZDP39LET0`7IM0080[g=K00@0QeM109Qb
G@2HLUd0b:FB0P30X9401@2cTHL0]8n90=J^[`3F[Zl0j;_00080TfA/00D0LDA;06Hm@`1V?D<0KTY<
0=:`/@020<j`[P040<R[Y`3<[j/0c:n[0=Vg]P80_I>E00D0ER@W07@l?`28CDl0R4e?08E?C`02060b
<P05064k>03:ZjP0bZ^X0<JYY@32X9l00P3;XJ<0103W/;D0_GMo0;egO`1g8RT20:52AP050:m=BP2W
ASl0VClf09To=P2NAch00P2WE4`01@2TE4/0YeM@0:MGD02YFU<0Z5UB0080WDi700@0[5eF0:9ID02R
FE00XV=D0P2CH4l01@2VPFl0a:ZI0;Z]VP2j[IX0`kf]0080i^;G00D0i>?N03`j>`0l>S/0?ci305]H
G`0205QEG00403`j?@0J6AL06QTG01PG5@809b<R00D0<2`[040l>`0Y8b<0:B<S02PT8@0202LV8P05
02<R7@0S91h08b@N02<T7`0J6QP00P0L71X0100R8R8092@T02@T900Q8B42024Q8`0502@R9`0R8BH0
4Q<H018C600<31@00P0?3aL01@23Ph/0ZjZ`0:^Z/023Ph<0P7mj0080S8b200@0S8b008^<OP2;S7h0
R8Ql0P29Rgh01@28RWd0RXao08R:O@28RWd0PhEh0080MgU/00D0NG]`07EgK01eMf`0Kg5V07]lM002
09RIT`040;Zk]P3NgmX0g]oJ0?Gel`d00?l03oooool000gooooo0`00o`00103J/J/0SdHm08m6?@2l
CD820=A>@P030=U:?03VD440keU80080keU80P3WCd401@3UCd00lE]<0?5KC03XEDD0jU]:0080kF1?
00@0kFAD0>MOC`3WGdl0jF5A0P3ZHU801@3XH500k6=C0?1TE@3`I5D0lFEH0080lFAJ00D0mFMM0?IV
F`3fIU/0l65C0?=UF@020?9TEP<0kf=D00D0kV9C0?5ZE`3aJUL0k6MD0>i]E`020>]]E0040>IZCP3^
LUH0kW9F0>]bE@80kWMI00D0jgQI0>ejF`3`PUl0l89O0?26G`020?nHL0050?nEKP3]P5T0kH1I0?B2
G@3]Me<00P3ZLU00103_M5D0jViB0>Y^DP3oQ6P20?A]E`050=U<>P3SDD80gTXn0=i:?P3OBd400P3R
CT@01@3LBCl0gTi30=i>@`3QDDH0g4do0080heI500@0gU910=]D@@3KE440fEY70P3?G4T01@3;IU@0
_6UG0:IQDP2VHE80LST^0080^hb400D0eZfW0=2YY03@ZJ@0b:2P0<^QX`020>Bg_P040=bZ/`1hA500
N4A@08=AG080Gc@k00D0YGj10=bl_@3B];80d[Bb0<bc[`020<fd/0050=Fg]@38ZJL0b:VW08IRHP1c
Cdl00P1cCD`0101WA480IdQ506M8A@2[Sh/20<bc[`050<N[Z03=ZJ/0fZ^a0=Z[/@3/[KH00P2GAe80
1@2>;cD0]DiA0;E>D@2_BDD0YT<m0080/eI>00@0]5]C0;EPF@2eH5T0Y55;0P2^GET01@2IB4@0^6QQ
0:mOF02_GeP0ZUYC0080We9:00D0VEE807To<@1i?c40U6UH0<^^W0020;j]V`040<:kZ`3HdLL0f=77
0?Cak080Ogf000D07Q/R03djA@1IEUl0FEIO065OI00208>1Q00505MEF00V92D09R@U02LU9P0T8R<0
0P0E4A80100U8B00;B`Z02d/:P0Y:2H202<S8@0502@V9@0P8B<07QlQ01hO8@0X:Bd00P0Y:Rh01@0K
720061TN01PI7P0Q82P05A<N0080<30l00@0CDmK02<S;`0S8bl0IVI`0P2a/;H01@2;Rh/0RHR308Z:
P02:RX00SXj20080TI>600D0T9:70864N@21Q7T0I6MN07ioM`0208>3N`0408F5O@1jNW80NWYb08^;
P@80S8b200D0Ph=g0863N01jO740NWaa06i_I`02071aJ@0508N8PP2XZJ@0Z:VT0=;Bd03`l>h02@00
o`0?ooooo`003Oooool01000o`00ooWc0?oil`3AYI`209I8?0050<1@A03BC400dTa00=]<?P3WDD<0
0P3bG4d0103ZE4<0iDdo0>E=?`3[DdD20>]EAP050>eGB03/FDT0lf5B0?=QDP3XFdX00P3/H4l01@3^
IED0iem?0>MOC`3RFTX0fU940080hEU;00@0hEM:0>5GC03QEd`0jEe@0P3ZG5001@3^H580kf5C0>iR
D`3^HU<0l6AE0080kV9C00D0lFEF0?1TE@3`I5D0lFEF0?=WEP020>iUDP040?1YE@3_IU<0kfIC0>mX
E080k6QC00D0jFMA0>MVD03TJ500i6Q@0>5ZC0020>9]C0050>aeE@3[LU<0jg9C0>Y_D03_LUH00P3_
Ke@0103[Je80j6YC0>QZD`3/JeD20>eVD`050>AKB@3YFdd0hE560>5AAP3UEDX00P3RDTL01@3OCd@0
hE560>5AAP3OCD00hDm20080hTi000@0hDm00>9CA@3RDdD0fE100P3FEdP01@3=G4`0bFAH09m8?`2O
B3l0T4E00080iZFS00D0jZj^0>FZ[P3UZZh0j:fc0>jc^@020?job0040<F3S@1o>dH0Oc]608m=E`80
KC@k00D0fZN/0>g1`P3Q^KT0hKVi0>:l^`020=jj^P050=bh^03I]KD0fKFe0<jZZP3>[:/00P38YZD0
1031XZ00bJ^Y0<V[Z@3B];820=>e/`050=Bb/`3I[k<0lk[30?>j``3RU:400P26:C@01@2dAdd0_Ta<
0;i<C02oDTd0a5aC0080aF9L00@0bfaV0<9WHP32If80ZU5;0P2mIF401@2cGUT0_VUT0;UTG@2iI5d0
dWid0080/65D00D0[6=D08=6<`23AS<0YGQQ0<naV@020<BbW0040<BlZ@3:a;P0b/Bh0>KSgP80b/S9
00D0:bP_03Hc?P11?TT0@Ci903hkA0020;2]]0050=?Be`1/K6h0K6a^07AbM@1=Bdh00P1HEUL01014
@T<0=SHf03Hf=P0L7Al202<V:`0502@Y;`0O8b`07B4Z01dQ:P0N8BX00P0I72D01@0];CL04Q8L018B
700P7bd08B0^0080=cU600@0EEMT05UKJ01IFfP0Lg=m0P2YZ:d01@2@Shd0TXn808n=P@2?SH40TI:4
0080TI>600D0VifB07]nM@1kOWD0@4<l05]LEP0205]JE@0404i=B01?CTT0Cdi905MGC`80H61F00D0
LW9X08>5NP1iNg00NG]`0863N00207anL`05079cJ`1YJV80JFYR065PG01gMW800P2=S8P00`3>cLT0
0?l0003o0004003o00oooooo000=ooooo`04003o003omo80ooOb0<VIS`80X4i200D0`5120=9=?P3B
CCh0fd`n0>mKC@020>iHB@040>]EAP3UCCl0iDdo0>mGB@80k5I800D0kUQ:0?EOD@3^FT`0kUY<0>MH
B0020>ePC`050?E/G03nMVP0oWIX0?QdI@3gLfH00P3eLF@0103bKV40kVYM0>iZG@3UHE820>MRD`05
0>UQD`3RFT`0hUY>0>9JCP3TG5000P3WGe<01@3YGe80kF5B0>eQDP3]HE80kV9A0080kVEC00@0kFAB
0?9VE@3bIUD0lFED0P3bIUD0103bJEL0kfID0?=/F03cK5P30>aXD@050>YVC`3[Ie00jfM@0>UUD03X
I4l00`3`K5L20>iYEP050>iYF03`J5X0l6QJ0?M_H@3dK5h00P3cJE`0103`I5L0k61C0>aPD`3VFTd2
0>9FB@050>IHC03QDDH0h4e30>1=@`3RCdD00P3PCD<01@3PDTH0f5120=Q@@P3HETT0dUU@0080/d<o
00@0ZD500;IFF02fEUP0]e]P0P2hGF@01@2lHV/0afef0=9gP03BMh00ZTeG0080X4=;00D0[U=J08Le
>`27=C/0dXF;0>^TZP020>NV[0040>NZ[`3Y[[@0jJjd0>^b^080k;Fj00D0j[Jj0?2n`@3Z_;h0j[bn
0>^o`0020>_1`P050>Rn`03Y_<40jKc10>^j`03`]l000P3o^L@0102lGfX0Vb`e09//=@3:Ce820<a?
C@050<U?BP34CdP0fFUU0=UYI@3JLFd00P3=If<01@2aD4X0aVMS0<IWH`3=L6T0_fEM0080`FUO00@0
kYJ80;5PB`2aH4/0/fU>0P2BES@01@2gRfH0ck6=0<fmW03=_I`0blBX0080`kf]00D0dm370>[Zj03Z
j^P0FUUN02h]=@0203hlA`0403<a?01hMgl0N7Mo0>g/lP80GUeR00D0>3Hi04Q6B@2k^KX0^kVj0;^k
_@0205eNH`0505IJH`1EFfT0EE]Y04Q?H@16CV400P12BUd0100Q:3X0;2m002`_@02VZ;L202d_?005
02`]?`0`<D<0<SE4038eA00Q9C400P0a<d001@1FEV00WIfO09fMW`2QX9`0UiB=0080UiF900@0U9F7
09>ER02CUHP0WZ2E0P1lOGD01@1EEU00MWE`071_J`1`Kf/0C4]70080CTm:00D0Ce1:02DV800U9R00
GEiF04Q9@@0203Tk<00407j0M@24QW/0Q8Ik07eoM080Ogmg00D0Ogae07UdL01<Ad40C4M1059?BP02
0>CSh@@00?l03oooool000gooooo00@00?l00?oglP3omo80bIV?0P2PCT801@30D480dTdn0=9=?P3K
C3h0ke]=0080kUQ900@0jeE60>E=?`3UCCl0keM90P3/ETP01@3^F4X0mEmA0>iJC03^FT`0ieQ80080
kF1?00D0mFaL0?ifJ03nMVP0n7AU0?McIP020?EaI0040?9^H@3^JUd0kVYM0>EQDP80if9C00D0jF5C
0>9JC03RFTh0hUY>0>ALD0020>MOD`050>UODP3]HE80kF5B0>eQDP3^HU400P3^IE<0103]I580lVIE
0?9VE@3aIE@20?9VE@040?9YE`3_IU@0lfaH0?=/F0<0k6QA00D0jVI?0>]WD03[Ie00jFE@0>QTC`03
0?1/E`80kVUF00D0kVUH0?1XFP3`J5X0mfmQ0?A/GP020?=YG0040?1TE`3/H5<0k61C0>IJC@80hUI9
00D0iUQ<0>5AAP3PCD<0h4e30>9?A@020>1=@`050>1BAP3HD480f5120=QFB@3BFE000P2c@cl0102Y
@D00]UIH0;IFF02gFf020;QMI0050;aRJ`37KGH0dWN00=9gP02ZCEL00P2P@d/01@2^DeX0QcDk08Le
>`3BQH/0jjBZ0080ijJ/00@0ijZ_0>V^]03Y[[@0jk:h0P3/]KX01@3Z][X0l;k10>Zl_P3Z_;h0jko0
0080jl7200D0j;k00>Vl`@3Y_<40jk[00?2g`0020?nia0040;aOJP2K;3D0Vb`e0<Y?DP80c4m=00D0
bDm:0<A?B03IJFD0fFUU0=YaK@020<eWH`050;5@BP36If<0aVMS0<e`J@2oIEd00P31JEl0103^UXP0
/F1;0;5PB`2cJDh2099F=0050;N;IP3?/Hd0cKfL0<fmW03;a:P00P33_Jd01@3Cd<L0j^[X0>[Zj01J
FEh0;Rde0080?Sa700@0<c4l07QgO`1hMgl0kNcb0P1NGF801@0h=ST0B4I90;^i^P2k^KX0^k^m0080
GEiS00D0EUYS05EKJ@1EFfT0B4mQ04I>H@02049:G@04024X>P0/;d00;2m00:JX]`80;Bll00D0;2do
030a@`0b=D@0<SE4024U<@02034c@00505IFH02MWIl0WIfO0:6PW02GU8d00P2GUHT0102DUHL0TiF8
09>ER02NX9D207amM@0505EFD01fMG00L6m[071_J`1<BdL00P1>CdX01@1?D4X09BHP02DV801MGUH0
B4U10080>C/`00@0OX1e08B6N`24QW/0OGmd0P1oOgL01@1oO7D0NGA`04a7@@1<Ad40DTm:0080i>?Q
1000o`0?ooooo`003Oooool01000o`00ooGa0?oel@31Rh420:MAA0050<EAA03BCCh0dTdn0>=DAP3_
Fdd00P3`FT/0103VD440jUA50>YDA@3^F4T20>eGB@050?5KC@3cG540lEY?0?5JC`3^G4d00P3_H500
1@3[Ge00kF=F0>eSEP3_JU/0jfMH0080kf]N00@0lfmR0?9`H03bL600mGAQ0P3dLf001@3fMF80mG9P
0?5]GP3aKEh0m71Q0080lFaM00D0k6AD0>QPD03XH500kFAB0>YQC`020>QOC@040>MNC03YGDh0jEe>
0>UMCP80ie]<00@0jUi=0>eQD03cIeH0lfMF0`3bIe@0103aIU<0lVIE0?9VE@3bIUD30?=ZF0040?M^
G03bJET0lVUI0?5YF@80lVQK00D0m6aP0?E]H@3aJEd0lFUM0?9XF`020?AZG@050>mUF03dJUd0m6YM
0>iTE`3dJ5/00P3]GeD0103XFU00iUQ>0>IHCP3QDdT20>9DBP050=]AAP3IDdX0cDa70<e<A`39CD/0
0P32Bdd01@2mBTl0_TmE0;i?E@2jCE80/dI<0080[d1700@0[Ci40;mAE02oDE@0b5]N0P2bBdh01@2Z
BT`0ZTiC0:YCF@2ZDeT0/UeT0080/5mU00D0[f1V0;=VK02cIV`0^Vmd0;ifNP020<AoPP040<b:S03C
TI<0di6C0=JEV@80gIZQ00D0jZ>[0?6Q[03AMWl0dGIo09l`=`020<95B@050=9=CP3BBdL0dT]70=QE
C@33A3d00P3?E4l0103BG5P0df1K0==PF`3<GEH20>9eL0050=YbJ@3FLFD0dG9P0=5bH03ANUl00P2e
ID001@33Oe00TU/U099K9@2YP4P0bZmj0080e/RK00@0e<jZ0<o=]P3?cKH0c<c00P3Wj><01@2>Si40
92<[04U7DP19Ae80?3Y70080ATA?00D0g=_Q0;2^/`2`[[<0G5YM04m=D00209nMWP040>_[k@1]KW<0
KFic02HZ<`808BLg00D082Pk02D`A00d?eD0=3mE03Y0F00203LlDP050;o2d`0m@540?D1A02DV>P0Y
;3l00P2OYKD0101ZKG`06A/X01TK:00Y:C<2071^L@050;>_[02VXi`0XInC0:6OT`2NWY800P2RXYH0
1@2[[J80LW=[079cJ`1QH5/0QhJ10080P7mk00@0Q8F008Z;QP2:RhH0S8f80P1fMg401@22Pgd0EEA?
04m@B01?D4P0RHV10080S8b400D0Q8Al081mMP20OGH0PWUd08EjMP0207aaJ`0303dd;`33_[/0`kjk
00@00?l03oooool000gooooo00@00?l00?oek`3omNl0^Gec0P2/CT801@3<E4H0ede00=M=@03WEDP0
lUa>0080j59300@0ie520>eGB03]EdP0jEI60P3^FT`01@3cGDl0leaA0>eFB`3]ET/0lee?0080lemA
00D0kEi>0>mRD@3_HU40kV9A0>mVE0020>UQD@040>UTD`3WI500ifA@0>=RC@80j6MA00@0i6I?0>]Z
E03XIe40j6MA0`3^KEL01@3_KEL0lW1J0?9`FP3aKEP0lfmJ00<0lVeJ0P3`J5P00`3]I5@0jF1@0>UP
D0020>ELC080iEa:00@0i5Q70>YMC03ZGD`0jE]=0P3ZG4h01@3_HE<0k61A0?5UE03aIE@0lVIE0080
m6QG00D0lfYJ0?EYG03eJE`0l6II0>mUF0020?=WFP040?9VF@3dJ5/0m6QK0?5WFP80mVaO00D0m6]K
0?5YF`3`JUh0l6YN0>aVFP020>aSF@050>MOD`3PDdT0h5=90>IHCP3QDdT00P3QE4/0103MEU00fEQC
0=UHD`3JGU`20=]SHP050=QTI03DH600deeM0==MG@3BG5`00P3AFEX01@3BG5X0ce]K0<mKF`39EeH0
a5IE0080`UIF00@0`eUK0;Y@DP2jD580]4a=0P2gCe001@2dCDh0[4Q80:e9B`2]BD/0[de>0080[DY=
00D0[4U>0:i9C`2^BDl0[DE<0;93BP020:lh?P040<4o@@3FCTh0eTi>0=Q=B080f4]400D0fDm50=I=
A@3BBdD0dT]50=E@B`020=MDC0050=YJD@3RIU`0hVIL0>9ZG03KJeL00P3AJT/01032JS`0_gDh0;me
>02VK2<2081E1P050;>D@P30[F40f]2C0=[@T`3MfJ`00P3Ge[X01@3@d/@0h>;M0>3Rg@2o`l@09bL_
0080E59O00@0BdUG03Da?`0e<Cl0ZjR_0P3`jo401@3Sg^80e];C0<c7b`3<al/0jnW/0080f]WN00D0
R8^@061TK@1PI6d0A4YF02Pa@P0201hV?@0403e2G`1>DVd0CU9]0:N/_`80L7J600D05AP[02H[?P2;
TJ40Ri6Q07QkRP0201XL:@0502DU;`0h=S/0>3Hk09:>S@2`[JP00P2VXiX0102UYI/0Y:JK0:BVV`2Y
Zj02079cJ`0507MhLP1RHed0I6EP06AUH01ZJVP00P1VIf801@1dMG00RHR408V8Q02KVYH0VYJC0080
Ph9m00@0RXN209VFT@2IUY40VIB@0P2HSX`01@2HR8P0TWim09V4P@2IQ840HDi:0080V8f;1000o`0?
ooooo`003Oooool01000o`00ooG_0?oek`2iOG<20:a>@P050<aDAP3GCD00ede00>MEB03bG4h00P3X
DT<0103WDD80kEM80>eGB03YETH20>iJC0050?=MC`3cG540kEI;0>eFB`3cGDl00P3cGe401@3]GTh0
kf9A0>mRD@3^HU40kfID0080jF5A00@0jFAC0>MTD03WI500hf9=0P3XIe40103TITl0jfYD0>QWD@3X
Ie430>i]E`050>m]E`3bL5X0lW1J0?5]F03cKeX00`3bKEX20?1XF0030>eTE03YH500jF1@0080iEa<
0P3UG4X0103TF4L0jUe<0>YMC03YFdd20>YLCP050>mQD`3/H540lFED0?5UE03bIUD00P3dJ5L01@3c
JUX0mFUL0?EYG03`IUT0kfEH0080lfMJ00@0lVII0?AXF`3dJ5/0lFMJ0P3fK5l01@3dJe/0lFUK0?1Z
GP3`JUh0k6IJ0080k6=I00D0iemC0>1CB@3PDdT0iUQ>0>5CB@020>5DB`040=eFD03IF5<0fEQC0=YN
G080ff=R00D0f6AT0=APH03CGEd0deeM0=9LG0020=5IFP050=9LFP3?Fe/0ce]K0<UGEP34EUD00P32
EUH01033FE/0^U1B0;Y@DP2dC4d20;M?D0050;A=CP2/B4P0[DU;0:e9B`2_CDh00P2]BTd01@2/BDh0
[TU?0:i9C`2]AD`0/T=:0080[cPn00@0`Cm10=I>CP3FCTh0f4e80P3HBd@01@3ICdD0eTe50=9;A@3B
BdD0eE1;0080eeA<00D0fUYA0>9VG03RIU`0hVYL0=][E`020=5ZB`040<9Z?02oMCP0_gDh0:I/8`80
P5D600D0/iA20<2]H@3Jd9<0f]2C0=gI[0020=OF^P050=3Ba03Ph]d0h>;M0;o3a00W9bl00P1DDUl0
101;BEL0=C4o03Da?`2[Z:l20?3[l@050>?NhP3Fd]<0c<O;0<c7b`3[jN`00P3JfMh01@28Ri00H6A]
061TK@14BUH0:35200807RHm00@0?D9O04iBK@1>DVd0Yjbo0P1`MXH01@0E62/09R/n08^AX@2;TJ40
N7^:00806Q`Y00D09BD_03Pf>`0h=S/0TXj=0;2]Z0020:JSVP040:FUV`2TYY/0Y:JK0:V[X080LW=[
00D0MgQb069SG@1TIF00I6EP06YZJ00206IWHP0507AeL029R8@0RHR409^JUP2JUY<00P23PWd0102:
Qh80VIJA09VFT@2IU90209R>S00509R8R02BOWd0VHB109V4P@1QCTX00P2HSH/4003o00oooooo000=
ooooo`04003o003ok^X0onkZ0;9_I`80]E1600D0cDm30=iBA@3NDTD0kUY>0>mIB`020>QBA0040>E?
@03`GDd0l5e=0>YGA`80ke]=00D0mV9D0>eFB`3cGDl0lee?0?1LCP020?9QD0050?5RD@3^HDl0kV5?
0>aTCP3[I4h00P3XITh0103WIdh0if]?0>M[C`3PJD/20>1[BP050=e[B@3PKT`0gF]90=e[B@3QKTl0
0P3NJd`01@3QJdl0hFU>0>5YCP3VKE80iFU?0080iVYB00@0jF]E0>i]FP3^KEX0lVeL0P3cJed01@3f
KUh0nW5Q0?A[F`3dJe/0m6MF0080lfIE00D0l69D0>YLCP3ZG4h0jE]=0>YLCP020>EHA`040>]OCP3S
EdH0heM60>MKC080jUiA00D0j5a?0>]ODP3[Ge80jemB0>aPD`020>mSEP050>iTF@3^IUX0kVIJ0>eX
F@3^JUd00P3VIUT0103YJE`0ngU/0?]iK03gLFH20>ePEP050>]KD03YET`0he=80>=CB03LDTP00P3J
Edl01@3KHUX0hG1Z0>5`JP3ML6/0gG5^0080gg9_00@0ffi[0=e]J`3MKF/0fVQW0P3IIV<01@3KJ6D0
fFQT0=UYI@3IJFD0efMU0080eF=R00@0df5P0=9PG`3BH5l0eFEQ0`3@H5h0103?Geh0d5eP0=1MH03;
F5/20<UEF0050<QAD`39C500e59D0=ABE03IDe000P3FCDL01@3JCdP0eTa20=I<@P3KDDL0ddTo0080
gE1900@0ge990=a?A@3LCdD0gE=80P3JDTH01@3KFDT0dUY20<QN=`38GSL0]E`T0080ch]000D0eJA8
0;nM>`2oWC/0ajm;0<:cEP020=S@Q`040>;OZP3NgKh0g]fn0=WJbP80g=gH00D0j>W[055AF@0f=440
=SA105ECH@0204Q4DP05081mQP3bl?D0l_3e0??^lP2IU9P00P1]J6`0102b[K40k^c_0>k/k`3Ui^X2
0=oRi`050=GIhP3?eN<0FF1c05UPL`0a=E000P1DEG401@24QiX0c<oN0<c?gP13AUD061/Z00808bLc
00@09BLc01TI9@0I6BD08B0X0P0I5a`01@1TH5l0^KFb0:bYXP2/ZJ80ZZZR0080Z:ZO00D0ZJZR08>4
O023Q7`0M7=^06IWH@0208n>RP04079cKP1@DD`0D55<055@C080EeIB00D0JfMT07A`K@1LF5D0G5QE
06UUHP020:2HUP0509Z>SP2[UiP0ZiNH0;VKW@2oVid00P3>Z:L0102VQ880Nf=O07]SG`3ijnP3003o
00oooooo000=ooooo`04003o003niN00o^GP0:mVG`80^4e300D0dTm50>EEBP3UEDX0lEeA0>mGBP02
0>9<?P040>mIB`3/F4X0k5Q:0>eIB`80lf9A00D0l5m>0>mKC@3aGe00lEm@0>eNC@020>mRCP050>YR
C03ZITd0jVI=0>MWBP3QJ4T00P3RKDX0103OLT/0h7I<0>1fC03JMDT20=emC@050=YkB`3FNTT0dgM8
0==gB03IO5400P3JNU801@3JN5<0g7QD0=ahE03NMED0gW=C0080hG9F00@0gfeB0>A/E03TK5@0iFMA
0P3XIE<01@3]IED0kVEE0?AXE`3dJ5L0kf9A0080lfAD00D0mFQG0?MYF`3gJE/0mVYK0?=WF0020?=W
EP040?5UE03bIUL0lVIG0?9YF@<0k69E00@0jV1C0>EKCP3UFdh0iE]@0P3WGe<01@3UGe@0ge]?0=mK
C`3SHeP0hfEI0080gVAI00@0hFML0?YjL@3jNW40lVeT0P3`IU/01@3]GE80k5Y=0>9DAP3RE4H0eU95
0080ceU;00D0^E560:e@B02]D4P0/eiI0;ASG`020;EQG`040;eWIP35JfX0aF]Z0<Y/K080cF]Z00D0
eW9`0=ihM03KMG40fgEa0>1jMP020=ifL`050>1iM03LMG00g7E`0=edL03JLFd00P3HK6T0103JKFX0
ff]Z0=][JP3KJFP20=aXJ0050=aVI03NI6<0g61N0=aPGP3LGEL00P3IF5801@3LG5<0fEI<0=UFC03H
DdX0gEM>0080gE9;00@0h5=90>1@A@3PD4D0ge530P3PE4L01@3KET<0deLm0<YN=`3:GSL0[eTN0080
c8Xl00D0jKeJ0=ZnD03J_U00e<9B0=76G@020=WCO`040>STY`3XiL80j>G20>7PcP80h=oJ00D0m?Cf
09ZIX@0P7R/081h[04E3D@0205ECH@0505UGHP3Mg>80gMcR0=SFf`1GEEX00P1UHfP01023PHH0jn_]
0>_[k@3]kNl20>KWj`050>?Vj`3enOl0UiZY09NJZ@0S93T00P18B6001@1YJ7X0inKd0>OVm038a]40
PX690080FUUO00@0A4=802XY;P0Z:Bh06QPM0P0Y9bP01@2BTHl0_[Zg0;>`Z`2c/:/0/;2X0080[ZjV
00D0Zj^S0:RXX02XZ:00XYnH09jNUP020:^XX@040:2PV02FUXh0UYJ>08n>R@80P7mk00D0HF1L04i=
B01=C4L0CDa705iIEP0209fAT@0509j5R02[Qh/0ZhN;0=^V[03_/kD00P3f^KP01033S8T0LDQ20758
@P3Wc/T3003o00oooooo000=ooooo`04003o003niN00o^GP0:mVG`80^4e300D0dTm50>EEBP3UEDX0
lEeA0>mGBP020>9<?P040>mIB`3/F4X0k5Q:0>eIB`80lf9A00D0l5m>0>mKC@3aGe00lEm@0>eNC@02
0>mRCP050>YRC03ZITd0jVI=0>MWBP3QJ4T00P3RKDX0103OLT/0h7I<0>1fC03JMDT20=emC@050=Yk
B`3FNTT0dgM80==gB03IO5400P3JNU801@3JN5<0g7QD0=ahE03NMED0gW=C0080hG9F00@0gfeB0>A/
E03TK5@0iFMA0P3XIE<01@3]IED0kVEE0?AXE`3dJ5L0kf9A0080lfAD00D0mFQG0?MYF`3gJE/0mVYK
0?=WF0020?=WEP040?5UE03bIUL0lVIG0?9YF@<0k69E00@0jV1C0>EKCP3UFdh0iE]@0P3WGe<01@3U
Ge@0ge]?0=mKC`3SHeP0hfEI0080gVAI00@0hFML0?YjL@3jNW40lVeT0P3`IU/01@3]GE80k5Y=0>9D
AP3RE4H0eU950080ceU;00D0^E560:e@B02]D4P0/eiI0;ASG`020;EQG`040;eWIP35JfX0aF]Z0<Y/
K080cF]Z00D0eW9`0=ihM03KMG40fgEa0>1jMP020=ifL`050>1iM03LMG00g7E`0=edL03JLFd00P3H
K6T0103JKFX0ff]Z0=][JP3KJFP20=aXJ0050=aVI03NI6<0g61N0=aPGP3LGEL00P3IF5801@3LG5<0
fEI<0=UFC03HDdX0gEM>0080gE9;00@0h5=90>1@A@3PD4D0ge530P3PE4L01@3KET<0deLm0<YN=`3:
GSL0[eTN0080c8Xl00D0jKeJ0=ZnD03J_U00e<9B0=76G@020=WCO`040>STY`3XiL80j>G20>7PcP80
h=oJ00D0m?Cf09ZIX@0P7R/081h[04E3D@0205ECH@0505UGHP3Mg>80gMcR0=SFf`1GEEX00P1UHfP0
1023PHH0jn_]0>_[k@3]kNl20>KWj`050>?Vj`3enOl0UiZY09NJZ@0S93T00P18B6001@1YJ7X0inKd
0>OVm038a]40PX690080FUUO00@0A4=802XY;P0Z:Bh06QPM0P0Y9bP01@2BTHl0_[Zg0;>`Z`2c/:/0
/;2X0080[ZjV00D0Zj^S0:RXX02XZ:00XYnH09jNUP020:^XX@040:2PV02FUXh0UYJ>08n>R@80P7mk
00D0HF1L04i=B01=C4L0CDa705iIEP0209fAT@0509j5R02[Qh/0ZhN;0=^V[03_/kD00P3f^KP01033
S8T0LDQ20758@P3Wc/T3003o00oooooo000=ooooo`04003o003hg=P0n=cH0:iSG@80`55800D0eU58
0>EEBP3UEDX0lUiD0>QAAP020>I@@P040>mIB`3ZETP0jUI80>mKC@80lf9A00D0k5e<0>]LC03`He40
l6=A0>aTCP020>ITBP050>EZB`3QK4T0hFa90=ibC03HMD`00P3BMD`0103BNe00cgiA0<mnD@3<Oe42
0<QnC`050=69F@3:PeD0`WiA0<9nD@36OUH00P36OEX01@37O5`0aWMH0<IgF038M5P0ag5F0080bg5I
00@0bfaF0<mXE@3?J5D0gVmL0P3UKE`01@3XJEP0jFAC0>]TD@3[I540l6EB0080kF1>0`3aI5<01@3_
HE<0kV9C0>mSDP3_He80lVIE0080l6AE00D0lVIG0?AXF`3dJ5/0mFUL0?Q/G`020?AZG@040?AZG`3c
KF40lfeQ0>aZG@80i6QN00D0h6]Q0=e]HP34F4h0a5Q>0;M8?`020=MPFP050>Y[I03]Ieh0kFMN0>UL
DP3/GDl00P3UG4`0103IFT/0cf1?0<mPC`2?<b@2078V6@05074a:01/<Bd0JRh]06X^;@1`<S<00P1j
>3T01@1j=3@0RT0o08Y0?`2BA480Vda80080We1<00@0X4m<0:UHE02YF5@0/5eG0P2dHE/01@2nJF@0
a6aX0<YaK@3:LFd0cgA_0080dW=a00D0dFm/0=YgLP3JMg80ggUe0=acL0020=ibK`040=Y_J@3ML6T0
gG1Y0>=dK@80gFaT00D0gfQR0>AWH@3YIF00jFEP0>MNEP020>1CB@050>9FB@3KDD@0fe540=YHB03C
G4@00P3>J480102mK3L0^W/d0;Yk=03^`fL20>?8G`050=O5F@3Hc6P0h=V80>3IR03AcI000P3Gdk00
1@3PgLh0hN3L0>7Pg03`ko@0g]cW0080@3i;00@0<c1104M4E@17A5D0CDUG0P2g];d01@3HeM`0?ce2
03Pc>P0h<cX0SXV?0080l_3c00D0j^S[0>KVj03Vi^P0h^?U0>kamP020<G8d@0402LX>P10?U@0@3iD
04E2E@80_kg;00D0jNK_0=GCeP38a/L0b<K70;^i^P020:ZXZ`0509RFU`2XYjD0Z:NU0<;1_`2o^kP0
0P2k]k@0102d/jh0]kJa0;Nf/@2f/jh20;>`Z`050;6^Y`2^Zj@0ZZNP0:ZWX02XYIh00P2YZJ401@2V
YYh0Z:NR0:RWXP2LViL0TI2;0080R8N200@0OGEc09N4QP2GQ8H0ZXN=0P2fPHT01@3<PhX0f8>80<ih
N@3>N7T0ZeeI0080RTm900@0cZVQ003o0000o`000?l03oooool000gooooo00@00?l00?7Dd03ae=00
ZUeE0P32DdP01@3GDTT0ieM<0>MGC03bGU@0j5A80080j5A600@0jeM90>mKC@3_Fdd0lEe?0P3dHU<0
1@3VFDP0kFAA0>APB@3TH4T0iVY>0080g6Y600D0gG=90=QiB`3HND/0c7Y:0<R2D@020<64F0040;j7
H031Sf`0`Hm/0<2?K`80`YAc00D0a9Eg0<fNPP3J[980fZbB0>BdWP020>>cW`050=^ZV@3W/jD0ik>U
0>ZaYP3//:H00P3][J@0103_Zj80iijG0>NNU`3EPGH20<eYF@050=m`G@3ZLE`0jF]D0>U[E03WHd`0
0P3]IDl01@3`He40l6=B0?1SDP3aI5<0k5m>0080lF=E00@0kf1B0?9SE@3bHeD0lF9D0`3aHeD0103_
HE<0kf=D0>mSE03^HUD20>YTF0050>AYFP3MKF40gFeQ0=EcJ03;LFT00P2RBd@0101l8Ah0Vc<b09/c
<P37De<20>MXHP050>eTG03YG580j61D0>QPE03QHe@00P3<HE401@22;al0FQ/<05XK301F9Q`0C2DN
0080BRLU00@0BRHV04lX:@1?:2T0E2X/0P1J;2h01@1N;Rh0FRXX05l_:`1O;b/0HC0/0080HBh[00D0
JcPd06@a;@1T<Bd0M3li07<l=`0207Hk=`0407e0>`22@Cl0PT4o088n>`80STM500<0U4Y709Q=BP2I
BdL00P2IBdL20:9CC`050:mKF@2`EUD0/5IE0;IGE@37GU/00P3CGE/0103KFeP0eU5<0=IAC03FDDX2
0=1AB0050<YDAP35G4T0aVaA0<I/D@2oMDh00P2`M4001@3Q]W40ilQf0>O8MP3Mag40fLYg0080l>NR
00@0/J]i07ijG`1nNUl0R8Ij0P2FUYH01@2/[;@0_ko;05IEI@1FEFD0?Ca>0080@SmB00D0ACi@08^5
T`2;QI<0mNoi0;^f_@020:JOYP040>;KhP3ajnl0lN__0>_VjP80i^CU00D0hN7S0>OXk03Uj>l0iNS_
0453DP0202PY?@0502/Y?P1iMXL0NGJ70>WVk`3Ie=P00P3Acm00103Cd]00blW:0<_9bP3<b//20<c;
b@050<[9a`38a<<0bLG20<W5`P33_k`00P32_[/01@30_;T0_KVf0;fi]P2j]k80^;F`0080/k2[00@0
];6Z0;6^Y`2a[ZL0[JZS0P2/ZJ@01@2SXYd0[JbW0;Fb[@2e/Zd0^:j]0080^9nR00D0]HZA0<Z9T@3:
RI40Ze1I0;M>E@020<=GE`040;iME`2WGE@0YeeD0;21N@80oo;]00<00?l0ooooooooool03Oooool0
00gooooo00@00?l00>O8a@3Wb<D0XeA=0P33DdP01@3KEd/0jUY?0>YJC`3^G4l0j5A60080kUY<00@0
jeM90?1NC`3`GTl0kf1?0P3ZGd`01@3WH4X0ifM>0>1YB@3PJDT0g7570080e7A200D0dGm70=2:C`3@
RTl0bI5H0;nAG`020=>]QP040>O5Z@3XbK@0j<Vd0>K9]`80j/fo00D0km;40>oAaP3B]:T0d[BY0<FW
W`020<:SWP050?;Cd02oX9h0_j2N0:n;S@2aR8`00P2bR8`0102]Oh80cYZL0<jJW03m`;/20=b?O`05
0<Y^E`3QN5/0iW=D0>IcE03ZLE800P3XJ4/01@3/IDl0kF9?0>eRC`3bIUD0l6=B0080kf5C00@0lV=E
0?5RE03aHU@0lF9D0P3bHeD01@3^Ge40lVAF0>eQDP3]HE80kfEH0080ifEG00D0h6aM0=mjKP3ONVh0
Xe560=6=Q00209ACC`0405dG5@1W5QD0IaHE08l];P80aUAC00D0iVUU0>QQF`3UGeH0iEmF0>5SE@02
0=UYF`0509e4=01Q7Ph0HAh>04PH30117aH00P0j8A`0100g8R40=AlQ03DO8@0k9BL203XR8P05040V
9`109RD0@RTU048Y9@1:;2X00P159bD01@1@<S00BB`X04T/:01@<B`0BbXU0080Cb`X00@0CbTV05D/
:P1E;2X0FBd/0P1M<2d01@1O;bd0HS4]06Lf<P1W=S80Hc0]0080Ic4_00D0IR`[078b<P1b<S80Mb/]
08T`<P0209<[;0040<5=C@3;Cdd0bdm=0<U>B@80_da500D0_eU=0;EMC`2CBSL0TdXg07Xn900206m1
7@0508QT=024JS40Q6Xa07eY;020LCH00P2;Pe80101iME00F5E205QE@P1EE4l205IEFP0505aLIP1G
EV@0?Ca<03dlC00o?U000P0n?5401@11?U40GEUZ05eIJP2XY;80[:Vd0080`kg900@0e<kH0=oGhP3O
en80i]oW0P3Wh^P01@3Th^L0hN;V0?7dn@3am?T0Q8JB00804A<P00D051<Q0490C@12@4d0emCK0>7O
hP020=SFe`040=OFe03Edm@0eM?D0=CBd`80dm;@00D0e=?A0=GAd03Bc/d0d/k=0=3<b`020<o;b005
0<g9b03:a/D0b/K50<K2_`35`Kh00P34`;d0102o_;L0_KZe0;fj]@2j]k820;Jc[P050:j[YP2a/:`0
^kJc0;^f/`35^KT00P3=];L01@39VZ80e8fE0=B=U@2cCeT0/Sm60080b51B00@0`EAA0;1LDP2`G580
TE]?0P3^fM@00`00o`3oooooooooo`0=ooooo`003Oooool01000o`00ilS50>O8a@2SE4d20<=CB005
0=]GB`3ZFTl0jUY?0>iLC`3XE4H00P3^FT`0103[EdT0l5i?0?1NC`3_H4l20>YOC0050>MPBP3WIdh0
h6U90>1YB@3LLDL00P3DM4801@3AOdL0d8Y?0=2:C`39TEP0_i5O0080djf600@0ilFY0>S9]03XbK@0
i/Vg0P3ZcKl01@3_d/@0km760=:dZ@3B]:T0aJNO0080`Z>N00D0l]?@0;nPWP2oX9h0[h^=0;68S002
0;:8S0040:eoPP3>VY`0cYZL0?g0^`80g8mo00D0bViG0>5hF`3VLe@0iW=D0>YaDP020>QXB`050>aU
C`3]HTl0kF9?0?9VE@3`He800P3_HE<0103bHeD0lF9D0?5RE03aHU@20?9SE@050>iOD@3bI5H0kF5B
0>eQDP3_IEP00P3WIEL01@3PK5d0ggY^0=mjKP2SDDH0dHf40080U5=?00@0GALE06LF5@1W5QD0Sbd^
0P36E5<01@3VJFD0j65K0>EOEP3UGeH0hF=E0080fFUK00D0WD@d064N3P1Q7Ph0B1P<044O5P0203XQ
700403LR8@0e7b40=AlQ03/U9`80>R8R00D0@2HW040V9@12:BD0@RTU04X/:P0204DW9@05050b<019
;2P0BB`X050a;01;:RD00P1?;2P0101?:BH0EB`Z05D/:P1I;B`205d`;@0505l_;@1R<Bd0IcHb06Lf
<P1S<2d00P1W<Bl01@1V;2/0LS8b078b<P1g:bd0RC0b0080Tb//00@0`De=0<]?C@3;Cdd0bDi90P2o
C4D01@2oFDd0]Ee?09=:=`2CBSL0NShT0080Kd4M00D0R6@d08AZ<@24JS40OFT/081a=P0208^3DP04
07UeD01HED80F5E205EDC`80EUEJ00D0G5aV05MFI00m?4`0?Ca<03lnD00203hlD@05044nD@1MFFX0
GEUZ0:RT/P2/ZK@00P33_LT0103Dc]P0gmOR0=oGhP3VgnL20>ORj0050>CRi`3Qh^H0lOCi0?7dn@24
QY800P0A4b001@0D4b40@T1=0490C@3Ge=/0hMoR0080f=KG00@0emKD0=GCe03Edm@0e=;C0P3Cd]00
1@3Ddm40eM7@0=;>c@3Bc/d0d<c;0080cl_800D0cLW80<[6a@3:a/D0a/:o0<G1_P020<C0_@040;nl
]`2m^[D0_KZe0;Zg/P80][>^00D0[Z^V0;6`[02k][<0^kJc0<Fi^@020<fd]`050<VJXP3DSID0e8fE
0;=?F@2b?dH00P38D5801031E540/5aB0;1LDP2AFdl20>kIe003003o0?oooooooooo00gooooo000=
ooooo`04003o003S`[d0hl:m0:=CBP80`e5600D0g5I:0>eND03]GU00jUQ90>EB@P020>]JB@040?AS
DP3^Gdh0kUm>0>UQB`80iF=900D0gVE60=i^B03ELD00eG500=J0A@020=:9A@050<jBB@3>WUH0cYiF
0<VUI`3J_i000P3`fkh0103Oc;d0_ZfV0;j]YP2cXIl20?3Mg`050=_7b@2@O7h0KeUL06mIG01H@dP0
0P1]F5l01@3E`LX0JeMR06]GHP1XDUl0JU9R0080K51O00@0IdMD05hi@01N>D00a9RE0P3j`[401@32
OEh0d7]B0=]jC@3KNTd0h7I<0080igI>00D0jVm>0>MUB`3WID/0k6EA0>]RC`060?5TD`<0l6=B00@0
kF1?0?9VE`3bIUL0k6MH0P3SJ5T01@3RN6X0aViR0<I^HP1i=Rd0REM>0080Y7Uc00@0YWUd070f=01`
=S@0Ha`J0P24:BP01@33EE@0i6QV0>MVH03WIV00i65G0080hFMJ00D0cV=C09<j:P2C>RX0Gad?04<E
200203XL5004030M5`0^7Qh0;QhN02dQ8@80;AlO00D0;R0P02/M7@0^81l0;R0O03TW9`0203<Q7`05
04Hd<P0i9b<0>BLS040_:00j9b400P1;=S40100i9240>RDR03XU8P0k9R<2040X9P05048Z:0109b<0
B2`Y04P/:@1092<00P18:RX01@148R40DBLX054W:01A6Qd0HA/M0080JA0B00@0/d]<0<YJF03:FUP0
bEUE0P3;IF001@2kI5/0VeQ?05l^801O;R00A1l?0080ABXE00D0Ac4I04@e5P14=AH0?cDB03Xd5002
03@c5`0402X[6@0l?3@0?3`d0410@080A4E:00D0ADE?03XiA`0_;Sh0;bhn034`@P02034bAP0503Xl
D@16BE`0ATUL05AEI`1=CV000P1CDFH0101QGg@0M76207AaPP24P8l209^EX@050=_Hh@3Qh>D0inS/
0>OXk038bLh00P1nOh@01@1UI6X0E5=H05ACF02h^;X0iNGU00<0fm_K0`3Jf]X20=WIf@050=KFeP3G
eMH0emKD0=OFe03FeM<00P3Ddm401@3Dd]<0d]7?0=;Ac`3>cL/0cLc:0080bl[800@0bLS60<G4`P35
a<80aLC00P32`Kd01@2l^kL0ZjZX0:RTX`2XY:<0^:j_0080`J^^00D0a9VR0=fJX`3MVZ<0/U=K0:<b
>0020<9:C0040<IFDP2gGE@0]eeD08=7?080b[6Z00<00?l0ooooooooool03Oooool000gooooo00@0
0?l00>6n^P3Q_[X0YeA<0P34DTL01@3OFDd0kEi>0>eNCP3ZF4T0h4ln0080iUM600@0jUe90>IOB@3V
GdT0gem20P3KI4801@3KL4H0cfll0=9n@03BOT00dHU10080dII600D0ejQH0=^gK@3K]fd0cKEi0>OH
[`020=S;^0040>?He036^kl0a[^o0;bb^P80j=cV00D0PGF106MIIP1MCe`0GDmL03T/=P020;>U/P05
09R<VP1GBU/0EdYK05I9F`1>?e@00P1F@eT0101WD680ABXc04DZ<`2ELW020?oJa@050=bTO`3DSU/0
dX590=:1B@3JOdP00P3NNTP01@3WN4d0k7AA0>adD@3YJD`0jfA>0080kF9?00@0lFAC0?1SDP3`He80
l6=B0P3cIUD01@3_HU40lVED0>iUE@3^IED0jVQH0080hViO00D0fGU[0:9HB`2RF4/0I30U04lZ8P02
079EC`040;FHTP2fTH/0]Y6;06`i=P80Ea4?00D0QRh/0<=KFP3OJFL0gfUW0>=VH0020>1TFP050=]U
F@3;HE<0bf5C094n;P1K70d00P0o4`P0100b5`h0;1XF02`J5P0W7A/202LO7@0502HM7P0T6a`09QdN
02HM7P0a9bH00P0Y7ah01@0j<2l0;R@R02hT8P0e;2L0<RTT0080>Rl[00@0<2DQ02hT8P0^9280=2XX
0P0c:BL01@0g;B/0=RPW02lQ800_8B00;R0O0080@S8b00D0=B4R04LZ;017:R`0@ALI05`N8@0206@?
4P040:e9B@3:FUP0bUYH0<aLF080b6EO00D0/F5H08iEC0188aX0B2<J030H3P02030R5`05034W6`0f
;R40=RhQ038/7P0/:Qd00P0];B<0100O81X0:BTW02TY9`0[;2h2038a=`0503Dd?00f=3l0;2Xg02`Z
=`0/:cT00P0Z;3T01@0Q93<06Qd/01XM;00S9SD0<SE40080=3M800@0?3eA04M6F017AUP0B4EF0P16
@U001@2l^L80i^GZ0=[Jg03Jf]`0gMgO0080fm_K00D0f][J0=7Ad@3AdM40eMGE0=kNgP020=gMg@<0
g]kN00D0gMgM0=kNgP3Ng]h0fm_K0=cJf`020=gKg0040=gLfP3LfmT0g=_I0=cJf`80fmWJ00D0f=SF
0=KFe03GeMH0emGF0=CBd`030<o?c@80clk<00D0bl[80;Nf]02PW9/0X9bK0:JMX0020:fJWP050<FP
Y`3UZ;00iJR`0;YOJ02J:c800P35CDl01036EE40^5aA0;QLD@28B3`20:25O0030?ohkooooooooooo
00gooooo000=ooooo`04003o003Q_[X0hKjj0:MDC080a59700D0geU=0>eNCP3]GTh0jUQ90>1??P02
0>IGAP040>YMB@3VGdT0iUm90=mO@P80ffA200D0fg160<m_?03BOT00dWi00=69@@020=6FAP050=NX
F03K]fd0fkM]0<feN@3Wf:l00P3HbkP0103Sf=@0a[^o0<Jk_`2l/[X20>SLiP05085eP@1WFFH0GDmL
05e?G00i;3H00P2cYK801@2HS9X0EdYK05M:F`1FBE/0CSmD0080ET=I00@0Ie1R04DZ<`15:S<0UG9`
0P3of/D01@3LY7l0e8iK0=:1B@3BPDT0fWm80080gWY800D0igQ=0>adD@3/M540jFU<0>]TCP020>eR
C`040?5TD`3`He80l6=B0?1SDP80lfIE00D0kf9A0?9UE03^IED0kVEE0>YXF0020>9^G`050=UiJ`2R
F4/0XUQ;06@`9@1?:R800P1bEDl0102eV980]Y6;0;JAR`1/>CH205LA3`0508H^;033FeX0gfUW0=mY
I`3SIV000P3PI5X01@3KIET0bf5C0<]QD`2A?Rh0Fa`=0080?a<800@0<QL>02`J5P0/6QH09adK0P0W
7ad01@0V7Ah091/L02HM7P0V7Ah0<BLV0080:AlN00D0>S0_02hT8P0^9280=B`W038Y900203X_:`04
030U8@0^9280;R@R03@Z:080<bTW00D0=bd[03HX9`0_8B00;b4P02hP7`02048b<P0503DQ8P17:R`0
AbX/044G6@1L7R400P1T3a80102]BDT0bUYH0<YJF03<G5P20<QUG`050;5QF02>ED`0B2<J04PS6P0`
60h00P0`8QL01@0a9a/0=RhQ03H^8@0b;1h0;2XM0080;BdS00@07b0J02TY9`0Y:BL0:b`^0P0b<CL0
1@0e=3`0=S@o02`Z=`0/:SL0;2/i0080:R`i00D08B@c01XM;00J7B`08bHe038eA00203@gB00403`m
D@17AUP0AdIH04Q5EP80AT9@00D0_;W20>KUjP3Jf]`0f][L0=gMg`020=_Kf`050=[JfP3AdM40dM7A
0=GEe@3Ng]h00P3MgMd30=kNgP050=gMg@3Ng]h0g]kN0=_Kf`3Lf]/00P3Mfm`0103Mg=X0g=_I0=cK
f@3Lf]/20=_IfP050=SHeP3Fe]@0emGF0=OEeP3Dd]<00`3?cld20<o>c0050<_:b02g][@0X9bK0:2L
V`2VWJ000P2]VYh01@35X:L0iJR`0>FX/02jGfP0VR/b0080aDe?00@0aUEA0;QLD@2hG540R4Pl0P2P
QG`00`3on>ooooooooooo`0=ooooo`003Oooool01000o`00hKZe0>6j]@2ZEdl20<MEBP050>9LD03a
HU80lF9B0>MEAP3TED@00P3VFdH0103SGdP0gV530=iQ@`3CHC`20>MnC`050=Mj@@3DPd40cHDi0<f5
>@3ATch00P3R[UP01@3]`6l0ekA`0=NdL03E_hd0h=6b0080cL6e00@0hMSI0;bf^P2l][X0j>7Y0P30
^<D01@1TG6/0G5AQ048gA@12=dD0L6Ia0080e<[E00D0KV=c04DlC@15?4d0GeIW071TN00204LiD004
06=@H`0k8B`0>b4/0;6>RP80om>l00D0k;F<0?NjP@3WXV40ij9Q0=64@0020==n?@050>20AP3VNT/0
iWY;0>egD@3WJ4P00P3]IDl0103_HU00kf9A0>mRD@3`HE420?9SE@050?5SE@3]HE00jVED0>YUE03R
JEP00P3SNFT01@34Lf80Kc@V06ld9P1C:1l0BRdU0080A30Y00@0FD@o09n6P@2OQX40_ijI0P1^?SX0
1@1B5A80PS@b0;AFEP2dEUH0efYW0080gFMS00D0hfQQ0=]UF`3KIE/0bf5C09Q0<P02060N400403dA
1P0`5@h0<1D>02TJ5@809adK00D091`J02TS8`0T7Qh091hN02TS8`0202DP7@0503`d<P0Z8Ql0:R8O
03D]:P0]9R000P0[91h0100Z8ad0=Rh[03H^:`0_9bD2038]:@0502PS7`0W7A/0;R@R02hT8P0U6aT0
0P0e:RP01@0a8b80?B@W03dT9`0g3A40F1LK0080JQ0B00@0]DU70=EKEP3EFeH0be990P30ETT01@2d
HE<0T5Q;03lM4`0o7A<0:QL@00809QdF00D09R4K02LT7`0W91l092<N01lN6@0202HV900401lO7@0L
71X071`J01hN7P808AlR00D08b4V02`W;@0V8BP09R4X02DR:@0201@A600503ln@`1SHVL0Hf9W04Y;
C`0f>Sd00P0N8bL0100O8R/092@`02@T<00M6bP201dJ9@0508B1RP3Yj>d0fm_M0=_Kg@3Jf=T00P3K
fMX01@3Mfm`0h=oM0>3Og@3Rh>40hMoP00D0hN7Q00@0g]kN0=kNg03Ng]`0h>3N0`3Ph>00103Rh^80
hn?S0>?Sh`3Ogml20>3Ph080gmoO0P3Ng]h0103MgMd0g=cL0=cLg03Kfm/20=cLg0050=WIf@3Cdm<0
bLO80<W7b035_l400P3B`/D01@3RaLX0m/?:0?K3bP2nJg<0TBP]0080`da>00@0a5==0;aNE02lGU@0
SD/o0P2<L6D00`3om^coooooooooo`0=ooooo`003Oooool01000o`00gKB`0=fd/02/F4h20<aGC@05
0>=MD@3]H4l0kF1?0>AEA@3QE4800P3TH4/0103OHd/0fV]=0=Y[C@3BKdH20>67E@050=j>C`3FST@0
fIQ60=VHAP3U[5D00P3b`6/01@3R^6h0Z8Q=0:R8C@3KaIh0flni0080hm[E00@0`K^o0<_6c03;a/`0
jnG_0P1gLh801@1BCUl0@Ce>0:NP/02WX;00ln_j0080UHfL00D0ACa?03hgB@0n=dT0e<cQ0=79gP02
0514FP0404`mD012:cD0@R/e0>6n_080cY^800D0_7eJ0?:`O03o_7/0okak0?6[H`020=V<A0050=J1
?P3PP4@0h8140>9fA@3_N5000P3YJ4T0103]IDd0kf9@0>mRD03bHe<20?9SE@050>iPDP3_IU@0iFIC
0>EVD`3OKU`00P3HNfT01@2NFDT0G2`N05`/7P159a`0?BTR0080@2hZ00@0?RlZ04`i=@1<>CD0ZI6=
0P34YJ001@1X?c/0DQXI07L_<01g;c00[EED0080cfMV00D0hF]W0=mVGP3OIUh0gfUM0<iTEP0209m9
>P0405lP4@0l4@P0?148030G4080;A/G00D09Q`J02LR7`0V8R409R8Q028N7@0202LS8P0503<^:`0V
8Ah09R4N038]:@0U81`00P0Z9B40100V8Ad0<B`X034/:00Z9B4202XW8P0502PU800R7AX0=Bd[03D]
:`0Z8Ql00P0d;2T01@0a9BD0=QdP03HM800k4AD0EaDI0080Ka0D00@0`Ti>0=AECP3DEDh0dE=70P36
F4T01@2kI5<0TEM903dM400m7A009QD=00808A`H00D07A`H01lO7@0O7ad07AdK01lO7`02020P8004
01XJ6P0K6QP06aXH01lK6P807ATH00D08AdL02DO8@0Q61/08APK01@>400203hh>0050;2/Z`3Lf=L0
g=SG0<O7a@2h^[L00P2RYZD0102@U9D0OWn407ioQ01VIFd204]8C`0506AQJ03Lfn00gmoQ0=oOh@3P
g^<00P3OgN801@3Rh><0i^CW0>KTi`3UhnH0hn7R00<0hN7Q0P3Ogml01@3MgMd0gmoM0=oOg@3Rh^00
h^;R0080hN7Q00@0iNGU0>KViP3Vi^H0h>3P0P3Rh^80103Ti>@0hN7Q0>3Ph03Ph>030>;RhP050=oO
g`3Ogn40gmoQ0=oOh@3Ogml00P3Pg]l0103Qfmd0i]OJ0>KGfP3`emd20?oGgP050<QkP`258RL0_4Q9
0;a8B@30Cd/00P2mGeD0102ACd40SFmT08e_I03omN`?ooooo`003Oooool01000o`00gKB`0=fd/02/
F4h20<aGC@050>=MD@3]H4l0kF1?0>AEA@3QE4800P3TH4/0103OHd/0fV]=0=Y[C@3BKdH20>67E@05
0=j>C`3FST@0fIQ60=VHAP3U[5D00P3b`6/01@3R^6h0Z8Q=0:R8C@3KaIh0flni0080hm[E00@0`K^o
0<_6c03;a/`0jnG_0P1gLh801@1BCUl0@Ce>0:NP/02WX;00ln_j0080UHfL00D0ACa?03hgB@0n=dT0
e<cQ0=79gP020514FP0404`mD012:cD0@R/e0>6n_080cY^800D0_7eJ0?:`O03o_7/0okak0?6[H`02
0=V<A0050=J1?P3PP4@0h8140>9fA@3_N5000P3YJ4T0103]IDd0kf9@0>mRD03bHe<20?9SE@050>iP
DP3_IU@0iFIC0>EVD`3OKU`00P3HNfT01@2NFDT0G2`N05`/7P159a`0?BTR0080@2hZ00@0?RlZ04`i
=@1<>CD0ZI6=0P34YJ001@1X?c/0DQXI07L_<01g;c00[EED0080cfMV00D0hF]W0=mVGP3OIUh0gfUM
0<iTEP0209m9>P0405lP4@0l4@P0?148030G4080;A/G00D09Q`J02LR7`0V8R409R8Q028N7@0202LS
8P0503<^:`0V8Ah09R4N038]:@0U81`00P0Z9B40100V8Ad0<B`X034/:00Z9B4202XW8P0502PU800R
7AX0=Bd[03D]:`0Z8Ql00P0d;2T01@0a9BD0=QdP03HM800k4AD0EaDI0080Ka0D00@0`Ti>0=AECP3D
EDh0dE=70P36F4T01@2kI5<0TEM903dM400m7A009QD=00808A`H00D07A`H01lO7@0O7ad07AdK01lO
7`02020P800401XJ6P0K6QP06aXH01lK6P807ATH00D08AdL02DO8@0Q61/08APK01@>400203hh>005
0;2/Z`3Lf=L0g=SG0<O7a@2h^[L00P2RYZD0102@U9D0OWn407ioQ01VIFd204]8C`0506AQJ03Lfn00
gmoQ0=oOh@3Pg^<00P3OgN801@3Rh><0i^CW0>KTi`3UhnH0hn7R00<0hN7Q0P3Ogml01@3MgMd0gmoM
0=oOg@3Rh^00h^;R0080hN7Q00@0iNGU0>KViP3Vi^H0h>3P0P3Rh^80103Ti>@0hN7Q0>3Ph03Ph>03
0>;RhP050=oOg`3Ogn40gmoQ0=oOh@3Ogml00P3Pg]l0103Qfmd0i]OJ0>KGfP3`emd20?oGgP050<Qk
P`258RL0_4Q90;a8B@30Cd/00P2mGeD0102ACd40SFmT08e_I03omN`?ooooo`003Oooool0103omo@0
fZnY0=Z_Z@2]ET`20<aHB`050>MRD`3ZGD`0jUe<0>9EA03TFdT00P3NHDd0103IJe80d75E0=1aE@38
M5020=:8E`050=ZFF@3LW5@0jZeM0>Z]G@3e^VX00P3Y]FT01@2NMCL0_Ii`0;fNL03VeKT0gM?70080
gmKG00@0Yj2W0>[Uk03ZiN`0_kc70P1IEVT01@1@CF80@3eB09B?X`2DSj<0ZZFi0080F51U00D0B41H
04m7G`1?Ael0XiZe07adS0020514FP0403DW>021JgL0PF]g0?KBeP80[G5Y00D0]FQD0<ijE@3ST5`0
hi1L0?nfLP020?VdJ@050=nCA`3IQcd0fHLm0>:3@`3VNdD00P3]Ld`0103[J4X0kfM?0>mWC`3_HU02
0>iQD0050?1TE@3[He<0i6UG0>AYE`3MM6400P35M6401@1i@2l0C2PJ04`X6P0l9Q/0>2TR0080>2XW
00@0=BLT03d^:@0m;RT0CS/e0P2CNgL01@2nXYh0SVQU050P7P1@81h0JBTY0080Xe9A00D0cFMU0=i]
J@3NKFT0hVUP0=aXF`020=1YFP040:==?P1M7a00GAl@03`B1P80<aPA00D0:AXE02DK6@0S7Q/08ahK
02LS800202PT8@05030/:@0R7Q/08QhK034]:P0U8Qd00P0^:bH0100/:B@0<RdY038]:@0]:2@202LT
7`0502`Y8P0U81`0<B`X034/:00W8Ql00P0g;bd01@0U6A/0>QlT03XO901151T0FQ<I0080MQ<F00@0
aDe>0=QDC`3HE4l0dU950P3:FdX01@2lHe40S5=203`L3@0l70d08a8:00808QdI00D07AdK01HH5`0F
61L06QXJ020P800201hL7@0401dI600Q71T08A`I01`G4`807aXF00D091`I01`B400U6QP09AXH07AZ
J0020<o7a0050=[Ed@3Gdm00em?@0=_JeP3Hf=H00P3KfmT0103Lg=`0gMgO0=gMg`3Ng=l20=?Ae005
0<_9c03NgN80hN3V0>7PiP3Uh^d00P3Who401@3Ien@0_K_60;fkaP2g][`0fMWK0080h>3P00@0g]kL
0=cLg03Lg=`0gMgM0P3Ogmd01@3Ng]`0gmoM0=kNg03Ng]`0g]kN0080h>3P103Ogmd00`3Ng]`0h>3P
0>3Ph0040>3Ph080hN7Q00D0h>3P0=kNh03OgMh0gmgN0>7Kg@020>KJg0050?;Kh@3me=X0oMCJ0<5j
PP2bDeT00P2b@D<0102nCTX0_5]B0;aKDP2GDdH209=cJ0030?odjOoooooooooo00gooooo000=oooo
o`040?oglP3EZZ<0eJZS0:IBA`80cEa<00D0iF5B0>UMC03YGD`0hUI50=]JA`020=QXE0040<][E@3;
Nf@0bg]T0=fHN`80hJ=l00D0h:A`0>FXJ@3e^G<0mKUc0?:gL@020;>0@@050:1hA`3SbJP0hlVX0=g<
^P3Sf]<00P39`<<0103<aL`0nOCk0?Wdn`28PXh204i9G@05051=HP1=B5h0FUEY05YEJ@1LE6T00P1G
Cf@01@1DC6@0Dd]S05=;H`1MDf`0EdeU0080@SM800@0;b4`0=6mb03A_LP0on3W0P3Y/K801@2nMFh0
_6YE0;eYA@2mJDD0f8mH0080oKQc00D0nkIY0=bCAP3LTdH0eH4i0>F3A0020>MgA`040?5eC`3WI4P0
ifA80>]SC@80kf=B00D0kVEE0>QUD`3OJUP0gfYH0=]jI`020:]RD@0505h_7`108aD0@2<E03HU6`0a
9R000P0a9R80100a9R@0@38_040b;`0m;RT2048`;00508=`JP31ZJD0V7Id09QfM01D9b@00P1]<2l0
1@2EA440aFAN0<ETGP3PKfL0hFaR0080gVeO00@0c6IG0:5>?P2QCSh0HR<D0P155P`01@0h5a00:Q8>
02`J5P0/6QH0<R@Q0080:b0N00D0<bTW02LM6`0W7A/0=Rh[02`T8@02030Y8`0402dV800`:B<0<2TS
02hW8@8091lI00D0;RTS02@O6`0]:2@0;BPT02TT8@02030X9P0502LH6`0n8BD0?R4U04<B601P5ah0
0P1j4aL0103<DU40fEA=0=UDC@3DDTD20<QGA@050;mWD`2:DCh0?Ad>03dM3P0U50`00P0Q71P01@0L
71X05aLG01LG5`0M6a`081`K008081/H00@08a/H02DJ5P0U6QH07A<:0P0M4`L01@0I4040Bclc0:VL
T`2YW9<0g=;90080aKjh00@0S8N30;2/Z@2`[:T0h^7M0`3Mg=X0103Pgmd0h^3Q0>;Ph@3Th^<20>SV
j@050>SWk03YjO40iNCb0>GTlP3Acn@00P2WYK/01@1^K840CdiN04m>GP1ACeX0/K2e0080kno_00@0
h^;R0=kNgP3Ng]h0gMgM0P3Ng]`40=oOg@040=oMgP3Ogml0gmoO0=kNgP80g=cJ0P3KfmT20=gMg@03
0=[JfP3Lg=`0g=cL00<0fm_K00D0g=cL0=cLgP3Mfm`0gM_L0=oIf`020>?Gf@050>kIgP3ecMD0mLgE
0<f7S`3LOhL00P2S=CP0102mCD/0^eYA0;]JD@2MEd/209UgK@030?oej_oooooooooo00gooooo000=
ooooo`040?ohlP3?Yil0cjNO0:IDB080bUY<00D0iF=E0>=KB`3SFd/0gEQ70=eTD`020<aVE`040<Yg
J@31Og<0`Gmc0:meI`80d9R100D0k;BA0?RkS03h_8H0n;b60=RLJ0020:QeAP050<NUPP3_fL@0kmW4
0>_JdP3LdLl00P34^[/0103PeMT0k^GZ0>kUjP2AQi0203H]?P05040gBP14?Dl0B45A04Q1D@16?Dh0
0`14>d`204<gB`0503lbA00f:CX0=2Hc03@V<`2=OHL00P3hhn`01@3mgnL0omcT0?oLi03mblh0eIJA
0080Xe]<00@0/VQ50=><F03CS5P0o;Qg0P3k]fh01@3QUDX0g8E00>IoA@3VOdD0k7U<0080l75@00D0
kfU@0>eTDP3]I580kFQG0>1SD@020=iaG@040=AkJ@2ACSd0TDhm054V5P80?R@G00D0>2LO02`Q6`0^
9B00;RDP02lU8`0203L^:@0503db;012=Bl0@SD_04Lh<@1`GEL00P2VShT01026If@0Kd=006m3@01[
<2`208m4?P050;iPF03LLFL0hg5V0>=aIP3JJ5d00P3=IEP01@2XC3l0Kb4E06lQ5@1A4@P0?0T50080
>a8>00@0@b4O03HJ5`0f6QL0?BDQ0P0^6aD01@0c8Q/0=BHO038U7`0b9Al0;B0J0080<RDO00D0=R/W
02PO6P0X7aX0<b`V02PP7@0203H^:`0402HN6`0b9bD0<RLU02hK7@80@b@Y00D0AA0H05lB601m51P0
OA@H0<iBD0020=YDB`050=9@@P37F4@0aeQ40;aUD@27CS/00P0n7Q40100Y61008A`H024L600M6AP2
01/G600502<J6`0S6AP0:Q`I02XL6@0[71D00P0X5P`01@0O3P00:ad202/M0P1`Hd<0c<6S0080bKnV
00@0NG=S08n;PP2?Rh80ZZNR0P3@c</01@3Og]`0g]gK0>7PgP3Qh=h0hn;P0080inGV00D0j^S[0>[Y
k`3ZjNl0hN7]0;jod`0208b>Y`04061QP01FEWP0EUIh06IWQ@80GUif00D0=3=107AcN@3`l?80l?3b
0>KViP020>7Qh@050=oOg`3Ph=h0h>3N0>7Qg`3ShN800P3Th^<0103Yi>P0j>KW0>SVi`3Th^<20>?Q
hP80h^;R0P3Qhn80103Nh=l0gmoO0=oOg`3MgMd20=kNgP050=gMg@3KgM`0gMgM0=gMg@3Pg=d00P3T
fMd01@3]f]h0o=CL0?cDg03HTYX0bfif0080X38e00@0`51>0;]JD@2kFU40VeE90P2LNW000`3oln_o
ooooooooo`0=ooooo`003Oooool0103on?80cjNO0<nWW`2VE4P20<YJC0050>ESE@3SFd/0he];0=eH
A`3MI5<00P3<IUL0103:MfT0`Gmc0<5oL`2_MFL20=2HP@050>bdT@3h^h`0n;b60?RlQP3HW6P00P2X
MDH01@37YH80kmW40>oIa03[f]80g=7?0080a;Zk00@0h=GI0>kUjP3^iNX0THN@0P0f;Ch01@10=dX0
A3e?04Q1D@18@E40ASe>00<0A3]<0P13=d/01@0o<T@0=RTj03@V<`0d9S<0SGf70080n>?/00D0oMoW
0?oLi03og>@0oL_>0=FFT@020:=KC0040;9XA@3CS5P0dhaH0?bhM`80nkM^00D0hIE:0=b5@03VOdD0
iWm50>aiC0020?1aD0050>mYD03]I580kFAB0>eXE`3PHe400P3NLEd0103DNfT0TDhm095>?@1A9QH2
03hT5`0503PW7`0/8A/0;RDP02hU800_9B<00P0g;RT01@0m<R`0@SD_048e;`17>340L5eG0080YXn9
00@0QVMT06m3@01_@d00Jc0/0P2?A3h01@2nH5P0g75W0>=aIP3SLFH0fVQM0080cFEH00D0Z4`o06lQ
5@1_8AD0DA4803`91@0203/B3P0404<Q7`0f6QL0=QXG03dU8@80;Q/E00D0<b8K03DV7`0b9Al0<RDO
02dP6P02038U7`0503H[9`0X7aX0:1lJ03</9P0X81d00P0f;R/0100V7Q/0<RLU038W9@0^6ad204<T
:@0504D@601O4QP0OA@H07dD603>DU000P3JE4/01@3BD480aeQ40<MHA02lIE40Qdhk0080?QhA00@0
:AP@024L600Q71P07ATH0P0K5aP01@0S6Q/08aTH02XL6@0Z71T0:a`E0080:1H<00D07`h002/M0P0[
7@80L6=30<c1X`020<VoYP0407UcH`2?Rh80Sh^20:ZWXP80d<c;00D0gmkL0=kMf`3Qh=h0hN3N0>?R
h0020>OUiP050>[Xj`3ZjNl0j^W_0>7Qk@2n_m<00P2<SZL0101PHH00EUIh05IFN01VIhD205iNMP05
03@c@@1dLgT0l?3b0?3`lP3Vi^H00P3QhN401@3Ogml0h>3N0>3PgP3QhMl0hn7R0080i>;S00@0jNCX
0>SVi`3Xi^L0i>;S0P3ShN820>;RhP80hN?R00@0g^3O0=oOg`3Ogml0gMgM0P3Ng]h01@3MgMd0fmgL
0=gMg@3MgMd0h=cM0080i=WM00D0kM[N0?cDg03le=`0f9:J0<]^MP020:0b=@040<1@CP2kFU40^eYA
09]EB@80W7Y`00<0oo?[ooooooooool03Oooool000gooooo00@0ooSb0<fUW@3=YId0YUM:0P3=Ge00
1@3SIEH0gU]90=iKB@3JGD/0e6ED0080`VYN00@0bXAl09mXI@2OJ6D0HS4/0P2<F4d01@3S[9L0nKfK
0=^PN03KX7P0]WmH0080/XIS00D0l]>n0>KDb03Ve<P0lN?P0<Zn`0020>3Df0040;FY[@2o/[/0_k:k
0=kBg080PGB500D0H5EV0559F01CBeX0Dd]J05iCH`02069GI@0506MLJP1UFVP0IEYX06aNK@21Lh00
0P33/kd0103ei>`0nNC]0?WTk@3ignX20?_Mj@050?oKiP3od=H0hZRV0>:XYP3FTh800P2eK4/01@3F
T5`0okai0?nlN@3i]6T0gY160080gh=200@0j7i:0>efCP3]MTh0jfa<0P3ZIU401@3WIU<0hf]J0=ef
H`3MMV<0`G1O0080Mc`/00D0C2HI048Z7P12:Qh0>2TR02dT7`0202`T8@0402dU8P0c;2H0<b`V03H]
:080=BXT00D0@SLa04@e<01JBD80FTU206iIE00209YmN@050:=jM01nAd00OTM008]1>02iGeH00P3H
L6L0103UMFX0gF]P0=e[H03AHeH20;QCA`0508le:P1W5a00GQLA05hG4@1V9B400P1A5Q801@1D7aT0
AaH?04LF3`1?8aX0AalG0080@QdE00@0>QP?04<P6P1381X0@b@O0P0g6Q@01@0o8al0=1PE040T8@10
9240<APD0080?R8Q00D0>aTJ04TL8@197240E1HK06<>4`0208/J70040=IFD`3ICdD0fDm50=IA@P80
bEI300D0a6UD08M5=@0o4`P0?a<802hA2`0202XE4P0502PB500/4aH0;1<F030D4`0c5Q800P0h6Q80
100a50@0;Q@002hD001B?1D209j<FP050;>VL@2@QUD0PGUB085iDP2JUWd00P3Nf/h01@3ThM`0hmoP
0>?Oh03Rg]l0h^3S0080jNGV00@0k^[[0>GSiP3UhnH0bl[@0P2QXJd01@1YJW`0ATQQ04I9J016BFP0
FEao0080KG2C00D0Feaj03hlE00n?5@0;2Tj04i;E0020>?QiP030>WWjP3QhN<0hN7S00<0h>3P00D0
gmgN0=oKg03Sg^80hmkR0>[Tj0020>ORiP050>KRh`3Qgn00hMoP0>7Qh@3Rh^800P3Qhn800`3Ph^40
h^;R0>;RhP030=oOg`050>3Ph03Nh=l0g]kN0=kNgP3OgMh00P3Ug=l01@3[fmh0om_R0?oKhP39QXl0
`fI^0080[Ci400@0_4Y:0;eJE02mFU@0WEA;0P2NO7<00`3oln_oooooooooo`0=ooooo`003Oooool0
103om^l0aIfE0<FMU@2XFD`20<YOC@050>=XEP3MGT/0gEi;0==KBP3?JEX00P2iKF00102gOWL0aYRJ
0<JHVP2iSi42085?CP050=:IT03`/Yd0`8=W0<23I`2DHdD00P3:YX`01@3ScKl0gm;<0=oBc03Wfm/0
a;Nn0080l^;/00@0g<cF0=c<f@3Lc=T0l>;a0P3TenP01@3Fbm`0bL3A0<NocP37_lh0bKk>0080b;g;
00D0`KK40;ne`02o]L00d/CA0<k1b`020<Vi``040<Fd_P36/[d0a[:m0;RP[@80^j6^00D0]9JR09Ac
OP3^aL/0k/G;0>nh]@020:aYEP050;Y_B03SV5l0hiQO0?noN03b[F000P3YUdh0103QPD@0jWa;0>Yl
B`3/M4l20>QXC@050>IYE@3NKUX0fgaX0=]lJ02WGTd00P1R;R001@1>;200?RXQ03hZ8@0e:200<RTT
0080<2PU00@0;BPT02`W8@0/9b40:B@N0P0`:B<01@0c;2H0?S<_04Lj=017>S@0C3dh0080IE9<00D0
WX9n0<NRVP37XYX0Z7=]0:ENF0020;MNF0040=MbJP3WN6l0igQ_0=mZH080fVII00D0cei@0;a<@@2W
>c40Yc/a09/`:00208dV7`0508PV7@1k7A<0NadC078J3P1]6@h00P1P4PH0101N50/0GA@=05dD3@1O
6Q<205DB3005064R6`1@4@`0FA`I05TL6@1B5a<00P1K7ah01@1D5QT0GQTL05hI701Q3aD0KP/>0080
VAhQ00@0feAA0=a=A@3LCDD0f4i10P3CF4P01@38HE00Scd_04h;0P1>2`80A@/90080@Pl>00D0?`P;
04P=3`183@l0B@`;04/?1`0204/C0P0405PZ202BKS@0TVhd0<J[I080/IiB00D0R7Xa09>:B@3>ai<0
c/NC0>WTa0020>WSd`050>WTh03Xi>D0j>CU0>[Uj`3Wh^P00P3FdMP0102/ZK00MgIn07MfOP1@D5X2
0412D@0503`oDP13B5h0BdmZ04]?JP1UJHH00P1XJHD01@0o?ED0;RTm02hY?@0V7bl0=2`i0080bLC;
00@0l>__0>;Ph`3Rh><0hN7S0P3Pg^401@3Of]h0i^3T0?3Yl03`jO00ZZ2X0080SHN;00<0jNGV0>GS
i03Uhn@00P3Ph=h50>7Qh@040>3Ph03Ogml0gmoO0=oOg`<0gMoL00@0gmgN0>GLg`3Ug=l0j]_P0P3o
gnH01@2hMX00^UmX0;]9D@2kBE40^DI90080_5UD00@0XEQA09YhK`2JN6l0ooG/3oooool000gooooo
00@0ooK_0<FMU@35WID0Z5U<0P3:Gdd01@3SJ5H0gEi;0=eNB`3CFdX0cfUJ0080^FeP00@0]gig0<JH
VP36V9X0^HnA0P21Cdh01@3BVI00l;:M0<23I`30PfL0U6=50080bZJ<00D0hlfo0=oBc03Od/`0im_K
0<Bg_P020?;Rk0040=c<eP3Lc=T0g<cI0?3Rl@80i=OX00D0e/_L0<W0d@37_lh0ako>0<VncP020<Rm
b`050<6fa02o]L00_kG00=;4d@3>`L/00P39^L<01035];h0a[:m0<Jb_@2hX:d20;^Q[P050;BFXP2D
Lgh0k/G;0>k5b`3_^;D00P2/JEH01@2jKdP0hiQO0>>HG`3o_gP0lZeP0080jIM>00@0hH540>YlB`3Z
O4/0k7A?0P3XJ4d01@3VJED0gViJ0=]lJ03KO6P0Yei=0080HRhP00D0CR`P03hZ8@0n:R40=BPP038Y
9002030X9@0402dX900/9b40;2LQ02TT7P80<2TS00D0<b`V03hc;`17>S@0AcXd04`m>00206EBC005
09j2OP37XYX0aj:J0:QcK@2UGUP00P2gGUP0103GLVX0igQ_0>MhK`3OJV020=YVF@050<mND02lC440
Yc/a0:Lk<@2K<2P00P2=9Ql01@289Qd0NadC07/M4`1b6Ph0KAT>0080H18600@0GQ@;05dD3@1M50d0
GaXC0P1E4P`01@1Q8Q/0D14<05TL6@1I71T0DQLC0080FalN00D0E1HI05hI701N6A`0H@lE06h;3P02
09TN8@040=]DD@3LCDD0g4e50=Q>@@80deQ800D0b65@08lm;`1>2`80CP/204D;2@02048?3P0503l8
2`183@l0B0d?04T<2`1;3`L00P1;4`80101H:PP0TVhd099^=036Zf@20;6NDP0508Qj<@2CRTT0c/NC
0<k7T`3Yi<@00P3Yhm<01@3Yi>00j>CU0>STi@3ZiN/0in;X0080e]7H00@0[:V`07MfOP1gMWh0D51J
0P10@U401@0l?e80@dQN04]?JP1;CfX0IFV60080J6V500D0?ceE02hY?@0^:Cd09Ql_03@/>@020<W4
b`040?3[k`3Rh><0h^3S0>7Qh`80h=kQ00D0gm[N0>KPi03`jO00l>W`0:ZPZ00208f7R`030>WUiP3U
hn@0iN?T0080h>3N1@3QhN40103Ph>00gmoO0=oOg`3Ogml30=gOg0040=oMgP3Ug=l0iMcO0>[Kh080
omoV00D0^7J00;YOJ02kBE40^dUA0;U6B@020;aIE0040:5HD@2JN6l0VWQ_0?oek0oooooo000=oooo
o`040?ofk`31VI40`IVA0:]LC@80cV=A00D0hFID0=YMB@3JGDT0e6A@0<AWEP020<5mLP04099QG@3M
];P0gKBh09ifOP80J3Dj00D0e9ZH0=fMT`2[L600Zg1P0:5fH`020>_@_`050<Zk]03EblX0eL_:0<Bk
_P3Fbm<00P3]gn`0102OTJ00VXfN09Z=WP2HSIh208j2UP0508V0T`24OHl0QWnA08IoT@1lMHL00P1n
MhL01@1aJgT0LF]g075[M`1iLGh0NW1k0080NVij00@0R7Z708alR@2<O8T0Qg=o0P2<MX<01@1dGVX0
OFMc0?KHh03ff>00omSJ0080b8f500D0^fmE0<EgB@35MdT0lJe^0?jlLP020>jTF@040>F>B@3VPDT0
iX590>YiC`80jW5B00D0h6Q@0=ebGP3DNfT0e7]Y09UJB`0204`P4`0504DZ7`0k:R80>bXR03L/9P0_
:2800P0c:bP0100^:BD09b8L02LR700U81X302XU7`0403@]9`0i<2/0>C0[04@i=@80BS`i00D0ED@m
081WHP20If80_9F@0<jGU0020<ElMP040<Q]J039H5X0bF1J0>ekL@80i71S00D0ef5C0=5KC@3AFdd0
dE]=0=5HC@020<eDB@050<=:?`31Bcl0`D/o0;50<P2V>2/00P2N=2L0102A:al0SbXP08lZ8029:1l2
07hP600507hQ6P1i7aL0M1/E07@K5@1^5a000P1]61<01@1/51<0Ka<D06lC501_2`d0M`H80080X20Q
00@0g59@0=]<A03KC4@0gE540P3BDd@01@3?Fd`0VS@X06X=1P1Z3@H0GPT60080GPX800D0H`/:06H<
2`1V30/0KA0907TP4P0207`_5@040:1R<`3X_7<0j;ac0>k@NP80ZiDo00D0I5D20:BLE03^ik00k^N`
0??]b@020?7/f@050>gXi03Of]h0gm[N0;Nb^@23P8T00P1LEV001017A4d0ATI>04I6CP15B54204M;
E`0503m2D`14BE`0DUMZ059GJP1JFfl00P0o?E801@0b;Sl0:b@d02/T=00]8S80:b0^0080YifV00@0
m>oe0>?Qi03ShN@0h>3R0P3Rh><01@3Sg^80mNoc0=C;d03Dbm009QlV0080:bDY00D0em7C0?3/k@3`
k>d0hn;P0>7PgP020>;Ph@030>7Oh03QhN40hN7Q00<0h>3P00D0gn7P0=kPg`3Mgmh0gMoN0>3Ng`02
0>;LgP050>WJg`3og^D0omkU0;YkQ02_EEl00P2nCeP0102e@TL0`5eH0<1MF02RFE8209UgKP030?oe
k?oooooooooo00gooooo000=ooooo`040?odk`2kTh/0^i>;0:IDAP80d6EC00D0hFID0=QNB@3HGTT0
dfIB0<1YF0020;ioMP04091SH03H/KH0f;6f08mVKP80YW5g00D0c92B0<J7PP2LIU`0W6IL0=RcZP02
0>;>a`050=c@d03>b<`0c/S<0;2[/@3bk?H00P2g[kh0101SG6`0JfIj06]VNP1QGW<205aIKP0505ME
J`1JF6h0G5Y`05aJL01MFg400P1QGg@01@1RHgL0HfAf06=TMP1[JW`0Kfam0080KVYi00@0N7:007eb
PP1mLX80Nfmm0P1cIW001@1DAe00_Jfg0?cWkP3linh0omoT0080kKfk00D0_gYZ0<MkF@37NeT0f9EP
0?o1O`020?bhK`040?:UG`3aTeH0lI=F0?B8F@80kGQG00D0g6YB0=MbGP3CPW40dh9a09aTE`0204hY
800503TU700e:R@0=BXT02hW8@0^9R<00P0c;2H0100_:280;RHS02hV8`0Z9B4302`W8`0402dU8P0e
;BX0=BdZ03`d<@80@CPc00D0AS/g058o>`1B?c/0Jda909mbK`020<R8R0040>fNVP3<KFL0c6eW0<1I
D080iX1b00D0kh]k0>>2K`3GM640egAQ0=1UE@020<YJC0050<mKC03CGDl0dee?0<mIB`3CGDl00P3B
G4h0103CGDl0d5Y>0=1JCP3;ED/20<A?A@050;m=@`2lBT00/d<h0;=3>02a@SL00P2Y>S401@2S=S40
XC4]0:4a;@2O;2T0W28Q0080]S8`00@0eDi:0=I=A@3FCDD0edm30P3CCd801@3@D4<0_T@i0:</902S
;2@0WRLQ0080X2TS00D0XBXT0:`c:P2/<bX0/3L/0;m?>@020;eK>0040;5T<03b`GD0l/5e0?OGPP80
ZI0n00D0SWha0=O>R`3/i[80k>Jb0=oJ^P020<C1/00509B@S`1WI6/0IfA[04]8D@15A4`00P1:Ae00
101;BU80AdM?04M7C`0o@TT203`oAP0503/nA`0i?4D0>Ca503TlA@0c<C`00P0/:C@01@0b;3P0;BDb
02dU<P0_8c409aTX0080ShF>00@0m^of0>GPi03Uh>@0h^;T0P3Rh^801@3[jNX0hmoP06YTIP1ZI6H0
IF1T0080?CTj00D0]k6c0?C^l03dk_00jnGU0>WSh`020>KRh@030>GQh03ShN80hn7R00<0gmoO00D0
gMoN0=oQh03Nh=l0g^3O0=oMgP020>;LgP050>[KhP3og^L0omkW0;j0R`2YDe`00P2lDET0102hAd/0
_EaF0;eLEP2SFU4209YhK`030?ocjooooooooooo00gooooo000=ooooo`040?odk`2kTh/0^i>;0:ID
AP80d6EC00D0hFID0=QNB@3HGTT0dfIB0<1YF0020;ioMP04091SH03H/KH0f;6f08mVKP80YW5g00D0
c92B0<J7PP2LIU`0W6IL0=RcZP020>;>a`050=c@d03>b<`0c/S<0;2[/@3bk?H00P2g[kh0101SG6`0
JfIj06]VNP1QGW<205aIKP0505MEJ`1JF6h0G5Y`05aJL01MFg400P1QGg@01@1RHgL0HfAf06=TMP1[
JW`0Kfam0080KVYi00@0N7:007ebPP1mLX80Nfmm0P1cIW001@1DAe00_Jfg0?cWkP3linh0omoT0080
kKfk00D0_gYZ0<MkF@37NeT0f9EP0?o1O`020?bhK`040?:UG`3aTeH0lI=F0?B8F@80kGQG00D0g6YB
0=MbGP3CPW40dh9a09aTE`0204hY800503TU700e:R@0=BXT02hW8@0^9R<00P0c;2H0100_:280;RHS
02hV8`0Z9B4302`W8`0402dU8P0e;BX0=BdZ03`d<@80@CPc00D0AS/g058o>`1B?c/0Jda909mbK`02
0<R8R0040>fNVP3<KFL0c6eW0<1ID080iX1b00D0kh]k0>>2K`3GM640egAQ0=1UE@020<YJC0050<mK
C03CGDl0dee?0<mIB`3CGDl00P3BG4h0103CGDl0d5Y>0=1JCP3;ED/20<A?A@050;m=@`2lBT00/d<h
0;=3>02a@SL00P2Y>S401@2S=S40XC4]0:4a;@2O;2T0W28Q0080]S8`00@0eDi:0=I=A@3FCDD0edm3
0P3CCd801@3@D4<0_T@i0:</902S;2@0WRLQ0080X2TS00D0XBXT0:`c:P2/<bX0/3L/0;m?>@020;eK
>0040;5T<03b`GD0l/5e0?OGPP80ZI0n00D0SWha0=O>R`3/i[80k>Jb0=oJ^P020<C1/00509B@S`1W
I6/0IfA[04]8D@15A4`00P1:Ae00101;BU80AdM?04M7C`0o@TT203`oAP0503/nA`0i?4D0>Ca503Tl
A@0c<C`00P0/:C@01@0b;3P0;BDb02dU<P0_8c409aTX0080ShF>00@0m^of0>GPi03Uh>@0h^;T0P3R
h^801@3[jNX0hmoP06YTIP1ZI6H0IF1T0080?CTj00D0]k6c0?C^l03dk_00jnGU0>WSh`020>KRh@03
0>GQh03ShN80hn7R00<0gmoO00D0gMoN0=oQh03Nh=l0g^3O0=oMgP020>;LgP050>[KhP3og^L0omkW
0;j0R`2YDe`00P2lDET0102hAd/0_EaF0;eLEP2SFU4209YhK`030?ocjooooooooooo00gooooo000=
ooooo`040?ock`2gS8D0]hb50:MEA`80dVME00D0hVUF0=QOC03HGd`0dVME0<1ZF`020<24NP040:]n
N`32Vih0`Y^N0;fBV@80aY6G00D0`hR:0:Y`KP2ZNWH0ZWYf0?3Cc`020=c=bP050=?:c`2j]K`0^[Fl
0=?@e`3/jO@00P1mNHP0101SH7<0HEic065NL`1=Bf0203hlD@05038`A@0a;dD0;be302l]@`0g=D/0
0P13A5T01@1BDfP0EEQ[05EHJ`12@eD0=cU80080=3=100@0@3a:04]5D@1;AE40C4A?0P0o=Cd01@1X
Gf@0j]oS0?CUj03diNP0n=oU0080omSH00D0ci660<AmH@34OF40ah=B0?ZjNP020?o2M`040?>^H`3W
SDh0ihe>0?69EP80k7aG00D0eFU?0=IgI@31MFL0`GEW09m[H00207mNE@0505U8@00n=Bh0?SD^034Z
900Z9Al00P0_:280100a:R@0;bLT02lW900e;BX202XU8@0502`W8`0^9R<0<BTV034Y9P0`:bL00P0b
;BT01@10=S@0AcPe04Lh=@1B>3L0GS@e0080OT9200@0^Va/0;QIE@2hFED0^eA;0P3XPW@01@3mW8/0
ojnM0?nXU03oZ9@0o9F40080kGm^00D0kGi]0>QgI@3XMfD0ffYJ0=ETE0020=aYE`040=YUE03QJE/0
hFUK0>5YF`80i6aN00D0j6mT0>5[G`3RKV40hViQ0=e/GP020=EUE`050=EUF@3>GU<0cUiC0=1NE03?
FU400P3CEU00103KG5D0geaB0=mLDP3SHE@20=eIC@050>1JC`3IDdX0fE=:0=UCBP3RFE400P3TFe<0
1@3QF4h0h5Y>0>1JCP3JETL0eUi60080d6U600@0/f<b0>FbL@3U/W40kLb50P38/Fd01@2jZVh0[jE`
08V6G@29QUd0K6YA0080F5I:00D0AdE604]8C`1;B4l0BTUA0491B@020491A`0403`k@@0g=S/0=cHk
02l`=080<c8g00D09RDZ02LX:P0W9bT09bLY02/Z;`0202`Z;`0502lZ<@0_9Bh0;bD^02`N;@0S5B@0
0P2;OhT0103hk_H0iN3T0>GPi03ShN@20>;RhP050?Gem@2QWIh0L6Y/071ZK03Xi>D00P1jMWL01@2]
YjT0^[Bf0;Zd]P2f[K00gmKG0080jN?S00@0jnGW0>STi@3Xi>D0hn7R0P3Ogml01@3Lg]d0gMkP0=gN
h03Mg^00gMgM0080h]cN00D0jM[Q0?oNi`3og^L0`hZC09Y9DP020<YQJ0040:i0@`2mG5D0_EaE0:1H
C080VWQ_00<0ooC/ooooooooool03Oooool000gooooo00@0oo7/0;66O`2aQWl0ZeU=0P3BIeL01@3S
JUL0fF1=0=UPC@3@IE<0aFmP0080]g]`00@0^Hb70<JLWP36W9h0h[Rl0P37TiL01@2fPh80WFe[0>6k
^03Q^kP0i<o>0080g];D00D0c/C<0;Na^`2g/K/0l^oh0;>__@0205ICI00405aIK014@540A41A07ah
Q`80Wi^Z00D0U92N08n;V@2@S9/0T8bK0:FR/`0205mLK`0505=@I@10?E00@3e@04Y8EP2YYk800P2Q
WZD0102VXJL0[jV]0:nY[@2e[k420;Rb]0050=;9bP3ajNL0l>CT0?3Ti03dhN<00P3oh^001@3S[j@0
/W9G0;9bE`2jN4H0jZ]X0080olMh00@0nKYZ0=Z5@P3JQD80fWM00P3PM4d01@3ILEH0cWIR0:eUE`2]
IEL0Kcdd0080NUUB00D0QWE^07ieKP1nMFh0GUM?03lh<P0203@_:@0402dX8P0Y9200:B@P030[9`80
;BDR00D0<RXW030X9P0[8b40:b<Q034/:002030[9`0503P^;00m;Bd0?Bd]04P^;`1J<3800P1W9BT0
101m92H0Y3/h0:@k>03SL6T20?B2M`050?V9N`3nU8@0oiN70?nGQ`3oTX400P3kSG`00`3oUH<0oib9
0?nLR@020?nNR`80mI9o00@0j8=a0>AjJP3TNVX0ggEU0P3MLf<01@3LLV@0g7EV0=YfIP3JMVH0g7e[
0080gX5_00D0iXUh0>V9N@3YRGT0ihIf0>V5M@020>IjK@040?61M@3dO6h0m7a^0?EiK@80nGU^00D0
mG1W0>MNEP3_I5d0kfAM0?e`J@020?5WG@050>UOE@3VHUD0iV9E0=aQD@3FIe<00P3:LE<0102eLD`0
/hMJ0;>7FP2GNd`206iK<@0505e@;@1>BB`0A48]04A2;@1>CT800P1;BTH01@16ATH0@T560491AP0g
=CX0=38g0080=S@g0`0X8bL01@0[9RX0:RPY02XX:@0S8B80:BTW00809bLU00@0:BTY02XZ;00Z:R`0
;RT_0P0Z8b/01@0`9380:Q`[089fP022MX00m>[b0080in7U00D0i=oS0>SVi`3Xi^L0jNOX09:>S@02
0:>MW@0408MnO`26OGh0QWen0<Nn`@80PWUl00D0@cdo05QBE025Oh40QGn10:^UZ@020<K0a0050=SC
e`3Qgn00hMoP0=kNgP3Mgmh00P3Lg]d0103MgMd0h]cN0>;LgP3Yf=h20?kMiP050<bDW`2:?DL0e6ae
0=A/M@2/?d800P2hEe00102MEDT0VgU`09]iL03omN`?ooooo`003Oooool0103olN`0ZWmh0:YoN02X
ET/20=AYF@050>=ZF@3FGDX0eUe:0==UE032JEL00P36Q7H0103P[Z<0Zgii0:]nN@33Ui@20;R;QP05
0:UnN02ZQh40km?@0>oCd03Pc/h00P3Fb/h01@2n/k/0hMOP0>7Gh03^i_40OWR60080FeMX00@0DTeQ
03/gB00k=dP0`[_;0P3ajOP01@3Wgn`0i^3/0?3Zn03`j_P0em?R0080If=d00D0BdIJ02@P<@0T8340
Z:F`0?ScnP020>_VjP040>cXj@3/i^H0k>KV0>gWi`80knWY00D0l>SV0>oWi@3bi^H0l^KV0?OWj002
0?oShP050?O;`P2bNV40/WYQ0;=c@`3EUU<00P3nagD0103l_fh0g8a50=b<A@3<K3820=igCP050=Mb
E03=MV80ZfEI0:]UF@1U=B/00P1B<BX01@1IAT00MfaV07M/IP2AR840QGae0080JV=M00@0AChh03@/
:@0d;2T0:B4N0P0X81d01@0c:bP0;bLU02lZ9`0_:RL0;BPT0080<B`X00D0=B/Z03h/;00n;2`0A2LY
05LV:P0206<H7@0407`L7P37EE@0aeED0>Q]IP80jFeS00D0k79U0>QbI03[MFL0jgEW0>UaH@020>ii
J0050>]jJ03`QG<0l8Ec0?B=NP3eTWl00P3oVXP0103oV8L0oYB40?jDQ03oU8@20?^AP@050?fCP`3k
UX@0o9V60?bIQP3iVXH00P3mXH`30?nVU0050?nRT03oVh/0oIJ70?fFQ`3iRg`00P3cOFl01@3`M6P0
jFUN0>UYGP3_JF00k6=K0080k69H00@0lVEL0>UOE@3YGeD0j69G0P3OI5D01@3GIeT0_f9@0:5I@`2Q
FD<0RULl0080K4P^00D0DC`Q048f7P12=Qh0ASl/04<o<`0203Xj<P0403hn?00h>ST0>3Xi038b=080
<c8g00D0:2L/02LU:P0/:Rl0;2X_02HQ9@0302TT:080:BDV00D0:BDT02HU8@0X:B@0:2TT02DU8`02
02<S8@0502HT9`0U7RH09AhV02hR<00/7Rd00P1iKGL0103ejo<0i^3T0>KPi03Tgn<20>k/k@050=_I
fP2GTI40OGMg07egM`29PGl00P23NGX01@3=a<L0dl[=0=?:c@3Bc<h0^kFg0080R8:400@0;2HX03hh
>P0n>3X0ViFG0P3Xi>D01@3Rh^80g^3O0=kPg`3Nh=l0g]kN0080h]cN00D0j=OM0?kMiP3ngNH0dYfW
08Dh@P020=UaNP040:`o@P2kG5H0^eaF09UCB@80Wgie00<0ooG/ooooooooool03Oooool000gooooo
00@0oo7/0:YoN02ZOgP0Z5I;0P3DJET01@3SJUT0eUe:0=IMBP3CIE@0`VUG0080aXAf00@0h:jS0:]n
N@2[OWT0`iND0P2hRhH01@2YOWP0ZXN10>oCd03_dm00h<k>0080e/[>00D0_[>k0>7Gh03Qen00k^Ka
07ihQP0205]GJ004059=H@0k=dP0>cM80<:kb`80lNWh00D0imo/0>KPk03`j_P0l>[h0=OChP0206MS
M00504]6FP0T8340920a0:RU/03hloX00P3[i^X0103/j>T0k>KV0>cViP3]inL20>oYj@050?3XiP3_
inD0l^KV0?;ViP3ginP00P3ohn801@3gbl80/WYQ0;9jH@2cLd<0eIIC0080o/Me00@0o;m^0=b<A@3L
S4D0c6`b0P3NMdh01@3GLU@0cGIR0:]UF@2[IET0ICD[0080DS4Z00D0FDI007M/IP1gK6H0THR108El
M@0206YSG@0404Dn>00d;2T0=2`Y02TQ7P80:20M00D0<b/X02lW9@0_:RL0;bXW02dX9002034/:005
03D[:P0n;2`0?R`/04@W:@1G9RX00P1S61d0101l71h0aeED0<MEE03XKFH20>U]H`050>abI@3XLV@0
jgEW0>]eI`3YLF400P3^NFP01@3[NVP0l8Ec0?25L`3dSGX0mI9o0080oiZ800@0oiR70?jDQ03nU8@0
oiB40P3kTH401@3mTh<0niJ40?bIQP3lVHH0nIZ60080oJ6<0`3oYY@01@3oXY00oi^;0?fFQ`3mUXL0
nH]l0080lge_00D0l7AX0>UYGP3YJEh0kfUP0>aSF`020>aRF0040?9UG03YGeD0jEmE0>QRE`80gfAE
00D0efMI0;mRD02QFD<0XEU308YG?00206a8;P05054l8@12=Qh0@SHN04Ho;013?c<00P0j>S80100n
?S`0>3Xi03Pj>@0b<S@203<b=`0502PW;00W9BX0;2X_02`Z;`0V8BD00`0Y92P202TU9P0502TU900V
9B40:2TT02PY900U9B<00P0S8b401@0V92L09AhV02DN9P0^8S00;1h]0080NFeg00@0mN_c0>KPi03V
h>@0i=oS0P3^k>d01@3KfMX0Ui6A07egM`1mMgL0RH5o0080PgUj00D0cLC70=?:c@3Cb/d0d/c>0;^e
]`0208R2Q00402`V:00n>3X0?SPj09^EU`80j>CU00D0h^;R0=kPg`3Nh=l0g^3O0=kNgP020>;LgP05
0>SGg@3ngNH0o]gV0=:MY`25>4800P3ILGX0102/?d80^eaF0;]LEP2IDdT209mnM@030?oek?oooooo
oooo00gooooo000=ooooo`040?obkP2bQh00/XN00:IDB@80eFMJ00D0iV]K0=ePCP3MH4h0f6EB0<m_
F@020=25L0040;f4L@24EDD0Q5E507aEA080Z8Ad00D0[I200=>k[`3Kb<80flS20>[Hf0020<jn`@05
0<bk`@3hjO00n>W`0<c1b@1NEV400P1PFF/0101BCF40BDAJ04U4FP1cKX82089kS@0507efR025OY00
RhBF08^4UP1gL8800P1KE6H01@0i<T80ACm=04DoC@3TgnH0kNO[0080jN?U00@0j^CT0>cSi03/hn@0
k>?T0P3]i>D01@3ai^X0lnS/0?KWk03fin`0n^O[0080o>;S00D0om[C0;b:L`2lRW<0]WM;0<B4A002
0?_4M0040?_1K`3QTd/0hI=;0<e`<`80gGQ<00D0egAE0<igH`2VHE80YV5B06Dd;@0205@c;P0504dh
=@1=?S/0CChk05]=BP1hKFT00P2AQX80102@QH40KVEP06iUH01?B48203H_:@0502XU7`0W8Qh0:bHR
02/V8P0/9b<00P0_9b@01@0e:RP0?RPZ03hX:P168RH0EA`R0080IA0G00@0TbT]0=eSHP3MHf80kVYU
0P3]J5l01@3bKV80kfeP0>aZG@3/JUd0kVYM0080kFUL00D0kF]M0>e_H03]Kf00jW5P0>adH`020>if
IP040>ecI03`MVT0l7IY0?AjK@80m7a^00D0kWQZ0?9oK@3cPW00lh9`0?B6M@020?R=N`050?R:N@3g
RGP0mhUh0?V;NP3iRG/00P3jQWT0103fOG80lWIZ0?9fJP3cLfP20?EaI@050?E/HP3cJEl0lVQN0?9X
GP3^I5X00P3/IU/01@3SIEL0gFeO0=e]G`2nHUD0Qcla0080HS4R00@0CblP04Ld9P17=2H0?C<W0P0c
;b@01@0_;2D0<C0/02l_;`0_;bl0:b`^00809BT/00D09RL[02X[<00Z:c009RH^02HV<00202LT;`04
02PU;P0W92/09b@[02XX;@80;BP/00<0;2PW02LV8P0T9B000P0T9B0202DU8`0502LU:00Z8bX0:R<Z
02TM:@0Z72/00P22MX00103ejo<0i^7U0>KQi@3ShN@20?3^k`050<o>c02PVYX0CDM704e7A`1_IfD0
0P1oMgD01@38_l00THR90968R@2`YjP0/:RV0080aknm00@0/JVW0<>j^`33^[/0fmGE0P3Th>401@3P
h>00gMoN0=gOgP3Mgmh0gmoO0080h]cN00D0jMSN0?gNiP3mg^H0dijX08<f@0020=YbN`040:m2A@2k
G5H0^eaF09MCBP80YXEl00<0ooK^ooooooooool03Oooool000gooooo00@0ooOc0<FNU`35WYL0XU99
0P3DJ5/01@3VJ5T0gUe:0=iMBP3KHTd0e6aC0080gHU_00@0`GmU08QE>P28ECX0NE@i0P2mWhD01@3J
aK00g<bm0=c=aP3LcLH0i=CE0080bkRl00D0jMCI0=6na03A_/@0e/G=05U=E`0204Y2D@04055:G01?
Ae`0CdML05Q@I`80GEEZ00D0GEIX069KK@1TFfh0I5]^05aCIP0204i5EP0502HN:`2YXJ`0ZJ6/0?C]
m03Zi>P00P3[iNL0103/i^H0kNCU0>gTi@3_i^L20?3Wk0050>cQj@3_i>`0lN7[0?7Qj`3/f>400P3e
g=l01@3oh=X0b9Z30<RJP`2iO500^WXl0080m[ia00@0olAc0>FGC@3UUdd0bFla0P3KND`01@3AL500
d7]V09iJC@2NFTd0Hc@/0080D34^00D0BcHc04dn>`1=?S/0ACLd04`n>`0205U;B004079WH`2AQX80
THJ20968P`80NG9/00D0EE1:03/c<00^:BD0;RTU02XU8@0202dU8P0503HX9`0n9RH0?RHV04HL801D
4aT00P1Z3Q<0102^?Cl0jFUV0>UYIP3]IV020?5WG@050?AZG`3cJEh0lVQM0?9XG@3bIE/00P3eJ5h0
1@3aIeX0l6QJ0?1XFP3aK5d0lViO0080lfmR00@0kFUL0>iZG@3^JUd0kFUL0P3/JUd01@3_L640jFYK
0?1bH`3`LV<0jg1Q0080jg5R0`3]LV<01@3/L6@0jfmS0?5cI`3aLfL0lW9W0080kfaR00D0mFmT0?=Z
H03cJV00m6YP0?=VG@020?9UF`040>mRF03WHED0if5E0>5VE`80efeO00D0^FEJ06hb9`1581L0AB0G
03XV7@0202hS7@0502`Y900[:RP0:bXX02HV9P0W9R/00P0Y:Rl0100R9B`082@]020T;@0P92l202@X
<`0502@W=P0Y:cX09bHf02LV=P0/:SP00P0];CT01@0/:c<0:RP]02XX;@0Z:2T0:BLX00809RDS00@0
9bLU02LW9`0W9bL0:RDY0P0^9bh01@0Z7RX0;Al/08n3S@2?Phd0mnge0080iN3T00D0i>;S0?;ak`3b
lNl0`Kfl09FAT00204I0@00406EMF`2ESH/0UHf;0=37b080IeiO00D0Dd]903@/:P1lM780O7Ab0:fU
X`020<>k^@050=kHf03Th=l0i>3O0=oOg`3Ng]h00P3Nh=l0103Pg]l0hM_M0>7Kg@3Yf=h20?gNiP05
0=BP[022=T00fWEm0=YeO@2X>ch00P2`Ddh0102HED`0/9::0;2BRP3omNl?ooooo`003Oooool0103o
mo<0aIjG0<FNU`2RDTT20=AXF`050>IXF@3NGDX0gUe:0=]RC@3DK5<00P3MRFl01031OfD0R5Dj08QE
>P1iE3T20;fOQ@050=[5/03Lc;d0g<g60=c=aP3Te=D00P3;^;`01@3Ye=T0dKk40=6na03FaLd0FDeG
0080BT9A00@0DDYL04m7G01?Ae`0F51W0P1MEFX01@1MEVP0HU]]06AKKP1TFfh0G5=V0080CTEF00D0
9Qh[0:VQ[02YXJ`0m>gd0>[Tj0020>_Ui`040>cViP3]i>D0kNCU0>oVi`80l>O/00D0k>7Y0>oTk03a
hN/0lN7[0>cHh@020?GLg`050?oPfP38VX<0b9Z30;UlD02jNS`00P3f_W40103oa7<0iIM=0>FGC@39
Kc420=]iC0050=5`D03@NfH0WUY=09iJC@1S=2`00P1@<Bh01@1;=S<0CChk04dn>`15=c@0C3hk0080
FD]800@0LVMS0966PP2AQX80THR30P1iLV`01@1ED4X0>c<`02hY9@0^:BD0:RDQ0080;BDR00D0=RPW
03hV9P0n9RH0AQ`P05@C6@0206X>4`040:hm?`3YJFH0jFUV0>eVH080lFMM00D0m6YO0?=YGP3bJ5d0
lVQM0?9UF`020?EXGP050?5WFP3`J5X0l6QJ0?5/G@3bKUl00P3cKf80103]JE`0kVYM0>iZG@3]JE`2
0>aZG@050>m`H@3YJU/0l79S0?1bH`3[L6400P3[LF830>ebH`050>a`I03[Kf<0lG=W0?5cI`3bLVL0
0P3_K6801@3eKf@0lfYP0?=ZH03dJV00lfIM0080lVEK00@0kf9H0>MQE@3WHED0hFIG0P3GKEl01@2i
IEX0KS8W04DP5`1581L0>RHM0080;R<M00D0;2TT02/Z:00[:RP09RHV02LV:`0202TZ;`04028U;00P
92d082@]020T;`8092Pc00D092Lf02T[>P0W9SH09bHf02`Z>00202d]>@0502`[<`0Z:2d0:RP]02XX
:@0Y9bP00P0V9B<0100W9bD09bLW02LW9`0Z9BT202hW;P0502XN:P0]7b`0Sh>=08n3S@3gkOD00P3U
h>@01@3Th^<0l_7_0?;ak`31_K`0UI6@0080AT1000@0IEeK09F=R`2ESH/0d<O80P1WGUl01@1CBdT0
=2`Z07adLP1lM780[JFS0080`k^i00D0g]SH0>CPg`3Th=l0gmoO0=kNgP020=kPg`040>3Ng`3Qfmd0
hM_M0>WHgP80oMkV00D0e:2/088f@03JMGd0fWEm0:Pk?P020;1CCP0409QEC02`TXX0/9::0?oek`oo
oooo000=ooooo`04003o003I^;<0fKRc09iDB`80cVAG00D0ifUK0>1MB`3PGD/0g5m90=a]DP020=]n
G`040<MlG02ZLTl0ZW9?0;bFLP80dKJH00D0iMFl0=c@`P3Uf]H0iM[F0<^k_0020=W4b`050=>j`028
KgD0R6me0>39d@2hYjl00P1@A500100h;Cd0<BPi034X>@0h;d8203lfB@05040gB011>DP0@SM7048g
A`10=D<00P14>TD01@2<PX/0l>K^0?3VkP3cj^l0lNS]0080knKY00@0k^GX0>gWj@3]inT0m_3d0P38
`LT01@2>QY<0Y9NX09N9V02GRIP0Pg5m0080jmCJ00D0onCO0<bORP3<WhX0^giA0;Ed=0020?>jJ`04
0?o4L`3WVDl0iiU?0=1f>080f7M:00D0cW5@0<UkI@2BE4L0TUA705H[900204``;00504Pf<P18?CL0
B3dg04Pm>@15>SH00P17?3X01011=S@0E4U705A9A`1/HV0208QoNP0509B=Q`24NgH0IEiH06ENF016
?S/00P0g;B/01@0`8200>b4R03/Q8P186ah0EQ4D0080N1PJ00@0beAF0>YVHP3ZIV80kV=L0P3cIUd0
1@3aI5X0lVQM0>mUFP3_IEX0lVII00<0m6QK0P3`IUT01@3cJUX0m6YM0>mWF`3_Ie/0lVYN0080l6IK
00D0kVAG0>mUFP3_IEX0lFUM0>iVFP020?1XG0040>mYG@3/IUX0k6IJ0>]UF@80kVQL00D0jfEJ0>YT
F@3_IU`0kfIL0>mUF`020>aRF0050>mRF@3`HET0l65I0>iPEP3^GUD00P3[Fe00103[GE40j61D0>QP
E03OHE<20=Y_G`050<1ZG@1Z;R<0?AP@03dH400d8A/00P0_9b@01@0Y:2H09RHX02HV:00Y:Rh09RH^
00808B<_00@08BLc01dT=00M93@08BPk0P0[<dP01@0Y;dD0<SM=03TkDP0i>e80=cY=0080=SQ700D0
9BLc02<S:`0S8b/09RDZ02/Z;`0202HV:00402LW:@0Y:B/0:BT[02/V;080:B8Z00D0<2<]02`O:@2H
S9H0V8bF0?K_mP020>GPi0050>CRh`3elO00mO7`0:^WYP28Q8<00P1JE5@0101`J6H0Xi^I0:>KV@3W
hN420=WCd`050=_Fd`2l]k@0MG1]07E`K@0c;Bd00P1OFET01@33_kh0inKT0>OVi03Ph=h0gmoO0080
g=kM00@0g]cO0>;Lh03Rg>00jM[Q0P3kgND01@3HY[40QSi90=AcNP3DLgX0WSHg0080[E9=00@0UeM>
0;RKU@2hViD0ooOc3oooool000gooooo00@00?l00>K9a@3VbLD0WeUA0P3=Ie/01@3VJUh0hUe>0>9M
CP3PGdX0gfU?0080gGUI00@0bg]H0;b2G02lPU`0bJ9k0P3PajP01@3Kbk80j]k@0=kAb`3NdL/0a[Jg
0080jmKM00D0f;g60<^_^`3;[k/0h/_E0?STk`020=g=fP040;FX^@2UVZ/0YIZ[0::I[080X9NZ00D0
XiRY0:2EY@2[X:h0Zj2^0;b`_0020<k2c0050>oTk03cj?00lnS`0>3Eg@3Qe]h00P3`in`0103cj^l0
l^_b0?;[lP3flOP209bFY00507=/O01nLXH0Ge1S05m@H`2DPi<00P3ki>`01@3oh=`0bYZ40<ZJQ02l
OE40]WDe0080lkQZ00@0ol5a0>RJD03XVU00dGPl0P3JNdl01@3:LE40aWiX08=;?P23Bch0BbHN0080
B30/00D0B3Td04@k=P14>cH0Bd8m044h<`0203le<`04040f=013>CL0@cTg04Pn?080Bd8m00D0IeiI
085hL`2ES8L0UHb708b2P00207Q]J`0505]9A`1?<C40Cc4a058P8@1E3@h00P288B80103IGeh0kfYU
0>mZI@3`HeX20?1RF0050?5SF@3aI5X0lFML0?5WG03_HUP00P3dIed01@3bIE/0l6=I0?1SF@3cIU`0
lVEK0080m6MN00@0lFAK0?=UF`3cIE/0lfEK0P3aI5X00`3dIed0lVEK0?5TFP020?5TFP<0m6MM0P3`
HeT01@3dIeh0kf9I0?9SF`3bHe/0l65I0080kemG00@0lF5I0>iNE@3^GUD0lUmG0`3_G580103]GE80
jEmB0>UODP3RHUD20=MYFP050<E_HP1]<BH0?A/B03dK4P0f92000P0_9bD01@0Y:B/09bP]02LX;@0_
;cL0:B/g0080:Bdi00@09bdm02T`@`0Y<4<0=cmF0P0mA5h01@0k@U`0?49L03/oF00k?eP0?T=G0080
<SE600D09BLd02@T;P0T92h08R4Y02TX;P0202DT:P04024P9@0Y9b`0:BL/024L8`8091XS00D0:1/U
030S;@2PU9h0X9BN0?C]m0020>COh`050>GSi03cknh0lno^09fIV02CShh00P1HDU80102=QhL0/:NX
0;2WZ03>b<P20;Vc/`050=;:b039`Kl0`KRi0<6h^@2l][H00P3Je=@01@3Sgmh0i>3O0>CPg`3RhMl0
h>3P0080gMgM00@0gM_N0>;Lh03Rg>00jM[Q0P3kgND01@3FYk40PSa60=IgO@3FMgd0VSHf0080ZEA=
00@0TEE;0<6UX@31YJ400?l03oooool000gooooo00@00?l00>K9a@3VbLD0WeUA0P3=Ie/01@3VJUh0
hUe>0>9MCP3PGdX0gfU?0080gGUI00@0bg]H0;b2G02lPU`0bJ9k0P3PajP01@3Kbk80j]k@0=kAb`3N
dL/0a[Jg0080jmKM00D0f;g60<^_^`3;[k/0h/_E0?STk`020=g=fP040;FX^@2UVZ/0YIZ[0::I[080
X9NZ00D0XiRY0:2EY@2[X:h0Zj2^0;b`_0020<k2c0050>oTk03cj?00lnS`0>3Eg@3Qe]h00P3`in`0
103cj^l0l^_b0?;[lP3flOP209bFY00507=/O01nLXH0Ge1S05m@H`2DPi<00P3ki>`01@3oh=`0bYZ4
0<ZJQ02lOE40]WDe0080lkQZ00@0ol5a0>RJD03XVU00dGPl0P3JNdl01@3:LE40aWiX08=;?P23Bch0
BbHN0080B30/00D0B3Td04@k=P14>cH0Bd8m044h<`0203le<`04040f=013>CL0@cTg04Pn?080Bd8m
00D0IeiI085hL`2ES8L0UHb708b2P00207Q]J`0505]9A`1?<C40Cc4a058P8@1E3@h00P288B80103I
Geh0kfYU0>mZI@3`HeX20?1RF0050?5SF@3aI5X0lFML0?5WG03_HUP00P3dIed01@3bIE/0l6=I0?1S
F@3cIU`0lVEK0080m6MN00@0lFAK0?=UF`3cIE/0lfEK0P3aI5X00`3dIed0lVEK0?5TFP020?5TFP<0
m6MM0P3`HeT01@3dIeh0kf9I0?9SF`3bHe/0l65I0080kemG00@0lF5I0>iNE@3^GUD0lUmG0`3_G580
103]GE80jEmB0>UODP3RHUD20=MYFP050<E_HP1]<BH0?A/B03dK4P0f92000P0_9bD01@0Y:B/09bP]
02LX;@0_;cL0:B/g0080:Bdi00@09bdm02T`@`0Y<4<0=cmF0P0mA5h01@0k@U`0?49L03/oF00k?eP0
?T=G0080<SE600D09BLd02@T;P0T92h08R4Y02TX;P0202DT:P04024P9@0Y9b`0:BL/024L8`8091XS
00D0:1/U030S;@2PU9h0X9BN0?C]m0020>COh`050>GSi03cknh0lno^09fIV02CShh00P1HDU80102=
QhL0/:NX0;2WZ03>b<P20;Vc/`050=;:b039`Kl0`KRi0<6h^@2l][H00P3Je=@01@3Sgmh0i>3O0>CP
g`3RhMl0h>3P0080gMgM00@0gM_N0>;Lh03Rg>00jM[Q0P3kgND01@3FYk40PSa60=IgO@3FMgd0VSHf
0080ZEA=00@0TEE;0<6UX@31YJ400?l03oooool000gooooo00@00?l00?7Ie@3afMD0ZVUS0P36IE`0
1@3RIel0h5a?0>1LC`3OFd`0hFQC0080fW9G00@0dWmO0;5gDP2aMe80cJN30P3G_Yl01@3C`jX0iMG6
0<Vj/`39^[<0hLo?0080j]GL00D0ckO40:R@X02XT:00ZiBV0:RCYP020:6?Y@040:2BZ@2ISJD0VHfU
09V=Y@80ThNM00D0V8ZQ09N:WP2MT:80WI2R07mcP@0209R<V0050?;Vl02`Y:h0/:B^08=ePP24N8@0
0P2bZ;40103`jO40n_Cn0?[doP39a]42075]OP05079]P@1WGW<0D4=G0513E`3Ga=L00P3nhn`01@3o
emH0b8mk0<R?N`32OU40_gXi0080n[ma00@0oKi^0>6AB03QTDP0fX140P3CMT/01@3:MEP0_7UV07M5
>P1gACX0CB`U0080B3D_00D0?c@`04<k>013>cP0BD4n04@l>@0203lg=00403`d<@11>CH0@CTf04Dm
>P80?SLa00D0@c`f04@j>01ICdd0FDm=06iPG@0208ajN00509MoO@2BKfd0TVm]08aDD`1o<Bl00P2S
>cP0103UJVD0jfEL0>]UG03aI5X20>iPEP050?9TF03cIeX0kF1F0>ePEP3cIE/00P3bHe/01@3cI5`0
lF9L0?5RG03aHUh0lfAP0080lF9N00@0m6EQ0>mPFP3_H5X0lF9J0P3eIUh0103`HET0m6EM0?5RFP3a
HUX30?9SF`050?5RFP3bHe/0lV=K0?5RFP3bHe/00P3aHET0103`H5P0lEiF0?5NEP3_G5@20?9OE`05
0>mJD`3_Fe40l5aB0?1LDP3_G5800P3XGU401@3OGe80f6YK0=QZF`39LfH0LcL]0080?AXD00@0>2HT
02dW:@0]9bT0;Rdc0P0];CD01@0/;3H0;c4n034d@`0a=4<0>SmB0080@DIJ00D0ADUR04=7H013Af00
@dMP03m4FP0203e2F0040412E`0^;d40;Rm1028T<@8071XW00D071XU01hL9`0S8RX08b8Z01lL8`02
02`W;P0503hg?P1CBE80DdUB06ePJP1PDed00P2OTid0103cjO40hn7V0>?QiP3Rh^@20?;`l@0507ij
N@2k]KL0aKo10<Fo`@23OGl00P3?bLT01@2TWYh0YijO0:NNW`3Db//0el_=0080fL[=00@0gm?E0<c2
`@3<`/40e/k<0P3Vh^401@3Qgn00gmoO0=kNgP3Ng]h0gmgP0080hmgQ00D0j=WN0?[OiP3jgnH0dj6/
07hh@0020=9hNP0409Pk=P2VF4`0YUQ<08]EB@80a:fW00<00?l0ooooooooool03Oooool000gooooo
00@00?l00?k[i`3njnL0/GI`0P2lHUT01@3MJ5l0hF5F0>5QEP3NGe00hV]G0080f79I00@0bgaN0;Qo
H@2hOf40i;fN0P3WcK801@3Pc[P0iMC40>KEc@3VeLd0g<[80080kmcP00D0OFUe05a7F01LAeP0G4UL
05A3EP020511EP<0C3iE00D0Ac]A04HhC`16>4l0BCa@04e0DP0204m2D`0402/O;@2/X:`0[:2/0?KZ
m080OG5k00D0HE=P06YNJP1ICeX0FDmJ0=cDg`020??`n`05092<V`1SH7<0Hf1c06IQM`10=Th00P2?
P9D0103hho@0oMkV0?gNiP3f`l020<B3K@050;igB@3<QdH0ol9g0?o2M`3k^F/00P3IQT001@3RQD`0
cg=:0<mcBP35M5L0]gQV0080Jcld00@0C2lY04Tg<`19=c<0?38`0P0m>3@01@0o>SH0@3/g04<n>P13
?SX0?STe0080>C@`00D0>SDa03`g<@0l=c40@3Tc03de<P0204<h=P0404@f<`1<>CD0C3Te06M;B080
R5aK00D0ZVYX0:eHE@37G5H0aeaF0>AXH0020>aVF`050>eQE03aHeL0lF=G0?1REP3_HeH00P3_IEX0
103]HeT0kVEO0>iUG`3ZIF020>MUH`050>MWJ03UI6P0j6QY0>QXJ@3YIfT00P3/IVL01@3ZHV80jf5O
0>]QG`3^Hf00k65N0080kV=P00@0kV9Q0>aRH03/HV00kF=Q0P3[HEh01@3^Hf00jUmL0?1RH03`HV00
k5iL00<0jeeK0P3[FeX01@3^Ge/0kEaI0>YIE03ZFE@0kEiH0080ieeC00D0hF5F0=IVFP3FIUX0bW=Y
07Pl<P0203dJ5P0403h/;00b;300<R``02d/<P80<30h00D0<30j03@d@00`<T40<39103XmCP0203Lj
C@05030aAP0b<dP0<S=803@gBP0X:ch00P0U9SP0100N7c4081l]020O;@0T8Rl202h[=P05048oB01J
Ef00JfQ_06]XK`1aK7<00P1eKWD01@1gL7L0M6Yb07AZLP1TEf40>2/e0080XYJP00@0lncc0>?QiP3S
hNH0hn?U0P3fm?D01@1lNgT0FUIG05A>D01DCU00RhN80080m_;c00D0QX20069IFP1RFEX0Ge=E05m@
D`02061@D`0406=CEP14>3P0A3Ph0;Zb/080kNOW00D0hMoP0=kNgP3Ng]h0g]kN0>3Nh@020>;LgP05
0>SIgP3jgn@0n]oT0=2OY@21?4400P3;LW@0102C?3D0YF1A0:EPD@1oDD820<fj]003003o0?oooooo
oooo00gooooo000=ooooo`04003o003om?80ooCb0;^6P080]69G00D0ef]O0>I/G`3VK5l0eee>0=m`
G@020=anI@040;meG02mQfl0_HM_0=B^U`80fKfX00D0glRh0?;Od@3?_[@0ckjd0<Nh/`020>GGe`05
089cNP1jKGL0NVeg07IXM@1dIWD00P1bIW@0101eJ7T0M6Mh07AWN01_HW<206iPL@80JE]Z0P1?@Dh0
101aIFl0lNK^0?7VkP3klOT20<6g_`0506eRJP1DB580M6ee07A]M@3/i_000P34`<h01@1YIWL0If9h
06MRN01GCfH0?C570080e/GG00@0nN7_0?oKh03ofn00iZNP0P36OVD01@2hLT40i:1Q0?o3NP3o`gX0
nK=[0080dg/l00D0gWi;0<ibC@3>LTd0agML0:meH@0206@l<00404P_:014=C00A3D`040f=080?SHd
00D0@3Pf048j=`17?c`0Acll04@m=`0203de<P0503/c<00l=340?3@a03/c<00i<Bh00P10=S@01012
<c00Ac8_04Lb;`1B<2l205/Y:00506TO7P2:;2X0e65L0=AQG03ZJV400P3ZI5P01@3bIUL0lF=E0?5S
E@3_HE<0lFEH0080kFEI00@0j6EM0>EZI@3UJVD0ff]Y0P2mEEH01@2bCe@0/E1I0;9AFP2bDEX0_5AM
0080dUi[00<0g61[0>ARK03THV`00P3VHf/20>5OI`@0hf5[0P3SHFT0103SH6H0iV1W0>IPJ@3VH6T4
0>ANI`80if5Z00D0iUmV0>QOI`3WG6<0ieaS0>MLG`020>QQGP050=mNF03GIe`0efML0<]dJP20A3X0
0P0m6QH0100o;bl0<R``038/<00V9B/202XZ<P0502PX<00V9S0092@^02@T;P0W9c<00P0S8S001@0P
7bd0:bXh02/Z>00d=400?3a80080BTQE00@0FUQS06MTK@1WI6d0KfYa0P1mMWh01@22Nh80NW=j06aW
J`1/If/0Ee5E0080CDM;00D0>cDi03H/=00f;3@0;R@]02TO:0020;J_]`040?7/lP3ShN@0hn7T0>?S
h`80l_;b00D0^;Rh02PV9`1KFEX0FeUJ0=3?c@020>k]j`050=??cP3KeMD0fmGE08EkNP2`Y:H00P3A
`/D0103>_l80Z9bL0:RLW03Fc/`20>STh`050>7Oh03Ng]h0gMoN0=gOgP3Ogml00P3Rg=h01@3XfMh0
oN3T0?gPi03;V9d0Q3m20080`Fe[00@0TT8i09UNCP2IGTh0NEA40P3Fal000`00o`3oooooooooo`0=
ooooo`003Oooool01000o`00ooCb0?odlP2kQX020;ARE`050=M[G`3VK5l0iVaO0=MMCP3OL5d00P3L
OVD0102oME`0_HM_0;f7K`3D[YL20=VmZ0050=o8^03bgm40ckjd0<nn]037^;<00P3UemL01@22LgX0
NVeg07Y]M`1fJ7D0M6Ie0080LVId00@0MFQi07AWN01dIgP0Kf9c0P1^H74206UKJP80Cd5>00@0LFE_
0?7VkP3ai^h0no7i0P31]kl01@1]HVX0E4QB07A]M@1dKGD0k>K`0080a<3>00D0JFIg06MRN01WHWP0
EdmV03daA`020=K5e`040?WQk`3ofn00om_P0>JWX080aWiU00D0^7910>BPH@3o`gX0ol=j0?VcJ`02
0==k?0050=inB`3>LTd0cW9=0<MgG02_MF400P1T?3001018;bP0A3D`04@e<010=S@203hf=005040h
=P12>SL0Acll04Lo?014?CL00P0m=C801@0k<c00?3@a03`d<@0k<c00>C4^0080@3Hd00@0@S<`04Lb
;`17<Rl0DS0_0P1K:BP01@1Y7ah0RR`Z0=AQG03DHE`0jVYQ0080jVAH00D0lVIG0?5SE@3aHeD0kf5C
0?5UF0020>eUF@040>QUG@3UJVD0iFYU0=][J@80_EEF00D0/TmD0;5@F@2bDEX0/U5J0;aDG@020=9N
J`030=aPJ`3THV`0i69/0080iV=[0P3QGfL40>=QJ`80hf5Y00@0hf1V0>IPI`3VH6T0iV1Y103TGVL2
0>MQJP050>IOIP3XGfL0ieaS0>MLH`3WG5l00P3XHEh01@3OGUP0efML0=MWG03;M6X0P4@j0080?AXF
00@0?bl_038/<00b;3009RD[0P0Z:S801@0X:3009RH`02@T;P0T92h09bLc00808b8`00D081l]02/Z
>00[:SP0=3A003`lB00204Y8E@0405YHH`1WI6d0IfA]06mZL@80OGIn00D0PW^207YcNP1/If/0K6M[
05MAE@0204e7B`0503/e>@0f;3@0=R`d02hT;@0Y7bP00P2f[kL0103ak?80hn7T0>?Qi03Shn<20?;b
lP050;Rh^00X9RL0FeUJ05]IFP3@cld00P3^kN/01@3Cclh0fmGE0=_Ee@25NgX0/:BV0080dL;500@0
c[o20:RLW02XW9`0e/k<0P3Xi><01@3Qgn00g]kN0=gOgP3Mgmh0gmoO0080h]cN00D0j=WN0?gPi03m
h>@0biRM08@o@P020<5]J`040992>@2IGTh0VEi>07UDA080e/O000<00?l0ooooooooool03Oooool0
00gooooo00@00?l00?ogm03omo@0bijH0P2]HeP01@3>J5`0h6mO0>1_G`3SM6<0dVeK0080dWm]00@0
XF1>0>>eYP3S]JH0gknd0P3Oa;d01@3MbL80iMC=0>3Bc`3Pd/l0i=SH0080imcP00D0gmGM0>3Fh@3P
e^40g]CO0=cAg`020=oDi0040=cAh@3Ndn<0g]?S0=kCh`80gM3Q00D0g=3N0=S;g03:_/`0b[k<0=36
d@020>GKiP050=oHh03VgnL0i]oW0=_Ag03?am800P3Yhnd0103^joH0R8BE08R4U@1SGW8206INM@05
03@X?P25M8L0onOg0?oWm`3og^L00P3kbLP01@3>RGT0bGeK0<UmF`2mMd<0n[Ug0080okmh00@0l:EQ
0=Uj@P3INT80eWA50P3AM5801@34N5h0YVmK05li;01O>B`0Bc@^0080A3Db00D0@SPg040h=P10>3H0
?SHd03lg=00204Dm>P0404Dn>015?3L0AC`g03lf<@<0?CDb00@0>S8_03`b<00l<S00@34^0P17;bd0
1@1B:b`0Fb<T05/S901Y5aT0VC<a0080gVMQ00@0kFYP0>mWF@3_IeT0l6AE0P3`I5<01@3_He@0kFEG
0>UYGP3YJEh0gVMO0080hWUe00D0Y4a:0:EIF`2UFE/0f9:J0<=oRP020;E^O0040;9TLP35J7/0aFQk
0;=<G`80dfMf00D0ef]h0;M?FP2/AU40[4IA0:U5D@020:=2C@050:Y6DP2YAE40ZDEA0:e7DP2/A4l0
0P2_Ae80102iD5h0]TeK0;I=F`2gCU`20;E<FP050;a@G`2nCU`0`4aI0<1<F@39D5T00P3GFUh01@3O
Hf40e6EN0=AUGP3?N6l0PTHl0080?AXF00@0;alO02LQ9@0W8BD08b8X0P0V9Rh01@0c<c/0=S@o040n
B@10?TT0CTaI0080GE]X00D0HEm]06m]N`1_KG/0MgF207ekQP0207=`N`0406]XL@1QG680HEaR059=
D@80Ad5500D0?3Hh038/;P0a:bd0<B/]02`V:00202hX:P0502hX;00/9RX0;2HZ02hT;00f;cH00P3;
a/`0103^k>l0h^;R0>;RhP3Rh^830>GUi@040;2`/032`/80`/;20>GUh`80i>?Q00D0k>SW0?gel`3m
mO<0N6i]06QLG00207m`L`0407Q/KP1^I6D0KVAU0=cCe080jNGV00D0g]kN0=kPg`3Lg]d0g=kM0=kN
gP020>7MgP050>SIg03oh>D0on3U0<FAU@29AD@00P2hIf<0102BB3d0TEa<095LC025IEH20>cRf@03
003o0?oooooooooo00gooooo000=ooooo`<00?l000@0f[>/0:MUF@2WIET0b6]L0P3HKe`01@3/QgD0
dGQX0:=OE02SGe@0_8^40080j<S900D0OVU^08=bNP23LWX0QGR108f1R`0208MmQP0409N?VP2ESIX0
UHfJ089lRP80PGf<00D0O7R907mhRP1mMHX0OGF:07Q_Q00207YaQP0507edR@1kLXL0Ng:707YaQ01f
KX<00P1fKh40101oN8X0RhBF08^4UP26Oi4208N0TP0508n8V02HTJ40YJ6b0:FQ/P2HTjL00P1^IWd0
1@1[HGT0EdUP05M9H00l:Cd0ekkC0080omo]00@0om3E0=fMT`3MWI<0chAW0P2oLT@01@3HV5X0ol5h
0?ZdK03j]6`0hHi<0080fgM300D0g7M=0=1eEP3@MEH0bGiW09QSD@0205/i;@0404hf<P16>3L0ASPg
03hb<P80Acdn00D0?38a040f=011>CH0@CTf04Ho>@0204Dn>00504<l=011>S@0@CXd03hg<@0k<Bl0
0P0k<2h01010<Bh0BBl`04T_<01A:2`205lQ9P05078I6`2Z?S`0iFQT0>EXI03_JF000P3^I5L01@3_
He@0l6AE0?1TE@3[HeD0jVQJ0080gfUO00@0fG=^0<McL@37Lg40LC@c0P3=Wj401@3og^@0o=CM0?[@
gP3jd=h0omCU0080j:Fg00D0UT]O0<5ePP31MH80Rd=?09iRJP020=JQZ@040=n^]03?X:H0cj2V0<VG
X080`i6J00D0_hbC0;9oQP2YM7`0ZGAl0:YeO`020:1[M@0509]SKP2JH6`0VV1/09IHI@2RFf/00P2Y
F6L0102dEV@0[TA>0:i4CP3@GUh20=IZI`050<E`J@2:CTH0G3Te05`i=@1LBTX00P1NF5X01@1PGfD0
IVI^06IVKP1]L7T0LG5m0080Kfil00@0KVem06i]O`1^KGl0G5]]0P1BDF<01@13@540@3i<03@`?P0d
<3h0<2df0080;RT_00D0;b//02/W:00[9bP0:RHU038^;@0202dY:00402hZ:@0[9bH0:bLV02`X:@80
:B@X00D09R0T03hh?03IemX0fMOJ0>c/k0020>7Qh@040>?Sh@3QhMl0hN7O0>7Qg`<0hN7Q00@0i>?Q
0>KRh@3Vh^40hMWG0P3_hn<01@3<_[d0]:BT0;6SX`2aXj<0ZinQ0080TXV:00@0hmgM0>CRh`3Th^<0
gmoO0`3Nh=l0103Ph>00hmgO0>?Mg`3Yf]d20?oQh`050;V1Q02FCdd0Z5QA0:QHD@2PF4`00P27EdT0
102LPWD0o_G`0?kel000o`0?ooooo`003Oooool3003o00040=Zc[02WIET0YfEI0<Q[G080f6mL00D0
k8Me0=5hJ02SGe@0XemD0;b;Q0020>S8b@0507iYKP23LWX0Pg9j08EhP@2=PH/00P27OHH0102GSiX0
UHfJ09F=VP22O8X2085mS00507ahR@1oN8X0OGF:07eeRP1hKh@00P1jLHH01@1mM8T0Ng:707]bQ`1j
LH@0MVj30080MVn100@0OgR:08^4UP2;Q9H0QWnA0P27P9801@2?R9P0V96Q0:FQ/P2UXK80V9>W0080
KVIm00D0Jf5i05M9H01GBF00?2Tm0=Nnd`020?oOk@040?o@e@3MWI<0gIfC0<n4I`80_g9400D0f9QJ
0?o1N03j]6`0n[A/0>6>C0020=]g@`050=agC@3@MEH0d7EF0<UnI`2HHe400P1K>Bd0101>=S80ASPg
04Hh=`0n<S8204Lm?P0503`b<@10=S@0@CTf044i=P16?cT00P15?SP01@13?3@0@CXd044j=00n=c40
>c4_0080>c0^00@0@34^04T_<019;c00DBP/0P1O8BH01@1b6A/0ZShl0>EXI03UJ6@0kfUP0080kVAG
00D0kf=D0?1TE@3`I5D0jf=E0>YXFP020=mYG`040=UcKP37Lg40ag=a074d<`80cInQ00D0omkT0?cD
g@3jd=h0n]3N0?oDi@020>RU]`0509I;G`31MH80`GF208]3C`2NHVX00P3FXJT0103O[[@0cj2V0<nP
YP39Uj020<>AVP050;n<T`2bOhH0ZGAl0:UdO02ZMGl00P2PJgD01@2KHfh0VV1/09YPK02FF6D0XU][
0080ZEQW00@0]5IT0:i4CP2^A4h0d5iN0P3FJVL01@35L6T0RTi605`i=@1L>CD0G4Y:0080GUQJ00D0
H5mU06IVKP1VIVh0KG1i075aO@0206m^O00406i]O@1^KGl0KVeo05aKK@80DU5S00D0@d1A040nC00d
<3h0=30n030]=P0202hY;`0502l[;00[9bP0:bLX02XV9@0b;Rd00P0]:BP0100^:RT0:bLV02/W9P0/
:2T202TT:00502HP900n>3`0fMOJ0=WGfP3/k>`00P3QhN40103Shn40hN7O0>7Qg`3QhMl30>7Qh@04
0>CSh@3Vh^40i^;Q0>7Ie`80kn?S00D0c;jm0;BTY02aXj<0/J>S0:^OX@0209:9RP040>?Mg@3Th^<0
i>;S0=oOg`<0g^3O00@0h>3P0>?Mg`3SgMl0jM[M0P3ohN<01@2iPH@0UTm=0:QHD@2XF540X5Q<0080
QeM900@0W89e0?kel03nmO000?l03oooool000gooooo0`00o`00103Yb<40XFML0:5WG037L5l20<mZ
F0050>Z;N@2jJe`0ZG1W0:U`I`3gdLh00P2aV9h01@1XF6<0JUa[06YLJ`1XGFd0KF9b0080Iem^00@0
KVIe06aVM01/IW@0GUYX0P1PG6/2065MKP80GUI[0`1PEf`01@1QF6d0HeY]06=JK@1OF6X0G5EW0080
GEIX00@0HEY/06IOL@1VGg40JVIg0P1VHW<01@1SGg00IF9e06QUNP1XIGX0If9i0080Ieef00D0JUYd
040Z?`10:Sl0TgB60?oHj0020?_6c0040=fJTP3=PfX0cH=Z0<YmD`80a7a200D0nKYc0?o0MP3_XET0
kj5I0=Ag>P020=mfAP050>1hD`3FNeh0eW]N0<MoI`2EI5<00P1E=BX0101;=S40ACLf04Dg=P11=CD2
04Dk?005040f=@12>3L0@CTf044i=P10>C<00P15?SP01@1:@c/0@3Ta040i<@0g<2X0?cHa0080?S<_
00@0@34^04H/:`16;2/0DbH[0P1O7R801@1i7B00_Ti<0>a]I`3/KFL0jf9J0080lFEH00D0kf=D0?1W
E`3`IeL0jVII0>AZG@020=M_IP040<ehM@2IFET0VEUI08QNG`80nMcN00D0mMcP0?;Hh@3if^T0nM[Y
0?oIj`0209UTN005099IJP28DV00R59P09EWL@3jfN000P3jgnH0103hgnD0mmkT0?ONi03hgN@20?_M
i@050?oNi`3ngNH0nmcT0?_Li03gfN400P3bemh01@3ae]l0l=;L0?3Bg03edMl0ml_L0080olSJ00@0
okg=0:M7D`2WAe<0`UAG0P3@If@01@38Lf`0STm8068o>`1R?c/0K5YJ0080GeUM00D0De=K04a?F01<
CeP0@dEA0412D@020452EP0403dnDP0h>Dd0>3U=03XkC`80?3]=00D0>SM803PfA00d<C`0=34l030]
=00203<^<P0502/W9P0_:bX0;b/Z02l[:P0]:BH00P0/:2D0100_:bX0;2PW02`X9`0Y9BH202/U9`05
024K7`1DCe<0iN?T0>GSi03Xj>P00P3QhMl0103Shn40hN7O0>7Qg`3QhMl30>7Qh@040>g/jP3Idm<0
fM?C06mUIP80`K>c00D0OVi^08YjNP2<O7d0S7am08=gM`0208j5QP050>gYj03Rh>40h^3Q0>7Qh@3N
h=l00P3Ogml0103Pg]l0iMcO0>GLg`3[fmh20?oPh`050:U^L02UFeX0ZUeE0:YME@2NGU800P1mETL0
1035/JH00?l0003o0000o`0?ooooo`003Oooool3003o00040?KJeP2TLVT0Y79Y0<1]G`80c6]J00D0
gH1^0:1DA03;Vhl0bi^?0=6b[@02058g?00506IAFP1LC5L0G4aG05mBG01LD5X00P1KDEX0101JD5T0
G5EM05aEG@1HDET205Q@F`0305UAG01JDUd0Fe1N0080Fe1N0`1ICeX205iDG`0505]CGP1GCe`0ETiK
05I>F`1JDUl00P1KDf001@1KEF40FEIQ05UFH@1HEV@0F5EV0080GEU`00@0H5Q`06MGL@1WEg40FT9J
0P1A<4<01@3W^L@0kjjb0=Z@Q`3JT8L0eXI[0080cWmD00D0b8970?>`JP3c/6X0n[Q/0?J/H`020>bB
D`040=]f@03QM4T0hGA90=mdDP80e7UL00D0cHE]09EVE01A<bP0DC<X04Tf<00204Li>00504Hj>P10
=SD0@3He04Dk>P14>ST00P12>SL0100o=c@0?cXf03lj=P12?CL204@o>@0503`g<@0l=Bl0>C0[03T`
:`0n;b`00P15:BP01@1C9BP0FQDH05XE601l7Ql0d5iM0080jVUT00@0kfIN0>iRE@3^HUD0lFQH0P3]
IEL01@3WJE/0gVmT0<meK@3?MFd0_7Qg0080LT5400D0c:nc0?cWk03lin`0lM[P0??IhP020?kOkP04
0>:lb`23D640Pe1Q09aYN080KDE@00D0gl380?kWk@3bgN@0l]gT0?CMi`020?GIi@050?gGiP3jc]d0
n/kM0?;2cP3da]400P3cbmH0103ce=`0m]oW0?KOi`3agNH20?3Ki0050?GIi`3he^H0omCU0?oDi@3f
[;/00P2F=T801@39Feh0eFUW0=EYI`3;Lfl0PD8m0080C2TW00@0@30c03Pc>P0h<cX0<C4m0P0c=D80
1@0h>d`0>ceB0494F`12A5/0BD]R0080ADML00D0@D9F0450D011@500?3Y7034`>00202h[<P0402h/
;`0^:RT0;RXY02TU8P80;bXW00D0;RTV02/W900Z9R<0:RHS02TU900202hX:00502XT900/9RH0;2HV
024K7@1QGEh00P3/j^/0103Ti>@0h^;R0>;RhP3Rh^820>;Th`050>3Rh@3QhN40h^;R0>;RhP3Xi^L0
0P3MfMX00`2cZZd0e/[<0=K:c0020:ZJV`80Z9RI00@0S82009ZDU02JU9@0l^k]0P3Qgn001@3Ogml0
h>3P0>3Ng`3Pg]l0hMgN0080iM[N00D0kM[P0?kKh@3nfn40TeQL0:YTHP020:APE@0409INC`25IEP0
QFEH0>SJc`<00?l03oooool000gooooo0`00o`00103ff]H0Y79Y0:AbJ@30KEl20<a[FP050=f0KP2P
E4@0bi^?0<^KS`3A/Zd00P1B=c`01@1VDEX0G4aG05a<E`1ODU`0G51J0080Fe5J00@0FU1I05aEG@1L
EEd0F55I0P1HD5/00`1IDE`0FU9M05]@GP0205]@GP<0FDmJ0P1NE5l01@1KDeh0EdmL05I>F`1FCU/0
FU9O0080Fe=P00D0FeEQ05UFH@1IEV40F5IT05QEIP0205eIL004061HL01WEg40IeMa05Y2FP80DC13
00D0ikW40>n^/P3JT8L0fY270=J6J`020<ioE0050<R2A`3c/6X0lk1Z0?ZhK03f[6<00P3/TU<0103K
MT00hGA90>5dB@3OM5820=AiG0050<f5K@2EIU@0DC<X054c:019=S000P17>CP01@16>SX0@3He040f
=@15>cX0A3Xi0080@SXg00@0?cLd03lj=P0o>SH0@Sdg0P14?cT01@0l=c40?3D_03T`:`0i<2/0?Rl/
0080ABTX00D0DbDX05XE601J5AP0O1hO0=1NG@020>YYI0040>mVGP3^HUD0kV9E0?5XF080kFEG00D0
ifUK0=i_I03?MFd0cgE]0;ahM`020791A0050<b_/`3lin`0o>O/0?7Jh03cfN800P3ngnh0103R_</0
Pe1Q08=@H@2LJGP206e5D0050=o0b03nind0l]gT0?;Mi03dgNL00P3efND01@3menH0n/kM0?[>g@3b
`/h0m<KA0080ll_F00@0lmCL0?KOi`3fgnL0lMgV0P3`fn@01@3efNL0n=KV0?oDi@3oe>D0mZbk0080
USI200D0bE]N0=EYI`3EJFL0bg=_0852?@0204`Y9`04040`<`0h<cX0>3<j034a?@80<cE200D0>3]<
03/mDP12A5/0@TAK04U;HP0204E7G0050452EP11@500@D1@03`jA`0a<3P00P0^:c80100^;2l0;RXY
02hZ:@0Y9B8202lZ9`0502hY9P0[9b@0:RHS02XV8`0Y9B@00P0^:2P01@0Z92@0;2HV02`V9P0Q6ad0
HEeN0080k>[[00@0i>CT0>;RhP3Rh^80h^;R0P3Ri><01@3Ph^40hN7Q0>;RhP3Rh^80j>KW0080gMWJ
00<0/jZ]0=K:c03Fb/`00P2ZVY/20:RHV@0408b0P02JU9@0VYBD0?;^k@80hMoP00D0gmoO0>3Ph03P
g]l0h=kO0>7MgP020>GJgP050>gJh03nfn40o]_Q09=HG02ZI6800P2TH5D0102FGTl0QFEH08EUF03X
f/l3003o00oooooo000=ooooo`<00?l000@0o^_W0:5fK`2QMVl0/FMJ0P3=LV001@37JUP0ZeQ60?k2
]`3n`[L0cIjH0080WW9c00D0SVM/06I3B@1V@dT0HD9705Pk?`02054g>P0404Xa=01?=ST0CcHi04`g
=P80BCDd00D0?R/W044_:`16<bl0AS<_04Td;`0204/c;`<0CSHb00D0C3@b04P`<015;2l0AB`_04@^
<@0204Pd=P0504Lg>P14>Cd0A3Tm04Q2C01=BeT00P1DCfD0101NDVX0IeAZ06MDJP119C@209mgO`05
0>fg]@33NV/0dX5S0=:1H`3?OTl00P38OT401@3j]g40okid0?nnM03f[6<0mJ1M0080kHQ@00@0lhAF
0>ajE@3/NUD0fVm?0P3?M5T01@3;Q6h0ZGaY05Lk;@1G>bd0?2TR0080@38_00D0@cPf040f=010=S@0
Acdl03dc<@02048h=P0403lg=00m>3@0?CPd044l>080@chj00D0?cXd03/d;P0i<2/0>C0[03l`;@02
04DY:00505LV:@1J51H0FQ@F08HW9@3HIF000P3/JfD0103]I5X0kfEH0>mUF03]IEL20>]YF`050>=]
H@3BL6L0ch9l0<n2O02BG5`00P21GV801@3gh^L0lN3V0?7PiP3`fn@0m][V0080omg]00@0WWF508aM
K@2<GFd0O51M0P2<KWH01@3jiNX0ln3V0?7Li@3ag>D0mM_X0080om[[00D0l[_>0;EeQP2eMHH0Y69`
0:]]N0020:5_NP0409A`NP3XdMT0j=7I0?7Pj080k][U00D0l=SU0?OGiP3oe><0omCS0;m^O@0209Xd
?`050=YWJP3CIV<0dfIS0<ifLP1o@3/00P1E<C401011<3H0?cU303li@`0f=D<203HhA`0503XmD00k
?E80?CmF03doEP1:C6<00P12A5T01@14AEL0=cM303Lg@`0];3@0;Rdb00809R@W00@09bDV02`X9`0/
:2L0:RHS0P0/:2D01@0]:BH0:RHS02PT8@0X92409AlO0080:bDU00D0:b8S03@[;00d:b`081XL06iZ
J`020?;`l@040>CTi03Rh^80h^;R0>;RhP80h^CS00D0hN?R0>7Qh@3QhN40hN7Q0>;Ph@020>GQhP05
0?K`lP3>`lL0c/?707a]L02EQhL00P2DR8X0101kLG80/J^[0;6[Z`3^kN/40>3Ph080g]cM00@0hmgO
0>KJgP3Vf]h0lMcS0P3ddML01@2AFEX0/W5]09aPE@2LH5D0RE]<0080UX1c00@0o??/003o0000o`00
0?l03oooool000gooooo0`00o`00103omoD0`J:M0<6RW@2MGe@20<QbH`050<]WE`2kEDH0k9B60>bD
QP3m[J800P3dYj401@3bZ:D0kjjZ0>n^ZP3XZjP0hZNS0080gJBM00@0fJ:K0=ZVV`3JYY/0ejNI0P3B
Yi@01@3:YH/0aZ>70<^VR@3;YXT0bZ>40080c9n000D0d:630=:NQP3BWXH0dYj90=BOS`020=6MS`04
0=6PTP3DZ9d0e:RM0=:`YP80c;F_00D0el_=08j6T@1@A5P0D4AH061AIP0205Y2DP0504l_=03/`[H0
k<:f0=6KP@2nNE000P32ND80103@T4T0mkQ[0?NhJ`3n^Vl20?>YH0050?BOGP3aSUD0lX=E0?:3E@3b
O5H00P3VKdl01@3MKe@0cg=J0<mcFP36OfT0[X5^0080RFeO00@0IeE;048e;`12=Bl0<bPT0P0m<Rh0
1@13>3H0@3Dc044f=011=S@0@cTg0080@SXh00D0ACdj04<k>013>cP0Acll03dc<@0203hc;`0404<a
;`16:RT0ARXY05DT9`80H1XJ00D0SRl[0=]XH@3YJF00jFUP0?5YG@020>aTEP050>aXF@3TJ5`0i6QL
0=]_I@3?N7400P2kNgT0101_AdP0b[6e0<Za]@3ii^`20>kMi@050?7Ki`3mhNl0jlCF0>_4eP26Ff`0
0P2GKG/01@1Q?DT0d;W10=2i`@3fiN/0l=_T0080lmWV00@0nMSY0?o@i@3od>D0/fIj0P2YD6801@3;
LGd0bGV20:a`N02/L7P0K4=;0080g<;;00D0m^;[0>oIi@3_fND0lMGS0?kHi`020?RkbP0409HiA033
DUP0`e9H0=eWI@80eVUT00D0bWE^07/n>`1C;c40Dbla048a>@0203`d@@0503PgA@0i>dX0>C]:03Tl
C@0f>D`00P10@ED01015AUX0?ci>03lnCP0h>4@202`[<`0302PW;00/:R/09B@R00809B@R0`0X9b<4
02PW9@80:2@S00@09AlO02TP8@0Y8240<2HW0P0a:2T01@0M5aT0PGen0?Gcm03elo@0iN?T0080h^;R
00<0hN7Q0>;RhP3Rh^80103Rh^80103Thn40j>OU0>SWi@3glo@20=SBe00505iCE`1ZH640OGAg07ed
M`1MEeL00P2c/[001@3Zj^P0gmoO0=oOg`3Ph>00g^3O0080h=kO00@0i]gP0>SIgP3XfMh0mMkT0P3V
`lL01@22C4`0]7Uc08aKC@2<Fdd0PUi@0080^:NO1000o`0?ooooo`003Oooool4003o0080n^OS00D0
/H9j0;A/H02dK600cfmQ0<EIC0020=U_H@040>EkKP3BJUl0dVYO0=QcJ@80ggie00D0h8=k0=b2N@3O
Qg/0ghMk0=j8N@020>FDP@050>:GP03TXH@0i:640>Z^R@3g`ID00P3kaiL0103_^XP0fIm]0=VOK@3<
SUd20<Z7G0050=>>I`3BS6P0ei9a0=NBL@3HUGP00P3DVX801@2nTGh0]9J;0;BFR`3chN40Nfmi0080
DdIH00@0He1S04<Y<P13:C80UgA^0P3R]Y/01@2JI3P0aXI90>NTG@3WY5d0ol5b0080oki^00D0lJMN
0>bGEP3/UeH0lHiG0?62E0020?5iE0040>iaD`3UJE40iFUA0>1`FP80eGUT00D0aH5/08QKB01WCCh0
Iddn08QfK00208f0NP0506AIE@0m<Rh0?C8^03H[9`0l<Bd00P10=C<00`18?C/0A3Xh04@j>00304@l
>@0504Q0?@11=cD0@CHd044f=011;bd00P17:BT01@1B8240H1TG060I5`2O?SP0hFmT0080jFUL00@0
jfIG0>aWF03/IeP0jVQJ0P3RK6001@3DLVT0cX=n08aIF02<FEP0NeeO0080mN;V00D0kmkT0?3Li@3`
g>D0mMgZ0?_Lj`020:MlS@04091TL`1gDEh0Me5N08]]M`80nNK/00D0kmkT0?7Li@3fenH0m]OV0?oG
jP020>2Q]P050:54E`3FKG`0eVel0=YfP03DPXP00P2PHfX01028GfL0m]cU0?KLi@3agNH20>oEhP05
0?KDi03oe^H0`GV70<5iQ`2S>4000P3NHfH01@3LIEl0e6UQ0=AYH@36Lf/0LSPd0080D2h_00@0@2lg
03/c?P0k<ch0>SQ50P0j?4/01@0d=TD0<cA603dlC00m?4`0@3m=0080>SQ500D0;B`d02HT:@0V92T0
9R@U02PW8`0202LV8P0402DT800W9R809bHR02PW8`80:BPV00D09RDS02<R800Z9RD0:RHU02PR8P02
02PO800502dS900_92P0;b@X02LN8@2RW9h00P3clO80103ShN80hn?S0>?Sh`3QhN420>;RhP80hn?S
0P3Rh^80103Thn40gm_J0=oKfP3glO4209jEUP0508IlO@3hk^l0m>_/0?C[k03Qfm/00P3NgM/01@3R
h^00h>3P0>3Ph03Ph>00g^3O0080h=kO00@0i]_O0>WIg03YfM`0n^7U0P3A[Jl01@1c@3d0/h5h08EN
C`25GTl0OFIF0080gM;<1000o`0?ooooo`003Oooool4003o0080n^OS00D0/H9j0;A/H02dK600cfmQ
0<EIC0020=U_H@040>EkKP3BJUl0dVYO0=QcJ@80ggie00D0h8=k0=b2N@3OQg/0ghMk0=j8N@020>FD
P@050>:GP03TXH@0i:640>Z^R@3g`ID00P3kaiL0103_^XP0fIm]0=VOK@3<SUd20<Z7G0050=>>I`3B
S6P0ei9a0=NBL@3HUGP00P3DVX801@2nTGh0]9J;0;BFR`3chN40Nfmi0080DdIH00@0He1S04<Y<P13
:C80UgA^0P3R]Y/01@2JI3P0aXI90>NTG@3WY5d0ol5b0080oki^00D0lJMN0>bGEP3/UeH0lHiG0?62
E0020?5iE0040>iaD`3UJE40iFUA0>1`FP80eGUT00D0aH5/08QKB01WCCh0Iddn08QfK00208f0NP05
06AIE@0m<Rh0?C8^03H[9`0l<Bd00P10=C<00`18?C/0A3Xh04@j>00304@l>@0504Q0?@11=cD0@CHd
044f=011;bd00P17:BT01@1B8240H1TG060I5`2O?SP0hFmT0080jFUL00@0jfIG0>aWF03/IeP0jVQJ
0P3RK6001@3DLVT0cX=n08aIF02<FEP0NeeO0080mN;V00D0kmkT0?3Li@3`g>D0mMgZ0?_Lj`020:Ml
S@04091TL`1gDEh0Me5N08]]M`80nNK/00D0kmkT0?7Li@3fenH0m]OV0?oGjP020>2Q]P050:54E`3F
KG`0eVel0=YfP03DPXP00P2PHfX01028GfL0m]cU0?KLi@3agNH20>oEhP050?KDi03oe^H0`GV70<5i
Q`2S>4000P3NHfH01@3LIEl0e6UQ0=AYH@36Lf/0LSPd0080D2h_00@0@2lg03/c?P0k<ch0>SQ50P0j
?4/01@0d=TD0<cA603dlC00m?4`0@3m=0080>SQ500D0;B`d02HT:@0V92T09R@U02PW8`0202LV8P04
02DT800W9R809bHR02PW8`80:BPV00D09RDS02<R800Z9RD0:RHU02PR8P0202PO800502dS900_92P0
;b@X02LN8@2RW9h00P3clO80103ShN80hn?S0>?Sh`3QhN420>;RhP80hn?S0P3Rh^80103Thn40gm_J
0=oKfP3glO4209jEUP0508IlO@3hk^l0m>_/0?C[k03Qfm/00P3NgM/01@3Rh^00h>3P0>3Ph03Ph>00
g^3O0080h=kO00@0i]_O0>WIg03YfM`0n^7U0P3A[Jl01@1c@3d0/h5h08ENC`25GTl0OFIF0080gM;<
1000o`0?ooooo`003Oooool6003o00050>O>a`2SLfT0Xg=Y0;YZG`36H5@00P3MJ5h0103bMV`0jVaP
0>Y/H03XJUh20>]aIP050>M^H`3XL680ig5S0>MaH`3OKU`00P3SMV401@3KME`0fgiM0=]nG@3KQUd0
hiMV0080kZU`00@0n;Ii0?NfMP3g]WH0iJAR0P3DSU001@39PDH0a7U00<AhA034N4@0aGe=0080_GmH
00D0Ree30=JfZ@3F]ZT0aK6b05M:E00205mAHP0404XhA01@>cP0D3/h0?3A_@80d:Am00D0ci]R0?bo
O03o`7H0ol1f0?^cI`020?2PF@050>bBD`3]R580kHQB0?>4E`3`N5D00P3aLEH0103[JE<0j6UF0>QY
EP3SL5d20=9eH`050<V5LP25EdP0CS@W04hd9`1A?SL00P1[GUP01@27O7P0S85m08b1O@1`IEl0BSdg
0080=b`X00@0?34]04<h=013>3@0A3/f0P13>SD01@16?CP0AS`j044c<P11<c80@Bd^0080BBTZ00D0
EB8Q06LM6P1W7AX0ZdU00>EaI0020>IWF0040>mZF@3[IUL0jfIG0>U[G080gW1S00D0dWQ_0;]lM`1]
A480KDA20=:i_0020?SWk@050>gLhP3`fn@0l=_T0?cPkP3P_/`00P20DF40102LL7d0Hd9;06=2B`3G
`<H20?OVk0050>kMi@3df^L0nmGT0?_Ei03obM/00P2^GFh01@2lDF40gVij0=i^NP3DM7P0ag]o0080
OTa?00@0c:ba0?cUk@3liNd0l=[V0P3aeN@01@3oe>L0o;_?09a1D02L@E00aE1F0080i6MU00D0g6EM
0=E_H`3EKf<0_6mU06Lb:P0204`]:`0403/[;P0f;cH0=Rlf03Dd?080?3Y700D0>CU503PhA00m>dP0
?C]803dlA00203@a>00502h/<@0V8R<09R8S02HR7`0Z9b800P0_;2L0100T8A`09R<N02HS7P0V8ah2
02XV8`0502HR7`0S7a`0:RDR02XU8P0]92D00P0[8R<01@0]8RH0:QlU02XO9@0]8RP0`;Zn0080k^c]
103Rh^820>;Rh0050>;RhP3Shn<0inOW0>OWi`3XinD00P1dKf`01@28OWd0ETY:05I:BP1cIF@0VH^:
0080Rh1n00@0PWQf0=oJe`3Of]L0i^GQ0P3Ogmd01@3Ph=h0g^3O0>3Ng`3Pg]l0i]_O0080jmSL00D0
o>;U0:n;R`2_Rh/0LT<m0:j4MP0207MLB@0308f0K`3dl>L0m?3W00@00?l03oooool000gooooo1P00
o`001@3on?@0ajVQ0<NYX@2IFe00^5iC0080fFMM00@0kfaR0?9YG`3bJEl0kVAI0P3gKF801@3eKEl0
lf]M0?E`H@3eL640lg1N0080lG9O00D0ifmG0>AeE`3TMEL0hg]F0>:3E@020>B?F@040>VIG03dZFP0
m:UX0?fdL080okEa00D0okQd0?V/J03]XV40kJ9Q0>BNH`020;f3D`050;R=K@3ef<P0mMS808YeM01S
CeP00P1ZEV40100e82D0WX=h09j3N03nfkl20>jkS0050?VmP@3f/fl0jYmK0>ZOF`3ZUE@00P3VR4/0
1@3ZPTl0lX5G0?:1E`3_M5<0lG5F0080kVYE00@0lFaK0>MUE@3WIED0h6eK0P3EN6H01@36PVl0QEY:
054g:P1A=bX0BCP`0080BChh00D0CD@o06]RG@1[HUd0R7ei0966PP0207]`K00405=8A00n<bl0?S<_
03T^:P80?SD`00D0@STd048h=P0l;Rd0?2h]044];P0204l];P0505HN7`1`8R00L28P0;5<A03UKf<0
0P3ZJeX0103/JEL0jfUK0>]YF`3QJel20=UdJP050=21NP2:EE40SF]Z08e[JP3ji^P00P3ah^L01@3a
g^@0lmcV0??LiP3ogn`0YX2?0080TVAa00@0Ne5M08mdN`2?M7/0nnS^0P3bhNL01@3bgNH0m=SV0?oG
i`3oenL0iYf^0080TSA200D0f6Ub0=UZL@3IJW40f7j009iJF`0208UOH@040?SMhP3cg^D0lmkU0?3H
i@80m=GU00D0omGX0<mnT@2H;cd0V2lm0>=VJP020>9QG0050=]VG03@Kel0d6mO0;Q`HP1S<BP00P16
:2H0100j:R/0<bTa03<Y<@0]:S42038_>00503/iA00j>4<0?Se503hmA@0m>T400P0d<SD01@0_:b`0
:2@S02PT8`0V8Ql0:BHQ0080:bPS00@0924L02XW8P0Z9b80:RLR0P0Z9B801@0W8Ql09B0M02PR8P0X
8R80<2LX0080<BHZ00D0;B0W02TL8`0Y72<0>2dc0=O>d`020>k/k@@0h^;R0P3Shn401@3Rh^00hn?S
0>KViP3Vi^H0j>OU0080WIRE00D0UXb;09B6Q@2DQXD0X96>09J7Q00208anN`040925P`3[i^<0jnKS
0>OSh080hN3N00D0gmoM0=gOgP3Qgn00hMoP0>SLh0020>kIgP050?kOi02BK6/0TVa[09AYHP2NN6/0
0P1[FDD00`2WXXl0ooce0?olm@04003o00oooooo000=ooooo`H00?l000D0ooSd0<NYX@37ZJ40VE]@
0;QND`020=UWG@040>m/HP3bJEl0lVUO0>iTF@80mfeR00D0mFeO0?=[G@3eL640mG1Q0?=`GP020?5b
G`050>M_E`3TMEL0i7EG0>=kEP3RPeD00P3TSeT0103YVE`0m:UX0?BYJ03m]7020?neL@050?nhM03i
[6P0kJ9Q0>fRH@3TWV<00P2mPe<01@2hSFd0mMS80?GHb02:MG@0HdmH0080JUIQ00@0=B0U09j3N02N
PgP0o]^o0P3^^h`01@3i_H40m[=_0>ZOF`3ZWe/0jYED0080iXQ;00D0jX9?0?:1E`3bPEL0kgAC0?5a
EP020>iZE@040?5/F`3WIED0ifEE0>1]F`80eGQV00D0aX9_08EJBP1A=bX0DCLZ04Th<00204Tn>005
04e4?`1[HUd0Jf9M08QmN@2AQX800P1kL6`0101CB4@0?S<_03hc;`0i;RX203he<005048i=012>3H0
?2h]03`^;@11;Bh00P1?;Bh01@1F7Ql0L28P070R802aC4@0iFmS0080jV]J00@0k6UG0>]YF`3[JE/0
hF]O0P3IM6X01@3@PGX0RUEA08e[JP2=JfX0n^KX0080lN;W00D0lMkT0??LiP3cg>H0omo/0:J0S`02
099TL@0407]AG@2?M7/0SgAk0?_XkP80l^7W00D0l]gV0?CHiP3oenL0omOW0>JM[P02098d@P050=QY
LP3IJW40fFYa0=QnP02NFU/00P29Gf40103hgN80lmkU0??Ni@3`f>D20?CEi@050?oEj03?OY40V2lm
09P_?@3SIVX00P3RHE`01@3KIU`0d6mO0=1_G`2hL680Hc4X0080ARPV00@0>RX[03<Y<@0c:C40;BXa
0P0b;cP01@0k>D@0>SQ303hmA@0n?DD0?CY10080=38e00D0;b//02PT8`0X92<09R8O02TV8@0202/X
8`0402@Q700Z9b80:RLR02XW8P80:RDR00D09b8O02DP7@0X8R80:28R030W:002034V:P0502dP9`0Y
72<0:A`S03P]<`3Gc]<00P3^k>d40>;RhP80hn?Q00D0h^;P0>?Sh`3Vi^H0i^KV0>SWi@0209fHU@05
09J<R`2DQXD0U8J50:2ASP2FQh@00P2<OW/0102@QH<0jnKS0>_Vh`3Whn020>7PgP050=oOg@3Mgmh0
hMoP0>7Oh03Xg>000P3^fMh01@3ngn@0TVa[099/J`2DJF80WWQ[0080JeU500<0Yj:?0?olm@3oo?D0
1000o`0?ooooo`003Oooool7003o0080nNKP00D0YGU`0:5HC`3:HUT0bV9I0>IZH0020?1ZH@050>eP
EP3dIed0m6MM0?U]H03hK5l00P3dJe/0103eKEl0mW9S0?IbH`3_KU/20>abF`050>IcEP3TMeH0ih5I
0>N1F@3UQUP00P3WSE/01@3USUP0l9aP0?2LH03cXV<0mZ]Z0080nKAc00@0m[Yn0=n_OP3O[gh0n=Rb
0P2_UX001@17;RT0DcXm04H^;P16;Rh0ECPb0080klVf00D0jKNF0>:NL@3RWW40jYYU0>RAF`020>R:
E0040>J0C`3_PeD0kh=E0>ihE080lWEG00D0kfeE0?1/E`3bJUX0lVYJ0>eXF@020>UWE`050=i[F@3D
MfD0e7MU0<^7M023F4L00P1@>B/01016>2l0BD8l04U2?01<A44204Lo?@0504]3@01OEU40PWMc089g
L`2HSHT00P24NGD01@1UFUH0ASdh04Hm>00h<B/0=R`Z0080>bd/00@0?b//04hZ;01>:R`0F1dO0P1f
9RD01@2kE4d0j6mT0>YXF`3ZJ5/0jfUK0080gfEH00D0ffmU0=9iM@3BNGD0^GQf06Pl?@020<bb/`04
0?WUi`3_g^@0kmkT0?3Mh`80o>;]00D0hK_:07mDI@2NLWl0WW9o060jA@020<jg_`050?KUj`3`gN<0
l=gS0?CJi@3ifNP00P3od>00102jHg<0]D]E0;E;E@3OKW@20=]bMP050<MgN01i@D80bZN[0<ZWZ`3k
i>X00P3_f^<01@3bf>D0o=OY0?cGj@3oa=P0XdMF0080`diG00@0ifEW0>ASG@3THed0eFAF0P3BMF@0
1@2[J5P0GRlU04<W90139b@0>B/[0080=b`d00D0=2de03La>`0g<C/0>CHo03/h@`02040mAP0403/h
?`0[:B`0:bT/02PT9@80;BTX00D0:bLT02TV8@0X8b00:2<P02LR7`0302`W9080;2<T00D0:1lP02DL
7@0^9BH0;RDV038W:`02030U:`0502/N9`0W6R<09aXS04]0B03Qf=d00P3]jNX0103Ph>00h^;R0>;R
hP3Ri><20>3PgP050>;Rh03Shn<0h^;R0>;RhP3QhMl00P3ZjND01@3Tgm`0S8:008b2P02ISXX0UXR5
0080Vi2>00@0XiVG0:BLVP2TW9X0Og]j0P3Qgn001@3Shn<0gmoM0>?OgP3Sgmh0im_M0080lM_N00D0
mMGH08IPG`26H5l0/8En08AREP0206IFA`030<k:_P00o`000?l000@00?l03oooool000gooooo2@00
o`001@3Ub<80V6=K0;QTFP2hI5X0dFEI0080j6aR00D0jVIJ0>YREP3ZHUH0lVQK0?=WFP020?E/G004
0?E[GP3dK5h0m6aN0?A/GP80l6eK00D0kW1J0>I/E03ZMeX0jWMJ0>MiF0020>IlE@050>J1E@3UPe80
iH=B0>J8E03QRU@00P3QTUX0103GTU/0fZ9c0=ZRL`3ogKL20=6/TP050;R>PP2aQWl0Zh1i0:^0N@3M
[Il00P3j`:P01@3ESVh0iHeW0>F=I`3[RUl0kH=I0080jgiE00@0kg]F0>mfE`3_MUL0kfmD0P3aKEP0
1@3aJUL0m6aL0?5WFP3aIeX0l6QJ0080jfMH00D0gfYI0=EfHP3EMV80c8Ea08iQCP0205@j:`0404Li
<014?CL0A3dg04M2?`80AD0m00D0B40n04Lo?015>cT0AC/i05Q>C00207U_K@0509>9Q`2@R8D0T8R5
071XI@1>A4800P0j;2/0100`6Q`0AB4S04DQ8`1K7b4207XY:0050<1GD`3VKfL0j6YN0>QZGP3SJEh0
0P3NKfH01@3@Lfh0b8210<R0P@22CU00TW9e0080nNGW00@0lMkR0?7Ni03ag^@0lmkW0P3mgn/01@2Y
OXl0TfMf085II021FF@0UWMo0080n^O]00D0lN3X0?7Lh`3ag><0mmWS0?oIi`020>:T/`0409PhA03F
Ifh0eVM^0=]^L@80eWQh00D0XUiM08=EE`3dfMh0m=WN0?;Ni`020?7Ji0050?GEhP3oe^L0omKW0=6:
W02J<3`00P3RHfX0103XHV40hF5H0>5QF03FIUP20=5hJ00509YKBP1?9a/0@BTU044Y9@0e:B/00P0g
;CD01@0e;CP0>S@n03Xd?P0k=D40?CY50080>cQ100@0<2dd02TW:P0Y9bX08b4R0P0W9R@01@0Y9B80
9R8Q02PT9@0X92D0;2PY0080;BLY00@0;2HX02TP8`0Y82<0:B0S0`0^9BP0100a:2d0<BH^034V;P0/
82X201hB700505]AF@3Zi>P0j^GY0>[Uj@3QhN400P3Rh^801@3Qhn80hn?Q0>?Sh@3Ti>80hn?S0080
h^;R00@0hN7O0>k]j`3^kN/0cLW80P1YI6401@27OG/0NFi/085fM021MW@0HeUH0080Q7in00D0Kf]Z
0>SVi`3Xi^L0i>CT0>3Og@020>7Mg0040>SLgP3ehN<0mN7S0=k0`P80I44o00D0_iZA06mCA`1mLfL0
OG=W0>cYh006003o00oooooo000=ooooo`T00?l000D0iLS209QSF`2hI5X0^6AJ0=5UF@020>Q/HP05
0>YVFP3ZHUH0jV9F0?9XF`3cIeX00P3eK5`0103eJeh0m6aN0?A/GP3dK5h20?1]F`050>i`FP3VK5@0
jWMJ0>YgFP3WNEP00P3VO5D01@3VPED0iH=B0>F3DP3VR5@0hHYD0080hI9J00@0ei9K0=ZRL`3JXW<0
omfg0P3A[9801@2hSX80/HIo0:^0N@2[P7T0gJfO0080n/2X00D0eHi^0>F=I`3USFL0jhYO0>f3F@02
0>]nE@040>mkEP3_MUL0kgIG0>m_E080lFeH00D0lFYG0?A/G03aIeX0lFMJ0?1XFP020>]WF0050=mZ
F@3EMV80eGIR0<b5L@2>HDh00P1D>R/01017>C00A3dg04@m=`17@Sl204E0?@0504Q0?P17?c`0AC/i
04Dk>@1HCT`00P1iKfd01@2CRHL0T8R50928Q@1`J6D0CTA20080>R`[00@0<1XL04DQ8`158B<0FalQ
0P1j:BP01@30Ee<0iVmW0>QZGP3XJUh0hfUN0080gVmV00D0d7=^0<R0P@38P840PTi@099bM@020?WU
i`040?7NhP3ag^@0lMkT0??Ni`80oMo[00D0ZGj?09=WMP21FF@0PEUT09IgO`020?[Wk@050?7Pj03a
g><0lMcS0?OIh`3ofNL00P3RY;<0102H>4@0eVM^0=IWKP3KKW420=IhN0050:9NG@23EEL0m=WN0?CI
gP3bg^L00P3af^@01@3eeN80omKW0?oFi`3ARY`0VS0l0080hV=Z00@0j69Q0>5QF03QHEP0eVIH0P3A
N6P01@2JFdX0CbLK044Y9@11:BD0=BT[0080=bde00D0=Bdh03Xd?P0j=3h0>cE103djA@0203/h@@04
030]=00Y9bX0:BLZ02<Q8P809bHT00D0:BDR02HR8@0X92D0:2@U02`X:@0202dW:@0402`V:00Y82<0
:B0S02TP8`<0;RDX00@0<BP]034V;P0a9Rh0;20Z0P0N4Q`01@1KDET0j^CX0>[Uj@3ZiNT0hN7Q0080
h^;R00D0hN?R0>?Sh@3Shn40i>CR0>?Sh`020>;RhP040>7Qg`3^kN/0k^g[0<g9b080JFAQ00D0Qgek
07U^K021MW@0PGId06=IF00208AnOP0506m[JP3Xi^L0j>KW0>CTi03Pgmd00P3QgM`0103Xg=h0mN7S
0?GQh`3N`<8206A1?`050;nJT@1_DdL0OG=W07ecI`3/jN001P00o`0?ooooo`003Oooool9003o0005
0?ogm035YZ40VEmD09UOE02iIeT00P3BK5d01@3PJU`0ifUK0>MYF`3TGU80jF5C0080jEmB00@0k69E
0?1TE`3`I5L0m6QK0P3cJE`01@3cJe/0lg1L0?5`F`3aL5/0jfeF0080k7=H00D0k7EG0>YhE03ZN5@0
j7QB0>UmEP020>R3F@040=]kD`3JQEh0fXEN0?6VQP80lJZ>00D0l:RB0?>WU`3bZIP0lZVH0?RZUP02
0>69L@050>1nH`3[Of80jgmR0>ikG03YLU@00P3_LeL0103[KE@0kfeG0>m]E`3]J5D20?5ZE`80lFQH
0P3gJeh0103aIeX0kFMK0>eWF`3QJET20=UhI@050<j5LP2AHU00EcXZ05Lj:P19>2h00P16?CH01@19
@Ch0A3ll04@o?014?c`0AT4n0080ACdk00@0AShl044i=`11>CL0CTI40P1[Hf401@26OW/0UH^908Yl
N`2:O7/0JeIE0080D2TZ00D0DaLI070O7P1`7ah0`5IF0>I`K0020>5ZHP040=i_IP3FNG80eWUb0:mU
HP80Se]M00D0G3Xk0=>m`03fin`0m^O/0>kMh`020?7Li@050?cRk`3H]/H0f;K607E9FP2PM8<00P1N
?DH0103D^l40n^O]0?[Wk@3ag^@20?GKiP050?_Gh`3odMh0]F]h0;E[N02_BE@00P3KKW@01@3ELG<0
b7Mf0<QgMP1i@d<0b:JW0080o>G[00@0k][S0?;Hi@3bf>D0n]CS0P3oamH01@2XDF40`4]D0>QQI@3X
HFD0if1L0080i6IJ00D0dfQH0=5nK03AOV`0RE0o04LU6@0203LV7`04034X:@0i<ST0>C8i03/e?`80
=c@o00D0>SM2044kA`0b;3H0<R`f02dZ<@0202`Z;`0502PV:@0U9BD09BDU02HT9@0W9BP00P0X9R/0
100X9B`0:RD/02XU;00]9Rh202/Q:P0302XP:00Z8BH09AlS00809AlS0P0[8BT01@0c:C80;BH^02dV
;P1cKW@0l>__0080i^CW00@0h^;R0>3Ph03Ph>00hn?S0P3Ti>@01@3Rh^80hN?P0>7Sh03Qhn00hn?S
0080l_3a00D0][:c07=]K@1cKFd0fLo@0=W?cP0209nEU0040:JMWP3]jNP0kNWX0=_Jf080h^;R00D0
hMoP0>;Ng@3SgMd0hmgM0>SLgP020?[Wj@050;RNW@1J?SX0FShj0;FMT@1SDdH00P2XXIT7003o00oo
oooo000=ooooo`X00?l000@0n>WT09UhK`2IN6l0SEU<0P2`J5X01@35KEl0dVeQ0=9]H@3JK5l0g6IJ
0080iF]L00@0h61C0>9PDP3RH580jfEI0`3_IeT0103^IUH0lFUI0?5YF@3^JEP20?5^FP050?9aF`3]
KeP0kFmH0>mcF@3_LeL00P3[M5H0103ZMeX0iGQK0>EhF`3SOV820=mmHP050>1lI03MNF80fWMR0=Yg
HP3PNV@00P3TMUl01@3XM5d0k79K0>abF`3^L5X0l6mJ0080kfaH00@0lFaI0?1XF03`J5P0lFQH0P3f
KEd01@3aJ5P0lVQK0?AXF`3dJ5/0lVQK0080kVQL00D0gfEF0=YeH`3JMF<0dH=_0:]cI00205hh:`04
04dd;@1:>cH0BS/f04Pn?080@Sdj00D0@chk04@o?012?CX0@Sdj04Do?`02048l?005044k>`17?Sl0
Acho04Q0?P1HD4h00P1kKF`0102OQXT0Z7n30:QoP`2RI6L208dk?@050;mGEP3RLVh0ffiW0=]^I`3G
MVl00P2lLF`01@1e?C`0b:BV0<RTYP3B^Kd0lN7T0080kn3U00@0l=cU0?SNj`3hg^/0omo^0P2YPY@0
1@2?H780Ne5O09EgO`2EMgl0n^GZ0080ln;X00D0l=gS0?GKiP3efnH0omSV0>2S/P0208`lB@040<QT
KP3HL7L0f71g0=ElOP80X5YL00D0PeII0?KIg@3fgnL0m]oW0?7IiP020?GFi@050?oEi@3PUZD0h9JU
09<_>`3QHfL00P3YGed0103VH5L0gfEH0=mUF03DKEh20<UjJ`0507Y6>0108QL0<B8M034R7@0[9BD0
0P0^:c801@0b;cX0=S9003Hb@00h=480?3I20080<2Xd00@0:BH]02HT:@0V92T0:2L/0P0X:2X01@0X
9b`09RDZ01lN900O7R@081dV00807Q/T00D07aTS02DM:00U7BP0<2Ta030Z;P0203Pb=P0404e6C@1O
F5l0GeQO079[L`80EE1F00D0RXR=0??am03Ti>@0i>CT0>?Sh`020>;RhP<0hn?S00D0h^;R0>7Sh03P
h]l0h>;O0>?Sh`020>[ZjP050=gIfP1hLW80N79b05]BD`1GCTl00P1dJf`0103CcLd0kNWX0>gYj03T
hn420>3Ph0050>;Ph@3QgM`0iMcM0>GLg@3Xg=h00P3lj^X01@2;Lg40Mf1H07MPF02VUXL0IE]?0080
g]_F1`00o`0?ooooo`003Oooool;003o0080hmK@00@0`:VQ0;:@Q`2bT8L0[Gid0P2_MFX01@2iLfL0
_feQ0<U]GP39KEh0dfeN0080g6iM00D0hFaK0>Y_G`3ZKel0jfUK0>QTE@020>aWF0040>]VE@3ZIE80
jVEB0>UTD@80kFQG00D0kfYG0?1/E`3_KEL0kfeG0?1_F@020?AfH0050?5gHP3_MV40kgIQ0>igH`3_
N6@00P3XL5l0103/Lf80lGAR0?5dHP3aL5d20>m/FP80l6]J0P3cJe/0103`J5P0lVQK0?9XF`3_IEP2
0?IZG@050?5WFP3bJ5d0m6MM0?AWG@3aI5X00P3bJUh01@3TIUP0gg5R0=maHP3JOVl0]W9W0080KS`c
00@0ESD`04hi>01>>CP0BC/j0P14?3X01@11>c/0@S`l048n?@12?Sd0@Cdn0080@Sho00D0@Shm04Do
?`15?cl0AD0m04<n>`0204Hj>P0405<j?P1gCU@0MdiD0:QZK`80^FM[00D0af=S0=YaK@3CL6X0dg1Z
0=N4OP0207/o?P0509eeM@3oinX0onOZ0?;Oh`3`gN<00P3bgN@0103cg>H0on7`0?oQl03K//@2085B
IP0509a]O`1S?DX0e[o70=Joa`3ei^/00P3_h>L01@3`g>D0mMgZ0?GMjP3ldn40XF5_0080X4iL00@0
d7En0<ieN`3>MG/0a7Um0P1d?3l01@2oW:00oNCZ0?7Ji03af^@0lmOU0080n=KV00D0oloM0;ILJ02f
G6P0^DI=0>YTI@020>]PF`040>=NE@3PJ5X0h6QJ0<m]H080`WQ[00D0JSX`03DJ4`0[81h0:b0N02/V
:P0202TV;@0502TW<P0b<3d0<S0m03Hd@@0g<d400P0Z9c80100^:c@0:2D/02PU;00U8RT202HT:@05
01XG7P0O72<0:RL`02XW<00e<S/00P11?TL01@1LEeh0KVU`06iYL01^JFl0LVea0080Kf]/00@0JF=W
05I@E01FD5@0A3m50P0/9bd0102PWZ<0lo7d0>?Sh`3Shn<30>;RhP030>?Sh`3SiN@0hnGT0080h^CS
0P3Qhn80103Rh^@0jNWY0>WYj@3bk^d20:BOW00504Lo?@1CBdT0a;bj0<Bl^P3ak>T00P3Sgmh01@3Q
h=h0h>3P0>3Ph03Qgn00hM_K0080i=[K00@0kn7Q0?3Ng03`g]`0HDY40P2[VHd01024N6X0RhMk0?Wh
l`3in?<7003o00oooooo000=ooooo`/00?l00P3Se]001030ZJ40/Y270;:@Q`2]OW@20:meJP050;Uc
I`2oKF40bFeN0<U]GP3CKEh00P3LKUd01@3QK5/0jVmO0>Y_G`3[JE/0j6AE0080k6MH00@0jfIE0>YU
DP3ZIE80jFAA0P3]J5L01@3_JUL0l6aG0>m]E`3_KEL0l6mI0080m7IP00D0lGMR0>mfH@3_MV40kWMS
0>mhI0020>Q`G`040>acHP3aM680lGAR0?5`G@80kfaJ0P3`JeX20?=[F`040?1XF03bJ5/0lVQK0>mU
F080mVYM00D0lFMJ0?9XG@3dIed0m6MM0?5TFP020?9ZGP050>AVF03OLF80gg5R0=YnK`2fLVL00P1^
?3<0101F=C00CSTh04hi>019>cX204@l>P05044k>`12?3`0@Shm048n?@11?Ch00P12?Sl01@12?Sd0
AClo04Do?`15@3d0@chk0080ASXj00@0DcXn07M>E01gCU@0Z6Y_0P2iIf/01@37Hf<0fW5]0==`JP3C
L6X0ehAn0080Ncln00D0WGEe0?oWjP3oinX0l]oS0?3Mh`020?;Mi0040??LiP3ohO00on7`0=^ba080
PE9V00D0W6eo06<mBP3F_lL0e[o70?GVj`020>oPi`050?3Li@3egNX0mMgZ0?cCh@2QHFl00P2PCU`0
103@MGh0cWEk0<ieN`34NGd207@l?`050;nLX03mi>X0lM[T0?7Ji03cenD00P3he^H01@3ocmd0]UaX
0;ILJ02iATd0jVAU0080jf1K00@0heiE0>1XFP3PJ5X0cfeP0P32N6/01@1Z>S00=AXC02/P7P0[81h0
:bHZ0080:BH]00D0:BLb038`?@0b<3d0=SA103Lc@@0202XW<P0402h[=00X9B`0:2D/02DR:@809R@Y
00D06QLN01lL8`0Z9c00:RL`03Db>`02044nA`0505aGGP1^JG00KVU`06iYK`1bKG400P1_Jf`0101Y
HfL0EU1D05I@E014?dD202`W;@040:2NX`3clO@0hn?S0>?Sh`<0h^;R00<0hn?S0>?Ui03SiN@00P3R
i><20>7ShP040>;Ri03YjNT0jNWY0?;^k@80Y9nL00D0Aclm05=;B@34_;X0a;bj0?7/j@020>?OgP05
0>7PgP3Ph>00h>3P0>7Oh03Qfm/00P3Tf]/0103_hN40l=kL0?3Ng01QBT@20:^IS@0408AhJP2;Qg/0
nOSc0?Whl`L00?l03oooool000gooooo3P00o`020?odl0050?KUgP3/dLX0k=7:0=Ze[03<WI<00P30
QWX0102jMVT0_g5T0;maI034K5h20<UYF@050=I_H03KJed0hfmP0>=_H03VKUh00P3UJUP01@3VJEL0
i69D0>ARE03WHe@0j6=B0080i5m>00@0kVIF0>]SD`3[He<0lVeL0P3aK5/01@3cKUd0m75O0?=^G@3c
KUd0mW5P0080m6aN00D0mViN0?5YF@3aJET0l6QH0?E[GP020>iTE`040?=YG03aIeX0lFMJ0?AXF`80
lfMJ00D0lFMJ0?5WG03eJ5h0mFQN0?=VG0020?5YG@050>QYFP3RK5h0hVaN0=ihK038MV/00P1i>S<0
101M<Bh0E3Pg05@h=`1>?3`204Lm?00504Po@012?3`0@3Xj040j>P0o>cX00P13?Cl01@15?cl0@cdm
04<m?@10>SX0AT100080Ac/k00@0CcHj05Xa=`1J<CL0HR<[0P22<3H01@37Hf<0fg=`0=UhLP3IN780
]VEQ0080RTi=00D0m<[;0?oRi@3oh^D0n=_P0?SJhP020?SIh@040?kJiP3oenD0omOU0:I_PP80Uei_
00D0PE5O09]eP03mi^h0oNK^0>kOi0020>oNiP050?3Li@3ih^`0nN;/0?3?fP1d?4T00P2:AU40102O
F600WEYQ09eJH@1e@DD208eTJ0050?GJg`3bgN@0lmWT0??Ii03eeN@00P3oenP01@3KVJL0VC4j09Ta
>P3OHF@0jV1M0080jf9H00@0i6AG0=EUE`3EIEL0cgIX0P2]Jel01@1H;BL0<ATG02/Q800[8B009B<V
0080:bP_00D0:RTa030]>00`;CP0;R/f02XW<P0202l/=@04030]=00]:S40;BXa03Dc>080BdI<00D0
FUEK06mZL020OH@0P7f408>0Q`02081nP`0507EcN01UH6@0IF1T04Q3A`0l>3T00P0f<S<0100`:Rh0
;BH]02dV;@0W82L203Td>P030=?Ae03]jnh0h^;R00D0h^;R0P3Ri><01@3Qhn80hnGT0>;Th`3Ri><0
iNGW0080k^c]00D0/Zj]08R4P@28Q840XijK096<R@0208^6P`040>;Ng@3ViN<0i^GS0>7PgP80h>3P
00D0h=kO0>?Mg@3Vf]X0i][J0?CTi@020<Vg/`0505i<@P2aXI@0/J6D06]UE`3Ac/D02@00o`0?oooo
o`003OoooolD003o00040?oel03ki^40nnKQ0>kCc080f;J]00D0aibC0;V7O02iQg`0]GMZ0;Q`H@02
0;i_H0040<M^G03@Ke`0d6mL0=I]FP80h6mO00D0i6aL0>Q]G@3[JE/0jfUK0>UTE@020>YRDP050>YQ
D@3[HU00jf9@0>iUD`3/He400P3bIUD0103`I5<0m6QI0?AXF@3hK5d20?IZF`050?=ZF03fJU/0mVYK
0?IZF`3bIUL00P3dJ5T01@3bJET0lFQH0?5XF03cJUX0lFMJ0080mFUL00@0m6QK0?1XFP3`J5X0jVIG
0P3VJ5X01@3TM6P0g7]b08a2>@2<@ST0DahJ0080Cb`Z00D0@bh[044c<P11<c80AS`k03hh>00204@n
?P0303lj=`15?3d0AC`m00<0A3/l00D0@cXm044k?@11=CL0@CDg04Tc=P0205Tb=`05060Q:@1e8bT0
MB<Y0<=OH@3NMG800P3JLVl0102[CTT0]FUY0;EYJ@3o`l@20?k6b@050?k;dP3ocMH0olgI0?o=f@3o
dn400P3TYkH01@2ABEL0/6Ye0;1ZM@20BeD0jL790080o^?Z00@0lmkS0?7Ni03ag^@0l]gT0P3dgnH0
1@3fgN<0aZ>Z0;::TP2bRY80[8F:0080UW=g00D0X8J90>3<cP3Pc<h0mnCX0?3KhP020??Ii0040?gG
iP3obm`0ol_L0:ECH@80_4QA00D0jfEV0>UPFP3WHeL0if=G0=mWE`020=9/G@050<UkKP2AF4l0TEQ?
04@Q6`0b7Qd00P0X7b00100S8B80;R`_02h/;`0f=3L2044l@P0504e8CP1CCU@0IF1T06EPI01^JFd0
0P1jMWL01@1mNGX0P7am081lO@1gLg@0If=T0080F5=G00@0Ad9603Pf=`0h=SL0<2h_0P0Y:2H01@0T
8b408R4O02PT9@0X92D0:B8Y0080;R@/00D08aTQ06]TJ`1[I6/0lNob0>CTi0020>7Qh@040>CTi03R
h^80h^;R0>;RhP80i>CT0P3Shn<20>CTi0040>WWj03Vi>D0i^CU08Z6Q`80d<c;00D0em7A0<S2`P2;
QhH0RhN60=KEd`020>KUh`050>7Qg`3Ogmd0gmoM0>7PgP3VgMh00P3Xg=`0103ijNX0Th5m09>1O@20
LVL208f3M`03089nM@3gm_400?l000P00?l03oooool000gooooo5000o`00103omO00nnKQ0?_Vh@3^
dl`20=Rf[@050<NLT`2iQg`0^HMl0;EgJP2hL6400P2nKf001037KU`0d6mL0=1_G03FKEX20>1_G`05
0>A/G03XKEd0jfUK0>]YF`3YI5D00P3ZHU801@3ZHE40jf9@0>]RD03^IE<0k6=A0080lVIE00@0l6AC
0?AXF@3dJ5T0n6aM0P3fJU/01@3cJUP0mVYK0?IZF`3fJU/0lVIG0080m6QI00D0lVUI0?5XF03aJ5P0
lfYJ0?5WFP020?EYG0040?AXF`3`J5X0l6QJ0>YVE`80iVQJ00D0i7AX0=akLP2<@ST0S48i05<N6P02
04l/:P0504<^:`11<c80@C<b04Hl>`0n>3P00P14?Sh00`0o>SL0AC`m04Dl?@0304@k?00504<j?@11
>cd0@CDg044e=`19<cH00P1I<SL01@1P8BT0MB<Y07DS:@33Gf40gWEb0080fW9_00@0Zdi90;EYJ@2e
JFT0ol?40P3na/T01@3nbm80olgF0?o=f@3ocMT0om?Q0080i:Nf00D0TDUG0;1ZM@2`JWD0P4]E0>W1
b@020?kSjP040??Nh`3ag^@0lMkT0?;Mi080m=oV00D0m]gS0<JSZP2bRY80/XZB0:b5RP0209IcM`05
0:26R@3Pc<h0h<c>0?OTj03`fn800P3cfN@0103menH0ol_L0?o;g02UDf420;a8D@050>]UIP3YH5X0
if=G0>MSE`3OIeL00P3BK5d01@39Nfh0TEQ?095HC`148A/0<QhM0080:1lP00@08b4R02h/;`0^;2l0
=S@g0P11?4801@1=B4h0DdiD06EPI01UH6@0KVU]0080NWIg00D0OGUj081lO@20O7d0Mg=d06MSI002
05QCE`0404M2AP0h=SL0>3Hg030^;`80:BPV00D092<Q028Q7`0X92D0:2@U02TR:@0202hT;00502<I
8@1[I6/0JfA[0?7_lP3Ti>@00P3QhN40103Ti>@0h^;R0>;RhP3Rh^820>CTi080hn?S0P3Ti>@0103Y
inP0i^CU0>KTi@2:QXL20=3<b`050=OAd@38`/80RhN608^7QP3FeM<00P3ViN<01@3QhMl0gmoM0=oO
g@3Qh=h0i]gN0080j=cL00@0nNWZ09>1O@2CPGd0P79W0P2=PgL00`22OWD0moKa003o0008003o00oo
oooo000=oooooaX00?l000D0ooG`0?[Vg`3ji]l0km770=VcZ0020<JHR`040;MoLP2_KEd0[feM0;U]
G@80_FYJ00D0bFeN0=1YFP3LJed0g6]M0>I[G0020>iZF`050?=[F`3dJeT0m6]I0?EZE`3dJEH00P3b
Ie80103/HD`0k5m=0>aOC@3`He420>mSDP030>eQD03_He@0lfMH0080lfMH0P3fJU/01@3eJEX0lfYJ
0?=ZFP3aJ5P0lfYJ0080lVII00@0mVYM0?1WE`3`IeL0kfMI0P3^JUd01@3ZL6<0jgmb0:mGB`2_Ed/0
GAXA0080D1lH00D0@1lH038J5P0b6QH0=bPU03P]:`0203/a<00403P`;P10=SD0@3He04<i>080A3Xk
00D0@cXm048i?013=cT0@cLi04`h>P0205@_=P0505dQ:@1d9B/0M2D[0<5OH03QMG<00P3NKVX0103=
HEh0a6EQ0<AUH@3:LW020<UgN@050=:3R03GRY00hIBL0>6DW03]WJP00P2`GFL01@2dEf40_VM]0;iW
K@2UGV@0ol[=0080om7D00@0o=?I0?cEfP3leMX0o]KN0`3mfMd0103og>40omkR0?oNhP3ogN420?cM
hP050?_Qi03mh^L0oN;W0?_Nh`3kf^<00P3oen80103oe>80gi>P0=nCX02K=d<20=iPI0050>iRH@3/
HUP0i69D0>ARE03IJ5P00P3;L5h01@2mNF`0PU=9089CB@1UBT<0JE]H0080JVAT00@0L6i_07UeMP1i
MGH0OWYk0P20O7d01@1lN7T0MG5b06YVI`1ZIVL0FeMF0080C4Q700@0A40o03`h=`0l>3L0:RHU0`0^
:RT0100[9bH0<Rh]038^;@0/:bL302XY9@0402DT8P0V8R<09R8S02HO9P80;28[00D08aTQ09nIW@2O
VId0m?;e0>CTi0020>?Sh`030>GUi@3Rh^80h^;R00L0hn?S00@0iN?T0?3/k@3`k>d0c/[;0P2CSHl0
1@1DCTh0KFMW0:jZZ`2^ZZ/0jNOX0080hN7O00D0h^;P0>7Qg`3QhMl0hmoN0>GLg@020>_Og`040?CT
i01RDdh0HU=>09b@Q080OgU[00<0_Kbg003o0000o`002000o`0?ooooo`003OoooolN003o00040?oh
m@3olNd0oo7]0?GQfP80i/W100D0dJnU0;^CR@2kThT0]81c0;5/G@020;mWF@040=1VF03PJ5P0h6QH
0>=TD@80k6YD00D0jfM@0>aXC`3`KE40l6eA0>mYCP020?E[D@050?AYDP3aI500lFA@0>iQC`3^HE00
0P3]Ge40103^HE00l6=B0?1SDP3/Gdh20>YNC@050>]OCP3]HE80lFEH0?5UF03`I5L00P3bIUT01@3b
J5/0kVAG0>iTE`3aKel0jWET0080eVmN00@0QS0Q064M401Q7A00Db8D0P137a<01@0j7aP0;1TC02XL
6@0Z71T0;B8P0080;bDT00D0;R@S03D/;@0e;2d0>c8c03Xa<P02040d=P0404/g>@1C<3H0Dc0f05dV
;080M2T^00D0_emP0=mbK@3SKVL0hfiW0>A[H`020>UbJP050>UfK`3SM6d0hgA]0=mcL03LKVd00P3H
JVT0103?HF80b5MI0<QGF@3NK6`20=]_K@050;mMGP3KPH40g8Z<0=b:S03OT9<00P3PUIX01@3SVil0
hY^Q0>:KX@3XXjP0kjfa0080lK2f00@0m[Vn0?Nna03g_/@0oLK<0P3mb=001@3oam00olSA0?o3c`3o
`ll0kin/0080Y3m700D0aDiB0>]UI03[IF@0kF1I0>aTF0020>9TE@040=A[F038MF<0b7ES0:]cHP80
N5A600D0KUYA06eTG`1SGU/0HeiK05QDD`0205MAD`0504I2@`10?3/0@3`k03@c<@0_;Bh00P0W9BH0
100Z:BL09RDS02HU8`0];2X202`X9`0502`X9@0a;BX0;b/X02l[:00Z9R<00P0_:bP01@0Z9b809R<N
02HS7P0[9b@0;2PW00809B4R00@0:28V02XP:00Z82P0<b`c0P3=b<`00`3^k>l0hn?S0>?Sh@020>?S
h@80i>CR00<0hN7O0>;RhP3Rh^80103Shn<0103Vi>D0lNg^0?7]kP35_;l2071WJP0506QOH02TWYh0
j>CU0>STi@3Uhn@00P3QhMl01@3Ph=h0hN3N0>7PgP3Sgmh0iMgK0080l^KV00@0dL7104Hh=@16>3D0
^K6V0P2NW8l00`3[j^H00?l0003o0008003o00oooooo000=oooooah00?l000@0ooSe0?oak@3olNd0
mN7J0P3VbL401@3A[jD0^i>90;^CR@2dP7<0/FaM0080_fMI00@0d6IH0>1XF03PJ5P0hfAA0P3/JU@0
1@3[Ie00k6Q?0?1]D@3`KE40kfU>0080mF]A00D0m6UB0?5TD03aI500kV5?0>iQD0020>eOD@040>iQ
D03`He80l6=B0>aOCP80jUi=00D0jem>0>eQDP3aIEP0lFEH0?1TE`020?9VF@050?9XF`3^I5L0kVAG
0?5_G`3ZMF@00P3FKeh01026<240HAd@064M401C8Q@204<O4`0503XO600/6A<0:Q`I02XL6@0]8R00
0P0_9B@01@0^92<0=B`]03D/;@0k<S<0>S4b0080@3@f00@0BcLi05<`=P1C<3H0GBH/0P1d:Bh01@2o
Gf00gg9]0>=^I`3SKVL0i6]S0080jG9Z00D0jGI_0>=dK@3SM6d0gg=`0=a^K@020=QZJ@040<mQHP38
EeT0b5MI0=i/K080ffm]00D0_eeN0=^1P@3LRX`0g8Z<0=n@T`020>2EVP050>>KW`3RVj40hY^Q0>RS
Z03_[K400P3a/;H0103f^Kh0mkk40?Nna03ma/`20?g8d0050?o7d03ob=40ol??0?o3c`3_Wj`00P2T
?dL01@35CU80jfET0>]UI03]H5T0k6AH0080hVAE00@0e6]H0<QeH`38MF<0Zg=R0P1hE4H01@1^FU40
KFAO06=NF`1SGU/0F5AC0080Ee5C00D0AT93040l>`10?3/0=3<a02l];P0202LU9P0402XY9`0V9B<0
9RDS02d/:P80;2PW00D0;2PU034]:P0_:bP0;b/X02XV8`0202l[:00502XW8P0V8ah09R<N02/W900/
:2L00P0U8B80100X8RH0:R0X02XP:00c;3<20<g8c0030>k/k`3Shn<0hn?Q0080hn?Q0P3Ti>800`3Q
hMl0h^;R0>;RhP040>?Sh`040>KTi@3akNh0lNg^0<Fl_`80L6MZ00D0J5mP0:BNWP3Xi>D0j>CU0>GS
i0020>7Qg`050>3PgP3Qh=h0hN3N0>?OgP3UgM/00P3bi^H0103A`L40ASPe04Hh=@2i/JH209jLS`03
0>_ZiP00o`000?l000P00?l03oooool000gooooo9@00o`020?odkP050?WRfP3<Y9X0XVQJ0:9XFP2h
Je/00P38JEL01@3FK5H0i71I0>A`F@3XL5L0l7AH0080kgAE00@0k6e=0>AQ@`3THD<0l6Y?0P3^ITh0
1@3_Ie40m6UF0?=ZF03cJUP0m6]H0080lV]G00D0lFaI0?5/F`3aK5/0kFYH0?5^G0020>UUEP040>IR
D`3SGTl0hei?0>EPD@80if9C00D0hf5A0=mVD`3XNFD0j7UU0;eJA`02094j:@0506hV5`1O91H0Gb@F
05<S5`178AP00P0l6aH0100_5Q80<a/I03<K6@0`71/202`L700502XL6`0`8240<b0R03<P8P0l8bH0
0P1892P01@1I8RP0KR<W06hS9`2aDU00hgA]0080iV]S00@0jf]P0?5_HP3aKf80kfeP0P3aLfL01@3b
LfX0l75X0?5aJ03aLFP0jfYT0080kVeW00D0jFYT0>Q]IP3XKFH0jG=_0>9bKP020=ibK`040=I^K@3D
KFh0e6e^0<UUI`80`V9S00D0_f5R0<1RH`30IVP0`6IX0;YTI`020<1[KP050<UdN`36M7X0aWAj0<Id
NP3<MGd00P37JW@0102fCUD0be=E0<]CE@3ZIV@20>UNF@050>ePE`3[IET0gfEF0=mUEP3?Je/00P36
OF`01@2MKUh0DSP[058h:`10<BX0>SDa0080=30]00@0:bLV030/;@0`;2d0:RHW0P0/:2L0100_;R`0
9bHT02PW9@0X9bD302/Z:00502LV900/:bL0;2/W02/W900^:RL00P0Y9B80100X9240=2l[03@_:`0/
9b<202PS7`0502LS800_:bX0;2PY02`X:@0Z92P00P0O61l01@1QFV40kn[^0>oZkP3Vi>D0i>CR00H0
hn?Q0P3Rh^801@3Shn<0i>CT0>?QhP3ShN80l>c]0080clK700D0NW1a09jDU@2NU9D0`[Ri0:>MW@02
0:jZZ@040>_Zj03Ogmd0gmoM0>7PgP80h]kM00D0i=oL0>KNg03gkN/0mng[09V>RP0205M>A`030;bh
[@3@d<H0d=3600/00?l03oooool000gooooo:000o`00103ol>T0/iR=0;>HS@29H4h20:U_F`050;]`
F@3=Le/0cG=K0=1ZD`3VN5d00P3QL580103`NU`0lgYK0?=jF`3eNU/20?1_DP050>m]D`3/J540jFM?
0>UWC`3XJU<00P3WKEH01@3UKUP0iW5M0>IaG@3VLf00iG9O0080jWMT00@0jGAR0>M_GP3WKeh0jW9Q
0P3XKeh01@3QJUH0fVEA0=][E`3KJeL0ffiJ0080dfYG00D0ZTTf08he8`2>=B<0O2XL078Z700206h`
9@04054M4P1;71H0Ba`F04@M6080>Q/F00D0=1PE03<I600e61X0=APJ03@D5`0203lE6@0504lB6@1R
4aP0HQ<H0:M5A03UM6h00P3WJf40103]Jed0k6QI0>aXF@3`K5d20>m[GP050?5]H03_Jeh0kVQL0>iX
G03_JEh00P3_Jel01@3]J5l0kV]Q0>i[H@3_L6L0k71V0080kG9Z00@0kgI]0>YaJ@3ZLFT0jW=]0P3[
M6h00`3VL6`0ig5]0>5^J`020>5^J`80gfaY00D0hfm`0>5]KP3QKFh0g6QY0=mYJ@020=aQH`040>9U
H`3[IF80jfER0>mTG`80kf9I00D0jV1E0>UUF@3MIeT0gFMI0<eaHP020<J4MP0507iFBP13;bH0@blV
03`c;P0g<c000P0g=S@0100a;c00:bTZ02/Y:P0^:R/202TU900502/W900V8Ql0:B@Q02TT8@0V8Ah0
0P0]:2D00`0Y9B80:2DP02PU800202TV8@809RDP00@09bHQ03<_;00c;b`0;BPU0P0Y92401@0/9RH0
:RHU02dY:P0]:BX0:RDY00808QdQ00D0V9JI0?Gcm03elo@0h^;R0>?Sh@020>GUh`040>CThP3Rh^00
h^;P0>?Sh`80i>CT00D0hn?S0>CRh`3Whn@0in?T0?O^k`020;BZZ@050:2BTP3@`/80d<;20<_1`02E
T8d00P2h];40103[j^P0h>3N0>3PgP3RhMl20>CPg@050>COg03Zh]l0kNKP0>gVh01oNg000P2DTXH0
0`2JVY00jN[T0>WZi00;003o00oooooo000=ooooobT00?l00P3^iml0102STH<0RVeK08Y]F`2DIe@2
0:M]F@050;E]E`31KeL0_VM;0;iWB`3@LUH00P3NO5l01@3LMeT0gWEH0=ieF03GJdl0f6iD0080cfM>
00@0cfeD0<1TC@30I4d0`VYF0P36LEd01@32Ked0`g1N0<E_GP35Keh0aW1O0080bg9P00D0dGIS0=1c
H@3@Lf40cG5L0=1dG`020<a`F@040=9cG@3CMf80dgMR0<EYE080`FUC00D0/Ea80:IEA02DBcX0U4/j
07hk:`0206T[7P0505PO501<6Q40C1XA04@E3@0n4@`00P0n3P`010103@`0B0`<04P<301B1`/205d3
1@050:8i=P3XLF/0jfeQ0>]]H@3[JE/00P3XIE<01@3]J5L0kfMI0>mWF@3_IeT0lVYJ0080l6QH00@0
kfMI0>iYFP3^JEX0kVQL0P3]JEd01@3bKV80kf]O0>i/G`3^K5l0lW1S0080kfeP0`3`KF<01@3bKfD0
l6eS0?9_I`3bKfL0kfaT0080lVmW00D0mG1[0?9]J03bKFP0lVeX0>iWH`020?5XHP040>mTG`3]H5T0
kF1I0?=VG@80kV5G00D0jV9F0>IVF@3KJed0ff]M0=1jK@020;UmLP0405lm=00m;2D0?B`U03/c<0<0
=3<a00@0;2X[02TW:00Y9bP0:RHU0P0X92401@0Y9B80:bHS02LR7`0W8Ql0;BDS0080;RTV00D0;RTU
02PS7`0X8al0:2DP02HS7P0302LT7`809b<P00D0:2@Q02PR8P0X8R80;bTY02PR8P0202hZ:`0402lZ
;P0^:Bd0;RT]0<K4a@80kno_00D0hn?Q0>;Rh03Ti>80i>CR0>GUh`050>?Sh`050>CRh`3Whn@0iMoO
0>GOg`3djn`00P3Vf]X01@2UUiH0LVAS079TH`1WGE/0ShZ70080i^GQ00@0iNCP0=oOg@3Ogmd0hN3N
0P3Rg]/01@3Sg]/0l^gY0<_8_`3;b;l0QHMi0080Ngma00<0WZ6H003o0000o`002`00o`0?ooooo`00
3OoooolY003o0080k^OO00@0Xi6308Y]F`2:KE/0U6MD0P2WKET01@2eKEL0`FmG0;iWB`2nId/0d79F
0080gWaO00D0g7MI0=ieF03NMEP0ef]?0=Q^E0020<mWCP040<m]E030I4d0`6A=0<9ZEP80aW5M00D0
`VmM0<=`GP35Keh0aFmN0<I`G`020<]bH0050=5fH`3@Lf40d7=Q0<eaG03@M5l00P3<L5T0103BLed0
dgMR0==gHP35JE@20<5YD`050;5LB02VED@0U4/j09A;>P1n>b/00P1Y:ah01@1H7a@0C1XA04`J4@14
5@d0?Q4<0080?Ph<00@0@0d<04P<301830`0DPL;0P1M0`D01@2R>CH0j75[0>]]H@3[KF40jfUK0080
j6EC00D0kFQG0>mWF@3_IeT0kfMI0?9ZFP020?1XF0040>mWF@3^JEX0kVUJ0>iXG080kFUM00D0lViR
0>m[G`3^K5l0kVaO0?9`H`020>m]H0<0l6eS00D0lVmU0?1]H`3bKfL0lVmW0>m/I0020?9_I`050?E`
J`3bKFP0lVeX0?9]J03^If<00P3aJ680103_I5l0kF1I0>ePF@3cIUd20>iQE`050>YREP3VIUT0ff]M
0=][G@3@NVd00P2iOG80101O?C@0?B`U03d/9@0k<c0303@c<@0402`Z:`0Y9bP0:BLX02XV9@80:2@Q
00D0:BDR02/V8`0W8Ql09b8O02dU8`0202hY9P0502hY9@0X8al0:2<O02PU800V8ah00`0W91l202LS
800502PT8@0X8R80:28R02lY:@0X8R800P0^:R/0100_:Rh0;RT]02hY;@36a<D20>o_k`050>?Sh@3R
h^00i>CR0>CThP3UiN<01@3Shn<01@3Th^<0in?T0>GOg`3Ugml0m>_/0080i][J00D0YINF079TH`1b
I6<0IeeK08n:Q`020>KUh@040>GTh03Ogmd0gmoM0>7PgP80h]kK00D0hmkK0?;]j@3;b;l0blRo08F7
N@0207]oL@0309jQV000o`000?l000/00?l03oooool000gooooo:`00o`00103gl^h0h]WB0>;IdP33
/ZP209n8NP05099aGP2DJeD0WVmE09i_E@2ZM5X00P2aLeX01@2`L5D0]W=I0;IcF@2^KE40[ViC0080
/GEM00@0/WmZ0;f?O`2mSgl0_YB60P2hT8@01@2bS7l0[XQk0:V1M@2YPGD0Y7Y/0080XgQX00D0YWQX
0:1aG`2PLEl0XG5M0:9`F@020:IdF`040:A`F02WLEL0Yg5G0:Q^EP80ZViD00D0/WAM0;=bG02bKe`0
/VmL0;1/F@0209YA@00508U0<@1m=2D0OC@U07L]801]81H00P1W6@l0101W5`h0JA8;06TB2`1]3PX2
07860`0509LP6P3PI5`0kViS0>i^H`3kNF/00P3dLEl01@3dLEd0kfYI0>mZF@3_JUT0l6]L0080jfIG
00@0kVUJ0>]VE`3[IUL0kFUJ0P3[JE/01@3ZJ5X0kF]M0>iZG@3^JUd0kf]N00D0kFUL00D0kVYM0>m[
GP3]JE`0kFUL0>iXG@020?5[H0050?=ZHP3eK6@0mFaT0?1UGP3`IU`00P3bIEh0103`HeX0lVEL0?9U
G03_HUP20?1SF@050>]UF@3RJ5T0eVmP0=I_H03=Og800P2SKF401@1=;bL0@C8_044b;`0n=S@0=C4`
0080<2`[00@0<bl^02dY:00]:BP0:bLT0P0Z9R<01@0Y9B80;2HV02XU8P0Z9B809b8O0080:bHR00D0
;2@R02dU8`0]9B<0;2LS02XU8@0202PS800402HR7`0O6aP07a/H02DQ7P809b<R00D0:BDT02LQ8`0[
9BT0:bDY02HP900204a7B`030>GSi03Xj>P0j>SX0080hn?S0P3Ri><0103SiN@0h^;R0>;RhP3Shn<2
0>CRh`050>OUiP3_jn`0T8Z:092:RP2FSHh00P2IShh01@2OU980Uhb809N<R02JThd0UiB?0080f]WE
00@0inSS0>7Qg`3QhMl0hN3N0P3QgM`01@3Th=d0knkY0;6cZ02a/jP0SYB60080Jg=V00<0emcE003o
0000o`002`00o`0?ooooo`003Oooool_003o0080nOG/00D0i=[>0<BdY02]V8L0[IR70;>JQP020;ZK
R@050;bKRP33X8d0`j2=0;jNR@30XHd00P3H_J`0103ag]00oo;X0?obj03om^d20?gcjP050?S^i@3b
jN00l^GM0?;Ug@3]h=P00P3[gM801@3Zf/d0gL^m0=g;_@3?_:d0`jjM0080^:>@00@0ZYAo0::7LP2R
Qg80UGUS0P2ALE`01@2>J5D0TFIC09IUE02FIE@0VfID0080XfQH00D0YfQG0:]XF02[J5P0Z6=C0:5E
A`0209a>@@0409a:?P2RBSh0XTXn0:]=@`80[4Dl00D0]THk0=QTE`3OIeT0gfMI0>E[G0020>U^G005
0>iaG@3]KUd0kFiM0>m`G`3`LF000P3aLV40103dLV80mG=S0?EcH`3bL6020>m`G`050?9`HP3aKf40
lfmP0?=_H03^JU/00P3]J5T01@3`Je`0kVYK0>iZF`3]JEX0k6MF0080kFQI00@0kfMI0>iVFP3^IUX0
lVUO0P3ZH5H01@3_IEX0l6=I0?1SF@3`HeT0lF=I0080kf5G00D0lVII0>iRE@3^HUD0k6QI0>1VE`02
0=M`H@040<]mL02?ET/0SeI;04lZ8P80Abl[00D0@34^03/`;P0d:RP0=2XX03D]:P0202lZ9`0502hY
9P0]:BH0;BTV030/:@0/:2L00P0Y9B@0100^:RL0;BPU02dX9@0/8b@202/R8`0502LR7`0]:2D0;2LT
02`W900[9R<00P0X92<01@0V8R409R@U02HT9@0W9BH09b8V0080:b@[00@071DL09:=T`2BSI<0lo7d
0P3UiND01@3Shn<0i>CT0>CTi03Ti>@0iNGU0080hn?S00D0i>CT0>CRh`3Th^<0jNOX0>[Xj@0209NC
TP04085kN`1mMG<0OGEc07ifL`80PGUf00D0NGIa06=RG@3LgMP0g=gH0>GUh`020>;Rh0050>7PgP3R
g]d0h]kM0>WUhP3[jn<00P2PXiP0101RJUd0SYJ;08jFR`3fnoD=003o00oooooo000=ooooobl00?l0
0P3imN`01@3Tf/h0a;BT0:fHQ`2]V8L0/iZ60080^Y^900D0_9^:0<>PS@33X8d0_Yj90<2QS@020=Rm
[0040?7Nd03ol^P0oo;X0?ofk@80oO?Z00D0n>kU0?;Yh03biMd0l^GM0>gPf0020>_MdP050>[Jc@3M
bkd0gL^m0<nl[@33[Yd00P2hXi00102ZU7l0XXMb0::7LP2ENF<2095aG00508iXE@2AIU<0UVED09IU
E02KIU@00P2SJ5P01@2WJ5L0ZfQH0:]XF02XHe<0XEE70080W4i100@0W4Xn0:9:?P2RBSh0Zde30P2/
AC`01@2fAS/0f6AG0=mWF@3OIeT0iF]L0080jFiL00D0kW5M0>e^G@3]KUd0kg1O0?1aH0020?5bH@04
0?AbHP3eLf<0mG=S0?9`H080kg1O00D0lW1R0?5_H@3cKf00lfmP0>iZF`020>eXF@050?1[G03^JU/0
kVYK0>eYFP3/IeH00P3]J5T0103_IeT0kVIJ0>iVFP3bJEl20>YPEP050>mUFP3`HeT0l6=I0?1SF@3a
HeT00P3_HEL01@3bIUT0kV9E0>iRE@3/J5T0h6IG0080eg1Q00@0bge`08mFB`2?ET/0CbXR0P17;b/0
1@10<Bh0>c0^03@Z:00d:RP0=BdZ0080;bXW00D0;RTV02dY9P0]:BH0<2`Y02`X9`0202TU900402hZ
9`0]:2D0;BPU02`S9080:b8S00D09b8O02dX9@0/9b@0;2LT02/V8`0202PT8`0502HR8@0V92D09R@U
02LU9P0W8RH00P0[92/0100L5A`0TXfC09:=T`3clO@20>GUi@050>?Sh`3Ti>@0i>CT0>CTi03UiND0
0P3Shn<01@3Ti>@0i>;S0>CRh`3YinP0j^SY0080Ui>B00@0PG]k07eeL`1mMG<0OWIc0P21NGH01@1i
MW40Hf9M0=cMf03LgMP0iNGS0080h^;P00D0hN3N0>;Ng@3Rg]d0jNGR0>_[h`020:2SV004069ZG@2>
UX/0SYJ;0?Kkm@d00?l03oooool000gooooo<`00o`050?okm@040?ojm@3ono@0oo_d0?ojlaL00?l0
00@0oOK^0?G^iP3ek^H0kNCK0P3WgM<01@3Md<L0d;ne0<6_X`31[j<0]:6C0080Zi>700D0Y8Ql09mo
LP2OOg80WWQ[09Y_G`0209e/G@040:]cI02ZKE/0ZVeK0;E`H@80_6iQ00D0`6YK0<MZF@3<J5P0c6QH
0=1YF0020==XE0050=MXE@3HIeD0f6ME0=i[F@3SJeX00P3QJ5L0103TJET0iFMH0>EWF03YK5X20>Y]
F`050>i_H03cM6<0lg9O0?=bG`3dLf000P3bKed01@3hMF<0mW=Q0?IcH@3gM680mg=T0080mW9S0`3f
LF801@3aJel0lf]O0?=[G`3`J5`0mViR0080m6MM00@0m6IJ0?=UF@3cIET0kf5C0P3aIEH01@3YI5D0
h6EF0=a`H`3LL6<0c7IY0080OSX_00D0DQdE04/S6`1;8a/0?b4G03XR600203<P6@0402lR6P0^9b40
;RLQ02PT8@8092<O00D09bHT02DS900T8R<0928S02HU8`0202XV9@<0;2HX00D0;RPZ02/U9`0/8bH0
;2<V02/U9@0202`X:@05020N7`0Q7b808AlR02PV:`0V8BP00P0U82L0100n>D00fMCJ0=WDfP3^k>l2
0>GSiP030>CRh`3Uhn@0i>?Q00D0i>?Q0P3Rh^00103Shn40hN7O0>?Sh@3Shn430>GThP<0in?R00D0
i>?O0=[Jf03Shn40hn?Q0>;Rh0020>;Qg`050>7PgP3Tgm`0i=oL0?;]j@31_[D00P1hNVl00`1TJV00
cmC=0<oDc@0>003o00oooooo000=oooooeh00?l00P3on_@01@3kl^/0mNSP0?GXh03_g]@0j]K;0080
hlVl00@0gKf`0=2/WP3@[9h0c:2C0P37UXP01@36SX40`hEf0<9oK`32Ofl0_WEV0080_g=S00D0`75P
0<5^GP31KUh0a6aN0<M[G0020<MZF@040<a[F`3@K5d0d6aM0<eWF080cfQG00D0e6UI0=AVE`3GJ5D0
efQE0=ETDP020=]ZF0050=]XEP3JIE@0fVED0>5/F`3PJ5P00P3SJe/0103RJ5T0iFYK0>EZF`3UJU/2
0>M/G@050>]]G`3]KF00k6YL0>aZG03[IeX00P3WHU<01@3UH540iV5B0>IQDP3THU80gF=D0080g6iO
00@0`FEF07<U601c9AP0GQ`<0P1A70X01@1670H0?Qh703HM1`0f7@L0:AP600806@l300D040`300/:
1@0;2PD02``700`:2`0200d;3004014?400@30d040`=010;3`805a8F00D06aDI01H@500B30h04P`>
01@>400201dK700502XX:`0_;S@0;bhd02l^=P0`;cL00P0n?DD0102HUil0g]gS0=kMh`3Ge]/20>3P
hP050>CRi@3WiNH0inGV0>OUiP3ViN<00P3Ui>801@3RhMl0h>3N0>3PgP3Qh]d0h>3N0080h^;P0`3S
hn401@3Rh^00hn?Q0>?Sh@3QhMl0h^;P00<0gmoM0P3Pgmd01@3QgMX0jN7N0>WQgP3ck>H0KVYO0080
I6AH00<0U9N>0?Khl`3fn?<03P00o`0?ooooo`003OoooomN003o0080oo[d00D0no;[0?GXh03ej>00
kmkD0>[Fb`020>?9_0040=fm/03@[9h0d:bN0<bPT`80aiJ800D0aXj10<>5MP32Ofl0`Wm_0;ieIP02
0;mcH`050<1aH031KUh0`FiN0<A/GP37Je`00P37JUT0103<Je/0d6aM0=1/G@3=IeP20<mXE`050=AY
F@3DIUL0efQE0=MXE@3EI5800P3KJUP01@3KJ5H0fVED0=YUE03QK5/0h6QH0080hf]K00@0hVQI0>EZ
F`3UJU/0iFYK0P3WK5d01@3[KEl0kFeP0>aZG03/JU`0jfMJ0080if9C00D0iF1A0>IQDP3VHE80i69B
0=eSE0020=a^G`040<5UEP1c9AP0LbDH05hL3080DA`:00D0AQ`603hN1`0f7@L0=Qd702TH1P0201T?
0`05010<0`0;2PD02`X500/<1`0<2P/00P0=2``0100A3a0040`=010<3@0@2`l201LB5P0501/E6@0F
41@04P`>018<3P0D3Q000P0M6a`01@0Z:2/0;bhd02l^=00_;SH0<2lg0080?Se500@0V9NO0=kMh`3N
gN<0emKK0P3Ph>801@3Th^D0inGV0>OUiP3WiNH0i^GS0080iNCR00D0h^7O0>3PgP3Ph=h0hN;M0>3P
gP020>;Rh0<0hn?Q00D0h^;P0>?Sh@3Shn40hN7O0>;Rh0030=oOg@80h=oM00D0hMgJ0>WQgP3YhMh0
lncV06iZG`0206ATF00309BGSP3fn?<0m_Sc00h00?l03oooool000goooooI@00o`020?ojm@<0ooWe
00D0ooOb0?ock`3olnl0onkX0?[Sg@020?KMeP040?;Ec@3[cL<0jlg30>?1]`80fK>X00D0d:FL0<NH
T030T8H0`9260;n;OP020;^6N0050;IkK@2dMFH0]7EV0;QdI`2gKf400P2jKUh0102kKU`0_6]J0;a[
FP2oK5`20<9[FP050<5VE032IE@0`F1?0<5PC`36HU800P38HE801@3;I5D0cF=E0<eSE@3:Gdl0dF5C
0080cUe=00@0dUi?0=9MC03BGD`0eF1?0P3GHU001@3GHU40dV5?0<iSD@3>He40_Ue:0080YE4i00D0
W5Dg08U=:@29CBT0MdLO06i;8@0206557@0404lm6@1iL5<0NG1C08=nJP80OG]_00<0MGA_081lN`1i
MGH00P1iMGH207QdM@0507MbMP1]Jfh0KF]^07IbL`1oNg`00P25PH80102@S8d0YZBW0:JTY`2QX:H2
079bO00504]=F@17BeH0BTiG04Y>E`1]LGX00P1dNGl01@1hOH<0SiBH08nDV02MX:D0/;6e0080`<73
00@0b/[:0=[Ie`3JfML0jNST0P3Thml01@3Thmh0iNCP0>CSg`3Thml0iNCP0080i>GP00D0hnCN0>;S
g@3Rhmd0hnCN0=oQg0020>7SgP040>3Qg03Qh=`0hN3L0>?Pf`80lN[R00D0g]S<048o<020OW40P7ia
0=;Cc@0@003o00oooooo000=ooooogD00?l00`3onO<0103om_80oo3Z0?o`jP3mjN820?WQe`050?GH
d03bdLP0l]780?3;`P3^a[`00P3X_[80103V^:/0gZjR0=j^XP3KZY`20=VSU`050=BJSP3EVX`0dY:6
0=:BQP3ASH000P3=Qg/01@3=QGT0ageb0<MmLP38O6l0aGMZ0080_VmR00@0`FmQ0;eZG02mJU`0a6iO
0P2mIeP01@30J5X0^VAE0;ISD`2fHe<0/VEC0080[VQ?00D0YfY;0;>2FP2cPUX0d:Yk0<FWM@020<2/
NP040<NjSP3Yh;l0jN2o0>_WcP80in?G00D0jNKQ0>[Vi@3VhND0i^7U0>GPi0020>OUj0050>KTj@3R
h><0h^3S0>CRi@3WiNH00P32`<40102KVIX0MGIh07EfN00i?D02028W;@0502lf?00g@4D0>TA603Y4
AP12C4h00P18DU@01@1<EUP0CEMH04eGF01CFed0DEII0080DUQH00@0D5AC071bK`1`LVl0hnCO0P3^
kNP01@3ViN00iNCO0>?Sf`3Shm/0i>?N0080i>GM00D0hnCL0>3SfP3PhmX0hnKO0>;UgP020>7Tg@04
0>3Sg03PhM/0h>7K0>OTg@80i>3G00D0XinC04Q5=P2RX9@0XZ2D0?Kel@0@003o00oooooo000=oooo
ohP00?l000<0ooWe0?ohm03on?@00P3on?@20?obk`040?o^jP3ojN@0onWT0?oVh@80oN7M00D0o=oK
0?WJe@3deM00m=G@0??Bb`020>k<``050>c7_P3S_K@0hkfd0>2j/@3E[jH00P3AZj001039YIT0`9n>
0<2OSP2YSGD20;2IN@050:RFKP36^Hd0dLRM0=78W@2PVgD00P2VXXD01@3Ge<40c<W00<c9`02VYJ40
];:c0080gmgR00@0dLoD0;2^/`2`[[<0^;Fl0P2n^l820>OUj080VYRI00@0MGMf07=iM`1cNGL0OhR5
0P1<Ee<01@0c?c/0AE9;04EBB@15DTT0AU=:00<0B5E>0P1:EU801@1?FUH0C5MC04UDD019E500Ae9<
0080BE1900D0[:jY0=;Cc@3Bdld0b<W10<K7_`020<c>``040<W:`P38bl00b<_00<[=`P80bLo300D0
alg30<W?a@38cLH0b<g60<C9`P020<G8_`050<74^`2KW9@0VibD07YjL02;Rh400P3Cd/dA003o00oo
oooo000=ooooohP00?l000<0ooWe0?ohm03on?@00P3on?@20?obk`040?o^jP3ojN@0onWT0?oVh@80
oN7M00D0o=oK0?WJe@3deM00m=G@0??Bb`020>k<``050>c7_P3S_K@0hkfd0>2j/@3E[jH00P3AZj00
1039YIT0`9n>0<2OSP2YSGD20;2IN@050:RFKP36^Hd0dLRM0=78W@2PVgD00P2VXXD01@3Ge<40c<W0
0<c9`02VYJ40];:c0080gmgR00@0dLoD0;2^/`2`[[<0^;Fl0P2n^l820>OUj080VYRI00@0MGMf07=i
M`1cNGL0OhR50P1<Ee<01@0c?c/0AE9;04EBB@15DTT0AU=:00<0B5E>0P1:EU801@1?FUH0C5MC04UD
D019E500Ae9<0080BE1900D0[:jY0=;Cc@3Bdld0b<W10<K7_`020<c>``040<W:`P38bl00b<_00<[=
`P80bLo300D0alg30<W?a@38cLH0b<g60<C9`P020<G8_`050<74^`2KW9@0VibD07YjL02;Rh400P3C
d/dA003o00oooooo000=oooooil00?l000<0oo_e003o003on_@00P3on_@20?okl@050?cci03KeKl0
fmFo09nJO@2JUgP00P2@Sg00101QHDD0=cTS03Li8`2TYYP20;g0]`050453@010@D<0X:6U0:2QY@30
`LD00P0`=3L01@11@TL0FeaP05]LH02LWIl0UYRG0080O7im00@0I6QW07=iM@1cNGD0^<6l0P2[]:l0
1029U8`0T9bB09>OU@2CWiD309n[X@050:2[X`2/]k40[;Na0;2k]@2_^[@00P2g`[`0102lal40_lG1
0;o5`@3Ae]020=oRf`040=oPfP3NgmL0hnCL0>?Tg0<0h>?J00D0i>ON0>CZh03Tj^00iNSQ0>O/i@02
0>[/i`040>O/iP3]l>T0kO3Y0?3ck080k_7Z00<0m?O`003o0000o`004P00o`0?ooooo`003OoooonY
003o00050?Shl03Mgm@0[;2Q0:b`X@23RWX00P1HH5401@1JI5T0IG5W06EaI`0`>cD0<c`i0080D5]G
00@0`/g903U4@00iA400=D4o0P0mBDD01@17DT`0C5E@04I<B016C4P0NGij0080bL_:00<0mOOf003o
0000o`00?@00o`0?ooooo`003OoooonY003o00050?Shl03Mgm@0[;2Q0:b`X@23RWX00P1HH5401@1J
I5T0IG5W06EaI`0`>cD0<c`i0080D5]G00@0`/g903U4@00iA400=D4o0P0mBDD01@17DT`0C5E@04I<
B016C4P0NGij0080bL_:00<0mOOf003o0000o`00?@00o`0?ooooo`003Ooooon]003o00040>S_j03>
eLh0c]G>0;[4_080YK2X00D0UJ2J08NBSP1fPGd0MX5m09nZY00205QUGP0504]GD`18EDh0B5E>05eZ
H`2NZJ<00P3EfmM3003o00oooooo000=oooookL00?l000@0k?3_0>?Yi`3SjNL0f^3L0P3Bf=@00`3J
h=`00?l0003o0014003o00oooooo000=oooookL00?l000@0k?3_0>?Yi`3SjNL0f^3L0P3Bf=@00`3J
h=`00?l0003o0014003o00oooooo000=ooooool00?l01@00o`0?ooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooo
oolQooooo`00oooooolQooooo`00oooooolQooooo`003Ooooooo003o00D00?l03oooool000gooooo
o`00o`05003o00oooooo000=ooooool00?l01@00o`0?ooooo`003Ooooom?003o00050?Gem@3Lg=X0
_[jl0;jn_02EUI<00P1fMW@01@29RhH0][Rc0;Jh/`3GfMH0l?3^0:T00?l03oooool000goooooB@00
o`00103^k^`0dm;@0=?Bd02^[J/208N6Q00505eLFP0n?cX092DP02@U800N7aX00P0L7AP302<V7`05
03Xl=`1CEE00O7eg07amM`2YZZ@00P3PhMbT003o00oooooo000=ooooodT00?l000@0k^k/0=?Bd03C
d]00[Zf[0P27QX@01@1MG5X0?Slj02@U800T9B007QlJ008071dH0`0S9Ql01@0j?3L0DeE@07amM`1l
OGL0ZJZT0080h>7LY000o`0?ooooo`003Ooooom7003o0080e=?A00@0GEaH03@c;`0d<bl07ahJ0P0T
81d01@0M71P07A`G01/J5@0K6QD081lJ0080824K00D08R<M01`M5@0L7AD06ahG01PK5002024R7004
028S7@1DEDl0E5E?0<K7`Z<00?l03oooool000goooooAP00o`00103cl_00LVi[079^J`0Q7QT202<R
7@0502DT7`0W9R409bHQ02DT7`0R8A`00P0R7aP0100V8a`0:BHQ02TV8@0S81/202<R7@05020O6`0R
8A`09RLQ02HW8@0S91h00P0R9Ah0100m?cX0YjVV0:NYYP3fn?FP003o00oooooo000=ooooodH00?l0
00@0lo;`079^J`1bKV/08AhI0P0S8Qd01@0U91l09bHQ02LV8@0U91l08R4L00808QlH00@09R<L02TV
8@0Y9R408b0K0P0S8Qd01@0P7a/08R4L02HW8@0V9b408b@N00808RDN00@0?Clj0:NYYP2WZJH0m_Se
X000o`0?ooooo`003Ooooom6003o00040:FTX00_;2L0;b`W02DR7@80:BHQ00D09RDP02@S7P0T8ah0
:BHQ02dZ9@0203D`;00403Xe<@0i=300>C@`03D`;080=c8^00D0=S4^02`X9@0Y:2<0:BPS02<R7@02
02HW8@0501hQ6P0U9b809BLR07eoO03Xj^T0W`00o`0?ooooo`003Ooooom5003o00050=3@cP11@3`0
8b8M02<R7@0W91l00P0U8Qd01@0S81/0:RLR02XW8P0h<bl0>cHb0080@SXh00@0@c/i03Ta;`0i<Bl0
?3@a0P13>cP01@12>SL0@CTf03`g<`0l=c<0;bXV0080:BHQ00D07QdH01hP6`0N81/06Q`I07UkNP02
0?GgmYd00?l03oooool000gooooo6P00o`001@3Xf]T0dKnm0=6o_@3Ha/@0gL_90080iM?A00@0j]SF
0>kOg03^gm`0m^OT0P3kjn/01@3olO00ooOe0?ofm03om_@0ooOe01L00?l00P3`l>h01@1/KFP07AhI
028Q700R8A`09B@O00<08AhI0P0k=S801@0m>3@0=C0]03Ta;`0i<Bl0>C0a0080<b/Y00D0=bd[03/a
;`0k<Bl0?cDc03hd<P0204@l>@04048m>@0m>3@0?CPd02DT7`807AhI00@06adH038d<@3=clh0cLo>
W@00o`0?ooooo`003OoooolJ003o00050>SJf@3A_kd0dKnm0=S6a03MblT00P3Udm40103Zf=H0k]oL
0>kOg03fin@20?_[j`050?oal03omoD0ooKd0?ofm03omoD05`00o`020?3`kP0506a]J00M7QT08R4L
028Q700U91l00`0Q7QT203/f<P0503dh=00e<2d0>C4_03Ta;`0i<3400P0c:bT01@0g;B/0>c4_03/a
;`0o=C<0?S@b0080A3`i00@0@Sdi03dh=00m>3@09B@O0P0M7QT0100K7AP0<S@a0<g?cP3=cljM003o
00oooooo000=oooooaP00?l00P3/em@01@1lEe40F2/U05P[9@1Q<2`0IC@`0080KC`g00@0KSli07Q;
AP1hBdH0OeA>0P26GET01@2=IV40TF]X099aK02BLF`0V7Ud0080YXV500D0Zhf;0;FIUP2eVIH0^inL
0<F/Z0020<bc[`040=No^`3K`kl0fl>o0>79a@80i<o<00D0j=KB0>cMfP3bi><0l^CS0?CZj0020?O_
k@050?[fm@2VYJ<0YZFS02l^:P0U91l00P0T8al0100R8Ad071/F01`K5P0[:RD2044m>P0302l[:00a
;BX0;bXW0080;bXW0P0a;2T01@0g<2X0=2dW03@]9`0l<bh0>c8]0080>c@^00@0?CPb04E0>P15@3X0
=CD]0P0T9Al0100S91l08b<Q08N7Q@27QhFM003o00oooooo000=oooooaL00?l000@0mmoM08eTH02=
I600Jc0Z0P1e<2T01@1c:BH0L2HS070Y8`1`:B<0JB@M0080JRLQ00D0I2DN06X]:01Z;BP0OT<m07<l
=`0206`j<`0406Xi=01X>cH0J3/f068f<`80I3Pe00D0Fc8^05`c;@1K=2d0Fc@]05Xc;00205D`:005
05dh<P1R?cT0HSli06=2?@1[CTX00P1/Ddl0101]FUH0GU1=05i@C@1ECD/203Lb;`0502HR7`0W9R40
9RDQ02HU8@0S7a`00P0I5Q401@0g=2l0@Sdj048m>P0W8Ql0;2PU0080:bLT00@0:2<P030[9`0`:bL0
<b`V0P0_:2801@0h;bX0>c8]03H_:@0f;bT0>CD/0080>3<]00D0@d0i03Pg<P0h=c808B8L02<T7`02
0410?P030=cLfP00o`000?l009X00?l03oooool000gooooo5`00o`00103ggmd0SFAP08eTH01[<2X2
07D`:@0507<Y9P1`9R<0L2TS070Y8`1Y91d00P1Z9b401@1T9Ah0JRdX06X]:01n@cd0Lc`g0080K3Xc
00@0JSTd06Pk=P1X>cH0HSHc0P1T>3D01@1K<Rh0G3<]05/d;@1K=2d0FS</0080EC0X00D0GCPb068o
>@1R?cT0Hd8m06]>BP0206aCC`0406eJEP1ND4d0GU1=05E=B`80=c8_00D09R8O02LV8@0V9B409RDQ
02<O700201TF4@0503Ld;`12?CX0@Sdj02LR7`0/:2D00P0[9b@0100X8b00<2/W030[9`0c;2H202lX
8P0503P_:P0k<Rd0=RlY03H_:@0i=B`00P0h<bd01@13@3T0>3Lb03Pg<P0Q8Q`08b@O0080@40n00<0
g=cJ003o0000o`00VP00o`0?ooooo`003OoooolE003o0080n^KU00@0WG1]07Da;P1e<Bh0QcHc0P27
;B`01@26;BT0PbXV084Y9`21:BL0PB`Y0080Ob`X00D0NR/V07LY9@1g:BD0OC<`07Xg;`0207/l=@04
074f<01[<R/0Jc8[06Pa;080LC`f00D0Ic8/06dh<01]>c80KC/b0792>00206ln=`0506`k=01a@3T0
LD0i07A5?`1W>S@00P1F;BL0101C=Bd0;aPB02lH4P0C1@82024I5P0502hY9P0U8Ah09R8O02HR7`0R
7AX00P0R6QL01@0j<Rl0AS`k04Hl>`0V7Q`0=S4]0080<B`X00@09b@O02TV8@0Y9R40:RDQ0P0]9B80
1@0c:BL0=bd[03H_:@0f;bT0>3<]0080;BPT00D0?c`g0410>010@3P0:2TS02<R7@02024P7003096A
S`00o`000?l009X00?l03oooool000gooooo5000o`00103oknd0Z8:10:R2P@1`;bd208Lb;`0508PY
9`2<:2P0S2PX09H`;P299B<00P2>;2/0102?<Bl0R2dZ08P]:P28;Rd208<^:`05084`;@1j;bT0O3H^
07`f;P1g=2`00P1Y:R<01@1e>C40NSlg07Xo=`1_=2`0L3L^0080JC<Y00@0JCDZ06hg<01^=c00L3Tb
0P1h@CX01@2?ETl0O4<l068]9`1R;BL0Kd@m0080AbHO00D07`X502LL600W71P0;RHS02HQ7P0202PS
800402DP7@0R61H08QPF03D[:@80BChl00D0;bDS03Pa:`0i=2h0>C@^02TT7P0202LR7P0502HQ7@0[
8b00:b<P02hV900e;BX00P0d;BL0100i=2h09R4M02HQ7@0d<B`204A4?005030`:00S8Qd07ahJ01lN
6P12@T000P3Hf=JJ003o00oooooo000=oooooa@00?l000@0ono]0:R2P@2XPX40L2l]0P27<Rl01@28
:BL0S2PX08`X:02F<2h0RBDS0080SR`[00@0Sc4_08P]:P28;BX0R2h]0P23;R/01@21<2d0NRlY07`f
;P1l=Rh0Mc@/0080JBXS00D0MCTa07Xo=`1j?cL0Kc@/070g;P0206Tc:@0406Te:P1^=c00KSL`070i
<P80N44j00D0SeI?07a3?01R;BL0HRdW06m4?@0204LV7`0501l:1@0W71P09a`H02hV8`0V8Ah00P0X
8b00100U81d08QPF028H5P0e:bT204Tn?00502lU8`0h<B/0>C@^03Td;P0Y91h00P0W8Qh01@0V8Ad0
:b<P02/S800^9R@0=BdZ0080=2dW00@0>C@^02HQ7@0V8Ad0=34/0P14A3`01@0`<2P08b8M01lN6P0O
7QX0@T900080f=SFVP00o`0?ooooo`003OoooolC003o00050?ofm@2lUY<0JBhZ06T^:P29>3D00P2K
?3X01@2cBdX0aUaL0<ILG02M=C@0Tbd[0080V3He00@0WSho09Tk>`2I>c/0W4910P2C>cT01@29=S80
P34/07lf;`1o=Rl0S4M00080Lc<Z00D0O40h08A9@@24BD40OdHo07Ho>00207a7?`0407A2>@1a?3H0
LC`f06`g<@80KcDa00D0MCPc07Tj=@1]<2/0KC0[07e8@002068g<00502hA2`0]6aL0;A/G02lT800^
9R<00P0Z9B80100W8Ql09adK02LM6`0_9R4204@i=@05040e;`0h;bP0>34Y03Pa:@0`:B<00P0Y8Ah0
1@0[8b009QhL02HN700Z8Ql0;RHS0080=2dW00@0AChh02XU8@0Z9B40>3<_0P1;B4<01@0_;RT09B@P
02LV8P0W9R809RHT0080P81nVP00o`0?ooooo`003OoooolC003o00050<JZY`1V;bX0LbDQ07<U8@2Q
@d400P2gCdh01@2lDU80^Dm?0;U?C`2P>3L0ZDE30080YTA500@0U3@e09@f=P2D=SH0T3Dd0P2D>ST0
1@2?>SL0QSLb07`a:`1l<B/0M2lX0080MCH_00<0JRlY070i<P1`>C800P1jACl208ABB`04085?B01b
?CL0LSdg07Dn>@80M3Ld00D0LBdZ07H_:`1e;RX0MBhZ08U6@00207a3?00504`O6P0j6A@0>QTD03HN
6P0e9R<00P0^8b40100[8b00;B<Q02dS8@0[8Qd2030W8P0503`c;014>c@0?SD^03he;P0a:R@00P0_
:2801@0b:RL09alL02LO700S6aP0<2TS0080@CXd00@0@Sdg02lZ9P0_:RH0@Slj0P11?ST01@0Z:B@0
92<O02TX900Y:2@0:RTW0080;bh/00D0L6a]0:JPX02VX:00clW90?3[j02E003o00oooooo000=oooo
oa<00?l000D0aZZW06H_:P1c9B40LbDQ0:53@@020;M?CP050;aBDP2iCdl0^Dm?0:0h=`2YAD<00P2V
A4D0102D=3D0U3Hf09@f=P2@=C@209@j>@0508lj=`26=c80O34[07`a:`1d;bP00P1e=Rl00`1Z;bT0
L3Tb070i<P0207Y5?`80Q59;00@0PDm8078m=`1b?CL0MChi0P1d=c@01@1a;BX0MRl[07D^:P1e;RX0
RDI00080O4<l00D0C1lJ03XI500j6A@0=QhJ03DV8`0202hS8@0402/S800]8b40;B<Q02/R7@80<2LR
00D0?3</04@k=00n=Bh0?SD^034Z900202lX8P05038Z9`0W7a`09alL02<K600`:B<00P11>S@01012
?CL0;bXV02lZ9P12?cX2044n>@0502XY900T8al0:BPT02TX900Z:BL00P0_;R`01@1`K6d0YZ2P0:JP
X03?bLT0l>_X09D00?l03oooool000gooooo4@00o`020=:i]00506Tl=P1Y81X0RC0/08T`;02[AD40
0P2Z@Ch01@2X@3d0Xcdi0:<m>@2F=340SRl[0080RR`/00@0R2XZ08T[:@29:bT0RRl/0P2=<S401@2:
<S00QcHb06dT7P1]91h0RTU30080VUmI00D0MChi07U6@P1iAT80QEA?08UHD`0208YGD`04099MF@27
D4d0Qe1=08]?CP80T4m=00D0Q3Xi084`;@23<2`0Pc0/08`i=@0209Q9A005084n>01F7aX0EQlJ03/B
300j7AL00P0e8Qh00`0^8al0:b4O02/Q7`0302XS7@0502/T7P11>3<0BT4l04Y1?019@3/00P0m=2l0
1@0m=S00<b`V03</9P0b;BL0>C@^0080?CPb00@0?CXc048o>P12?cX0?S/f0P0d<2d01@0Z:BD09B@R
02XY9`0Z:BL092<Q008081XJ00D07Q@E01d=400M3A00@Rh_075KG@0208MaL`040;JTY03IbLT0fLW9
0?CYihl00?l03oooool000gooooo4000o`001@3WeM40LTU30799@`1O81T0OBPS0080VcLe00@0YShk
0:8j=`2R>SL0W3Hb0P2C<2/01@2::bL0Q2HT08PZ:P28:RX0Rb//0080S2d[00D0Rb`Z08TY:P29:BX0
Qb`[088]:00206`Q6`04099AB`35RhL0aH^70:]fL080U6=N00D0TV5M09=RGP2SL6`0Xg1/0:E`K002
09YRH@0509=GE`2DDU<0U59C08Hl?@2:=SH00P26;2/0102><2h0X4900:12@02QBDL208/m>@0505hR
6P186A<0?AXF03dJ5P0f7QX00P0_81d01@0^9B00:B8L02TR700[91h0;B@O0080>2lZ00<0AC`g04M0
>P17@3X00`17@3X01@17@S`0AT4k048o>012?cP0@d0i0080@d0k00D0;bhY02XY9@0Z:BD0:RTU02/Z
:00202HR8@0402HM7P0W6ad09a/M02<>4`809PT>00D0?alR05hl?@1G=cP0EcLh04X/;00204`c;`05
06E@B`29N740RGQa0;R[X`3Kd<X00P3ek>N9003o00oooooo000=oooooa000?l000D0/IFA068[9P1R
:bH0LB@N094b<00209li=`040:<m>`2O>CL0WcTg09<_;@80SbdZ00D0Sbd/08h/:`2<:R/0S2X[08dY
:`02098Z:`0508`T9@2A:BX0TBTZ08d[:P2><bh00P20<2T0101]:240RTe808Y=B02kQWh20;b:P`05
09AQG@29EU<0/7ei0;1mN@2LIf<00P2ZLW401@2JGUh0Od5207m1@P1_:b`0MBHY0080O2HW00@0Sbl`
0:8n?P2R?Sh0ZdE30P2ZBdL01@2K@cl0MRdW05DK5`1E6aL0AATF0080?1hL00D0=b@P03<U8P0c9B80
;R<Q02`R8002038X9P0402`T8@0b;BT0<RdY034/:080>cHb00D0@3/g03`g<`0i=S40>CHa03Hc;P02
02`[9P0502XY900Y:2@0:BPT02LV8P0[9R<00P0Y7ah0100Z6Q/0=1/O03@K7`0]31<203T@600504`O
901O<SD0SVAU08iTI@2AJfP00P1mFe801@1UACX0ESTY05Hi:@1=<R40Fd4`0080KeQ800@0UGmb0<6_
Y@31[jD0hm;:0P3lknV3003o00oooooo000=oooooa000?l000D0/IFA068[9P1R:bH0LB@N094b<002
09li=`040:<m>`2O>CL0WcTg09<_;@80SbdZ00D0Sbd/08h/:`2<:R/0S2X[08dY:`02098Z:`0508`T
9@2A:BX0TBTZ08d[:P2><bh00P20<2T0101]:240RTe808Y=B02kQWh20;b:P`0509AQG@29EU<0/7ei
0;1mN@2LIf<00P2ZLW401@2JGUh0Od5207m1@P1_:b`0MBHY0080O2HW00@0Sbl`0:8n?P2R?Sh0ZdE3
0P2ZBdL01@2K@cl0MRdW05DK5`1E6aL0AATF0080?1hL00D0=b@P03<U8P0c9B80;R<Q02`R8002038X
9P0402`T8@0b;BT0<RdY034/:080>cHb00D0@3/g03`g<`0i=S40>CHa03Hc;P0202`[9P0502XY900Y
:2@0:BPT02LV8P0[9R<00P0Y7ah0100Z6Q/0=1/O03@K7`0]31<203T@600504`O901O<SD0SVAU08iT
I@2AJfP00P1mFe801@1UACX0ESTY05Hi:@1=<R40Fd4`0080KeQ800@0UGmb0<6_Y@31[jD0hm;:0P3l
knV3003o00oooooo000=ooooo`h00?l00P3kjND01@23GUP0IB8L06DR7024:bL0WcTg0080XSPh00@0
V30_09dg=@2M=cD0VC<a0P2E;bd01@2@:RP0S2@U09@Z;02D:R`0UbX]0080URPY00D0URDW09HX:@2F
:2T0VBl_098_:P0208Xa:`0407`a:`21@3X0PD0j08eFC`80_8Z300D0aiBA08MDD@2RKf`0XVm/0<6>
R`020;InO`0509YOH@2VJV`0YVY/0:YZJ`2WGf800P2B@TD01029<c@0SS8c08hb<`2M?Ch209Li>@05
09<k>@2HBTP0PT4o0891?`1L:BH00P0k5A@01@0m8Ah0@2PX040X:00j9RL0<b<S0080<bDT00@0;B8P
034W9@0a9bD0=B/Y0`0_9B<0100f;2X0;bLT02lW900c:bP202XU8@0502dX9@0^9R@0;RHT02XP7`0]
7Ah00P0/5QP0100h6Ah0>10H03P@600d1@d204dJ8@0505XU;@1L:2`0LD510751@@2JKfT00P2[PgT0
1@2JMF<0UgAN09MdGP2@LED0PVE70080KU4c00@0FSlT050f7`1@=Ql0EchZ0P1^FDP01@2CPGD0_k6X
0>;Ec@3ReLd0n^o[07h00?l03oooool000gooooo3P00o`020=_2_@0506Df<01`8Qh0L28N090a;@2Q
>3D00P2U=cH0102L<300VBl_09T_;`2L<2h209PZ:@0509LY:02J:RT0X2`]0:0/;@2S;2h00P2R:bd0
1@2N9bT0YBh`0:D^<02T<340XC<b0080RbPS00@0UD0k0>fVX03]YZ00b8f70P2AGeP01@3BWi`0ZgUh
070n?`1`?Sl0fjNY0080e9fR00D0KSDk0;MoPP2gOh80finQ0<R7R`020;5_L@040:]YJP29ADH0RDE6
0;UcM@80fI>E00D0_Wam08i@D@1i?ch0NCln07=1@00206Dm?@0504TW9P1>;2d0CR`]04PX:`15:2X0
0P13:B`0100m9bT0>bLY03/W:@0e8b<203@R8P0503<S8`0f9RH0=2@U03@T9@0b8R<00P0^7Ql01@0a
7R80<A`Q034L8@0f6b00>A@K0080>@hE00@0@@hE04<<4P133180EQXR0P1[;SH01@1X;3@0IBhc06@`
<P1T<380MTI20080XWY^00D0XWm[09=dE`2CM5L0TgMB09R0DP0209YoD00409f0E02EN4h0UGQ>081R
?080Ke4_00D0GChR05<e7@1I?2X0FC`Z079HB@0209N1MP050<>aY`3Se<d0hmC=0?[_j@3on?D0M`00
o`0?ooooo`003Oooool>003o0080fl:m00D0ICH`070R7P1`8Qh0T34]0:4h=@020:Dg=P0409``<02I
;bl0VBl_09``;P80V2XY00D0UbTX09XZ:@2P;2d0X2`]0:</;P020:8[;@0509hW:@2U;S00YBh`0:@`
<@2Q<c800P2;:2<0102E@3/0kJJP0>fVX038SHL2095OF0050=:OW02[NGP0L3ho070n?`3KYjT00P3D
WJ801@1^=C/0]gn20;MoPP3KWj40b8N;0080/Fma00@0ZfUZ08U5AP29ADH0^G=e0P3ITiD01@2nO7d0
SU1A07To?P1i?ch0Ld500080ICdm00D0BBLV04h/;@1>;2d0B2P[04DX:P0204<Y;00403dW:@0k9bT0
>bLY03DS8`80=28R00D0<b<S03HV9P0d92D0=2@U038R8`0202hN7`05034N8P0a7240<A`Q03HK800i
51/00P0i3QD010113QD0@``B04<<4P1F6R8206/^=P0506P/=01U;S<0I30b06@`<P1fAT800P2RNVh0
1@2ROf/0TgAG09=dE`2CMe80V81B0080VWm@00@0WH1D09EhCP2EN4h0P68l0P1_DBl01@1M?R80DcDM
05Tl:P1I?2X0LUQ90080Uh5f00D0`k6W0>?Dc@3Se<d0n^oY0?ohm@1g003o00oooooo000=ooooo`h0
0?l00P2^SHP01@1P9R80OBXV07dZ9P2L>3H0XcLe0080XC4`00@0VB//09TX:P2I:2X0WBX]0P2Q;Bh0
102X=3D0Y2d_0:H^<02V;S030:T^<0050:X_<@2^<cH0[S<f0:/c=@2W<c@00P2O<C0010248R40^6EQ
0;QUH@3b[JP20<fBSP050:1YIP3GY:<0TV1S099PH`3FXjP00P3a_<801@1[=S`0TeYP09=JH03OY:P0
/7=h0080^h2200@0T5YJ0:mhN`2_N7/0l;Vl0P3h`L@01@3`_;h0gJ^/095QH@2AHF40c:2O0080l<[9
00D0_9RH05df>@1M=ST0EC4c050]<@02040P9@0404PX;@1B<SL0DS8g04DU:080@28T00D0?R4S03PN
8@0l8BH0?24V03/N8`0203XK8`0503@C700k5B00>aDP04<E801841/00P1<3AP0101C41T0I24Z06@Q
:P1c<3T206d^=P0508U=E@1`>Ch0JCDg06Te=`1G9b<00P1kDdT01@2YQW80YHM[0:F7J`2>M4l0SGE5
0080TGY400@0UGa409f2B`2MPT/0XH=?0P2SQ5D01@2MO540Tg5;08AS@P24Hd80JT/^0080FCdU00D0
BS4K05@o;01D?b`0LF1@09B4M`020<:e[0030>?HdP3jl^l0n_;_07800?l03oooool000gooooo3@00
o`00103hj^L0PU]F089KEP1S91l208Pb<@050:8k?02S=ST0WB`^09d/;P2I9R/00P2P;2l01@2i@TH0
^D150;U0A@2mA4T0_TI80080]cm100@0/CTk0:Ta<`2Y<C<0Zc<e0P2j?d@01@2_=3L0/SLj0:hg>@2^
=cT0Y34d0080S2HT00D0Y4a:0>^RW03[XY`0c8b:0<28Q`020=FSYP040;b;S`3[^L80jkW2099OJ080
GRL]00D0bi:H0:]`MP3<U9L0c9BG0:eiN`0208MEEP050?2n`@3Z^K`0j[Vl09EWJ@2nU9D00P3[`l<0
103ie]@0n=WG0?SIe`3Xb/P208EUIP050=2`/`3H^;d0Z8F;0:R5R`1L<c/00P1L;CD01@1P;cD0EbT/
05LY;0177R80?AHK0080@APP00@0Bb0Z04PH9P1862H0A0lO0P1A5RP01@1I5RL0J1/[07TV=P1i9SH0
ORhi0080OC4k00D0N3Dl070e>`1`=C/0Yg9h095PI00207M6B@0406Tk>`1M=2h0GC@^07iJC080/I5l
00D0YX]]091iC`2;MD<0RgE3095k@P0209J0A00509An@P2EOD40UGe109UnA`2RQe800P2WSEX0102S
REP0XXMJ0::7FP2BNE02085W@P0506iD<`1H?R<0CCDM04de7@1J@c400P1`GDl01@2QShD0bKZc0<Vj
/`3Xf]L0o_Cb06d00?l03oooool000gooooo3@00o`00103hj^L0PU]F089KEP1S91l208Pb<@050:8k
?02S=ST0WB`^09d/;P2I9R/00P2P;2l01@2i@TH0^D150;U0A@2mA4T0_TI80080]cm100@0/CTk0:Ta
<`2Y<C<0Zc<e0P2j?d@01@2_=3L0/SLj0:hg>@2^=cT0Y34d0080S2HT00D0Y4a:0>^RW03[XY`0c8b:
0<28Q`020=FSYP040;b;S`3[^L80jkW2099OJ080GRL]00D0bi:H0:]`MP3<U9L0c9BG0:eiN`0208ME
EP050?2n`@3Z^K`0j[Vl09EWJ@2nU9D00P3[`l<0103ie]@0n=WG0?SIe`3Xb/P208EUIP050=2`/`3H
^;d0Z8F;0:R5R`1L<c/00P1L;CD01@1P;cD0EbT/05LY;0177R80?AHK0080@APP00@0Bb0Z04PH9P18
62H0A0lO0P1A5RP01@1I5RL0J1/[07TV=P1i9SH0ORhi0080OC4k00D0N3Dl070e>`1`=C/0Yg9h095P
I00207M6B@0406Tk>`1M=2h0GC@^07iJC080/I5l00D0YX]]091iC`2;MD<0RgE3095k@P0209J0A005
09An@P2EOD40UGe109UnA`2RQe800P2WSEX0102SREP0XXMJ0::7FP2BNE02085W@P0506iD<`1H?R<0
CCDM04de7@1J@c400P1`GDl01@2QShD0bKZc0<Vj/`3Xf]L0o_Cb06d00?l03oooool000gooooo3@00
o`00103Ia/80Jc`f06/l=P1b:bL209@i>00509dd>02M;c80ZSTm0:Xi?@2K:Rh00P2/>d401@2gB4h0
ZCPn0:Th?P2kB4d0a55F0080fVIY00@0iW9c0>=/L03SK700dUUN0P3EFUl01@3:Ce@0c4mE0<=6BP33
ATX0_D950080]D5200D0WcTg09i5@@2NAD40eHN30>NVY0020?_5a@040<BCU`2RLgT0XW=i0>fka080
[7V000D0NdA:0;ElP`3SZ[00hjZ`0>fe^002081<CP050=ZY[03^`/<0k/;30=BZZ`25Geh00P30WY`0
103ohn40jLg:0>W=bP2MPGh208EYJ0050?;DeP3hfml0oMcS0?gLh`3R^L400P2GJ7001@1iATd0Kci2
06ln@P2KLGD0aijV0080VVmi00@0HSA108=>H023CV00`HJL0P2SHWP01@2mM8P0ScY?09a1D`2L@E<0
V41>0080QSDn00D0Pca20:U/L@2YK740Z75d0:=aM00209IVIP0409EWI`2HK6T0V6aY07YDB`80UW9T
00D0^IZ50:F;JP2<MD/0S7E;081Y=`0208Yd>`05099i@02FO440UWa109]nA02KOTH00P2NQ4/0102I
OdH0WX=<09j3C02URUD20:Z>G0050:^?H02WRV00U7I@09AfD01mH4000P1UBc001@1K@R`0CCHT04df
901IASP0KeeC0080WY2700@0bKnf0>SMe`3XgML0o_G`I`00o`0?ooooo`003Oooool=003o00040:jA
S@1[<2`0Jc0/08Da;`80VcLi00D0WS4d09d^=02V=cd0YSLm09dd>0020;EBE@050;aQIP2hGF80^5eR
0:m<D@2[A4L00P2^@D@0102nD540eV=X0=ISJ03IHVP20=mVK@050>aaMP3SIV`0fEYQ0=UJH@3FFEd0
0P3BEeX01@36DU<0]Te:0;I=BP2UAT@0_fi[0080lK6a00@0ol_=09QWJP2HIfX0UVU/0P3gb<h01@3B
Wj@0TeYQ0:AUK@2TIFd0bXN>0080O3i300D0aiFH0>[0`@3Z`<40`ifL0<ZYY00209MhL`040>c@c03n
iN40o^GQ0=o7a@80ZHb>00D0il[>0?[Oi02fVIh0]YVN0=fna0020>C1a`0506E1A@2^RXh0[XZ>0=2`
]@3M_/H00P3ddmh0102lV:H0T6=g091SM`3^^]420=bR^P050=>?YP31KhH0X4MK0:17F`2WC5d00P22
;3L01@2`Hf/0cXb>0<j<SP2TJ6P0[WIe0080X6YZ00@0VFMV0:=cK`2SLfl0VFaV0P2HKFH01@2YPgH0
^IV40;6CM`2aTgL0OF4l0080F3/A00D0LDlR085M;@21GBd0S6<e09M_?P0209ijB00409mnB`2OP4X0
Wh1:09j1B@80WXA;0P2OQTd20:F<E0040:F>FP2USEd0YHeM0:27GP80UG]H00D0Nf130696;P1<<A`0
C34L04L]700205Lm;P0507=MD02PS8<0X8b30<bk/`3ZgML00P3mm>mQ003o00oooooo000=ooooo`/0
0?l00P3jj>H01024G5X0Mc0^07L`;P2D=SH209X]<0050:hk@02f@DL0_TmE0;i?E@2T?D400P2ZCU40
1@3^Wj@0okZo0?nj_`3[TYH0fgb00080cFY]00@0^eUJ0:U4B02YA4P0ZT560P2]@4H01@2jBDl0a55H
0<eHH03=F600fF9X0080fV5V00D0fV=U0=ESH`3EHf<0dFES0;]LFP020;i^K@040?Nc/P3k_kl0nkno
08aFEP80/Geo00D0om7E0?Bm``2IG6<0VEaS08Y7CP0208Q6BP0508aDE`3fb<P0m/S80;^ETP2aTXd0
0P2jViH0102cUi<0nN7M0?WQg@3bf]P20>74aP050=Bg^`3oh^H0ck:f0<nb]P2XRhl00P3ce=T01@2I
Ngd0h/G70>;5a`3oiNX0glC;0080k<kH00@0omk/0<NM/@37WK40/XFJ0P3HY;/01@3Z[lD0iYjd09i<
HP2NC680Ye1Q0080SSQ500D0Xe9K0<QmPP38OH80WEUJ0;QhN0020;1cLP040:ibL@2[LFl0Zg5_0:9[
J080Uf9L00D0OTi40:UoL@3<Yi@0c:ND0:n;L@0207]H>00506U17@1lD2T0O50Y07mB:@20DBL00P1o
E2T01027GS00Tfdl09=]?02KMd<20:>4C@050:B7C@2MPdH0Xh]=0:>;C@2RRT`00P2RS5801@2ZTE/0
Zi5P0:^AH02XSF80Y8QQ0080UgYJ00@0PVA806U;<@1YBc40ESXT0P15;1H01@0m9Q@0E44b07ESE`1e
HeL0Wi290080bKjh00<0jN3K0?gelP3mmO80F`00o`0?ooooo`003Oooool;003o0080n^SV00@0Q5aJ
07L`;P1g<2h0U3Hf0P2J;C001@2^>d00]T570;i?E@2nCeD0Y3e10080ZTiA00D0kYnT0?nj_`3o^[l0
ji:F0=]lP0020<eZK@040;]IFP2YA4P0ZDA80:Y1AP80[D1600D0^TU?0<AAF03=F600cEQP0=URJ002
0=YQIP050=YSI@3EHf<0eF=S0=5UH`2kG5X00P2nKVd0103g/k80nkno0?^o_`2<EUH20;5mO`050?oA
e@3d_L<0VEaS09ULH`2:Adh00P28ATX01@2<E5L0m/S80?K8b02kUI80/I:=0080^Y^F00@0/iNC0?WQ
g@3ihMd0l][H0P3Qa<H01@3D]k/0on;V0<nb]P3?/[H0Z8^?0080lmCI00D0VG]m0>;5a`3RaLL0onGZ
0=o4b`020>c>f0040?oNk037WK40aifa0;:5VP80f:Bk00D0jZo50>JN]02NC680WTaR0:M@H@0208hh
A@050:=BF`38OH80b7f209eIFP2hN7P00P2`Lg80102^LW40Zg5_0:]aK`2RJfP209MRG00507i>A02Y
Og40c:ND0<bWU02_Rg400P1kF3P01@1Y@Ad0O50Y07a@:@1oDRT0P54W0080Oe@Y00@0Qeh`09=]?02C
KC`0VgM30P2SQ4d01@2TQdd0WH=60:>;C@2SRdd0XXY<0080XXaB00D0ZY5K0:^AH02[TF00Z8eR0:B8
H@0209MjFP04089TB01YBc40JD/a05Hj9080AB`F00D0?BHD05A1<P1eHeL0MF=G09n@R@020<Vn^003
0>WPf`3mmO80oOGb05/00?l03oooool000gooooo2`00o`020>75`P0407Do?@23;S40Pbha09hd>080
Y2le00D0^Ci30;XoA02h@dT0^4=90;16BP0209Di?P050=V<TP3fZk00mZ^`0<1YK`35JVl00P3IPh@0
103KRh`0hiNK0>>GV`3@PHH20<E^M0050;EHH02RADd0WSe409hmA02[@TT00P2lCE@01@35E5P0aeAG
0<MDE`3@GUh0dVAS0080df]Z00@0egUg0?ZVY03jYZ@0gY:B0P2]IV@01@3CUYD0omWL0?c;c`3lbll0
]gb20080XVAW00D0R4Q90;Z0O`2jP7l0llS20:>0NP020<^/Y`040;bPW03Rb/P0h/[80=:j^P80fK^m
00D0i/K90>C4a`3ogn<0omoS0=jk_`020?3=d@050=Fg]`3?/[@0ck:d0?oWjP34Yj`00P32XjT0103o
g>H0dJ^j0=6[^P2]Q9H20;Z?XP050=FT]`3l`MD0/fj10;=^P@28>D`00P2<>4P01@26<Sl0T3m6090o
AP26=cX0SCi10080[61R00@0[fEV0;=YJP2cJFX0_gQf0P2fLF`01@2SHU`0NT4f0;j?O`2nSgl0bIn9
0080Z81V00D0OEDb0716801`AR00Pe<[08MF;P0208AC:`0408MF;P24D2/0Q50[08IE;@80R5/a00D0
Ufi00:b8E02/SE@0[8eD0:F;CP020:F=C`050:B?D02RSU40XXiA0:2=E@2KRUH00P2PReh0102QRf80
Xh]U0:>;I@2NQV0209EmF@0507UQ?`1VCBh0CS@I04hd6@0m8Pd00P0n91<01@1C?Bl0N6IJ07QVFP2Z
W9<0d<Jm0080kNCM00<0oo[d003o0000o`005@00o`020>WXi0050=CCc`33`[h0YjJR0:NVXP2;RXP0
0P1/JfL01@1UHF00Hf9N06=RGP1YJ6@0IFAO0080HV=M00@0MWMa0;Nh/`2g^;<0jNWW:`00o`0?oooo
o`003Oooool;003o0080^YBA00@0LS8b08l`=02?<3@0Y34h0P2f>T801@32@4P0]3<h0;Tn@`2i?T<0
/DA90080V3`o00D0hIZN0>6PY03QX:@0SdM:0:ILG@02095;B`0409=FE@3ob/X0ol[:0<jFU`80`H62
00D0ei:E0=N@UP3YW:@0jIbT0<icO0020<YUK@050;]>E02eA4P0]DA80;e;B`2hATD00P31Cdh01035
FEL0c6QX0<aXJ039Jf/20<I^K0050:iPGP3NXjD0omWK0?oIf`3obL`00P2mOGh01@2/HV<0XEYH0:5J
F03IWi/0i[Na0080f[F_00@0j<W60<2RX030XZ00jlg=0P2iUiP01@3T`<@0e:fb0=2VZP3@YZX0m<76
0080lKg100D0oLc?0>fo`@3]_l40omSI0>2h^@02085HG0040=nf_P3P]/00h;K00:=iQ@80m/cJ00D0
h[C10=bW]`3LWjl0g9n_09UBI00207ha@@0507/]>P1n;SL0ORhg07TZ;`1k;2l00P2A@D@01023<CD0
WD]=09e;C@2UD5<20:YFEP050:9DD01_:R<0S59608aBAP33U8800P37WH@01@2TOE`0OUPa07iH<@1c
BAl0MdXP0080NDXP00@0OTdU08E?:`25Cb/0QDl]0P24Cbd01@1hAR40P50X091U>02@ICP0XWe90080
ZHYA00D0ZY1C0:B@D`2TT5<0XiAI0:JKH`020:6EH`0409f@H`2IRUl0VHYO09j=HP80WX]Q00D0WXQO
0:::I02JP5d0VX1M08]aD00207QM@00506I<<`17;QP0AbhH03DP3@0f9A<00P1@@300101jK5l0Z9^B
0:RKTP3CbL020>oVh@l00?l00P3Zj^P01@1dMG00B4M204Q7@P0b<B`09RDQ0080;b/X00@0<Rh[030/
:@0`;2T0<B`Y0P0i=C801@0i=S40=c@_038b:P0b<RX0;2`T0080;bhY00@0CDa8092@SP2@T8h0e=CB
:000o`0?ooooo`003Oooool;003o0080^YBA00@0LS8b08l`=02?<3@0Y34h0P2f>T801@32@4P0]3<h
0;Tn@`2i?T<0/DA90080V3`o00D0hIZN0>6PY03QX:@0SdM:0:ILG@02095;B`0409=FE@3ob/X0ol[:
0<jFU`80`H6200D0ei:E0=N@UP3YW:@0jIbT0<icO0020<YUK@050;]>E02eA4P0]DA80;e;B`2hATD0
0P31Cdh01035FEL0c6QX0<aXJ039Jf/20<I^K0050:iPGP3NXjD0omWK0?oIf`3obL`00P2mOGh01@2/
HV<0XEYH0:5JF03IWi/0i[Na0080f[F_00@0j<W60<2RX030XZ00jlg=0P2iUiP01@3T`<@0e:fb0=2V
ZP3@YZX0m<760080lKg100D0oLc?0>fo`@3]_l40omSI0>2h^@02085HG0040=nf_P3P]/00h;K00:=i
Q@80m/cJ00D0h[C10=bW]`3LWjl0g9n_09UBI00207ha@@0507/]>P1n;SL0ORhg07TZ;`1k;2l00P2A
@D@01023<CD0WD]=09e;C@2UD5<20:YFEP050:9DD01_:R<0S59608aBAP33U8800P37WH@01@2TOE`0
OUPa07iH<@1cBAl0MdXP0080NDXP00@0OTdU08E?:`25Cb/0QDl]0P24Cbd01@1hAR40P50X091U>02@
ICP0XWe90080ZHYA00D0ZY1C0:B@D`2TT5<0XiAI0:JKH`020:6EH`0409f@H`2IRUl0VHYO09j=HP80
WX]Q00D0WXQO0:::I02JP5d0VX1M08]aD00207QM@00506I<<`17;QP0AbhH03DP3@0f9A<00P1@@300
101jK5l0Z9^B0:RKTP3CbL020>oVh@l00?l00P3Zj^P01@1dMG00B4M204Q7@P0b<B`09RDQ0080;b/X
00@0<Rh[030/:@0`;2T0<B`Y0P0i=C801@0i=S40=c@_038b:P0b<RX0;2`T0080;bhY00@0CDa8092@
SP2@T8h0e=CB:000o`0?ooooo`003Oooool:003o00040?WWi@2?HUl0Sf9O07P^;@80V3<g00D0/CY0
0;m0A`2o@4L0`3Y30;`f?`020<52B@040;M9C029<C00RC4`0>nc/P80lLC100D0ZgYf07e:AP1Q<R`0
HC8/0<NLU@020?oMe`050>c9``1lD4d0O51=0712@P3N/K@00P3odmT0103ER980i8NA0>B7T@3bRY42
0>n2Q@050>9fMP3BI6<0aUQG0<IHE`2lCTd00P2mD5<01@2oEEL0b61Q0<QPH@2]CDh0Td530080j:2S
00@0om3D0?bh^@3l^;T0dgmo0P36KV`01@2bHeh0eiB<0?k;a`3nblL0omWC0080`ibG00D0dZZX0>Fm
_P3U_Kh0]8Z>0>Zma0020<:;T@040=V>U@3TSiH0i8nF0>ZEVP80fHN900D0chF40>j]Z`3OYJ@0gjFT
0<2<SP020?_:d0050;B5S@36U9l0aYBO0?K2cP2nR9D00P3IXJ`0103VZ[H0YfUd0:MYM01b<c`20:=R
JP050:]YK@2CC580Nbhd07/^=023<SP00P2==S`01@2B=c`0Sc0d08l`=02@=SH0R3Ld0080L2`S00@0
TUe=0=2VSP3@YXh0^iQh0P2QPEP01@2>Kd00QVDb07aH9P1lF2H0O5@S0080MTLM00D0MD4L089::@22
BRT0QDX/0896:P020897:@0407i8902<GC<0S5dc09ihA`80ZXmJ00D0Xi9L0:nUL02SWFd0Xie]09FB
I`0209ZFL00509bFLP2LU6l0W9A_09ZAJP2LSVL00P2LSF@0102MRf<0X8eU0:2=I@2OS6@209AnE`05
081YA`1VCbl0D3TJ050i6P15;A400P0h7`T01@0k9180F48d05Q2=01hIUX0ZIZC0080d/O100<0k^OQ
0?cim03lnO@02000o`0208V:Q@0501TJ500M71L07A`G02<P6`0X9B000P0k=S80100n>CH0>SDb03Xe
<P0o=c@304Lo?00404Dm>P10>cD0@3/e03`g<@80>cPa00D0<BhY01dL5`0M71L0<C0[08j?RP020?Ce
l2D00?l03oooool000gooooo2P00o`00103La<80Md0m07M0?@24<c020:4g>`050;LnA@31A4`0`DA<
0;/lA@2o@4T00P2mAT`0102dCE00M2DQ07@U8@3BX9T20?_Gb`050?kIb@2lUhD0Yh9_0:N2K`3cdk`0
0P2mXH/01@3df<80`:6=0<2QS@2kVh`0mmK?0080omWH00@0`W^30:Y?F02ZCeP0bf1X0P3HIF`01@3U
LWD0kgao0?F1PP3ePH80lWio0080iW9e00D0f6AW0<MDE`37E5L0^dm?0:8n@00209a4@`040=J7RP3^
WYl0kYjO0<e]KP80dFe[00D0egQd0=1mM`3MVY@0gIZD0?o7``020=ZUX@05099OG03R/[80h[:b0=f_
/@3hald00P3[[[H0102kI6d0aUiW0<INI`35FV020;iEF@050:94A03:M7<0mZZZ0?JZZP3SWj000P3U
YjX01@3XZk00W5eU09aMI@3VYjl0`HB<0080RTmE00@0ijZa0<J9T036RI00ZF]`0P3KWJ801@3MWj80
dY6E0<AoQ034Oh@0Sd9:0080QBhf00D0T3<k090/=02@;3@0T30d08le=@0207//9`0406l_9@37Uh<0
aiN30=jiW080^Iad00D0YXYJ09EjA@1kG2H0Ne`V091Z>@0209MX?005091J=025B2/0QDP[080l9@29
@2l00P2>AC@01021?BP0O3lS07`o8`1hA1l2091Y?P050:::FP2ZW6/0WIUZ09fIJP1XJCl00P1SID00
1@1jNeT0RXYX08Z:J02HUG80ViEa0080W9A]00@0XIE]09jAI`2NTFL0VHYO0P2MS6401@2NR5l0TW]B
09=gD02CMe00QfU50080M5<d00D0HD8V05@f7P1D=Qh0>b0;02`E1@0203XW6@0405A4=`1fJUh0MVYN
0:VPU`80d<c300D0kncU003o0000o`000?l00;Jg/P0202X[9@0501/J5@0^:bH0;R/V02LT7`0i=300
0P15@3`0100l=380>C4^03Ta;P0l=34203/c<00504i4@P1=A3l0>c8]03/b;@0m=2d00P13?3H01@13
?3@0=34X03@a:00L71808B4I0080UiRB9@00o`0?ooooo`003Oooool:003o00040=c4`P1g@3d0Md0m
08@c<080XCLk00D0]ci50<54C031A4`0^ca50;m0B@020;e6C0040;A=D01d9B40M2DQ0=:PV@80nmO;
00D0o]W90;bGQ@2WPVl0Yh9_0??C_0020;fQR`050?CH`P30XHd0`:6=0;^KS03ge/l00P3ofMP01032
Nh<0ZTmH0:Y?F03;H6P20=QUK0050>EbM@3_O7l0mH620?F1PP3bOWl00P3VLWD01@3HI6L0aeAG0<MD
E`2kCdl0XSi00080W4A300@0eXN:0>jNW`3^WYl0cFe^0P3AKF/01@3GN7@0d7eg0=fJU03MVY@0olO3
0080fZFQ00D0TUmL0>:b/P3R/[80gJna0?S7c@020>^^]P040;]TK@36GVL0aUiW0<EJH080_UEI00D0
XTA40<YdL`3fZZX0mZZZ0>>OX0020>FWZP050>R[/02LGFD0W5eU0>JW[`31Q8`00P2:CeD0103WZ[40
aXV@0<J9T02YJg020=^MXP050=fOXP3BTID0a7n40<AoQ02?@TX00P25;SH01@2@<c/0T2`d090/=02@
<3@0ScDe0080Nb`W00@0KblU0<NGP`37Uh<0g[VL0P2iW7@01@2VRUX0UGY507]L9P1kG2H0T6Xi0080
UfPl00D0T5Xd08E8:`25B2/0P3`U08U0;`0208i5=004084m:01l?b<0O3lS07Q47`80T6Tn00D0XXYJ
0:ZLJ`2MVFX0WIUZ06QY?`0206=U@00507YkF@2:RVP0RXYX09RELP2KUG400P2LU6d0102QUFd0WY5W
09jAI`2IRUl209f<H@0509j8G`2BNe80TgM@09=gD027JDD00P1dDc@01@1Q@RH0E3HN05@f7P0k80/0
;1D50080>RLI00@0E4@g07IZGP1fJUh0ZJ2G0P3@c<<01@3_k>D00?l0003o0000o`00][Nb0080:R/U
00D06aXE02h[9P0^:bH09b@O03Td<00204E0?00403`d<P0i<Bh0>C4^03`d<@80>c<`00D0CTA204e4
?`0k<Rd0>c8]03dd;@0204<l=P0504<l=00d<BP0=34X01`L4P0Q8AT00P2GV98U003o00oooooo000=
ooooo`X00?l000@0]IJC07Ti=`1i>CL0TCLf0P2Y?3l01@2h@DL0^D980;U2B02b?dH0XcHl0080UC8g
00@0VDE505/H4P1K6180aIV<0P3@[IL01@2lVG/0klbV0?_I[03kfJ`0d;210080[XiM00D0d[:10?cM
/@3lgK40k<jX0;RHO`020?_=`0040>>MW@2]D5P0[E1H0<]EH@80d4iJ00D0c4UA0=EBF03DDeP0e5=H
0>5SI`020>iaM@050?9gNP3cO7h0lgan0>]iN@3QLg800P32FUT0102^C4/0`EeM0<5MG@2fC4h20<AH
F0050;Y@D02fE540/UeJ0;9MFP3:O7X00P3>QhD01@2hMgD0[g=b0:mcLP3[]KD0omGH0080olK<00@0
ag1i0<UOJ@39GfT0df9X0P3@Gf<01@36G5h0gg]m0=eoP03MOh00b6i`0080]f5T00D0hXfB0:IAEP2V
DEH0[E]Q0>^PY@020;Q`M0040;ifN@3^YZT0kZJY0:MLH080gIFH00D0di6B07do@03@TYL0d9:G0<f7
S`0208Xi@P050:mDG@2aCEL0/DeG098]<`2>:bh00P29;bl0101_91l0QDXl08E:?03@Xh`20<fZRP05
0:n?IP2[S5d0NeTY07]I:@1N<`H00P1iAAd01@2=DBl0Xee30:=M@`2EB3@0OB/O0080RcL]00@0RcT^
08Lj:P27>RX0O3PS0P1f?b401@20FS<0W8IG0:JKK@2VVfd0ShiP0080D5D]00D0Be<^05EJ>P1EFSX0
GV5406a[C`02085lG`0409>:J`2ISVh0VHi^09fCL080XiIc00D0U8EN09AnE`2JOUH0VWiF08IV?`02
07aJ=00508AQ>`23HCh0Pf4n085P?`1aDSD00P1N@2H01019;aH0>28:03PR2P0a7`T203/^6`0505A=
?@1kMf`0XYnH0::OV019B4<00P0O7aL01@0U9Ad0:RLR02XW8P0/9b<0AD0j0080@3/e00@0=Rh[03L_
;00g;b`0>S0^0P0c:RD01@1DBDD0CT<o03P]9`0h;BL0>c4X0080ACPb00D0@SP_04Q1=`18@CL0?CT^
02LT6`02038b:P030;2a[000o`000?l002800?l03oooool000gooooo2@00o`001@3ij^L0S6AR07/d
<P1k=380V3Hg0080]TE900D0]3e30:dl@02]?400Yci20;QNH0020:QJFP040:QSGP25CD00QDe00=N]
U@80ek>A00D0aj5b0=J_MP3E[fh0eJm^0<JPF@020>_5O0050<bWH03E]g40eKMa0<R[K`2YRU/00P3U
_9h0103i^k00Z5AD0:QDE031De`20<iBG@050=5BG@3@CUP0dDeH0=5=F03>Be<00P3BCeL01@3DDeP0
eEMK0=EGF`3OI6H0jG5b0080kWYj00@0kWim0?63PP3aPh80jWin0P3LLW801@3;IfD0`F=Q0:iJF02^
FUP0XeUF0080XemL00D0[G1]0;1dL`2`M7<0XfQZ0>6Z[@020?o8c0040=j3S03:G6D0bUaU0<iIH@80
d5]Q00D0bE]N0<]SI039JFX0bFUZ0;]OH0020;]RI0050;YTI`2fGF40]UeQ0:A;C`2VE5P00P3APH@0
103JR8X0iYBF0>JDUP2oKFl209E7A`050=^GUP2RIF@0XFIZ0:5VJP3d]Kd00P2PD5/01@2J@4X0XSa7
0:8lA`2@9bh0Ubhe0080TB``00@0Qbd]06TN601Y7QP0TUU80P3=XHP01@2oVgT0[8]R0:F2F02UPUP0
JChD0080IS0:00D0O3/K08Tm9@29?BD0RSLW07lU7@0208d`:`0408db;@2==2h0SC@^08Hg:P80P3`W
00D0KCXK06Q57@2@Ne00T7]@0:RQL`0208>4FP0504Q>:012AbL0@TLW06MZC`1mNF000P1[Hd`0101[
GdL0L616071PAP1fIdX208IgEP0508AdD02JQel0U7]B09AkDP21I3X00P1oH3@01@1gER/0Le8W07=B
9`25I3/0ME<]0080LE4[00@0N5Pb07AH<`1dF3<0HDXX0P1C@R@01@0g:a<08a`:01TB200I4PP071TB
008081dF00D09B8M02HQ7@0V8Ad09b8N04Y5?`0203Td;P04030X9@0_9b@0;bLT02`U7`80<bXU00D0
C4<n04Ll>00_91h0;b@N03L/9P02044d;P0503dc:P13>S40@cXa04E1=P0n>Rl00P0T91X00`0k?3H0
`<2n0<30_P0R003o00oooooo000=ooooo`T00?l000D0nN[W08aTHP1k=380Nc@b09Pf=`020;I5B@05
0;@m@`2]?400[Ca00:Ln@P2hGV000P2XFUX0102XHeh0QDe008E=@03G[ID20=NcT@050<NQLP3F[gH0
eJm^0=F_KP36X5T00P3[aG`01@3<Yf00eKMa0=FgL@38Zfl0ZHYK0080iKbN00@0nK^`0:QDE02XE5@0
`E=L0P3>DUd01@3ADUd0d4iH0=5=F03ACEP0cT]C0080dTmG00D0e5=H0=EGF`3EEe/0gfAV0>UaLP02
0>ijNP040>inO@3aPh80lH>20>YnOP80g79b00D0bfMU0<5SH@2^FUP0[UYH0:=IEP020:=OG0050:e`
K@2`M7<0/7Ac0:=XJP3QZZd00P3ob<`0103NPh`0bUaU0<YLI@3>FF420=1KH@050<UKGP3;Hf@0bFUZ
0<UYJP2kGf000P2kHV@01@2jI6L0]UeQ0;IMH@2TBdl0YUAH0080dH6400@0fXR:0>JDUP3VU9H0_fe_
0P2EAdL01@3KUiH0XVET0:5VJP2QIVX0m;Fm0080X51K00D0VT1:0:8lA`2R?4L0T2L^09L^=@02094/
<00408L];@1Y7QP0JAhH099IB080cJ6800D0_i]i0:b;HP2UPUP0YH9H06Tn500206H`2P0507`k6`29
?BD0RCdU08Xg9`1o9Ad00P2=<2/0102=<Rd0SC@^08dd;P26=bX2080l9`0506dj6`1XAAd0T7]@091k
D02XXG<00P23Q5X01@18CRP0@TLW04979`1WJTl0OGUP0080Jf=<00@0Jem7071PAP1`H4H0MVM:0P26
MeH01@24M500VXMO09AkDP2DNe80PF@j0080Of0d00D0MeH[07=B9`1cDRL0QF@k07EC;@02075A:`04
07QH<P1dF3<0M5Pc065::080Dd8T00D0=b/C02<L2P0I4PP06A8801`I4P02020M5P0502DR7@0V8Ad0
9R4M02LR7P1:ACl00P0i=2h0100`:2D0;bLT02lW900/9Al203<Z9@0504a3?P17?3P0;b@N02lT7P0g
;2H00P11=2h01@0m<bX0@cXa04<j<@15@CH0?SX_008092@J00<0>c`f0<30_P30`;h08P00o`0?oooo
o`003Oooool9003o00050=[5`P1gAdD0ORh]07h^;@2V?D400P2h@DL01@2e?4<0YSDi0:He>@2I>CX0
kJ>P0080olc400@0m;na0>blY@3/_:D0m<RU0P34VVP01@3DZ6T0kKmd0>BdH03T]600gZaC0080hKAG
00D0l/Y[0;fL?`2mW3l0gKi[0<^^J0020<VXL`040?oF^P2TIUT0Y6II08`h=P80Wci500D0ZD5<0;A4
DP35BeP0aD]H0=1=F`020=E=F@050=E<E03FCE@0eTeD0=9;D@3;B4d00P3@DUD0103>F5P0cf5P0<mQ
H03?JfT20<Q_J`050;Y[I02mNW80]Wef0;ImMP2aPW`00P2_QX801@2jSX/0b9JG0<RFU`2bMg/0YF=W
0080ehJ<00@0`UeU0<ACF@34DeT0aTmE0P31C5801@2^A4H0^UaL0<akN03<NgP0^G9^0080]G5`00D0
/6a]0;=XK02cJ6`0]fQ]0;=NH`020:QAE`040;eRI`2aEeT0/EMI0:mIFP80P30a00D0RD=30;eoP03D
VIl0e9VO0?o1b@020:QLJ00508L_>`2Q>D@0XCU409d^=`2O;CL00P2H:C00102D:bl0QBXW08DZ9`1Z
8AP20:E/F`050=Z^U@2dT6h0[8US0:b9H`2NM4`00P1/>1<01@1g=QP0RC/U08Tk9@2:<R@0SRlY0080
Sbd/00@0Tc4`094b<02A<S00SS@/0P28>B`01@1k>B<0IS<D06A2701T@Q`0SGY?0080[:Eg00D0Oh1D
04106P10@1X0De0a0:6GOP0209>1J`0407YOC026JU@0QVYD07ML@@80L5Lh00D0H4XU07AQ=`1lIc`0
O6Ll07eX>`02089/?@0507eU=`21IST0PFHi09=gB01iFR`00P1`DB<0101hFB/0OV8c07iR<`1PBQ/2
06EB:00507AUA01GCC@08AT<024I300K50`01@0W8Qh01@0R6QL0@chh03Td;P0i=2h081/G00808A`H
00D091lI03H_:@0f;bT0>c<`03/a;`02034X8`0402hU800c:2@0<bPT03P_:080>c@/00D0>SH]04E1
>00X:200:2PP01`O5P0205]MF0030?;bl000o`000?l001l00?l03oooool000gooooo2@00o`001@2a
Ti40L3Pg08L^<027;S00[3m40080^cm700D0]STo0;E2A@2e@TD0TS0_0919@`020?[4^0040=FVTP2l
TG40_95a0=^_P080bieQ00D0ikM_0=j/E`3LZT/0g:Y;0<ZI<P020;b@9@050=bcA`3;ZCd0bjTm0=^k
EP3SaFd00P2eUdl0103ofZT0k/2O0>k0W`3EVXP20<^6O`050;]/L@2jGV/0aUMW0<IGI`38BUP00P3C
BeL01@3EB540e4U@0=A9D03DCE<0cdiB0080b55C00@0b5aL0;EGE@2eEeD0YEA@0P2JEdl01@2YLfT0
`9B90;VGSP2iUhh0^ijF0080/iZE00D0ZXf90:j8Q`2^R8L0_H^>0;akO`020:eKH@040<9MH`31D5H0
`E1F0<9;D@80`4a?00D0[dE709a1@02dJF<0]6US0;IjLP020:ehM0050:QgL`2[Lg@0Zg=d0:maM02m
MWX00P2kL7@0102iJ6h0[UiQ0:iNH@2YGEl207Tc=@0509iRHP2XL7<0/7Ek0;1eN`3n_LD00P3KSiT0
1@2SBED0WcE109le@@2Y=D00Xb/e0080Y2`e00@0WBX_09P`<@2H<340NR8N0P1c;B<01@31RGP0fjnF
0;N@K`2gT6l0[hMS0080YG=@00D0Kc8C07P]5P1h;AH0S3TY090c:`0208l`;00408h_;@2><2h0SS0^
094h<080QcDY00D0PS/W07Dm8P1H<0d0F30=06587`0209b>G@050:^UL`1`KD00L6e003`h4P1^HdL0
0P2XTgh0101gF4H0ID8^06E2;P21GDD207aK?00507AF<P1_ERd0ITlS06I?8`1]F2T00P1bGBh01@1f
H2l0OVPg07iX=`2:Ld40TgU60080SW<n00@0Qf`g08I]=`26KCL0HDXF0P1OBQ/01@20LDP0KV=502LN
3@0W7Pd06A070080;RLQ00D0:bHR02HN6`0V7Q/09alL03H_:@0204E0>P0402lZ9P0Q71H08A`F02DP
6P80;bXT00D0?CH`03/d;P0d;2T0=2`Y02@M5`0202`S7P0502dT7`0i<RX0>C8Z03Te;019ASl00P0c
<b/0100N8AP0@dHo04=6?`3UiN<Q003o00oooooo000=ooooo`L00?l00P3gk>X01@2?JFP0MSHf09<d
>02C=3P0/Sm60080/c@k00D0^3Ll0;i3AP2n@dH0/DM7080]:@020:a^H@040?;4[03:Xg`0bZ=l0>Jk
QP80k[il00D0kl1b0;b==@2eRBH0]HTV0<FL<0020=:/?@050<FR;P2cT1`0/i0L0;JE903]c6D00P39
Ydh0103F]6X0i<240>C0Q03`aY`20?;6[@050?k<a@3obm80l8jK0?2>V`30AeH00P3CC5X01@3DB540
e4]B0=A;DP3>CE40b5EH0080^eUH00@0YUMC09EFC`2EETl0Y7=/0P2jU8/01@2kWI<0[iN=0:bHS`2/
V8l0/j2I0080YIB<00D0WHZ40:68Q02QR8@0Yh>30<:>TP020<=lPP040;UNI@31EU`0`EIL0;e8CP80
`DY>00D0`U5C09`j=`2DAd40U4M10:Y^IP020:5dKP0509MdKP2HMW@0V7Id09]gM`2OMgP00P2VNW/0
102_OH00[7Yk0:ajN`2TLWD209ETI`050?77b@3dal`0TeMO09=GG`2hLWX00P3cXj`01@3DNH80XcDn
0:<e?P2`>440ZC0g0080ZBhc00@0Ybhc09l^<02O;S00Tbd[0P1j8Qh01@27@cP0gjNF0=BXS`3DZ8l0
/XUY0080/HEP00D0X6a706X[301Z:``0OS<L08Tf9P0208/c:@0408Tb:@22;R@0PRhT07d_8P80Mc0L
00D0MSHK07E08@1U?1h0IC`N048T000208]jAP050:JLH@2[Z740ZjQa05eK:`0m=1<00P22LUT0102`
UH80IT<_06I3;`1gCSP208aPA@05089J=`1eDRX0HT<G06935`1K@1400P1WCal01@1B?0/0ET8@05I2
401SCa`0L5/V0080Mf8[00@0N68Y08=]=023KC@0O6L^0P1gHc001@21LdH0Kf90024I1P0Q6@H08AT>
0080;bPN00D0;bPP02dT7`0]91l09QlI02XS7@0203/d;P0404Dn>00c;2H0<b`V02LP6P80;RLO00D0
@3Ta04Ho=`0g;RT0=bhY02HM5P0202PO600502TP6@0f;bL0=RlW03Xf;@18ACh00P0c<b/0100T9Al0
?3dh03`m>03IfMLQ003o00oooooo000=ooooo`L00?l00P3gk>X01@2?JFP0MSHf09<d>02C=3P0/Sm6
0080/c@k00D0^3Ll0;i3AP2n@dH0/DM7080]:@020:a^H@040?;4[03:Xg`0bZ=l0>JkQP80k[il00D0
kl1b0;b==@2eRBH0]HTV0<FL<0020=:/?@050<FR;P2cT1`0/i0L0;JE903]c6D00P39Ydh0103F]6X0
i<240>C0Q03`aY`20?;6[@050?k<a@3obm80l8jK0?2>V`30AeH00P3CC5X01@3DB540e4]B0=A;DP3>
CE40b5EH0080^eUH00@0YUMC09EFC`2EETl0Y7=/0P2jU8/01@2kWI<0[iN=0:bHS`2/V8l0/j2I0080
YIB<00D0WHZ40:68Q02QR8@0Yh>30<:>TP020<=lPP040;UNI@31EU`0`EIL0;e8CP80`DY>00D0`U5C
09`j=`2DAd40U4M10:Y^IP020:5dKP0509MdKP2HMW@0V7Id09]gM`2OMgP00P2VNW/0102_OH00[7Yk
0:ajN`2TLWD209ETI`050?77b@3dal`0TeMO09=GG`2hLWX00P3cXj`01@3DNH80XcDn0:<e?P2`>440
ZC0g0080ZBhc00@0Ybhc09l^<02O;S00Tbd[0P1j8Qh01@27@cP0gjNF0=BXS`3DZ8l0/XUY0080/HEP
00D0X6a706X[301Z:``0OS<L08Tf9P0208/c:@0408Tb:@22;R@0PRhT07d_8P80Mc0L00D0MSHK07E0
8@1U?1h0IC`N048T000208]jAP050:JLH@2[Z740ZjQa05eK:`0m=1<00P22LUT0102`UH80IT<_06I3
;`1gCSP208aPA@05089J=`1eDRX0HT<G06935`1K@1400P1WCal01@1B?0/0ET8@05I2401SCa`0L5/V
0080Mf8[00@0N68Y08=]=023KC@0O6L^0P1gHc001@21LdH0Kf90024I1P0Q6@H08AT>0080;bPN00D0
;bPP02dT7`0]91l09QlI02XS7@0203/d;P0404Dn>00c;2H0<b`V02LP6P80;RLO00D0@3Ta04Ho=`0g
;RT0=bhY02HM5P0202PO600502TP6@0f;bL0=RlW03Xf;@18ACh00P0c<b/0100T9Al0?3dh03`m>03I
fMLQ003o00oooooo000=ooooo`L00?l00P3KbLL01@1cADD0OCDf0:8oA02R?d@0/3]30080]3Dl00D0
^C/o0;]7B02kAdP0[4I4080a:P0206hc8`040>^oXP3W`I@0il6D0<:FF@80i[Q]00D0/88]0;N;;03[
`UT0jl9I0?7;G0020?7>FP050??@F03`c5@0l<aD0=6/=`2lV2X00P3K^ED0103@/EL0gL1d0=g0M03<
[gD20:F5GP050?OB`P3oaLL0_V5/0;iQK034CUh00P3<BEL01@3=BU80bdiB0<]>DP35E5H0/UAD0080
Udi800@0Uf1K0;2:P@2`RX40_Z6I0P2YUH`01@2NSHD0Vhf40:6DS02QU8`0YIR@0080ZijF00D0[Z6I
0:^IU@2[VID0YH^:0;28R@020<bAU@040<9cN@2lFf80_5]R0<IGGP80`DaB00D0_DU<0;I<C02C?ST0
Tchi09YJD@020:AeK`0509EgK`2<MFl0S7E_08ejMP2<M7@00P2@MWL0102ENGP0VG]k09UkN`2FMWL2
09EgN@050<nb]P3gdmL0_HR@0;f8T02SH6T00P2hJ7401@2kH6L0]daD0;M<E02c@4L0[cY00080[3Lm
00@0ZCHk0:@f>@2T=ST0WCDf0P2E=cD01@1a8Qd0ZFUO0>RhY03X^:@0cJB80080[hMS00D0^XiW09MS
?02GHc`0K2d<088h7`0208Xi9P0408Lf9@1d9A@0M2DD07X_7080RdL`00D0NCTM070i6P1M<140GC0A
04h[1@0209UnA`0509n=C`2]YFL0[JEW0:nZL`1CCR@00P18?Al0102DOVL0[hik0:n>N`1Q=R<208QH
@P0509m]DP2EIdH0OeD_07mE;`1bCB<00P25HSP01@1L?A40D3@5050d1@1M@a80GD<@0080HdXD00@0
GD@<05Y1201J@@P0L5PL0P29LcX01@1fI380HE</028H000R60008a`:0080:R@D00D0<B/O03<Z8@0c
:R40;RDN02LN5`0202`S7P0403Xa;019@3/0BD0k040i<@80<2TQ00D0>C8Z03@]9@0_9Ql0;bHO02/R
6`0202XQ6P0502/T700h=2/0>3@[03ll=@0n?SH00P0];2L0100O7QT0=3D`03@e<03?c/`Q003o00oo
oooo000=ooooo`L00?l00P2oYjL01@1/=SH0R3Pi0:Hm@P2V?D80/CY00080/CHk00D0]d=40:<o?`2S
?cl0PC4Z0:=WG0020=Z[U`040>RmVP39XFh0bJ5^0=R]J@80h[ET00D0XgHI0>^nE`3cbEd0llUM0??9
F@020>FnA`050=2Y<03edEL0mM5G0?SCGP3C[D000P2WQ1h0103I^e/0l]J30?;FP`2_U5420=:cQ@05
0?oF``32P840^EEQ0;UEH@3?EVL00P39BeT01@35C5D0^U1B0;Y@DP2_EE@0TTm90080X6mX00@0b:NP
0;bUW@2lYId0XY690P2JRh@01@2HRh<0VHn609^@RP2KT8X0VXn90080WI:<00D0Y9VC0:nQWP2_XIh0
/j2L0:Z<S0020;^>T@040=6@UP30JW<0`6Yc0<ALI@80b5AM00D0_TM=0;a;C@2ZB4L0ZTQ708Hg<P02
0:A[I0050:=lM@2AN740TGQa08YiLP29MgD00P2:NWX308UjM`0508]iM`29MGH0RGEf08McM02TQh/0
0P2/PHP0102iOHL0bWj80<YnR030JG420;=?E`050;17C02^Ad/0/Da@0;5<D02`CE800P2V@dP01@2R
@T@0XDE60:55AP29=C<0KbXS0080ej6E00@0jl:/0<2NN`30WW/0]95W0P2lTV801@2BGc80JR/8080i
6`20>A/0RchR0080ORhC00D0NB/D09U?=P2ICcH0YF1309eN?@0209=K>00409UZ@02YPT/0ZH9;0:65
A080Whe=00D0]Za_08b9EP18@a/0B4<K05=5:P020:V?OP0509E^G`2:FD/0RUU;09QPC`2?ED400P2J
HDH0102MITL0YW5A0:IaD@2=GCT207mB:`0507mE:`1/AaX0JDLG06U75`1L>`P00P1^CAL01@26IbL0
QVPX08IX:01WCQD0He4Q0080<B@200@08Q/102DN2`0U7P/0<2XJ0P0c:b001@0g;RD0=2/R02dT7@0]
91d0:R4J0080;BHN00D0@cXc04U0>@19@3T0@CPc03T`:`02038[9@0403</9P0h<B/0>34[03`g<@80
@C`f00D0?S/f030_:P0X9b80:2LR01dL5`0202`[9P030<O3`000o`000?l001l00?l03oooool000go
oooo1`00o`020;nWY`0506`f=P28>3T0YSe20:Hm@P2a>T000P2a=S/01@2g@d@0Xclo0:<o?`21<BX0
XfML0080fZ^G00@0j;fJ0<VQKP39XFh0f:eY0P3R]F@01@2SMQT0jkiG0??9G@3cbEd0llUI0080iKi7
00D0d:T`0?GAE`3edEL0n==N0=>]@0020:N47P040=VkF`3beX<0l]J30:nDD@80d[>500D0omK30<:0
P@2iEF40^EEQ0<mFI`020<U;F@050<E<E@2jD580^U1B0:mEE02BCdT00P2PKfP01038Yj00_:FM0;bU
W@2RTHT209Z;Q00509R;P`2IShH0Vi2:09^@RP2JShT00P2MTX`01@2TVI<0[j6N0:nQWP2cX9`0ZXb<
0080^hjA00@0dI2F0<1ZL`30JW<0a5aU0P38E5d01@2nAdd0_4]=0:Y8A`2ZB4L0QSLb0080Y6]T00D0
Xgae095hL@2AN740RWUb08UgM@0208YjNP<0RGYg00D0RgUg08UeMP29MGH0Qg=d0:B7R`020:b1R004
0;UmQ`3:OXP0bWj80<1YL@80/dmG00D0/4M<0:i7B`2aC500/Da@0;1=DP020:I3B0050:92A02QADH0
XDE608Te<`1_:R<00P3GXID0103[`Z`0`9ik0<2NN`2dTFL20;bBHP05099O<P1Z:`P0P3TK080i6`2;
?R800P1n;Q<01@1i:a@0VDlf09U?=P2UH4<0WEhm0080Te/h00@0VFY00:V2B`2YPT/0XHE40P2OSDd0
1@2f[6l0S8UF04Q36`18@a/0DdDZ0080ZHmn00D0UFiO08YIB`2:FD/0V61?08mE@@0209YQAP0409eV
A`2VLE40YW5A08eM>@80Oe8[00D0OeD[06a76P1YAaL0JDLG05`k200206i=5`0508IW9`26J2P0QVPX
06M>5@1SDB400P0a9080100R6`409Ah;02DN2`0`:QX203<[800503L^9@0d:b80;B@M02dT7@0Z8AX0
0P0]9Qh01@13>S<0BD0i04U0>@11>3<0>C0[0080<R/U00@0<b`V03Pa:`0h<B/0?3La0P11?3H01@0n
>cH0<2lZ02PW8P0X9b807A`G0080;2/V00<0al?0003o0000o`007`00o`0?ooooo`003Oooool7003o
0080Z8b;00D0LCLf08li?02[?T<0Zci30;@k@0020;Hk?P050:lk?02Q?c`0XCll0>:CS03oe/X00P3R
]9d0102cR6D0gK>10=fcP@3fbX/20<jPDP050;649`3W^U<0fJe40=V]A02bQaL00P3F[3H01@3Q^Cl0
gkLn0=ng?P3/aE00n=9U0080]I0X00@0eK=B0=foJ@3M_fT0Zi570P3nh:`01@3cbk40UUUD0:a?F@2/
CeT0aeQX0080`e1M00D0_eAL0:M?CP2WCdh0UU5<0:IeKP020;^JT@040<RdZ`2WVY40YiZA09^>QP80
V8f700D0Uhb609Z?R@2KTXd0Vi:=09V@R`0209V>R00509^@RP2KT8`0Vi2<0:JGU02aW9T00P2eTi@0
1039UY/0dHZB0=6:TP33Ig820<5FH0050;e9DP2iAT/0_E=E0;eCE@2I@3`00P2AC4L01@2SLV/0UgUa
09MiL@2@O7D0Rgag0080RWmk00@0Qgek08=iM`23NGL0PWMe0P26NWX01@23Lg@0SGAh09adO02LM7`0
Yg9j0080`gZ300D0/E]T0:=8C@2SB4d0Vd5309a7BP020;UZK@040;AXK02/H6@0[61T0:AEFP80We1C
00D0Ve5B06PY902JJV00VVYP0?WD`P020>33Y@050;RKL`2mW6L0_IaW0<FNI`1mCAd00P1U:P00101l
>@l0PCTC084i4`1n<a@207le600508@j7@20>AT0Q48P08A2802>Db/00P2FHBl01@2QMcd0W7i209an
@P2QSU<0/:M`0080OgQ:00@0?C8B05U7<@1IAc40[Xj10P2VO7001@2AGE00PDLi08]@?P2;D3h0O3lZ
0080PTPb00D0X6Q?0:M_E02WKe@0U69108eM>@02091T?@0408]R=P2;IS40RfHa09]h>080RV`T00D0
HdP108ai=`1iK3L0NF`g02LN000202@M000502PQ3P0a:QX0<BXJ03dc:@0o=B/00P12>2l0100f;BH0
;bHO02lV7`0X7aP2030W800403`c;P16?3X0@3Pe040h=@<0?STe00D0?cXf03Lc<00g<c00;2PU02HR
7`0202@P7@04020K5`0^9R<0;RHS09nHTP80l^_U00<0ooSe003o0000o`007000o`0?ooooo`003Ooo
ool6003o00050?oel`2CM780TgAb07Tl>`2G?T000P2]?T@0102c=S`0^STn0;Xi?P2n@T@20:0`;P05
0;YMEP3[XYT0oLFd0?g5]03W^Yd00P3F[8@01@3M[WX0dj9O0=>RG`2bQ2l0nLe^0080fZm900@0W703
0>RkAP3X^dH0h;@k0P2eR1401@3?Y3<0mLaR0<fW@P3=Yd80[XLX0080jLE_00D0bJUN0=NhO`3G^7l0
o=^j0>BdZ0020:=KG`040:9:EP2fEV40]UIQ0:eDFP80UU1>00D0ZWQa0;2>Q@2^UX`0[YJ<0;b[X@02
0;BWWP050:RKT`2QU8h0XIB>09fBS02LTHd00P2JSh/0102KT8`0VXn;09Z?R`2HSHT209V<QP0509f>
R@2UTi40]I^J0;FKVP32Vih00P3?V9h01@3;OhT0_V5[0;iQJ`2hCEL0_D]C0080`5=F00@0/U1?09A5
@@2DAD40VUeH0P2NMFl01@2GO7D0T7mh08b1N`2<PG/0Qgii0080RGmm00D0QWak08AhN024N7P0QgMj
08mfO00209Q`N@040:A_M`2hKgP0^6mh09m>E080W4Y<00D0RShn09aOG02ZMg@0ZWMd0:MgM`020:=e
M`050:IdM`2QKg00XFm`09i/K@25F5D00P1aC4H0103Wb[`0onG>0?oUcP3F_YX20;bPKP050<b^LP2d
TU<0MThA07I>4@1[>P800P1W;`001@1V:040KB/906d[2@1g<100OS<D0080O2lA00@0OC8B07/f3`1k
=Pl0MST=0P1a@Q@01@2ALCh0/IeX0;6UL`2aYG<0JEdg0080A3HI00D0K5Y6099fJ02BMVP0T6aN08aP
D`0208aLCP0407M3=@1f@C<0MT4c089:>`80SUI500D0RE0m08YC?P2BGd@0TUm408IH=002099Z>@05
0:9o?`2HNbd0V7/]09In902gY4P00P2o[eX0101`Hal0:1`002PL000U6`8202hS4@0503<Z6`0i;b<0
Bd4g04]1=`1>A3/00P14>c@01@0k<R/0:b8M02/R7@0[8Al0:AlN0080:b<Q00@09b8O02TS8`0Y8b<0
:bLV0P0U7al01@0R71`091hN02`T8P0/9280;28P0080<RDO00D0=bHO06]IC`1[FDl0]J>I0=_:`P02
0?OZi1/00?l03oooool000gooooo1P00o`001@3omO<0TgAb09=dLP1i?3/0Uci00080[Ci400@0/cHl
0;Xi?P2j>Ch0_T940P2P<2h01@2jGEH0jj:I0?g5]03maK@0ikZM0080eZb400D0gJij0=>RG`3CXUl0
/X@_0?W=KP020=Z_B@0409a`0`3X^dH0j;]60>2d>`80]HPA00D0cj@c0?G<HP3=Yd80cJM20:j7:002
0>W5K`050<VYGP3G^7l0ekQo0?cK^P3T]:P00P2SFel0102RBUH0]UIQ0;IFH@2]E5X209I@CP050:Yh
L@2`SXD0[YJ<0:jFS02lZj400P2dYih01@2XVi<0XIB>0:6DSP2MTX`0W96=0080VXn;00@0Vi2<09Z?
R`2JSh/0V8f90P2IS8H01@2MSXT0YI>A0;FKVP2eViX0`Y^N0080ciRN00D0bgn90;iQJ`2nHF/0^4eG
0;e;D`020<1CEP040;9@C`2DAD40U4E109YMF080WWE_00D0Ugae091oN02<PG/0S85k08MnN@0208Uo
O@0508IlN`24N7P0Q7Qh08MgNP2?MW`00P2HL7T0102TKgL0^6mh0;Q_N02OCU@209a:C00508Xn?P2L
Ge`0ZWMd0:YgM02WMgL00P2SMGL01@2VM7L0XFm`0:5_L02NK6d0QEQE0080LDa600@0ilZl0?oUcP3o
iLh0e[jJ0P2lX6h01@3<[W80]99C07I>4@1fCQ40JcX20080Ibl000D0IRP106d[2@1]:`T0Mc0@07hc
500207`_4@0407db4P1k=Pl0NcH?07Hi3@80LD8D00D0TG4n0;6MJ02aYG<0/JEc06UM=`0204@f6@05
06aJAP2BMVP0TWIX091/GP2<H5<00P2<G4h0101g@cD0MT4c07I1<`22BS/208iFA@0508U@?@2:Dch0
TUm4099OA026F3@00P2BJST01@2ROcl0V7/]09Qk;@2FOR@0]jA80080_jmJ00@0L6<O02PL000X7000
9A/20P0^8a401@0c:Q/0>BlS04]1=`1;@CL0CT@k0080A3/d00D0>c8[02/R7@0[8Qd0:b4O02TO7P02
02/S8@0402LR7`0Y8b<0:B<S02/W9P809AlO00D08Q`L02@N7P0/9280;2@R02`R8002038U7`0503LV
7`1[FDl0JeU?0;FSV@3Kb/800P3gj^@K003o00oooooo000=ooooo`H00?l000D0m>GR08IPG@26H5d0
Oc/j09ho@`020:hk@P040;4b>@2o>D00_cU00<4l?`80^3hm00D0XcPb08/g;@2fMfP0]WMX0>ViX`02
0?G<[0050<jRM@3P[gD0h:me0;B4>P3K[EL00P3mdG00103BYSd0jke=0>^mC@3?X2`20;J75@050>Vk
C03hcfD0aYlj0<JO>P2fSc800P3_bG@01@3/c8<0[XmH0:j?F033XX40om_>0080mkVl00@0YUeX0:EE
GP2UEEh0TDU=0P2QK6P01@2jUHd0Y8V00:2>Q02PSX@0Z9Z?0080_K2W00D0cL2h0;jaZ@2n/JT0Zj2J
0:2ES`0309jCS@<0WI:<0P2OTX`01@2PThd0WXn<0:B@S`2TT8l0[i>B0080`YVM00D0bhnG0<f1R`3=
PH/0^UmX0;I>E`020<AIG`040<=LG`2WCD`0Yde<08e3@080XFmX00D0X7ie09EnMP2>OgP0SWmh08Ml
N00208UoO@0508MmO027Ng/0Qg]k08IfN@2?M7/00P2HKgL0102^MGh0[6=Z0:aSJP2HBDh209E;C005
08E5@`2SLfl0UgA`09MdL02CMG<00P2DN7L01@2FN7X0UgUi09MiN@2HN7T0UGId0080OfIR00@0]YnG
0>cGaP3/elH0jmJk0P3=]hh01@3:/gl0b[9f0<FYJP35ZFX0]iEH0080YWe500D0U6@d07Q35`1h@aL0
Kc@8070_1@02070/1`0407H`301g<``0Mc<<07Xl4`80H2l600D0Hcd@09Z0C@2fYW80]ZIb0:RLK002
05mF;@0503hc5@1A@BP0DD4X075H@P1kG4L00P2;J5@0102HLUd0V6eJ09Q]FP2=H4d208UJB00508]J
B@29ET<0Odlh07m?>01N<A800P2@JSd01@2[RDT0X8@a0:24<@2VSbT0^ZHf0080a[A600@0a;IE07Y]
9`1jKBL0;b<00P0X7P001@0^90T0;RHC03/b8`0k<R<0AS`b0080DTPo00D0ETa304e4?@1=A3d0?S<_
03@Z:00202hV900402XR800V82009R0P02`V9P80:1lP00D0:B0Q02dS8P0e:bT0=B/Y03HX9@0202/L
5@0502PF301NB3/0GTPk08efJ029LV@00P2JQ7T0102eXY/0f/_40=[;a03ai^0G003o00oooooo000=
ooooo`H00?l000D0i<o<07I:A`1fBTL0Rcdm0:Ho@`020:de?P040;Db>P31>3l0`CPo0<8j?P80`T10
00D0_4I20:Q7?P26?2l0QS`_06/h9@020>2kX0050<VRN`3M/Wl0gK9o0<FEE@2`Oc800P3b`f/0103V
^5H0eJHl0=FV?03DYSL20<>E9P050>:fB@3fbf80/HXU0;6:9@3J/eH00P3B[ed01@2nWe`0eKF40=Fe
Q03Q_:80om;:0080ol[?00@0hYjY09EBF@2EDUT0SE9D0P2eSH/01@2URX<0W8Z009j@Q`2NT8L0VXf4
0080XiV@00D0^jjV0<Zm]@3:_KD0cl:j0<2cZ`020:jQV@040:BGS`2NU8/0WYB;0::GT@80WY6;0P2O
THh209n@S@040:6=S02_TY@0[i:D0;RAU080`hjD00D0a7f50;=NI@30G6@0`5aT0<5JGP020;EEEP05
09M4@02BDd`0TU=<0:MkLP2LOWH00P2DP7T0102<OgT0Rh1n08^0OP2:OWh208YlO00508agO02DMG/0
XG9j0:5bNP2gN8400P2LDEH01@2KC540Qd5308M1@`2;De80X7Ud0080Sg=_00@0S7Md08]gMP2;MgH0
S7Yj0P2<NWP01@2=NGP0SWYi08QfM028MW@0R7Ib0080WHb400D0YiF70:JDOP2VU7h0/Ymo0;n/PP02
0<ZfQ0040<jhO`3C^Gh0dkUn0=2bMP80aZIY00D0^YIH0:In@02?IB/0SfD[07E84@0206Dg0`0505hb
0@1N=@L0GSD704h/001M@a800P2OSUH0102`Y6P0Qgi308Mn@`1OFBL2055:7P05061B:`1QCbT0FD<J
05U36P1dFc<00P1jGC/01@21I4@0SFi?08e^C`2FMeX0TFmD0080TfmE00@0Q65109]jC@2KNTd0ZXa<
0P2SRC801@2YTB<0^jLZ0<Zi=@3:^CD0f<U80080d/MC00D0Vi4b04]2001;@P00:b<0030W2002038Z
5@0403L[6`0j;R00>RhP04@h;080CT@j00D0E4Lo04i3?@11=S80@CHb03ld<00203hd<P05040f=00g
;B/0=bd[03<Y9`0c:2@00P0e9b@0100e:2809aT@02LI400`7Q8207]XF@0509QnK`2<LF00SW5Q08ia
H@2DM6L00P2>L6D01@2IOG40[Y>:0:jCRP3B_[D0l^3L0080ooKb4@00o`0?ooooo`003Oooool6003o
00050=Nk]`1d@Ch0M44n09<o?`2X>d000P2/<3P0102k=Ch0aCa30<Dl@`34>Ch20<I0@@050;a0?P2f
BdD0X4i30:1>@`1R;Al00P3N^:<01@30Vgh0iK^C0>FkT`3O[gl0`8iA0080`i=900@0fZaF0>2bE03P
/U@0llIQ0P3baf401@3T^E<0`9Hd0;^D=`2kU3L0i<1/0080d:iV00D0a:E^0?oP^P3oh;X0klJd0;F4
P0020;=fO@040:QYLP29CU@0RDiD0:YiO080[i2=00D0VXN009^=Q02KSXH0Vhj609V?QP0209bBR@05
0:>FSP2/WiL0[9nG0;jaZ@3Aa;/00P3Ca[d0102m/:L0Zj6H0:^QV02UVi820:2CS@050:2BS`2NThl0
WY>?09jCS`2MSX/00P2NS8X01@2USHd0[hb@0:n<T035T9H0`Wb40080]EiV00@0]UIJ0;YEF@2jEET0
]5UH0P2BA4001@2LHET0YW]d0:23O@2PPgd0V8Eo0080T89o00D0SGmn091mO`2@OGl0TWUm09UdN`02
0:]cO0040;1]MP2AADT0TDE909U?D080OT1100D0UVIT09]iM`2<Mg80S7Mb08ekN@0208YlN`0508Ej
N028OG/0R7ek08EjN024NGL00P26N7L01021Lg80R7Yg08QjM`28NG@208YlL@0508inKP2@P6L0W8a[
09b<J`2]Vg<00P2lZWX01@37/h00dKb50=6lQ@3D_X@0dKUk0080cK=h00@0`ZE[0;NHH@2gV640Wh1:
0P27Ic@01@1ZC1P0@B/006ID5P1VE1H0[J=K0080]JiV00D0XZ1S071_>@1`KcT0K6Hf08AiC00206MF
:P0406aG:P1`FBl0L5T_05<l4P80I4dS00D0Ie0V06eD;01mI3`0OF@l08]_B002091d@P050:F:A@2S
RRh0XhX^0:VC702nZR<00P3B`Rl0103GbC@0fm4n0=_A?P3OeU<20<>lE00506YU500b;0009Ah002DN
000/8P000P0a9PX01@0e:Q@0>c0N03/`7P0n<R80@S@W0080?c4V00@0>bdT03d`9`0m<2L0>RdT0P0e
:1l01@0^8AP0<bHM03HX7@0f:1d09AP8008091@400D0@S4M07YXDP1jJ580WhUd09=hI@02095bH004
095]G@2IM6@0VGAT09]fIP80SVYL00D0QVII08icJ02QSH@0XHf40<fl]0020>gSfP030?oglP00o`00
0?l000/00?l03oooool000gooooo1P00o`001@3G^kL0M44n07A1?P2C?cl0Z3]00080[30h00@0^cDn
0<Dl@`35?4<0a3Tn0P36@4401@2l@3h0]T]50:1>@`2PCT<0HRdO0080g[RS00D0`9]n0>FkT`3U^i<0
gjmo0<2>D@020<>CB@040=Z/EP3P/U@0h;9D0??6H@80l/MQ00D0i;UC0<2F=02kU3L0^i@g0>C0K002
0=2^IP050<BUKP3oh;X0on2j0>o6]02eQ8000P2cMWd0102XJG80RDiD08U>E02ZNG`20:n@S@0509Z7
P02KSH@0Vhj609^>QP2IShH00P2LTXT01@2SUXh0[9nG0:bOU`2n/JT0dLBk0080dlJm00@0_K2W0:^Q
V02[XIP0YI^B0P2PThd01@2PTXl0WY>?09jCS`2NThl0WHj;0080WXb:00D0YHf=0:n<T02_S900aI2F
0<9lQ0020;ENIP040;IFFP2jEET0^UEI0;AIF080TTA000D0W65I0:IkM02PPgd0X8=m09R5O`020922
O`0508eoOP2@OGl0T7eo099iO@2IM7/00P2[Lg`0102`KGH0TDE90955B@2ICe0207i0@@0509IVI02K
NGL0S7Mb08agLP2=NgT00P2:O7/01@25NWP0R7ek08QmN`25NWP0Q7Ug0080QWQg00@0PG=b08QjM`28
NWL0R7Ud0P2:O7401@2>OVh0T81W09b<J`2LS6/0[I]c0080_:Yj00D0ak>00=6lQ@3A_8D0e;j40=6i
N`020<fcN0040<:UJ`2gV640]iQQ09n0BP80QfLd00D0JT`H044[001VE1H0IU@F0:fSF`020;F^IP05
0::PH`1`KcT0L6li06aV=P24ND`00P1WERX0101/EbX0L5T_071I;`1C?18206A=8`0506M@9P1]E2`0
OF@l07eT?02;KdP00P2@M4801@2URTD0XhX^0:>:;P2YTa`0_ZXS0080d/8_00@0elTd0=_A?P3KdCh0
gmIC0P33_5@01@1ZIA@0<R`002DN000U7P00;2800080<BH:00D0=BXD03/`7P0k<1h0?S8R048d9`02
03la9P0403/]900m<2L0?C0W03X]9080=BPO00D0;R4H03<V7@0f:1d0=RPM02DH200202@D1005048a
7@1jJ580NVQB09n9M02CN6D00P2ALV00102AKEd0VGAT09UdI02KMVH208iZG00508IVF@2>LfP0XHf4
0:6=Q03=_;@00P3]hmX00`3omo800?l0003o000;003o00oooooo000=ooooo`H00?l000D0`j:M0815
@@20AD40WD520:dl@0020:/^=P040<0j@`32>D00`SU00<Tn@`80a3ho00D0_d900;m?C@2@>C80T3Tb
08=:@@020>k6^P050:Z3LP3I[iL0fJnG0=JYS03N[XH00P3BXfl0103<W5`0aYI:0<JFBP2hRcP20<RO
A`050;28<@30VTL0j<9g0>S2M`3H]G<00P3V`hd01@2TQ5d0fkVP0=^iX03fc/@0SE]L0080SU1E00@0
XF1X09]TJP2KI6X0[XB60P2QR8@01@2LSHH0W8n709V>R02ISXP0VXn900<0Vi2:0P2OU8h01@2RUi40
[::I0;bbZ@2l/ZT0b;je0080c<:i00@0_K>Z0:VOUP2YWiH0WY>=0`2QUY00102KT8`0Wi6>09nASP2O
Shl20:B>T0050;JBUP32Si@0`gj30<=nP`2bGF@00P2dE5P01@2iEUT0ZDi=0:U>C@2HBTH0XFMS0080
[HAn00@0XhN309Z7P`2JQh<0TX200P2ANgh01@2HMgh0XGAk0;AeOP2dMGh0XEQO0080T4E900D0STY9
08I@CP26D4h0WWId09=iN00208UgM@0408YlN`2:OWh0RWin08IjNP80R7al00D0QGUi08EkNP27Ng/0
Qg]k085eM@0208UnO00508]mO027NGH0QgUf08EhLP27NG000P2:O6l0102<O6`0SWmZ08ioJP2CPfX2
09n@L`050:fMN`2iYgl0akB:0<NdRP3>^HX00P3F`8h01@3B^hD0cKMm0<fgO@35/740XXm:0080PgDZ
00@0Xi]80;fjJ@2m^VT0d]>=0P2?TeP01@1NG2`0PGUB081aBP20LDX0KEL`0080OF8g00D0O64b07mV
<01oIS00Mf4W065;4@0206eI7P0406UB701I@@<0FD4308ie9@80Zi@^00D0[IPK0;RV5P3EaR/0eLH[
0=[@<0020=C<:`050=_F>P3NfDT0g]U90=??D@2SWc@00P1^J180100n=`00:b4002/Q000S6P0202HM
000502lT200e9`d0=2D@03@U400b8a000P0h9aD01@0e9180<R<@038S400a8Pd0<24<0080:1X000@0
7a4003LX1`0g:0L0L68o0P1fIdH01@1eID`0RWER09=iJP2CNFX0Vgi^0080XH1a00D0TViN09E`GP2E
L5h0UW5O09AaGP0208MVD`0408=WDP2;L5d0Rg1M0:2;NP80b;JX00<0k=oF0?oim000o`002000o`0?
ooooo`003Oooool4003o0080ooKe00D0[hV608I5@@26AD40Wcm10:/f?0020;8c>P040<8lA@31>400
`CQ00<U0A`80`c/o00D0a4940;a4A@2B;2X0TR`Z0<IhM0020?o:``050?:f[P3g_K40mkfa0?FlZ`3g
_jP00P3P[X/0103CY7P0h[En0>:eOP39WF020=VbK`050=jhM`3Xa8H0]Y5L0;JAG03=YW/00P3W_Yh0
1@3:WHH0fJVM0=VYW@3ogm/0j;6d0080UUAH00@0SU1E0;1mPP2`OH80RfMW0P1PBdH01@2;OWH0WY>=
09^@RP2KT8X0VXn900<0V8f70P2KT8X01@2MTX`0XYVB0::HS`2RV8l0ZInF0080]J^R00D0aK^b0<k4
^`3>a;/0^[2W0:fRW0020::GT@<0WYF@00D0WI>A0:6AT@2QTI40YHf=0;6=S`020<VBU`040;YcN@2k
HFX0^f5Z0;YGG080^EII00D0XdU809M=BP2^Mg80[WMb0:N0N`020:B7P`0509MoO`2IO7h0VGan0:1g
O@2ZMGd00P2fL7P0102GBU00V4i?09Q>C`1o?cd209=VH@0509enN`2>NGH0S7al08alO02:O7`00P29
OGd01@25NGT0QWYj08IjNP25NgX0Qgel0080R7im00@0PgUh08EiN@25NGT0QWYj0P28O7`01@23MgL0
RG]k08QjN@28NWT0QWQe0080R7]e00D0QGQ`08AfJ`24MV/0RGa[08]lI`020963J@0409^<K@2^WWX0
[Yij0;NVN`80akF500D0e<>;0=C4QP3<`7P0c<1h0<FlK@020;VfI`050=7ER`33bH/0`lV;05iP<@1H
E2h00P2AQ6@0102cWgh0RVi908Y^B@24ICL2099e>`0508]`:`1mIa`0QW<V08Ic9P1mJQh00P1PB`00
1@29LQ80[9LT0:bG902`W1D0[ih80080bK/L00@0fm8[0=oH;`3Of2l0f=@Z0P3Og3L01@3NgT80g]eA
0=SFF`3HeU/0_;MC0080Ui4m00D0K6DM059=3@1BC@d0>c8003L/000202lS000302/M000^8000;R00
00<0;Al000D0<R@003P[001:?@H0BSd606]O8`0209Z>DP0507a_>P1eIcX0MFLj06aK?@1`GTX00P1b
Fd/01021IeX0R6]M08Q[G@2KNV/20:B0L00509mlJ@2@L5T0S6aC08a/D`2?L5@00P2MOf<01@2@MeT0
MV5607IQAP1bH4`0QWIW0080_;:X00<0jN;J0?gjm@3mn_D01000o`0?ooooo`003Oooool4003o0080
ooKe00D0[hV608I5@@26AD40Wcm10:/f?0020;8c>P040<8lA@31>400`CQ00<U0A`80`c/o00D0a494
0;a4A@2B;2X0TR`Z0<IhM0020?o:``050?:f[P3g_K40mkfa0?FlZ`3g_jP00P3P[X/0103CY7P0h[En
0>:eOP39WF020=VbK`050=jhM`3Xa8H0]Y5L0;JAG03=YW/00P3W_Yh01@3:WHH0fJVM0=VYW@3ogm/0
j;6d0080UUAH00@0SU1E0;1mPP2`OH80RfMW0P1PBdH01@2;OWH0WY>=09^@RP2KT8X0VXn900<0V8f7
0P2KT8X01@2MTX`0XYVB0::HS`2RV8l0ZInF0080]J^R00D0aK^b0<k4^`3>a;/0^[2W0:fRW0020::G
T@<0WYF@00D0WI>A0:6AT@2QTI40YHf=0;6=S`020<VBU`040;YcN@2kHFX0^f5Z0;YGG080^EII00D0
XdU809M=BP2^Mg80[WMb0:N0N`020:B7P`0509MoO`2IO7h0VGan0:1gO@2ZMGd00P2fL7P0102GBU00
V4i?09Q>C`1o?cd209=VH@0509enN`2>NGH0S7al08alO02:O7`00P29OGd01@25NGT0QWYj08IjNP25
NgX0Qgel0080R7im00@0PgUh08EiN@25NGT0QWYj0P28O7`01@23MgL0RG]k08QjN@28NWT0QWQe0080
R7]e00D0QGQ`08AfJ`24MV/0RGa[08]lI`020963J@0409^<K@2^WWX0[Yij0;NVN`80akF500D0e<>;
0=C4QP3<`7P0c<1h0<FlK@020;VfI`050=7ER`33bH/0`lV;05iP<@1HE2h00P2AQ6@0102cWgh0RVi9
08Y^B@24ICL2099e>`0508]`:`1mIa`0QW<V08Ic9P1mJQh00P1PB`001@29LQ80[9LT0:bG902`W1D0
[ih80080bK/L00@0fm8[0=oH;`3Of2l0f=@Z0P3Og3L01@3NgT80g]eA0=SFF`3HeU/0_;MC0080Ui4m
00D0K6DM059=3@1BC@d0>c8003L/000202lS000302/M000^8000;R0000<0;Al000D0<R@003P[001:
?@H0BSd606]O8`0209Z>DP0507a_>P1eIcX0MFLj06aK?@1`GTX00P1bFd/01021IeX0R6]M08Q[G@2K
NV/20:B0L00509mlJ@2@L5T0S6aC08a/D`2?L5@00P2MOf<01@2@MeT0MV5607IQAP1bH4`0QWIW0080
_;:X00<0jN;J0?gjm@3mn_D01000o`0?ooooo`003Oooool4003o0080o^k^00D0W71_08Do?@25?cd0
Y3m30:lh?P020:l`=`040<8lA@30=cl0`3Lo0<a3B`80aSe400D0aCa30<M0AP2d=SX0]3Hj0<EBE@02
0=E]K0050=McL@3JOGP0fWeh0=R4NP3CRgd00P3d_JT0103DZ8d0i;VI0>BiV@3BZXH20;JCK@050<j/
Q`3K^9P0[8M]0:b7K@3ldL400P3e`;P01@3_ZjP0mJj/0?F^[03l^;T0olK70080^gUj00@0R4i=0;V@
SP2iT8h0YhV70P1/FE<01@1EB480LFIP09J=QP2FSHH0WI>:0080VHn600<0W8n709^@RP2KT8X00P2L
TH/209jCS@0409nDSP2TVI<0Y9VC0:^PVP80^JbT00D0c/Bk0=;8_`2g[ZD0]jjU0:VPV@020:6HT@05
09fDS`2NThl0WY>?0::CSP2XT8h00P2gT9401039TYL0_G1h0;e`N02kH6T20;aGG@050;IDE@2K@d40
WeI@09mFD02^Mg000P2[PW`01@2QOW`0XGYk0:5jN`2YMW/0^G^00080Zf1W00@0UTM<0918B@2@B4T0
QDY60P2PMg<01@2ENGD0SG]g08UkNP29NgX0Qg]k0080RGem00D0Q7Yi08EkNP25NgX0RGil08MlNP02
08IlN`0408EkNP25NGT0QGUi08EiN@80Qg]m00D0PWIh08EiN`25NGT0QGUi08IjNP0208EiN@0508Ej
N027NGH0QgUf08QkM@22MFd00P26NG001025Mf`0RGa/08UlK02<O6`209>4K@0509f>L@2]WWL0`[B3
0<:dP`39_X000P35_WX01@36ah40i^b/0>K/[02LXg00@dDN0080KFQ;00@0fl^b0:Z<LP2ZS780KTXV
0P2iU5d01@2mVe40UGXQ09f7902MQb@0RgLD0080L5d000D0XXlI0;FR7`2eXQl0]Z@D0;6Q1P020;f_
3P040=357P3MeB`0gMD/0>3L<P80i^@j00D0i>E10>?UAP3Ti4h0i>A>0>KUF@020>;RH0050=WIG`3>
cET0c/eI0;JbA02WXcP00P2GTR`0102;QR80RH4O08V17`2;PB020926900509V@:`2XVcD0]JQ00;FX
@02n/D/00P34]eT01@2TU4L0K5`Q06aL8@1RCRT0J58k0080PFMH00@0QVYO07mSE`1oHeL0QfUN0P1m
HE<01@2HOVd0Qg5J08ahG@2<N5d0S7UI0080TgmJ00D0X8eS0:VCJP2YTfX0WXQS07aWB00205Q4:`04
069C@026O700QWa`0<C0]`<00?l03oooool000gooooo1000o`020?3NgP05091PH028?3`0R3`l0:Ho
@`2/=C/00P2h=Sh01031>d80a3i70<@nA`36@4T20<0j@`050<<kA@3:?TL0c4190<a0B@2j<cT00P2`
;C801@2b=SP0[c/k0:lk>`2S>SH0OB@N0080_7ic00@0k[j`0:^0L02[P700bj6A0P3bcK/01@3cc[h0
XWaa0<6HTP31V980omGG0080_gb300D0VT570:Q8C02XB4`0Ze9D0<5cL@020:5MFP0409]VHP2eT8X0
]I2:0:J?R@80WHj900D0OgA^05Q=A`1GCTL0Edi707ebK00209bBR@050:6DSP2NTH/0WY6;09jCS@2K
T8X00P2OU8h0102NThd0WiB>09nDSP2PUHl20::ES@050:VOUP32^:l0bl:i0<_2^@2n]Jh00P2`Yj00
1@2UW9D0X9N@0:2GT02QUY00YYB@0080Z8j=00@0_9>G0<j?U`3>SiL0_6ae0P2nGfL01@2kEUX0]5AE
09U1?`2I@Cl0YV1H0080]7Ua00D0[gah0:miN@2_NGT0]gMh0<9jO@020:=AE`0409];CP25?cl0QClo
095LF080Y85m00@0Tg]g08]lN@28OG/0R7ek0`29OGd01@26O7/0QG]j08EkNP28O7`0Qgel00<0QWak
0`27Ng/208AhNP0408EiN`27Ngd0Q7Qj08AhNP<0QWYl0`25NG/208IjNP80PgQf00@0QGYh08MiN027
NGP0RG]h0P25MVl01@26MVL0Rg]Q09J7GP2FQeh0Wi1I0080XiYE00D0_Kib0=cRVP3LhYX0hNZc06aa
B00203dl7P040;BXTP3[d;d0jm2m06E29080V70l00D0hkeb0<^^BP33[S/0`jhk0;VY<0020:^L7@05
0;RX8@33/b80`k<R0;n`6@31/a@00P2k[PX0102o]0`0dl/P0=?;803MfRd20>KT>@050>OV?03Ri3/0
h^Dn0>;U?P3WjDH00P3Zk4d01@3Zje40l?1J0?3`FP3^kU`0jNQJ0080gMiD00<0f]YD0=[GEP3JeeH0
0`3FdE401@3FcD`0ele90=G8A@3Eb4D0c/130080a;M500D0/9m7099m?02BOC`0GTLM05Xn9P0206iA
@@0407YLD@23HUT0Pf9I08Y/HP80PFMJ00D0PfeO071OB`29OF<0RGeS09N<KP0209f@K@0509b?I@2I
R5`0VHQL0:6?H@2_VG000P2UTFh0101cHT@0>c0L03/`701dKV020?[im@03003o0?oooooooooo00go
oooo000=ooooo`@00?l00P3`g]h01@2@H600R3`l08Pl?02V?d<0[3Dk0080^3Hn00@0`C]20<@nA`34
?TL0aT190P30>T<01@33>dD0bSi70<a0B@3<@4T0^S<i0080/2db00D0/SHh0:lk>`2_>c/0XcXf07dT
7P020;anL`040>jn/02[P700Zh1`0<^QT@80l/fk00D0lljn0:9lL@31V980`IRB0?oEe`020;mlP`05
09Y1A`2XB4`0Z4Q<0:]BE031Lg400P2QGEX0102KIV80]I2:0;F@RP2VShT209f>R@0507mdKP1HCDL0
Edi705M>A`1mLV`00P2LTXT01@2QU8h0WY6;09jAR`2NThd0Vi2:0080WiB>00@0WY>=09nDSP2OU8h0
X9F?0P2RUHd01@2YWiH0`[R_0<_2^@3;`[T0_[F^0080/:NP00D0YIbE0:2GT02PUi00XIJ@0:JDT002
0:R>S@040;bCU`3>SiL0cXnG0;a/M@80_UmW00D0^eIJ0;ADE@2I@Cl0VD4o0:IPF0020;AiL@050:ml
N02_NGT0[gUi0;MgN032NWd00P2SDEL0102KBdh0QClo08Do?`2AG5P20:B1O@0409=kM`2;O7T0R7ek
08QmN`<0RGem00D0QWak08EkNP25NgX0R7al08MmO00308IlN`<0Qg]k0P24N7X01025NG/0Qg]m08Ah
NP24N7X308IjO0<0QGUk0P26NWX208=hMP0408EjN027NGP0QgUh08UkN080QGI_00D0QWIW08]kH@2F
Qeh0UXMN09n@F@020:>JE@050;fnLP3LhYX0g>:J0>7Z/`1/LDP00P0m?1h0102dZ980jm2m0>_@_@1U
@R@209Q`?0050>>mLP3;[TX0`jhk0<>^>`2iZC000P2[W1d01@2hZ240`k<R0<>c8P2o/1T0`K<D0080
^jh:00@0_k@<0=?;803Cbb00gMX]0P3Vi3T01@3WiS`0h^@k0>;U?P3RiCh0inU60080j^a=00D0j^]A
0?3`FP3`l5X0k^iL0>WXFP020=gNE0030=[JE03JeeH0f]MF00<0e]5A00D0e/e<0=O=B@3Eb4D0eLQ5
0<k0@`020<BgA@050;2OA`2BOC`0TWdl05i77@1J?RH00P1^DD40101jG540Pf9I08=RF@2:K682085W
FP0508=]G`1`Gd/0RGeS08UmH`2GS6h00P2MT6d01@2LSfD0VHQL09V8G02QSf40[iU`0080YI5^00@0
Lf9403/`700k<1`0M6iP0P3jnOD00`00o`3oooooooooo`0=ooooo`003Oooool4003o0080h/g<00D0
Q55@08/m?@2;?Cd0Yci30:`c>P020;Li?@040;ln@`2l?D@0_3e40;/nAP80]ce800D0/SI10<DoBP37
?TP0aci80<TmAP020<TnA@050<e5B@39AdT0bDM90<E=C02/A4400P24=c40103_]:h0f:VS0=RYX`3m
d//20?G6`0050>bm]`3K[jh0jKRk0>Vh^`3oam000P2dHF/01@2hBE80aDiD0<E>E02dB4P0/59@0080
UDi800@0/Weg0:j=QP2^SHH0WXZ30P2KSXP01@2MTXh0V8f9079WH`1bIf<0DDI20080Eda600D0PWAa
09f?S02MSh`0XiRD0:2ES`0209nDSP<0WiF<00D0WI>:09jCS@2NThd0WY>=0:BJT@020:bRV@040;N/
YP2n/jd0_[>]0<6g[P80]ZbS00D0Z9^E0::CSP2SShh0Xhn>0:^?SP020<>DVP050<f>UP2jJG00^VU`
0;EIGP2gE5L00P2fE5<0102PAd<0Xe=<0:=CC02mKf/20<AfM0050<YiN037LG80Ydi@0:M>D02PD540
0P23@T001@2QL6`0X85l0:21O02@OGL0S7ik0080QWaj00@0RX1o08UoOP29Ogh0S85o0P27Ng/01@27
OG`0Rh6008Z0O`2:P7l0QWak0080R7al00@0Rgmo08EkNP25NgX0QWak0`28O7`01026NWX0Qg]k08Mk
N`29OGd308EiN@0408MkN`26NWX0QWYj08IjNP80QGUi00D0S7im08amN02<OGP0Rg]^091oI@0209F4
F00408]k?@2DRCX0U8Tj0<C3J@80cM9n00D0j_>`0;BjRP1CDS<0De8c07UaG0020?CRcP050;NIO@1d
Ca/0M4lK0=VeJ@3Pb5h00P3D`T@01039_CD0bL4`0<W1<037^bL20<Zo9@050<_19038_Qh0a[dH0<Jm
6036_QD00P39`aL01@3Fdb@0h^0c0>;P<`3Xj3X0h>8f0080gMld00@0hnDl0>;T>`3Ri3/0h^<m0P3Q
hS`01@3UiT00iNQ30=_P?P3Kh3h0g>150080fme;00D0inIH0=kKCP3Nfdh0f=960=S=@0020=?7?@04
0=33@031/Sd0`K8m0:nL@080V84m00D0LE@X06119@24HDh0Q65>07YFBP0206@n=@0507YHCP1nH5H0
OV1F07eUF@1gIeP00P1XH4d0101cKEL0X9Z00:2JP02^Z8P20:FMMP0509^@H`2IS5l0Z9]_0:RKK`2i
[HD00P1WH4<0101^K5L0nOSc0?Whl`00o`0?ooooo`003Oooool4003o0080d;Rh00D0O4I4090n@02@
?T00ZCi40;0g?P020;Tk?`040;do@`2f>d00]S]00;4i@P80mXN@00D0igB10;/mB@39@Dd0bD5=0<Tm
B0020<XmA@050</nAP37?d<0acm30<E3A@2nBT/00P259R@01037NGL0om7A0?oAd@3i_;/20:IPH005
08M1@`3X[:h0olkD0?o>e03jZ[D00P2]BED01@3;CeT0bTU>0<Y9CP31Bd/0[Ta90080VU==00@0^HR1
0:J8P02VR800WHZ40P2LShT01@2FSHP0VXn;09bAS@2LTHd0UHZ60080JUmK00D0CT0m05Y?B`1JCd/0
P7Ea09Z?R`020::GT@<0WI>:00@0WYB;09bAR`2LTH/0WI:<0`2SVI00102WW9H0ZIjH0:VNV02h[ZD2
0<Nm]0050=74_P31]:h0[YnL0:jOW02]V9L00P2_Rhd01@3=V9h0hiZQ0>>JX@2eGVH0_EeQ0080_UYJ
00@0bFYV0<EXH`35J6<0[E9?0P2bEeH01@3:JV/0`61Q0;EGE`2eEeL0WDM60080UTm=00D0[GIc0:=l
M`2SO7L0VGei099mNP0208mmN`0409>4P@2>P7l0SX1o08n1P080SGmn00D0S82008f3PP29Ogh0RGmn
08MmO00208YnOP0508b0P02;Ogl0Rgmo08UoOP26NWX00P29OGd01027Ng/0RWin08YnOP2;Ogl208Mk
N`0508YnOP28OG/0Rgel08]mO02;OGX00P2<OgT01@2>P7L0T81a0920L@2@P6L0UXAL0080TX5900@0
SGdb0:fQB`2]XD/0cLY]0P33aG401@3LhIl0hNBg07AcE`1dLeL0KfQF0080e/Jg00D0k]Jn07iM<P1n
GC80]iIA0?GMN`020>?CFP040=gAB`3Kdd@0fm=40=[@?@80fm4l00D0dl`e0=;<<03Abbd0dL/]0=;<
;0020=;=:@050<g:8`3Jec00f]L`0>;Q>@3Si3h00P3Rhcd0103PhST0hN<h0>7S>03QhcL20=oR<`05
0=kQ<P3Ohc@0g^8f0=kR=P3KhCT00P3MhD801@3Vidd0hn9:0>?RBP3Je400dLLb0080e/Xj00@0c/4g
0;j^=02n[S@0]J4n0P1nIa/01@1[CAT0KD`Y09A`EP2DL5H0MDll0080OEI700D0ME5306M7>P1WAcX0
G48e065@@00205mB@@0406MOB01ZI4X0JVA:089mG@80[jZ400D0]Zn30:FMKP2KTf@0Vi=T0:bUN@02
09^IL`0408J6KP3inO40nOWa003o00oooooo000=ooooo`@00?l00P2hW9/01@21AdD0T3`l090l?02/
?d@0/3Ln0080]cXn00@0_T550;@k@02d>d00[CY10P3gSIL01@3/PXh0/SY60<A1C`34@Dl0b45?0080
b3m900D0a3]50<Y1B@3:@DT0bD980<M6BP020:/g>P040:Lm?`3gU9L0miBG0;YGFP80]4Y>00D0WC@h
09Lk?P3oYZ/0ojJ[0>V4S0020;U7C`050<e?D`37BDX0adU:0;i<B`2RAd800P2OGeH0102jShP0XXJ2
0::6PP2LRXH209j@S@0509Z?R`2KT8h0VXn=09Z?S@2PUI400P2QUY801@2=PX00JEiL06UNG01:?cd0
FE1;0080QWeh00<0Uhj70:2ES`2PUHl00`2MTX`0102NThd0Vi2:09fBS02MTX`309nDSP050:FJU02/
XI/0[:6K0<Fj]P3IblP00P3DaL80103>^KP0_I^L0;fKW036UIT20>>NX`050;m]L`3GNgh0aFEV0<EU
IP37JFL00P3BMg801@39JfT0[e1>0:m@CP2hE5@0]e1A0080_eQI00@0YTQ60:YFE02ZEU@0^W=_0P2`
MG401@2YNGD0Y7eh09YkMP2JNgH0VWik0080VH5o00D0TWmk095oO@2AOgd0TH9o0922P@0208n1P004
08b1O`2?PH00Sh6008YoO@80SX>100<0S85o08MmO029Ogh01029Ogh01@2:Ogd0Rh1n08^0OP2=Ogh0
Rgej0080SWmj00@0Sh5h09:1L@2BPG40UHAZ0P2GQEl01@2DPdl0U89009:2=02BPS@0Zie40080`kYM
00D0c<Q_0<W7O039ag`0fm^W0>3P_P02096<N@0408^2N@2cXYX0/j:J0>SA`@80QfY:00D0ZXYG0?[P
T`3bfg/0l]]k0>oMK@020>kNI@050>_NGP3Zh5`0j^1L0>CLE@3Qfe400P3PfTh0103Fe4<0f=I50=SF
A@3JfD<20=OF?P050=[I@03Kg480i^M;0>KWB`3Qhd@00P3NhC`01@3RiSX0gn<d0=oS=03Lh340gn<d
0080g^8e00@0hNDi0=cO>P3LgcX0hnA10P3[idP01@3PfS`0elhc0=;7;`3Babl0c<0^0080_JlZ00D0
^ZPj07QS2P1hH`X0Ech0085S<@0207aL<`04060m7@2:IT`0RVI<06Y7<@80Tg9O00D0Of=>0617<@1E
@2D0ED0U05e::P0206mQ?P0506UM=`1`JCd0L6Tm09jGJ@2g/h@00P2b[Wl0102DTfL0ZZZ40:ZZQ02Y
[9420?Sil@03003o0?oooooooooo00gooooo000=ooooo`@00?l00P2hW9/01@21AdD0T3`l090l?02/
?d@0/3Ln0080]cXn00@0_T550;@k@02d>d00[CY10P3gSIL01@3/PXh0/SY60<A1C`34@Dl0b45?0080
b3m900D0a3]50<Y1B@3:@DT0bD980<M6BP020:/g>P040:Lm?`3gU9L0miBG0;YGFP80]4Y>00D0WC@h
09Lk?P3oYZ/0ojJ[0>V4S0020;U7C`050<e?D`37BDX0adU:0;i<B`2RAd800P2OGeH0102jShP0XXJ2
0::6PP2LRXH209j@S@0509Z?R`2KT8h0VXn=09Z?S@2PUI400P2QUY801@2=PX00JEiL06UNG01:?cd0
FE1;0080QWeh00<0Uhj70:2ES`2PUHl00`2MTX`0102NThd0Vi2:09fBS02MTX`309nDSP050:FJU02/
XI/0[:6K0<Fj]P3IblP00P3DaL80103>^KP0_I^L0;fKW036UIT20>>NX`050;m]L`3GNgh0aFEV0<EU
IP37JFL00P3BMg801@39JfT0[e1>0:m@CP2hE5@0]e1A0080_eQI00@0YTQ60:YFE02ZEU@0^W=_0P2`
MG401@2YNGD0Y7eh09YkMP2JNgH0VWik0080VH5o00D0TWmk095oO@2AOgd0TH9o0922P@0208n1P004
08b1O`2?PH00Sh6008YoO@80SX>100<0S85o08MmO029Ogh01029Ogh01@2:Ogd0Rh1n08^0OP2=Ogh0
Rgej0080SWmj00@0Sh5h09:1L@2BPG40UHAZ0P2GQEl01@2DPdl0U89009:2=02BPS@0Zie40080`kYM
00D0c<Q_0<W7O039ag`0fm^W0>3P_P02096<N@0408^2N@2cXYX0/j:J0>SA`@80QfY:00D0ZXYG0?[P
T`3bfg/0l]]k0>oMK@020>kNI@050>_NGP3Zh5`0j^1L0>CLE@3Qfe400P3PfTh0103Fe4<0f=I50=SF
A@3JfD<20=OF?P050=[I@03Kg480i^M;0>KWB`3Qhd@00P3NhC`01@3RiSX0gn<d0=oS=03Lh340gn<d
0080g^8e00@0hNDi0=cO>P3LgcX0hnA10P3[idP01@3PfS`0elhc0=;7;`3Babl0c<0^0080_JlZ00D0
^ZPj07QS2P1hH`X0Ech0085S<@0207aL<`04060m7@2:IT`0RVI<06Y7<@80Tg9O00D0Of=>0617<@1E
@2D0ED0U05e::P0206mQ?P0506UM=`1`JCd0L6Tm09jGJ@2g/h@00P2b[Wl0102DTfL0ZZZ40:ZZQ02Y
[9420?Sil@03003o0?oooooooooo00gooooo000=ooooo`<00?l000@0ooKd09anO02LOW`0Q4M40P2E
?ch01@2Y?440[C@i0;Pm@02h?D00^d150080^dA:00D0[d980=EaN`3ELG/0gGV50:TkB0020;M2DP04
0;]2D@30@e40`4=A0;i0C080`dA?00D0`T1:0<93BP32Ad`0`TM<0:/b>@020;a7C@050;a3BP3<CE@0
c4eD0<a?E@2M:2h00P35DUT0103DFf80bDaB0<U<DP3?CU820<A:B@050;iBC`2IA3d0[W=[0:icJ`2e
T8P00P2MQH40102IRXL0VXb909Z<R@2ISXX309Z?S@0409Z?R`2MTXh0WI:>09nDTP80XINE00D0RGmm
05iDDP18@C/0B44k05QAB`0208AkMP0509nDSP2QUY00XIJ@09fBS02KT8X00P2LTH/0102JShT0WiB>
09nDSP2SV9820::GT@050:RMV@2aXj00`k6_0<>a[`3Sbl/00P3[a<L01@3S[k<0cHJ<0<f6S02bGF80
cW9e0080cfm`00@0fh1m0>F:Q`3URXL0l9:@0P3JNgT01@38I6@0`eaM0<1IFP30FEX0^5AD0080ZD]9
00D0Z5=@0:YLFP2ZG5X0ZF=Q0:mbK`020:mhM@040:UhM02XO7T0Z7ai0:=mNP80WWaj00D0XHB009Um
NP2IP7`0VH1l09MoN`0209F0O@05099oN`2CPGl0Th5o09:3P02=Ogh00P2CQHD0102<PGl0SX>108j3
P@2>P7d208n2NP0509F4NP2@P740UhId09N6M02DQ6X00P2HQV801@2DPU@0T8140920A02BQ3d0YIE7
0080/:A@00@0akeX0=;;N`3Bbg/0gMRD0P3Ge9d01@35`Yl0ZjVD09bES@2LUHd0XYRG0080XiFD00D0
`k2Z06eC@P1]Dd80JDl^0:F9E`020;nRH0040=k1L@3`eGX0l=Ej0?CJN@80lmie00D0l=i`0>oSK@3]
hfX0kN=Z0>_SIP020>WQHP050>OPGP3SgeT0hmmI0=oKD`3Ge4T00P3[jUX0103Wie<0h>570>3QA`3Q
hd020>;U?0050>7U>@3OhcL0g^8e0=kR=@3MhCD00P3OhCP01@3PgcT0i^<n0>KS?P3OfSH0eLd/0080
dlTZ00@0c;lU0<Vj:`39^R/0_Zl`0P2YUbT01@20Ja00OFHH08=Z9`23JRL0N5hS0080Wh=C00D0MeX`
089V@@22IT40VX1M07AJ=`0207IO=P04085[?01ZER<0JUHS069B7P80JUhZ00D0MV`k08AnCP2[YgP0
ZjMh0:JUN@020:RZP`040;>fV`3hnO40n?Wa003o00oooooo000=ooooo`<00?l000@0mncZ08Y[J02:
JfP0PDA10P2K@d401@2U>cd0ZS<g0;Hn@02f?T00^T=70080^TU?00D0ZT9909Xk@`2J>d<0/5AO0:A6
E0020:Q7F0040:m:G02]AUL0[DIG0;15E@80/DED00D0/T9>0;M5C`2iAE00^DE@0;Q3C0020;i5CP05
0<A5CP3=Ae00cDM@0<Y4C@39@d`00P32?4D0103?Ae40d4U@0=19D03;B4d20<1:BP050:i:B02GB4<0
^HAn0;V4OP2/Rh@00P2NRH@01@2GRX@0Uhb809N<R02JSh/0V8f90080VXn;00@0W8j;09Z?R`2JSh/0
VXn;0P2IT8/01@2MU8l0WIJ@08b4P@2<Q840Edm<0080B3hl00D0IU]G08b1O@2<PGd0XiFB0:BGT@02
0:>FT00409jDR`2MThX0WI>:09jCS@80XYNA00D0Y9JC0:NHU@2`ViX0/9^J0;bLW@020=j]/@050?Bc
^@31L7L0`G1g0;9EG@2[Bdl00P2eDUD0103NP800nYnL0?ZOW03gW9T20?:GU0050?JKVP3UQhL0dG9`
0=5bL03CLG000P2oFe/01@2cDE00ZTY;0:Y:B`2RAdH0WDE40080Wd]900@0YUED0:UMG@2YGEd0/F]Y
0P2`L6h01@2eNgT0[GYg0:elN02]O7P0Yg]h0080XWai00D0X85l09f0O02MP7`0Vh6009N2P@0209V5
QP0409>1O`2@OWX0T7ij09>2NP80W8al00D0VXU_09R6HP2JQe`0VXML09B3C@0208mm?@0509B3>`2P
Td@0X9=40;6VEP30]fX00P3Ec8L0103Pei`0f=2Q0=S@X@31^iL20:ZVS@0509nKS`2MVYD0WiVK09nI
V`2PVYh00P2SVJ401@2cYj/0SG]i08ekN@1A>340IDHd0080JdH[00@0Qe/d0;63DP2aPe80fZaa0P3X
^gL01@3_bWX0m=Ek0?CJN@3dfWT0nN=m0080m>5h00D0m>Ae0?;UL`3biG<0lnQb0>kVJP020>gXJ004
0>SVG`3Ui5H0iNAF0>3SC080g>1300D0i>I30>;U@03NhCX0g^4j0>;U?0020=gO=P050=cN=@3KfS80
fmXb0=KC;03DcBL00P3Ec2T0103@`bD0dlH/0=?6;03?`c420<^n=0050;V/;02ZVbH0X8lU0:2?9@2L
S2d00P2LRSH01@2>O3@0LEdN075M7P1jIbd0Mf@Z0080MV8U00@0/9iF0;RVFP2hYUX0RgT_0P1NC@P0
1@1VEAd0MFLf07Ua@P1iLD80`l2E0080/;:=00@0[JnG0?Sil@3hnO400?l03oooool000gooooo0`00
o`00103gk>X0RV]X08Y[J021A44209]3@@050:Dk?@2Z<cL0]Si00;Hn@02j@dL00P2jBDl01@2Z@TT0
VS]309Xk@`2`E5l0Y4ID0080Z4MH00@0[dYL0:e6E`2]AUL0/4EE0P2aAE@01@2b@Th0]dE?0;U5D02i
AE00^4=<0080_TE>00D0a4E>0<e7D03=Ae00bTA=0<U3C0020<8lA@040<m7D@3@BE00d4U@0<]8C@80
`4Y:00D0[TY809M8@`2iQ7h0^HAn0:b;Q00209j9Q00509N:Q02GS8P0Uhb809Z?R`2HSHT00P2JSh/0
102LSX/0VXn;09Z?R`2JSh/209V@R`0509fDS`2MUY00S8B108b4P@1GCd`00P18?S`01@1VFeL0S85m
08b1O@2SUI80Y9NA0080XiJ@00@0WYB;09fCRP2MThX0WY>=0P2RUi401@2TUY<0YiRE0;2KVP2`ViX0
_9bM0080gZfa00D0m;>i0<5`M`31L7L0/UEM0:];C`020;EBE@040=j0P03jWi`0nYnL0?NLV@80lYND
00D0mY^J0>F7Q`3ALW00dG9`0==aL0020;mKF`050;=AD02ZBT/0ZTY;0:97AP2MAD@00P2OBdT0102V
EE@0ZEeM0:UMG@2aJfT20;1`KP050;EkN@2]NWL0[Gah0:elN02WNgP00P2RO7T01@2PPG`0WH1l09f0
O02KPH00Uh:10080VHF600@0Th5o091nNP2@OWX0Th9j0P2LS7`01@2JRFl0V8IR09Z7G02JQe`0U8==
0080Sgdm00D0U8<k0:2CA02PTd@0/JIF0<2gJP020=G<Q`040>3GW03Hd:40f=2Q0<6kU`80ZZJ=00D0
Wi^?09fJU@2OVI/0WiVK0:2JWP020:>IX@050;>WZ`2=NgT0SG]i054h<@1UAS@00P1[AR/01027Fc@0
/H=B0;63DP3J[7420>RkM`050>o:NP3deG/0m=Yi0?CJN@3ihgd00P3dhGP01@3di7D0l^Ec0?;UL`3c
j780k^IZ0080kNQX00@0j>IO0>GTEP3Ui5H0h>=<0P3Lh4<01@3TiT<0h^E00=kQ>P3NhCX0h^Dl0080
gMlf00D0g=he0=_J<P3KfS80e]</0=C=9`020=G<:@040=339@3CaR`0dlH/0<o3<@80bkhd00D0^J`/
0:ZK9P2PSbD0X8lU09b<;@0209b:=P0508il=01aGAh0LEdN07YW;@1gI2X00P1fHRD0102`WUH0^:IJ
0;RVFP2;NBl205i=200506IE7@1eIcH0NG5207Ua@P33`9D00P2`/Xd0102][iL0n?Wa0?Sil@00o`0?
ooooo`003Oooool3003o00040>GGe01kFUD0NeYE08I7@P80UCdk00D0YC/m0:/d>02h@480^4120;Q4
A`020;13B0050:0k@@2^De`0[U=L0;5KIP2dI7400P2fJ7H0102VFFT0XUAT0:9DI02C@U4207l]>`05
08lkB02;<cl0V3]609PkAP2Q?DT00P2c@dl01@2k@dl0aTA@0<I4D03>AU00cD5:0080c3m800@0cCe7
0<m3C03?@d`0b4E:0P2nBT/01@2XBDL0WEI@0;f>R02mSXP0XXEo0080WX^500D0Vhj809^@S02KT8`0
VXn;09N<R00209V>RP0409j@S@2KT8`0Vi2<09Z?R`<0VI2;00@0ViB>0:2IT`2PVI<0WYNA0P29Ogd0
1@1NEE00BSlk04Xo>`1XFUL0Rgej0080XYF?00@0XiRB09jCS@2NThd0W96;0P2RUi401@2TUY<0ZYJE
0:nBU02_TY@0^HnC0080e9FM00D0eHF>0<QWL038Ig00aeiU0:i1A`0209`b=P0409/d=@2mFeX0_E]J
0=AeL`80fG]i00D0h8:20>B6QP3VQhD0iXN50>Z6Q0020>N1O`050>AlN`3HL740f71a0<YSI02hDE80
0P2fDU80102U@D<0Wcm009lo@02Q@d<20:98B0050:QDDP2[FeX0/VQW0;9XI`2bKV/00P2fNGH01@2b
NgP0[Gah0:elN02[OGd0Z8210080XGem00@0WX5m09V0N@2IP7T0VXAf0P2NRW401@2JR600TX5=095n
@`2AOT<0WHa60080YYI900D0]ZUJ0<FlK`35_6l0f=690=[DUP020=;<VP040;RbT02XXX`0Z::<0:6K
S`80X9^G00D0X9bM0:2KX@2QW:<0XIbS09nJX@020:6IY0050:RNY`2gZ[<0]jZc06mLH016:B/00P1U
@Sh0101aAc/0LD8^0752;P2WN5X20;23G0050:=iA`2kUed0bJMW0<VWI`3J_7@00P3YcX401@3^eH<0
lMV30?7IP`3_fWl0l=ak0080l=mg00@0k=m_0>oUK03_iF`0j^5P0P3TgU@01@3Sg4d0i>190>?PA`3S
h4L0h]m20080hMi100D0gmdm0=[H>03Jf3P0fMDf0=OA<`020=S?=0040=?:<@3EbS80eLXb0=;8<P80
eL/e00D0d<Hc0<No<038_SP0b;hh0;Z`=0020:VN:`0509jC:P2>PbL0SX<W089g7P1jJaH00P1^H0P0
102TUSD0hM9]0>7BK@3XfG@20<2aE00507][7P1SEAH0N6lh07Q_>02k]hP00P2b/X`0102]/9D0n?Wa
0?Sil@00o`0?ooooo`003Oooool3003o00040=_=bP1cDTd0Le9=08A5@080Uclm00D0YcXm0:hg>`2i
@4D0^D150;U2B0020:dnA0050:8m@`2cG6@0/eaT0;IYL`2/J7<00P2FGFH0102CGf/0[gf90:mmR@2e
Phh20;:0R`050<bJY@2/N8@0^7j:0;QnRP2mNHH00P2@?4/01@2N>DL0_DMC0;e7D`36A4h0c4E<0080
cD1800@0cCe60<i3BP3>@dX0adI:0P2nC4`01@2NA4<0ZFQT0;>:Q02cRX@0WhIo0080WHb500D0UX^5
09^@RP2KT8X0VXn909^>R00209Z=Q`0409^@S02ISXX0VHj:09Z?R`80VI2;0P2KTX/209jESP0409fD
S@2QV9<0XIRC09nFT@80PWUd00D0G55=04Hh=@1UEe@0IEMD0963P00209nDT0<0X9F?00D0XiB?0:R@
SP2eSY40]HjA0<>:T0020=f=UP050<9QJP3:EUl0bUIO0=]OI`3=D5H00P37BU00102`>Cd0YS<f0:Hc
=P2P=3@20:To?`050;UCD@3DKV`0gGMe0=egM@3PNWP00P3TOW`01@3XPWh0jH>10>V3P@3RO7X0i7il
0080i7ak00@0ggMh0<EMGP35GEh0^Te@0P2oDE@01@2bADP0/DM90;9;CP2bBdh0YTA50080Yd]<00D0
[UIE0;9QH02bHF00]f]]0;YfM`020;IjN@040;:1O02WPGH0Yh5f09amJ@80UgmM00D0TWi<0:2@DP2Y
Ve@0ZI]D0;^_I@020=75O@050=[AT03Jdid0f]>M0<K1U`2b[Hd00P2PWXT0102MVHd0XIjI0:6NV@2P
W9d20:2KX@0509nLX`2NVj80W9VR09bIXP2JUj000P2OVJ<01@2OUj80]j^e0;N[]@2GQi40>BH/0080
@2X]00@0@2HU03XN6P0j7QX0UGY_0P3_eLH01@3;/9d0^Yj80:V9L02YRG00X7mP0080[XiX00D0]YEZ
0<NSL`37Xg<0e:mh0>:lOP020>[5O`040?;>P03bdW/0l]9k0?;FL`80l=Q/00D0kMQS0>cJGP3Zg5T0
j]aI0>[NF0020>CKDP050>CMD@3SgE40hmeA0=oIC`3Pf5400P3Hd4T0103JdT/0e<a30=C<@`3DcCh2
0=G?>`050=C?=`3EcSD0eLhg0=G>=`3Bc3P00P3:`cD01@35_ST0]Zha0;J^<@2UW2D0X9LR0080Rh8=
00@0WY@I0=?:B@3CbTT0j^5N0P3Zh6D01@3Sf6h0SX@[061I5@1PFAD0^kR30080/K:800@0[K2C0?Si
l@3hnO400?l03oooool000gooooo0`00o`00103KcLX0Le9=07=BC@24AD0209Lo?@050:Lj?@2^=c/0
^D150;U0A@2i@TP00P2]?T@01@2R?D<0/eaT0;=LI02fJG<0[6Qc0080UUeV00@0Tem[0:mmR@2_OHT0
]H>>0P2bP8/01@3<VZD0[7R40;QnRP2hOXX0_GV60080T3a;00D0WSU70;e7D`2mAe<0aTA>0<a5C002
0<e0B0040<dmAP3>@dX0cT=:0<M6BP80_Ta<00D0WTA30:UXI02cRX@0/hZ409n6O`0209f<Q@0509J;
Q@2KT8X0Vi2:09Z?R@2KSXP00P2JSHL0102KT8`0VHj:09V>RP2JSh/209V@R`80Vi:;0P2NUHh0102M
U8d0XIRC0:6HT`2OUY42089iM00505aAC@16>3D0IEMD06EGE02APh000P2OU9030:2ES`050:>DS`2X
T8h0]HjA0;F>T@33RY000P3MSIH01@32HFX0bUIO0<YFG`3KGfL0cE1F0080adY@00@0/3Tm0:Hc=P2V
<cH0X3@d0P2Y?cl01@2iDe40e6i/0=egM@3MMgD0h7Yh0080i7il00D0j89n0>V3P@3YPh40hWaj0>An
O0020>AlN`040=mgN035GEh0aEeN0;Y=D080_e5D00D0/TE80;57B@2bBdh0/T]>0:I4A@020:M;C005
0:iFE@2bHF00/V5P0;M[K@2jMWL00P2fNWT0102bPG`0Yh5f0:N1MP2LOFT209MoG@05099nC02PT580
ZI]D0:VKE02k[fD00P3AaGd01@3JdI00f]>M0=[CW@36`IL0/Zf=0080X9j900@0WIV=0:6NV@2QWYT0
X9bM0P2PVj401@2OW:<0WY^R09bIXP2LVJ80VYNP0080WiVS00D0WiNR0;N[]@2gZkD0UhNA03TV;002
040Z;@04040V9@0j7QX0>QhJ09EjK`80kmG600D0bk2M0;ZNR02YRG00ZHU`0:1oH0020:j>J0050;JE
JP37Xg<0aj=c0=B_N03R_7h00P3ZaGl0103bcX00l]9k0?;BN`3beW<20?3HK0050>gHH`3/fUh0j]aI
0>[LF@3ZgUP00P3Tfe801@3TgE40hmeA0>?MD@3OfDl0h=QA0080f=1900@0f]9;0=C<@`3Dc4<0e<dn
0P3Ecc/01@3DccL0eLhe0=G>=`3EcSL0d/`h0080b/<e00D0aKhi0;J^<@2f[S40YI`U0:2G8P0208^2
3@0409jD6@3CbTT0dlY90>[QGP80j^1U00D0hmQ^08j4:`1PFAD0H5TE0;^hP`020;6bR0040:f`T`3h
nO40n?Wa003o00oooooo000=ooooo`<00?l000@0jM_H07]LE`1kG5L0OdA00P2F@3l01@2W?Cl0[3Di
0;Y1AP2j@DH0]Sm50080]DA:00D0XCa20:eFGP2]EUh0^Fie09YMI00209QWK@040>>ka03]b]40kL[A
0>2ob080i/G>00D0lM;J0<f]^03V`/h0i/;>0:moS@0207`jB00508@]?@2bB5@0/TQD0<A:E@3:A4d0
0P3?@d`0103<?dL0bd990<]2B@36B4/20;M9BP0509i:B02bMG00[XV30:j9P`2QRX@00P2MSXL309Z?
R@0509bAR`2NTH/0WHn<09f?S02HSHT00P2KT8`01@2NThl0VXn;09Z?R`2HShP0W9><0080VY6:00@0
Vi:;09jESP2NUHh0WIB?0P2PUi801@2LThh0QGYf05eBCP1MDTh0Bd0n0080I5UE00D0RGij0:2ES`2P
UHl0ZINE0:b@S`020;N9S0040=>@U`3ENH@0eGV40;Q8E080bTeE00D0e4iE0=I=E03GD5H0ee1F0=1=
DP020<Q:C@040;a1A02a>S`0/CXl0:Hb<`<0Zc/j00@0_U1?0=1THP3@I680fFe[0P3PMWH01@3KLG40
fFm_0>AjNP3TNWX0j7in0080jgen00D0hg1c0>5ZKP3QJVh0dUUN0<M@E0020<MDE`040;m>D02cATT0
/dI90;18B@80ZDE700D0YDM80:18A`2SEE<0XeEC09AECP020;20LP050=>`VP2mYH<0_JF30;>NK`2m
[WD00P3>`hD0103MdiH0e/bG0=K<U`30]h`20:ZTQ00509nJQP2QWI80WIZE09fJU@2MVIX00P2MVj00
0`2LVJ00WibU09nLY@020:2JY080X9^R00@0WIRO09nJX@2OVZ40WiRP0P2ZX:T01@2cZ;00Bci702hO
9P0^7bH0:Q/N0080;b4Q00D0Bcdl0?7Sh03ahn00n>WT0?[Wh@020?OOf`040>gDc@3O`kL0gl>g0<R[
V@80]iN000D0[ha`0:IoGP2XPeT0Z8=I0;^EIP020<>PJ0050=FbLP3K^g00fk]`0>?4L@3Yc7000P3/
d6l0103^eFh0l]Y`0?;JL03`fVd30>oKJ`040>oMK`3bh780l^1b0?CTL`80iMIO00D0fm1D0=cBCP3L
dTh0fM130=S@?@020=gF@0040=SA>`3Fd3`0e]0l0=G@@080aKlc00D0_kTa0<S1?02k]Bd0^kD]0;be
:@020;J_80050<c6=03UgU80iMiB0>oWJ`3Rfg<00P1bJad0102[ZFh0/K>40;6cQ02Y[8l20?Sil@03
003o0?oooooooooo00gooooo000=ooooo`<00?l000@0k^?Q07iRGP1nHUh0ND8m0P2CA4001@2P?3h0
Yc@i0;Hm@P2f?D80^T580080]dA;00D0Z3m40:56C@2QATd0^Fab09eOI00208QGF`040??;d`3`d=D0
l=3E08m^M@80RV]a00D0`jF]0;nT[@3:Z[L0bZZg0:9iQ`020:M]O00509Q;F`2S@E00Xd5@0;a8E@37
B5<00P38@4X01039@4P0bTA;0<Y4B`32AdX20;=;BP0509I8A02gP7T0ZXN10:Z7P@2LR8400P2MSXT0
1@2NThl0VXn;09Z?R`2JSh/0W8j;0080Vhf:00@0V8f909ZAS02JTH`0VXn;0P2PUI401@2ES8L0Vi:=
09Z?R`2JSh/0Vi2<00<0W96=0P2KTXd01@2NUI00XiZE09^BS@2KTXd0QGag0080GU=?00D0C44m06QJ
E`1XFUL0TG]m0;2>S`020<6:T0040=b?U`35HF/0aF5[0<5<E@80cD]C00D0e4]B0=E8CP3JCU40fTiA
0=M<D@020=E=D@050=A;DP3>BDh0cTU>0=5>D`3;BTh00P2l?T40102e>C/0[SHg0:hf=`2^>3P20;<o
@0050<5AD03?Hf40f6aZ0=Q/JP3FJVP00P3JK6/01@3GIfH0fVQX0=YXJ03EHF@0cEYM0080cemN00@0
eVQW0=Q^KP3HKVh0df]Z0P39HF801@30FEX0`emO0;9IE@2bFED0TdY10080ZGAT00D0oM[60?;J`03b
f/00e/JT0=73X0020<boW@040;Z_T`2XWHL0Z9f709nFQ@80Y9^B00D0XYZG0:6KV`2TWZ00Y9jP0:2J
WP020::MX`050:2KXP2SWZD0XijU09jGW`2RVj<00P2RVj80102NUih0XIZQ0:6JX@2PVJ0209jGWP05
0;R_]01LDeP0:AhR02TN8P0]8b@00P0^92<01@0[9R80f=??0=SCc`3ak>H0k>CQ0080k^CR00@0l>KT
0?7Xh`3aj><0l^OQ0P3ci=d01@3]g=80hlo40=K0/P3F`;80`jfH0080/YZ200D0[I1b0:B3H02TPf00
Xh1F0:b4D`020;B9DP040<VMH03>XEh0cZ5N0>BeK`80k[mg00D0lLEj0?_BP`3ofXT0omZ90?oPR@02
0?oRQP050?WQO`3cgWD0lmie0>_JJ03Te5X00P3Qe580103KdD/0f=170=S@A`3CcD<20=S@B@050<k6
?`3@b3l0al0b0<O0<P3>b3H00P34_RX01@3;`c00iMi@0>GND03RfeT0m>j00080S8Dd00@0X9iQ0;:d
P`2b]8<0YJR90P3ino000`00o`3oooooooooo`0=ooooo`003Oooool3003o00040>kSh@1nHUh0OV9N
07U2?@80TdA000D0X3`n0:Ld>@2f?D80]Se20;Y1B0020;M4B`050:PoA02QATd0XDI=0;U/LP2MGf@0
0P28Ee/0103cbm<0l=3E0?3@e@2?KWD208Y[L@050<>U[@2oY:d0bZZg0<ZZ]`2RNHL00P2WKG`01@2H
Be/0Xd5@0:=1D02lB5D0adQC0080b41:00@0bD180<Y4B`3:A4/0`TM:0P2cBdX01@2FB4@0]h1i0:Z7
P@2ZQh40W8R10080WHj900D0WY>?09Z?R`2JSh/0VXn;09b>R`0209^=RP0409R=R@2JTH`0VY6<09Z?
R`80X9FA00D0UHb709^BS@2JSh/0VXn;09^@S00309bAS@80Vi:=00D0WYF@0:>JU@2KTXd0Vi:=08El
M`0205iCC`0504a1?@1XFUL0J5YG095kO@2`SXl00P31RY00103LSiL0aF5[0<EQJ`31C5D20<e;D`05
0=A;DP3EB4h0fTiA0=Y>D@3GC5400P3ECE401@3DBe80cTU>0<i9CP3ACU<0bdY>0080_3i100@0]CTk
0:hf=`2^=SL0[SPh0P2c?d001@31DE00cf=Q0=Q/JP3HK6X0eVYX0080fVa[00D0efMV0=YXJ03JJ6P0
eF5T0<eJG@020<mOGP040=IXI`3HKVh0f6i^0==[JP80bF5R00D0`5UJ0<=OG`2bFED0/UUE09=:@@02
0:UdI0050?gJaP3bf/00l][00=K6Y03A`j000P3<_id0102j[i<0Z9f70:RMQ`2OUXD20:BKTP050::J
U`2QVi/0Y9jP0:BNX02PVYh00P2RWJ<01@2PVj80XijU0:>NY@2NUil0XY^S0080XY^R00@0WYNN0:6J
X@2QVZ40X9VP0P2NUih01@2h[k@0G5=H02TN8P0Y7R80;B<T0080;R@S00D0:bHR0=SCc`3Hdll0lNcV
0>cTh@020>kThP040?3Vi03aj><0lNSS0?;Wh@80lnCM00D0kMcB0>??a03F`;80e/2b0<>]V0020;:J
PP050:f@LP2TPf00Y8=P0:>0EP2/Q5<00P2dRE801039WF00cZ5N0<jQGP3T]Fl20>joM`050?75NP3k
dX<0omZ90?oJR@3oh8T00P3ohXH01@3ihGl0lmie0??NM@3[fVP0i=AJ0080hMAB00@0fm5;0=S@A`3H
d4L0dle30P3Hd4T01@3>aSl0d<Po0<O0<P37`380c/Pf0080a;hZ00D0bl<`0>GND03UgU00h]]I0?C^
P00208b5=0040:2NH@2b]8<0/[B30:FXR@80nO_`00<00?l0ooooooooool03Oooool000gooooo1000
o`020;RSWP0507=8@P21@3X0PD0j09<j?02P=c/00P2c@4D0102g@4H0^TE;0;Y5B`2dAd`20:51A@05
0;5QI02VIFT0P4iA081>D@3Q^;`00P3ifM`01@2SPhH0=aXN03LJ7P20IFX0ekc50080Wh6=00@0_9JS
0>6/_03Q[;`0TTiM0P2E?Dd01@2]A5<0_dMC0<A5D034AE00ad=>0080`dA;00D0_d]<0:a8AP2/B4H0
U4]50;N5OP020:J8P00409f:Q02JRhH0VX^609Z?R`80Vi:=00D0VY2>09^@SP2ISX`0VHj<09Z?R`02
09V@R`<0Vi2<00D0VI2;09bCSP2LTHd0W96=09Z?R`0309bAS@80VY6:00D0VI2909nHTP2LUHl0W9F?
09jET00209fDS`0508j3P@1_Gel0KemO06Q>D@1iD5@00P2aLWX0103EOhP0^4iH0;Q>F039D5L20<Y<
C`050<i:B03BC4T0ddi90==>B@3CC4T00P3EBdT01@3DBTX0ede=0=M=C@3DBD`0eTi@0080eDeA00@0
dDa?0<a:C03<BT`0_d520P2m?d801@2c>3X0[cTi0:`h>@2/>3T0/3`m0080`Ti?00D0eF5R0=5OG`3A
Gel0dUiQ0=1NGP020=1RH@040=1THP3LLg00g7=`0>R0O`80k8B300D0ggMd0<aTH@2hFE<0^5UC0;9T
FP0209UND0050>o:^03/e/40k=K10<FdX02ZWH`00P2PU8H0102UVi80YYfH0:JMV02QVIL20:NNX@05
0::IWP2RW:00XifQ0:>MX@2QVil00P2TWZ801@2QW:80XIZQ0:6JX@2OV:00XINO0080WYRL00@0WINK
09jHW02NV9`0W9JJ0P2ITiL01@2_ZJd0Lfea02`V:00/9RP0=Rd^0080:RDR00D081dH0<G4_`35a;l0
l_7/0>KUh@050>[Vi@050>cWi03]iN<0kNGS0>kThP3ai^@00P3bin<0103ei^40mnKN0?OVgP3agM82
0>[Ca@050>74]03@[IT0_IQn0;fHOP2dRf/00P2PM5401@2EICl0YgI=0:MfC@2VMDX0/H=B0080aiaW
00@0eJ]a0>BlOP3T_7h0kLN60P3fdHX01@3heH@0m=Ek0?KHMP3ff7H0kmM[0080j==P00D0jMIN0>_K
H@3[ff40hMAB0=_BB@020<c3=P040=gEAP3@b3T0d<Pi0=;6?080hMMD00D0f]1G0?;[P@2ITT40VI91
08f<B`020;>eP`040:BXQ`3hn^l0n?[_003o00oooooo000=ooooo`@00?l00P3Wg=P01@1iHUX0OU=:
07iCBP2@C4/0TCLi0080/4=900@0_DQ@0;a5B`2lAD/0_4U>0P2X@D@01@2XDU<0/Vi_08eGE`2=EeL0
XGMh0080m]CC00D0ilW906M=CP1WCDh0YXfA0?WNi@020:R7TP040;J<V02WLh00Yg>007XjBP80^Val
00D0Z4aK0:a3D@2kAe@0^dMD0<A8D`020<58C`050;i=C`2XBDD0Z4U509QCC02jRhD00P2UQX40102M
RXH0VX^809Z;R02ISX`209Z@SP0409^AS`2LTHl0VXn;09Z?R`<0Vi2<00<0W96?09^@SP2KT8h00P2J
Sh/209jCS`0409R=R@2MTX`0WI:<09nDSP80Vi:;00D0W9><09jET02KTXd0Vi:=09fETP0209jFT`05
0:FKV@2TU9@0Y9BD0::5Q`2<GF<00P2aJW001031IVd0^4U@0;Q9D038DE<20<1;@P050;U5=P2b@Bl0
_d`i0;m<>@3<Dd800P3@DT<01@3BD4<0dD]20=5;@P3DBTL0eTY90080eDU:00@0ede=0=A<C03DC4`0
eTi>0P3FCU001@3>B4T0b4I80;ln@P2o?T80_ci30080[S0d00D0]c`o0;<k?@2c>cd0^4530<5?C`02
0<]NF`040<iUH@3DK6T0e6aY0=I`K080eFm[00D0g7Ib0=1ZIP2jFeD0^U]E0<YjL@020:i^I0050<FK
S`2jWY<0^YjC0:JCS02UV9800P2NU980102RVIX0X9ZJ0:2JVP2OVI/20:FOX`80WiVM0P2PVYh0102M
V9`0WiZN09nJWP2PVYh209fGV`0509bEW02LUYX0ViFI09^EV@2LUYX00P2NVIl01@2LUid0VIBJ09VD
VP2[YZX0Q7n30080=C4b00@0;RPX02PT8@0X92405QD@0P2c/Zd01@3elNh0j>CQ0>[UhP3ZiN80k>CR
0080k^?Q00D0l>;O0?;Sh03bhn00lnCO0?;Ug`020?3Ug`<0lNKP00D0lNSQ0?7Vh03ai^00lnSR0?GX
h0020?KUg@040?3NdP3ZelT0j]O90=g6^080d;>S00D0_Yf<0:B1KP2>J5<0SVQC08]OAP02091QA@05
09iYBP2[Le00Zg=@0<B;H03>U6800P3KXfP0103U/6`0j;MX0>RgJ03/`fT20>_;I0050>?<F03Se5<0
bkdh0<^m>03Jc4D00P3PcTh01@3MaeL0VXLP09Z7802MT2X0n_6D0080ZZ=C00@0Q8=00;NjQ@2g^XD0
XZJ50P3ino000`00o`3oooooooooo`0=ooooo`003Oooool6003o000509bBR@1SB3l0HdPo09YYI02R
F5T00P2N?T80102hATh0`4U?0<19C`2jAD/20;9:B`050:=7B02]Hf@0XVIV0:9VIP23DE000P38WYl0
1@3B[jd0aZJW0<JVY`2nX:80hL760080X7^300@0`iRR0:McO`2WLgl0RDaK0P2<AED01@3MRYX0VSY8
0:XnB`2Z?T/0/ce90080_4E;00D0_U1A0:15@02PAD00XEiF0:j1N`0209AgL`0409^8Q02HRXL0V8Z7
09R=R`80V8j=00D0V8j<09^@S02HSHT0V8f909^@S00209fBSP0509bAS`2KT8`0Vi2<09V>RP2JSh/0
0P2LTHd0102GS8P0WiB>09nDSP2LTH/209^BR`0509fDS@2LThh0W9>>09bCSP2NU9800P2LTY001@2N
Ti40YI6B0:FATP2`SI40`X^A0080f8RA00@0]e=K0<5>D`31CU<0ae5?0P2gBC`01@2/B300]E/i09Q0
602H@1P0VSdD0080/4dV00D0^Dh/0<ID>@36E3T0be8o0<mA@P020<m=@0040=9=A03ED4L0eE170==<
AP80eDa600D0f4e:0==9B@3CBdd0dd]=0=A<D0020=9;D@050<]8C@32@DH0`T560;m1A@2d>C/00P2b
?3`00`2[>CP0aeMF0<MGEP030<mQH0050=Q/JP3EJFH0`f1K0<=PF`2eH5T00P2LF4l01@2@HET0[Hj9
0:f>R@2UTI00XiNG0080X9FI00@0X9NL0:2JWP2PVYh0ViJJ0P2ITiL01@2NV9`0W9JH09^EU`2KUIL0
ViJJ0080WYVM00D0WYRL09bFVP2LUYX0WiRO09nIW@0209jGWP0409^FW02JUI/0VYFK09fHW`80V9JK
00D0YJ>X09RCV@0l=c/0?3Lk02XV9`0202HR8@0501@@3@2TX9d0Y:2M0?KakP3]hn800P3_hn<0103a
hN40m>7M0?CQg@3hh=`20>_Bc@050>cCcP3fh]/0m^?L0?KSg03gi]h00P3diml01@3^in40jnSS0>_X
h`3/j>L0jnWZ0080k^[Y00@0l>_X0?;Zj03bj^P0mN[V0P3fin@01@3jin<0nN7M0?;Ed@3beM40jlS2
0080ejnW00D0_i280;1oL@2`Og40XFaJ08UA>P0208A8;00407Hl5P21BAH0PDTF08]J5`80_IQ000D0
g/=H0>??EP3?_Cd0ckdm0=[6B`020>K@H0050:jD=@1I@@00FD4009B39`3kl9H00P2g/5l0101nOSP0
/kIo0;>fO`2RYX<20?Sjk@03003o0?oooooooooo00gooooo000=ooooo`H00?l000D0W9:906=8?`1S
B3l0VVUT0:9HF@0209hn@P040;Q6CP30BDl0`4U?0;Y5B`80/TY;00D0XdM80:eSI02RIVH0XVIV08=A
D0020<RNW`050=:_[@36YZL0aZJW0;jPXP3Q`LH00P2PNh<01033V:80Yg=o0:McO`29C5/208a5E@05
0=f:VP2J>TP0ZSi;0:XnB`2c?DT00P2lAD/01@2nD540X4E00:15@02QGUH0[X5k0080U7Mc00@0VhR4
09R:Q`2HRXL0V8f;0P2HSXd01@2HSX`0Vi2<09R=R@2HSHT0Vi2<0080WI:>00D0W96?09^@S02KT8`0
VHj:09Z?R`0209bAS@0409N<R02OU8h0WiB>09bAR`80Vi:;00D0WIB=09bCSP2LThh0W9>>09jDTP02
09bBT00509jCT@2UTI80YI6B0;2=T@32Ri400P3HR940102gDe/0`DiC0<5>D`37DDl20;M9?0050:a8
<02eFcT0V40H09Q0602J?A@00P2`CBH01@2iCR`0aU@i0<ID>@3;DSl0ce520080cde000@0dTe40=E@
A`3ED4L0dda60P3EC4H01@3HCDX0ddU90==;C@3CBdd0e4a@0080dT]A00D0bdQ=0<91AP32@DH0_d55
0;@i>`020;8l?0030:/i>037EeH0aeMF00<0cf5P00D0f6aZ0=EYIP33H5/0`f1K0;EPF@0209aHC`05
091QF@2]SXT0[Hj90:FAT02SUiL00P2PUIT0102PUi`0X9ZN0:2JWP2KUYX209VCU`0509jHW02LUYP0
ViFG09^EU`2KUYX00P2NVId01@2NV9`0W9JJ09bFVP2OV9l0WiVM0080WYNN00@0ViJL09ZEV`2JUI/0
WIRO0P2HUY/01@2UXjP0V9>I03`g>`0l=c/0:RHW00809R8Q00D0510=0:BPW@2TX9d0m_7^0>gShP02
0>oSh`040?7Qh@3dhMd0m>7M0?SPg080jm;=00D0k=?>0?KRf`3fhm`0m^?L0?OVgP020?CWg`050>kW
h@3[j><0jnSS0>cXi`3[jNX00P3^j^T0103`jnP0l^[X0?;Zj03ej^H20?KWi0050?[Wh`3ihMd0l]GA
0?;Ed@3[b<800P3G[jL01@2oT8P0/7ma0;1oL@2QK5X0RE4j0080Q4P/00@0MS`F08595P21BAH0ReXG
0P2mV4001@3N`eP0hlmF0<nm?@3?_Cd0f/I;0080i]1P00D0[Y@e05U1001I@@00U8<W0?_`UP020;N`
G`0407in>02c]Wl0/kIo0::VP`80n?[]00<00?l0ooooooooool03Oooool000gooooo1P00o`001@3C
c/P0FD]205U;@P1dDd`0dibI0080W4M:00@0/4Q?0;]8C`2kB4l0^DI;0P2eBdd01@2YBD/0Xe5E0:mY
J`2_JF/0OT110080F20Q00D0S5UH0>fo_`3]_kl0jl720=N_/00207Y=DP040;:3R@3GYJh0ejF^09aW
L@80QdQC00D0iYZW0:mCH02iCe/0^DmK0:0[=0020;<l@0050;]?C@2UBd<0YD]30:5NEP2iSH@00P1^
DD/0101`GeP0U8F209B5PP2ISX`209Z?S@0509R=R`2KT8`0Vhj809^>R02LShT00P2NTH/01@2MSh`0
XI>@0:6CT02HSHT0Vi2:0080WI:<00@0Vi2:09^BR`2KTX/0VI290P2MTXh01@2NThl0WI:>09bAS@2L
THd0WiBB0080WI:@00D0WHn>0:ZAU02ZTI@0/HJ=0<f>U`020=EkQ`040;a>F@38Ce@0b4mD0<UBCP80
[dPi00D0WdX[0?RfPP3W/W00ik9`0<F@A0020:5U700508e9202CAPh0TdH>0:19702aDB/00P2kDS80
1036E3T0be<j0<]C>P3<CcT20==?@0050=9:?P3DBD80eT]80=I;B03EBDX00P3EBD`01@3HBe40eDYA
0=E:D@3CB4l0cdI=0080dDY@00@0ad970<8oA@32?dD0_Ca10P2i?Cl01@2Z;c40[3Hf0:m3@@2_@d40
Vd0k0080RD0j00D0SEYF0;:@SP2bT8h0XXj?0:6EU`020:2EV`040:2FWP2LUYX0W9JJ0:2JWP80VYBF
00D0WINI09bGV`2HTiL0V9>G09^FW00209fHWP0509JAU`2KUY`0ViJL09^FW@2KUY`00P2NVJ00102K
UYd0WINQ09fGX@2NVj@209ZGWP050:^Y[P2GTYP0;RP/02hX;00/9RP00P0Z92H01@0F4100XIRI0:6H
V@3ll?00lN7R0080m=kP00@0nMoP0?oMg03ogM`0b::O0P1dBdL01@2hTHX0om_C0>W8_`3Yb;l0]iV?
0080_:>L00D0l^?L0>kVh`3^i^<0kNWX0>cZj`020>OVi0040>STh@3ZiN80j^GR0>oXhP80m>_V00<0
m>WS0?7Vh03biMl00P3biMl20?CUh0050?WVhP3hhmh0n>?N0?;Ie03]c/T00P3P^[401038WH`0cJ64
0<fQQ01lE2<20;RDBP050>gAKP3UcUX0eL580=G1B03Rbe/00P2TRbL01@1lHPh0Fd8005]2002/W3d0
n>j=0080_[UN00@0O7da0;2eN`2`]G/0WZB00P3innh00`00o`3oooooooooo`0=ooooo`003Oooool6
003o00050?Gfl@1oN700OgQ`05E2>`3AZZ<00P2GDe80102MA4P0/dY?0;=:C`2hBDl20;=9B`050;=?
D@2QB4`0Td9809=2B02AADT00P1]9BT01@2=BDX0b8R80<R8R03UZJT0`8F70080JB/^00@0SE1E0>N/
/P3W[;80j:^b0P3FUId01@2XFfD0Sc<n0:4g@@2Q=d40XRXc0080]Ci200D0_U5>0:=9@@2SBD40Xf1H
0;jBR@020:23O@04079OF@1JBdP0FT]807MYJ080U8J500<0W96?09^=RP2LShT00P2LShT20:2CS@<0
Wi6>00D0WI:<09jCS@2NThd0WY>=09nDSP0209ZARP0509fDS@2MTXh0WI:>09bAS@2MTXh00P2LTHd0
102NTi40Wi6@09nAT02UTi<20:V;S@050;V8SP3GSiX0b6=a0<QSL@2oBED00P3>CE801@3:CD/0`eM:
0<=GBP1l9`P0cYEN0080nm6500@0l<ea0?7?K@3acfd0hkYN0P3;VdL01@2aNBh0Te8>09E;302EB``0
VdTA0080ZThK00D0]E0T0<=G<@33Ec40aE8c0<aB>`020=5??`040<m;?`3CBT@0ddY40=M9B080g4]@
00D0fDQ?0=M6C@3JBU<0fTYC0=I6C`020=U9DP050=95C@3AB4l0dDQ?0<a7BP32A4L00P2jATH0102^
C4T0TTA00994@02AFUL20;JCT@050:FATP2PUIT0WYFJ09jEVP2NUih00P2JU9P01@2LUYX0ViFI09^E
V@2JUIT0WYVM0080ViJL00@0W9NM09RCV@2HTiT0W9NN0P2NVJ001@2LUih0WIRO09nJX@2OVZ40WiVS
0080VIJO00D0W9VR0:2MY02PWJ@0][6g096:T@0202TS9`0402`V:00^9BP0;RDX01P?4P80Wi>E00D0
o>c]0??Jg@3kgMd0nmgM0?gGeP020;V=S00507];A`2bPG`0/X5l0>fn^02mT8X00P1`B400101D;bH0
QFQP08EXH03fiMh20??Zi@050?3ZjP3Cclh0Sh^:08n;RP1aKFX00P1RGEX01@1fLFd0ViB>09^DSP3C
c<H0kn[V0080k>OS00<0j^GR0>cXi@3/j>D00`3/in@01@3`j>H0m>CU0?SNg`3hg]l0omkI0080on;B
00D0QV8n0;fLF@2mW5T0lmIh0>K?F`020>G@F@040;fX?`1aFP00LEX007UQ2@80Q6lD00D0hM=Z0>_S
N03;afH0blMV07Uk:0020:^aM@0409bRO03innh0nO_^003o00oooooo000=ooooo`H00?l000D0mOKa
07mhL01oN700ED8k0=6ZX`0209MCDP0409e4B02cBTl0/dY?0;Q9C`80/dU;00D0/dmA0:58C02C@TP0
Td980955B@0206dU:@0508e9BP38R8P0b8R80>FYZ@30QHL00P1Y:bh0102=D5D0ijbb0>N//P3XZk82
0=JEW@050:QKI@2?<ch0XCM10:4g@@2R:S<00P2e?T801@2nDDh0XdU10:=9@@2SH5P0_Y:90080X8=m
00@0LUmI05Y;B01JBdP0MfUX0P2DQXD00`2LTHl0Vhf:09b?R@0209b?R@80X9>=0`2OTHh01@2MTX`0
WY>=09jCS@2NThd0WiB>0080VY6:00D0WIB=09fBSP2MTXh0W96=09fBSP0209bAS@0409jCT@2OTI00
Wi6@0:FCT`80ZH^=00D0^HR>0=N?VP38Hg40b6=a0;m9E@020<i=DP050<Y=B`33EdX0`eM:07`W203>
UEh00P3kdHD0103`cG40lLm]0?7?K@3S^Uh20<^KA`050;5i;P2CDPh0UD/<09E;302KBA400P2ZCQ/0
1@2eD2@0`eLa0<=G<@35DS<0c58k0080dDlo00@0cd/o0==:A03CBT@0edU80P3LBe001@3IB4l0edI=
0=Y:D`3JBU<0eTI?0080fDUB00D0dTE=0=58C`3AB4l0c4M:0<94A`020;Y6AP040:i<B@2BA400TTA0
095JE`80]Y>A00D0YI6B0:2EV@2NUIX0WYFJ09jGWP0209ZDV00509bFVP2KUIT0ViFI09ZEV@2NVId0
0P2KUY`0102LUid0V9>I09RCV@2LUih209jIX00509bGWP2MV9l0WiZQ09nJX@2OVJ<00P2IUYl01@2L
VJ80X9fT0:2MY02f/KL0THZA0080:B<W00@0;2HX02hU:00^9BP060lB0P2OTiD01@3lk>d0lm[M0?_M
g@3kgMd0oMOF0080^Hf<00D0Nd]70;:1O02bPG`0kKjh0;f@RP020718@00405@_9P25J600QFQP0?KU
gP80ln[U00D0l>[Z0=??cP2?RhX0Sh^:075]JP02069MFP0507IaK@2KU8h0ViB>0=?<aP3_j^H00P3/
in<00`3ZiN80k>SU0>cXi@030>cWi0050?3XiP3di>D0n=kO0?SNg`3og]T00P3oh]801@26HSh0_IaI
0;fLF@3ceWP0i/mK0080iM1I00@0_JPo075J001aFP00NF490P24Ka@01@3QdfX0jn=h0<_7IP3;afH0
NG/X0080Zk5e00@0W:9l0?WkkP3innh00?l03oooool000gooooo1`00o`020;jm^00504e5>P2NR7d0
REYD08UJE024?Sh00P2L@T@01@2/ADP0[4A50:a4A@2aBTd0Y4A80080V3]300@0USa509a2B`2L@T/0
Rc8h0P1k8RH01@1l9RT0NR@W08DZ;`25:Rl0NB<V0080XE5D00D0fX^@0;QYKP2hJFh0Qc8i08hZ=002
0;Y;E0040<58C`33B4d0`dQ=0;i<C080Z4U500D0WUMA0;j=QP2VQh80YXN20:B?S00208MeL`05061B
D@1A@d80DD=207IXI`2FQh@00P2OT8d0102MSh`0W8j;09b>R`2NT8d209nASP050:>HU02NThl0W96=
09bAS@2JSh/00P2KTXd01@2JTH`0W96=09bAS@2JSh/0WI:>0080W96=00@0WY2?0:6AT@2QTI40YI2?
0P2]RHd01@31R8l0fXZE0;iBG`2nDUl0b4YF0080dDYA00D0cDQ90<iGC`3>Edl0U3@L0:5M;P020?o?
S0040>o<L03Zcf@0j/mT0>oHJ080lmaZ00D0lMMY0=fnE03H]E40f;EA0;jC=@020:9`6`05099G2@2B
C0L0TT`709U93P2[Cb000P2cBb@01035DS<0d58l0=1B?03ECD420=Y<B0050=M6B@3KB4h0fDI>0=U6
CP3IAU000P3JA4l30=Y7C`050=I7B`3DC500b4i=0<Q>C@2oEe@00P2TDdl01@2GH5d0]I6A0;FAT@2V
TY@0X9FI0080ViFI00@0WiRO09bEW02LUI`0W9FL0`2LUid00`2OVZ00ViRO09^HW`0309VFW@0509nI
X`2MUj40WINQ09ZGWP2KV9l00P2MVZ<0102PWJH0W9VR09bIXP2LVJ020:NRZ@050;F^]@25Oh40:B0S
02TP8`0d:bh00P0b9b/01@0L4180XI6D0:6AU03ji^P0n=_M0080n<o=00@0ZGQd091MF@2@GET0lkjh
0P3Q[ZX01@2SM6h0N4e60:5jL`2QNW<0ck6W0080l]_C00D0nncW0>GKf@3UfmT0NW9`06mWI@0209RC
S`0409ZET@29Q840RHB107MbK`80AT4n00D0EU5>0:RPWP3[i^<0jnKS0>SSh0020<g8a0050=SEd03U
h]d0iN;M0>SSh03]hn800P3ehN80103jg]/0on7F0?oQeP1iF3L20;VJF@050>gCM03Ud5T0kMeS0>gM
H`2PTBX00P1RE0001@2CQAP0dlMA0=?7D@3VgV40i=mW0080em9Z00@0OglY0:Z_K`2Z[fl0UYYe0P3h
n^d00`00o`3oooooooooo`0=ooooo`003Oooool7003o0080l?7/00D0RHIm06EKD@1ZCdH0JTm607Y;
A@02095=C00509M6A@2K@3l0Vd0o09Ph>@2O?3l00P2H=CX0102H<c/0_UIO0;iFG`2X?dH20:@i?`05
09LZ<02D9bd0YSLn0:Hg?P2X>d400P2M=SX01@2P@480QRL]08HW;@3BKWH0XcQ00080/Ca400@0aTUA
0<I7CP36Adh0_DU<0P2/B4P01@2OE540_HR40:F2OP2UPWh0WhZ50080Xi6?00D0VXb;07IXI`1fJ6L0
Cd5005A6A@0207maKP0409V;R02QTi00XI>@0:6CT080Wi6>00@0WiB@0:6FTP2NThl0WY>?0`2KTXd0
1@2HShX0WY>?09jCS`2KT8`0WI:>0080W96=00@0WY2?0:RFUP2XUYH0Zi6B0P2cRXh01@38RI80eGn:
0;E5D@2eAE40c4YF0080dTM>00D0ddQ;0<m@BP3?D4X0/d@c098g60020>:JJ0040?FmL`3fbW40m/Ya
0??@JP80mMMY00D0k]AU0>cEH`3cg6`0lma/0??IJP020>oCJ0050>G4G@3DZDX0e:U:0<BA>02aLRD0
0P2OD@l0102ZC1P0`58]0<1B;@3ADc`20=E;@0050=E5A03HATT0g4I?0=a6C`3I@dh00P3F?dP01@3N
Ae00gDI=0=e6C@3HAD/0dTI90080bTa=00@0^e9?0:ACC`2TDdl0UEiK0P2cTI001@2VTY@0XYNK09fG
V`2MUi/0XijT0080X9VP00D0XIZQ09nJX@2OVZ40WYVP09fJX@0209bIX00409fJX@2IUYd0VIJM0:2J
Y080W9JP00D0W9VR09nLX`2QWZL0XIjW09nLX`0209fJX@050:JQY`2UWZD0YIjU0;F_/`1dJfh00P0V
7Ah0100d:R/0<bLY03<W:@0S4a@20;NTYP050?oZk03SaLD0PeMD08=GE01M:RH00P2ZMFl01@3@ViD0
`Xf90<:=R@3KZ:@0l/>m0080mLc600@0mmWA0?_Tg03ki=`0o_7[0P2f[:X01@0K4@l0R7il0?O`jP3g
l>X0lncV0080m>cY00D0kn[W0=oJe`3Of]L0ThZ;03lf=`020;2XYP040<6i]`2:QH40RXF108N2OP80
SX^600D0QX9o0;R`[P3jinT0n^OY0?KNgP020?kRe`0507aM@02gUeX0]iMJ0?7FN`3TdE/00P3[h680
1027N`/0R7h;08Qn2`3KdU420=cFC0050=cICP3Wi6<0f]Q[0=[HJ`21PB/00P2VZf/0102AUVh0n?[]
0?Sjk@00o`0?ooooo`003Oooool7003o0080l?7/00D0RHIm06EKD@1ZCdH0JTm607Y;A@02095=C005
09M6A@2K@3l0Vd0o09Ph>@2O?3l00P2H=CX0102H<c/0_UIO0;iFG`2X?dH20:@i?`0509LZ<02D9bd0
YSLn0:Hg?P2X>d400P2M=SX01@2P@480QRL]08HW;@3BKWH0XcQ00080/Ca400@0aTUA0<I7CP36Adh0
_DU<0P2/B4P01@2OE540_HR40:F2OP2UPWh0WhZ50080Xi6?00D0VXb;07IXI`1fJ6L0Cd5005A6A@02
07maKP0409V;R02QTi00XI>@0:6CT080Wi6>00@0WiB@0:6FTP2NThl0WY>?0`2KTXd01@2HShX0WY>?
09jCS`2KT8`0WI:>0080W96=00@0WY2?0:RFUP2XUYH0Zi6B0P2cRXh01@38RI80eGn:0;E5D@2eAE40
c4YF0080dTM>00D0ddQ;0<m@BP3?D4X0/d@c098g60020>:JJ0040?FmL`3fbW40m/Ya0??@JP80mMMY
00D0k]AU0>cEH`3cg6`0lma/0??IJP020>oCJ0050>G4G@3DZDX0e:U:0<BA>02aLRD00P2OD@l0102Z
C1P0`58]0<1B;@3ADc`20=E;@0050=E5A03HATT0g4I?0=a6C`3I@dh00P3F?dP01@3NAe00gDI=0=e6
C@3HAD/0dTI90080bTa=00@0^e9?0:ACC`2TDdl0UEiK0P2cTI001@2VTY@0XYNK09fGV`2MUi/0XijT
0080X9VP00D0XIZQ09nJX@2OVZ40WYVP09fJX@0209bIX00409fJX@2IUYd0VIJM0:2JY080W9JP00D0
W9VR09nLX`2QWZL0XIjW09nLX`0209fJX@050:JQY`2UWZD0YIjU0;F_/`1dJfh00P0V7Ah0100d:R/0
<bLY03<W:@0S4a@20;NTYP050?oZk03SaLD0PeMD08=GE01M:RH00P2ZMFl01@3@ViD0`Xf90<:=R@3K
Z:@0l/>m0080mLc600@0mmWA0?_Tg03ki=`0o_7[0P2f[:X01@0K4@l0R7il0?O`jP3gl>X0lncV0080
m>cY00D0kn[W0=oJe`3Of]L0ThZ;03lf=`020;2XYP040<6i]`2:QH40RXF108N2OP80SX^600D0QX9o
0;R`[P3jinT0n^OY0?KNgP020?kRe`0507aM@02gUeX0]iMJ0?7FN`3TdE/00P3[h6801027N`/0R7h;
08Qn2`3KdU420=cFC0050=cICP3Wi6<0f]Q[0=[HJ`21PB/00P2VZf/0102AUVh0n?[]0?Sjk@00o`0?
ooooo`003Oooool9003o00050>k]j@36`k`0UH^209F;PP1gHeX00P1dCdT01@1nBD<0TDi8095>B02N
CDX0WD910080W3Dh00@0WC0e0:hk@P2^>d80/CY00P2l@dX01@2m@DT0_D180<93CP32@dh0`TA?0080
`4M>00D0`TeC0;4mAP2a?DH0`DeF09`T;@020;8e?@040<U5D03:B580bTQB0<58C`80/dY>00D0WDa;
0<24P`2YPGl0ZH5o09j6PP0209j?RP0509^@S02NThl0WY>?09>8QP1/HEl00P1;?C`0101IBdX0QGMf
08EgMP2HSHT209nDT00509jCS@2OU8h0WIB=09fDS@2KTX/00P2MU8d01@2ITXX0WIB?09fDS`2KTXd0
W9>>0080WY>?00@0WY2?0:FCT`2UTi<0[i:D0P2aQ8T01@3BSiP0b6ih0;Y8DP2jB580d4eE0080dDI=
00D0eTM;0=A:B03DBTP0d4a70;<i;P020:<d80040:a:9`38LT40b7910>RNH@80n[ac00D0oLUe0?cA
L`3ge6h0mmA^0?;DIP020>gDH0050>_EG@3^f5h0k]QN0?3FG@3`ceh00P3c`f40103QWe<0X4HA0:16
4@3:F3H20=A??P050=E6@P3LAd/0fTM?0=Y7C`3IATh00P3F@4T01@3JA4d0fTE;0=Y5B`3EA4T0e4U>
0080bDe=00@0_EEB09m@B`2OD4/0UV=O0P2bTi401@2UTi<0Y9VM0:2JWP2PVYh0XY^R0080WYNN00D0
WiRO09jIW`2NVIl0WI^P09fJX@0209bIX00409fJX`2JUj00VYNP09nLY`80WY^T00<0X9ZT0:>MY`2T
WjH00P2TWjH20:>NY@050:6LXP2UWZD0YIjU0;6[[`1TFeh00P0[8B00100a9BD0;1hM02`N7@0`7Qh2
0=c8a`050?o]jP35ZJH0[HN40:f7Q03J[Z/00P3Y_;T01@39V9@0[WAc0:idL`2dN7L0SUMD0080NDQ3
00@0RfUP0:nFS`2_UXl0n^_T0P3VgMP01@2j[j/0gmC@0=C9``3DbL<0_kJ_0080b;nh00D0h=WC0?og
m03omo@0d<S6020F5@0208n5Q0040:>IV03<`/40c<;108MoO@80Y9nL00D0b/C40<g3a03gi>P0mnCX
0?GMg@020?oSf`05095cE`2]SUL0[HiG0?;HP`3Qcel00P3OeE80102VWQT0c/Lk0<k7>`3Fd3X20=SE
?0050=cJA`3RhU`0g]i`0=kNL01mOb/00P2OYFL0102:T6X0n?[]0?Sjk@00o`0?ooooo`003Oooool;
003o0080nOSc00@0hmcD0;JUWP2fYIh0SG1Z0P21EU001@2@EU80U4Y70:5;BP2QBdX0[D]<0080Zd55
00D0ZcPm0;@k@02d>d00_D160;lmA@020<Q4C`040<U3CP3:AU40bTIA0<e;E@80a4E>00D0_Sm80;Hd
?P33?dX0`cm:0<]3C`020<]7DP050<I9D@2iBdh0^D]>09m5A@2fLW400P2bQH80102NPWh0X8n80:2?
R02GS8H209Z?R`0509bAS@2PUI<0SH6108f1P@1WFEP00P1<@Cl01@1OE500Q7Ue08AiM@2MTXh0WiB>
0080XIJ@00@0WIB=09bCS02LTh`0VY>;0P2MU8l01@2KTXd0W9>>0:6FTP2QUY80WHn>0080Uh:100D0
[hnB0;J5R`2fQH/0eXjI0;iQJ`020<1<E@040<m<DP3DAdd0e4M=0=A3B080e4E700D0d4A30=E;B@39
AD00bDE00;Lo;`020:Hj800509Xi5P2MBAX0WDTJ0;A];`3BU4/00P3W/el0103dbF/0lm=/0??CK03Z
del20>?ED0050>CGB`3[fE<0lMAL0?7DG03odGD00P2/IR401@2iCbL0dE<m0=5C?@3HBd80fDM80080
fTM=00@0edA<0=M1BP3G@DX0ed5:0P3IA4X01@3GAT/0cdA90<Y>D03:CU00_EME0080V4Y600D0W6]W
0;>ET`2cUI<0Xi>D0:>JW@020:6JX@040:BMY02PVJ00X9VP0:6JX@80X9^Q00D0X9jS09jKXP2MVZ<0
WIZS09bIXP0209bIY00509fJY@2JUj80VYNR09^EX@2HTY`00P2DSYP0102=R8l0QX6808J1R01hLgT2
06eWJ`0507afNP1<@dH0;B4Q02dQ8@0f9RH00P0/61L01@1@>3H0l]SG0?;He`3kh]h0n]gI0080k/c:
00@0^YNE0:9jNP2RNWX0iKNg0P3RZZ/01@3;Shl0cI>A0<BDT034U900`J2I0080NfMP00D0l>GO0=K?
b@3FclT0UX^708QmN@0206aSG00406QOF01@BD<0D4U304i7@@80QGej00D0YIfJ08EkNP37_K`0akfl
09B:R@020:RNW@050:VQW`3CcLd0dlg=0>SRi03`iNT00P3`gnD0103bg=h0onGN0?oUgP2cU7l209=c
A0050?CHSP3PcFH0g=5C0=cAD`30^Bd00P3QfdD01@3@c2d0eM<c0=GC<`3NgDD0h>1J0080h^5g00@0
KG4M08jDEP2>U5H0S99/0P3hn^d00`00o`3oooooooooo`0=ooooo`003Oooool@003o00050?K[i`3B
`;`0d/2l0:R<R027H5/00P23CTX0102FDTl0Y5EA0:AED@2/DE020:i6A`050;91@`2h?d@0^ca30;/l
@`30?4L00P36@4/00`39@dh0b41<0<Q0C0020<m7D`80cDE?00@0d4MA0<e7D03=Ae00bTQ@0P32CU40
1@2U@D<0[5iL0;b7P`2lQh<0X7mj0080V8Am00D0VXf709V>RP2ISXX0Vi2<09Z?S@0209fBT0040:6F
U02=PX00SH:005mDDP80BD0k00D0IU]G08^0O02NThd0WY>=0:2ES`0209bCS0<0WYF>0P2MU8d20:2E
S`040:>AS`2SRHX0XhV:0;:;T080_hJ=00D0f8^E0;MFG`33CUH0`diF0<e:D0020==8C@050=A5B@3F
ADP0eTE80=I7B@3?AD<00P3@C4L01039Cd@0a5E20<AE@P2gCcH20:538@0509Po4`2<>PP0TTL>0997
3P2PHb@00P2`PCT01@3R`F@0jmML0>_GG03SeTT0j=U<0080jM9@00@0ommd0<V>@039ST00YDLD0P3B
FSl01@3CCSl0e4I20=E3A03E@d@0fDI<0080f49;00D0fD=<0=Y7C`3JAdl0f4M>0=56B`020<Y>D004
0;eGE@2IBdT0VD]909e/J080/YBB00D0Whn@09nFV@2HTIP0V96H09F>UP0209:;TP0508b5S027PXT0
Qh:9085lP`1lMX000P1gLG/0101^JgH0J6Ab06QTLP1OFfX205eIJ00505YDHP1?BED0AdA=04M4C@12
?dH00P1;ATd01@1:AD/0CdY>04m:CP1LEUX0>2da0080=RHY00@0>b8U038D500b51@0PV=Q0P3Xa/@0
1@32X9h0TFm]06U:B01YBTP0RVY[0080jlO700D0lLO80>^i^03[^KP0fJ>Q0:elN0020<:KUP040?oX
i03ai=h0lNCN0>SPg@80A44l00D0?SHc09fETP2`ZjD0/:^U0;bg/@020:nZYP0508f8Q01QG5T0HEaI
06MRG`2l];400P3fk^/0102QVIH0OgYg07mjM`24Og`206]WIP0507A`L@3cj^d0l>7V0?3QiP3bg^00
0P3miN401@3I_:`0NEDa07UE<@3XaXT0k]Am0080g/iM00@0`[Pd0=oIA`3OfDL0a/<V0P3EdSD01@3L
fd<0h>1J0>CUO`3TiGl0G64A0080OHE900@0SYI_0?Oik03gnN`00?l03oooool000gooooo4000o`00
1@3fjnL0d/2l0=;0_02XS8P0Qf1K0080Pdi:00@0UU9?0:AED@2TEE40[55@0P2^ATL01@2b@D<0^3m4
0;/l@`2k?4<0`3a70080aT1;00<0bD=>0<Q0C038@4`00P3?Ae<20<e5C`040=17D@3=Ae00cDM@0<Y8
D080`TiA00D0YD530:aNG02lQh<0_8N30:1oNP0209R4O@0509Z=Q`2ISXX0VHj:09^@S02JShd00P2M
TY00102QUY@0SH:008f2P01OE58204U0>`0506IKE`2;P7`0WY>=09jCS@2PUHl00P2LTh`309jESP80
WIB=0P2PUHl0102STHl0XhV:0:>9RP2bRi020;n6S@050=R;U@2gEUl0`diF0<=>EP3=BU000P3CB4d0
1@3DADT0eTE80=I5B03FAdT0cdE30080d4a700@0bDm40<AE@P34ED80]dlf0P2Q@b401@2H?a<0S3X8
09973P2BA`h0X6<T0080/84i00D0h/5T0>_GG03[ee`0hmI90>SIC0020>WBD0040?oOM039ST00bHi0
0:E75080dUXo00D0ddho0=A6@P3E@d@0eD=40=U6C0020=Q2B`050=U3C03JAdl0fTM?0=Q7CP3AAT/0
0P3:CU00102mEeD0VD]909U;B@2MK6P20;:DTP0509n?T02OUYT0V96H09RAV02ESYH00P2BRi801@2<
QH`0Qh:908N2R@21O8<0O7J00080Mg5k00@0KV]f06QTLP1XI780Ge]Z0P1MFFP01@1JE680CdUE04M4
C@17A4d0@Sm60080BdI=00D0BTE;04m:CP1?BTh0G5IJ03P]<@0203HV:@0403/R9@0b51@0<Q@D089S
H@80j<K400D0`Z2N095_K@1YBTP0JDY808YZJ`020>_7a`050?77b03[^KP0jkVh0=VSX@2]O7P00P32
ViH0103oj>@0lNCN0?7TgP3Xh=d204A1?00503hf<`2MUI80/:^U0;2[Y@2l]k400P2_ZZH01@2=R8@0
HEaI065LF@1WHUl0_;Ba0080m^k[00@0XIVF07mjM`1oNWL0Q7ml0P1[IfH01@1dL740ln[]0?3QiP3`
hNH0l]kP0080oNGQ00D0fKb/07UE<@1iEC40j<J90>kDO@020=k>G@040<:h=03OfDL0gmU70<K39P80
eM8e00D0g=]30>3PFP3TiGl0i>Eo05aQ4@0207f5B@0408jFK`3gnN`0moW/003o00oooooo000=oooo
oa<00?l000D0ooGc0>OEd@2mXId0_J6M09I_JP02089?B`0508i?BP2EBTD0UDY50:A>C@2YBd/00P2[
A4L0102I;340YC0i0:D`>@2i?DP20;diAP050<]3C`3;@dd0bd==0<]3C@3@Ae400P3<A4h01@3<ATd0
adaA0<M<D@2iC4l0WdM60080_Gek00@0Zh1j09EjL`2ENW<0UhIo0P2GRX@01@2KT8`0VXn=09R=R`2H
SH/0W96?0080XiRF00D0WiBB08EjN025NWP0FDi:04Ll>00206EGE00408UnN02OU900WiB@0:>JT`80
XIRA00D0WIB=09bCS02OTX`0Wi:<0:JBT@020:V;S@050;F8S@35QXh0aHJ>0=N1S02gCeX00P35C5D0
103?BE00ddQ?0==8C`3CA4X20=E6BP050=57A`39B4<0b5980<QBB030Ed@00P2UAb/01@2<=a00RCT8
08Ti202>@@T0R4430080Oc/000@0MC`005<W001C9`00WWlU0P3agf<01@3SedL0i]Y60>OEB`3WeD/0
lmYT0080k;eQ00D0VTP>0<=G<`33Ec<0dU4l0=98?P020=I6A@040=I4A`3H@dT0f4=90=Y4C@80eT=;
00D0eTM=0<m7B`38CDl0b4e?0;QDE00209M<B@050:9bL02DN7L0U7Qg06QJFP1IDeL00P1GD5L0101>
Adh0Ad1704M0A`14?D@204I1A`0504I1B018@dX0BTA>04Y4CP1=Ae<00P1DD5h01@1IEF<0Hem]06=O
K@1VH6h0JVA`0080M75j00@0O7V008=nQ@23OXD0RhJ<0P2RWJ401@2BS8h0=BX^03`/;`0l;2l0@BP/
0080<Q@F00D0N5QI07mPG@1oH5d0GC/i07mMF`020<b^[0040?oRh03B[jd0dZn]09E/JP80k[bk00D0
_hj:08]OG020GeX0P5mJ0?_Xi0020?W`j`050>?NfP0d<B`0=34/065LF03Ie=000P3]j>@0103`kNP0
l>_X0?3[j03_j^L20>_Vh`05081kN01nNGD0m_7]0?Kak@3hlnl00P3ak>P01@3jm_<0RXJ508Z6Q@27
Ph@0m>k`0080k>7U00@0kmoR0?KRh@3fh^40n=gD0P29IDd01@2bSF<0mmRE0>?;L@3Sbg40`;0o0080
g==@00D0clXk0=KD@@3Fe440gme<0=oOF`020>GXP@0405mV601hP4@0N81408fEKP80moW/00<00?l0
ooooooooool03Oooool000gooooo5`00o`00103`iN40cKbe0<fl]@2IP7/207EDC@0507iCC029F540
PdU508=9A@35PH000P2[EU/01@2I=Cd0[cU50:liA@2i>TD0_c]60080a3i700@0bT9<0<a4CP3<A4h0
cTM>0P3<Be001@32CU40ZdM70:aNG02/GU`0_hF10080W7Ma00D0Tgaf09>1O@2CPGd0UHN409J;Q`02
09R=R@<0VHj:00D0WI:>0:2ET@2PUI40WI:>08AiM@0205I;A`04048g<`1XGE/0J5eK0966PP80XIJB
00D0WiB@09fBSP2SUI80XiFB0:B@S`020:f=T0050;J3RP3>QY40cXJA0=AfQ02hB5H00P3:C5L0103C
BeD0e4M?0=A7C`3DAD/20=56B@050<e=BP33DdP0]UM10;IG@@1k=Pl00P1kA`h01@2[P380`Ye20<:M
@P3;Z4@0aj@l0080_Idf00@0[i8/08Q`3P28L0h0NfT00P3MdD/01@3XgT/0i=Y40>;FAP3ReTH0k=UH
0080oMI]00D0ZfHQ0:i=8P2^CB80d5Ll0=I>@0020=E7@`040=Q6A`3H@dT0f4=90=U4BP80edA:00D0
ddA80=59C@31BDX0`DU:0;UJF00208U4?`0509mcL02JPX00VX:007a`L01eKg<00P1lMG`0101mN7h0
PW^2089kPP27PHD208^6RP0508f8SP2ARY40Ui:H09NBV02JUI`00P2OVJ<309bFX00509fGX@2NVJ00
XYfT0::MY02LUid00P2MUYd01@2GTID0ZjFY0:^UZ@23OGl0<BP[0080=RX/00@0=RLZ038P800b8200
ck^j0P3G`[l01@3NaL00o>3L0?oVhP3oi^80on?O0080hkNd00D0a9B@0>^h]@3[^;D0i[Jb0:AoN@02
0<R/Z0040?WWh`3`iN40l>GQ0?kgk`80`knf00D0Ee1803lh<P1GD4X0Ee1:09NBS0020=S@c@050<c7
``2KUY<0ViJC03Xe<P1ZIf800P3Yi^430>7LeP050=OBcP2`[JP0/:fX0=KEd@3]k>X00P3YhnD0103[
h>@0kmoR0>oOhP3li>@20<^XXP0506Y4<@3B[8D0kLf@0>g=T03:/Ed00P3Veg001@3Ldeh0dli>0=?>
CP3JeU00g]mO0080i^V200@0IVhK07Mo@`1gOd<0Q8aU0P3hn^d00`00o`3oooooooooo`0=ooooo`00
3OoooolG003o00040?3Uh@3=_;D0cKbe09V0N`80MEA=00D0OU=<08UHD@23BDD0PdU50<F1P0020:]F
F`0509Te?@2_>DD0[cU50;TjA@2o>dH00P34?TL0103:@T`0c4A>0<a4CP3>Adh20<a;D0050<9>D@2[
AdL0[5iL0:aNG02oQH400P2LMg401@2CO7H0Th5m09>1O@2EQh@0UX^70080V8f90`2ISXX01@2MTXh0
X9FA0:2ET@2MTXh0Q7Ue0080ET]700@0@SLc06QMF`1XGE/0THJ20P2QUY801@2OU900WI:>0:>ETP2S
UI80Y92?0080[Hf@00D0]X>:0<j6T@3>QY40e7J40;Q8EP020<Y<E`040==;E@3DAdl0e4M?0=A5B`80
dDI900D0cDe:0<=CB02fEd40]UM107/f3`0207]73P050:^0<P32WD80`Ye20<^XA037Y3`00P2mWCH0
102_TR`0R70>08Q`3P1kJ@020=gAB`050>SNB`3TfT@0h]I60>;FAP3/fEP00P3meVd01@2[IR40[TdR
0:i=8P3@Ec`0eTi00080eDM300@0f4I70=Q3B@3H@dT0fDA:0P3GA4X01@3CA4P0dDU=0<59BP31BDX0
^EYH0080RD@o00D0Wg=`09Z2P02JPX00O71`07E_L`0207aeO00407ehOP22Nh80PW^208N1Q@80RhJ:
00D0SHR>096:T@2GTYP0Ui:H09ZEW00209nIX`<0W9JP00D0WINQ09jIX02RWJ@0XYfT09bGW@0209fF
W@0509NAU@2[YJT0ZjFY08=mO`0a:2/00P0f:R`0100f9bX0<R0P038P803?^kX20=O2_`050=k5`03l
h=`0onKR0?oVhP3ohml00P3S]k@01@34U900jkRe0>^h]@3V][80Y7mi0080b:bX00@0nNOS0?3Uh@3`
iN40o_O_0P33_kH01@1GD4P0?cPb05M@BP1GD4X0Ui:<0080f=3=00D0c<O309^FT`2KUY<0>SDb06YW
HP020>WVh@<0hMcF00D0em;>0;2]Z02`[JP0e]GA0>g/jP020>WSi@040>_Pi03_gn80kmoR0?cTi080
bjRR00D0JT@a0=:/Q@3]cI00kLf@0<ZaG@020>KGL0050=cCGP3CcTh0dli>0=[FD03Ngel00P3VjH80
101VKQ/0Mgm307Mo@`24S6D20?Sjk@03003o0?oooooooooo00gooooo000=oooooaX00?l000D0nOC`
0=_Bb`3Kd//0/J:K08ijL@0206A9@P040<NRW03la/H0o<K60;1UJ@80/E1G00D0_TmF0;]3C02i?4@0
^Ca40;hlA0020<4kA0050<HoAP39AT`0bDI<0<M:CP2nCDl00P2Q@d<0102jL6d0]7mk0;AoN`2IMW82
09=jMP05091nNP2CQH80TXN309:7P`2HSHT00P2ISXX309b>R`0509bAS@2UVYH0WiBB09nDTP1oM780
0P1HCD/01@17?3X0K65M06aQG@2@QH40X9FA0080Y9JC00@0XXf<0;2=T@2`SI40^X:;0P3IRiP01@3B
K7X0_DME0<Y6D`3:AU<0dTIA0080eTI?00D0dTE;0<i8B@3>B4T0aTm90<9NC`0207db4`0408mP:03S
aWH0hlIf0?3MM080jMiR00D0jMaI0>_OF@3^hEh0k^5N0>kQH@020>[KI0050=O9C`3ReE80h]EB0>OJ
CP3TedX00P3VfDl0103YeUH0omic0?oNL`3IWeD209Q24@050<aI?03CCSl0f4Y60=Q:AP3C@d<00P3H
@dL01@3JAD/0f4E;0=Q5B`3GB4`0cdQ<0080`de=00@0/5EB08]:A02;BT@0YGii0P2[V9@01@2RV9L0
WINI09VDVP2IU9X0WYVO0080WYRL00D0XYbP09fGV`2MUi/0W9JJ0:2JWP0209bEW0040:6LXP2NVIl0
WYVO09bGW@80ViJL00D0W9NM09^FW02HTiT0V9>I09F@U00209NAU@0509NAT`2_ZJ/0[jV[06=MG`0Y
82400P0f;2d0100W7Ah0CT9204i2@P3di>@20?kYiP050?oVhP3jfmH0h;fg0>2m]`3H[jT00P3Z^K@0
1@3BWi/0`8f90<2=R@2IK6L0SVeV0080nnCN00@0m>GP0?7Xh`3aj><0al2h0P39`[X01@3?b<80V96;
05iGD@1NEe40HEYD0080VI2;00D0PGQc04U1?P19@Ch0PGUf0>7LeP0207MbK00403di<029QG`0RHEl
04Y5?`80VYNB00D0jn[U0>SYi03Uhn@0iN?T0>SRi0020>_Pi0050?;Oh`3mh>@0oN3T0:J5P01W@Rl0
0P2jV7<0103@/W`0f<Am0=S4O@2IRSD209N@:0050=WEFP3QhFL0i>N00>CWP01/M1l00P1jQ4D01023
Rf@0n?[]0?Sjk@00o`0?ooooo`003OoooolN003o00040>gXi02k/Zd0^k:]09>2N`80/iJ@00D0SUiJ
08Y6A@2:ATD0YU1A0;M@E0020<9AE`040<A;DP2o@4L0_d170;Xg?`80a45900D0`d970<Q=D02dATL0
]4I70:U;B`020<5gM0050;AoN`2JMg<0VWMc08mgL`2BP7`00P2>PG/0102>Pgd0ThR209>8PP2HSHT3
09V>RP0409^@S02QUY@0XIJD09nDTP80WYBB00D0OWAb05eBD01MDU00CD9006eRH0020920P0040:>:
S@2bRi00/X^@0;eoRP80gXZI00D0bUi^0<E8F03BC5L0dTaG0=96C`020=A4C@050==8C@3<BTX0c4Y:
0<EBB`2dF4T00P1W9@80103D/6H0l=ef0?3MMP3Vfe/20>;LBP050>7KA@3Uh4P0i=e70>CMA`3XgDl0
0P3XfUD01@3/fU`0jMEJ0>WEFP3YeE`0j]IM0080im9K00@0k=9Q0?OEL@3geG40o<]o0P2NEB801@2j
CS40dU130=E:A`3EBTL0eTE80080f4=900D0g4M=0=M5B03GADP0ddM80=1;C0020<5?CP040:QABP28
C4@0R4a40:^8Q080Xi6?00D0WYFF09nKW02ET9H0UI2F09VDVP0209VDV00509fGV`2GTID0Ui6E09RB
UP2ITYT00P2IU9X0102MV9h0UY6G09JAU`2IU9X209RCU`80VIBH0P2DSi<0102FTID0UHnC09F?T`2K
UIL20:bVZ00504Q2@P0/8b@0=B//03D[;00Q5AD00P22LW801@3kinH0n=cI0?SLf@3BZZP0[h9m0080
bibF00@0h[6Z0>Vd[P3Y]:h0VFIR0P2dQGl01@2EK6H0JDa40?GQfP3ehMX0m>WU0080j>3M00D0BDA0
048m>@12?CT0EU5=0559AP0205UBC00405mFD@1]HU`0KF9L09J9P`80a;Na00D0gM;<0?W`i`31^Jh0
`KV^08Z1N00208N0MP0503Xe;`31_[T0`Kji0?7`k03Vi^@00P3Ti>@0103Uhn@0j>CU0>STi@3VgMh2
0>kNh@050?WPh`2TQh<0OV5C07iQD`2DMU`00P1QBB<01@0f9@00KV8H06iR603Rfg40h=eZ0080g^=l
00@0Jg<N07J2@P1fPT80NXEK0P3innh00`00o`3oooooooooo`0=ooooo`003OoooolN003o00040>gX
i02k/Zd0^k:]09>2N`80/iJ@00D0SUiJ08Y6A@2:ATD0YU1A0;M@E0020<9AE`040<A;DP2o@4L0_d17
0;Xg?`80a45900D0`d970<Q=D02dATL0]4I70:U;B`020<5gM0050;AoN`2JMg<0VWMc08mgL`2BP7`0
0P2>PG/0102>Pgd0ThR209>8PP2HSHT309V>RP0409^@S02QUY@0XIJD09nDTP80WYBB00D0OWAb05eB
D01MDU00CD9006eRH0020920P0040:>:S@2bRi00/X^@0;eoRP80gXZI00D0bUi^0<E8F03BC5L0dTaG
0=96C`020=A4C@050==8C@3<BTX0c4Y:0<EBB`2dF4T00P1W9@80103D/6H0l=ef0?3MMP3Vfe/20>;L
BP050>7KA@3Uh4P0i=e70>CMA`3XgDl00P3XfUD01@3/fU`0jMEJ0>WEFP3YeE`0j]IM0080im9K00@0
k=9Q0?OEL@3geG40o<]o0P2NEB801@2jCS40dU130=E:A`3EBTL0eTE80080f4=900D0g4M=0=M5B03G
ADP0ddM80=1;C0020<5?CP040:QABP28C4@0R4a40:^8Q080Xi6?00D0WYFF09nKW02ET9H0UI2F09VD
VP0209VDV00509fGV`2GTID0Ui6E09RBUP2ITYT00P2IU9X0102MV9h0UY6G09JAU`2IU9X209RCU`80
VIBH0P2DSi<0102FTID0UHnC09F?T`2KUIL20:bVZ00504Q2@P0/8b@0=B//03D[;00Q5AD00P22LW80
1@3kinH0n=cI0?SLf@3BZZP0[h9m0080bibF00@0h[6Z0>Vd[P3Y]:h0VFIR0P2dQGl01@2EK6H0JDa4
0?GQfP3ehMX0m>WU0080j>3M00D0BDA0048m>@12?CT0EU5=0559AP0205UBC00405mFD@1]HU`0KF9L
09J9P`80a;Na00D0gM;<0?W`i`31^Jh0`KV^08Z1N00208N0MP0503Xe;`31_[T0`Kji0?7`k03Vi^@0
0P3Ti>@0103Uhn@0j>CU0>STi@3VgMh20>kNh@050?WPh`2TQh<0OV5C07iQD`2DMU`00P1QBB<01@0f
9@00KV8H06iR603Rfg40h=eZ0080g^=l00@0Jg<N07J2@P1fPT80NXEK0P3innh00`00o`3ooooooooo
o`0=ooooo`003OoooolQ003o00040?G`k03JcLL0f/g70;2GTP80RV5O00D0RDm>08e3A02QB4X0XDQ:
0:m=CP020;]>D@050<9=D`31AT/0`DI;0<93BP2n@4@00P2mADL0102aADD0[U=B0:iCDP2oN7H20:ik
M`0509UfL02BNG@0SW]e08ikM@2<OGP00P2=PW`01@2BQh<0UHZ609F:QP2GS8P0VXn;0080W96=00@0
VY2>09nET`2OUI<0XYRF0P2PUI<01@24NGL0GeAB05E5A@1EADD0MeeP0080XGIm00D0_Wb80>::V03R
RYP0aEEU0<I6E@020=18E0040=95CP3C@d`0dd=<0<m4B@80cde=00D0`e9:0:eDA01e=@l0MCD?0>c9
N0020>_KJP050>CMD@3Rgd@0h]m40>?Q?`3Sgch00P3Ug440103Se4D0kmIH0>oFF03fe6H20??9I@05
0??6J@3gbG40mlUa0?O9L@3hbW@00P3jagP01@3odi@0bgiB0<]nDP2R=Ah0cTi50080eD]900@0dd97
0=]8CP3KB4h0fdQ>0P3C@TD01@3CBDT0bd]<0<AFE@34EUD0Y55;0080RU5:00D0/96>0:6AT@2QTI40
WiJG09bGV`0209NBUP0409VDVP2KUYX0ViJJ09VDV0<0V9:F00@0UY6G09RCV@2HTiT0VYFK0P2GTYP0
102GTYH0VYFI09ZEV@2GTYH409JAU@80UHnA00D0Yj6S0:2JVP2PVYX0>C0a02hT9@0203HZ:P04028D
502dXZ80]::R0?o]k@80^iVH00D0FRXV0;^4O`3Z/JX0j[6Z0=2GT0020<jDT0050>Ja[@3lblL0o<_7
08QQG02[T8T00P3jjN80103llnh0c<O30<c7``0/:2D20;Fa[P050=7<b@2n][<0DTY7059:A`0V7AP0
0P1SEU001@1NDD/0ETU105I9@@1`He/0elg30080^k>X00@0b;nf0<W2^P39`[X0PWei0P2MW9P00`3a
l>h0i^KT0>CTi0020>CTi080i>CR00D0i>3Q0>CIg@3TfMd0m^?Y0?oWj`020:V=RP0405a0=00h7PL0
>1h703DS0080Mf`^00D0hm]h0=kLK@3Nhgd0g^=m075k90020760?`0407F2E`3gnnd0mo_]003o00oo
oooo000=ooooob@00?l000D0ooKe0>_Kf`3[fm/0bJn^0:1jM`0208QEDP0408=2@02B@T40TT910:E7
B080]D]?00D0`4U=0<I9C`37BU00adY@0<17C0020:i1A0050:U=CP2lMG<0_7Ec0;R3O@2IM6`00P2@
MFh0102<NG<0S7mi08aoN@2=PWh208j5P0030968P`2ES8L0V8n:0080V8n:0P2MU8l01@2ITHh0WYBB
09jDTP2PUYD0W9:A0080RWYk00@0N5]P06m1B`1_@D/0VE9P0P3SQiH01@35D680bdQH0=98E@3BB5D0
e4M@0080dD5:00D0d4E:0<m9BP3?BDX0b55;0;MGB@0207@_20040>BmL03[fFT0jmUY0>3GC080hmi4
00D0hmm00>CK?P3Vf4<0i]Q30>oFE@020?;6H`050<Z?@`2cIbT0/fLY0;EO;02nISP00P38Kd<0103I
Pe@0hHmP0>6?H03l[HH20?fTQP050:di:P3;Ad<0eDY=0=E:C@3GB4h00P3E@TX01@3IATh0eDA90=E4
B@3>ATX0bTa?0080_E=C00@0Wdm>09ALF`2DG5/0/92A0P2QTI800`2MTYH0VYBH09ZDV00209ZDV080
ViJJ00D0VYFI09bGV`2LUi/0V9>G09RCV@0209ZEV`0409NBV02HTiT0V9>I09F@U080U8nC00D0UI2D
09VDV02FTY<0UY:C09FATP0209NCU0050:ZTYP27PH<0Qh6303<X;00f9bX00P0h:2T0100d8B<0hlk=
0>?>c@3ojNP20>G2_P050<2?R`3AUY80_Gii0;enN@3<S8X00P3ATI401@35RhX0VVAR09YTHP2;HUh0
m]gH0080m>OO00@0m^oY0>OTg`3Wi=l0JVEQ0P1MF5@01@2GSh`0Vi>@038Z9`0b:RL09A/I0080X9FC
00D0fm3<0=;7`@3Bal40d/W20>CKe00207=/I004028K5@1MF5@0GEQD081lN@80^kZh00D0kNcZ0>GU
h`3UiND0iNGU0>CTi0020>?Sh`050>WUiP3/hND0k>7U0>oOhP3nj>/00P2LPgl0101D>Rd0A2`B04@/
4P0j:00208=h>0050=kHMP3QhG40gNAm0=gTO@1_O2@00P1YNCP0101dPeX0mo_/0?Okk000o`0?oooo
o`003OoooolX003o00040?_/j@3Qb<@0hLS40;JCS`80SUeI00D0PD0n0950?`2A@3l0WCXm0:`oA002
0<59DP040<M?F033D5L0`e1G0;I?DP80YU9B00D0]7=_0:MhLP2ELV`0UG9/095eL@0208agLP0508]l
M`2>PG/0SX5k08b1N`2=PW`00P2>QGh0102CRX<0V96;09RAR`2JThd209^AS`0509R>S@2NU9<0YIFF
0:FEUP2WRXh00P2VMgl01@2ZHVh0f7Z:0=QjRP2nBE/0dDaM0080dTQG00@0ddEA0=I6D03FAU00d4=;
0P3ABD/01@36BdH0aE]>07TY201i:@P0_HY80080m]Yg00D0hmAC0>OOC03Wgd`0i]m60>GL@`020>SJ
AP040?cSI@2kS380^h`b08<o0080ZTlR00D0ZT4Q0:Hf7P2V<ah0YS<N0:0`6P0209ha6P050:0j902j
Ccl0^Tlo0:DY8@37@D000P3FBdh0103EAT`0eTE<0=I5C03HAdh20=A5B`050=19C`32BT`0^U=F0;YC
EP2FBT`00P2LJ6X01@2_TI<0WhnB09n?TP2MTYH0ViFI0080WINK00@0X9ZN09VDV02IU9P0U8nC0P2L
Ui/01@2HTiL0VYFK09^FW02KUY`0UY6G0080VIBH00D0V9>G09>>TP2CSY80UY6E09RCU`0209FATP<0
Ui>D00D0[JVZ06YTIP1ZI6H0:R0Q03d]<00202/H6P04069>D03fg]h0m]kN0?KFe`80fk>a00D0cIfI
0=6JU`3TZ:L0i:RW0=nRX@0208A6A`050:abL@2cOGd0/gem06<j>03Tc<P00P3fjN<0103]iN80kn[V
0>oZiP3Of]H208R0O@0505aCCP1<@ch0O7=^07acKP1kLVd00P15>SP01@1:@3h0Uhj909N>R@3Tfm@0
UHj80080LFYT00@0DDa906UTH@1YI640dlo>0P3Wi^@20>GUh`D0i>CT00D0j>CU0>_QhP3[hN80kmoP
0?cXj@0208mgL`04050f9`17;a<0AblC03PW0080R7dk00D0gmUg0=_MK`3Ni800g^B006ei9@02059Q
9P0407f;I`3ho>h0n?c^003o00oooooo000=ooooobP00?l000@0nncY0>78a03Qb<@0]Y>?0P2>GET0
1@21@3h0TD0o0950?`2M>Sd0[3m40080`DUB00@0admH0<=@E`33D5L0]TmB0P2VDU801@2dLfl0YgQb
09EbK02ELV`0TGEa0080S7Mb00D0Rgag08j1N`2>PG/0S85k08f2O00208j5OP0409>:P`2HTH/0V96;
09ZCS@80Vi6?00D0V8j=09jDT`2UUIH0YIFF0:N:SP020:IgO`050:YRKP3HNXX0f7Z:0;i9F`3AC5d0
0P3BB5L0103CAE40eTI@0=I6D03@@d/20=59B`050<I;AP35Fdh0NBT807TY202mRTP00P3ffWL01@3S
e5<0imm<0>OOC03VgdH0iMa30080j=Y600@0o>=U0;^<<P2kS380Pcl00P2ZCb801@2Z@B40YSHN0:Hc
7P2V<ah0X30J0080WS4J00D0X3XT0;Y??`2jCcl0YBTQ0<M1@0020=I;CP040=E6C03FAD`0eTE<0=Q7
CP80e4E;00D0d4U?0<9:C02jDeH0^U=F09I:C00209aXJP050:nAT`2OSi80WhnB09fBUP2KUIT00P2M
Ui/0102PVYh0VIBH09VDV02DSi<209bGV`0509RCU`2JUI/0ViJL09^FW02FTIL00P2IU9P01@2HTiL0
ThjB09>>TP2FTID0V9>G0080UI6B0`2GTi@01@2]ZJX0JVAV06YTIP0Z8240?Bd`0080:aPJ00@0HTi@
0?KNgP3fg]h0m]KG0P3K/k401@3=WIT0dIZG0>BXY`3TZ:L0gj:Q0080Q4I700D0[79a0;=mO@2cOGd0
HcXh0>C<b0020?KYh`040>gUhP3_j^H0kn[V0=oJeP80R81m00D0G5=>04a3?P1lLfh0O7=^07]bK@02
04Dj>00504Y0?P2GSXT0Uhj90>CKe02ESXP00P1aJV@0101AC4T0JFAQ06UTH@3Cclh20>OVi080iNGS
1@3Ti>@01@3Xi>D0jn7R0>_QhP3_gn00o>SY0080SgMc00@0D3HW04L_4`17;a<0>2L00P28OC/01@3O
fGL0fme_0=kTP03Ni800KGTU0080DV4V00@0OH]W0?SlkP3ho>h00?l03oooool000gooooo;000o`02
0>kKe`050<BUXP2JKFX0VVeZ0:IUH`2OCDl00P2F=C`0102J<3X0/49;0;12B`2dC5<20;=IF`0509aB
D@2GGeh0YGUh0:EiN02KMG@00P2GN7D01@2=M700SgYe08mjM@2=O7D0RGaf0080Rh1j00@0S8=n08j7
P@2>Qh40UXn90P2HT8d209Z@SP80X92@00@0ZHb>0;F6S02eQX`0b82;0P3LO8X01@30BE`0cTUJ0=57
EP3AAeH0dTA@0080e4A>00D0ddI>0<m4B@3?A4T0bTQ80<YCB`020:=0:@0408Y35@3Z_6l0j[a_0?7G
J@80h]I@00D0i=a90>GNA`3Rf4<0h]Q30?cYIP020<6M?00507Po002_GBd0[ed]0<1L>P34ECX00P37
CS/0103<CSl0bTa00<Y<@02l@3H20;Xi<`050<Y3@03BATL0e4Q;0=A8B`3FAdd00P3CA4X01@3DAD/0
dDI;0=56B`3:BDd0`DiA0080/eEF00@0STQ:0:EdM`2UM7L0/I>E0P2PT9<01@2NTiT0WI>K09ZCVP2J
TiX0W9FL0080W9JJ00@0VI>G09^DV`2KU9/0ViBK0`2JU9P0102IU9P0UY6E09JAU@2DSY8209B>T005
09J@TP2ITiD0UI2D09F@U02DSi<00P2HUYL01@2WYJH0AClo04Do?`0]8b@0>b/^00809a@F00@0Uh>5
0>W?dP3Ycm80Sf]_0P1nEUL01@3@Y:<0e:JV0=>SX`3CXj<0dZ2O0080hjf[00D0olg;0>Ne]03W]K@0
^I6A0?;Jf0020?SZj@040>GMfP1TGe/0I5mK07YbK`80Uhj900D0XIJ@0;jaZ@3GcL@0elg40>SMe`02
0=K;a`0508b2P01:@C`0BT4l0:NPVP2RVI@00P3HdL/0103Wh]l0XijK0:>NV`2ASH`20>[Xj@050>OW
i`3Vi^H0hn?S0>?Sh`3Ti>@00P3Ui>801@3Whn80jn7R0>_QhP3`h>40mn?R0080QVeX00@0DSPY04D]
4@15;A40=2D00P2<Pd001@3NfWT0g=md0=kUQP3NiHH0H6`P0080Ce/[00@0_<J[0?_nm@3ko_D00?l0
3oooool000gooooo;P00o`001@3onO@0[IRC0:fHT`2VPG/0/Wei0080e8j@00@0WD]?09Ll@`2G?4<0
TcPm0P2KATT01@1k<C80^7eo0>Vi^@3Y^KT0YWQj0080TVIW00D0X7Qh09IdLP2FM780Sg9^08adL002
08ikM`0408]lM`2:OgT0RWmi08f4O`80THR300D0ThV709R=R`2NSh`0WXn<0:N=S0020;B7RP050<b6
T03FN8H0eWR60;a9FP3;BeX00P3?AeD0103BA500dDA=0=54C@3BADd20=54BP050<e5A`3>C4X0aUE7
0<IEA`2:;a@00P2JEb<01@3baG80l]IY0?;FJ@3YeeL0i]]>0080h]M900@0kMmJ0?KLKP3fg6h0]Xde
0P2<C@P01@2EAA00/E4W0;iC<`2nDc<0aeDk0080bU<o00D0bTm00<e?@`3=Cd<0dDi60=1;AP020=A:
B0040=16AP3BATT0dTI90=15B080cTM;00D0ad]=0;iAE02/EUL0[5IG08Y<C@020:^3P`050:^BU@2O
T9D0Wi2E09jCV@2LUI`00P2MUYd0102LUI`0VY>J09ZCVP2KU9/209ZCVP0509bEW02LUYX0V9:F09RB
UP2HTiL00P2FTID309J@TP0509ZAU02ESi40V9:F09RBUP2ETI800P2QWj001@2LViT0=C4`03Da<00`
:2H0=b/[00809QHG00@0a[Jg0=6k_P3A^kh0Ke5C0P2=Jf`01@2jV9L0_Y^I0>No_`3W_kl0g;2_0080
]HF100D0UVEQ09Y]JP2JKFX0gKNf0?_Sh@020?GWiP040>gSh@1bJVP0LVYX03D]:P806Q0>00D07a@@
034V8018?CL0B3dg0597@`0206QNG00507idLP2=QX00SHJ00:2IT`1]I5l00P1OF580101kMW80OWYg
07ijM`2HUiD20?;`l@D0i>CT0P3Ui>801@3Vh^40k>;S0>cRh`3ahn<0l]gL0080Nf9K00@0BS0O04</
3@13;0d0=BL00P29PS`01@3Rggh0gN1g0=SQR03HhHP0CEPD0080NXAO00@0lOSV003o0000o`000?l0
3oooool000gooooo;P00o`001@3onO@0[IRC0:fHT`2VPG/0/Wei0080e8j@00@0WD]?09Ll@`2G?4<0
TcPm0P2KATT01@1k<C80^7eo0>Vi^@3Y^KT0YWQj0080TVIW00D0X7Qh09IdLP2FM780Sg9^08adL002
08ikM`0408]lM`2:OgT0RWmi08f4O`80THR300D0ThV709R=R`2NSh`0WXn<0:N=S0020;B7RP050<b6
T03FN8H0eWR60;a9FP3;BeX00P3?AeD0103BA500dDA=0=54C@3BADd20=54BP050<e5A`3>C4X0aUE7
0<IEA`2:;a@00P2JEb<01@3baG80l]IY0?;FJ@3YeeL0i]]>0080h]M900@0kMmJ0?KLKP3fg6h0]Xde
0P2<C@P01@2EAA00/E4W0;iC<`2nDc<0aeDk0080bU<o00D0bTm00<e?@`3=Cd<0dDi60=1;AP020=A:
B0040=16AP3BATT0dTI90=15B080cTM;00D0ad]=0;iAE02/EUL0[5IG08Y<C@020:^3P`050:^BU@2O
T9D0Wi2E09jCV@2LUI`00P2MUYd0102LUI`0VY>J09ZCVP2KU9/209ZCVP0509bEW02LUYX0V9:F09RB
UP2HTiL00P2FTID309J@TP0509ZAU02ESi40V9:F09RBUP2ETI800P2QWj001@2LViT0=C4`03Da<00`
:2H0=b/[00809QHG00@0a[Jg0=6k_P3A^kh0Ke5C0P2=Jf`01@2jV9L0_Y^I0>No_`3W_kl0g;2_0080
]HF100D0UVEQ09Y]JP2JKFX0gKNf0?_Sh@020?GWiP040>gSh@1bJVP0LVYX03D]:P806Q0>00D07a@@
034V8018?CL0B3dg0597@`0206QNG00507idLP2=QX00SHJ00:2IT`1]I5l00P1OF580101kMW80OWYg
07ijM`2HUiD20?;`l@D0i>CT0P3Ui>801@3Vh^40k>;S0>cRh`3ahn<0l]gL0080Nf9K00@0BS0O04</
3@13;0d0=BL00P29PS`01@3Rggh0gN1g0=SQR03HhHP0CEPD0080NXAO00@0lOSV003o0000o`000?l0
3oooool000gooooo;`00o`020<6j/P0507MYGP1hHE<0f[F/0=Ze[03@WiP00P3BUYD01@2SHF80V5AE
09QDE@1T92@0Uf5Q0080omCE00@0i[Bg08YFFP2:EUX0SEEH0P2ZLgH01@2PLW80V71^099cL02BLg00
SgIa0080Sgaf00D0SWmj0923O@2@Pgd0THJ209:7P`0209f>R`040:F;RP2`QXP0/8J80<Z<T@80cgV2
00D0]d]H0<U<FP3>BUL0cTYG0<m6D0020=54C@050=E8D03AA4X0dDA:0=95B`3=ADL00P3>CdT01032
D4D0QBD<08DU302SFbT20?2lL`050?_GMP3bfF<0imQG0>OHE`3VfU@00P3YfUT01@3fhFX0gKaE0=fl
E@2YNbD0T5H<0080Qd4300@0VTXG0:997`2RBAl0/50Z0P2mESD01@32ECP0a50i0<e@?P3=D3h0cde0
0080cdQ400D0d4Q80<m:C@3?BTd0a4a>0;YFF0020:1BDP0408QFE@2/SXh0[8j>0:>@U080WiBJ00D0
VY>J09ZCV`2MUYh0WIJN09nHX00209VBVP0509RAV02OUId0WiFM09nEW@2MUYd00P2ITYT0102ITiL0
UY2D09J@U02ESi4209NAT@0509RBTP2EShl0V8nB09R?TP2ES8l00P2^Z:X01@27Ph80;RPX02hX:00a
;2T0=2`Z0080;BDR00@0gMGB0?7Wi@3ainD0jM_J0P3Zf=P01@3cg]d0onGR0=Fb[P3E/Zh0VG1/0080
aIbF00D0_9>=058[9P1B:bH0]iFC0?gXi@020?OXi@040>7Fe03EblX0eL_:0=?=c@80ShV900D0?CTj
02LS901AB4T0DDQ909J=SP0209jDT`0507E[J@2;PWd0Rh9m08b3O033^[D00P1oN780102YY:00EE5>
05EACP2<RhT20?;ak`030>CThP3UiN<0i>CT00@0i>CT00D0i^;S0>_QhP3[hN80l>;R0>cGe00206mF
C`0404P_6`11:PX0@BX:03HY0080Ui5700D0hMmj0=kTNP3@fX@0d=Z405EO8`020<O=/`@00?l03ooo
ool000gooooo;`00o`020=gNf005075_HP1>AcL0MVIF07IVEP38/J400P3fdLP01@3AY9h0`Hj:0<6>
RP2aNgT0Pe5@0080^XR900@0lko30=ZQY`3JXJL0R4]@0P1n@DH01@2?EeP0VVQW09i`L02NL700W7Ab
0080TgAa00D0TWIb09AmM`2DOGL0TGih0921NP0209R5P@0409b2P@2YPH80ZH620<:7R`80bW^100D0
]DmJ0<I@G038BE@0b4UD0<m7D@020=55CP050=95C@3BAD/0dTE;0=95B`3DAdd00P3?AdT0103?CDd0
aE170<E@A`2F<Q/209A26P050=^KF`3jbWH0mmA`0?ODL03/dV<00P3VdUT01@3[f5l0l=]X0?3KJ03d
fFh0k<YX0080e:]A00@0]HDc0:5Y7P2QJAh0UE@@0P2=APH01@2D@`/0Uc`=0:m78P2_Ab80aU<h0080
cU1100D0cTi50<I9A`36BDL0`U1@0;=GF002095=CP0409=[J`2ZUI@0ZYFD09^?T`80W9FL00D0VIBJ
09VDV`2LUId0W9FM09fFWP0209RAV@0509^DV`2OUId0WiFM09^DV`2LUI`00P2ITYT0102ITiL0WINK
09fGV`2DSY0309NAT`0409B>T02ES8l0UHb?09V@T@80/jZ[00D0HeeM030[:00`:bP0<bh[01hI5@02
05aGD`040?3]j03[j><0jnSS0>gUh`80l>CT00D0m>CT0?WQg`3C[J`0djf/0>:f/`020>>h/P050:Qo
N@2JMFl0VWE_0?GFd@3mi^000P3oknP0102VUi@0C49004a2@01KEED2075]KP0504Q6B@0U8bH0:B@X
02TT:01>B4X00P2LTi@01@3Fc</0lnWW0??Yi`2]Y9l0X9JD0080c/K300@0j>?O08F1OP25PGh0c<_9
0P3/jnT20>GUh`<0iNGU0P3Ti>@01@3Whn@0j=kO0>SNg`3eiND0i<o<0080ITi200@0AB`F048^2@12
;PT0>c400P2UXU401@3OhWL0gnIn0<79O031bG`0UYi]0080m_[Y1000o`0?ooooo`003Oooool_003o
0080gMkH00D0LFmR04i7=`1fIUH0MVIF0<RaX@020?KAb0050=6TWP31SXX0`Hj:0;5kN@23DE000P2j
R8T0103c_l<0fZ6W0=ZQY`28Be0207i1AP0508mGF02JJ6L0WW1`09i`L02LM7800P2CM7401@2BMW80
U7eg09AmM`2AOWP0T85j0080V8F100@0W8:10:V1PP2YPH80`XN;0P3:Nh401@2eCeX0aU1L0<Q9E038
BE@0cdMA0080dDE>00D0dTE=0=95B`3BAD/0dTE;0=A7C@020<m7B@040<m=C@35D4L0aE1709Hb6`80
U48J00D0fi]K0?[:MP3ge700mmA`0>cBH`020>KBF@050>_HG`3`ffP0l=]X0?CIKP3/bVP00P3DZe40
102eQC<0XFTN0:5Y7P2EE10208e61P0509A32`2G?0d0[dLR0:m78P36DcP00P3>D4401@3>CTD0aTU7
0<I9A`32D500/eMH0080TDe>00@0Tf][0:ZEU02ZUI@0VhnC0P2LUI`01@2IU9X0VIBK09bEW@2LUId0
WIJN0080V96I00D0ViBK09nEW@2OUId0ViBK09bEW00209VBV@0409VCU`2MUi/0WINK09B>T0<0Ui6C
00@0U8j@09F<S`2ES8l0VI2A0P2cZZ/01@1SGEd0<2/X030[:00c;R/07QTE0080G5MC00@0l>gX0>_X
h`3[j><0kNGS0P3`i>@01@3di>@0nN7O0=>][03C[J`0h[Jc0080hkRb00D0Z7mi09YeK`2JMFl0mMKA
0?gVh0020?o_j0040:JGU01<@T00C49005]EE@80LFe^00D0B4I902DS9P0Y92P0:B@X04i8BP0209bC
U0050=K<b`3cjNL0lnWW0:fTW`2PUY@00P3>a/<0103Xhml0QH5n08F1OP3<blT20>c[j@80iNGS0`3U
iND20>CTi0050>OSi03Xg]l0j=kO0?GUi@3Tcl`00P1VCT801015;1H0@Rh9048^2@0k<@020:FRD@05
0=oRM`3OiWh0`LUl0<79O02FWVd00P3fn^T4003o00oooooo000=ooooobl00?l00P3fn?<01@2a/ZX0
HfAF04e:=`1=BSL0R7eY0080c[VX00D0cK2R0;>=Q02cSH@0f:fW0;b?S0020:MgM`040:ilO`3KYj/0
fjN[0<RAUP80/gZ000D0]Gf00:Q]L@2>DeT0SU=I09aTI`020:9_KP050:1cKP2LMfl0W7M_09EgK`2B
NG800P2FOgT0102IO7P0Xg]k0:=kN`2jPHL20<=hO`050;ACGP32D5X0dUIP0=9FH03;B5000P3@BE00
1@3AATd0dTM>0=97CP3DAdl0dTE=0080dDI;00@0e4U>0=9=CP3BCDh0cU5=0P2X=bT01@2B;1<0]Edg
0>BMI`3TWFL0nl9m0080n/eh00D0lLm]0>kCJ03^dfP0kMIV0>_FH@020?COJP040?CMJ@3_f6H0kmQV
0>G9G080fKQA00D0dJU:0=fVEP2dJBl0]6T_09m25`020<UG?0050<]B@@36CdL0aTm70;YACP2[FUL0
0P21BDP0102PPGl0YYRH0:JHV02HSi8209RCV@0509VDVP2KUY`0VIBJ09VDVP2GTYP00P2ITYT409ZD
V00409VBV@2DSiD0U8nE09JAU`80VIBJ0`2FTID01@2DSi<0THf>09B>T02DSY00X9ZJ0080YijO00D0
?3@b03<[:@0c:bT0=2`Z01PC400209fHU@040?Odk`3Yi^40jNKQ0>_Sh@80l>;R00D0mN?S0??GeP2Y
OGh0ZGen0=^XY`020=6KV`050=VYY`3nem80o]OB0?WKd`3PaK`00P2WT8P0102gYYl0akbj0<Nl^P2O
VIT208b8R@05075/L01>BDd0>S@h03Xd>00X8R@00P0K5AL01@17?Sl0OGEc07eeL`1JDU00Dd]90080
SHF300@0c/W606]WI01[If@0jNSV0P3XinD01@3Ti>80i>KS0>CTi03Ti>@0hn?S0080iN?T00D0i^3R
0>SNg`3Xg]l0nNWY0=S4_@0205e6>00404Pb6P0m;040?B`104]20080b<Q^00D0fMmc0>;ZQ`36ci00
a/n@0>7Wa@020?gom@@00?l03oooool000gooooo<P00o`00103Ee/h0OX1b07j0LP1LFDP2075UE@05
07UXF01MACT0GDDi0=2bZ02EL6X00P3<Xil01031UI@0_Y:C0;jBT`3GZJ/20=b[[P050>fk_030S8h0
[75g0:aaM`2MHVH00P27DE401@1nCDT0SF9K08eRF`2MNg40V7Y`0080V7aa00@0V7M`0:1gL`2PMg<0
]W]m0P2nLgP01@2YBU80`59K0<A?E`34CeL0bDaB0080cDaA00D0d4]@0=5:D03ABU00d4U?0=58C`02
0==8C`040=E8CP3FBe00eT]@0==;C`80eE1C00D0`dM50:4_902B;QL0TRhG0:aG<P020=B;F0050>nb
K`3jagH0n/Mf0?S?L`3ddF/00P3beVP0103_eV80kMQS0>gHH`3_g6H20>oJI`050?CHK@3og7l0kkI_
0>nfK`2AAA400P30FCH01@36ESh0`eE80<=EB02eEdl0WeQD0080R5QF00@0ZHn>09jDU@2NU9D0ViFI
0P2FTIL01@2IU9X0VYFK09VDVP2IU9X0WIRN0080ViBK00D0ViFI09RAV02HTIP0W9FL09ZEV`0209NB
V00409JAU`2ET9H0UI2F09F@U`80V9>I00D0ThjD092;S`2:QXL0RXJ709jJV@0208b6QP0502/S8@0g
;bd0=bl]030X9P0V8Ah00P3Bc//0103akNX0j>CQ0>STh@3]hn@20>oOhP050?OQi03_cm80XG1d0:5`
M03AVI`00P2_LgD01@2oQhH0nLk80?W>b02eU8/0aJRP0080L5UA00@0^:NP0?cbl03ll_00l>[Z0P3]
jn`01@3/j^/0iN7R0=GAdP3EdM80al?40080XinP00D0S8R908R2Q028PX@0[:JV0<2j^P0204@n?P04
06QTH`1/J6D0K6QU0>k]j`80inOU0P3SiN820>CTi0040>GSi03Vh^<0i^;S0>ONh@80j]_N00D0oN_Y
0<RbY`1B>bT0DS/Y04@_4P0203X/000507Qb903IfgX0fM]j0=ONMP3TkI@00P3QikL00`3ko^T00?l0
003o0004003o00oooooo000=oooooc800?l000@0eMK>07j0LP1nP780G5U80P1aIED01@1iJ5P0GDDi
05e5>@3@/ZP0UG1Z0080c:>O00@0`IFD0;jBT`2nTY<0ejV[0P3LZjh01@3]^k`0`8b>0:aaM`2/LGL0
WF9V0080Qe5A00D0OTe908eRF`2=HU/0WG]a09QjL00209QlL@0409QgL02PMg<0X7Mc0;IkO@80_W=h
00D0ZDYB0<1BF`34CeL0a4mG0<U<DP020<e<D@050=1;D03ABU00dDY@0=19C`3AB4l00P3CB4l0103E
B4h0eT]@0=I;D03CBdl20=E@D`050<=7A@2Q;b@0TRhG098^5`2/Ec800P3DReP01@3_/Vl0n/Mf0?[7
MP3hcg<0m=5[0080l]IX00@0kmIR0>gHH`3]f6<0kmaV0P3_fVL01@3df6d0omao0>nfK`3_]Vl0TDDA
0080`5Tf00D0aUHn0<=EB033EDP0]EM?09mHE00208QHEP040:V?SP2NU9D0WYBE09^EV@80UY6G00D0
VIBJ09ZEV`2IU9X0VIBJ09fHWP0209^DV`0509^EV@2HTIP0V96H09bEW02JUI/00P2GTYP0102FTIL0
UI2F09F@UP2ET9L209RCV@0509>>U02@Rhl0RXJ708Z6Q`2NVYT00P2<QXH01@0[8b40=bl]03L_;@0`
:2H09R4N0080d/k;00@0lNgZ0>STh@3Xi>40kN?T0P3_gn801@3ghN@0kloB0:5`M02QL7@0dIVL0080
[g=e00D0_hN60?W>b03ic/P0]IB;0<FXX002071ID@040;RWX03ll_00o?;`0?3ZjP80kN_/00D0k>[[
0>GQhP3EdM80eM7B0<O3a0020:>OX00508b8R@28PX@0R8:40:bVYP30^[X00P14?Sh0101XI6<0K6QU
06aXI@3^kN/20>OWi@80hnGR0P3Ti>@0103Uhn@0i^;S0>KRh`3Wg^420>[KgP050?g[j@38/ZL0DS/Y
058k:@14;a800P0j;0001@1hLR@0fM]j0=WKNP3GgWH0i>fD0080hNNg00<0nokY003o0000o`001000
o`0?ooooo`003Ooooolc003o0080k>gW00@0_;bd09JBQ`2FTXL0P7Q]0P1@A3P01@28MV`0Yhn50;RM
U02hWI@0l]G=0080[Hn700D0UG1Z0=F`ZP3E/:X0n]OC0<bVX`02095UI0040:1dL`2QN7H0XGQf0:R1
O080QV5I00D0L515089RE@2HN6/0V7Q[0:5kL0020:QgL0050;MjM`32M7@0`WAd08d^<P2P=c/00P2k
BTh01033Ce80a4a>0<A<CP36BDd20<M9C0040<Y9C@3@CU00dda@0==<D0<0dDU=00D0dTU@0=5:D03A
BU00d4U=0=5?C`020<Q=B0040:hi;`2E:QH0UBXF09dj7@80/eTd00D0eXAD0>^SJ03i^WD0nKYe0?c4
M`020?c<M`050?S@L@3ecf`0mLm/0??;J@3icG@00P3odh/0102UIS00XdTT0:=9902oFd420;aKBP05
0:mKD02@Ddh0U6aZ09A/JP2^VIP00P2OUIH01@2OVId0WYRL09jHW02JU9P0VI:I0080Ui2H00@0W9FM
09N@V02GT9P0TX^B0P2?RY401@2>RI00Q7n608=nQ@23OXD0P7^20080N7=j00D0J6E^06MTJ`1WI6/0
HUeT05iIH00204=1A00407EaLP1/IVP0K6IX03`f=P80FU5B00D0:B0Q04m9B@3^j^T0k^[Y0>WUi002
0>[Ti0050>kRi03cg^<0lmkS0?cOi03:XZX00P2BHFL0103KX:@0YfEW0:MUI`2UJ6L20;N6P@0508eX
H02YSXD0]jJN0;NVWP3XgML00P3]j>@00`3Wi^@0i^KT0>KVi0020>KVi0<0j>SV0P3YinP01@3Zj>T0
i^CU0>KTi@3Xi^L0jNOX0080W9^I00@0SXf;0=_Jf03Kf]P0k>c/0P3UiND40>?Ui0040>GSi03Yh><0
jN3S0>cMhP80k]kQ00D0o^_W0:2:O@19<a`0BC<L040]300203hc00050;VhGP3IgWL0fMig0=cSQ03V
kZD00P3cm]L00`3ko?@00?l0003o0004003o00oooooo000=ooooocP00?l000D0k^kV0=C@a`3Dd<L0
Z9nF0:6DR`020;2RU`040=;1]`2jZ9h0^ZRN05Hn=080WHEk00D0hL[20>7:a02gViL0]i^G0;FIUP02
0=6e/P050??JeP3L`kh0g<>n0:F<Q@24K6800P1`EDX0101mGE80T6EL091UG02_N7<20<J2O`0509E4
@@2A=SD0X3`l0:0l?02_ADD00P2cADH01@2iAdL0_TY;0;i:B`32BT/0ad]=0080bTa=00@0c4]?0<m<
D@3?C540c4U?0P3ABe801@3>BDh0dT]A0=E@E@3ED5D0dU1B0080bdi<00D0`4I10:lj<02_>S00WS4M
09Xe6@020:9480040;AM<039ND@0bGU40=><C080j:EO00D0lk=[0?RiMP3oahh0olN>0>bXN`0209Y1
8@050;QH@P2fGDd0]Ue=0:MMDP29E5000P2RP7l0102FQ8@0PgQl08=hO01nN7`207QbMP0506eWJ`1X
HFP0H5UQ061IH@1JDe/00P1:@d/01@1<AD`0CdQ@04m8D01:AD/0BdI<0080E4mE0`1HDeX01@1GDUT0
GeYQ05mJH@1SGVD0If9X0080NWQk00@0T8b=048n?`12?Sl0?cTi0P1RG5`01@0T7Qh0TH^;0?Gal03e
lO00i^;Q0080j^CT00D0k]oR0?SQi`3hhNL0l]?I0<BKX@020>Vh_0040=jVY`2SIVD0XfIU091ED@80
WVmY00D0`ijF0=Rm]P3ii]l0nNKO0?;Th@020>cRh0050>_Sh03[i=h0jnCN0>cSgP3[i=h00P3Xhmd0
103XiN00in?P0>OSh03ViN<20>OUiP050>GUi@3/k>`0gMgM0=gMg@37alD00P3YjNL00`3UiND0hn?S
0>?Sh`020>?Ui080iNGU00@0in?T0>[NhP3Zg^80k=cO0P3dh>401@3`fmH0KUM704D`4`15<1<0>2T0
0080MFhZ00D0gMml0=3GL03@eg00i>^K0>gd`0020?_nj`L00?l03oooool000gooooo?000o`00103g
m>l0i=oI0>COf@3@bL<20:ZSV`0508ElL`2>Q7X0SXAj0:ROUP2k/Z/00P3BbL@00`3_iN<0ooKe0?of
m@04003o00040?K]j03Kd<X0fm3:0;ZYXP80Ugii00D0SFaU08mRG02?HU`0RU5:08]6?`0209I7@P04
09Y1?@2R@3d0XT0m0:Q0?@80Ychk00D0]4I50;I4A02oBDT0_dU90<E>D0020<=;C@050<A<CP3:Ce80
bTmB0<]>DP39Bdh00P3>CE40103@Ce<0dE5B0=5ADP3@D5420<e=C0050<a?B`32Acl0]chc0;Ln<`2a
>B/00P2O;1T01@2M;AL0Wc<I09lc6@2Q>A`0]e@g0080`VA;00@0gGiX0:<m;P2S?Bh0]U550P2fGeH0
1@2JEE00T6=P09QlN`2HO7/0K5iN0080FeEG00D0GEMK05]FFP1KEUX0G5IJ05iHG002069HH00406]Q
J@1YGfL0JEmW07E/L@80O79j00D0OgUm08N1Q@29PhL0RH>708V2R@0208f6S@05096;S`2DSi<0U8nC
09FATP2ASHh00P2/Z:L0102:QXD0;BTX02dY:00X924202XV8`0502`X9@3EdLh0lNgZ0?7]jP3Whn00
0P3Yi>401@3_hN40n^CV0?[TiP3_dM<0[8F60080ZGai00@0`I2;0:EdK@2UM6d0Y7Q_0P3id//01@3g
e/l0hlBo0?7He03af=@0m>7M0080mN;N00D0mn3J0?KNe03fg]@0n^3C0?_Qe0020?KSe@040?3Re`3/
hmX0k>?J0>WTgP80jNKQ00D0i^GQ0?7ak`32`/00`/;009fMW@020>c/k0050>GUi`3Ti>H0i>CV0>;T
h`3Ti>@00P3Vi>D0103Yh><0k=gP0>cMh03^g=`20?_Vh`050;^RV`1:<Ad0@2`7040/1`18?P400P35
`g001@3Ih7P0gNN60=gWQP3[lkL0n?gM0080nogb1`00o`0?ooooo`003Oooooll003o00040?Odk`3T
gmT0i=oI0=39``80ZZ>K00D0QGac08j4NP2>Q7X0Z9nF0;^bZ`020=;9a0030>oUh`3om_D0ooKe00@0
0?l000@0m^gX0=_@bP3Kd<X0^ZVR0P2GOWT01@2=K6D0Sf9L08mRG02:DDX0RdHo0080UTM200@0VT4m
0:90?@2R@3d0Z40m0P2W?S/01@2dATD0]TA40;m9B@2oBDT0aDi@0080`d]=00D0a4a>0<Y?DP3:Ce80
bdiB0<U;CP020<i=D@040=1?D`3ADE80dE5B0=1@D@80cDe<00D0c4m;0<97?`2g?S<0]chc0;4i:`02
09l/6@0509d]5`2O<aT0Wc<I0:4i702gE3L00P32I4/0103MOVP0Xcd^0:<m;P2fDDD20;IOEP0509YE
D02@Hf00V7ak09QlN`1/GUh00P1KEEL01@1MEe/0FeIJ05]FFP1LEUX0GUQL0080HUQP00@0Jf5Y06UO
I`1YGfL0MFaa0P1lLWX01@1oNGd0Qh6508V3Q`29PhL0RH:90080SHJ=00D0TH^?09B?T`2DSi<0UI6B
096=SP020:bXY`0408Z6Q@0]:BP0;BTX02PT8@80:RHS00D0;2PU0=GAcP3akNX0lNgZ0>OSh0020>WT
h@050>oQh@3ji>H0n^CV0>oAd`2/QHH00P2YO7T01031T8/0YGA]0:EdK@2TN6l20?WBb`050?OFc`3S
a;l0lMSD0?7He03dhMd00P3eh]h01@3gh=X0m]kD0?KNe03jh=<0nn7D0080m^?E00@0l>;G0>cSfP3/
hmX0jNCN0P3Yi^401@3ViN40lO7_0<;2`032`/00WIfM0080k>c/00D0iNGW0>CTiP3Ti>H0h^CS0>CT
i0020>KTi@040>WPh`3/gN00k=gP0>kLg080nnKS00D0^j:K04Xa7@10;0L0@2`704Pn0@020<G3L005
0=WPN03MihH0gNN60>_c]`3hoMd00P3koO87003o00oooooo000=oooood800?l000D0k^kV0=OGc`3G
ell0i^KN0?[im00=003o0080ooKb00D0lN3I0=S1^@3H`KT0^iZC0:5fK`0209AOF@0408Y=B027@3`0
Qd0l0911?080Ud8o00D0WD8o09dk>02U?cd0YClm0:i4A0020;55@`050;I6A@2lBTX0_4Y:0;e9BP32
Bdd00P37Ce001038CDl0c51B0<a@DP3:C4l20<i=D@050<m<D@3>C4h0dDa?0=5<C`3AC4d00P3@Bd`0
1@3=Bd/0a4A10<A4@@2k?S`0/CLd0080Yc@_00@0XS8^0;I9A02fBD@0^EQB0P2^GEX01@29CD`0Ug5`
0:F?T@2USi40U8R:0080TXb>00D0THb@09NBUP2GTYH0V9:F09F?T`0209R?U00409jEVP2QV9d0XIRM
09^BU`80VY6F00D0ViFG09bFV02FT980UY2B09F?T`0209ZDUP0509F?T@2DSXh0U8j>09:>S@2IUI@0
0P2[Yj@0101HE540920M02@P7@0a;BX201HB3`0506APG@3al>`0j^KS0>[Vh`3Yi>400P3[hN001@3`
h>00n>3P0?SPh03hf=T0hKVi0080g:bX00@0cijG0=faZ03M/JP0oMG=0P3E/:X01@35Y9l0IdE30;:C
T@2bTi40on;R0080nmWG00D0n<_60>NbZP3W/ZX0dYb@0<nNS`020>>l[@040?GIb`3fi=P0m^CH0?3V
g080j^KK00D0inCM0>SWhP3NgmX0g]oJ0=gMf`020>KVi0<0i>CT00D0hnGT0>CTi03WhN<0in7S0>WO
h0020>_Kf`050??Pg03gh=P0mn3H07]TE013:a400P0i:@00102=QSP0h^>50>;SQ@3FgWT20>K_W003
0?7fc@3koNl00?l000P00?l03oooool000goooooFP00o`00103jk>T0jMKB0>WFdP3:/Jd20:N6P@05
099YH`21CdP0PDm808M;@`2=A3h00P2B?c/0102L@Ch0XCll0:4o?02T?SX20:Hm>P050:e1?`2bA4<0
_4a;0;a<B`2oCDd00P2nC4`01@34D540`da>0<=<CP39DE<0bTmA0080bDe?0`3?CU<01@3ACU@0d4eB
0=1=DP3>CE80ce5E0080c4mC00@0a4e?0<5DE`31E5L0^EeN0P2JDe401@21Cdh0YHN709f;R`2MRh/0
UH^<0080Thf?00@0TXb>09B>T02DSY00U8j@0`2CSHl0102ESi40V8nB09R?TP2DRhh209B>T00509F?
T@2DSY00TXj=09:>S@2ARhd00P2DSY001@2ARhd0TH^;096;R`2?RHT0XYfJ0080U8n<00@0>C@a02`W
900/9b@0<RdZ0P0H51<01@2UXJ00mO7`0>SRhP3Xh^80jn?Q0080kn7Q00D0m^;S0?GKfP3efmX0eK>b
0:n3PP020;N1O`0407@m>P35U900aIB@0<FHU@80[8B200D0dZb[0:J0O`3Q^[/0hKZk0?oQhP020>F_
[`050:1BD02J@Cd0VT4m094h<027=b`00P2;CD00102OLF80bZfM0<Z]W@3Yf<P20>_Rd@050>KSe03Y
im/0j>SN0>SXgP3Wj>000P3TiMl01@3Ui^40hn?Q0>?Sh@3SiN@0i>;S0080j=oP00@0jmgL0>oNe`3_
g]L0o^[O0P32[I`01@13;Q<0>RP005U>401ICQ00clY/0080fmaf00@0gN>;0?7g^@3amkT0n_cT2P00
o`0?ooooo`003OoooomJ003o00040?[/j@3Ye]80jMKB0<Za[@80YhJ100D0TVUS085?B021CdP0Qd]3
08e4?P02098o>`0409a1?P2Q?c`0XCll0:@n>P80YSdj00D0[D4o0;94@`2lC4/0_4a;0;m=C@020;i<
C0050<A@D@33C4h0`da>0<UAD`3:Ce400P39CDl30<m>D`050=5>E03@CE80d4eB0<i=DP3?DED00P3<
Ce<01034CDl0`EAG0<5DE`2iGEh209YCD@05085?CP2UQhL0WH^;09f;R`2ERh`00P2CSHl0102BS8h0
U8j@09B>T02DSY0309>=S`0409F?T@2HSi80V8nB09B;SP80U8j@00D0UHnA09B>T02BSXd0TXj=096;
S@0209B>T005096;S@2ARh/0TH^;08n9R@2RWIX00P2DSh`0100i=340;2LT02`W900b;BX201PD4`05
0:FQX03elO00j>;R0>SRhP3[hn400P3_hN401@3fh^<0mM_J0?GKfP3E/k80[h>20080]h5o00@0M3dj
0<FDT035U900aIRE0P2/Q8801@3B[:/0YX1o0>6j^`3Q^[/0on7R0080iJn_00D0X59@09Y1?@2J@Cd0
TCP`08Lg;00208]=@00409maHP3:[Id0bZfM0>WHb080jn;A00D0i^?D0>WWf`3Xj=h0j>SN0>OXh002
0>CUg`050>GVh@3Shn40hn?Q0>?Ui03Th^<00P3Xgn00103[gM`0kmkG0>oNe`3nj]l20<:]W00504<^
4`0j:000FDh@05U>403?bV`00P3Kg7H0103Mhh/0lONi0?7g^@3jo>@:003o00oooooo000=oooooeh0
0?l00P3on?<01@3ei^40g/O10=k7`@36YIh0ZGag0080TEYG00@0QTE10916@`2@AT<0Rchh0P2F@cd0
1@2K@cl0WD8m0:A5@@2TAD40Y48o0080ZD=100D0/4I60;A8AP2dB4H0^DU80;i:B`020<A=C`040<Y?
E03;CU@0bdiD0<]<D`80bdaE00D0cDiG0<e@F03:CUH0bTiF0<AAF0020;aGF`050;5OH@22ATH0PTI6
09E]K@2USHd00P2DQXH00`2DRh`0ShV;08n9R`04092:S00408n9R`2CSHd0Thf=09:<S080UHb?00D0
THR;09B;SP2DRhh0Thf?096;R`02092<R`0408j8RP2<QXH0S8J608j8R080T8^800D0ShZ70:JQWP1Q
G5T0HEaI02/V8`0203H^;00502DM6`0k=CD0>cDe0=oIf@3_jNT00P3[hN00103_hN40m>;R0?CRhP3h
h^@20;bPW`050<6NW03/`;l0ikBc0>Nd/`2AGUd00P2QLg<01@1mDe@0[HJ70:f6Q`3CZj`0gJna0080
omCF00@0l[Jh08]1@P2;@D80YdU90P33Ged01@33JF40/VEK091FB02@ETP0Ich/0080H4D`00D0HE<i
07UbF01iLUP0_KbP0>oaf@020>S[eP040>K[e`3Tj=T0i>SI0>?Wf@80hnKK00D0hnCL0>OTg@3ZgmT0
j]oI0>gLdP020??Rd0050?OVc022Kdl0PVm?03XY000j;`000P2TWdd0103Ui7X0g=ii0=cNN@3YkjT2
0?KkdP030?_mk`00o`000?l000P00?l03oooool000goooooI000o`00103olo80km_J0>oKfP3I_KX2
0;JET00509ieK`2;G5@0ReaD085;@@24AC`00P2:A3`0102EAT40X4Q40:18A02RAD020:I3?P050:Po
?02/?Sd0]TI50;I6A@2iATT00P2h@dT01@2kA4X0`4QA0<18D@33BeD0`TeF0080`4iF00@0_UIM0;EO
HP2eGf80Ue=D0P20DU801@2TQXH0V8R909>9RP2CRHX0TXV<0080SXR:0`2@RX`01@2?QXT0THR;0968
R`2AR8/0U8^>0080ThZ=00D0T8N:09:7R`2BQh/0U8V=09:<SP0208b6R00408b6QP2=QhL0SHN7092:
RP80SXV600D0XIVG08j6P`0g;bd0=bl]034Y9`0203/b<`0501`C501eK6l0MFa_0?K]kP3^h^@00P3a
g^00103dg^00n^3S0?[Ph`3ign820=o1``050<^YZ032W9/0Vg9`09]bL026GUh00P38Z:T01@3Ybld0
omoV0?oOiP3L/KP0MCLl0080gXnB00@0`FQZ09`n?P2L?Sh0c6mZ0P2oK6@01@2EEd`0R5i>09n6LP2O
QW80ZIf50080X9]m00D0QHEQ0;:dS02b]8`0emjb0<C=XP020<KAY`040=_W`@3Oj/P0gn[80>?/c`80
i^_D00D0i>OB0>OUd03[g//0jmk;0>kNa0020?_[a`050<JhR`13<`00@c<0040f001iM1P00P3EefX0
103Hgfl0iNb?0>G/S`3amL<20?[mj0030?_lm000o`000?l000P00?l03oooool000goooooI000o`00
103olo80km_J0>oKfP3I_KX20;JET00509ieK`2;G5@0ReaD085;@@24AC`00P2:A3`0102EAT40X4Q4
0:18A02RAD020:I3?P050:Po?02/?Sd0]TI50;I6A@2iATT00P2h@dT01@2kA4X0`4QA0<18D@33BeD0
`TeF0080`4iF00@0_UIM0;EOHP2eGf80Ue=D0P20DU801@2TQXH0V8R909>9RP2CRHX0TXV<0080SXR:
0`2@RX`01@2?QXT0THR;0968R`2AR8/0U8^>0080ThZ=00D0T8N:09:7R`2BQh/0U8V=09:<SP0208b6
R00408b6QP2=QhL0SHN7092:RP80SXV600D0XIVG08j6P`0g;bd0=bl]034Y9`0203/b<`0501`C501e
K6l0MFa_0?K]kP3^h^@00P3ag^00103dg^00n^3S0?[Ph`3ign820=o1``050<^YZ032W9/0Vg9`09]b
L026GUh00P38Z:T01@3Ybld0omoV0?oOiP3L/KP0MCLl0080gXnB00@0`FQZ09`n?P2L?Sh0c6mZ0P2o
K6@01@2EEd`0R5i>09n6LP2OQW80ZIf50080X9]m00D0QHEQ0;:dS02b]8`0emjb0<C=XP020<KAY`04
0=_W`@3Oj/P0gn[80>?/c`80i^_D00D0i>OB0>OUd03[g//0jmk;0>kNa0020?_[a`050<JhR`13<`00
@c<0040f001iM1P00P3EefX0103Hgfl0iNb?0>G/S`3amL<20?[mj0030?_lm000o`000?l000P00?l0
3oooool000goooooJP00o`001@3lkNP0j=C=0>SDc@3:[JD0ZhIn0080V6]U00@0RUE?08a?BP2<CdX0
QT4l0P2>@3`01@2HAD40W4910:12@02P@T00X3`l0080YSm000D0YSa00:Tl@@2Y?440Zci40:e2B002
0;=<D0040:]AD`2KDe@0Ve=D07a6A080UW=_00D0WHR309>5PP2CRhT0Th^90928QP0208j9QP<0SXR8
00D0ShJ70968R`2?QXT0ShJ908j5R0020927RP050968R`2CR8`0ThR<08n4R02DRhh00P2;QHL0102=
QhL0S8J608b6QP2<Qh@209JASP050::JV01FCT`0:b<Q02/S8@0g;Rl00P0b:BX01@0R6A`0_KNi0;fg
^@3gk?00l^?V0080lMgO00@0Z8^?0:j?U02^Si@0jL[?0P3mgN001@3_bl/0dk2^09IdLP2FM780kLo=
0080on[Z00D0n^CW0?oXk`3oj>l0_Y>L07`c>P020;9FF`040:U2A@33GE/0`eeK0<M`I`80TTi300D0
WgEW0>SC`P2^Z980[ZRB0820I00207QiE`0507YkD@2<S5X0S8aJ08b?EP1SJ2h00P1OJ2l0101^NdD0
QYAQ08JDH@2ga9T20<7<Y0050<o@[P3QgKX0k^2m0>kP_@3gi[X00P3TeIX01@1lL2P0PGLR085g8P2W
XSh0dm9L0080gN=Y00@0gNAj0>[cY03Zlj@0n?cK0P3ko?@;003o00oooooo000=ooooofh00?l000@0
ooCc0?OUh`3giN<0im;?0P3E^KH01@2gUY40X7Ud0:1iM02GIf<0SEIC0080R4M300@0SD8m098o>`2B
?c/0VT4m0P2N@3h01@2S@D80XT930:18AP2PB4H0TDI10080Gb@P00D0QeaE0:25O02PQG`0VXYm0926
NP0208j6N`0408f4N`2=QWh0SHIn08b5O`80SXJ300D0S8N408n9R@2=QhL0SHN708^5Q@0208b3QP04
0927RP2AQXX0THJ:08j3Q`<0SXF600@0TXV:08Z1PP2:PH80T8^80P2UX9d01@1`J6H0<2LX03<X;00c
:2`0=BX^00806Q4D00D0FE=G0>WTj03Yi>P0kNO[0?CXk0020?3KhP0409AfOP2EM7/0UGAk0>W5b@80
j/?600D0_IJG0=:_[@1oHEl0Of5O099hM`020??Oh0050?GRi03ojNl0onW_0=:W/02;@TT00P3:Jg40
1036GF40afER0<MUHP2eJ5h208mJC0050>C9^026NfT0JfI@06]VD02ASG800P2>QV801@1hJch0IETO
06EI7`1SF1H0MVlW0080NGTa00@0JgD`06Mf=@1WMSD0IWPn0P1IIS401@1OHBl0MFdl09^9E`2KREL0
VHE80080U8@_00D0[:4g0=C<D03Dc500eM9=0=gQEP020=CMH0040>?/T@3/m;/0k?Bk0?_oj0d00?l0
3oooool000goooooM@00o`020?oelP050?WTh@3_d/h0g;Na0=bg/@38VI<00P2]MW401@2PHeh0UU9?
09IBC`2BBdL0SDQ30080O3df00@0JC@/07Q@AP1hD4H0[i>70P2HQgD01@2CR780S8I/08^5J`2;QF/0
SHM_0080S8I`00D0S8Md08Z4M02:Q7@0RXIj08f9OP0208V4OP0408V4P028Ph00R8>008b4PP80SH>4
00D0SXB308f3P@2:P7h0RX1n08f4O`0209B;QP050:BKUP1jLfd0NW=]03H/:P0g;B`00P0j<340100T
6ah0>C0c03T`<`3@b/`20>cZj`050>KQi@3[h>H0l=oW0?3Oi`3fgnL00P3eeml01@2dU9T0P61S081P
H`36Z:P0iLW80080UGem00@0L5aM0?3Ph@3`h>40ln3T0P3ih>H01@3oeMl0ZemY0:m@F02_D5P0bfAX
0080b6YX00D0XeeE0:IhJ`2VN6/0/I^=05I??@020=oJaP040=O@]P1aHCl0LF4o06A?8080b[Ef00D0
YY9909b<?`32^fd0`[]]09>EBP0206af<@0506eg>01XKS00J6h`06eY:P1[H1h00P1[FA40101YE`40
/J@d0;6T=03JdDh20<g;>0050=_NA`3FgDl0hNYg0>7ZM`3VkJL00P3goMT00`3lo_400?l0003o000;
003o00oooooo000=ooooogD00?l00P3omO801@3ii>40km;>0=bg/@3L]k40b9VC0080[GIa00D0X6=N
09IBC`2FDTl0TT]708e8@`0207`m=P0406Td;01hD4H0N5160:nCQ`80V8Me00D0ThQb08b6K02;QF/0
RhE[08f7K`0208b6L00508b7M02:Q7@0RXAd08Z6NP2=RGh00P29Q7h01029Q800R8>008R3P02<Q882
08f3Q00508j4P`2=Ph40RX1n08Z0OP2=Q7l00P2DRhH01@2TViH0NW=]07YcK@0f;2X0=bd/0080>S0a
00@091/N03T`<`0i<3<0d<[<0P3/j^/01@3VhND0jn3V0?3Oi`3`gnL0m]oW0080mMOO00D0]9BI081P
H`20H6<0aZRX0>G9b00209EmO@04071LG@3`h>40l>3Q0??Pi080nN3V00D0omGO0:]OJ@2_D5P0[e1H
0<]TJ0020<QZJ0050:=ME@2VN6/0YWQ[0;6KS@1FCcd00P3Of/H0103Gd;H0LF4o075Q?`1TCb020<Ze
MP050:JBB@2LS3l0`[]]0<:kK@2CUDX00P1/MS401@1]McP0J6h`06Q^<01]JBX0Jf0N0080JeTA00@0
JEL10;6T=02aY3@0f]5>0P3=bcP01@3KgTL0e]e?0>7ZM`3QjWL0i^fW0080mogI00<0o?ka003o0000
o`002`00o`0?ooooo`003Oooooml003o0080ooGc00D0nnKS0>_BcP3[d/h0f;Vf0;^LV@0208Y_J004
0:nISP3WelP0imO80>WNbP80a;nQ00D0WI]e09VGKP2BTF<0TY5S08j=G`0208^:GP0508N4F`28QV00
R8IP08J7I@26QVX00P25PVl01025PW<0RXIm08Z6O@23OgH208^2O@0508^0NP2>PGP0Sh5f08n1MP2H
RWd00P2XW8h01@22MVX0>B`S03T/8`0i;2@0?34]00808QXG00@0@Sdj0;jj^@2n^[T0lO3^0P3ViN<0
1@3Uhn@0jN?W0>gRj03]h^P0n^gd0080/9nU00D0PVmc0;^XZP2kZ:X0]jNX0:^MW@020;R/[0040>?G
f@3ei^/0mNK[0?GPi`80f;W100D0hZjj0?f__@2`DV00/59P0;aFH@020<1TI`050:5KF@2WNW@0YgYd
09Z3N`1TFTh00P24OF/01026NV80ET8Q05I28@2DNDX20>kCT0050=k7N`2MRS/0^:aP0;R/H03UgYX0
0P1kMcP01@1VH2@0Mfl`07M_<01lKRD0NVXE0080UXLR00@0c<1:0=K>A@3FcTD0b<La0P3FfSl01@3J
h4`0gNIU0>G_S`3Ukhl0koG70080n_k]00<0nOce003o0000o`002`00o`0?ooooo`003Ooooon3003o
0080ooWc00@0nOG/0?Oci`3glnL0l>oM0P3Hf;h01@31`Z00^;RB0:n`QP2_/8H0[:f10080XjAh00D0
WYea09RIK`2HVFl0SiA/08B8I@0208>6J`0408F4K`25Q780QHAb07miJ`80Rgma00D0UHEe09Z8LP2K
Qfh0VhM^0:bHO@0208QgF`0503h^500m;A@0?BdD04Dd800a8Pl00P0h<1d0103=a[@0n_CT0?[di03[
j=T20>OUf@050>WVg@3/i>40jn?P0>_Sh03`j>H00P3Hd<h01@3UfmX0mng/0?O]k03/in@0j^KU0080
lN_[00@0k^SZ0>kSi`3^hnL0n^W_0P3@/[`01@1[?DP0Z65a0;APL02dH700_69^0080_V]c00D0YFUY
08aVH`2<IV<0[ibF05M>A@020;ngZP040=;7/`1LBB/0G4T[0:69G@80k=:G00D0k=F?0:FBC@2hZFH0
^:UV0;N[L@0207AW<00507m^=P22LB`0PW4/079P302aX3P00P3OdEH0103DcD40c<Pa0<c8<@3>cc<2
0=_RA`050=SPE`3TkH80gnJP0=oVX03ioN804000o`0?ooooo`003Ooooon3003o0080ooWc00@0nOG/
0?Oci`3glnL0l>oM0P3Hf;h01@31`Z00^;RB0:n`QP2_/8H0[:f10080XjAh00D0WYea09RIK`2HVFl0
SiA/08B8I@0208>6J`0408F4K`25Q780QHAb07miJ`80Rgma00D0UHEe09Z8LP2KQfh0VhM^0:bHO@02
08QgF`0503h^500m;A@0?BdD04Dd800a8Pl00P0h<1d0103=a[@0n_CT0?[di03[j=T20>OUf@050>WV
g@3/i>40jn?P0>_Sh03`j>H00P3Hd<h01@3UfmX0mng/0?O]k03/in@0j^KU0080lN_[00@0k^SZ0>kS
i`3^hnL0n^W_0P3@/[`01@1[?DP0Z65a0;APL02dH700_69^0080_V]c00D0YFUY08aVH`2<IV<0[ibF
05M>A@020;ngZP040=;7/`1LBB/0G4T[0:69G@80k=:G00D0k=F?0:FBC@2hZFH0^:UV0;N[L@0207AW
<00507m^=P22LB`0PW4/079P302aX3P00P3OdEH0103DcD40c<Pa0<c8<@3>cc<20=_RA`050=SPE`3T
kH80gnJP0=oVX03ioN804000o`0?ooooo`003Ooooon9003o0080nO[b00D0moW/0>c]g@3SiM00hnG@
0=CH`@020<34Z@050;BgVP2/[i00[:n@0:J]S02IX7l00P2RZ8`0102WZi80NGUQ07UiH@1cJeH20:ZJ
P`050=BlX03</8/0[8mS0:b?H`23J3T00P1>>0H01@0o:P00BcH904/f2@1>>@`0?2X00080ZIe]00@0
o_?50?C[`P3djl80l>S40P3`jL`01@3_im00knOD0>oVe@3_i]D0kNGH0080kNOK00D0knSP0>[Ug`3Z
iMl0jNKQ0>GTh0020>STh@040>OSh03Yhn<0jN?S0>kSi`80nNK/00D0Zh^F081<F@2OGfd0Wem]0;1/
N@020:mbNP0508aRI01dFUT0M5YI0>SMf`2IU9000P2BSXD01026OW40DDD_0555;`1dI4<20=C1UP05
0?7O[@29NDP0TH=D0963E01cHSL00P2EPUL01@2=N4<0Je@>06]D3P2cXCd0h=9G0080d<Lj00@0b<D/
0<c<<03<c300g>570P3Gh5401@3RjgH0emnD0>cab03/lLP0nog_01000?l03oooool000goooooS`00
o`00103ko_D0n_k`0?[nl03gnN/20>[]fP050=gRc037ckP0][jW0;JnY`2VZiD00P1aL5`01@22NfP0
dl>/0=?3[02lYhX0UWaG0080XXMH00@0]j1Z0;>OI02cWf@0WHY?0P2>O3h01@22L2h0OF`W0<VmL`39
_G<0im^C0080j]fI00D0kn6T0??S[`3chjl0l^Be0?CU^P020?GW`0040?KYaP3cj<X0lnS:0?;Vc080
l>G?00D0kNCC0>cUe@3/iMD0k>GE0>[Te0020>cVfP050>cSfP3ciN80lnGR0?_Vi@3B[[800P2EJ6d0
1020DeP0OUEI07iEF@1aEE@20:fNV`050?O_k@3/j>D0bLK10<W6`@2b[Z<00P2h[j001@2^Xhd0^Zb?
0;Z/S`3;_9/0X99_0080g/j/00@0i]B`0>cG[03/ej`0R70d0P2aVdH01@3Ue600clHk0<W6;@39aRd0
bL//0080eM/m00D0fN5>0=SSH`3Hhf<0g^R80=KMZP020?_njA400?l03oooool000goooooS`00o`00
103ko_D0n_k`0?[nl03gnN/20>[]fP050=gRc037ckP0][jW0;JnY`2VZiD00P1aL5`01@22NfP0dl>/
0=?3[02lYhX0UWaG0080XXMH00@0]j1Z0;>OI02cWf@0WHY?0P2>O3h01@22L2h0OF`W0<VmL`39_G<0
im^C0080j]fI00D0kn6T0??S[`3chjl0l^Be0?CU^P020?GW`0040?KYaP3cj<X0lnS:0?;Vc080l>G?
00D0kNCC0>cUe@3/iMD0k>GE0>[Te0020>cVfP050>cSfP3ciN80lnGR0?_Vi@3B[[800P2EJ6d01020
DeP0OUEI07iEF@1aEE@20:fNV`050?O_k@3/j>D0bLK10<W6`@2b[Z<00P2h[j001@2^Xhd0^Zb?0;Z/
S`3;_9/0X99_0080g/j/00@0i]B`0>cG[03/ej`0R70d0P2aVdH01@3Ue600clHk0<W6;@39aRd0bL//
0080eM/m00D0fN5>0=SSH`3Hhf<0g^R80=KMZP020?_njA400?l03oooool000goooooV@00o`00103f
mo40j>SP0>SXh03Qg]D20=gEbP050;BXV02DR6h0[Z5o0:jQO`3>`iH00P3KdY/01@3Nei<0g=J:0=cF
RP3@bWH0_kQN0080_;9C00@0_[9@0;VYB@2iZDT0ZiPj0P2]Ud801@2nYeT0bK9V0=FoMP3E_gH0hLb9
0080k]RL00D0lmfT0?GN[03egZ`0m^2g0?GQ_0020?OU_`040?CV`@3ci/@0lnK40?7Vb080l>C<00D0
mNKC0?oYf`3bg<l0l]c?0=c6^`020=6m]0050=kAb03`jN40l>WQ0>[WhP3Wi^400P3Yj><0103/jN80
lncT0??/i03fk^<20;jbY00509B7M03DaZ`0c;fN0<bmWP3SdJd00P2JQU401@2NRCH0imEW0>OEI`3?
`c/0d</c0080a/HX00@0d]Pj0=KOB03FgdP0eN5K0P3OjX801037dHX0koCF0?cmm@3loODA003o00oo
oooo000=oooooil00?l000D0oogd0?olk@3gl]h0mo;N0>gZb`020=kL/`050=GDWP3Hf9P0f=RH0=OG
S`3LfHX00P3Je800103OeW/0gLm^0=g?KP3A_e/20<F_C0050;ZR?P2]URh0YHhV0:F>9P2ORBH00P2P
RBT01@2OQR`0[iE10:nE@@2hWU@0`jaX0080bKE`00@0gLZ80>SHVP3Xf9X0kmjV0P3agjl01@3bhKD0
mNJo0?SXaP3hj<H0nN[90080nNc<00D0mnc@0??Yd03cjM00kNG@0>gUdP020>gTd`040>oVe@3`j=D0
l>SE0?cag@80f<^h00D0O6eF0>kO`P3Te;00i=B`0:ZHJ00208Aa;0050>KDL03Eb4P0eLQ80<[3=037
aRd00P3;cc@0103Hh4`0dMeE0=7ME@3Nk7X20;O4M@030<_CY03lonh00?l001800?l03oooool000go
ooooW`00o`001@3ooO@0ooc]0?ObgP3gl]h0kN[;0080g]bc00D0eMBN0=SHV03Hf9P0emN?0=cIRP02
0=[DP0040=oFN`3Mcfh0gLm^0=6oF`80aJm<00D0^Z8n0:fF;P2USRH0YHhV09n99P020:29:@0509n6
;02_UD40[iE10;RNE033[6P00P39]G00103MbXP0j=RJ0>SHVP3_gZH20?7O[`050?;Q]@3ei[l0n>S6
0?SXaP3ij/T00P3ik<`01@3gk=00lnW@0??Yd03]iM00kNGB0080kNCC00@0knKE0?3Xe@3`j=D0o?7M
0P3HbkP01@1lKEH0k]o20>CD/03Te;00ZYQX0080Q74/00D0i]A`0=G8B03Eb4P0b/<d0<O6;@020<_?
=0040=SPC03AgED0dMeE0=k/NP80]lAe00<0bm>T0?cokP00o`004P00o`0?ooooo`003OoooonQ003o
0080oOge00@0o_kd0?cmk`3loNl0oOcZ0P3inN401@3_l=40j^[60>3O/`3Pgk<0fMRP0080d<^700D0
dl]h0>3DL03Pe700imYX0>SJG@020>[LF@040>CFD@3Pcd/0h<m;0=C3@@80b[Pl00D0^jXh0:ZH:P2S
TBD0Xi4U0:BA:P0209^7:00509n7<@2[TT00Zi900;bRE`2oZ6@00P3;]WD0103JaH80im:A0>OBT@3_
fih20??NY`050?CN[@3fgk<0m]nf0?KO]P3hh[T00P3hhkP01@3likX0m=nb0?CO/P3SdJ40o>bk0080
gljF00@0NF@Q0<^gH03;]f00f<UF0P3:`S/01@35`S<0bL/i0=SOD@3Hge40dmiK0080g>ek00D0`m=k
09nYM`2OZGL0l_OP0?_lm00C003o00oooooo000=ooooojX00?l000@0oOod0?cokP3lonh0o?oT0P3a
klH01@31_h@0`KaZ0<6lJP3>ael0dLQA0080f=1;00@0eL`o0=oDA03Oe4@0hmM50P3[gdl01@3[geD0
k>1H0>cNF@3/gUT0j=UJ0080i=5I00D0f/IF0<nhD03?^500`Za90:VF>P0209j==@0409n>=P2MRcD0
WH/e09b7=P80/Ya@00D0Zi==0;:IE`30YVT0`:IY0<F[KP020<nfM0050=BmNP3Lah@0g<N40>;?S@3T
eI@00P1oL2/0102FQSP0gM1`0=g@L034_D/20;nn@0050<c?CP3BfeX0dMaR0=7LHP3JjWl00P3Ahhd0
1022TU@0cMJi0<gF^@3loo@D003o00oooooo000=ooooojd00?l000@0o?kc0?oolP3ooo80kNgA0P2c
/H401@2b[fX0bLE/0=;>H`3BcV<0bL=90080bL4l00D0b;ld0<_3=03;`c@0dl/j0=WA@0020=gBA004
0=kEB03LdT`0g=9<0=oFE@80hMUM00D0hmaX0>?LL@3NfG<0g]Uc0=gGM`020=SBM0050=;9KP3?a6X0
clAZ0<FgG`2hZ5<00P2cXU00102ZV4@0Xi4k0:>A>`2HQS0209N7<P0509b=?02HS400ShHi08n6>@3K
e8<00P35a6X01@2c]eH0a/iY0<K>J@3=fG<0b]Yh0080`]Ek00@0[<5d06j2A`1^PTL0UjF10P3go^hE
003o00oooooo000=ooooojd00?l000@0o?kc0?oolP3ooo80kNgA0P2c/H401@2b[fX0bLE/0=;>H`3B
cV<0bL=90080bL4l00D0b;ld0<_3=03;`c@0dl/j0=WA@0020=gBA0040=kEB03LdT`0g=9<0=oFE@80
hMUM00D0hmaX0>?LL@3NfG<0g]Uc0=gGM`020=SBM0050=;9KP3?a6X0clAZ0<FgG`2hZ5<00P2cXU00
102ZV4@0Xi4k0:>A>`2HQS0209N7<P0509b=?02HS400ShHi08n6>@3Ke8<00P35a6X01@2c]eH0a/iY
0<K>J@3=fG<0b]Yh0080`]Ek00@0[<5d06j2A`1^PTL0UjF10P3go^hE003o00oooooo000=oooook40
0?l00P3Wi]401@2OX7P0WIaS0;VgK@2i]fd0c<Q]0080eM9[00D0dm1M0<c:C`3<bTl0c/]:0<c9AP02
0<[7AP040<g9C038`d/0b<=;0<2oB`80aLAH00D0`<1L0;g1H`30`f`0`<=/0<C5M`020<72MP050<S5
N03=bWd0cLYm0=K>P`3IdHH00P3NeHX0103OeXT0g]:60=kBQP3MdHD20=O>P`050=K>QP3CbhX0f=BD
0=SDU02o_Wd00P24Qd801@1kPSh0RiIB08^FDP28Ue@0TJ5R0080P95J00@0JGY=07V8J@1iR6T0h^_H
5`00o`0?ooooo`003Ooooona003o0080oOge00D0mOKX0=oOa`3?d:h0cm2^0<72UP020<72R@050;k1
O030aG<0`<Ec0<G:L036bfd00P34afh01039bgP0c<f10<c=P@3<cHT20=7BV0050<_?W039c9l0f=fe
0=SM]@3Rhl400P3Oh;h01@3Nh;/0i>K10>CV`@3Yi/<0k>[40080l>c700<0lNg70?3/aP3`k<H00`3c
klX01@3bkl`0l>g>0>c[c@3/jld0g]o00080b/f^00D0b<f_0<gC]`3=dkL0dmVo0=WQb@020>7Ye003
0>_bhP3eno40mO_a01P00?l03oooool000gooooo/@00o`020?gmm@050?Gfj03OglL0cm2^0<o@[P31
`YH00P31`XT01@2n`G`0`<Ec0<35L`35bW00a/]]0080a<M^00@0bL]h0<c=P@3<cH40c<f90P3AdYP0
1@3;ci`0bLbO0=SM]@3HgKD0h^?10080gn2n00D0g^2k0>CV`@3Ti/40jNK30>cZa0020?3/a`030?7]
a`3`k<H0l>c600<0lno:00D0l^o<0?3]cP3/jld0k>_=0=kO`0020<[=[P050<S=[`3=dkL0cM>g0=?I
_`3IhLT00P3QjM@00`3[l^80mO_a0?Gkl@0H003o00oooooo000=oooookL00?l000@0n_g/0?7eg03a
mM`0hnO40P3<dZH01@2_]X80]Kf40<oCX03?dj00i^Vl0080ko7:00D0l_KE0?OkhP3gnn80nokY0?[n
k`020?_nl`@00?l00`3moo80103no_80oOk`0?gnl03mo_060?gml@<0oOgc9@00o`0?ooooo`003Ooo
oonj003o00050?gom03lo_40o?ka0?[mk03io>/00P3loNd0103mo_00o?ka0?cnl@3moo@o003o00oo
oooo000=oooookX00?l000D0oOod0?cnl@3lo_40n_g/0?Wlj`020?cmk@040?gnl03lo_40o?ka0?go
m3l00?l03oooool000goooooo`00o`05003o00oooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {334.625, 0}} -> {-0.0250052, -0.0294352, \
0.00365857, 0.00365857}, {{6.8125, 280.125}, {326.562, 174.875}} -> {-9.3143, \
-13.1678, 0.699207, 0.699207}, {{6.8125, 280.125}, {159.688, 8}} -> {-9.3143, \
-124.848, 0.699207, 0.699207}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Extract RGB data", "Subsection"],

Cell[BoxData[{
    \(\(data1 = ExtractRGB[obj1];\)\), "\[IndentingNewLine]", 
    \(\(data2 = ExtractRGB[obj2];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize RGB data", "Subsection"],

Cell[CellGroupData[{

Cell["3d distribution in RGB cube", "Subsubsection"],

Cell[BoxData[{
    \(\(gobj1\  = \ 
        PlotRepresentativeSample3D[data1, \ 2000, pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample3D[data2, \ 2000, pointStyle2];\)\), "\n", 
    \(\(gdist1 = 
        Show[{gobj1, gobj2}, nS, \ ImageSize \[Rule] 288];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["RG plane", "Subsubsection"],

Cell[BoxData[{
    \(\(which = {1, 2};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\n", 
    \(\(gdist2 = 
        Show[{gobj1, gobj2}, nS, FrameTicks \[Rule] False, \ 
          FrameLabel \[Rule] None, ImageSize \[Rule] 288];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["RB plane", "Subsubsection"],

Cell[BoxData[{
    \(\(which = {1, 3};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\n", 
    \(\(gdist3 = 
        Show[{gobj1, gobj2}, nS, FrameTicks \[Rule] False, \ 
          FrameLabel \[Rule] None, ImageSize \[Rule] 288];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["GB plane", "Subsubsection"],

Cell[BoxData[{
    \(\(which = {2, 3};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\n", 
    \(\(gdist4 = 
        Show[{gobj1, gobj2}, nS, FrameTicks \[Rule] False, \ 
          FrameLabel \[Rule] None, ImageSize \[Rule] 288];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Show all", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{gdist1, gdist2}, {gdist3, gdist4}}], \ 
        imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0258451 0.47619 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0258451 0.477324 0.518133 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.96078 .96078 Mdot
.71373 .70196 Mdot
.52941 .51765 Mdot
.13725 .12157 Mdot
.87843 .86275 Mdot
.11373 .09412 Mdot
.1098 .08235 Mdot
.77647 .76078 Mdot
.15294 .12941 Mdot
.13725 .10588 Mdot
.13333 .11765 Mdot
.1451 .11373 Mdot
.20784 .17255 Mdot
.17255 .1451 Mdot
.4902 .48627 Mdot
.1451 .11373 Mdot
.26275 .22353 Mdot
.23529 .2 Mdot
.47451 .47843 Mdot
.89804 .81961 Mdot
1 .96078 Mdot
.13333 .1098 Mdot
.20784 .17647 Mdot
.24706 .2 Mdot
.11373 .09804 Mdot
.3451 .1451 Mdot
.49804 .30588 Mdot
.65098 .52157 Mdot
.84314 .73333 Mdot
.94902 .8902 Mdot
.1451 .12157 Mdot
.18431 .15686 Mdot
.20392 .15294 Mdot
.20784 .17647 Mdot
.55294 .37647 Mdot
.41176 .11373 Mdot
.42353 .2 Mdot
.36078 .17647 Mdot
.38824 .23922 Mdot
.21569 .18431 Mdot
.21569 .18431 Mdot
.18824 .15294 Mdot
.22353 .17255 Mdot
.25098 .24314 Mdot
.52941 .17255 Mdot
.47843 .14902 Mdot
.41961 .16863 Mdot
.44706 .21961 Mdot
.33725 .15294 Mdot
.1451 .11765 Mdot
.14902 .1098 Mdot
.17647 .13333 Mdot
.24706 .21569 Mdot
1 .92941 Mdot
.58824 .18039 Mdot
.51373 .16863 Mdot
.45882 .19216 Mdot
.43137 .18824 Mdot
.43529 .23922 Mdot
.15686 .12549 Mdot
.21961 .16863 Mdot
.18039 .14118 Mdot
.26667 .23529 Mdot
1 .96078 Mdot
.77647 .36078 Mdot
.61176 .2549 Mdot
.45098 .16471 Mdot
.4549 .22353 Mdot
.42745 .16863 Mdot
.18039 .13725 Mdot
.25098 .18431 Mdot
.14902 .1098 Mdot
.21961 .18431 Mdot
.50196 .49412 Mdot
.73725 .32157 Mdot
.58039 .21176 Mdot
.4549 .15686 Mdot
.51765 .29412 Mdot
.46275 .16863 Mdot
.21176 .10196 Mdot
.18824 .13333 Mdot
.19608 .15294 Mdot
.18431 .14902 Mdot
.16471 .15294 Mdot
.82353 .70588 Mdot
.65882 .23922 Mdot
.53725 .16078 Mdot
.54118 .26275 Mdot
.54118 .32549 Mdot
.50588 .17647 Mdot
.23137 .04706 Mdot
.16471 .11373 Mdot
.23922 .18824 Mdot
.25882 .22745 Mdot
.14118 .12941 Mdot
.52941 .45098 Mdot
.37255 .09804 Mdot
.57647 .16863 Mdot
.5451 .16471 Mdot
.77255 .52941 Mdot
.64706 .42353 Mdot
.52549 .16863 Mdot
.28235 .07451 Mdot
.16863 .11765 Mdot
.27843 .22745 Mdot
.18431 .16078 Mdot
.15294 .11373 Mdot
.2902 .17255 Mdot
.96078 .90588 Mdot
.63922 .23137 Mdot
.54902 .16863 Mdot
.55686 .18039 Mdot
.58039 .36471 Mdot
.49804 .25882 Mdot
.67059 .26275 Mdot
.23529 .1098 Mdot
.17255 .12941 Mdot
.22353 .19216 Mdot
.16863 .13725 Mdot
.29804 .14118 Mdot
.33725 .16078 Mdot
.8902 .79216 Mdot
.62353 .21569 Mdot
.56471 .15686 Mdot
.58824 .16078 Mdot
.55294 .3098 Mdot
.71373 .49804 Mdot
.53725 .20392 Mdot
.5098 .24706 Mdot
.2 .13725 Mdot
.18431 .13725 Mdot
.18039 .14118 Mdot
.20392 .05098 Mdot
.67059 .47451 Mdot
.35294 .14118 Mdot
.88627 .80392 Mdot
.63137 .20784 Mdot
.59216 .15686 Mdot
.64706 .18824 Mdot
.78431 .52941 Mdot
.83137 .63529 Mdot
.67059 .41569 Mdot
.47451 .24314 Mdot
.27059 .16471 Mdot
.2 .13725 Mdot
.19216 .12941 Mdot
.33725 .13333 Mdot
.63529 .43137 Mdot
.61569 .32941 Mdot
.34902 .16471 Mdot
1 .96078 Mdot
.63137 .18824 Mdot
.64314 .18431 Mdot
.67059 .20784 Mdot
.80392 .55686 Mdot
.41961 .23529 Mdot
.68627 .48235 Mdot
.8 .62353 Mdot
.25098 .1451 Mdot
.21961 .12941 Mdot
.26275 .12549 Mdot
.42745 .21176 Mdot
.66275 .44706 Mdot
.61569 .29412 Mdot
.41569 .18039 Mdot
.76078 .67451 Mdot
.53333 .19216 Mdot
.72549 .27451 Mdot
.66275 .2 Mdot
.64314 .20392 Mdot
.83529 .65098 Mdot
.67059 .46275 Mdot
.58431 .41176 Mdot
.52157 .4 Mdot
.37647 .20784 Mdot
.28235 .14902 Mdot
.49412 .22353 Mdot
.46667 .28627 Mdot
.56471 .3098 Mdot
.6 .27843 Mdot
.50588 .25882 Mdot
.63137 .52157 Mdot
.44706 .15294 Mdot
.67451 .2549 Mdot
.90196 .45098 Mdot
.76471 .2902 Mdot
.90588 .64314 Mdot
.48235 .2902 Mdot
.93333 .76471 Mdot
.61569 .49412 Mdot
.59216 .43922 Mdot
.38431 .2549 Mdot
.61176 .32549 Mdot
.63922 .4549 Mdot
.72549 .52157 Mdot
.58824 .2549 Mdot
.64706 .33333 Mdot
.39608 .18824 Mdot
.78824 .71373 Mdot
.60784 .22353 Mdot
.73725 .4 Mdot
.83922 .40784 Mdot
.83922 .36471 Mdot
.9451 .69412 Mdot
.57647 .38039 Mdot
.76471 .61176 Mdot
.66275 .55686 Mdot
.39608 .27059 Mdot
.56471 .46667 Mdot
.6549 .36471 Mdot
.62745 .41569 Mdot
.72549 .51765 Mdot
.54902 .20784 Mdot
.61961 .29412 Mdot
.62745 .36863 Mdot
.34118 .18039 Mdot
.98039 .90196 Mdot
.71373 .27843 Mdot
.92157 .58824 Mdot
.67843 .27451 Mdot
.8549 .39608 Mdot
.98431 .74902 Mdot
.54118 .30588 Mdot
.72941 .58824 Mdot
1 .90196 Mdot
1 .91765 Mdot
.84706 .73333 Mdot
.63922 .35686 Mdot
.67059 .43529 Mdot
.68627 .44314 Mdot
.49804 .16078 Mdot
.61569 .27451 Mdot
.65882 .38431 Mdot
.27059 .08627 Mdot
.91373 .85882 Mdot
.64314 .20784 Mdot
.85098 .57255 Mdot
.8902 .60784 Mdot
.67059 .28627 Mdot
.82745 .41569 Mdot
1 .86275 Mdot
.95294 .76078 Mdot
.85098 .74118 Mdot
.83529 .71765 Mdot
.81961 .72941 Mdot
.53333 .29804 Mdot
.67451 .38431 Mdot
.47843 .21176 Mdot
.51373 .16863 Mdot
.53333 .19216 Mdot
.64314 .31373 Mdot
.63922 .39608 Mdot
.23922 .05098 Mdot
.92941 .86667 Mdot
.5451 .53333 Mdot
.38431 .36471 Mdot
.56078 .20392 Mdot
.69412 .28627 Mdot
.56863 .29412 Mdot
.84314 .58824 Mdot
.74118 .29412 Mdot
.77647 .42353 Mdot
.67451 .38824 Mdot
.75294 .62745 Mdot
.95686 .77647 Mdot
.50588 .36078 Mdot
.86275 .71765 Mdot
.47451 .18431 Mdot
.66667 .33725 Mdot
.64314 .36078 Mdot
.52157 .16863 Mdot
.63529 .28627 Mdot
.63137 .38824 Mdot
.63529 .39216 Mdot
.20784 .05098 Mdot
.93725 .88235 Mdot
.18431 .15686 Mdot
.21569 .18431 Mdot
.83137 .82353 Mdot
.74902 .27843 Mdot
.93725 .69804 Mdot
1 .84314 Mdot
.83529 .57255 Mdot
.77647 .34118 Mdot
.57647 .26275 Mdot
.69804 .36863 Mdot
.89804 .7451 Mdot
.91765 .60392 Mdot
.98431 .81569 Mdot
.90196 .71373 Mdot
.48235 .20392 Mdot
.53333 .20392 Mdot
.55686 .25098 Mdot
.5098 .16078 Mdot
.61961 .27843 Mdot
.60392 .43922 Mdot
.61569 .38824 Mdot
.31373 .10196 Mdot
.66275 .57647 Mdot
.11373 .0902 Mdot
.24706 .20392 Mdot
.23137 .19216 Mdot
.86275 .76078 Mdot
.73333 .27059 Mdot
.98431 .79608 Mdot
.95686 .76078 Mdot
.66667 .3451 Mdot
.94902 .49804 Mdot
.61176 .26275 Mdot
.81569 .46667 Mdot
.86667 .69412 Mdot
.7451 .34902 Mdot
.9098 .6902 Mdot
.77647 .56471 Mdot
.56078 .2902 Mdot
.48235 .15294 Mdot
.58431 .27059 Mdot
.50196 .1451 Mdot
.56471 .24314 Mdot
.47843 .34902 Mdot
.61961 .40392 Mdot
.52941 .27059 Mdot
.22745 .09804 Mdot
.71373 .69804 Mdot
.27059 .23529 Mdot
.30196 .24706 Mdot
.1098 .07059 Mdot
.66275 .24706 Mdot
.6 .27059 Mdot
.98431 .67451 Mdot
.72157 .49804 Mdot
.8 .31765 Mdot
.95294 .49412 Mdot
.71373 .30588 Mdot
.80784 .52157 Mdot
.78039 .47451 Mdot
.86667 .50196 Mdot
.92157 .64706 Mdot
.82745 .57255 Mdot
.69412 .34118 Mdot
.81569 .54902 Mdot
.47451 .11373 Mdot
.5451 .18039 Mdot
.65098 .42745 Mdot
.42353 .3098 Mdot
.58039 .36863 Mdot
.51373 .24314 Mdot
.19216 .03529 Mdot
.12157 .0902 Mdot
.21176 .16863 Mdot
.21961 .15294 Mdot
.15294 .10588 Mdot
.59608 .21569 Mdot
.65882 .35294 Mdot
.83922 .46275 Mdot
.78431 .43529 Mdot
.80784 .36471 Mdot
.83137 .3451 Mdot
.9451 .5098 Mdot
.63922 .33725 Mdot
1 .8 Mdot
.79608 .39216 Mdot
.64314 .3098 Mdot
.58431 .27843 Mdot
.60392 .2902 Mdot
.41176 .09412 Mdot
.41176 .07843 Mdot
.55294 .16863 Mdot
.40784 .11373 Mdot
.40392 .3098 Mdot
.52549 .33725 Mdot
.46667 .16863 Mdot
.4549 .2 Mdot
.1098 .07059 Mdot
.22353 .18039 Mdot
.27843 .21961 Mdot
.27059 .21176 Mdot
.46667 .27059 Mdot
.6 .22745 Mdot
.76863 .40784 Mdot
.94902 .41961 Mdot
.64314 .34902 Mdot
.81569 .35686 Mdot
.81569 .33333 Mdot
.74118 .44706 Mdot
.69804 .48235 Mdot
.75686 .32157 Mdot
.6902 .42745 Mdot
.69412 .34902 Mdot
1 .78824 Mdot
.59608 .18824 Mdot
.70588 .43137 Mdot
.54118 .14118 Mdot
.53333 .17255 Mdot
.49804 .32941 Mdot
.52549 .32941 Mdot
.4902 .23137 Mdot
.43922 .13725 Mdot
.34118 .20392 Mdot
.13333 .0902 Mdot
.21176 .16078 Mdot
.21961 .15686 Mdot
.35686 .3451 Mdot
.73333 .27843 Mdot
.83529 .57255 Mdot
.86275 .29412 Mdot
.8902 .42745 Mdot
.73333 .44314 Mdot
.83137 .31373 Mdot
.64706 .31373 Mdot
.70196 .58431 Mdot
.76078 .38824 Mdot
.70588 .38824 Mdot
.74118 .47843 Mdot
.61961 .38431 Mdot
.62353 .2549 Mdot
.47843 .11765 Mdot
.64706 .31373 Mdot
.55686 .17647 Mdot
.3451 .05098 Mdot
.43137 .27843 Mdot
.4549 .19608 Mdot
.49412 .21569 Mdot
.38039 .08627 Mdot
.18039 .12941 Mdot
.18431 .14902 Mdot
.20392 .16078 Mdot
.28627 .24706 Mdot
.56078 .40784 Mdot
.7451 .27451 Mdot
.90196 .52549 Mdot
.82353 .23922 Mdot
.83922 .41569 Mdot
.94118 .60784 Mdot
.78431 .3451 Mdot
.73333 .57647 Mdot
.63137 .51765 Mdot
.74118 .30588 Mdot
.63137 .43137 Mdot
.68627 .50196 Mdot
.57647 .37255 Mdot
.66275 .21569 Mdot
.52941 .21961 Mdot
.41569 .04706 Mdot
.4902 .13333 Mdot
.5451 .27451 Mdot
.6902 .5098 Mdot
.38431 .0902 Mdot
.43922 .14902 Mdot
.50588 .27451 Mdot
.17647 .12157 Mdot
.15294 .10196 Mdot
.15686 .09412 Mdot
.14118 .12157 Mdot
.63529 .26667 Mdot
.50196 .16471 Mdot
.6902 .17647 Mdot
.94118 .32941 Mdot
.8 .45882 Mdot
.8 .34118 Mdot
.59216 .35686 Mdot
.63137 .54902 Mdot
.6902 .53725 Mdot
.74118 .29804 Mdot
.54902 .43529 Mdot
.58824 .46667 Mdot
.72157 .44314 Mdot
.66275 .23137 Mdot
.9098 .64314 Mdot
.5098 .12157 Mdot
.47451 .11373 Mdot
.67843 .40392 Mdot
.38039 .13725 Mdot
.52157 .21961 Mdot
.36471 .04706 Mdot
.13333 0 Mdot
.15294 .0902 Mdot
.22353 .16471 Mdot
.21961 .16863 Mdot
.81176 .8 Mdot
.69412 .23137 Mdot
.9098 .60392 Mdot
.95294 .36471 Mdot
.82745 .25098 Mdot
1 .76471 Mdot
.72941 .32157 Mdot
.63529 .53725 Mdot
.61569 .54902 Mdot
.81961 .58824 Mdot
.66667 .27843 Mdot
.53725 .45882 Mdot
.52941 .4549 Mdot
.70196 .34118 Mdot
.63529 .26667 Mdot
.75294 .48235 Mdot
.5451 .13333 Mdot
.57647 .21961 Mdot
.54902 .33725 Mdot
.59608 .3098 Mdot
.49804 .16863 Mdot
.52549 .15294 Mdot
.1451 .04314 Mdot
.16471 .10196 Mdot
.19608 .1451 Mdot
.18824 .16471 Mdot
.44314 .21176 Mdot
.63137 .23529 Mdot
.96471 .5451 Mdot
.83922 .21176 Mdot
.83529 .32157 Mdot
.67451 .34902 Mdot
.65098 .43137 Mdot
.59216 .52549 Mdot
.60784 .54902 Mdot
.76471 .44706 Mdot
.56863 .27843 Mdot
.52941 .48235 Mdot
.61176 .48627 Mdot
.61176 .2902 Mdot
.60784 .32157 Mdot
.74118 .40392 Mdot
.49412 .07843 Mdot
.58824 .18431 Mdot
.23922 .07059 Mdot
.5451 .24314 Mdot
.55294 .22353 Mdot
.38824 .00392 Mdot
.19216 .10196 Mdot
.15686 .09412 Mdot
.24314 .20784 Mdot
.12549 .0902 Mdot
.57647 .44706 Mdot
.7451 .26667 Mdot
.83922 .51765 Mdot
.61176 .01176 Mdot
.80392 .25882 Mdot
.89412 .65882 Mdot
.66667 .44314 Mdot
.63137 .55686 Mdot
.59608 .53725 Mdot
.81176 .61961 Mdot
.69804 .3098 Mdot
.54902 .48235 Mdot
.56078 .48627 Mdot
.54118 .24314 Mdot
.63137 .43922 Mdot
.83922 .60392 Mdot
.40392 0 Mdot
.4902 .07059 Mdot
.69412 .45098 Mdot
.54902 .32549 Mdot
.53725 .23922 Mdot
.59608 .17647 Mdot
.1451 .00784 Mdot
.26667 .20392 Mdot
.15294 .12157 Mdot
.17255 .13333 Mdot
.85882 .76078 Mdot
.68235 .25882 Mdot
.5451 .17647 Mdot
.70588 .22745 Mdot
.71373 .08235 Mdot
.92549 .51373 Mdot
.64706 .36863 Mdot
.65882 .56078 Mdot
.61961 .55294 Mdot
.61961 .54902 Mdot
.72941 .40784 Mdot
.63137 .40784 Mdot
.52941 .48627 Mdot
.67451 .41569 Mdot
.57647 .45098 Mdot
.49804 .38431 Mdot
.79216 .46275 Mdot
.43529 .03137 Mdot
.37647 .02353 Mdot
.24314 .08235 Mdot
.59608 .35294 Mdot
.36863 .07059 Mdot
.77647 .27451 Mdot
.18039 .07451 Mdot
.24314 .18431 Mdot
.15686 .12549 Mdot
.15686 .04706 Mdot
.8549 .76863 Mdot
.67843 .24314 Mdot
.65882 .24314 Mdot
.77255 .33333 Mdot
.76471 .14902 Mdot
.7451 .36078 Mdot
.58431 .34902 Mdot
.60392 .51765 Mdot
.68235 .6 Mdot
.62353 .55686 Mdot
.76863 .52157 Mdot
.57255 .29804 Mdot
.54118 .49412 Mdot
.61176 .33725 Mdot
.54902 .4549 Mdot
.53333 .4549 Mdot
.74902 .5098 Mdot
.72941 .3451 Mdot
.36863 .02745 Mdot
.37255 .15294 Mdot
.47843 .23137 Mdot
.51765 .2549 Mdot
.79216 .20784 Mdot
.18824 .03137 Mdot
.32941 .24706 Mdot
.21569 .16863 Mdot
.18824 .07059 Mdot
.55686 .39608 Mdot
.84314 .71765 Mdot
.77255 .26275 Mdot
.38431 .12157 Mdot
.76471 .28627 Mdot
.75294 .20392 Mdot
.93725 .70588 Mdot
.68627 .55294 Mdot
.63922 .55686 Mdot
.67059 .59608 Mdot
.61569 .5451 Mdot
.7098 .4 Mdot
.65098 .4549 Mdot
.57255 .4902 Mdot
.49412 .2549 Mdot
.52157 .47059 Mdot
.53333 .46667 Mdot
.67843 .45098 Mdot
.80392 .47059 Mdot
.2549 0 Mdot
.42353 .21176 Mdot
.39216 .13725 Mdot
.64706 .27059 Mdot
.85882 .24314 Mdot
.17255 0 Mdot
.24706 .14902 Mdot
.2 .11373 Mdot
.62353 .4549 Mdot
.55686 .36078 Mdot
1 .94902 Mdot
.75294 .26275 Mdot
.56471 .19608 Mdot
.87059 .52549 Mdot
.6902 .19216 Mdot
.85882 .62745 Mdot
.68235 .52549 Mdot
.60784 .54118 Mdot
.78431 .7098 Mdot
.63137 .56471 Mdot
.76078 .58039 Mdot
.59608 .27451 Mdot
.56863 .49412 Mdot
.55686 .28627 Mdot
.54118 .49412 Mdot
.50588 .45882 Mdot
.54118 .43529 Mdot
.72549 .49804 Mdot
.77255 .44314 Mdot
.56078 .3451 Mdot
.48627 .19608 Mdot
.34902 .01176 Mdot
.8549 .18824 Mdot
.43137 .07059 Mdot
.20784 .05098 Mdot
.19216 .05098 Mdot
.46275 .27451 Mdot
.57255 .36863 Mdot
.5451 .36471 Mdot
.68627 .52549 Mdot
.75686 .25098 Mdot
.77647 .4549 Mdot
.87843 .5451 Mdot
.9098 .52549 Mdot
1 .85882 Mdot
.37647 .27451 Mdot
.59608 .52941 Mdot
.7098 .63529 Mdot
.61961 .56471 Mdot
.78824 .59216 Mdot
.59216 .2902 Mdot
.62745 .4902 Mdot
.57647 .38039 Mdot
.52157 .47451 Mdot
.52157 .47451 Mdot
.52549 .45882 Mdot
.56863 .41176 Mdot
.83137 .52549 Mdot
.36863 .19216 Mdot
.57255 .23137 Mdot
.53725 .07059 Mdot
.87451 .18431 Mdot
.73725 .32549 Mdot
.18431 0 Mdot
.21961 0 Mdot
.42353 .23922 Mdot
.64314 .43922 Mdot
.56471 .34902 Mdot
.99216 .96078 Mdot
.68627 .21569 Mdot
.78039 .27451 Mdot
.84706 .47843 Mdot
.71373 .42745 Mdot
.93725 .65882 Mdot
.72549 .55686 Mdot
.61569 .54118 Mdot
.61961 .55294 Mdot
.82353 .74902 Mdot
.63529 .55686 Mdot
.73725 .36471 Mdot
.63137 .48627 Mdot
.56471 .28627 Mdot
.52941 .48235 Mdot
.52549 .48235 Mdot
.52157 .48235 Mdot
.53333 .45882 Mdot
.57647 .42745 Mdot
.77647 .50588 Mdot
.66667 .44706 Mdot
.5451 .07843 Mdot
.74118 .0549 Mdot
.8902 .27451 Mdot
.71373 .26667 Mdot
.56471 .14118 Mdot
.64314 .27843 Mdot
.49804 .34118 Mdot
.54902 .34902 Mdot
.3451 .16863 Mdot
.53333 .23529 Mdot
.77647 .28627 Mdot
.6902 .19608 Mdot
.93333 .6902 Mdot
.75686 .57255 Mdot
.75686 .44314 Mdot
.49804 .43137 Mdot
.61961 .5451 Mdot
.62745 .56078 Mdot
.6902 .62745 Mdot
.73725 .59216 Mdot
.6 .24706 Mdot
.76078 .4902 Mdot
.57647 .46667 Mdot
.52157 .47843 Mdot
.52941 .48235 Mdot
.52549 .48627 Mdot
.52157 .47059 Mdot
.58824 .36863 Mdot
.42353 .28235 Mdot
.8902 .44706 Mdot
.76471 .13333 Mdot
.86667 .17647 Mdot
.91765 .30196 Mdot
.8549 .32941 Mdot
.83529 .27059 Mdot
.35294 .14902 Mdot
.51373 .37255 Mdot
.6 .36078 Mdot
.4549 .37647 Mdot
.67451 .22745 Mdot
.69804 .2549 Mdot
.78824 .28627 Mdot
.99216 .79608 Mdot
.70588 .41961 Mdot
.69804 .46667 Mdot
.44706 .38824 Mdot
.62745 .56078 Mdot
.61961 .55294 Mdot
.71373 .63922 Mdot
.80392 .58824 Mdot
.63922 .29804 Mdot
.62745 .31765 Mdot
.52549 .47843 Mdot
.5451 .50196 Mdot
.52549 .48235 Mdot
.52157 .47451 Mdot
.54902 .4902 Mdot
.58039 .22745 Mdot
.47451 .36078 Mdot
.83137 .26667 Mdot
.78431 .11765 Mdot
.9098 .22745 Mdot
.88235 .23529 Mdot
.90588 .3451 Mdot
.75686 .23922 Mdot
.47843 .2902 Mdot
.40784 .30196 Mdot
.6 .37255 Mdot
.81569 .72157 Mdot
.74118 .26275 Mdot
.78824 .30196 Mdot
.7451 .29412 Mdot
.52941 .26275 Mdot
.79216 .30588 Mdot
.61569 .51765 Mdot
.41569 .35686 Mdot
.61569 .54118 Mdot
.63922 .56471 Mdot
.75686 .68235 Mdot
.7098 .4 Mdot
.69804 .33725 Mdot
.67843 .45098 Mdot
.55686 .49804 Mdot
.52941 .48627 Mdot
.53725 .4902 Mdot
.53333 .48235 Mdot
.56471 .40392 Mdot
.76471 .44314 Mdot
.93333 .7451 Mdot
.85882 .26667 Mdot
.82353 .17255 Mdot
.88627 .23922 Mdot
.87451 .20392 Mdot
.8549 .25098 Mdot
.49412 .10588 Mdot
.45882 .26275 Mdot
.41569 .2902 Mdot
.67451 .47451 Mdot
.56471 .23529 Mdot
.67843 .2549 Mdot
.78431 .28627 Mdot
.6549 .24706 Mdot
1 .67059 Mdot
.63529 .25882 Mdot
.60392 .5451 Mdot
.41176 .36078 Mdot
.61569 .54902 Mdot
.62353 .55686 Mdot
.80784 .72157 Mdot
.77255 .4 Mdot
.71765 .31765 Mdot
.66275 .45882 Mdot
.56863 .4902 Mdot
.54118 .4902 Mdot
.53725 .49412 Mdot
.56078 .47059 Mdot
.57255 .20392 Mdot
.87843 .7451 Mdot
.66667 .34118 Mdot
.91765 .36078 Mdot
.8549 .26275 Mdot
.87059 .23529 Mdot
.88235 .22353 Mdot
.82353 .18431 Mdot
.50588 .19216 Mdot
.49804 .30588 Mdot
.43922 .23922 Mdot
.66275 .56863 Mdot
.66275 .2549 Mdot
.83529 .48235 Mdot
.7451 .29804 Mdot
.73725 .30196 Mdot
.83137 .38431 Mdot
.68235 .41961 Mdot
.60392 .55294 Mdot
.53725 .4902 Mdot
.63137 .56471 Mdot
.63922 .57255 Mdot
.92157 .78039 Mdot
.85882 .4902 Mdot
.75294 .35294 Mdot
.68627 .43529 Mdot
.63137 .50196 Mdot
.57647 .49804 Mdot
.55686 .4902 Mdot
.59608 .38431 Mdot
.78039 .40784 Mdot
.61176 .55294 Mdot
.64706 .34118 Mdot
.94118 .43922 Mdot
.8902 .34902 Mdot
.88235 .25098 Mdot
.87451 .21961 Mdot
.8 .1451 Mdot
.51373 .15294 Mdot
.4549 .21569 Mdot
.46275 .23137 Mdot
.97255 .9451 Mdot
.66667 .21569 Mdot
.6902 .37255 Mdot
.69412 .32941 Mdot
.76863 .30588 Mdot
.81569 .31373 Mdot
.67451 .51765 Mdot
.60392 .5451 Mdot
.61569 .56471 Mdot
.63922 .57255 Mdot
.63529 .56863 Mdot
.95686 .72549 Mdot
.98039 .61176 Mdot
.82745 .43922 Mdot
.62353 .28627 Mdot
.67843 .46667 Mdot
.60784 .50196 Mdot
.61176 .48627 Mdot
.58039 .23137 Mdot
.84706 .63137 Mdot
.62745 .61961 Mdot
.41961 .16863 Mdot
.95686 .48235 Mdot
.95294 .44706 Mdot
.86275 .26275 Mdot
.86275 .20784 Mdot
.82745 .17255 Mdot
.61176 .17647 Mdot
.46275 .1451 Mdot
.45882 .21176 Mdot
.89804 .83137 Mdot
.72157 .25882 Mdot
.70588 .44314 Mdot
.56078 .28235 Mdot
.77647 .31373 Mdot
.78431 .2902 Mdot
.61961 .52157 Mdot
.61961 .55294 Mdot
.62745 .57647 Mdot
.5451 .47843 Mdot
.64314 .57647 Mdot
.78431 .43922 Mdot
.83137 .45098 Mdot
.90588 .49804 Mdot
.64706 .26275 Mdot
.69804 .40392 Mdot
.65882 .50588 Mdot
.60392 .37647 Mdot
.77255 .43529 Mdot
.63137 .56078 Mdot
.63137 .64314 Mdot
.44314 .23137 Mdot
.78824 .40392 Mdot
.94118 .48235 Mdot
.8902 .30196 Mdot
.8549 .21961 Mdot
.82353 .19608 Mdot
.66275 .16863 Mdot
.64314 .20784 Mdot
.47059 .21961 Mdot
.45098 .30196 Mdot
.72549 .28235 Mdot
.58824 .4 Mdot
.67451 .51765 Mdot
.77647 .30588 Mdot
.7451 .29804 Mdot
.58824 .52157 Mdot
.6 .54118 Mdot
.61569 .55294 Mdot
.39608 .32941 Mdot
.65882 .55686 Mdot
.85882 .40392 Mdot
.66275 .24706 Mdot
.9098 .49412 Mdot
.77255 .36863 Mdot
.65098 .27059 Mdot
.71373 .47451 Mdot
.62745 .32157 Mdot
.77647 .59216 Mdot
.62745 .63137 Mdot
.62353 .63529 Mdot
.22745 .10196 Mdot
.62745 .37647 Mdot
.91765 .49804 Mdot
.92549 .36863 Mdot
.87451 .3098 Mdot
.83529 .23137 Mdot
.77255 .22353 Mdot
.82745 .28627 Mdot
.73333 .51373 Mdot
.49804 .25098 Mdot
.7098 .2902 Mdot
.8902 .76863 Mdot
.90196 .80784 Mdot
.79216 .30196 Mdot
.61961 .28235 Mdot
.60392 .53725 Mdot
.61961 .56078 Mdot
.61961 .55686 Mdot
.29412 .24314 Mdot
.71765 .54902 Mdot
.83922 .32941 Mdot
.65098 .2 Mdot
.87843 .46275 Mdot
.8902 .45098 Mdot
.70196 .28627 Mdot
.58039 .30588 Mdot
.80784 .52157 Mdot
.63137 .57255 Mdot
.62745 .64314 Mdot
.66667 .66275 Mdot
.29412 .23529 Mdot
.87451 .71765 Mdot
.73333 .4 Mdot
.92549 .43529 Mdot
.93725 .43529 Mdot
.85098 .26275 Mdot
.77255 .2 Mdot
.8 .20392 Mdot
.69412 .51765 Mdot
.57647 .25098 Mdot
.65882 .26667 Mdot
.94118 .83529 Mdot
.63529 .52941 Mdot
.78431 .2902 Mdot
.71765 .47451 Mdot
.60392 .5451 Mdot
.62745 .56863 Mdot
.61176 .55294 Mdot
.36863 .3098 Mdot
.86275 .59216 Mdot
.8549 .31765 Mdot
.79608 .30588 Mdot
.75686 .31373 Mdot
.8549 .40784 Mdot
.82745 .41569 Mdot
.66275 .39216 Mdot
.72941 .57647 Mdot
.64314 .62745 Mdot
.63529 .63922 Mdot
.72157 .70588 Mdot
.84706 .81176 Mdot
.94902 .88235 Mdot
.69804 .5098 Mdot
.78824 .37647 Mdot
1 .53725 Mdot
.89412 .35294 Mdot
.80784 .24706 Mdot
.89804 .31373 Mdot
.64706 .53725 Mdot
.62745 .23137 Mdot
.69412 .39216 Mdot
.21569 .11765 Mdot
.57255 .36471 Mdot
.76471 .29412 Mdot
.61569 .51765 Mdot
.6 .54902 Mdot
.61176 .55686 Mdot
.6 .53725 Mdot
.43529 .37255 Mdot
.78824 .34118 Mdot
.83529 .28627 Mdot
.81961 .3098 Mdot
.67451 .22353 Mdot
.81569 .36863 Mdot
.87451 .4549 Mdot
.92549 .75686 Mdot
.63137 .59216 Mdot
.64314 .63529 Mdot
.61569 .60784 Mdot
.17255 .15686 Mdot
.90196 .88235 Mdot
.93333 .88627 Mdot
.91765 .77255 Mdot
.58431 .24706 Mdot
.89412 .49412 Mdot
.93725 .41961 Mdot
.8 .21176 Mdot
.94902 .50588 Mdot
.90588 .84706 Mdot
.74118 .31373 Mdot
.55294 .34118 Mdot
.97647 .89804 Mdot
.65882 .35686 Mdot
.65882 .27059 Mdot
.6 .54902 Mdot
.60784 .54902 Mdot
.59608 .53725 Mdot
.60784 .55294 Mdot
.54902 .38824 Mdot
.72549 .21176 Mdot
.81961 .25882 Mdot
.83922 .30588 Mdot
.68235 .20392 Mdot
.80784 .38039 Mdot
.72941 .33333 Mdot
.64706 .57255 Mdot
.62353 .61569 Mdot
.61569 .60784 Mdot
.61176 .61569 Mdot
.15686 .12941 Mdot
.92549 .88627 Mdot
.94118 .87451 Mdot
.96078 .87843 Mdot
.7451 .54902 Mdot
.67059 .31373 Mdot
.92549 .41176 Mdot
.87843 .30588 Mdot
.51765 .25098 Mdot
.60392 .39216 Mdot
.69804 .29412 Mdot
.82353 .67843 Mdot
.6549 .49804 Mdot
.70196 .28627 Mdot
.58039 .45098 Mdot
.60784 .54902 Mdot
.6 .54118 Mdot
.60784 .5451 Mdot
.61961 .56863 Mdot
.75686 .32549 Mdot
.60392 .07843 Mdot
.81176 .25098 Mdot
.82745 .28627 Mdot
.74902 .27059 Mdot
.81176 .37647 Mdot
.56471 .34902 Mdot
.62745 .61961 Mdot
.60784 .60392 Mdot
.61961 .61961 Mdot
.59608 .6 Mdot
.96471 .93333 Mdot
.92157 .80392 Mdot
.93333 .88235 Mdot
.94902 .9098 Mdot
.92157 .76078 Mdot
.51765 .17255 Mdot
.8902 .33725 Mdot
.58039 .15294 Mdot
.97255 .92941 Mdot
.6902 .3098 Mdot
.68627 .41961 Mdot
.84314 .6902 Mdot
.90196 .6549 Mdot
.64706 .26275 Mdot
.6 .54902 Mdot
.61961 .5451 Mdot
.60784 .54118 Mdot
.61176 .55294 Mdot
.80392 .59216 Mdot
.62353 .16863 Mdot
.57647 .0549 Mdot
.8 .22353 Mdot
.83529 .29804 Mdot
.78039 .27843 Mdot
.68627 .2549 Mdot
.63137 .59216 Mdot
.61569 .6 Mdot
.60784 .61176 Mdot
.61961 .64314 Mdot
.16471 .14902 Mdot
.97647 .87843 Mdot
.91373 .74902 Mdot
.92549 .92157 Mdot
.95686 .8902 Mdot
.97255 .87059 Mdot
.48627 .13725 Mdot
.64314 .15294 Mdot
.48627 .19216 Mdot
.33333 .23137 Mdot
.70196 .29412 Mdot
.55294 .2902 Mdot
.90588 .69804 Mdot
.63529 .2 Mdot
.62745 .4902 Mdot
.60784 .54118 Mdot
.61569 .54902 Mdot
.61569 .55686 Mdot
.64706 .57647 Mdot
.80784 .32157 Mdot
.94118 .44314 Mdot
.58431 .04706 Mdot
.8 .23137 Mdot
.85098 .3098 Mdot
.81961 .3098 Mdot
.56863 .34118 Mdot
.60392 .59608 Mdot
.61176 .61569 Mdot
.62353 .63137 Mdot
.56863 .56863 Mdot
.98824 .92941 Mdot
.69804 .48627 Mdot
.96471 .87059 Mdot
.38431 .35294 Mdot
.91765 .88627 Mdot
.97255 .87451 Mdot
.90196 .35686 Mdot
.88235 .41569 Mdot
.97647 .93333 Mdot
.61176 .26667 Mdot
.58824 .27059 Mdot
.52157 .18431 Mdot
.55686 .20392 Mdot
.61961 .31765 Mdot
.31765 .25882 Mdot
.61961 .55294 Mdot
.60784 .55294 Mdot
.61961 .56078 Mdot
.7451 .37255 Mdot
.63137 .18039 Mdot
.9451 .41176 Mdot
.57255 .02745 Mdot
.83529 .2549 Mdot
.8549 .3098 Mdot
.74902 .32941 Mdot
.60784 .6 Mdot
.62353 .62745 Mdot
.60392 .61961 Mdot
.6549 .66275 Mdot
.1098 .07059 Mdot
.56471 .34902 Mdot
.81176 .6549 Mdot
.59608 .56078 Mdot
.65882 .61961 Mdot
.9098 .87843 Mdot
.72549 .34902 Mdot
.57647 .09412 Mdot
.66667 .43529 Mdot
.41569 .27451 Mdot
.62353 .24706 Mdot
.59216 .18824 Mdot
.52549 .17647 Mdot
.74118 .29804 Mdot
.63922 .56078 Mdot
.6 .53333 Mdot
.61961 .56078 Mdot
.61569 .55686 Mdot
.78431 .57255 Mdot
.81176 .2902 Mdot
.95294 .41569 Mdot
.93725 .40784 Mdot
.66667 .09412 Mdot
.86275 .3098 Mdot
.82353 .28627 Mdot
.65098 .58039 Mdot
.62353 .63137 Mdot
.62745 .64314 Mdot
.61569 .63137 Mdot
.20392 .16863 Mdot
.51373 .32941 Mdot
.94902 .74118 Mdot
.10588 .05882 Mdot
.87451 .84314 Mdot
.52941 .49412 Mdot
.99608 .84314 Mdot
.52941 .04314 Mdot
.8549 .41961 Mdot
.77647 .73725 Mdot
.61961 .2902 Mdot
.73725 .2902 Mdot
.76078 .32549 Mdot
.79216 .32157 Mdot
.61961 .5098 Mdot
.29412 .23529 Mdot
.62353 .55686 Mdot
.60784 .55294 Mdot
.69412 .53725 Mdot
.83922 .29412 Mdot
.78431 .2549 Mdot
.94902 .4 Mdot
.95294 .38039 Mdot
.86275 .29412 Mdot
.83529 .28627 Mdot
.69804 .56863 Mdot
.62353 .62353 Mdot
.60392 .62745 Mdot
.64314 .65098 Mdot
.16863 .12549 Mdot
.77255 .65098 Mdot
.70588 .46667 Mdot
.90196 .84706 Mdot
.87843 .82745 Mdot
.8 .75686 Mdot
.96078 .86667 Mdot
.87451 .32157 Mdot
.88627 .36078 Mdot
.97647 .95294 Mdot
.58039 .27843 Mdot
.74118 .27451 Mdot
.76863 .30588 Mdot
.77647 .31765 Mdot
.62745 .53333 Mdot
.40392 .3451 Mdot
.63137 .56471 Mdot
.61176 .55686 Mdot
.83922 .6 Mdot
.83137 .27843 Mdot
.60392 .08627 Mdot
.95294 .42353 Mdot
1 .45882 Mdot
.8549 .30196 Mdot
.81176 .28627 Mdot
.63922 .58039 Mdot
.62745 .63137 Mdot
.61569 .64706 Mdot
.52549 .53333 Mdot
.21176 .14902 Mdot
.93333 .79216 Mdot
.80392 .56863 Mdot
.58824 .52941 Mdot
.52157 .47843 Mdot
.66275 .62353 Mdot
1 .87059 Mdot
.75294 .17647 Mdot
.88627 .46667 Mdot
.82353 .73725 Mdot
.67451 .31373 Mdot
.77647 .29412 Mdot
.81569 .31765 Mdot
.73725 .51373 Mdot
.60392 .55294 Mdot
.4 .34118 Mdot
.61961 .55686 Mdot
.69804 .56471 Mdot
.82745 .30196 Mdot
.78824 .26667 Mdot
.57255 .0549 Mdot
.9098 .29804 Mdot
.82745 .24706 Mdot
.8549 .3098 Mdot
.61569 .40784 Mdot
.57255 .57255 Mdot
.43137 .46275 Mdot
.27843 .30196 Mdot
.21961 .19216 Mdot
.76078 .61961 Mdot
.92157 .72157 Mdot
.9098 .86667 Mdot
.68627 .65098 Mdot
.63137 .58824 Mdot
.94118 .90196 Mdot
.93333 .4902 Mdot
.86275 .26275 Mdot
.96863 .92549 Mdot
.55686 .2902 Mdot
.64706 .22353 Mdot
.81569 .31765 Mdot
.74118 .48235 Mdot
.60392 .55294 Mdot
.34902 .2902 Mdot
.63137 .56863 Mdot
.7098 .55294 Mdot
.82745 .3098 Mdot
.75294 .26667 Mdot
.49804 0 Mdot
.90196 .27451 Mdot
.82353 .23529 Mdot
.83922 .29412 Mdot
.63529 .43922 Mdot
.27843 .27843 Mdot
.30196 .32549 Mdot
.4549 .47843 Mdot
.20784 .18039 Mdot
.36471 .22353 Mdot
.93333 .73333 Mdot
.8902 .8549 Mdot
.94118 .9098 Mdot
.97255 .93725 Mdot
.92549 .89804 Mdot
.96863 .58431 Mdot
.87451 .29804 Mdot
.96863 .92549 Mdot
.53725 .31765 Mdot
.72549 .27059 Mdot
.8 .31373 Mdot
.57647 .46275 Mdot
.6 .54118 Mdot
.25882 .2 Mdot
.63922 .57255 Mdot
.72157 .33725 Mdot
.80392 .2902 Mdot
.76078 .25882 Mdot
.48235 0 Mdot
.99216 .42745 Mdot
.84706 .27843 Mdot
.75686 .2902 Mdot
.45882 .45098 Mdot
.55294 .55686 Mdot
.61176 .62745 Mdot
.59216 .58431 Mdot
.19608 .12549 Mdot
1 .87451 Mdot
.78431 .65882 Mdot
.24706 .19608 Mdot
.22745 .19608 Mdot
.6902 .65882 Mdot
.98824 .89412 Mdot
.90196 .43922 Mdot
.4 .10588 Mdot
.69412 .60784 Mdot
.69412 .34118 Mdot
.77647 .27451 Mdot
.70588 .48235 Mdot
.59608 .53725 Mdot
.62353 .57255 Mdot
.62745 .56863 Mdot
.82353 .47843 Mdot
.80784 .28627 Mdot
.94118 .4549 Mdot
.91765 .39216 Mdot
.91373 .33725 Mdot
.84706 .27451 Mdot
.81176 .29804 Mdot
.63529 .59216 Mdot
.61569 .60784 Mdot
.61176 .61569 Mdot
.59216 .58431 Mdot
.15294 .11765 Mdot
.87843 .71765 Mdot
.55686 .4 Mdot
.81176 .76078 Mdot
.28627 .24314 Mdot
.2902 .24706 Mdot
.92157 .89412 Mdot
.81569 .48627 Mdot
.89412 .50196 Mdot
.73333 .67843 Mdot
.71765 .32941 Mdot
.76471 .27843 Mdot
.60392 .45098 Mdot
.59608 .53725 Mdot
.61961 .57255 Mdot
.63922 .55294 Mdot
.82353 .34118 Mdot
.70588 .28627 Mdot
.88235 .27059 Mdot
.91373 .35294 Mdot
.98824 .49804 Mdot
.84706 .28627 Mdot
.65882 .2902 Mdot
.58431 .58824 Mdot
.6 .6 Mdot
.6 .59608 Mdot
.67451 .65882 Mdot
.98431 .90196 Mdot
.91373 .68235 Mdot
.95686 .89804 Mdot
.34902 .29804 Mdot
.97647 .90588 Mdot
.9451 .92549 Mdot
.93333 .88235 Mdot
.21176 0 Mdot
.46275 .25882 Mdot
.54118 .37255 Mdot
.76078 .32549 Mdot
.68235 .32157 Mdot
.54902 .47059 Mdot
.61176 .55294 Mdot
.37255 .32157 Mdot
.77255 .39608 Mdot
.81176 .30196 Mdot
.89412 .31765 Mdot
.93725 .3451 Mdot
.97255 .4549 Mdot
.83529 .28627 Mdot
.79608 .29804 Mdot
.62353 .59216 Mdot
.59608 .58824 Mdot
.59216 .58824 Mdot
.58431 .56863 Mdot
.13333 .07843 Mdot
.91765 .66667 Mdot
.67059 .53725 Mdot
.81961 .78824 Mdot
.33725 .2549 Mdot
.5098 .47451 Mdot
.89412 .88627 Mdot
.36078 .20392 Mdot
.87059 .4902 Mdot
.92157 .85882 Mdot
.64706 .28235 Mdot
.68235 .26667 Mdot
.54902 .45098 Mdot
.59608 .54118 Mdot
.61176 .56863 Mdot
.77255 .38431 Mdot
.81176 .2902 Mdot
.87843 .29804 Mdot
.94902 .38824 Mdot
.85098 .32941 Mdot
.83529 .30196 Mdot
.79216 .3098 Mdot
.61569 .58824 Mdot
.61176 .60784 Mdot
.58431 .58039 Mdot
.59216 .58039 Mdot
.20392 .13725 Mdot
.74118 .47451 Mdot
.96471 .84706 Mdot
.59216 .54902 Mdot
.82353 .75686 Mdot
.50196 .47451 Mdot
.8902 .8902 Mdot
.32941 .17647 Mdot
.86667 .4902 Mdot
.88235 .76863 Mdot
.67451 .26667 Mdot
.70588 .43529 Mdot
.55686 .48235 Mdot
.60392 .55294 Mdot
.65098 .49804 Mdot
.82745 .31765 Mdot
.47451 .03137 Mdot
.89804 .26275 Mdot
.66667 .12941 Mdot
.72941 .24706 Mdot
.84706 .30588 Mdot
.61176 .41569 Mdot
.62745 .61961 Mdot
.60784 .61176 Mdot
.59608 .59216 Mdot
.16471 .12941 Mdot
.85882 .69412 Mdot
.67451 .44314 Mdot
.93725 .90196 Mdot
.48235 .42745 Mdot
.44314 .39216 Mdot
.89804 .8902 Mdot
.93725 .87843 Mdot
.53333 .23137 Mdot
.4902 .40392 Mdot
.62353 .3098 Mdot
.61176 .31765 Mdot
.56078 .45882 Mdot
.58824 .53725 Mdot
.7098 .54902 Mdot
.82353 .31373 Mdot
.63922 .16078 Mdot
.89804 .27843 Mdot
.75294 .22745 Mdot
.72941 .2 Mdot
.83137 .29412 Mdot
.64706 .46667 Mdot
.61176 .61176 Mdot
.60392 .59608 Mdot
.6 .58431 Mdot
.17647 .14118 Mdot
.49412 .34118 Mdot
1 .79608 Mdot
.39216 .35686 Mdot
.9098 .84314 Mdot
.84706 .79608 Mdot
.90196 .90196 Mdot
.94118 .88235 Mdot
.54902 .25098 Mdot
.73725 .67059 Mdot
.83137 .56471 Mdot
.72157 .49804 Mdot
.56078 .43137 Mdot
.56863 .51373 Mdot
.8 .56471 Mdot
.81961 .30196 Mdot
.54118 .07843 Mdot
.88627 .28627 Mdot
.69412 .15294 Mdot
.81961 .27451 Mdot
.80784 .29412 Mdot
.67059 .58431 Mdot
.60392 .60392 Mdot
.59608 .59216 Mdot
.59608 .58824 Mdot
.21569 .16863 Mdot
.72941 .59216 Mdot
.60392 .41569 Mdot
.20784 .16471 Mdot
.40784 .36078 Mdot
.48235 .44706 Mdot
.89412 .89412 Mdot
.94902 .86275 Mdot
.88627 .49412 Mdot
.75686 .69804 Mdot
.63922 .38431 Mdot
.54118 .35294 Mdot
.56078 .44314 Mdot
.61569 .5451 Mdot
.78824 .35294 Mdot
.82353 .29412 Mdot
.94118 .45098 Mdot
.96471 .41569 Mdot
.63529 .12157 Mdot
.81176 .25098 Mdot
.62745 .32157 Mdot
.60392 .60784 Mdot
.62353 .61569 Mdot
.59216 .56863 Mdot
.52941 .5098 Mdot
.9451 .89804 Mdot
.6 .42353 Mdot
.96863 .89804 Mdot
.15294 .14118 Mdot
.54902 .48627 Mdot
.94902 .93725 Mdot
.90196 .8902 Mdot
.2549 .03922 Mdot
.33333 .13725 Mdot
.78431 .63137 Mdot
.72941 .53725 Mdot
.60392 .40392 Mdot
.56863 .47059 Mdot
.79216 .50588 Mdot
.82353 .30196 Mdot
.77255 .27843 Mdot
.92549 .38824 Mdot
.83137 .31765 Mdot
.59216 .05098 Mdot
.76078 .31373 Mdot
.61176 .61176 Mdot
.60784 .60784 Mdot
.61569 .60784 Mdot
.6 .56863 Mdot
.36078 .32549 Mdot
.97647 .87451 Mdot
.96078 .81961 Mdot
.44314 .43137 Mdot
.83922 .79608 Mdot
.52157 .49412 Mdot
.89804 .89804 Mdot
.4 .25882 Mdot
.87451 .49412 Mdot
.38824 .33725 Mdot
.84706 .6549 Mdot
.70196 .50196 Mdot
.62745 .43137 Mdot
.63922 .48235 Mdot
.79608 .31373 Mdot
.81961 .29412 Mdot
.7098 .21569 Mdot
.92941 .4 Mdot
.85098 .31765 Mdot
.79608 .2549 Mdot
.65098 .59608 Mdot
.59216 .59608 Mdot
.58039 .58431 Mdot
.56863 .55686 Mdot
.20392 .16471 Mdot
.94118 .88627 Mdot
.85098 .6549 Mdot
.78039 .72941 Mdot
.15686 .14118 Mdot
.55294 .51373 Mdot
.89412 .8902 Mdot
.97647 .91373 Mdot
.78431 .43137 Mdot
.83529 .80784 Mdot
.81569 .65882 Mdot
.86275 .68235 Mdot
.49412 .28627 Mdot
.62745 .45098 Mdot
.78824 .32157 Mdot
.82745 .3098 Mdot
.63137 .14118 Mdot
.97255 .45098 Mdot
.93725 .40392 Mdot
.77647 .24314 Mdot
.61961 .58431 Mdot
.61569 .61961 Mdot
.59216 .59608 Mdot
.56471 .56078 Mdot
.18824 .14902 Mdot
.93725 .88627 Mdot
.74902 .52549 Mdot
.98824 .94118 Mdot
.78039 .76863 Mdot
.26667 .24314 Mdot
.8902 .88627 Mdot
.99216 .91373 Mdot
.85098 .47843 Mdot
.73725 .70588 Mdot
.72157 .58039 Mdot
.8 .63922 Mdot
.43922 .27059 Mdot
.76078 .4549 Mdot
.77647 .30196 Mdot
.81961 .30196 Mdot
.68235 .18431 Mdot
.97647 .45882 Mdot
.97647 .4549 Mdot
.68627 .31373 Mdot
.61961 .61176 Mdot
.57255 .57255 Mdot
.47059 .47843 Mdot
.45882 .44706 Mdot
.93333 .91373 Mdot
.79216 .66667 Mdot
.55294 .37647 Mdot
.90196 .89412 Mdot
.91765 .91373 Mdot
.85882 .84706 Mdot
.89804 .89412 Mdot
.28627 .1098 Mdot
.90196 .64706 Mdot
.63137 .5451 Mdot
.88235 .76078 Mdot
.86275 .7451 Mdot
.68627 .45098 Mdot
.70196 .27451 Mdot
.8 .3098 Mdot
.83529 .33333 Mdot
.60392 .09804 Mdot
.95294 .41961 Mdot
.71373 .30196 Mdot
.49412 .48627 Mdot
.2902 .29412 Mdot
.3451 .35294 Mdot
.47843 .48235 Mdot
.56863 .5451 Mdot
.94902 .85098 Mdot
.61961 .41176 Mdot
.92157 .87843 Mdot
.90588 .87843 Mdot
.78039 .77255 Mdot
.89804 .89804 Mdot
.43137 .27843 Mdot
.89412 .60784 Mdot
.66667 .60784 Mdot
.93725 .8902 Mdot
.55294 .39608 Mdot
.63529 .23922 Mdot
.77255 .31373 Mdot
.80784 .31765 Mdot
.76078 .24706 Mdot
.63137 .1098 Mdot
.71373 .33725 Mdot
.36471 .35686 Mdot
.41176 .40392 Mdot
.53725 .53725 Mdot
.67451 .6549 Mdot
.83529 .80784 Mdot
.93725 .82745 Mdot
.97647 .79608 Mdot
.96863 .8549 Mdot
.92549 .8549 Mdot
.61569 .61569 Mdot
.90196 .89804 Mdot
.2902 .11373 Mdot
.92157 .71765 Mdot
.98039 .95686 Mdot
.58039 .34902 Mdot
.61569 .21961 Mdot
.74118 .2902 Mdot
.80784 .31765 Mdot
.80392 .29412 Mdot
.71373 .26667 Mdot
.58039 .54118 Mdot
.59608 .58039 Mdot
.61176 .59608 Mdot
.57255 .55294 Mdot
.08627 .05882 Mdot
.94118 .87843 Mdot
.86667 .65882 Mdot
1 .88627 Mdot
.8902 .67843 Mdot
.9098 .88627 Mdot
.8902 .89412 Mdot
.96863 .84706 Mdot
.83922 .47451 Mdot
.79216 .67843 Mdot
.57255 .23137 Mdot
.69804 .26275 Mdot
.78824 .32549 Mdot
.81569 .32157 Mdot
.72549 .36863 Mdot
.57647 .56078 Mdot
.58431 .56863 Mdot
.57255 .55294 Mdot
.63529 .60392 Mdot
.64706 .62745 Mdot
.96078 .8549 Mdot
.77255 .58431 Mdot
.89804 .68627 Mdot
.62353 .38431 Mdot
.9098 .87059 Mdot
.89412 .8902 Mdot
.26275 .07451 Mdot
.9451 .72549 Mdot
.66275 .46667 Mdot
.60784 .24706 Mdot
.70588 .27451 Mdot
.79608 .32549 Mdot
.73725 .35686 Mdot
.58039 .54902 Mdot
.57647 .55294 Mdot
.56863 .5451 Mdot
.56078 .52941 Mdot
.23137 .20784 Mdot
.97255 .89412 Mdot
.63137 .45098 Mdot
.94902 .72157 Mdot
.56471 .28235 Mdot
.93725 .85098 Mdot
.8902 .86275 Mdot
.5098 .3098 Mdot
.91373 .66275 Mdot
.71373 .56471 Mdot
.58431 .2549 Mdot
.71373 .27059 Mdot
.76078 .33725 Mdot
.64314 .52549 Mdot
.56471 .54902 Mdot
.56471 .54118 Mdot
.55294 .52941 Mdot
.19216 .15294 Mdot
.9451 .87843 Mdot
.76078 .60784 Mdot
.86275 .72157 Mdot
.74902 .39216 Mdot
.52157 .38039 Mdot
.87451 .78431 Mdot
.93333 .76863 Mdot
.83529 .41569 Mdot
.98824 .9098 Mdot
.54902 .2902 Mdot
.62745 .23529 Mdot
.70196 .31373 Mdot
.57647 .5098 Mdot
.56078 .52941 Mdot
.57647 .54902 Mdot
.54902 .51765 Mdot
.19608 .16471 Mdot
.65882 .56078 Mdot
.58824 .44706 Mdot
.48627 .22745 Mdot
.62353 .40392 Mdot
.54902 .35294 Mdot
.71765 .6 Mdot
.89412 .60392 Mdot
.86667 .47843 Mdot
.90588 .81176 Mdot
.53333 .26275 Mdot
.63529 .26275 Mdot
.60392 .4902 Mdot
.55686 .51373 Mdot
.56471 .54118 Mdot
.54118 .5098 Mdot
.20784 .18039 Mdot
.94118 .88627 Mdot
.82353 .67843 Mdot
.82353 .6902 Mdot
.56078 .29804 Mdot
.47059 .24314 Mdot
.40392 .20784 Mdot
.6 .28235 Mdot
.83137 .37647 Mdot
.93725 .80784 Mdot
.57255 .27843 Mdot
.59608 .45882 Mdot
.54902 .4549 Mdot
.53333 .50196 Mdot
.55294 .49804 Mdot
.22745 .19216 Mdot
.92157 .90196 Mdot
.77647 .65882 Mdot
.97647 .90196 Mdot
.63922 .33333 Mdot
.44314 .24706 Mdot
.57647 .2902 Mdot
.41961 .06667 Mdot
.83922 .3098 Mdot
.98431 .8902 Mdot
.90588 .78431 Mdot
.55686 .37255 Mdot
.52157 .43529 Mdot
.55686 .47059 Mdot
.22353 .14118 Mdot
.90196 .8902 Mdot
.5098 .45098 Mdot
.96078 .92157 Mdot
.73725 .38039 Mdot
.51765 .41961 Mdot
.61569 .23137 Mdot
.48627 .1451 Mdot
.83922 .24706 Mdot
.97647 .96078 Mdot
.75686 .62745 Mdot
.59608 .43529 Mdot
.49804 .41961 Mdot
.53333 .35686 Mdot
.80392 .70588 Mdot
.92157 .87843 Mdot
.91765 .89804 Mdot
.41961 .28235 Mdot
.54902 .38824 Mdot
.63137 .36471 Mdot
.4549 .18824 Mdot
.83137 .2549 Mdot
.87451 .62745 Mdot
.83137 .75686 Mdot
.63529 .54902 Mdot
.8 .5451 Mdot
.30588 .04706 Mdot
.94118 .8 Mdot
.93725 .87843 Mdot
.91373 .8902 Mdot
.6902 .47451 Mdot
.57255 .52157 Mdot
.53725 .28235 Mdot
.70196 .23922 Mdot
.84314 .31765 Mdot
.98039 .94118 Mdot
.65098 .58431 Mdot
.63529 .3451 Mdot
.4902 .15294 Mdot
.94902 .7098 Mdot
.94118 .81176 Mdot
.92549 .8549 Mdot
.49412 .34902 Mdot
.69804 .63922 Mdot
.87059 .67451 Mdot
.81176 .23137 Mdot
.87059 .53333 Mdot
.86667 .79216 Mdot
.87059 .57647 Mdot
.72549 .28627 Mdot
.88235 .53725 Mdot
.96863 .74902 Mdot
1 .85882 Mdot
.91765 .88627 Mdot
.7451 .64314 Mdot
.61961 .21176 Mdot
.83922 .28235 Mdot
1 .95686 Mdot
.84706 .59608 Mdot
.81961 .35686 Mdot
.62745 .16078 Mdot
.86667 .53333 Mdot
.97255 .77647 Mdot
.92941 .82353 Mdot
.48627 .33725 Mdot
.83529 .28235 Mdot
.87059 .47843 Mdot
.98824 .93725 Mdot
.85098 .62745 Mdot
.91765 .34902 Mdot
.66667 .16471 Mdot
.73725 .34118 Mdot
.95294 .6549 Mdot
.98824 .72941 Mdot
.79608 .37647 Mdot
.82745 .35686 Mdot
.99216 .95686 Mdot
.80784 .37255 Mdot
.92157 .3098 Mdot
.8549 .33725 Mdot
.61569 .20784 Mdot
.77255 .43137 Mdot
.49804 .16863 Mdot
.82353 .35294 Mdot
.98824 .95686 Mdot
.78824 .42353 Mdot
.82745 .22745 Mdot
.88235 .36471 Mdot
.82353 .43137 Mdot
.63922 .23137 Mdot
.85882 .51373 Mdot
.76078 .48235 Mdot
.62353 .47059 Mdot
.8 .3098 Mdot
.75294 .29412 Mdot
.75686 .46275 Mdot
.87451 .53725 Mdot
.84706 .58039 Mdot
.56863 .38431 Mdot
.96078 .9098 Mdot
.75294 .45098 Mdot
.8 .53725 Mdot
.87451 .7451 Mdot
.9451 .78039 Mdot
.92549 .80392 Mdot
.85098 .78824 Mdot
.8902 .76863 Mdot
.93725 .79216 Mdot
.99216 .94902 Mdot
.99216 .9451 Mdot
.98824 .9451 Mdot
.628 .126 .941 r
.90588 .89804 Mdot
.49412 .48235 Mdot
.8 .79216 Mdot
.17647 .1451 Mdot
.18039 .15294 Mdot
.13333 .0902 Mdot
.32157 .27059 Mdot
.36863 .34902 Mdot
.20784 .15686 Mdot
.28627 .23137 Mdot
.24314 .22353 Mdot
.21569 .16471 Mdot
.26275 .20392 Mdot
.23529 .18824 Mdot
.17255 .12549 Mdot
.20392 .14902 Mdot
.3098 .23529 Mdot
.83922 .83137 Mdot
.2902 .21961 Mdot
.23922 .18431 Mdot
.2902 .23137 Mdot
1 .95294 Mdot
.79608 .72157 Mdot
.27451 .21569 Mdot
.26667 .2 Mdot
.27059 .20392 Mdot
.9098 .79608 Mdot
.83529 .73725 Mdot
.72549 .49412 Mdot
.1451 .07059 Mdot
.18431 .12549 Mdot
.24706 .17647 Mdot
.16863 .13725 Mdot
.41569 .40784 Mdot
.55686 .54902 Mdot
.53725 .25882 Mdot
.64314 .4549 Mdot
.62353 .2 Mdot
.15686 .0549 Mdot
.21569 .16863 Mdot
.27843 .21176 Mdot
.17647 .13725 Mdot
.90196 .81961 Mdot
.67451 .67059 Mdot
.11765 .09412 Mdot
.39216 .38824 Mdot
.61176 .23137 Mdot
.60392 .39216 Mdot
.78431 .27059 Mdot
.25882 .04706 Mdot
.16863 .12157 Mdot
.25098 .19216 Mdot
.19216 .15294 Mdot
.34902 .18039 Mdot
.53725 .39608 Mdot
.85882 .73725 Mdot
.94902 .94118 Mdot
.1098 .08627 Mdot
.09412 .07451 Mdot
.83922 .83922 Mdot
.61176 .16863 Mdot
.67843 .41961 Mdot
.80784 .27059 Mdot
.21176 .02353 Mdot
.18824 .12941 Mdot
.24314 .2 Mdot
.18824 .13333 Mdot
.47843 .18824 Mdot
.34902 .0549 Mdot
.40392 .13333 Mdot
.55294 .42745 Mdot
.85098 .73725 Mdot
.99608 .9451 Mdot
.12549 .10588 Mdot
.22353 .18431 Mdot
.07059 .07451 Mdot
.71373 .23137 Mdot
.72549 .45098 Mdot
.74902 .28235 Mdot
.73725 .20392 Mdot
.22745 .12157 Mdot
.2 .14902 Mdot
.16078 .12157 Mdot
.22353 .01961 Mdot
.45882 .09804 Mdot
.43529 .0549 Mdot
.35294 .12549 Mdot
.32941 .1451 Mdot
.37647 .24314 Mdot
.61176 .5098 Mdot
.89804 .80392 Mdot
1 .95686 Mdot
.10196 .08627 Mdot
.21961 .17647 Mdot
.20392 .16471 Mdot
.31373 .31765 Mdot
.82353 .20784 Mdot
.56471 .25098 Mdot
.81961 .26667 Mdot
.83529 .3098 Mdot
.21961 .10588 Mdot
.20392 .15294 Mdot
.19216 .13725 Mdot
.54118 .2 Mdot
.59608 .23922 Mdot
.55294 .11373 Mdot
.52157 .35686 Mdot
.32157 .13725 Mdot
.29804 .1451 Mdot
.31373 .13333 Mdot
.4902 .24314 Mdot
.61569 .47843 Mdot
.11373 .09804 Mdot
.26275 .23137 Mdot
.19216 .14902 Mdot
.0902 .07451 Mdot
.86275 .59608 Mdot
.69412 .15686 Mdot
.81961 .38824 Mdot
.86667 .27451 Mdot
.72941 .23137 Mdot
.25098 .10196 Mdot
.22745 .15686 Mdot
.27843 .08627 Mdot
.68235 .32549 Mdot
.53725 .17647 Mdot
.58431 .20784 Mdot
.72157 .56078 Mdot
.59216 .41961 Mdot
.4902 .30588 Mdot
.41176 .16863 Mdot
.40784 .08627 Mdot
.36471 .23137 Mdot
.12157 .10196 Mdot
.16078 .12941 Mdot
.16863 .13333 Mdot
.1098 .10196 Mdot
.82745 .23529 Mdot
.99216 .47059 Mdot
.80392 .23529 Mdot
.86667 .24706 Mdot
.69412 .2 Mdot
.28627 .0902 Mdot
.2549 .10196 Mdot
.47843 .05098 Mdot
.51373 .18039 Mdot
.47843 .12549 Mdot
.42353 .20784 Mdot
.35686 .20784 Mdot
.71373 .52941 Mdot
.62745 .45882 Mdot
.48235 .1451 Mdot
.53333 .16471 Mdot
.39608 .32157 Mdot
.12549 .09412 Mdot
.13725 .09412 Mdot
.13725 .10196 Mdot
.09412 .0902 Mdot
.83922 .19216 Mdot
.84706 .27843 Mdot
.84706 .22745 Mdot
.8549 .22353 Mdot
.79608 .25098 Mdot
.34902 .06275 Mdot
.32157 .03529 Mdot
.77255 .23529 Mdot
.64706 .32941 Mdot
.49804 .13333 Mdot
.78431 .61569 Mdot
.30196 .16471 Mdot
.55294 .32549 Mdot
.64706 .49804 Mdot
.61961 .22353 Mdot
.55294 .15294 Mdot
.0549 .00784 Mdot
.12549 .09412 Mdot
.34902 .30588 Mdot
.1451 .1098 Mdot
.12549 .12157 Mdot
.86275 .21961 Mdot
.87059 .24706 Mdot
.85098 .21176 Mdot
.85098 .20784 Mdot
.87059 .26275 Mdot
.51373 .07843 Mdot
.50588 .08235 Mdot
.81176 .23529 Mdot
.64314 .31765 Mdot
.63922 .29412 Mdot
.68627 .51765 Mdot
.4 .25882 Mdot
.46667 .18431 Mdot
.67451 .52941 Mdot
.61176 .22745 Mdot
.55686 .17255 Mdot
.08627 .03137 Mdot
.12941 .10588 Mdot
.34118 .29804 Mdot
.11765 .07843 Mdot
.0902 .08627 Mdot
.86275 .21961 Mdot
.88627 .23529 Mdot
.85098 .2 Mdot
.86667 .21569 Mdot
.93333 .29412 Mdot
.88235 .33725 Mdot
.85098 .34118 Mdot
.84314 .24706 Mdot
.60784 .29412 Mdot
.58431 .27843 Mdot
.67843 .52549 Mdot
.52549 .38431 Mdot
.51373 .19608 Mdot
.72549 .58039 Mdot
.6 .26667 Mdot
.59216 .25098 Mdot
.12157 .06667 Mdot
.1451 .12157 Mdot
.29804 .25882 Mdot
.11373 .07451 Mdot
.07451 .06667 Mdot
.83922 .23922 Mdot
.8902 .23922 Mdot
.8902 .23922 Mdot
.88235 .23137 Mdot
.90196 .24314 Mdot
.92157 .30588 Mdot
.87059 .3098 Mdot
.89804 .28235 Mdot
.63922 .31373 Mdot
.59608 .32549 Mdot
.66275 .51373 Mdot
.38431 .23529 Mdot
.73333 .47451 Mdot
.67059 .49412 Mdot
.52941 .32549 Mdot
.58824 .31373 Mdot
.59608 .47843 Mdot
.14118 .12157 Mdot
.14118 .1098 Mdot
.09804 .06667 Mdot
.12941 .1098 Mdot
.81961 .81569 Mdot
.86275 .22745 Mdot
.87059 .22353 Mdot
.87843 .23922 Mdot
.88235 .23529 Mdot
.87059 .21176 Mdot
.91373 .27843 Mdot
.92157 .33333 Mdot
.86667 .24706 Mdot
.53725 .21569 Mdot
.54118 .2902 Mdot
.74902 .61569 Mdot
.53725 .40392 Mdot
.51373 .16471 Mdot
.69412 .53725 Mdot
.39608 .18431 Mdot
.35686 .12941 Mdot
.72941 .63529 Mdot
.12941 .1098 Mdot
.22745 .19608 Mdot
.21961 .19608 Mdot
.11373 .10196 Mdot
.52157 .50588 Mdot
.81961 .2549 Mdot
.86667 .23137 Mdot
.88235 .26667 Mdot
.87451 .2549 Mdot
.83137 .18431 Mdot
.89412 .26667 Mdot
.92549 .2902 Mdot
.90588 .28627 Mdot
.54118 .11373 Mdot
.50588 .19216 Mdot
.34902 .18824 Mdot
.38824 .26275 Mdot
.81569 .56471 Mdot
.68627 .5098 Mdot
.46275 .23922 Mdot
.52549 .31373 Mdot
.45882 .30196 Mdot
.12157 .10588 Mdot
.12157 .10196 Mdot
.20392 .17255 Mdot
.14902 .1451 Mdot
.43529 .41961 Mdot
.73725 .71765 Mdot
.81961 .23922 Mdot
.90196 .27059 Mdot
.92157 .31765 Mdot
.89804 .29804 Mdot
.87059 .25882 Mdot
.89412 .29804 Mdot
.90588 .27451 Mdot
.87451 .24706 Mdot
.67843 .20392 Mdot
.63137 .27059 Mdot
.41176 .23529 Mdot
.31373 .19216 Mdot
.65098 .40784 Mdot
.79608 .63529 Mdot
.55686 .28235 Mdot
.7098 .47059 Mdot
.57647 .4 Mdot
.08235 .07451 Mdot
.11373 .09412 Mdot
.13725 .10588 Mdot
.12157 .12549 Mdot
.47843 .47059 Mdot
.44706 .41176 Mdot
.61176 .36078 Mdot
.92157 .26667 Mdot
.98824 .43137 Mdot
.96078 .37647 Mdot
.91373 .31373 Mdot
.95294 .39216 Mdot
.86275 .28627 Mdot
.82353 .19608 Mdot
.84706 .24706 Mdot
.79216 .30196 Mdot
.52941 .29412 Mdot
.73333 .58431 Mdot
.78039 .64706 Mdot
.53725 .30196 Mdot
.84706 .63137 Mdot
.64706 .32157 Mdot
.6 .31373 Mdot
.95294 .89412 Mdot
.19608 .16863 Mdot
.13333 .1098 Mdot
.13333 .12549 Mdot
.05098 .07451 Mdot
.50588 .4549 Mdot
.41961 .38431 Mdot
.69412 .24314 Mdot
.89804 .24314 Mdot
.97647 .40784 Mdot
.95686 .37255 Mdot
.95294 .36471 Mdot
.96863 .41176 Mdot
.91765 .3451 Mdot
.99216 .37647 Mdot
.86275 .26275 Mdot
.80784 .28627 Mdot
.78431 .57255 Mdot
.44314 .29412 Mdot
.85098 .71373 Mdot
.38039 .21961 Mdot
.46667 .16078 Mdot
.64314 .29412 Mdot
.63529 .32941 Mdot
.89412 .87059 Mdot
.09412 .08235 Mdot
.13725 .11373 Mdot
.12941 .12941 Mdot
.51373 .5451 Mdot
.53333 .48627 Mdot
.47451 .43922 Mdot
.96078 .95294 Mdot
.93725 .28235 Mdot
.92941 .3098 Mdot
.94118 .33333 Mdot
.94902 .33725 Mdot
.92157 .32941 Mdot
.94118 .37255 Mdot
.91765 .31373 Mdot
.87059 .24314 Mdot
.8902 .27059 Mdot
.65098 .32157 Mdot
.89412 .7451 Mdot
.82353 .69804 Mdot
.45098 .29804 Mdot
.8549 .69412 Mdot
.70196 .30588 Mdot
.68627 .3451 Mdot
.7451 .60784 Mdot
.34902 .37255 Mdot
.08235 .07059 Mdot
.11765 .12941 Mdot
.18824 .23529 Mdot
.54118 .50196 Mdot
.51373 .48235 Mdot
.47843 .44314 Mdot
1 .95294 Mdot
.94902 .30196 Mdot
.95294 .32157 Mdot
.88235 .29412 Mdot
.93333 .32549 Mdot
.93333 .32157 Mdot
.89412 .31373 Mdot
.93725 .32941 Mdot
.88235 .27451 Mdot
.88627 .25098 Mdot
.62353 .24706 Mdot
.99608 .78431 Mdot
.88235 .72549 Mdot
.78431 .64706 Mdot
.95294 .76471 Mdot
.77255 .36078 Mdot
.72549 .36471 Mdot
.76863 .61176 Mdot
.2549 .28627 Mdot
.3451 .34118 Mdot
.11373 .16471 Mdot
.21569 .27451 Mdot
.56078 .50588 Mdot
.35686 .33333 Mdot
.47451 .43922 Mdot
.55294 .53333 Mdot
.85882 .24314 Mdot
.93333 .2902 Mdot
.97255 .39608 Mdot
.91373 .32549 Mdot
.92941 .32157 Mdot
.94902 .34118 Mdot
.91373 .31373 Mdot
.96863 .38039 Mdot
.90196 .29804 Mdot
.84706 .28627 Mdot
.73725 .41961 Mdot
.82353 .5451 Mdot
.91765 .72941 Mdot
.92157 .75294 Mdot
.78824 .2902 Mdot
.80392 .41176 Mdot
.71765 .4 Mdot
.35294 .36863 Mdot
.21961 .22353 Mdot
.28235 .38039 Mdot
.17255 .24706 Mdot
.63137 .61176 Mdot
.33333 .31373 Mdot
.36471 .33725 Mdot
.49804 .45882 Mdot
.6549 .26667 Mdot
.91765 .27059 Mdot
.93725 .31373 Mdot
.94902 .37647 Mdot
.9451 .36471 Mdot
.91373 .30588 Mdot
.94902 .32941 Mdot
.94902 .34902 Mdot
.95686 .36471 Mdot
.90196 .30588 Mdot
.76078 .30196 Mdot
.74902 .32941 Mdot
.6902 .39608 Mdot
.82745 .57647 Mdot
.76078 .28627 Mdot
.82745 .35686 Mdot
.7098 .25098 Mdot
.81176 .71373 Mdot
.27451 .3098 Mdot
.42745 .45098 Mdot
.21569 .32157 Mdot
.09804 .15686 Mdot
.63529 .58824 Mdot
.54118 .52549 Mdot
.54902 .51765 Mdot
.76471 .73333 Mdot
.94902 .30588 Mdot
.95294 .31765 Mdot
.93725 .32941 Mdot
.92157 .32941 Mdot
.95294 .35294 Mdot
.89804 .29804 Mdot
.92549 .31765 Mdot
.93725 .3451 Mdot
.9451 .35686 Mdot
.88235 .28627 Mdot
.83137 .37647 Mdot
.76863 .33333 Mdot
.67451 .28235 Mdot
.69804 .2902 Mdot
.83922 .27059 Mdot
.85882 .34118 Mdot
.75294 .38039 Mdot
.15294 .18431 Mdot
.83922 .82745 Mdot
.15686 .25882 Mdot
.14902 .24314 Mdot
.6902 .65882 Mdot
.38431 .36471 Mdot
.60392 .57647 Mdot
.57255 .4902 Mdot
.80392 .26275 Mdot
.91765 .27843 Mdot
.9451 .31765 Mdot
.87843 .29412 Mdot
.88235 .3098 Mdot
.94902 .36078 Mdot
.94118 .32941 Mdot
.90588 .29804 Mdot
.93333 .34902 Mdot
.96863 .4 Mdot
.85882 .35294 Mdot
.8549 .40392 Mdot
.82745 .37647 Mdot
.79608 .35686 Mdot
.8549 .28235 Mdot
.86667 .28235 Mdot
.83529 .28235 Mdot
.85098 .79216 Mdot
.50196 .52549 Mdot
.89804 .91765 Mdot
.51765 .60392 Mdot
.12941 .15686 Mdot
.66275 .63529 Mdot
.31765 .29804 Mdot
.60392 .55686 Mdot
.97647 .9098 Mdot
.93725 .2902 Mdot
.93725 .30196 Mdot
.88235 .28627 Mdot
.83922 .28627 Mdot
.87059 .32549 Mdot
.93333 .33333 Mdot
.95294 .3451 Mdot
.91765 .32549 Mdot
.8902 .34902 Mdot
.92549 .30196 Mdot
.70588 .37255 Mdot
.87059 .4549 Mdot
.8549 .42745 Mdot
.87059 .38824 Mdot
.86667 .30588 Mdot
.82745 .23922 Mdot
.81961 .36471 Mdot
.60392 .63137 Mdot
.34118 .35294 Mdot
.96078 1 Mdot
.5098 .53725 Mdot
.7451 .71765 Mdot
.61961 .58824 Mdot
.30588 .28235 Mdot
.93725 .7098 Mdot
.75294 .28235 Mdot
.91765 .28235 Mdot
.90196 .2902 Mdot
.81176 .31765 Mdot
.77647 .35294 Mdot
.81176 .33333 Mdot
.92941 .30588 Mdot
.94118 .33333 Mdot
.95294 .38039 Mdot
.84314 .35294 Mdot
.81176 .3098 Mdot
.47843 .22353 Mdot
.66275 .32941 Mdot
.82353 .44314 Mdot
.86667 .41176 Mdot
.87843 .28627 Mdot
.72941 .20392 Mdot
.84314 .6902 Mdot
.27843 .33333 Mdot
.94902 .95294 Mdot
.25098 .32941 Mdot
.66667 .67059 Mdot
.71765 .69412 Mdot
.66275 .63137 Mdot
.59216 .52549 Mdot
.54118 .28627 Mdot
.94902 .32941 Mdot
.90196 .28235 Mdot
.8 .2902 Mdot
.76863 .46667 Mdot
.91765 .65098 Mdot
.87451 .36471 Mdot
.9451 .32549 Mdot
.9451 .33333 Mdot
.83529 .40784 Mdot
.92941 .36078 Mdot
.33725 .1098 Mdot
.36863 .18039 Mdot
.4549 .22353 Mdot
.58039 .27843 Mdot
.71373 .33333 Mdot
.79216 .27451 Mdot
.86667 .44314 Mdot
.67451 .70588 Mdot
.96078 .97647 Mdot
.88235 .8902 Mdot
.91373 .93725 Mdot
.79216 .78039 Mdot
.72941 .69804 Mdot
.63922 .61569 Mdot
.67059 .34902 Mdot
.90588 .77255 Mdot
.93333 .29804 Mdot
.87843 .28627 Mdot
.82745 .52549 Mdot
.82353 .66275 Mdot
.69804 .54902 Mdot
.90196 .32941 Mdot
.93725 .32549 Mdot
.92941 .32157 Mdot
.58039 .3098 Mdot
.89804 .33725 Mdot
.22745 .1098 Mdot
.25882 .1451 Mdot
.3098 .15686 Mdot
.40392 .19608 Mdot
.57647 .17255 Mdot
.57647 .21569 Mdot
.5451 .32157 Mdot
.23922 .29804 Mdot
.76471 .78824 Mdot
.9451 .97647 Mdot
.84706 .84314 Mdot
.82353 .80392 Mdot
.76863 .74118 Mdot
.73333 .70196 Mdot
.78431 .32157 Mdot
.76471 .27451 Mdot
.93333 .30588 Mdot
.82353 .27059 Mdot
.7451 .65098 Mdot
.42745 .37255 Mdot
.36863 .25098 Mdot
.90588 .30588 Mdot
.9451 .32549 Mdot
.8902 .34902 Mdot
.43922 .20392 Mdot
.88235 .35294 Mdot
.18039 .11765 Mdot
.2 .12157 Mdot
.22745 .13333 Mdot
.28235 .16471 Mdot
.79216 .3451 Mdot
.27059 .08235 Mdot
.23529 .20392 Mdot
.19216 .27451 Mdot
.4549 .5098 Mdot
.49412 .51765 Mdot
.8549 .8549 Mdot
.83137 .81961 Mdot
.77255 .76078 Mdot
.75686 .68235 Mdot
.71765 .32941 Mdot
.92941 .30588 Mdot
.85882 .25882 Mdot
.85882 .42745 Mdot
.9098 .90196 Mdot
.34118 .35686 Mdot
1 .77255 Mdot
.92549 .31765 Mdot
.95294 .33333 Mdot
.63529 .29412 Mdot
.34118 .05882 Mdot
.79608 .32549 Mdot
.15294 .11373 Mdot
.18039 .13333 Mdot
.2 .15294 Mdot
.27843 .17255 Mdot
.78431 .37255 Mdot
.21176 .12941 Mdot
.19608 .21569 Mdot
.10196 .17255 Mdot
.27451 .31373 Mdot
.81961 .81961 Mdot
.87059 .87059 Mdot
.85882 .8549 Mdot
.81176 .8 Mdot
.89804 .6902 Mdot
.62745 .48627 Mdot
.90588 .27451 Mdot
.84314 .2549 Mdot
.83529 .55294 Mdot
.39216 .41961 Mdot
.37255 .40392 Mdot
.92549 .54902 Mdot
.92941 .31765 Mdot
.9451 .33333 Mdot
.32549 .12157 Mdot
.32157 .07059 Mdot
.79608 .32549 Mdot
.14118 .10196 Mdot
.20784 .16471 Mdot
.15686 .12157 Mdot
.21569 .06667 Mdot
.70588 .32549 Mdot
.14118 .11765 Mdot
.13725 .14902 Mdot
.2902 .3098 Mdot
.51765 .54118 Mdot
.88627 .88235 Mdot
.87843 .87059 Mdot
.87451 .87451 Mdot
.85098 .85098 Mdot
.7451 .45098 Mdot
1 .92549 Mdot
.88235 .25882 Mdot
.83922 .26667 Mdot
.85882 .72549 Mdot
.2549 .30588 Mdot
.81961 .87059 Mdot
.94902 .48627 Mdot
.93725 .31373 Mdot
.93725 .32941 Mdot
.23922 .13333 Mdot
.32157 .09804 Mdot
.80784 .33725 Mdot
.15294 .12157 Mdot
.1451 .1098 Mdot
.13333 .10196 Mdot
.34118 .09804 Mdot
.56863 .28627 Mdot
.12157 .12157 Mdot
.1451 .12941 Mdot
.72157 .71765 Mdot
.86275 .87843 Mdot
.8902 .88627 Mdot
.88627 .88627 Mdot
.88235 .88235 Mdot
.87451 .87451 Mdot
.52157 .15294 Mdot
1 .95686 Mdot
.89412 .28627 Mdot
.86275 .32941 Mdot
.86667 .78039 Mdot
.25098 .32157 Mdot
.48627 .54902 Mdot
.80784 .33333 Mdot
.90196 .27059 Mdot
.92157 .32549 Mdot
.21961 .13333 Mdot
.55686 .39608 Mdot
.86275 .35686 Mdot
.1451 .09804 Mdot
.1451 .11373 Mdot
.1451 .1098 Mdot
.35294 .09804 Mdot
.54902 .25882 Mdot
.12549 .12549 Mdot
.1098 .06275 Mdot
.84706 .83922 Mdot
.87059 .88627 Mdot
.85098 .85882 Mdot
.87451 .86667 Mdot
.87059 .86275 Mdot
.87059 .87843 Mdot
.69804 .34902 Mdot
1 .94902 Mdot
.85882 .27843 Mdot
.89804 .41176 Mdot
.8902 .82745 Mdot
.30196 .36863 Mdot
.34118 .39608 Mdot
.73725 .33333 Mdot
.89804 .26667 Mdot
.9098 .32549 Mdot
.19216 .12549 Mdot
.75686 .64706 Mdot
.88235 .38431 Mdot
.16471 .0549 Mdot
.17255 .12941 Mdot
.14118 .10588 Mdot
.37647 .11765 Mdot
.54118 .24314 Mdot
.12549 .10588 Mdot
.29412 .2 Mdot
.86667 .8549 Mdot
.91373 .9451 Mdot
.69412 .7098 Mdot
.87451 .86667 Mdot
.85882 .85098 Mdot
.86275 .87059 Mdot
.86275 .52941 Mdot
1 .94902 Mdot
.86667 .32549 Mdot
.97255 .54902 Mdot
.86275 .81176 Mdot
.26667 .3098 Mdot
.21176 .22745 Mdot
.83529 .56863 Mdot
.86275 .25098 Mdot
.87843 .31765 Mdot
.17255 .10588 Mdot
.43922 .34118 Mdot
.86275 .40392 Mdot
.23529 .01961 Mdot
.20784 .12157 Mdot
.15686 .11373 Mdot
.37255 .09412 Mdot
.52941 .23137 Mdot
.13725 .09412 Mdot
.8 .63922 Mdot
.87059 .85882 Mdot
.7451 .82745 Mdot
.4549 .47451 Mdot
.8902 .88627 Mdot
.88627 .88627 Mdot
.85882 .86275 Mdot
.79608 .46275 Mdot
1 .94902 Mdot
.83137 .32941 Mdot
.97647 .60784 Mdot
.79216 .75294 Mdot
.31765 .3451 Mdot
.50588 .50196 Mdot
1 .83922 Mdot
.87059 .27451 Mdot
.8902 .35294 Mdot
.17647 .12157 Mdot
.26667 .18824 Mdot
.72549 .33725 Mdot
.40392 .06275 Mdot
.27843 .0902 Mdot
.20392 .08235 Mdot
.38824 .07451 Mdot
.52941 .20784 Mdot
.2 .07059 Mdot
.56471 .33333 Mdot
.88627 .8902 Mdot
.27451 .38039 Mdot
.30588 .32941 Mdot
.87451 .86275 Mdot
.88627 .88627 Mdot
.87059 .87451 Mdot
.76471 .43137 Mdot
1 .93725 Mdot
.81176 .35294 Mdot
.94118 .61569 Mdot
.76863 .7451 Mdot
.78824 .81961 Mdot
.80784 .79608 Mdot
.58039 .49412 Mdot
.94902 .37647 Mdot
.87059 .35294 Mdot
.19608 .14118 Mdot
.24314 .18431 Mdot
.64706 .3451 Mdot
.73725 .2549 Mdot
.42745 .0549 Mdot
.31373 .04706 Mdot
.43137 .0549 Mdot
.56078 .18431 Mdot
.29412 .02745 Mdot
.57647 .28627 Mdot
.90588 .9098 Mdot
.26275 .36863 Mdot
.20392 .22353 Mdot
.90196 .89412 Mdot
.87843 .87059 Mdot
.86667 .86275 Mdot
.72941 .40784 Mdot
1 .93725 Mdot
.76863 .33725 Mdot
.86667 .57647 Mdot
.83922 .82745 Mdot
.51765 .56078 Mdot
.47843 .48235 Mdot
.4902 .45098 Mdot
.99608 .44706 Mdot
.86667 .36863 Mdot
.18431 .13333 Mdot
.20392 .15294 Mdot
.80784 .58039 Mdot
.81961 .30196 Mdot
.65098 .16863 Mdot
.47451 .0902 Mdot
.46667 .03137 Mdot
.60392 .15686 Mdot
.47451 .07059 Mdot
.64314 .32941 Mdot
.51373 .53725 Mdot
.26667 .36078 Mdot
.16863 .18039 Mdot
.96078 .95294 Mdot
.88235 .87059 Mdot
.87059 .87451 Mdot
.68627 .37255 Mdot
1 .93725 Mdot
.75294 .3451 Mdot
.77647 .5098 Mdot
.94902 .96471 Mdot
.35294 .43137 Mdot
.43529 .4902 Mdot
.74118 .71765 Mdot
1 .49804 Mdot
.84314 .36863 Mdot
.18039 .13725 Mdot
.17647 .13333 Mdot
.62353 .43529 Mdot
.8902 .43529 Mdot
.82745 .3098 Mdot
.73725 .25098 Mdot
.61176 .12941 Mdot
.7451 .22353 Mdot
.74902 .22353 Mdot
.84314 .5451 Mdot
.27059 .29804 Mdot
.22353 .27059 Mdot
.15294 .15686 Mdot
.8902 .87843 Mdot
.91373 .8902 Mdot
.87451 .87843 Mdot
.66275 .36078 Mdot
1 .93725 Mdot
.75294 .35686 Mdot
.66667 .43137 Mdot
.92549 .95686 Mdot
.19216 .27059 Mdot
.21569 .28235 Mdot
.91765 .8902 Mdot
.98039 .47843 Mdot
.83922 .39608 Mdot
.16471 .12157 Mdot
.18039 .13725 Mdot
.36863 .20784 Mdot
1 .61569 Mdot
.83529 .32941 Mdot
.88235 .37255 Mdot
.81176 .31765 Mdot
.85098 .2902 Mdot
.83922 .27451 Mdot
.68627 .43922 Mdot
.25882 .28627 Mdot
.15294 .16471 Mdot
.13725 .14118 Mdot
.63137 .61961 Mdot
.87451 .84314 Mdot
.86667 .87843 Mdot
.60392 .32157 Mdot
1 .92549 Mdot
.77255 .37647 Mdot
.61569 .41961 Mdot
.70196 .74118 Mdot
.56078 .6 Mdot
.66275 .69804 Mdot
.9451 .90588 Mdot
.91765 .40784 Mdot
.80784 .38431 Mdot
.24706 .19608 Mdot
.18824 .14902 Mdot
.35294 .19608 Mdot
.99608 .51765 Mdot
1 .5451 Mdot
.86275 .4 Mdot
.91373 .45882 Mdot
.90588 .33725 Mdot
.83922 .32549 Mdot
.30588 .17255 Mdot
.20392 .21569 Mdot
.16078 .15294 Mdot
.16471 .16863 Mdot
.57255 .55294 Mdot
.3451 .32941 Mdot
.86667 .87059 Mdot
.54118 .27843 Mdot
1 .92549 Mdot
.76078 .34118 Mdot
.66667 .50588 Mdot
.49412 .52549 Mdot
.90196 .92549 Mdot
.97255 .98039 Mdot
.93725 .89804 Mdot
.83529 .32549 Mdot
.80392 .38431 Mdot
.52157 .45882 Mdot
.18431 .1451 Mdot
.34118 .16471 Mdot
.9098 .39216 Mdot
.96078 .49804 Mdot
.98431 .51765 Mdot
1 .5451 Mdot
.92549 .35686 Mdot
.74902 .31373 Mdot
.26275 .2 Mdot
.15294 .16471 Mdot
.14902 .12941 Mdot
.17255 .17647 Mdot
.59216 .56863 Mdot
.73333 .71765 Mdot
.87059 .87451 Mdot
.52157 .25882 Mdot
1 .93333 Mdot
.81176 .34902 Mdot
.82745 .68627 Mdot
.36863 .38039 Mdot
.52157 .56471 Mdot
.92941 .92157 Mdot
.95294 .92549 Mdot
.76863 .26667 Mdot
.80784 .38824 Mdot
.47059 .41176 Mdot
.15294 .11765 Mdot
.33333 .13333 Mdot
.93725 .37647 Mdot
.92549 .38824 Mdot
.94902 .42745 Mdot
.97647 .48235 Mdot
.95294 .37255 Mdot
.52941 .19216 Mdot
.19216 .17255 Mdot
.14902 .18824 Mdot
.15294 .13333 Mdot
.16471 .16863 Mdot
.62745 .60392 Mdot
.6902 .65098 Mdot
.86667 .87059 Mdot
.51373 .25098 Mdot
1 .95294 Mdot
.83137 .32549 Mdot
.86275 .74118 Mdot
.34902 .34118 Mdot
.38431 .42745 Mdot
.91765 .9098 Mdot
.93725 .92549 Mdot
.72941 .23529 Mdot
.81569 .4 Mdot
.29804 .23137 Mdot
.23137 .18824 Mdot
.32941 .09804 Mdot
.95294 .36863 Mdot
.94902 .37255 Mdot
.91373 .35686 Mdot
.92157 .38824 Mdot
.95294 .36471 Mdot
.43137 .15294 Mdot
.15294 .16863 Mdot
.16078 .22745 Mdot
.16078 .15686 Mdot
.17647 .17255 Mdot
.58431 .56471 Mdot
.20392 .16471 Mdot
.87059 .87059 Mdot
.5098 .25098 Mdot
.85098 .70196 Mdot
.85882 .37255 Mdot
.89804 .83922 Mdot
.31373 .31373 Mdot
.25882 .27843 Mdot
.93725 .91373 Mdot
.59216 .59608 Mdot
.95294 .41961 Mdot
.57255 .27843 Mdot
.27843 .22745 Mdot
.39608 .3451 Mdot
.47059 .10196 Mdot
.93725 .35294 Mdot
.93725 .35686 Mdot
.94118 .36078 Mdot
.93725 .36078 Mdot
.92157 .31373 Mdot
.23922 .06275 Mdot
.12941 .18431 Mdot
.22353 .32157 Mdot
.14902 .15686 Mdot
.59608 .58824 Mdot
.35294 .32941 Mdot
.45882 .42745 Mdot
.86275 .86667 Mdot
.83137 .47843 Mdot
.62353 .31765 Mdot
.79608 .3451 Mdot
.77647 .71765 Mdot
.7098 .72549 Mdot
.73725 .73725 Mdot
.95294 .93725 Mdot
.58039 .57647 Mdot
1 .44314 Mdot
.29412 .11765 Mdot
.25098 .20392 Mdot
.54902 .50196 Mdot
.85098 .36863 Mdot
.93725 .3451 Mdot
.9451 .35686 Mdot
.9451 .35294 Mdot
.94118 .34902 Mdot
.92941 .32157 Mdot
.21176 .12549 Mdot
.15294 .23922 Mdot
.24314 .34118 Mdot
.12941 .1451 Mdot
.95686 .95686 Mdot
.55294 .52941 Mdot
.73725 .71373 Mdot
.86667 .87059 Mdot
.60392 .21176 Mdot
.88627 .37255 Mdot
.80392 .51373 Mdot
.81176 .76863 Mdot
.6 .64706 Mdot
.94902 .94118 Mdot
.78824 .81961 Mdot
1 .83922 Mdot
.8549 .26667 Mdot
.24706 .18824 Mdot
.27059 .22745 Mdot
.59216 .4902 Mdot
.9451 .35294 Mdot
.95294 .36078 Mdot
.9451 .35294 Mdot
.9451 .35294 Mdot
.93725 .32941 Mdot
.87451 .32157 Mdot
.18039 .2 Mdot
.27059 .38431 Mdot
.13333 .19216 Mdot
.24314 .24314 Mdot
.88627 .89412 Mdot
.64314 .61961 Mdot
.83922 .8 Mdot
.9098 .87059 Mdot
.5451 .28627 Mdot
.87059 .31373 Mdot
.87843 .72157 Mdot
.36078 .36078 Mdot
.28627 .31373 Mdot
.38039 .37647 Mdot
.4 .46667 Mdot
.7451 .28627 Mdot
.77255 .34118 Mdot
.24706 .21176 Mdot
.25098 .2 Mdot
.66667 .40784 Mdot
.94118 .33725 Mdot
.90588 .40784 Mdot
.93333 .37647 Mdot
.93333 .37647 Mdot
.93333 .35686 Mdot
.79216 .41176 Mdot
.18824 .22745 Mdot
.20392 .2902 Mdot
.25882 .28235 Mdot
.39216 .38039 Mdot
.48627 .47451 Mdot
.37255 .33333 Mdot
.88235 .87843 Mdot
.81569 .64706 Mdot
1 .94902 Mdot
.86275 .39608 Mdot
.81176 .70588 Mdot
.44706 .4549 Mdot
.3098 .30588 Mdot
.4549 .45882 Mdot
.83922 .84314 Mdot
1 .47843 Mdot
.39216 .18824 Mdot
.27843 .23529 Mdot
.25098 .20392 Mdot
.83137 .36078 Mdot
.92941 .34902 Mdot
.69804 .35294 Mdot
.88235 .40392 Mdot
.90196 .41176 Mdot
.90588 .38824 Mdot
.23922 .08627 Mdot
.14118 .18039 Mdot
.2902 .33333 Mdot
.42353 .41961 Mdot
.71373 .71765 Mdot
.35686 .35294 Mdot
.81961 .77255 Mdot
.86667 .87059 Mdot
.75686 .41961 Mdot
.67843 .3451 Mdot
.8902 .65098 Mdot
.90588 .87843 Mdot
.87059 .8902 Mdot
.89804 .90196 Mdot
.53333 .58431 Mdot
.98431 .78431 Mdot
.85098 .25882 Mdot
.26667 .19608 Mdot
.27059 .21569 Mdot
.27843 .17647 Mdot
.93725 .34902 Mdot
.88627 .45882 Mdot
.77255 .48235 Mdot
.63922 .30196 Mdot
.71373 .35686 Mdot
.84314 .36863 Mdot
.15294 .1451 Mdot
.36471 .40784 Mdot
.38039 .38431 Mdot
.18039 .16471 Mdot
.88627 .88627 Mdot
.89412 .88235 Mdot
.43137 .39608 Mdot
.88235 .87059 Mdot
.56863 .29804 Mdot
.92549 .45882 Mdot
.52157 .50588 Mdot
.48627 .53725 Mdot
.47843 .51765 Mdot
.56078 .59608 Mdot
.23529 .23922 Mdot
.84706 .35294 Mdot
.78824 .40392 Mdot
.23529 .19216 Mdot
.24314 .19216 Mdot
.44706 .10588 Mdot
.92157 .33333 Mdot
1 .89412 Mdot
.5451 .3098 Mdot
.74902 .57647 Mdot
.58824 .39608 Mdot
.77255 .41176 Mdot
.42745 .47451 Mdot
.26275 .31765 Mdot
.16471 .1451 Mdot
.14902 .14118 Mdot
.88235 .87451 Mdot
.8 .74118 Mdot
.87451 .87451 Mdot
.72549 .51765 Mdot
.91373 .75686 Mdot
.96863 .80784 Mdot
.43137 .45882 Mdot
.37647 .42353 Mdot
.38039 .42353 Mdot
.40392 .47451 Mdot
.86667 .57255 Mdot
.83137 .22745 Mdot
.29412 .19216 Mdot
.25098 .2 Mdot
.25098 .18039 Mdot
.92157 .35294 Mdot
.80392 .45882 Mdot
1 .92157 Mdot
.97255 .89804 Mdot
.96863 .88235 Mdot
1 .80392 Mdot
.42353 .35294 Mdot
.23922 .32157 Mdot
.18824 .20392 Mdot
.18431 .16471 Mdot
.9098 .9098 Mdot
.92941 .91765 Mdot
.51373 .46667 Mdot
.87843 .87451 Mdot
.61961 .32157 Mdot
.86667 .43137 Mdot
.37255 .36078 Mdot
.34902 .36078 Mdot
.35686 .36863 Mdot
.3451 .39216 Mdot
.90588 .76863 Mdot
.98039 .42353 Mdot
.80392 .42745 Mdot
.27059 .22745 Mdot
.23529 .19216 Mdot
.48627 .12157 Mdot
.90588 .35686 Mdot
.9451 .87843 Mdot
.87451 .78431 Mdot
.94902 .80784 Mdot
.96078 .90588 Mdot
.79608 .43529 Mdot
.21961 .29804 Mdot
.23529 .27843 Mdot
.18039 .14902 Mdot
.12941 .11373 Mdot
.87843 .88235 Mdot
.66667 .60784 Mdot
.87451 .87451 Mdot
.57647 .36078 Mdot
.63137 .43529 Mdot
.61961 .45098 Mdot
.3098 .22353 Mdot
.29412 .18431 Mdot
.28235 .21176 Mdot
.40392 .41569 Mdot
.78431 .2549 Mdot
.92549 .33333 Mdot
.25098 .18431 Mdot
.23922 .20392 Mdot
.27059 .15686 Mdot
.93725 .3451 Mdot
.50588 .38431 Mdot
.54902 .42745 Mdot
1 .92157 Mdot
.9098 .85098 Mdot
.60392 .24706 Mdot
.24706 .26275 Mdot
.25882 .34902 Mdot
.17255 .15294 Mdot
.16863 .1451 Mdot
.88627 .88627 Mdot
.89804 .88627 Mdot
.69412 .67059 Mdot
.90196 .87059 Mdot
.58824 .45098 Mdot
.73333 .27451 Mdot
.88627 .63922 Mdot
.77647 .52941 Mdot
.83137 .56078 Mdot
.55686 .56863 Mdot
.7451 .31373 Mdot
.9451 .33333 Mdot
.68235 .43137 Mdot
.25098 .2 Mdot
.23922 .19216 Mdot
.85882 .38039 Mdot
.81176 .44314 Mdot
.99216 .93725 Mdot
.94118 .89412 Mdot
.78824 .5098 Mdot
.99608 .90588 Mdot
.48235 .23137 Mdot
.21176 .29804 Mdot
.17255 .16863 Mdot
.15686 .1451 Mdot
.50588 .49412 Mdot
.88627 .88627 Mdot
.41569 .38039 Mdot
.87059 .87451 Mdot
.70588 .45098 Mdot
.81176 .38039 Mdot
.87843 .48235 Mdot
.91765 .53725 Mdot
.82745 .40392 Mdot
.95294 .88235 Mdot
.60392 .21961 Mdot
.9451 .34118 Mdot
.77255 .42353 Mdot
.21176 .15294 Mdot
.28235 .23922 Mdot
.62353 .21961 Mdot
.83137 .41176 Mdot
.96078 .91765 Mdot
.93725 .89412 Mdot
.8549 .50196 Mdot
.96471 .89412 Mdot
.77647 .41961 Mdot
.20392 .27059 Mdot
.14902 .1451 Mdot
.14902 .13725 Mdot
.15294 .12941 Mdot
.8902 .8902 Mdot
.52549 .4902 Mdot
.87843 .87843 Mdot
.45098 .23922 Mdot
.72941 .37255 Mdot
.90588 .38824 Mdot
.85882 .36471 Mdot
.78824 .27451 Mdot
.77255 .69804 Mdot
.81176 .38431 Mdot
.95294 .34118 Mdot
.78824 .44706 Mdot
.43922 .37255 Mdot
.27451 .21961 Mdot
.67059 .25098 Mdot
.82353 .43529 Mdot
.98824 .93333 Mdot
.93333 .89804 Mdot
.83137 .47059 Mdot
1 .90588 Mdot
.73725 .39608 Mdot
.22353 .27059 Mdot
.14902 .12157 Mdot
.14902 .12157 Mdot
.17647 .15686 Mdot
.88627 .88627 Mdot
.45098 .39216 Mdot
.87843 .87059 Mdot
.44706 .23922 Mdot
.6 .31373 Mdot
.96078 .37255 Mdot
.8902 .33725 Mdot
1 .4549 Mdot
.54118 .4549 Mdot
.97647 .50588 Mdot
.93725 .32549 Mdot
.77647 .43529 Mdot
.53333 .47451 Mdot
.25882 .20392 Mdot
.69412 .26667 Mdot
.81569 .47843 Mdot
1 .92549 Mdot
.94902 .90196 Mdot
.84706 .50196 Mdot
1 .9098 Mdot
.72157 .38431 Mdot
.23137 .26667 Mdot
.14902 .12157 Mdot
.15294 .12157 Mdot
.21961 .2 Mdot
.88627 .87843 Mdot
.62745 .55686 Mdot
.87451 .86667 Mdot
.58039 .38431 Mdot
.63137 .3098 Mdot
.97255 .37255 Mdot
.89412 .33725 Mdot
.96471 .41569 Mdot
.32549 .23922 Mdot
.9098 .35686 Mdot
.94118 .34118 Mdot
.51373 .27843 Mdot
.37255 .31765 Mdot
.21176 .16471 Mdot
.9098 .39216 Mdot
.40784 .23922 Mdot
.49804 .39608 Mdot
.97647 .9098 Mdot
.47451 .25882 Mdot
.63922 .33725 Mdot
.36863 .1451 Mdot
.23137 .26275 Mdot
.16078 .12941 Mdot
.1451 .11373 Mdot
.88235 .86667 Mdot
.8902 .8902 Mdot
.58824 .52157 Mdot
.87451 .86667 Mdot
.51765 .33725 Mdot
.9098 .38431 Mdot
.95686 .36863 Mdot
.90196 .33333 Mdot
.8549 .45098 Mdot
.98039 .65882 Mdot
.93725 .34118 Mdot
.92157 .3451 Mdot
.26667 .21569 Mdot
.47451 .42745 Mdot
.27059 .13725 Mdot
.87059 .4 Mdot
.9451 .89412 Mdot
.98039 .92941 Mdot
.83922 .43137 Mdot
.9451 .89412 Mdot
.88235 .3451 Mdot
.21569 .20784 Mdot
.16078 .16471 Mdot
.17647 .16078 Mdot
.19216 .18039 Mdot
.88627 .88627 Mdot
.93333 .92157 Mdot
.51765 .49412 Mdot
.96078 .8902 Mdot
1 .95686 Mdot
.89412 .32157 Mdot
.95294 .35686 Mdot
.9098 .32157 Mdot
.94118 .57255 Mdot
.93333 .36078 Mdot
.9451 .3451 Mdot
.80784 .44706 Mdot
.26667 .23529 Mdot
.52549 .48235 Mdot
.75294 .33725 Mdot
.36078 .23137 Mdot
.45882 .35294 Mdot
.98431 .8902 Mdot
.47451 .26275 Mdot
.65882 .38039 Mdot
.53725 .24706 Mdot
.22745 .25882 Mdot
.14902 .1451 Mdot
.16471 .15686 Mdot
.45098 .4549 Mdot
.88627 .88627 Mdot
.85098 .81569 Mdot
.88235 .87843 Mdot
.7098 .56863 Mdot
.77255 .37255 Mdot
.92157 .34902 Mdot
.94902 .35686 Mdot
.8902 .38431 Mdot
.9098 .36471 Mdot
.9451 .3451 Mdot
.87451 .33725 Mdot
.28235 .23529 Mdot
.2549 .23137 Mdot
.63529 .40392 Mdot
.45882 .23529 Mdot
1 .93333 Mdot
.94118 .8902 Mdot
.83529 .49412 Mdot
1 .89804 Mdot
.83137 .36863 Mdot
.19608 .22745 Mdot
.15686 .17255 Mdot
.12157 .13725 Mdot
.44706 .45098 Mdot
.8902 .8902 Mdot
.86667 .8549 Mdot
.89412 .88235 Mdot
.5451 .44314 Mdot
.69804 .52941 Mdot
.86275 .36471 Mdot
.91765 .32157 Mdot
.95686 .37647 Mdot
.9451 .38431 Mdot
.94902 .35686 Mdot
.94902 .36863 Mdot
.30588 .21961 Mdot
.25882 .24706 Mdot
.46667 .32941 Mdot
.48235 .24314 Mdot
1 .94118 Mdot
.93725 .90588 Mdot
.80784 .48235 Mdot
.97255 .90196 Mdot
.87843 .35294 Mdot
.16078 .17647 Mdot
.15686 .17255 Mdot
.2549 .27843 Mdot
.33725 .32941 Mdot
.88627 .88627 Mdot
.91373 .91373 Mdot
.8902 .87059 Mdot
.94118 .86275 Mdot
.96471 .87059 Mdot
.76863 .36863 Mdot
.90196 .34118 Mdot
.94902 .36078 Mdot
.96471 .36863 Mdot
.95686 .35686 Mdot
.9098 .35294 Mdot
.30588 .23529 Mdot
.27059 .24706 Mdot
.38431 .16863 Mdot
.95686 .79608 Mdot
.65098 .5098 Mdot
.94118 .89804 Mdot
.45882 .27059 Mdot
.85882 .6549 Mdot
.81176 .40784 Mdot
.16471 .19216 Mdot
.20784 .21961 Mdot
.45882 .47059 Mdot
.15294 .15294 Mdot
.88627 .88627 Mdot
.69804 .67843 Mdot
.88235 .87059 Mdot
.36863 .25882 Mdot
.84706 .67843 Mdot
.81569 .36078 Mdot
.91765 .32157 Mdot
.95686 .34902 Mdot
.95686 .34902 Mdot
.94118 .35294 Mdot
.3098 .16471 Mdot
.27059 .23922 Mdot
.34902 .21569 Mdot
.7098 .41176 Mdot
.89412 .71373 Mdot
.9451 .89412 Mdot
.58824 .46667 Mdot
1 .86275 Mdot
.82353 .36471 Mdot
.18039 .18431 Mdot
.47843 .46667 Mdot
.21961 .21569 Mdot
.18039 .17255 Mdot
.88627 .88627 Mdot
.90196 .89804 Mdot
.90196 .8902 Mdot
.57647 .4902 Mdot
.93725 .78039 Mdot
.78824 .36863 Mdot
.96078 .34118 Mdot
.92941 .31373 Mdot
.9451 .3451 Mdot
.91765 .38824 Mdot
.21569 .1451 Mdot
.26275 .23922 Mdot
.75686 .37647 Mdot
.82353 .53333 Mdot
.64706 .39216 Mdot
.99216 .86667 Mdot
.98431 .8902 Mdot
.93333 .38039 Mdot
.39608 .26275 Mdot
.48627 .47451 Mdot
.16471 .1451 Mdot
.16471 .1451 Mdot
.95686 .96078 Mdot
.8902 .8902 Mdot
.32941 .30588 Mdot
.8902 .87059 Mdot
.74118 .71765 Mdot
.70588 .45098 Mdot
.92157 .31373 Mdot
.93333 .3098 Mdot
.92157 .30588 Mdot
.9451 .37255 Mdot
.22745 .09412 Mdot
.23137 .2 Mdot
.74902 .37647 Mdot
.87451 .43922 Mdot
.74902 .36863 Mdot
.9098 .65882 Mdot
1 .81569 Mdot
.92941 .34902 Mdot
.43137 .31765 Mdot
.20392 .19216 Mdot
.17255 .1451 Mdot
.16863 .14118 Mdot
.93333 .93725 Mdot
.8902 .8902 Mdot
.40784 .37647 Mdot
.8902 .87059 Mdot
.92157 .90196 Mdot
.83922 .33725 Mdot
.94118 .3098 Mdot
.9451 .34902 Mdot
.89804 .31765 Mdot
.43137 .0902 Mdot
.18824 .10588 Mdot
.34902 .15686 Mdot
.93725 .37647 Mdot
.91373 .39216 Mdot
.78824 .40392 Mdot
.78824 .48235 Mdot
.91765 .39216 Mdot
.61569 .36863 Mdot
.16471 .15294 Mdot
.15294 .14118 Mdot
.17255 .13725 Mdot
.38039 .38039 Mdot
.8902 .88235 Mdot
.47843 .44314 Mdot
.88235 .87059 Mdot
.73725 .67843 Mdot
.80392 .35686 Mdot
.94118 .32157 Mdot
.90196 .36471 Mdot
.9098 .36863 Mdot
.55686 .13725 Mdot
.22745 .08627 Mdot
.38431 .09412 Mdot
.93725 .36863 Mdot
.93333 .38039 Mdot
.92157 .43137 Mdot
.88235 .43137 Mdot
.93725 .34902 Mdot
.26275 .14902 Mdot
.16078 .14118 Mdot
.15686 .12549 Mdot
.16078 .12941 Mdot
.96078 .95686 Mdot
.89412 .89412 Mdot
.81569 .76078 Mdot
.89412 .86667 Mdot
.91373 .89412 Mdot
.75686 .34118 Mdot
.84706 .32941 Mdot
.76471 .36863 Mdot
.81569 .37255 Mdot
.65098 .26667 Mdot
.24314 .04706 Mdot
.9098 .41961 Mdot
.94902 .35294 Mdot
.93725 .37255 Mdot
.94118 .38824 Mdot
.93333 .38824 Mdot
.90196 .34902 Mdot
.20392 .19216 Mdot
.16863 .13725 Mdot
.14902 .11765 Mdot
.15686 .13333 Mdot
.88627 .87843 Mdot
.90588 .89412 Mdot
.56078 .52941 Mdot
.94902 .91373 Mdot
.76471 .65882 Mdot
.6902 .33333 Mdot
.7451 .52549 Mdot
.65098 .40784 Mdot
.65882 .33725 Mdot
.53725 .19216 Mdot
.42745 .03922 Mdot
.95686 .36471 Mdot
.92941 .35294 Mdot
.92941 .36078 Mdot
.95294 .38431 Mdot
.93725 .3451 Mdot
.30196 .15294 Mdot
.16863 .14118 Mdot
.17255 .13333 Mdot
.1451 .11765 Mdot
.89804 .89412 Mdot
.8902 .8902 Mdot
.62353 .57255 Mdot
.88235 .87059 Mdot
.84314 .83529 Mdot
.73725 .54118 Mdot
1 .92941 Mdot
.91765 .80392 Mdot
.58431 .38824 Mdot
.6549 .34118 Mdot
.67059 .26275 Mdot
.93333 .36471 Mdot
.94902 .37647 Mdot
.94118 .36078 Mdot
.94902 .37255 Mdot
.94902 .34902 Mdot
.3098 .13333 Mdot
.18039 .14902 Mdot
.17255 .14118 Mdot
.14902 .12941 Mdot
.95294 .95686 Mdot
.89412 .89412 Mdot
.49412 .45098 Mdot
.88235 .87059 Mdot
.96471 .96078 Mdot
.99216 .93333 Mdot
.70588 .57647 Mdot
.67059 .39216 Mdot
.81569 .3451 Mdot
.89412 .34902 Mdot
.95686 .37647 Mdot
.96471 .38431 Mdot
.95686 .35294 Mdot
.8 .41176 Mdot
.18431 .10196 Mdot
.14902 .13725 Mdot
.16863 .1451 Mdot
.24314 .25098 Mdot
.89412 .88235 Mdot
.89804 .88627 Mdot
.88627 .87843 Mdot
.39216 .37647 Mdot
.8902 .73725 Mdot
.76078 .43529 Mdot
.78039 .34902 Mdot
.84314 .33333 Mdot
.8902 .35686 Mdot
.92549 .36078 Mdot
.86275 .37255 Mdot
.21176 .02745 Mdot
.05098 .04706 Mdot
.07059 .0549 Mdot
.24314 .27059 Mdot
.90588 .90196 Mdot
.88627 .87843 Mdot
.87451 .86667 Mdot
.39216 .3451 Mdot
1 .93725 Mdot
.85098 .65882 Mdot
.70588 .4 Mdot
.76078 .35294 Mdot
.80392 .33333 Mdot
.84314 .31373 Mdot
.53725 .16078 Mdot
.4902 .43529 Mdot
.42745 .43137 Mdot
.44706 .48627 Mdot
.56078 .59608 Mdot
.89412 .87451 Mdot
.88627 .86667 Mdot
.9451 .88627 Mdot
1 .94902 Mdot
.93333 .73725 Mdot
.83529 .54902 Mdot
.77255 .41569 Mdot
.72941 .33333 Mdot
.77255 .45882 Mdot
.91765 .89804 Mdot
.90588 .90196 Mdot
.21569 .27059 Mdot
.31765 .34902 Mdot
.89804 .87451 Mdot
.88627 .87059 Mdot
.28235 .21176 Mdot
1 .93725 Mdot
.95686 .81569 Mdot
.81961 .62745 Mdot
.81961 .61569 Mdot
.87451 .88627 Mdot
.60392 .6 Mdot
.27059 .28627 Mdot
.28627 .31373 Mdot
.8 .76471 Mdot
.78431 .77647 Mdot
.82745 .80392 Mdot
.62353 .4902 Mdot
.2549 .25098 Mdot
.61176 .62353 Mdot
.53725 .54902 Mdot
.6902 .7098 Mdot
.87451 .8549 Mdot
.89804 .88235 Mdot
.95686 .94118 Mdot
.39608 .40392 Mdot
.23922 .27059 Mdot
.9098 .9098 Mdot
.62353 .64314 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0258451 0.97619 0.518133 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.96078 .96078 Mdot
.72157 .70196 Mdot
.52549 .51765 Mdot
.14902 .12157 Mdot
.88235 .86275 Mdot
.1098 .09412 Mdot
.11373 .08235 Mdot
.78039 .76078 Mdot
.14902 .12941 Mdot
.12549 .10588 Mdot
.1451 .11765 Mdot
.13333 .11373 Mdot
.18824 .17255 Mdot
.15686 .1451 Mdot
.49804 .48627 Mdot
.13333 .11373 Mdot
.23137 .22353 Mdot
.21569 .2 Mdot
.48235 .47843 Mdot
.82745 .81961 Mdot
.96863 .96078 Mdot
.12941 .1098 Mdot
.18824 .17647 Mdot
.20784 .2 Mdot
.11765 .09804 Mdot
.16863 .1451 Mdot
.32941 .30588 Mdot
.53725 .52157 Mdot
.74902 .73333 Mdot
.89412 .8902 Mdot
.14118 .12157 Mdot
.16863 .15686 Mdot
.17647 .15294 Mdot
.20784 .17647 Mdot
.39216 .37647 Mdot
.14118 .11373 Mdot
.22745 .2 Mdot
.2 .17647 Mdot
.25882 .23922 Mdot
.19608 .18431 Mdot
.20392 .18431 Mdot
.16863 .15294 Mdot
.20784 .17255 Mdot
.25098 .24314 Mdot
.17647 .17255 Mdot
.16863 .14902 Mdot
.19608 .16863 Mdot
.25882 .21961 Mdot
.17647 .15294 Mdot
.12941 .11765 Mdot
.11765 .1098 Mdot
.1451 .13333 Mdot
.23529 .21569 Mdot
.93725 .92941 Mdot
.18824 .18039 Mdot
.18039 .16863 Mdot
.22353 .19216 Mdot
.21569 .18824 Mdot
.26667 .23922 Mdot
.13725 .12549 Mdot
.19216 .16863 Mdot
.14902 .14118 Mdot
.26667 .23529 Mdot
.96471 .96078 Mdot
.36078 .36078 Mdot
.25882 .2549 Mdot
.2 .16471 Mdot
.25882 .22353 Mdot
.18824 .16863 Mdot
.14902 .13725 Mdot
.20784 .18431 Mdot
.11765 .1098 Mdot
.2 .18431 Mdot
.50196 .49412 Mdot
.32157 .32157 Mdot
.21176 .21176 Mdot
.18431 .15686 Mdot
.32157 .29412 Mdot
.18431 .16863 Mdot
.11765 .10196 Mdot
.15294 .13333 Mdot
.16471 .15294 Mdot
.16471 .14902 Mdot
.16078 .15294 Mdot
.72549 .70588 Mdot
.25098 .23922 Mdot
.16863 .16078 Mdot
.28627 .26275 Mdot
.34118 .32549 Mdot
.18824 .17647 Mdot
.07059 .04706 Mdot
.13725 .11373 Mdot
.21176 .18824 Mdot
.24706 .22745 Mdot
.13725 .12941 Mdot
.44314 .45098 Mdot
.12549 .09804 Mdot
.18824 .16863 Mdot
.17255 .16471 Mdot
.5451 .52941 Mdot
.43922 .42353 Mdot
.17255 .16863 Mdot
.09804 .07451 Mdot
.14118 .11765 Mdot
.25098 .22745 Mdot
.18039 .16078 Mdot
.10588 .11373 Mdot
.17255 .17255 Mdot
.92549 .90588 Mdot
.23922 .23137 Mdot
.16471 .16863 Mdot
.2 .18039 Mdot
.38039 .36471 Mdot
.2549 .25882 Mdot
.27059 .26275 Mdot
.11765 .1098 Mdot
.14118 .12941 Mdot
.21176 .19216 Mdot
.14902 .13725 Mdot
.12157 .14118 Mdot
.22353 .16078 Mdot
.82353 .79216 Mdot
.22353 .21569 Mdot
.16471 .15686 Mdot
.15686 .16078 Mdot
.33725 .3098 Mdot
.49412 .49804 Mdot
.2 .20392 Mdot
.2549 .24706 Mdot
.13725 .13725 Mdot
.1451 .13725 Mdot
.14902 .14118 Mdot
.01961 .05098 Mdot
.51373 .47451 Mdot
.24706 .14118 Mdot
.83529 .80392 Mdot
.21961 .20784 Mdot
.16078 .15686 Mdot
.18039 .18824 Mdot
.55294 .52941 Mdot
.61569 .63529 Mdot
.41176 .41569 Mdot
.24706 .24314 Mdot
.15686 .16471 Mdot
.13725 .13725 Mdot
.1098 .12941 Mdot
.10196 .13333 Mdot
.47843 .43137 Mdot
.50196 .32941 Mdot
.23529 .16471 Mdot
.97255 .96078 Mdot
.19216 .18824 Mdot
.17647 .18431 Mdot
.2 .20784 Mdot
.57255 .55686 Mdot
.21176 .23529 Mdot
.47059 .48235 Mdot
.62745 .62353 Mdot
.12549 .1451 Mdot
.11765 .12941 Mdot
.08235 .12549 Mdot
.18039 .21176 Mdot
.52549 .44706 Mdot
.5098 .29412 Mdot
.29412 .18039 Mdot
.7098 .67451 Mdot
.19608 .19216 Mdot
.25882 .27451 Mdot
.19216 .2 Mdot
.19216 .20392 Mdot
.63922 .65098 Mdot
.43922 .46275 Mdot
.40392 .41176 Mdot
.39608 .4 Mdot
.18431 .20784 Mdot
.09412 .14902 Mdot
.18039 .22353 Mdot
.27451 .28627 Mdot
.47451 .3098 Mdot
.49412 .27843 Mdot
.40392 .25882 Mdot
.56078 .52157 Mdot
.16863 .15294 Mdot
.23137 .2549 Mdot
.44706 .45098 Mdot
.27451 .2902 Mdot
.65098 .64314 Mdot
.26667 .2902 Mdot
.76078 .76471 Mdot
.50588 .49412 Mdot
.40784 .43922 Mdot
.20392 .2549 Mdot
.2549 .32549 Mdot
.44314 .4549 Mdot
.60392 .52157 Mdot
.48627 .2549 Mdot
.54118 .33333 Mdot
.29412 .18824 Mdot
.74902 .71373 Mdot
.21569 .22353 Mdot
.38039 .4 Mdot
.38824 .40784 Mdot
.34902 .36471 Mdot
.69412 .69412 Mdot
.35294 .38039 Mdot
.61569 .61176 Mdot
.54902 .55686 Mdot
.2549 .27059 Mdot
.38824 .46667 Mdot
.29804 .36471 Mdot
.41569 .41569 Mdot
.6 .51765 Mdot
.38824 .20784 Mdot
.51765 .29412 Mdot
.52941 .36863 Mdot
.23922 .18039 Mdot
.9098 .90196 Mdot
.2549 .27843 Mdot
.57255 .58824 Mdot
.25098 .27451 Mdot
.38824 .39608 Mdot
.74902 .74902 Mdot
.27843 .30588 Mdot
.60784 .58824 Mdot
.88627 .90196 Mdot
.89804 .91765 Mdot
.64314 .73333 Mdot
.32157 .35686 Mdot
.44314 .43529 Mdot
.5451 .44314 Mdot
.32941 .16078 Mdot
.51373 .27451 Mdot
.55294 .38431 Mdot
.17255 .08627 Mdot
.87843 .85882 Mdot
.18431 .20784 Mdot
.54902 .57255 Mdot
.59216 .60784 Mdot
.25882 .28627 Mdot
.41961 .41569 Mdot
.85098 .86275 Mdot
.78431 .76078 Mdot
.73333 .74118 Mdot
.71765 .71765 Mdot
.67059 .72941 Mdot
.22353 .29804 Mdot
.37647 .38431 Mdot
.2549 .21176 Mdot
.32549 .16863 Mdot
.35686 .19216 Mdot
.56078 .31373 Mdot
.5451 .39608 Mdot
.13333 .05098 Mdot
.89412 .86667 Mdot
.54118 .53333 Mdot
.38824 .36471 Mdot
.18824 .20392 Mdot
.26667 .28627 Mdot
.29412 .29412 Mdot
.56471 .58824 Mdot
.29412 .29412 Mdot
.43137 .42353 Mdot
.38431 .38824 Mdot
.63529 .62745 Mdot
.75686 .77647 Mdot
.3451 .36078 Mdot
.6549 .71765 Mdot
.16471 .18431 Mdot
.33725 .33725 Mdot
.4902 .36078 Mdot
.3098 .16863 Mdot
.4902 .28627 Mdot
.58431 .38824 Mdot
.54118 .39216 Mdot
.12549 .05098 Mdot
.90196 .88235 Mdot
.16863 .15686 Mdot
.20392 .18431 Mdot
.83137 .82353 Mdot
.25098 .27843 Mdot
.70196 .69804 Mdot
.86667 .84314 Mdot
.53333 .57255 Mdot
.3451 .34118 Mdot
.2549 .26275 Mdot
.38824 .36863 Mdot
.74118 .7451 Mdot
.58431 .60392 Mdot
.79216 .81569 Mdot
.66667 .71373 Mdot
.18039 .20392 Mdot
.21569 .20392 Mdot
.43529 .25098 Mdot
.2902 .16078 Mdot
.47059 .27843 Mdot
.58824 .43922 Mdot
.5451 .38824 Mdot
.22353 .10196 Mdot
.60392 .57647 Mdot
.1098 .0902 Mdot
.21569 .20392 Mdot
.21961 .19216 Mdot
.76863 .76078 Mdot
.23529 .27059 Mdot
.84314 .79608 Mdot
.84706 .76078 Mdot
.3098 .3451 Mdot
.49412 .49804 Mdot
.26667 .26275 Mdot
.4902 .46667 Mdot
.68627 .69412 Mdot
.33333 .34902 Mdot
.67059 .6902 Mdot
.53725 .56471 Mdot
.25882 .2902 Mdot
.17255 .15294 Mdot
.47843 .27059 Mdot
.23529 .1451 Mdot
.41176 .24314 Mdot
.48235 .34902 Mdot
.56863 .40392 Mdot
.41176 .27059 Mdot
.15294 .09804 Mdot
.71765 .69804 Mdot
.25098 .23529 Mdot
.26667 .24706 Mdot
.1098 .07059 Mdot
.23529 .24706 Mdot
.27059 .27059 Mdot
.85098 .67451 Mdot
.59608 .49804 Mdot
.28627 .31765 Mdot
.48627 .49412 Mdot
.29804 .30588 Mdot
.52941 .52157 Mdot
.43922 .47451 Mdot
.49804 .50196 Mdot
.62745 .64706 Mdot
.56863 .57255 Mdot
.30196 .34118 Mdot
.63922 .54902 Mdot
.27059 .11373 Mdot
.22353 .18039 Mdot
.60784 .42745 Mdot
.41961 .3098 Mdot
.52157 .36863 Mdot
.38039 .24314 Mdot
.12157 .03529 Mdot
.12157 .0902 Mdot
.18039 .16863 Mdot
.17647 .15294 Mdot
.14118 .10588 Mdot
.21176 .21569 Mdot
.35294 .35294 Mdot
.68627 .46275 Mdot
.67059 .43529 Mdot
.32157 .36471 Mdot
.32549 .3451 Mdot
.51373 .5098 Mdot
.34902 .33725 Mdot
.78431 .8 Mdot
.38824 .39216 Mdot
.29412 .3098 Mdot
.27843 .27843 Mdot
.25098 .2902 Mdot
.11765 .09412 Mdot
.24314 .07843 Mdot
.18824 .16863 Mdot
.27059 .11373 Mdot
.41569 .3098 Mdot
.46667 .33725 Mdot
.33725 .16863 Mdot
.3451 .2 Mdot
.09804 .07059 Mdot
.20392 .18039 Mdot
.23529 .21961 Mdot
.2549 .21176 Mdot
.27843 .27059 Mdot
.22353 .22745 Mdot
.60392 .40784 Mdot
.79216 .41961 Mdot
.4 .34902 Mdot
.30196 .35686 Mdot
.32157 .33333 Mdot
.47843 .44706 Mdot
.46667 .48235 Mdot
.29804 .32157 Mdot
.42353 .42745 Mdot
.34118 .34902 Mdot
.75686 .78824 Mdot
.16078 .18824 Mdot
.56471 .43137 Mdot
.19608 .14118 Mdot
.22353 .17255 Mdot
.50196 .32941 Mdot
.41569 .32941 Mdot
.40784 .23137 Mdot
.31765 .13725 Mdot
.30196 .20392 Mdot
.10196 .0902 Mdot
.18431 .16078 Mdot
.18431 .15686 Mdot
.36471 .3451 Mdot
.24706 .27843 Mdot
.65098 .57255 Mdot
.66667 .29412 Mdot
.77255 .42745 Mdot
.42353 .44314 Mdot
.28627 .31373 Mdot
.32941 .31373 Mdot
.60392 .58431 Mdot
.36471 .38824 Mdot
.41176 .38824 Mdot
.46275 .47843 Mdot
.38431 .38431 Mdot
.20784 .2549 Mdot
.13333 .11765 Mdot
.45098 .31373 Mdot
.18431 .17647 Mdot
.18824 .05098 Mdot
.38824 .27843 Mdot
.33725 .19608 Mdot
.40784 .21569 Mdot
.2902 .08627 Mdot
.15294 .12941 Mdot
.16471 .14902 Mdot
.17255 .16078 Mdot
.27451 .24706 Mdot
.41176 .40784 Mdot
.26275 .27451 Mdot
.73333 .52549 Mdot
.67451 .23922 Mdot
.70588 .41569 Mdot
.55686 .60784 Mdot
.33333 .3451 Mdot
.61569 .57647 Mdot
.53333 .51765 Mdot
.28235 .30588 Mdot
.4549 .43137 Mdot
.4902 .50196 Mdot
.34118 .37255 Mdot
.18824 .21569 Mdot
.26275 .21961 Mdot
.16863 .04706 Mdot
.18431 .13333 Mdot
.47843 .27451 Mdot
.58431 .5098 Mdot
.26275 .0902 Mdot
.35686 .14902 Mdot
.45098 .27451 Mdot
.14118 .12157 Mdot
.12549 .10196 Mdot
.12157 .09412 Mdot
.1451 .12157 Mdot
.24706 .26667 Mdot
.19216 .16471 Mdot
.5098 .17647 Mdot
.8 .32941 Mdot
.68627 .45882 Mdot
.28627 .34118 Mdot
.37647 .35686 Mdot
.58039 .54902 Mdot
.53333 .53725 Mdot
.28627 .29804 Mdot
.45882 .43529 Mdot
.46275 .46667 Mdot
.40784 .44314 Mdot
.21176 .23137 Mdot
.72157 .64314 Mdot
.21961 .12157 Mdot
.22353 .11373 Mdot
.64706 .40392 Mdot
.21176 .13725 Mdot
.38431 .21961 Mdot
.26667 .04706 Mdot
.09412 0 Mdot
.11765 .0902 Mdot
.19608 .16471 Mdot
.20392 .16863 Mdot
.80784 .8 Mdot
.21176 .23137 Mdot
.74118 .60392 Mdot
.78824 .36471 Mdot
.67843 .25098 Mdot
.83922 .76471 Mdot
.31373 .32157 Mdot
.56863 .53725 Mdot
.57255 .54902 Mdot
.56471 .58824 Mdot
.28235 .27843 Mdot
.46667 .45882 Mdot
.45098 .4549 Mdot
.3098 .34118 Mdot
.25882 .26667 Mdot
.61961 .48235 Mdot
.24314 .13333 Mdot
.35686 .21961 Mdot
.53725 .33725 Mdot
.37647 .3098 Mdot
.32157 .16863 Mdot
.40392 .15294 Mdot
.11765 .04314 Mdot
.12941 .10196 Mdot
.16863 .1451 Mdot
.18431 .16471 Mdot
.21569 .21176 Mdot
.24706 .23529 Mdot
.79216 .5451 Mdot
.67451 .21176 Mdot
.70196 .32157 Mdot
.3098 .34902 Mdot
.45882 .43137 Mdot
.54902 .52549 Mdot
.56471 .54902 Mdot
.40392 .44706 Mdot
.29804 .27843 Mdot
.4902 .48235 Mdot
.4549 .48627 Mdot
.27843 .2902 Mdot
.31765 .32157 Mdot
.61176 .40392 Mdot
.2 .07843 Mdot
.38039 .18431 Mdot
.19608 .07059 Mdot
.31373 .24314 Mdot
.36471 .22353 Mdot
.28235 .00392 Mdot
.16471 .10196 Mdot
.12157 .09412 Mdot
.22353 .20784 Mdot
.10588 .0902 Mdot
.4549 .44706 Mdot
.25882 .26667 Mdot
.67451 .51765 Mdot
.43922 .01176 Mdot
.6549 .25882 Mdot
.70588 .65882 Mdot
.47059 .44314 Mdot
.58039 .55686 Mdot
.55294 .53725 Mdot
.59608 .61961 Mdot
.31373 .3098 Mdot
.50588 .48235 Mdot
.46275 .48627 Mdot
.24314 .24314 Mdot
.43529 .43922 Mdot
.7451 .60392 Mdot
.18431 0 Mdot
.19608 .07059 Mdot
.64706 .45098 Mdot
.37647 .32549 Mdot
.31373 .23922 Mdot
.48235 .17647 Mdot
.10588 .00784 Mdot
.23137 .20392 Mdot
.13333 .12157 Mdot
.14118 .13333 Mdot
.79216 .76078 Mdot
.23137 .25882 Mdot
.21569 .17647 Mdot
.51765 .22745 Mdot
.52941 .08235 Mdot
.8 .51373 Mdot
.33333 .36863 Mdot
.60392 .56078 Mdot
.57647 .55294 Mdot
.56078 .54902 Mdot
.37255 .40784 Mdot
.43529 .40784 Mdot
.4902 .48627 Mdot
.38824 .41569 Mdot
.45882 .45098 Mdot
.4 .38431 Mdot
.69804 .46275 Mdot
.20392 .03137 Mdot
.18431 .02353 Mdot
.2 .08235 Mdot
.42745 .35294 Mdot
.19216 .07059 Mdot
.70588 .27451 Mdot
.14902 .07451 Mdot
.2 .18431 Mdot
.12157 .12549 Mdot
.08627 .04706 Mdot
.79608 .76863 Mdot
.20784 .24314 Mdot
.27843 .24314 Mdot
.58431 .33333 Mdot
.58431 .14902 Mdot
.62353 .36078 Mdot
.32157 .34902 Mdot
.55294 .51765 Mdot
.63137 .6 Mdot
.56863 .55686 Mdot
.4902 .52157 Mdot
.32549 .29804 Mdot
.49412 .49412 Mdot
.31765 .33725 Mdot
.46667 .4549 Mdot
.46275 .4549 Mdot
.67451 .5098 Mdot
.58824 .3451 Mdot
.20784 .02745 Mdot
.34902 .15294 Mdot
.36471 .23137 Mdot
.38039 .2549 Mdot
.72549 .20784 Mdot
.15294 .03137 Mdot
.27843 .24706 Mdot
.17647 .16863 Mdot
.11765 .07059 Mdot
.43922 .39608 Mdot
.73333 .71765 Mdot
.23529 .26275 Mdot
.17647 .12157 Mdot
.57647 .28627 Mdot
.58824 .20392 Mdot
.77647 .70588 Mdot
.56471 .55294 Mdot
.58824 .55686 Mdot
.63137 .59608 Mdot
.55686 .5451 Mdot
.36863 .4 Mdot
.48235 .4549 Mdot
.47451 .4902 Mdot
.25098 .2549 Mdot
.47843 .47059 Mdot
.47843 .46667 Mdot
.60784 .45098 Mdot
.70196 .47059 Mdot
.16863 0 Mdot
.4 .21176 Mdot
.30196 .13725 Mdot
.54118 .27059 Mdot
.81961 .24314 Mdot
.13333 0 Mdot
.19216 .14902 Mdot
.14902 .11373 Mdot
.53725 .4549 Mdot
.41569 .36078 Mdot
.96863 .94902 Mdot
.22745 .26275 Mdot
.22353 .19608 Mdot
.68235 .52549 Mdot
.53333 .19216 Mdot
.72549 .62745 Mdot
.51765 .52549 Mdot
.56471 .54118 Mdot
.7451 .7098 Mdot
.58824 .56471 Mdot
.56078 .58039 Mdot
.2902 .27451 Mdot
.48235 .49412 Mdot
.2902 .28627 Mdot
.49412 .49412 Mdot
.45882 .45882 Mdot
.48627 .43529 Mdot
.6549 .49804 Mdot
.6902 .44314 Mdot
.57647 .3451 Mdot
.38039 .19608 Mdot
.2549 .01176 Mdot
.81569 .18824 Mdot
.40784 .07059 Mdot
.15294 .05098 Mdot
.13333 .05098 Mdot
.40392 .27451 Mdot
.43137 .36863 Mdot
.43922 .36471 Mdot
.53725 .52549 Mdot
.21961 .25098 Mdot
.47059 .4549 Mdot
.68235 .5451 Mdot
.76863 .52549 Mdot
.87451 .85882 Mdot
.29412 .27451 Mdot
.55294 .52941 Mdot
.67059 .63529 Mdot
.58431 .56471 Mdot
.57255 .59216 Mdot
.30196 .2902 Mdot
.46667 .4902 Mdot
.4 .38039 Mdot
.47451 .47451 Mdot
.47451 .47451 Mdot
.47059 .45882 Mdot
.51373 .41176 Mdot
.76863 .52549 Mdot
.37647 .19216 Mdot
.45882 .23137 Mdot
.44706 .07059 Mdot
.84706 .18431 Mdot
.71765 .32549 Mdot
.13725 0 Mdot
.16863 0 Mdot
.35686 .23922 Mdot
.50196 .43922 Mdot
.46667 .34902 Mdot
.98039 .96078 Mdot
.18824 .21569 Mdot
.25098 .27451 Mdot
.51765 .47843 Mdot
.57647 .42745 Mdot
.67059 .65882 Mdot
.56471 .55686 Mdot
.57647 .54118 Mdot
.57647 .55294 Mdot
.78431 .74902 Mdot
.57647 .55686 Mdot
.34118 .36471 Mdot
.49412 .48627 Mdot
.28235 .28627 Mdot
.48235 .48235 Mdot
.48627 .48235 Mdot
.47451 .48235 Mdot
.48235 .45882 Mdot
.51765 .42745 Mdot
.78039 .50588 Mdot
.54902 .44706 Mdot
.46667 .07843 Mdot
.68627 .0549 Mdot
.89804 .27451 Mdot
.69804 .26667 Mdot
.52549 .14118 Mdot
.58039 .27843 Mdot
.38824 .34118 Mdot
.47451 .34902 Mdot
.26667 .16863 Mdot
.23529 .23529 Mdot
.25098 .28627 Mdot
.17647 .19608 Mdot
.7451 .6902 Mdot
.59608 .57255 Mdot
.45098 .44314 Mdot
.4549 .43137 Mdot
.56863 .5451 Mdot
.58431 .56078 Mdot
.6549 .62745 Mdot
.57647 .59216 Mdot
.2549 .24706 Mdot
.47843 .4902 Mdot
.48235 .46667 Mdot
.48235 .47843 Mdot
.48235 .48235 Mdot
.47843 .48627 Mdot
.47843 .47059 Mdot
.52941 .36863 Mdot
.44314 .28235 Mdot
.74118 .44706 Mdot
.70196 .13333 Mdot
.8549 .17647 Mdot
.92549 .30196 Mdot
.8549 .32941 Mdot
.78431 .27059 Mdot
.24314 .14902 Mdot
.42745 .37255 Mdot
.53333 .36078 Mdot
.43137 .37647 Mdot
.2 .22745 Mdot
.21176 .2549 Mdot
.27843 .28627 Mdot
.82353 .79608 Mdot
.38039 .41961 Mdot
.4902 .46667 Mdot
.40392 .38824 Mdot
.58431 .56078 Mdot
.57647 .55294 Mdot
.67451 .63922 Mdot
.55686 .58824 Mdot
.32549 .29804 Mdot
.31373 .31765 Mdot
.48627 .47843 Mdot
.50588 .50196 Mdot
.48627 .48235 Mdot
.47451 .47451 Mdot
.49412 .4902 Mdot
.53725 .22745 Mdot
.44314 .36078 Mdot
.76078 .26667 Mdot
.7451 .11765 Mdot
.9098 .22745 Mdot
.88627 .23529 Mdot
.90196 .3451 Mdot
.69804 .23922 Mdot
.33725 .2902 Mdot
.37647 .30196 Mdot
.54902 .37255 Mdot
.72157 .72157 Mdot
.24706 .26275 Mdot
.2549 .30196 Mdot
.2902 .29412 Mdot
.2549 .26275 Mdot
.28627 .30588 Mdot
.54118 .51765 Mdot
.37255 .35686 Mdot
.57647 .54118 Mdot
.6 .56471 Mdot
.70588 .68235 Mdot
.36863 .4 Mdot
.34118 .33725 Mdot
.46275 .45098 Mdot
.50196 .49804 Mdot
.4902 .48627 Mdot
.4902 .4902 Mdot
.4902 .48235 Mdot
.50196 .40392 Mdot
.77255 .44314 Mdot
.83922 .7451 Mdot
.82745 .26667 Mdot
.8 .17255 Mdot
.8902 .23922 Mdot
.8902 .20392 Mdot
.83137 .25098 Mdot
.40392 .10588 Mdot
.31765 .26275 Mdot
.39216 .2902 Mdot
.64706 .47451 Mdot
.23529 .23529 Mdot
.22745 .2549 Mdot
.24706 .28627 Mdot
.23922 .24706 Mdot
.65098 .67059 Mdot
.27843 .25882 Mdot
.56078 .5451 Mdot
.36863 .36078 Mdot
.57255 .54902 Mdot
.58039 .55686 Mdot
.72549 .72157 Mdot
.39608 .4 Mdot
.31373 .31765 Mdot
.47451 .45882 Mdot
.49804 .4902 Mdot
.49804 .4902 Mdot
.49804 .49412 Mdot
.50588 .47059 Mdot
.5098 .20392 Mdot
.87843 .7451 Mdot
.54118 .34118 Mdot
.87843 .36078 Mdot
.85098 .26275 Mdot
.88235 .23529 Mdot
.89804 .22353 Mdot
.78039 .18431 Mdot
.38824 .19216 Mdot
.38824 .30588 Mdot
.41176 .23922 Mdot
.67451 .56863 Mdot
.23529 .2549 Mdot
.44314 .48235 Mdot
.25098 .29804 Mdot
.27843 .30196 Mdot
.35686 .38431 Mdot
.45098 .41961 Mdot
.56078 .55294 Mdot
.49804 .4902 Mdot
.58824 .56471 Mdot
.59608 .57255 Mdot
.76863 .78039 Mdot
.50196 .4902 Mdot
.34902 .35294 Mdot
.44706 .43529 Mdot
.51765 .50196 Mdot
.50588 .49804 Mdot
.50196 .4902 Mdot
.52549 .38431 Mdot
.74118 .40784 Mdot
.58431 .55294 Mdot
.53725 .34118 Mdot
.87059 .43922 Mdot
.87451 .34902 Mdot
.8902 .25098 Mdot
.88235 .21961 Mdot
.74902 .1451 Mdot
.41569 .15294 Mdot
.35294 .21569 Mdot
.42353 .23137 Mdot
.97647 .9451 Mdot
.2 .21569 Mdot
.32941 .37255 Mdot
.27059 .32941 Mdot
.27059 .30588 Mdot
.28627 .31373 Mdot
.5451 .51765 Mdot
.56078 .5451 Mdot
.58824 .56471 Mdot
.58431 .57255 Mdot
.59216 .56863 Mdot
.70196 .72549 Mdot
.62353 .61176 Mdot
.44314 .43922 Mdot
.29412 .28627 Mdot
.47843 .46667 Mdot
.50588 .50196 Mdot
.54902 .48627 Mdot
.51373 .23137 Mdot
.81569 .63137 Mdot
.60392 .61961 Mdot
.27451 .16863 Mdot
.83529 .48235 Mdot
.9098 .44706 Mdot
.87843 .26275 Mdot
.87059 .20784 Mdot
.77647 .17255 Mdot
.54902 .17647 Mdot
.38431 .1451 Mdot
.40392 .21176 Mdot
.84314 .83137 Mdot
.25098 .25882 Mdot
.39216 .44314 Mdot
.23137 .28235 Mdot
.26667 .31373 Mdot
.27059 .2902 Mdot
.5451 .52157 Mdot
.56471 .55294 Mdot
.6 .57647 Mdot
.4902 .47843 Mdot
.58824 .57647 Mdot
.40392 .43922 Mdot
.45882 .45098 Mdot
.50588 .49804 Mdot
.2549 .26275 Mdot
.40784 .40392 Mdot
.50196 .50588 Mdot
.53333 .37647 Mdot
.73725 .43529 Mdot
.60784 .56078 Mdot
.6 .64314 Mdot
.27843 .23137 Mdot
.6549 .40392 Mdot
.86275 .48235 Mdot
.86275 .30196 Mdot
.84706 .21961 Mdot
.78431 .19608 Mdot
.61961 .16863 Mdot
.58824 .20784 Mdot
.43529 .21961 Mdot
.32157 .30196 Mdot
.25882 .28235 Mdot
.36471 .4 Mdot
.47059 .51765 Mdot
.26667 .30588 Mdot
.29804 .29804 Mdot
.5451 .52157 Mdot
.55686 .54118 Mdot
.58039 .55294 Mdot
.34118 .32941 Mdot
.56471 .55686 Mdot
.37255 .40392 Mdot
.24706 .24706 Mdot
.5098 .49412 Mdot
.36471 .36863 Mdot
.26667 .27059 Mdot
.47843 .47451 Mdot
.56471 .32157 Mdot
.75686 .59216 Mdot
.60784 .63137 Mdot
.59216 .63529 Mdot
.11765 .10196 Mdot
.49804 .37647 Mdot
.77255 .49804 Mdot
.8549 .36863 Mdot
.85098 .3098 Mdot
.81176 .23137 Mdot
.7451 .22353 Mdot
.79216 .28627 Mdot
.72157 .51373 Mdot
.26667 .25098 Mdot
.26667 .2902 Mdot
.73333 .76863 Mdot
.76078 .80784 Mdot
.26667 .30196 Mdot
.2902 .28235 Mdot
.56078 .53725 Mdot
.57647 .56078 Mdot
.58431 .55686 Mdot
.25098 .24314 Mdot
.53725 .54902 Mdot
.30196 .32941 Mdot
.19608 .2 Mdot
.46275 .46275 Mdot
.43922 .45098 Mdot
.27451 .28627 Mdot
.33333 .30588 Mdot
.76471 .52157 Mdot
.61569 .57255 Mdot
.60392 .64314 Mdot
.62745 .66275 Mdot
.23922 .23529 Mdot
.76471 .71765 Mdot
.58431 .4 Mdot
.81569 .43529 Mdot
.86667 .43529 Mdot
.81569 .26275 Mdot
.74902 .2 Mdot
.77647 .20392 Mdot
.70196 .51765 Mdot
.26667 .25098 Mdot
.24706 .26667 Mdot
.81569 .83529 Mdot
.47451 .52941 Mdot
.25098 .2902 Mdot
.50196 .47451 Mdot
.56078 .5451 Mdot
.58431 .56863 Mdot
.56863 .55294 Mdot
.32549 .3098 Mdot
.56078 .59216 Mdot
.30588 .31765 Mdot
.2902 .30588 Mdot
.31765 .31373 Mdot
.40784 .40784 Mdot
.41961 .41569 Mdot
.4549 .39216 Mdot
.68627 .57647 Mdot
.61961 .62745 Mdot
.60784 .63922 Mdot
.68627 .70588 Mdot
.82745 .81176 Mdot
.90588 .88235 Mdot
.60392 .5098 Mdot
.61569 .37647 Mdot
.8549 .53725 Mdot
.83137 .35294 Mdot
.77647 .24706 Mdot
.87059 .31373 Mdot
.65882 .53725 Mdot
.21569 .23137 Mdot
.38039 .39216 Mdot
.10196 .11765 Mdot
.30588 .36471 Mdot
.26667 .29412 Mdot
.54118 .51765 Mdot
.55686 .54902 Mdot
.57647 .55686 Mdot
.56471 .53725 Mdot
.37255 .37255 Mdot
.31373 .34118 Mdot
.29412 .28627 Mdot
.29804 .3098 Mdot
.21961 .22353 Mdot
.36863 .36863 Mdot
.46667 .4549 Mdot
.83922 .75686 Mdot
.6 .59216 Mdot
.61961 .63529 Mdot
.59216 .60784 Mdot
.14902 .15686 Mdot
.89804 .88235 Mdot
.89412 .88627 Mdot
.82745 .77255 Mdot
.39608 .24706 Mdot
.73725 .49412 Mdot
.84314 .41961 Mdot
.76471 .21176 Mdot
.92157 .50588 Mdot
.86275 .84706 Mdot
.28235 .31373 Mdot
.34118 .34118 Mdot
.87059 .89804 Mdot
.29804 .35686 Mdot
.28627 .27059 Mdot
.55686 .54902 Mdot
.56471 .54902 Mdot
.55294 .53725 Mdot
.57255 .55294 Mdot
.36471 .38824 Mdot
.27059 .21176 Mdot
.29412 .25882 Mdot
.30588 .30588 Mdot
.18824 .20392 Mdot
.39608 .38039 Mdot
.35686 .33333 Mdot
.59608 .57255 Mdot
.6 .61569 Mdot
.59216 .60784 Mdot
.59216 .61569 Mdot
.14118 .12941 Mdot
.89412 .88627 Mdot
.89804 .87451 Mdot
.9098 .87843 Mdot
.61569 .54902 Mdot
.45098 .31373 Mdot
.76471 .41176 Mdot
.80784 .30588 Mdot
.51373 .25098 Mdot
.41176 .39216 Mdot
.2902 .29412 Mdot
.68627 .67843 Mdot
.45098 .49804 Mdot
.23922 .28627 Mdot
.46667 .45098 Mdot
.56471 .54902 Mdot
.55686 .54118 Mdot
.57255 .5451 Mdot
.57647 .56863 Mdot
.30588 .32549 Mdot
.23922 .07843 Mdot
.30196 .25098 Mdot
.28627 .28627 Mdot
.2549 .27059 Mdot
.38039 .37647 Mdot
.38039 .34902 Mdot
.60392 .61961 Mdot
.58824 .60392 Mdot
.59216 .61961 Mdot
.57647 .6 Mdot
.9451 .93333 Mdot
.82353 .80392 Mdot
.90588 .88235 Mdot
.91765 .9098 Mdot
.78431 .76078 Mdot
.28235 .17255 Mdot
.81176 .33725 Mdot
.51373 .15294 Mdot
.98039 .92941 Mdot
.28235 .3098 Mdot
.41176 .41961 Mdot
.68627 .6902 Mdot
.60392 .6549 Mdot
.29412 .26275 Mdot
.55686 .54902 Mdot
.56863 .5451 Mdot
.56471 .54118 Mdot
.56863 .55294 Mdot
.55686 .59216 Mdot
.2902 .16863 Mdot
.27451 .0549 Mdot
.3098 .22353 Mdot
.28627 .29804 Mdot
.25882 .27843 Mdot
.26275 .2549 Mdot
.58431 .59216 Mdot
.59216 .6 Mdot
.58824 .61176 Mdot
.60784 .64314 Mdot
.14118 .14902 Mdot
.87451 .87843 Mdot
.78431 .74902 Mdot
.91765 .92157 Mdot
.91373 .8902 Mdot
.8902 .87059 Mdot
.32941 .13725 Mdot
.5451 .15294 Mdot
.4902 .19216 Mdot
.25882 .23137 Mdot
.28627 .29412 Mdot
.28627 .2902 Mdot
.67451 .69804 Mdot
.16471 .2 Mdot
.51373 .4902 Mdot
.55294 .54118 Mdot
.57255 .54902 Mdot
.57255 .55686 Mdot
.57647 .57647 Mdot
.30196 .32157 Mdot
.80392 .44314 Mdot
.29412 .04706 Mdot
.32157 .23137 Mdot
.28235 .3098 Mdot
.28235 .3098 Mdot
.35294 .34118 Mdot
.58039 .59608 Mdot
.59216 .61569 Mdot
.60392 .63137 Mdot
.54118 .56863 Mdot
.92549 .92941 Mdot
.50588 .48627 Mdot
.89804 .87059 Mdot
.36471 .35294 Mdot
.89804 .88627 Mdot
.87059 .87451 Mdot
.81176 .35686 Mdot
.82745 .41569 Mdot
.98431 .93333 Mdot
.25882 .26667 Mdot
.23529 .27059 Mdot
.16471 .18431 Mdot
.16471 .20392 Mdot
.34118 .31765 Mdot
.26275 .25882 Mdot
.56471 .55294 Mdot
.57255 .55294 Mdot
.56471 .56078 Mdot
.32157 .37255 Mdot
.36471 .18039 Mdot
.84314 .41176 Mdot
.29804 .02745 Mdot
.30196 .2549 Mdot
.26667 .3098 Mdot
.34118 .32941 Mdot
.58431 .6 Mdot
.60392 .62745 Mdot
.59216 .61961 Mdot
.63529 .66275 Mdot
.06275 .07059 Mdot
.36471 .34902 Mdot
.69412 .6549 Mdot
.57647 .56078 Mdot
.62745 .61961 Mdot
.8902 .87843 Mdot
.60392 .34902 Mdot
.52157 .09412 Mdot
.68627 .43529 Mdot
.3098 .27451 Mdot
.23529 .24706 Mdot
.16471 .18824 Mdot
.15294 .17647 Mdot
.28627 .29804 Mdot
.56863 .56078 Mdot
.5451 .53333 Mdot
.57647 .56078 Mdot
.57255 .55686 Mdot
.53725 .57255 Mdot
.31373 .2902 Mdot
.81569 .41569 Mdot
.82745 .40784 Mdot
.29804 .09412 Mdot
.27451 .3098 Mdot
.27451 .28627 Mdot
.57255 .58039 Mdot
.60392 .63137 Mdot
.60392 .64314 Mdot
.60392 .63137 Mdot
.16471 .16863 Mdot
.34118 .32941 Mdot
.76471 .74118 Mdot
.06667 .05882 Mdot
.8549 .84314 Mdot
.5098 .49412 Mdot
.88627 .84314 Mdot
.48235 .04314 Mdot
.84706 .41961 Mdot
.76471 .73725 Mdot
.30196 .2902 Mdot
.26275 .2902 Mdot
.30196 .32549 Mdot
.28235 .32157 Mdot
.52549 .5098 Mdot
.23922 .23529 Mdot
.58039 .55686 Mdot
.57255 .55294 Mdot
.51765 .53725 Mdot
.27843 .29412 Mdot
.44706 .2549 Mdot
.83137 .4 Mdot
.76471 .38039 Mdot
.27843 .29412 Mdot
.26667 .28627 Mdot
.57647 .56863 Mdot
.59608 .62353 Mdot
.59216 .62745 Mdot
.62353 .65098 Mdot
.12941 .12549 Mdot
.66275 .65098 Mdot
.47059 .46667 Mdot
.86667 .84706 Mdot
.85098 .82745 Mdot
.76078 .75686 Mdot
.86667 .86667 Mdot
.83529 .32157 Mdot
.88627 .36078 Mdot
.97255 .95294 Mdot
.2902 .27843 Mdot
.25098 .27451 Mdot
.27059 .30588 Mdot
.28627 .31765 Mdot
.56078 .53333 Mdot
.34902 .3451 Mdot
.58824 .56471 Mdot
.57647 .55686 Mdot
.55686 .6 Mdot
.27059 .27843 Mdot
.22353 .08627 Mdot
.82745 .42353 Mdot
.81961 .45882 Mdot
.27843 .30196 Mdot
.26667 .28627 Mdot
.57647 .58039 Mdot
.60784 .63137 Mdot
.60392 .64706 Mdot
.50588 .53333 Mdot
.14902 .14902 Mdot
.8 .79216 Mdot
.57647 .56863 Mdot
.5451 .52941 Mdot
.4902 .47843 Mdot
.63137 .62353 Mdot
.89804 .87059 Mdot
.72549 .17647 Mdot
.88235 .46667 Mdot
.75294 .73725 Mdot
.31765 .31373 Mdot
.25098 .29412 Mdot
.27843 .31765 Mdot
.52941 .51373 Mdot
.56078 .55294 Mdot
.35686 .34118 Mdot
.58431 .55686 Mdot
.5451 .56471 Mdot
.28235 .30196 Mdot
.3098 .26667 Mdot
.27843 .0549 Mdot
.85098 .29804 Mdot
.30588 .24706 Mdot
.27843 .3098 Mdot
.42353 .40784 Mdot
.5451 .57255 Mdot
.41961 .46275 Mdot
.26667 .30196 Mdot
.17647 .19216 Mdot
.62745 .61961 Mdot
.72549 .72157 Mdot
.87843 .86667 Mdot
.66667 .65098 Mdot
.6 .58824 Mdot
.88235 .90196 Mdot
.83137 .4902 Mdot
.85882 .26275 Mdot
.97647 .92549 Mdot
.3098 .2902 Mdot
.18824 .22353 Mdot
.27843 .31765 Mdot
.4902 .48235 Mdot
.56078 .55294 Mdot
.30588 .2902 Mdot
.59608 .56863 Mdot
.53333 .55294 Mdot
.28235 .3098 Mdot
.34118 .26667 Mdot
.23137 0 Mdot
.8549 .27451 Mdot
.31765 .23529 Mdot
.26275 .29412 Mdot
.44706 .43922 Mdot
.25098 .27843 Mdot
.27843 .32549 Mdot
.44314 .47843 Mdot
.16471 .18039 Mdot
.23137 .22353 Mdot
.73725 .73333 Mdot
.87059 .8549 Mdot
.92157 .9098 Mdot
.95294 .93725 Mdot
.88235 .89804 Mdot
.84706 .58431 Mdot
.86667 .29804 Mdot
.97647 .92549 Mdot
.3451 .31765 Mdot
.22745 .27059 Mdot
.29412 .31373 Mdot
.48627 .46275 Mdot
.55686 .54118 Mdot
.21569 .2 Mdot
.58431 .57255 Mdot
.28235 .33725 Mdot
.30196 .2902 Mdot
.61569 .25882 Mdot
.41176 0 Mdot
.83922 .42745 Mdot
.27451 .27843 Mdot
.28627 .2902 Mdot
.43529 .45098 Mdot
.53333 .55686 Mdot
.58824 .62745 Mdot
.56863 .58431 Mdot
.12549 .12549 Mdot
.8902 .87451 Mdot
.67451 .65882 Mdot
.21961 .19608 Mdot
.20784 .19608 Mdot
.67843 .65882 Mdot
.89412 .89412 Mdot
.84314 .43922 Mdot
.43137 .10588 Mdot
.63529 .60784 Mdot
.31373 .34118 Mdot
.24706 .27451 Mdot
.49804 .48235 Mdot
.55294 .53725 Mdot
.58039 .57255 Mdot
.58431 .56863 Mdot
.42353 .47843 Mdot
.28235 .28627 Mdot
.86667 .4549 Mdot
.85882 .39216 Mdot
.83922 .33725 Mdot
.2902 .27451 Mdot
.28235 .29804 Mdot
.59608 .59216 Mdot
.59216 .60784 Mdot
.59216 .61569 Mdot
.56863 .58431 Mdot
.11373 .11765 Mdot
.74118 .71765 Mdot
.42745 .4 Mdot
.78431 .76078 Mdot
.2549 .24314 Mdot
.27059 .24706 Mdot
.87843 .89412 Mdot
.69804 .48627 Mdot
.90588 .50196 Mdot
.69804 .67843 Mdot
.31373 .32941 Mdot
.25882 .27843 Mdot
.46667 .45098 Mdot
.55294 .53725 Mdot
.58039 .57255 Mdot
.54118 .55294 Mdot
.29804 .34118 Mdot
.3451 .28627 Mdot
.85882 .27059 Mdot
.83529 .35294 Mdot
.79608 .49804 Mdot
.26275 .28627 Mdot
.31765 .2902 Mdot
.56471 .58824 Mdot
.57255 .6 Mdot
.58039 .59608 Mdot
.65098 .65882 Mdot
.90588 .90196 Mdot
.70588 .68235 Mdot
.91373 .89804 Mdot
.32157 .29804 Mdot
.94118 .90588 Mdot
.94118 .92549 Mdot
.87059 .88235 Mdot
.1451 0 Mdot
.5098 .25882 Mdot
.38039 .37255 Mdot
.30196 .32549 Mdot
.32549 .32157 Mdot
.4902 .47059 Mdot
.56863 .55294 Mdot
.32941 .32157 Mdot
.33333 .39608 Mdot
.30196 .30196 Mdot
.86667 .31765 Mdot
.83922 .3451 Mdot
.79216 .4549 Mdot
.29412 .28627 Mdot
.29412 .29804 Mdot
.58824 .59216 Mdot
.57255 .58824 Mdot
.57255 .58824 Mdot
.56078 .56863 Mdot
.07843 .07843 Mdot
.69412 .66667 Mdot
.56471 .53725 Mdot
.8 .78824 Mdot
.28627 .2549 Mdot
.4902 .47451 Mdot
.89412 .88627 Mdot
.25098 .20392 Mdot
.8902 .4902 Mdot
.85882 .85882 Mdot
.27843 .28235 Mdot
.2549 .26667 Mdot
.47451 .45098 Mdot
.56078 .54118 Mdot
.57255 .56863 Mdot
.31373 .38431 Mdot
.28627 .2902 Mdot
.84314 .29804 Mdot
.77647 .38824 Mdot
.51373 .32941 Mdot
.2902 .30196 Mdot
.29804 .3098 Mdot
.57255 .58824 Mdot
.59216 .60784 Mdot
.56471 .58039 Mdot
.57647 .58039 Mdot
.12941 .13725 Mdot
.49412 .47451 Mdot
.86667 .84706 Mdot
.56078 .54902 Mdot
.78039 .75686 Mdot
.48627 .47451 Mdot
.8902 .8902 Mdot
.22745 .17647 Mdot
.89412 .4902 Mdot
.78431 .76863 Mdot
.24706 .26667 Mdot
.45098 .43529 Mdot
.50588 .48235 Mdot
.57647 .55294 Mdot
.46667 .49804 Mdot
.27059 .31765 Mdot
.16078 .03137 Mdot
.86275 .26275 Mdot
.2549 .12941 Mdot
.3098 .24706 Mdot
.27843 .30588 Mdot
.40784 .41569 Mdot
.60392 .61961 Mdot
.58824 .61176 Mdot
.57647 .59216 Mdot
.12549 .12941 Mdot
.70196 .69412 Mdot
.44706 .44314 Mdot
.91765 .90196 Mdot
.44706 .42745 Mdot
.41569 .39216 Mdot
.89804 .8902 Mdot
.87451 .87843 Mdot
.4902 .23137 Mdot
.5451 .40392 Mdot
.30196 .3098 Mdot
.32157 .31765 Mdot
.47843 .45882 Mdot
.56078 .53725 Mdot
.52549 .54902 Mdot
.26667 .31373 Mdot
.25098 .16078 Mdot
.87059 .27843 Mdot
.36078 .22745 Mdot
.22353 .2 Mdot
.27059 .29412 Mdot
.4549 .46667 Mdot
.58431 .61176 Mdot
.58039 .59608 Mdot
.57647 .58431 Mdot
.13725 .14118 Mdot
.33725 .34118 Mdot
.80392 .79608 Mdot
.37255 .35686 Mdot
.86667 .84314 Mdot
.81961 .79608 Mdot
.90196 .90196 Mdot
.87843 .88235 Mdot
.51373 .25098 Mdot
.77647 .67059 Mdot
.55686 .56471 Mdot
.4902 .49804 Mdot
.44706 .43137 Mdot
.53333 .51373 Mdot
.52549 .56471 Mdot
.26667 .30196 Mdot
.18431 .07843 Mdot
.84314 .28627 Mdot
.31765 .15294 Mdot
.30588 .27451 Mdot
.27843 .29412 Mdot
.57255 .58431 Mdot
.57647 .60392 Mdot
.57647 .59216 Mdot
.57255 .58824 Mdot
.16863 .16863 Mdot
.59608 .59216 Mdot
.42745 .41569 Mdot
.17647 .16471 Mdot
.36863 .36078 Mdot
.46275 .44706 Mdot
.89412 .89412 Mdot
.86667 .86275 Mdot
.87451 .49412 Mdot
.72941 .69804 Mdot
.38039 .38431 Mdot
.33725 .35294 Mdot
.46275 .44314 Mdot
.55686 .5451 Mdot
.29804 .35294 Mdot
.27059 .29412 Mdot
.73725 .45098 Mdot
.88235 .41569 Mdot
.28627 .12157 Mdot
.30196 .25098 Mdot
.32157 .32157 Mdot
.57647 .60784 Mdot
.58431 .61569 Mdot
.56863 .56863 Mdot
.51373 .5098 Mdot
.90588 .89804 Mdot
.43922 .42353 Mdot
.9098 .89804 Mdot
.13725 .14118 Mdot
.51373 .48627 Mdot
.9451 .93725 Mdot
.88627 .8902 Mdot
.16471 .03922 Mdot
.37255 .13725 Mdot
.69412 .63137 Mdot
.53333 .53725 Mdot
.40784 .40392 Mdot
.49412 .47059 Mdot
.48235 .50588 Mdot
.27059 .30196 Mdot
.31373 .27843 Mdot
.82353 .38824 Mdot
.67059 .31765 Mdot
.23529 .05098 Mdot
.31373 .31373 Mdot
.58431 .61176 Mdot
.58039 .60784 Mdot
.59216 .60784 Mdot
.56471 .56863 Mdot
.34118 .32549 Mdot
.88235 .87451 Mdot
.83922 .81961 Mdot
.42745 .43137 Mdot
.8 .79608 Mdot
.50588 .49412 Mdot
.89804 .89804 Mdot
.30588 .25882 Mdot
.90196 .49412 Mdot
.39216 .33725 Mdot
.67843 .6549 Mdot
.47843 .50196 Mdot
.45098 .43137 Mdot
.48235 .48235 Mdot
.28235 .31373 Mdot
.27451 .29412 Mdot
.36471 .21569 Mdot
.83922 .4 Mdot
.72157 .31765 Mdot
.32157 .2549 Mdot
.59608 .59608 Mdot
.57255 .59608 Mdot
.56078 .58431 Mdot
.55294 .55686 Mdot
.17255 .16471 Mdot
.88627 .88627 Mdot
.66275 .6549 Mdot
.73725 .72941 Mdot
.13333 .14118 Mdot
.52157 .51373 Mdot
.90196 .8902 Mdot
.91373 .91373 Mdot
.78431 .43137 Mdot
.83922 .80784 Mdot
.69804 .65882 Mdot
.67059 .68235 Mdot
.30196 .28627 Mdot
.46667 .45098 Mdot
.29804 .32157 Mdot
.28235 .3098 Mdot
.18431 .14118 Mdot
.81176 .45098 Mdot
.8549 .40392 Mdot
.33725 .24314 Mdot
.58039 .58431 Mdot
.59608 .61961 Mdot
.57255 .59608 Mdot
.5451 .56078 Mdot
.15686 .14902 Mdot
.87451 .88627 Mdot
.52941 .52549 Mdot
.94902 .94118 Mdot
.76471 .76863 Mdot
.24314 .24314 Mdot
.89804 .88627 Mdot
.92157 .91373 Mdot
.85882 .47843 Mdot
.73725 .70588 Mdot
.61569 .58039 Mdot
.65098 .63922 Mdot
.31373 .27059 Mdot
.4549 .4549 Mdot
.28627 .30196 Mdot
.28627 .30196 Mdot
.22353 .18431 Mdot
.72941 .45882 Mdot
.80392 .4549 Mdot
.35686 .31373 Mdot
.59608 .61176 Mdot
.5451 .57255 Mdot
.45098 .47843 Mdot
.44314 .44706 Mdot
.91765 .91373 Mdot
.63529 .66667 Mdot
.40784 .37647 Mdot
.90196 .89412 Mdot
.9098 .91373 Mdot
.8549 .84706 Mdot
.8902 .89412 Mdot
.2 .1098 Mdot
.93333 .64706 Mdot
.58039 .5451 Mdot
.79216 .76078 Mdot
.76471 .7451 Mdot
.47059 .45098 Mdot
.27059 .27451 Mdot
.29412 .3098 Mdot
.31373 .33333 Mdot
.20784 .09804 Mdot
.70196 .41961 Mdot
.36471 .30196 Mdot
.47059 .48627 Mdot
.26275 .29412 Mdot
.32549 .35294 Mdot
.47059 .48235 Mdot
.5451 .5451 Mdot
.82745 .85098 Mdot
.43529 .41176 Mdot
.8902 .87843 Mdot
.8902 .87843 Mdot
.78039 .77255 Mdot
.89804 .89804 Mdot
.34118 .27843 Mdot
.92157 .60784 Mdot
.63922 .60784 Mdot
.89804 .8902 Mdot
.42353 .39608 Mdot
.25098 .23922 Mdot
.30588 .31373 Mdot
.30196 .31765 Mdot
.27843 .24706 Mdot
.22353 .1098 Mdot
.37255 .33725 Mdot
.34118 .35686 Mdot
.37255 .40392 Mdot
.5098 .53725 Mdot
.65882 .6549 Mdot
.81961 .80784 Mdot
.81961 .82745 Mdot
.82353 .79608 Mdot
.87843 .8549 Mdot
.8902 .8549 Mdot
.61569 .61569 Mdot
.89412 .89804 Mdot
.19216 .11373 Mdot
.95294 .71765 Mdot
.97647 .95686 Mdot
.37255 .34902 Mdot
.23137 .21961 Mdot
.28627 .2902 Mdot
.30196 .31765 Mdot
.29412 .29412 Mdot
.28627 .26667 Mdot
.53333 .54118 Mdot
.56078 .58039 Mdot
.58824 .59608 Mdot
.55686 .55294 Mdot
.07059 .05882 Mdot
.87843 .87843 Mdot
.69412 .65882 Mdot
.88627 .88627 Mdot
.73725 .67843 Mdot
.90588 .88627 Mdot
.89804 .89412 Mdot
.87843 .84706 Mdot
.87059 .47451 Mdot
.69412 .67843 Mdot
.24706 .23137 Mdot
.26667 .26275 Mdot
.31765 .32549 Mdot
.30196 .32157 Mdot
.36471 .36863 Mdot
.55294 .56078 Mdot
.56078 .56863 Mdot
.55686 .55294 Mdot
.61569 .60392 Mdot
.63137 .62745 Mdot
.85882 .8549 Mdot
.59608 .58431 Mdot
.68627 .68627 Mdot
.44314 .38431 Mdot
.9098 .87059 Mdot
.88627 .8902 Mdot
.18039 .07451 Mdot
.96863 .72549 Mdot
.48627 .46667 Mdot
.26275 .24706 Mdot
.28235 .27451 Mdot
.29804 .32549 Mdot
.34118 .35686 Mdot
.5451 .54902 Mdot
.55294 .55294 Mdot
.5451 .5451 Mdot
.54118 .52941 Mdot
.20784 .20784 Mdot
.88627 .89412 Mdot
.45098 .45098 Mdot
.71373 .72157 Mdot
.33725 .28235 Mdot
.9451 .85098 Mdot
.89412 .86275 Mdot
.43529 .3098 Mdot
.93725 .66275 Mdot
.58431 .56471 Mdot
.27451 .2549 Mdot
.27451 .27059 Mdot
.30196 .33725 Mdot
.52549 .52549 Mdot
.54118 .54902 Mdot
.52941 .54118 Mdot
.52941 .52941 Mdot
.16078 .15294 Mdot
.87059 .87843 Mdot
.61176 .60784 Mdot
.69412 .72157 Mdot
.42353 .39216 Mdot
.52157 .38039 Mdot
.91765 .78431 Mdot
.87059 .76863 Mdot
.84314 .41569 Mdot
.92941 .9098 Mdot
.3098 .2902 Mdot
.23529 .23529 Mdot
.29804 .31373 Mdot
.52157 .5098 Mdot
.52549 .52941 Mdot
.53333 .54902 Mdot
.52941 .51765 Mdot
.16078 .16471 Mdot
.5451 .56078 Mdot
.4549 .44706 Mdot
.2 .22745 Mdot
.45882 .40392 Mdot
.54902 .35294 Mdot
.76863 .6 Mdot
.83529 .60392 Mdot
.89412 .47843 Mdot
.82353 .81176 Mdot
.27843 .26275 Mdot
.25882 .26275 Mdot
.54118 .4902 Mdot
.52549 .51373 Mdot
.52941 .54118 Mdot
.50588 .5098 Mdot
.16471 .18039 Mdot
.85882 .88627 Mdot
.68627 .67843 Mdot
.6549 .6902 Mdot
.35294 .29804 Mdot
.41961 .24314 Mdot
.46275 .20784 Mdot
.52157 .28235 Mdot
.86667 .37647 Mdot
.82353 .80784 Mdot
.29412 .27843 Mdot
.52941 .45882 Mdot
.52941 .4549 Mdot
.51373 .50196 Mdot
.51765 .49804 Mdot
.18824 .19216 Mdot
.87843 .90196 Mdot
.65882 .65882 Mdot
.87843 .90196 Mdot
.36471 .33333 Mdot
.38039 .24706 Mdot
.58431 .2902 Mdot
.34902 .06667 Mdot
.86667 .3098 Mdot
.90196 .8902 Mdot
.84314 .78431 Mdot
.55294 .37255 Mdot
.5098 .43529 Mdot
.50588 .47059 Mdot
.17255 .14118 Mdot
.89804 .8902 Mdot
.43529 .45098 Mdot
.90196 .92157 Mdot
.33725 .38039 Mdot
.4902 .41961 Mdot
.54118 .23137 Mdot
.43137 .1451 Mdot
.8549 .24706 Mdot
.98824 .96078 Mdot
.76078 .62745 Mdot
.6 .43529 Mdot
.47451 .41961 Mdot
.46667 .35686 Mdot
.77647 .70588 Mdot
.8902 .87843 Mdot
.90196 .89804 Mdot
.23922 .28235 Mdot
.4 .38824 Mdot
.53725 .36471 Mdot
.40392 .18824 Mdot
.80392 .2549 Mdot
.90196 .62745 Mdot
.84706 .75686 Mdot
.65882 .54902 Mdot
.6902 .5451 Mdot
.22353 .04706 Mdot
.91373 .8 Mdot
.9098 .87843 Mdot
.8902 .8902 Mdot
.42353 .47451 Mdot
.55686 .52157 Mdot
.47451 .28235 Mdot
.63137 .23922 Mdot
.87843 .31765 Mdot
.99608 .94118 Mdot
.67059 .58431 Mdot
.52941 .3451 Mdot
.42353 .15294 Mdot
.89412 .7098 Mdot
.89804 .81176 Mdot
.8902 .8549 Mdot
.33333 .34902 Mdot
.68235 .63922 Mdot
.80784 .67451 Mdot
.77647 .23137 Mdot
.9098 .53333 Mdot
.83529 .79216 Mdot
.84314 .57647 Mdot
.66275 .28627 Mdot
.8 .53725 Mdot
.89804 .74902 Mdot
.91373 .85882 Mdot
.90588 .88627 Mdot
.69804 .64314 Mdot
.53725 .21176 Mdot
.87451 .28235 Mdot
.99216 .95686 Mdot
.84706 .59608 Mdot
.74902 .35686 Mdot
.53725 .16078 Mdot
.79216 .53333 Mdot
.9098 .77647 Mdot
.89804 .82353 Mdot
.42745 .33725 Mdot
.78431 .28235 Mdot
.92549 .47843 Mdot
.99216 .93725 Mdot
.84706 .62745 Mdot
.86275 .34902 Mdot
.59608 .16471 Mdot
.63529 .34118 Mdot
.87059 .6549 Mdot
.90588 .72941 Mdot
.71765 .37647 Mdot
.87059 .35686 Mdot
1 .95686 Mdot
.78039 .37255 Mdot
.87451 .3098 Mdot
.77647 .33725 Mdot
.5451 .20784 Mdot
.67059 .43137 Mdot
.43922 .16863 Mdot
.85882 .35294 Mdot
1 .95686 Mdot
.77255 .42353 Mdot
.79608 .22745 Mdot
.85098 .36471 Mdot
.78824 .43137 Mdot
.56863 .23137 Mdot
.83137 .51373 Mdot
.83529 .48235 Mdot
.62745 .47059 Mdot
.79216 .3098 Mdot
.74902 .29412 Mdot
.76078 .46275 Mdot
.83922 .53725 Mdot
.83137 .58039 Mdot
.63137 .38431 Mdot
.96471 .9098 Mdot
.77255 .45098 Mdot
.80392 .53725 Mdot
.87843 .7451 Mdot
.92941 .78039 Mdot
.92157 .80392 Mdot
.88235 .78824 Mdot
.90588 .76863 Mdot
.9451 .79216 Mdot
1 .94902 Mdot
.99216 .9451 Mdot
.99608 .9451 Mdot
.628 .126 .941 r
.90588 .89804 Mdot
.4902 .48235 Mdot
.8 .79216 Mdot
.16471 .1451 Mdot
.18431 .15294 Mdot
.11373 .0902 Mdot
.29412 .27059 Mdot
.37255 .34902 Mdot
.19216 .15686 Mdot
.25098 .23137 Mdot
.23922 .22353 Mdot
.2 .16471 Mdot
.21961 .20392 Mdot
.22353 .18824 Mdot
.16078 .12549 Mdot
.16863 .14902 Mdot
.27843 .23529 Mdot
.83922 .83137 Mdot
.2549 .21961 Mdot
.20392 .18431 Mdot
.27451 .23137 Mdot
.96471 .95294 Mdot
.7451 .72157 Mdot
.23137 .21569 Mdot
.22353 .2 Mdot
.24314 .20392 Mdot
.81961 .79608 Mdot
.73333 .73725 Mdot
.51765 .49412 Mdot
.09412 .07059 Mdot
.14118 .12549 Mdot
.21176 .17647 Mdot
.15686 .13725 Mdot
.41569 .40784 Mdot
.55686 .54902 Mdot
.30196 .25882 Mdot
.4549 .4549 Mdot
.24706 .2 Mdot
.08235 .0549 Mdot
.17647 .16863 Mdot
.25098 .21176 Mdot
.1451 .13725 Mdot
.85098 .81961 Mdot
.68235 .67059 Mdot
.11373 .09412 Mdot
.4 .38824 Mdot
.28627 .23137 Mdot
.40392 .39216 Mdot
.30196 .27059 Mdot
.09412 .04706 Mdot
.12941 .12157 Mdot
.22353 .19216 Mdot
.16078 .15294 Mdot
.23529 .18039 Mdot
.46275 .39608 Mdot
.76863 .73725 Mdot
.94902 .94118 Mdot
.10588 .08627 Mdot
.09804 .07451 Mdot
.83922 .83922 Mdot
.23922 .16863 Mdot
.42745 .41961 Mdot
.30588 .27059 Mdot
.0549 .02353 Mdot
.1451 .12941 Mdot
.22353 .2 Mdot
.13333 .13333 Mdot
.30196 .18824 Mdot
.2 .0549 Mdot
.18431 .13333 Mdot
.43529 .42745 Mdot
.75294 .73725 Mdot
.95294 .9451 Mdot
.12157 .10588 Mdot
.22353 .18431 Mdot
.0902 .07451 Mdot
.27451 .23137 Mdot
.49804 .45098 Mdot
.30588 .28235 Mdot
.25098 .20392 Mdot
.12549 .12157 Mdot
.15686 .14902 Mdot
.12941 .12157 Mdot
.02353 .01961 Mdot
.29412 .09804 Mdot
.2 .0549 Mdot
.16471 .12549 Mdot
.16863 .1451 Mdot
.27059 .24314 Mdot
.52941 .5098 Mdot
.81569 .80392 Mdot
1 .95686 Mdot
.10588 .08627 Mdot
.2 .17647 Mdot
.20392 .16471 Mdot
.32157 .31765 Mdot
.27451 .20784 Mdot
.2902 .25098 Mdot
.2902 .26667 Mdot
.36471 .3098 Mdot
.12157 .10588 Mdot
.16078 .15294 Mdot
.13725 .13725 Mdot
.27451 .2 Mdot
.43922 .23922 Mdot
.24314 .11373 Mdot
.39216 .35686 Mdot
.17255 .13725 Mdot
.16078 .1451 Mdot
.16078 .13333 Mdot
.28627 .24314 Mdot
.59608 .47843 Mdot
.11765 .09804 Mdot
.25098 .23137 Mdot
.17255 .14902 Mdot
.09412 .07451 Mdot
.62745 .59608 Mdot
.22353 .15686 Mdot
.41569 .38824 Mdot
.30588 .27451 Mdot
.27059 .23137 Mdot
.12157 .10196 Mdot
.15686 .15686 Mdot
.08235 .08627 Mdot
.46275 .32549 Mdot
.37255 .17647 Mdot
.30196 .20784 Mdot
.57255 .56078 Mdot
.45882 .41961 Mdot
.32941 .30588 Mdot
.18431 .16863 Mdot
.18039 .08627 Mdot
.35294 .23137 Mdot
.12549 .10196 Mdot
.14902 .12941 Mdot
.14902 .13333 Mdot
.1098 .10196 Mdot
.28627 .23529 Mdot
.54118 .47059 Mdot
.26667 .23529 Mdot
.28627 .24706 Mdot
.2549 .2 Mdot
.09804 .0902 Mdot
.09804 .10196 Mdot
.06667 .05098 Mdot
.31765 .18039 Mdot
.28627 .12549 Mdot
.23922 .20784 Mdot
.20392 .20784 Mdot
.55294 .52941 Mdot
.50196 .45882 Mdot
.15294 .1451 Mdot
.39216 .16471 Mdot
.39216 .32157 Mdot
.11373 .09412 Mdot
.11765 .09412 Mdot
.11765 .10196 Mdot
.10196 .0902 Mdot
.25098 .19216 Mdot
.32157 .27843 Mdot
.26667 .22745 Mdot
.2549 .22353 Mdot
.31373 .25098 Mdot
.07059 .06275 Mdot
.03137 .03529 Mdot
.27059 .23529 Mdot
.42745 .32941 Mdot
.26667 .13333 Mdot
.63922 .61569 Mdot
.16863 .16471 Mdot
.33725 .32549 Mdot
.54118 .49804 Mdot
.23529 .22353 Mdot
.44314 .15294 Mdot
.0549 .00784 Mdot
.11373 .09412 Mdot
.32941 .30588 Mdot
.12549 .1098 Mdot
.13333 .12157 Mdot
.27451 .21961 Mdot
.29804 .24706 Mdot
.2549 .21176 Mdot
.24706 .20784 Mdot
.32157 .26275 Mdot
.0902 .07843 Mdot
.08235 .08235 Mdot
.27451 .23529 Mdot
.38039 .31765 Mdot
.38039 .29412 Mdot
.54118 .51765 Mdot
.25882 .25882 Mdot
.19216 .18431 Mdot
.56078 .52941 Mdot
.24706 .22745 Mdot
.45098 .17255 Mdot
.07843 .03137 Mdot
.12549 .10588 Mdot
.32157 .29804 Mdot
.10588 .07843 Mdot
.09804 .08627 Mdot
.27451 .21961 Mdot
.28235 .23529 Mdot
.24706 .2 Mdot
.26275 .21569 Mdot
.35686 .29412 Mdot
.36863 .33725 Mdot
.34118 .34118 Mdot
.28627 .24706 Mdot
.34902 .29412 Mdot
.33725 .27843 Mdot
.54118 .52549 Mdot
.38431 .38431 Mdot
.2 .19608 Mdot
.61176 .58039 Mdot
.28235 .26667 Mdot
.4902 .25098 Mdot
.11373 .06667 Mdot
.14118 .12157 Mdot
.28627 .25882 Mdot
.10196 .07451 Mdot
.07451 .06667 Mdot
.2902 .23922 Mdot
.28627 .23922 Mdot
.28627 .23922 Mdot
.27843 .23137 Mdot
.3098 .24314 Mdot
.36078 .30588 Mdot
.33333 .3098 Mdot
.30196 .28235 Mdot
.38431 .31373 Mdot
.37647 .32549 Mdot
.53333 .51373 Mdot
.23137 .23529 Mdot
.46275 .47451 Mdot
.52549 .49412 Mdot
.32941 .32549 Mdot
.44706 .31373 Mdot
.57255 .47843 Mdot
.13725 .12157 Mdot
.14118 .1098 Mdot
.09804 .06667 Mdot
.12549 .1098 Mdot
.82745 .81569 Mdot
.28235 .22745 Mdot
.27451 .22353 Mdot
.28235 .23922 Mdot
.28627 .23529 Mdot
.31765 .21176 Mdot
.36863 .27843 Mdot
.36863 .33333 Mdot
.27451 .24706 Mdot
.3098 .21569 Mdot
.36471 .2902 Mdot
.62745 .61569 Mdot
.41569 .40392 Mdot
.16863 .16471 Mdot
.56471 .53725 Mdot
.19608 .18431 Mdot
.23922 .12941 Mdot
.7098 .63529 Mdot
.12549 .1098 Mdot
.21569 .19608 Mdot
.21569 .19608 Mdot
.1098 .10196 Mdot
.52549 .50588 Mdot
.30196 .2549 Mdot
.28627 .23137 Mdot
.30588 .26667 Mdot
.29412 .2549 Mdot
.30196 .18431 Mdot
.40784 .26667 Mdot
.38039 .2902 Mdot
.31373 .28627 Mdot
.20392 .11373 Mdot
.32549 .19216 Mdot
.24706 .18824 Mdot
.24706 .26275 Mdot
.55686 .56471 Mdot
.52549 .5098 Mdot
.23137 .23922 Mdot
.36078 .31373 Mdot
.38824 .30196 Mdot
.12549 .10588 Mdot
.11765 .10196 Mdot
.20392 .17255 Mdot
.14118 .1451 Mdot
.43922 .41961 Mdot
.74118 .71765 Mdot
.28627 .23922 Mdot
.32941 .27059 Mdot
.36471 .31765 Mdot
.33333 .29804 Mdot
.38824 .25882 Mdot
.46667 .29804 Mdot
.4 .27451 Mdot
.29412 .24706 Mdot
.28235 .20392 Mdot
.41961 .27059 Mdot
.31373 .23529 Mdot
.17647 .19216 Mdot
.39216 .40784 Mdot
.64706 .63529 Mdot
.28235 .28235 Mdot
.50196 .47059 Mdot
.47843 .4 Mdot
.08235 .07451 Mdot
.1098 .09412 Mdot
.13725 .10588 Mdot
.11373 .12549 Mdot
.47843 .47059 Mdot
.4549 .41176 Mdot
.38824 .36078 Mdot
.33333 .26667 Mdot
.4902 .43137 Mdot
.41961 .37647 Mdot
.37647 .31373 Mdot
.56863 .39216 Mdot
.48627 .28627 Mdot
.32549 .19608 Mdot
.28235 .24706 Mdot
.40784 .30196 Mdot
.40784 .29412 Mdot
.56863 .58431 Mdot
.65882 .64706 Mdot
.30196 .30196 Mdot
.61569 .63137 Mdot
.35686 .32157 Mdot
.35686 .31373 Mdot
.9451 .89412 Mdot
.18039 .16863 Mdot
.12941 .1098 Mdot
.13333 .12549 Mdot
.0549 .07451 Mdot
.5098 .4549 Mdot
.42745 .38431 Mdot
.28627 .24314 Mdot
.3098 .24314 Mdot
.45882 .40784 Mdot
.41569 .37255 Mdot
.43137 .36471 Mdot
.56863 .41176 Mdot
.54118 .3451 Mdot
.50196 .37647 Mdot
.29804 .26275 Mdot
.37647 .28627 Mdot
.64706 .57255 Mdot
.26667 .29412 Mdot
.71765 .71373 Mdot
.23137 .21961 Mdot
.13333 .16078 Mdot
.32941 .29412 Mdot
.38824 .32941 Mdot
.8902 .87059 Mdot
.0902 .08235 Mdot
.13333 .11373 Mdot
.12941 .12941 Mdot
.51373 .5451 Mdot
.53333 .48627 Mdot
.48235 .43922 Mdot
.96078 .95294 Mdot
.34902 .28235 Mdot
.37647 .3098 Mdot
.39216 .33333 Mdot
.39216 .33725 Mdot
.42745 .32941 Mdot
.5098 .37255 Mdot
.44706 .31373 Mdot
.2902 .24314 Mdot
.33725 .27059 Mdot
.38039 .32157 Mdot
.71765 .7451 Mdot
.70588 .69804 Mdot
.30196 .29804 Mdot
.67059 .69412 Mdot
.33725 .30588 Mdot
.37255 .3451 Mdot
.67843 .60784 Mdot
.33725 .37255 Mdot
.06667 .07059 Mdot
.12157 .12941 Mdot
.18824 .23529 Mdot
.54118 .50196 Mdot
.51373 .48235 Mdot
.48627 .44314 Mdot
.97647 .95294 Mdot
.36078 .30196 Mdot
.38039 .32157 Mdot
.34902 .29412 Mdot
.38431 .32549 Mdot
.39608 .32157 Mdot
.40784 .31373 Mdot
.43529 .32941 Mdot
.31765 .27451 Mdot
.30588 .25098 Mdot
.28235 .24706 Mdot
.74902 .78431 Mdot
.72549 .72549 Mdot
.65098 .64706 Mdot
.72941 .76471 Mdot
.38431 .36078 Mdot
.39216 .36471 Mdot
.69804 .61176 Mdot
.24314 .28627 Mdot
.33725 .34118 Mdot
.12941 .16471 Mdot
.22353 .27451 Mdot
.55294 .50588 Mdot
.35294 .33333 Mdot
.48235 .43922 Mdot
.54902 .53333 Mdot
.29804 .24314 Mdot
.3451 .2902 Mdot
.4549 .39608 Mdot
.38039 .32549 Mdot
.38039 .32157 Mdot
.41176 .34118 Mdot
.39608 .31373 Mdot
.43529 .38039 Mdot
.3451 .29804 Mdot
.33725 .28627 Mdot
.38431 .41961 Mdot
.52157 .5451 Mdot
.71373 .72941 Mdot
.72941 .75294 Mdot
.3098 .2902 Mdot
.43922 .41176 Mdot
.5451 .4 Mdot
.34902 .36863 Mdot
.21176 .22353 Mdot
.3098 .38039 Mdot
.17647 .24706 Mdot
.62745 .61176 Mdot
.33725 .31373 Mdot
.36863 .33725 Mdot
.48627 .45882 Mdot
.31765 .26667 Mdot
.32941 .27059 Mdot
.37647 .31373 Mdot
.43922 .37647 Mdot
.42353 .36471 Mdot
.36471 .30588 Mdot
.40392 .32941 Mdot
.41176 .34902 Mdot
.41569 .36471 Mdot
.3451 .30588 Mdot
.29412 .30196 Mdot
.31765 .32941 Mdot
.37255 .39608 Mdot
.56863 .57647 Mdot
.27059 .28627 Mdot
.37647 .35686 Mdot
.39608 .25098 Mdot
.80392 .71373 Mdot
.26667 .3098 Mdot
.43137 .45098 Mdot
.23529 .32157 Mdot
.10588 .15686 Mdot
.63529 .58824 Mdot
.5451 .52549 Mdot
.54902 .51765 Mdot
.7451 .73333 Mdot
.36078 .30588 Mdot
.36078 .31765 Mdot
.4 .32941 Mdot
.41569 .32941 Mdot
.43529 .35294 Mdot
.36078 .29804 Mdot
.37647 .31765 Mdot
.39608 .3451 Mdot
.41176 .35686 Mdot
.32549 .28627 Mdot
.37647 .37647 Mdot
.33725 .33333 Mdot
.28235 .28235 Mdot
.26275 .2902 Mdot
.30196 .27059 Mdot
.41961 .34118 Mdot
.67843 .38039 Mdot
.15294 .18431 Mdot
.82353 .82745 Mdot
.19216 .25882 Mdot
.16863 .24314 Mdot
.67843 .65882 Mdot
.38824 .36471 Mdot
.58824 .57647 Mdot
.49412 .4902 Mdot
.3098 .26275 Mdot
.34118 .27843 Mdot
.38431 .31765 Mdot
.41176 .29412 Mdot
.41961 .3098 Mdot
.42745 .36078 Mdot
.38431 .32941 Mdot
.35686 .29804 Mdot
.39216 .34902 Mdot
.44314 .4 Mdot
.38431 .35294 Mdot
.40784 .40392 Mdot
.38039 .37647 Mdot
.3451 .35686 Mdot
.3098 .28235 Mdot
.32549 .28235 Mdot
.64314 .28235 Mdot
.8549 .79216 Mdot
.4902 .52549 Mdot
.90196 .91765 Mdot
.52941 .60392 Mdot
.12549 .15686 Mdot
.66667 .63529 Mdot
.31373 .29804 Mdot
.55686 .55686 Mdot
.92157 .9098 Mdot
.34118 .2902 Mdot
.35686 .30196 Mdot
.40784 .28627 Mdot
.47843 .28627 Mdot
.45098 .32549 Mdot
.39608 .33333 Mdot
.40392 .3451 Mdot
.37647 .32549 Mdot
.39608 .34902 Mdot
.35294 .30196 Mdot
.38824 .37255 Mdot
.47059 .4549 Mdot
.44314 .42745 Mdot
.39216 .38824 Mdot
.34118 .30588 Mdot
.34118 .23922 Mdot
.77647 .36471 Mdot
.6 .63137 Mdot
.33333 .35294 Mdot
.97647 1 Mdot
.50588 .53725 Mdot
.72941 .71765 Mdot
.61961 .58824 Mdot
.30196 .28235 Mdot
.70196 .7098 Mdot
.31765 .28235 Mdot
.33725 .28235 Mdot
.39216 .2902 Mdot
.49412 .31765 Mdot
.4902 .35294 Mdot
.40784 .33333 Mdot
.37647 .30588 Mdot
.39216 .33333 Mdot
.42745 .38039 Mdot
.37647 .35294 Mdot
.37647 .3098 Mdot
.21961 .22353 Mdot
.3451 .32941 Mdot
.45098 .44314 Mdot
.43922 .41176 Mdot
.32549 .28627 Mdot
.48235 .20392 Mdot
.82745 .6902 Mdot
.26667 .33333 Mdot
.94118 .95294 Mdot
.24314 .32941 Mdot
.65882 .67059 Mdot
.71373 .69412 Mdot
.66275 .63137 Mdot
.51765 .52549 Mdot
.3098 .28627 Mdot
.36863 .32941 Mdot
.34902 .28235 Mdot
.47843 .2902 Mdot
.58431 .46667 Mdot
.69412 .65098 Mdot
.43922 .36471 Mdot
.39216 .32549 Mdot
.38824 .33333 Mdot
.45098 .40784 Mdot
.39216 .36078 Mdot
.14902 .1098 Mdot
.18039 .18039 Mdot
.24706 .22353 Mdot
.2902 .27843 Mdot
.34118 .33333 Mdot
.32941 .27451 Mdot
.78039 .44314 Mdot
.67451 .70588 Mdot
.93725 .97647 Mdot
.88235 .8902 Mdot
.90196 .93725 Mdot
.78824 .78039 Mdot
.71765 .69804 Mdot
.63529 .61569 Mdot
.31373 .34902 Mdot
.78431 .77255 Mdot
.35294 .29804 Mdot
.41176 .28627 Mdot
.67843 .52549 Mdot
.70588 .66275 Mdot
.53333 .54902 Mdot
.45098 .32941 Mdot
.38039 .32549 Mdot
.38039 .32157 Mdot
.32549 .3098 Mdot
.37255 .33725 Mdot
.12941 .1098 Mdot
.16078 .1451 Mdot
.17255 .15686 Mdot
.21176 .19608 Mdot
.16863 .17255 Mdot
.2902 .21569 Mdot
.51373 .32157 Mdot
.23529 .29804 Mdot
.74118 .78824 Mdot
.95686 .97647 Mdot
.83922 .84314 Mdot
.80784 .80392 Mdot
.75294 .74118 Mdot
.71373 .70196 Mdot
.31373 .32157 Mdot
.31765 .27451 Mdot
.37255 .30588 Mdot
.53725 .27059 Mdot
.67843 .65098 Mdot
.3451 .37255 Mdot
.22353 .25098 Mdot
.46275 .30588 Mdot
.39216 .32549 Mdot
.40784 .34902 Mdot
.21176 .20392 Mdot
.40392 .35294 Mdot
.11765 .11765 Mdot
.12941 .12157 Mdot
.1451 .13333 Mdot
.16471 .16471 Mdot
.35294 .3451 Mdot
.16471 .08235 Mdot
.23529 .20392 Mdot
.19608 .27451 Mdot
.44314 .5098 Mdot
.49804 .51765 Mdot
.8549 .8549 Mdot
.82745 .81961 Mdot
.76863 .76078 Mdot
.67059 .68235 Mdot
.36471 .32941 Mdot
.36863 .30588 Mdot
.39216 .25882 Mdot
.71765 .42745 Mdot
.86275 .90196 Mdot
.2902 .35686 Mdot
.8549 .77255 Mdot
.4549 .31765 Mdot
.4 .33333 Mdot
.3451 .29412 Mdot
.06667 .05882 Mdot
.38039 .32549 Mdot
.12157 .11373 Mdot
.14118 .13333 Mdot
.16078 .15294 Mdot
.16471 .17255 Mdot
.39608 .37255 Mdot
.18039 .12941 Mdot
.19216 .21569 Mdot
.11373 .17255 Mdot
.25882 .31373 Mdot
.81961 .81961 Mdot
.87059 .87059 Mdot
.85098 .8549 Mdot
.80784 .8 Mdot
.65882 .6902 Mdot
.52157 .48627 Mdot
.33333 .27451 Mdot
.47843 .2549 Mdot
.74902 .55294 Mdot
.36078 .41961 Mdot
.33725 .40392 Mdot
.7098 .54902 Mdot
.46667 .31765 Mdot
.38824 .33333 Mdot
.15686 .12157 Mdot
.08235 .07059 Mdot
.38039 .32549 Mdot
.1098 .10196 Mdot
.17647 .16471 Mdot
.13725 .12157 Mdot
.05098 .06667 Mdot
.38039 .32549 Mdot
.13725 .11765 Mdot
.12941 .14902 Mdot
.29412 .3098 Mdot
.50588 .54118 Mdot
.87843 .88235 Mdot
.87843 .87059 Mdot
.87451 .87451 Mdot
.85098 .85098 Mdot
.41961 .45098 Mdot
.96471 .92549 Mdot
.32941 .25882 Mdot
.55686 .26667 Mdot
.81176 .72549 Mdot
.23922 .30588 Mdot
.78824 .87059 Mdot
.6902 .48627 Mdot
.47059 .31373 Mdot
.4 .32941 Mdot
.16078 .13333 Mdot
.10196 .09804 Mdot
.39216 .33725 Mdot
.13333 .12157 Mdot
.12549 .1098 Mdot
.11373 .10196 Mdot
.08235 .09804 Mdot
.34118 .28627 Mdot
.12157 .12157 Mdot
.12157 .12941 Mdot
.72941 .71765 Mdot
.85882 .87843 Mdot
.88235 .88627 Mdot
.88627 .88627 Mdot
.88235 .88235 Mdot
.87451 .87451 Mdot
.13333 .15294 Mdot
.96863 .95686 Mdot
.35686 .28627 Mdot
.61176 .32941 Mdot
.82745 .78039 Mdot
.23922 .32157 Mdot
.4549 .54902 Mdot
.47843 .33333 Mdot
.48235 .27059 Mdot
.38824 .32549 Mdot
.16078 .13333 Mdot
.40784 .39608 Mdot
.40784 .35686 Mdot
.10588 .09804 Mdot
.13333 .11373 Mdot
.12549 .1098 Mdot
.07451 .09804 Mdot
.32549 .25882 Mdot
.12549 .12549 Mdot
.07059 .06275 Mdot
.84706 .83922 Mdot
.86667 .88627 Mdot
.85098 .85882 Mdot
.87451 .86667 Mdot
.87059 .86275 Mdot
.87059 .87843 Mdot
.32549 .34902 Mdot
.96863 .94902 Mdot
.35294 .27843 Mdot
.65882 .41176 Mdot
.8549 .82745 Mdot
.28235 .36863 Mdot
.30196 .39608 Mdot
.41569 .33333 Mdot
.51373 .26667 Mdot
.39608 .32549 Mdot
.14902 .12549 Mdot
.66275 .64706 Mdot
.42353 .38431 Mdot
.07059 .0549 Mdot
.14118 .12941 Mdot
.12157 .10588 Mdot
.0902 .11765 Mdot
.31765 .24314 Mdot
.1098 .10588 Mdot
.24706 .2 Mdot
.86275 .8549 Mdot
.91373 .9451 Mdot
.6902 .7098 Mdot
.87451 .86667 Mdot
.85882 .85098 Mdot
.86275 .87059 Mdot
.49804 .52941 Mdot
.97255 .94902 Mdot
.39216 .32549 Mdot
.73333 .54902 Mdot
.81961 .81176 Mdot
.23922 .3098 Mdot
.16078 .22745 Mdot
.58824 .56863 Mdot
.52157 .25098 Mdot
.38824 .31765 Mdot
.12941 .10588 Mdot
.36471 .34118 Mdot
.44314 .40392 Mdot
.03529 .01961 Mdot
.14902 .12157 Mdot
.12549 .11373 Mdot
.07059 .09412 Mdot
.30588 .23137 Mdot
.09804 .09412 Mdot
.75686 .63922 Mdot
.86667 .85882 Mdot
.74902 .82745 Mdot
.45098 .47451 Mdot
.88235 .88627 Mdot
.88627 .88627 Mdot
.86667 .86275 Mdot
.43137 .46275 Mdot
.97255 .94902 Mdot
.39608 .32941 Mdot
.74118 .60784 Mdot
.7451 .75294 Mdot
.28627 .3451 Mdot
.45098 .50196 Mdot
.81569 .83922 Mdot
.56471 .27451 Mdot
.41961 .35294 Mdot
.14118 .12157 Mdot
.20784 .18824 Mdot
.37255 .33725 Mdot
.0902 .06275 Mdot
.12157 .0902 Mdot
.09412 .08235 Mdot
.0549 .07451 Mdot
.27059 .20784 Mdot
.08627 .07059 Mdot
.52549 .33333 Mdot
.87843 .8902 Mdot
.28235 .38039 Mdot
.29412 .32941 Mdot
.85882 .86275 Mdot
.88627 .88627 Mdot
.87843 .87451 Mdot
.4 .43137 Mdot
.96471 .93725 Mdot
.41176 .35294 Mdot
.69804 .61569 Mdot
.71765 .7451 Mdot
.75294 .81961 Mdot
.75686 .79608 Mdot
.45098 .49412 Mdot
.67843 .37647 Mdot
.43137 .35294 Mdot
.16078 .14118 Mdot
.2 .18431 Mdot
.36863 .3451 Mdot
.29804 .2549 Mdot
.09804 .0549 Mdot
.06667 .04706 Mdot
.04314 .0549 Mdot
.23922 .18431 Mdot
.05882 .02745 Mdot
.54118 .28627 Mdot
.88627 .9098 Mdot
.28235 .36863 Mdot
.17255 .22353 Mdot
.87843 .89412 Mdot
.87843 .87059 Mdot
.87451 .86275 Mdot
.37255 .40784 Mdot
.96471 .93725 Mdot
.40392 .33725 Mdot
.61569 .57647 Mdot
.79608 .82745 Mdot
.4902 .56078 Mdot
.43922 .48235 Mdot
.40392 .45098 Mdot
.73725 .44706 Mdot
.44706 .36863 Mdot
.15686 .13333 Mdot
.17647 .15294 Mdot
.59216 .58039 Mdot
.35686 .30196 Mdot
.21961 .16863 Mdot
.12157 .0902 Mdot
.02353 .03137 Mdot
.20392 .15686 Mdot
.12549 .07059 Mdot
.61176 .32941 Mdot
.50196 .53725 Mdot
.28627 .36078 Mdot
.12549 .18039 Mdot
.93725 .95294 Mdot
.87843 .87059 Mdot
.87843 .87451 Mdot
.33333 .37255 Mdot
.95686 .93725 Mdot
.41176 .3451 Mdot
.52941 .5098 Mdot
.92549 .96471 Mdot
.3451 .43137 Mdot
.42353 .4902 Mdot
.67843 .71765 Mdot
.75686 .49804 Mdot
.44706 .36863 Mdot
.14902 .13725 Mdot
.1451 .13333 Mdot
.44706 .43529 Mdot
.5098 .43529 Mdot
.36471 .3098 Mdot
.2902 .25098 Mdot
.13333 .12941 Mdot
.26667 .22353 Mdot
.3098 .22353 Mdot
.80784 .5451 Mdot
.26667 .29804 Mdot
.23529 .27059 Mdot
.09804 .15686 Mdot
.87451 .87843 Mdot
.8902 .8902 Mdot
.88235 .87843 Mdot
.32549 .36078 Mdot
.95294 .93725 Mdot
.41569 .35686 Mdot
.43922 .43137 Mdot
.91373 .95686 Mdot
.18431 .27059 Mdot
.22353 .28235 Mdot
.87451 .8902 Mdot
.72941 .47843 Mdot
.46667 .39608 Mdot
.1451 .12157 Mdot
.14902 .13725 Mdot
.20392 .20784 Mdot
.68627 .61569 Mdot
.39216 .32941 Mdot
.41961 .37255 Mdot
.35294 .31765 Mdot
.32549 .2902 Mdot
.36863 .27451 Mdot
.64706 .43922 Mdot
.2549 .28627 Mdot
.15686 .16471 Mdot
.08235 .14118 Mdot
.61569 .61961 Mdot
.83922 .84314 Mdot
.87059 .87843 Mdot
.28627 .32157 Mdot
.9451 .92549 Mdot
.43529 .37647 Mdot
.42745 .41961 Mdot
.68627 .74118 Mdot
.5451 .6 Mdot
.6549 .69804 Mdot
.91373 .90588 Mdot
.67059 .40784 Mdot
.46275 .38431 Mdot
.21961 .19608 Mdot
.15686 .14902 Mdot
.18824 .19608 Mdot
.58039 .51765 Mdot
.61961 .5451 Mdot
.45882 .4 Mdot
.52157 .45882 Mdot
.36863 .33725 Mdot
.40392 .32549 Mdot
.28627 .17255 Mdot
.19608 .21569 Mdot
.16078 .15294 Mdot
.1098 .16863 Mdot
.55686 .55294 Mdot
.32157 .32941 Mdot
.87451 .87059 Mdot
.23922 .27843 Mdot
.9451 .92549 Mdot
.41176 .34118 Mdot
.52941 .50588 Mdot
.47059 .52549 Mdot
.87843 .92549 Mdot
.95294 .98039 Mdot
.90588 .89804 Mdot
.58824 .32549 Mdot
.46275 .38431 Mdot
.48627 .45882 Mdot
.15294 .1451 Mdot
.14902 .16471 Mdot
.44706 .39216 Mdot
.57255 .49804 Mdot
.58824 .51765 Mdot
.60784 .5451 Mdot
.38824 .35686 Mdot
.38431 .31373 Mdot
.24706 .2 Mdot
.1451 .16471 Mdot
.1451 .12941 Mdot
.11765 .17647 Mdot
.56863 .56863 Mdot
.7098 .71765 Mdot
.87843 .87451 Mdot
.21961 .25882 Mdot
.94902 .93333 Mdot
.43529 .34902 Mdot
.73333 .68627 Mdot
.33725 .38039 Mdot
.49412 .56471 Mdot
.90588 .92157 Mdot
.9098 .92549 Mdot
.51765 .26667 Mdot
.46667 .38824 Mdot
.42745 .41176 Mdot
.13333 .11765 Mdot
.1098 .13333 Mdot
.42745 .37647 Mdot
.4549 .38824 Mdot
.49804 .42745 Mdot
.53725 .48235 Mdot
.41176 .37255 Mdot
.24706 .19216 Mdot
.18824 .17255 Mdot
.14902 .18824 Mdot
.14902 .13333 Mdot
.1098 .16863 Mdot
.60392 .60392 Mdot
.65882 .65098 Mdot
.87451 .87059 Mdot
.21176 .25098 Mdot
.96863 .95294 Mdot
.42353 .32549 Mdot
.8 .74118 Mdot
.30196 .34118 Mdot
.35686 .42745 Mdot
.89412 .9098 Mdot
.89412 .92549 Mdot
.47843 .23529 Mdot
.48235 .4 Mdot
.24314 .23137 Mdot
.2 .18824 Mdot
.07451 .09804 Mdot
.41176 .36863 Mdot
.43137 .37255 Mdot
.41569 .35686 Mdot
.43529 .38824 Mdot
.4 .36471 Mdot
.19608 .15294 Mdot
.14902 .16863 Mdot
.16863 .22745 Mdot
.15294 .15686 Mdot
.12157 .17255 Mdot
.56863 .56471 Mdot
.17255 .16471 Mdot
.87059 .87059 Mdot
.21176 .25098 Mdot
.72157 .70196 Mdot
.49412 .37255 Mdot
.8549 .83922 Mdot
.26667 .31373 Mdot
.21569 .27843 Mdot
.90196 .91373 Mdot
.53725 .59608 Mdot
.72941 .41961 Mdot
.32941 .27843 Mdot
.23529 .22745 Mdot
.36863 .3451 Mdot
.09412 .10196 Mdot
.39608 .35294 Mdot
.40392 .35686 Mdot
.40784 .36078 Mdot
.4 .36078 Mdot
.35686 .31373 Mdot
.09412 .06275 Mdot
.13725 .18431 Mdot
.23137 .32157 Mdot
.14902 .15686 Mdot
.54902 .58824 Mdot
.32941 .32941 Mdot
.43922 .42745 Mdot
.87059 .86667 Mdot
.45098 .47843 Mdot
.34902 .31765 Mdot
.48235 .3451 Mdot
.71373 .71765 Mdot
.65882 .72549 Mdot
.6902 .73725 Mdot
.91765 .93725 Mdot
.51373 .57647 Mdot
.75686 .44314 Mdot
.14902 .11765 Mdot
.21176 .20392 Mdot
.5098 .50196 Mdot
.37255 .36863 Mdot
.38431 .3451 Mdot
.39216 .35686 Mdot
.39216 .35294 Mdot
.38039 .34902 Mdot
.36471 .32157 Mdot
.14118 .12549 Mdot
.17647 .23922 Mdot
.26275 .34118 Mdot
.12549 .1451 Mdot
.92941 .95686 Mdot
.52941 .52941 Mdot
.71373 .71373 Mdot
.85882 .87059 Mdot
.21176 .21176 Mdot
.40392 .37255 Mdot
.6549 .51373 Mdot
.71765 .76863 Mdot
.55294 .64706 Mdot
.90196 .94118 Mdot
.77647 .81961 Mdot
.84314 .83922 Mdot
.50196 .26667 Mdot
.20392 .18824 Mdot
.23922 .22745 Mdot
.49804 .4902 Mdot
.39216 .35294 Mdot
.39216 .36078 Mdot
.38431 .35294 Mdot
.38431 .35294 Mdot
.36078 .32941 Mdot
.37255 .32157 Mdot
.17647 .2 Mdot
.28627 .38431 Mdot
.14118 .19216 Mdot
.21569 .24314 Mdot
.88627 .89412 Mdot
.61961 .61961 Mdot
.80784 .8 Mdot
.85098 .87059 Mdot
.33333 .28627 Mdot
.37255 .31373 Mdot
.80784 .72157 Mdot
.28627 .36078 Mdot
.23529 .31373 Mdot
.32549 .37647 Mdot
.38039 .46667 Mdot
.46667 .28627 Mdot
.4549 .34118 Mdot
.22745 .21176 Mdot
.22353 .2 Mdot
.41569 .40784 Mdot
.38431 .33725 Mdot
.40392 .40784 Mdot
.38824 .37647 Mdot
.38824 .37647 Mdot
.37255 .35686 Mdot
.45098 .41176 Mdot
.18824 .22745 Mdot
.21569 .2902 Mdot
.24706 .28235 Mdot
.34118 .38039 Mdot
.48235 .47451 Mdot
.32549 .33333 Mdot
.87451 .87843 Mdot
.62353 .64706 Mdot
.95686 .94902 Mdot
.49412 .39608 Mdot
.7451 .70588 Mdot
.4 .4549 Mdot
.2549 .30588 Mdot
.42745 .45882 Mdot
.77255 .84314 Mdot
.76471 .47843 Mdot
.23529 .18824 Mdot
.24706 .23529 Mdot
.21176 .20392 Mdot
.38039 .36078 Mdot
.39608 .34902 Mdot
.31765 .35294 Mdot
.37255 .40392 Mdot
.37647 .41176 Mdot
.36078 .38824 Mdot
.10196 .08627 Mdot
.14118 .18039 Mdot
.28235 .33333 Mdot
.40392 .41961 Mdot
.68627 .71765 Mdot
.34902 .35294 Mdot
.76078 .77255 Mdot
.87451 .87059 Mdot
.42745 .41961 Mdot
.38824 .3451 Mdot
.7098 .65098 Mdot
.86275 .87843 Mdot
.82745 .8902 Mdot
.85882 .90196 Mdot
.51765 .58431 Mdot
.78824 .78431 Mdot
.47843 .25882 Mdot
.20784 .19608 Mdot
.23529 .21569 Mdot
.18431 .17647 Mdot
.40392 .34902 Mdot
.47451 .45882 Mdot
.40784 .48235 Mdot
.25882 .30196 Mdot
.30196 .35686 Mdot
.35294 .36863 Mdot
.12941 .1451 Mdot
.35686 .40784 Mdot
.36078 .38431 Mdot
.15686 .16471 Mdot
.88627 .88627 Mdot
.8902 .88235 Mdot
.39216 .39608 Mdot
.86667 .87059 Mdot
.36078 .29804 Mdot
.52941 .45882 Mdot
.47059 .50588 Mdot
.47059 .53725 Mdot
.44314 .51765 Mdot
.53333 .59608 Mdot
.16078 .23922 Mdot
.59608 .35294 Mdot
.49412 .40392 Mdot
.19608 .19216 Mdot
.21569 .19216 Mdot
.09804 .10588 Mdot
.38824 .33333 Mdot
.87059 .89412 Mdot
.26275 .3098 Mdot
.54902 .57647 Mdot
.3451 .39608 Mdot
.43922 .41176 Mdot
.43922 .47451 Mdot
.25098 .31765 Mdot
.14902 .1451 Mdot
.12549 .14118 Mdot
.88235 .87451 Mdot
.7451 .74118 Mdot
.87451 .87451 Mdot
.50588 .51765 Mdot
.78431 .75686 Mdot
.81961 .80784 Mdot
.4 .45882 Mdot
.34118 .42353 Mdot
.35294 .42353 Mdot
.38431 .47451 Mdot
.60392 .57255 Mdot
.46667 .22745 Mdot
.21176 .19216 Mdot
.22353 .2 Mdot
.19216 .18039 Mdot
.38431 .35294 Mdot
.47059 .45882 Mdot
.85098 .92157 Mdot
.87451 .89804 Mdot
.85098 .88235 Mdot
.74118 .80392 Mdot
.35294 .35294 Mdot
.24314 .32157 Mdot
.17647 .20392 Mdot
.16863 .16471 Mdot
.9098 .9098 Mdot
.92549 .91765 Mdot
.46667 .46667 Mdot
.87059 .87451 Mdot
.36863 .32157 Mdot
.50196 .43137 Mdot
.32157 .36078 Mdot
.31765 .36078 Mdot
.32549 .36863 Mdot
.33725 .39216 Mdot
.72549 .76863 Mdot
.72157 .42353 Mdot
.52157 .42745 Mdot
.23137 .22745 Mdot
.21569 .19216 Mdot
.11765 .12157 Mdot
.41176 .35686 Mdot
.8549 .87843 Mdot
.75294 .78431 Mdot
.76078 .80784 Mdot
.85098 .90588 Mdot
.45098 .43529 Mdot
.23137 .29804 Mdot
.22745 .27843 Mdot
.16078 .14902 Mdot
.10588 .11373 Mdot
.88627 .88235 Mdot
.60392 .60784 Mdot
.87451 .87451 Mdot
.3451 .36078 Mdot
.46275 .43529 Mdot
.44706 .45098 Mdot
.21176 .22353 Mdot
.2 .18431 Mdot
.20392 .21176 Mdot
.32941 .41569 Mdot
.49412 .2549 Mdot
.47843 .33333 Mdot
.19608 .18431 Mdot
.21961 .20392 Mdot
.16078 .15686 Mdot
.39608 .3451 Mdot
.36863 .38431 Mdot
.36471 .42745 Mdot
.8549 .92157 Mdot
.81961 .85098 Mdot
.20392 .24706 Mdot
.22353 .26275 Mdot
.26667 .34902 Mdot
.15686 .15294 Mdot
.1451 .1451 Mdot
.88627 .88627 Mdot
.88235 .88627 Mdot
.67059 .67059 Mdot
.8549 .87059 Mdot
.50196 .45098 Mdot
.33333 .27451 Mdot
.6549 .63922 Mdot
.63922 .52941 Mdot
.62353 .56078 Mdot
.52549 .56863 Mdot
.47451 .31373 Mdot
.55686 .33333 Mdot
.50588 .43137 Mdot
.20784 .2 Mdot
.2 .19216 Mdot
.40784 .38039 Mdot
.47059 .44314 Mdot
.88235 .93725 Mdot
.85882 .89412 Mdot
.47451 .5098 Mdot
.84706 .90588 Mdot
.24314 .23137 Mdot
.22353 .29804 Mdot
.16471 .16863 Mdot
.15294 .1451 Mdot
.4902 .49412 Mdot
.88627 .88627 Mdot
.37647 .38039 Mdot
.87843 .87451 Mdot
.47451 .45098 Mdot
.43529 .38039 Mdot
.51373 .48235 Mdot
.68235 .53725 Mdot
.55686 .40392 Mdot
.88235 .88235 Mdot
.39216 .21961 Mdot
.55686 .34118 Mdot
.50588 .42353 Mdot
.16863 .15294 Mdot
.25098 .23922 Mdot
.24314 .21961 Mdot
.44706 .41176 Mdot
.86667 .91765 Mdot
.87059 .89412 Mdot
.46275 .50196 Mdot
.83137 .89412 Mdot
.45098 .41961 Mdot
.21176 .27059 Mdot
.14118 .1451 Mdot
.1451 .13725 Mdot
.11765 .12941 Mdot
.8902 .8902 Mdot
.48627 .4902 Mdot
.87843 .87843 Mdot
.25098 .23922 Mdot
.41569 .37255 Mdot
.43137 .38824 Mdot
.52549 .36471 Mdot
.50588 .27451 Mdot
.69412 .69804 Mdot
.60784 .38431 Mdot
.51765 .34118 Mdot
.52157 .44706 Mdot
.39608 .37255 Mdot
.23922 .21961 Mdot
.28627 .25098 Mdot
.47059 .43529 Mdot
.87843 .93333 Mdot
.86667 .89804 Mdot
.4549 .47059 Mdot
.83137 .90588 Mdot
.43529 .39608 Mdot
.22353 .27059 Mdot
.13333 .12157 Mdot
.13333 .12157 Mdot
.13333 .15686 Mdot
.88627 .88627 Mdot
.39608 .39216 Mdot
.87843 .87059 Mdot
.26275 .23922 Mdot
.35686 .31373 Mdot
.42745 .37255 Mdot
.48235 .33725 Mdot
.72157 .4549 Mdot
.45882 .4549 Mdot
.74118 .50588 Mdot
.4549 .32549 Mdot
.5098 .43529 Mdot
.4902 .47451 Mdot
.22353 .20392 Mdot
.29804 .26667 Mdot
.50588 .47843 Mdot
.87451 .92549 Mdot
.86667 .90196 Mdot
.49412 .50196 Mdot
.83529 .9098 Mdot
.43922 .38431 Mdot
.22353 .26667 Mdot
.13333 .12157 Mdot
.13333 .12157 Mdot
.17647 .2 Mdot
.88627 .87843 Mdot
.56863 .55686 Mdot
.87451 .86667 Mdot
.41176 .38431 Mdot
.3451 .3098 Mdot
.42353 .37255 Mdot
.46667 .33725 Mdot
.67059 .41569 Mdot
.22745 .23922 Mdot
.56863 .35686 Mdot
.42353 .34118 Mdot
.3451 .27843 Mdot
.33725 .31765 Mdot
.17255 .16471 Mdot
.43529 .39216 Mdot
.23529 .23922 Mdot
.32941 .39608 Mdot
.85098 .9098 Mdot
.2549 .25882 Mdot
.27843 .33725 Mdot
.18431 .1451 Mdot
.21961 .26275 Mdot
.14902 .12941 Mdot
.1098 .11373 Mdot
.84706 .86667 Mdot
.8902 .8902 Mdot
.53333 .52157 Mdot
.87451 .86667 Mdot
.38431 .33725 Mdot
.42353 .38431 Mdot
.42353 .36863 Mdot
.48627 .33333 Mdot
.63529 .45098 Mdot
.75294 .65882 Mdot
.46275 .34118 Mdot
.40392 .3451 Mdot
.23922 .21569 Mdot
.43529 .42745 Mdot
.12941 .13725 Mdot
.43529 .4 Mdot
.87059 .89412 Mdot
.90588 .92941 Mdot
.40392 .43137 Mdot
.8549 .89412 Mdot
.38039 .3451 Mdot
.17647 .20784 Mdot
.15294 .16471 Mdot
.15294 .16078 Mdot
.14902 .18039 Mdot
.88627 .88627 Mdot
.92941 .92157 Mdot
.49412 .49412 Mdot
.88235 .8902 Mdot
.96863 .95686 Mdot
.36863 .32157 Mdot
.41961 .35686 Mdot
.47059 .32157 Mdot
.65882 .57255 Mdot
.48235 .36078 Mdot
.40784 .3451 Mdot
.52157 .44706 Mdot
.24706 .23529 Mdot
.49412 .48235 Mdot
.33725 .33725 Mdot
.22745 .23137 Mdot
.28627 .35294 Mdot
.84314 .8902 Mdot
.26275 .26275 Mdot
.31765 .38039 Mdot
.31373 .24706 Mdot
.21569 .25882 Mdot
.14118 .1451 Mdot
.12549 .15686 Mdot
.43137 .4549 Mdot
.88627 .88627 Mdot
.81176 .81569 Mdot
.87451 .87843 Mdot
.61569 .56863 Mdot
.42745 .37255 Mdot
.39608 .34902 Mdot
.44314 .35686 Mdot
.49412 .38431 Mdot
.4549 .36471 Mdot
.40784 .3451 Mdot
.39608 .33725 Mdot
.24314 .23529 Mdot
.23137 .23137 Mdot
.39216 .40392 Mdot
.23922 .23529 Mdot
.87451 .93333 Mdot
.86667 .8902 Mdot
.48627 .49412 Mdot
.83529 .89804 Mdot
.42745 .36863 Mdot
.18431 .22745 Mdot
.15294 .17255 Mdot
.09804 .13725 Mdot
.41961 .45098 Mdot
.8902 .8902 Mdot
.85098 .8549 Mdot
.8902 .88235 Mdot
.45098 .44314 Mdot
.56471 .52941 Mdot
.43137 .36471 Mdot
.39608 .32157 Mdot
.46275 .37647 Mdot
.4549 .38431 Mdot
.40784 .35686 Mdot
.41569 .36863 Mdot
.22353 .21961 Mdot
.24314 .24706 Mdot
.30588 .32941 Mdot
.24706 .24314 Mdot
.88235 .94118 Mdot
.87843 .90588 Mdot
.45882 .48235 Mdot
.83922 .90196 Mdot
.40784 .35294 Mdot
.14902 .17647 Mdot
.1451 .17255 Mdot
.24314 .27843 Mdot
.31373 .32941 Mdot
.88627 .88627 Mdot
.91373 .91373 Mdot
.87451 .87059 Mdot
.87059 .86275 Mdot
.89804 .87059 Mdot
.42353 .36863 Mdot
.41176 .34118 Mdot
.42745 .36078 Mdot
.43137 .36863 Mdot
.40784 .35686 Mdot
.41176 .35294 Mdot
.23529 .23529 Mdot
.24706 .24706 Mdot
.13725 .16863 Mdot
.79216 .79608 Mdot
.43529 .5098 Mdot
.86275 .89804 Mdot
.2549 .27059 Mdot
.6 .6549 Mdot
.46275 .40784 Mdot
.16078 .19216 Mdot
.2 .21961 Mdot
.45098 .47059 Mdot
.12549 .15294 Mdot
.88627 .88627 Mdot
.68235 .67843 Mdot
.87843 .87059 Mdot
.29804 .25882 Mdot
.71373 .67843 Mdot
.43529 .36078 Mdot
.38431 .32157 Mdot
.40784 .34902 Mdot
.40784 .34902 Mdot
.40784 .35294 Mdot
.17255 .16471 Mdot
.23529 .23922 Mdot
.19608 .21569 Mdot
.41176 .41176 Mdot
.6549 .71373 Mdot
.87059 .89412 Mdot
.45098 .46667 Mdot
.79608 .86275 Mdot
.42353 .36471 Mdot
.17255 .18431 Mdot
.46275 .46667 Mdot
.21176 .21569 Mdot
.14118 .17255 Mdot
.88627 .88627 Mdot
.89412 .89804 Mdot
.89804 .8902 Mdot
.50588 .4902 Mdot
.81961 .78039 Mdot
.42745 .36863 Mdot
.41569 .34118 Mdot
.38039 .31373 Mdot
.40784 .3451 Mdot
.43922 .38824 Mdot
.15686 .1451 Mdot
.22745 .23922 Mdot
.37255 .37647 Mdot
.51373 .53333 Mdot
.36863 .39216 Mdot
.85098 .86667 Mdot
.87059 .8902 Mdot
.38431 .38039 Mdot
.2902 .26275 Mdot
.47059 .47451 Mdot
.14902 .1451 Mdot
.16078 .1451 Mdot
.94902 .96078 Mdot
.8902 .8902 Mdot
.30588 .30588 Mdot
.87451 .87059 Mdot
.73725 .71765 Mdot
.50196 .45098 Mdot
.40392 .31373 Mdot
.38039 .3098 Mdot
.37255 .30588 Mdot
.43529 .37255 Mdot
.12157 .09412 Mdot
.19608 .2 Mdot
.37255 .37647 Mdot
.45098 .43922 Mdot
.36471 .36863 Mdot
.63922 .65882 Mdot
.78039 .81569 Mdot
.37647 .34902 Mdot
.35294 .31765 Mdot
.2 .19216 Mdot
.15686 .1451 Mdot
.15294 .14118 Mdot
.92549 .93725 Mdot
.8902 .8902 Mdot
.37255 .37647 Mdot
.87451 .87059 Mdot
.91765 .90196 Mdot
.42353 .33725 Mdot
.41569 .3098 Mdot
.42353 .34902 Mdot
.37647 .31765 Mdot
.14902 .0902 Mdot
.1098 .10588 Mdot
.13333 .15686 Mdot
.42745 .37647 Mdot
.41569 .39216 Mdot
.39608 .40392 Mdot
.4549 .48235 Mdot
.4 .39216 Mdot
.43137 .36863 Mdot
.14902 .15294 Mdot
.14902 .14118 Mdot
.15294 .13725 Mdot
.35294 .38039 Mdot
.8902 .88235 Mdot
.43922 .44314 Mdot
.87843 .87059 Mdot
.72157 .67843 Mdot
.45098 .35686 Mdot
.43529 .32157 Mdot
.44314 .36471 Mdot
.43529 .36863 Mdot
.20784 .13725 Mdot
.10588 .08627 Mdot
.07451 .09412 Mdot
.41961 .36863 Mdot
.41961 .38039 Mdot
.4549 .43137 Mdot
.42745 .43137 Mdot
.38431 .34902 Mdot
.18431 .14902 Mdot
.1451 .14118 Mdot
.1451 .12549 Mdot
.14118 .12941 Mdot
.95294 .95686 Mdot
.89412 .89412 Mdot
.76078 .76078 Mdot
.87843 .86667 Mdot
.91765 .89412 Mdot
.43529 .34118 Mdot
.43137 .32941 Mdot
.43922 .36863 Mdot
.4549 .37255 Mdot
.33333 .26667 Mdot
.06667 .04706 Mdot
.44314 .41961 Mdot
.41569 .35294 Mdot
.41961 .37255 Mdot
.42745 .38824 Mdot
.40392 .38824 Mdot
.4 .34902 Mdot
.2 .19216 Mdot
.14902 .13725 Mdot
.13725 .11765 Mdot
.13333 .13333 Mdot
.88627 .87843 Mdot
.8902 .89412 Mdot
.54118 .52941 Mdot
.92941 .91373 Mdot
.69804 .65882 Mdot
.43922 .33333 Mdot
.58039 .52549 Mdot
.47059 .40784 Mdot
.43137 .33725 Mdot
.25098 .19216 Mdot
.0549 .03922 Mdot
.44314 .36471 Mdot
.41176 .35294 Mdot
.41176 .36078 Mdot
.41569 .38431 Mdot
.38431 .3451 Mdot
.18431 .15294 Mdot
.15294 .14118 Mdot
.14118 .13333 Mdot
.12941 .11765 Mdot
.8902 .89412 Mdot
.8902 .8902 Mdot
.58039 .57255 Mdot
.87843 .87059 Mdot
.86275 .83529 Mdot
.60784 .54118 Mdot
.96471 .92941 Mdot
.8549 .80392 Mdot
.47451 .38824 Mdot
.40784 .34118 Mdot
.30196 .26275 Mdot
.44314 .36471 Mdot
.43922 .37647 Mdot
.41961 .36078 Mdot
.41176 .37255 Mdot
.4 .34902 Mdot
.16471 .13333 Mdot
.16078 .14902 Mdot
.13725 .14118 Mdot
.13333 .12941 Mdot
.9451 .95686 Mdot
.89412 .89412 Mdot
.46275 .45098 Mdot
.87843 .87059 Mdot
.98431 .96078 Mdot
.96471 .93333 Mdot
.63137 .57647 Mdot
.45098 .39216 Mdot
.41176 .3451 Mdot
.41176 .34902 Mdot
.45098 .37647 Mdot
.44314 .38431 Mdot
.4 .35294 Mdot
.46275 .41176 Mdot
.13333 .10196 Mdot
.1451 .13725 Mdot
.1451 .1451 Mdot
.22353 .25098 Mdot
.8902 .88235 Mdot
.89412 .88627 Mdot
.88627 .87843 Mdot
.41569 .37647 Mdot
.78824 .73725 Mdot
.49804 .43529 Mdot
.41569 .34902 Mdot
.40784 .33333 Mdot
.41961 .35686 Mdot
.41569 .36078 Mdot
.43137 .37255 Mdot
.11373 .02745 Mdot
.04314 .04706 Mdot
.04706 .0549 Mdot
.23922 .27059 Mdot
.89804 .90196 Mdot
.88627 .87843 Mdot
.87451 .86667 Mdot
.39216 .3451 Mdot
.95294 .93725 Mdot
.70196 .65882 Mdot
.45882 .4 Mdot
.41961 .35294 Mdot
.38824 .33333 Mdot
.38431 .31373 Mdot
.30196 .16078 Mdot
.48235 .43529 Mdot
.41961 .43137 Mdot
.44706 .48627 Mdot
.58039 .59608 Mdot
.8902 .87451 Mdot
.8902 .86667 Mdot
.91765 .88627 Mdot
.96471 .94902 Mdot
.77647 .73725 Mdot
.60392 .54902 Mdot
.46667 .41569 Mdot
.39216 .33333 Mdot
.6549 .45882 Mdot
.90196 .89804 Mdot
.89804 .90196 Mdot
.25098 .27059 Mdot
.33725 .34902 Mdot
.89412 .87451 Mdot
.89804 .87059 Mdot
.27059 .21176 Mdot
.94902 .93725 Mdot
.83529 .81569 Mdot
.67059 .62745 Mdot
.78431 .61569 Mdot
.86667 .88627 Mdot
.59608 .6 Mdot
.32157 .28627 Mdot
.32941 .31373 Mdot
.80784 .76471 Mdot
.80392 .77647 Mdot
.82353 .80392 Mdot
.60392 .4902 Mdot
.26275 .25098 Mdot
.61569 .62353 Mdot
.58039 .54902 Mdot
.73333 .7098 Mdot
.87843 .8549 Mdot
.9098 .88235 Mdot
.96863 .94118 Mdot
.44314 .40392 Mdot
.28627 .27059 Mdot
.93725 .9098 Mdot
.66667 .64314 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.567362 0.477324 1.05965 MathSubStart
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 .5 0 r
.01 w
.84334 .49598 Mdot
.71169 .37959 Mdot
.82923 .47225 Mdot
.85068 .50668 Mdot
.8322 .49341 Mdot
.86945 .50754 Mdot
.84231 .50093 Mdot
.75307 .42162 Mdot
.83227 .47188 Mdot
.84085 .50927 Mdot
.84856 .50845 Mdot
.85195 .51097 Mdot
.79117 .45953 Mdot
.85029 .51743 Mdot
.82268 .49257 Mdot
.8137 .46662 Mdot
.76401 .43304 Mdot
.81681 .5115 Mdot
.83677 .52283 Mdot
.85792 .53021 Mdot
.82318 .53544 Mdot
.78766 .45061 Mdot
.78687 .45838 Mdot
.8818 .54799 Mdot
.73151 .41753 Mdot
.78833 .46543 Mdot
.77317 .47093 Mdot
.83213 .51623 Mdot
.73229 .44878 Mdot
.8257 .51502 Mdot
.8034 .48988 Mdot
.75035 .46466 Mdot
.53724 .34147 Mdot
.82043 .50257 Mdot
.79484 .48403 Mdot
.85364 .51109 Mdot
.82811 .5536 Mdot
.84396 .51652 Mdot
.77054 .47067 Mdot
.82262 .54648 Mdot
.85632 .5215 Mdot
.8195 .49397 Mdot
.49024 .30453 Mdot
.84264 .53422 Mdot
.78108 .48211 Mdot
.80026 .49947 Mdot
.75021 .47476 Mdot
.82253 .50825 Mdot
.85473 .51352 Mdot
.81491 .50374 Mdot
.77946 .49055 Mdot
.5751 .37048 Mdot
.85113 .532 Mdot
.45033 .37804 Mdot
.81897 .57356 Mdot
.84335 .51825 Mdot
.87193 .56394 Mdot
.75594 .45652 Mdot
.85823 .53909 Mdot
.65251 .42476 Mdot
.83952 .53482 Mdot
.83935 .52556 Mdot
.81362 .56839 Mdot
.8552 .54046 Mdot
.82993 .54955 Mdot
.87282 .53416 Mdot
.46051 .34632 Mdot
.85971 .52245 Mdot
.79842 .49976 Mdot
.54136 .34898 Mdot
.85753 .57021 Mdot
.79647 .51172 Mdot
.82126 .58154 Mdot
.57002 .39668 Mdot
.85644 .55962 Mdot
.78144 .52857 Mdot
.57023 .29361 Mdot
.64815 .41361 Mdot
.53109 .3395 Mdot
.79894 .50561 Mdot
.74243 .51469 Mdot
.83636 .53542 Mdot
.70543 .49073 Mdot
.72952 .46896 Mdot
.79009 .49039 Mdot
.87433 .56194 Mdot
.39449 .38464 Mdot
.83125 .51744 Mdot
.86998 .55069 Mdot
.65485 .34005 Mdot
.57549 .3949 Mdot
.46121 .43783 Mdot
.60378 .413 Mdot
.62019 .39394 Mdot
.84703 .56115 Mdot
.39765 .27605 Mdot
.51565 .42397 Mdot
.63333 .43636 Mdot
.43541 .32461 Mdot
.60912 .39797 Mdot
.86142 .53746 Mdot
.74422 .48549 Mdot
.36694 .27725 Mdot
.86398 .64655 Mdot
.8487 .54638 Mdot
.67985 .45585 Mdot
.26768 .26541 Mdot
.84081 .53244 Mdot
.49373 .34875 Mdot
.49768 .37949 Mdot
.72615 .5226 Mdot
.87395 .5566 Mdot
.86137 .5441 Mdot
.701 .38217 Mdot
.81973 .59324 Mdot
.87596 .5371 Mdot
.50833 .46843 Mdot
.77055 .43107 Mdot
.22988 .26152 Mdot
.60529 .42612 Mdot
.23756 .26055 Mdot
.87152 .57144 Mdot
.83258 .59306 Mdot
.58306 .43987 Mdot
.81112 .52688 Mdot
.78576 .55496 Mdot
.70336 .48591 Mdot
.28661 .25781 Mdot
.4974 .37955 Mdot
.25505 .25775 Mdot
.59528 .48869 Mdot
.37856 .29502 Mdot
.57028 .41983 Mdot
.62592 .44163 Mdot
.7624 .44769 Mdot
.50661 .39143 Mdot
.628 .126 .941 r
.7914 .54744 Mdot
1 .5 0 r
.85414 .63716 Mdot
.84889 .54025 Mdot
.60532 .4244 Mdot
.24385 .28053 Mdot
.54049 .4553 Mdot
.19462 .25435 Mdot
.77654 .63875 Mdot
.7662 .45418 Mdot
.90807 .61055 Mdot
.2048 .26015 Mdot
.83176 .63228 Mdot
.40794 .3755 Mdot
.628 .126 .941 r
.13799 .2593 Mdot
1 .5 0 r
.33172 .29059 Mdot
.41406 .40564 Mdot
.86161 .64661 Mdot
.628 .126 .941 r
.53885 .37415 Mdot
1 .5 0 r
.85479 .64337 Mdot
.86814 .51485 Mdot
.60446 .43628 Mdot
.9069 .58296 Mdot
.86247 .62368 Mdot
.4697 .36659 Mdot
.57534 .39153 Mdot
.39415 .31941 Mdot
.88313 .57263 Mdot
.69678 .41274 Mdot
.85621 .64142 Mdot
.50821 .37181 Mdot
.54221 .43396 Mdot
.28504 .30509 Mdot
.78408 .53401 Mdot
.55834 .44916 Mdot
.57614 .43324 Mdot
.628 .126 .941 r
.162 .27289 Mdot
.54351 .38583 Mdot
1 .5 0 r
.74645 .4542 Mdot
.87484 .64861 Mdot
.20728 .28133 Mdot
.60567 .5544 Mdot
.84406 .57951 Mdot
.87444 .56673 Mdot
.47114 .39655 Mdot
.63236 .46854 Mdot
.77529 .59103 Mdot
.28809 .31138 Mdot
.64463 .3992 Mdot
.83614 .62845 Mdot
.86764 .55603 Mdot
.25346 .28554 Mdot
.48968 .42047 Mdot
.88778 .59291 Mdot
.79408 .49851 Mdot
.44766 .36291 Mdot
.89133 .59557 Mdot
.45202 .41297 Mdot
.28363 .27455 Mdot
.86333 .67071 Mdot
.77427 .58228 Mdot
.628 .126 .941 r
.19199 .29592 Mdot
1 .5 0 r
.51121 .36494 Mdot
.18403 .29874 Mdot
.628 .126 .941 r
.58253 .47137 Mdot
.15555 .30125 Mdot
.17356 .29476 Mdot
1 .5 0 r
.23615 .30099 Mdot
.76106 .5968 Mdot
.63762 .3827 Mdot
.628 .126 .941 r
.64227 .50547 Mdot
1 .5 0 r
.75437 .60305 Mdot
.86099 .59349 Mdot
.23431 .26906 Mdot
.88559 .57129 Mdot
.71049 .44845 Mdot
.23786 .28113 Mdot
.91218 .64616 Mdot
.88129 .57682 Mdot
.18483 .30587 Mdot
.36131 .26165 Mdot
.58455 .51674 Mdot
.628 .126 .941 r
.17101 .29932 Mdot
1 .5 0 r
.88449 .56045 Mdot
.628 .126 .941 r
.16743 .29861 Mdot
1 .5 0 r
.79973 .58522 Mdot
.86214 .63565 Mdot
.77986 .49657 Mdot
.19361 .31019 Mdot
.48144 .42352 Mdot
.87686 .56536 Mdot
.17958 .2941 Mdot
.38702 .30974 Mdot
.47314 .40733 Mdot
.628 .126 .941 r
.17746 .30633 Mdot
.15209 .29049 Mdot
1 .5 0 r
.76081 .56492 Mdot
.46512 .46392 Mdot
.628 .126 .941 r
.18292 .29667 Mdot
1 .5 0 r
.89137 .6025 Mdot
.628 .126 .941 r
.16822 .30575 Mdot
.18627 .29925 Mdot
.34946 .37498 Mdot
.12879 .27381 Mdot
.24237 .25796 Mdot
1 .5 0 r
.29207 .29577 Mdot
.628 .126 .941 r
.17156 .30833 Mdot
.15877 .29564 Mdot
1 .5 0 r
.24691 .31773 Mdot
.40351 .34595 Mdot
.15731 .28269 Mdot
.20722 .33004 Mdot
.628 .126 .941 r
.19443 .31735 Mdot
.20702 .32051 Mdot
.18164 .30466 Mdot
1 .5 0 r
.46432 .42778 Mdot
.628 .126 .941 r
.1875 .31406 Mdot
1 .5 0 r
.1875 .31406 Mdot
.21058 .33263 Mdot
.628 .126 .941 r
.21038 .32309 Mdot
1 .5 0 r
.18499 .30724 Mdot
.76277 .53765 Mdot
.628 .126 .941 r
.18834 .30982 Mdot
.19421 .31923 Mdot
.16754 .29995 Mdot
1 .5 0 r
.24344 .27461 Mdot
.2169 .31872 Mdot
.628 .126 .941 r
.18476 .30911 Mdot
1 .5 0 r
.18476 .30911 Mdot
.33422 .31498 Mdot
.87452 .52658 Mdot
.628 .126 .941 r
.19253 .30814 Mdot
.19253 .30814 Mdot
1 .5 0 r
.21122 .33028 Mdot
.628 .126 .941 r
.19841 .31757 Mdot
.19147 .31428 Mdot
.19695 .3046 Mdot
.51197 .36455 Mdot
.20177 .32015 Mdot
1 .5 0 r
.20177 .32015 Mdot
.37355 .23153 Mdot
.628 .126 .941 r
.18221 .3137 Mdot
.19483 .31686 Mdot
1 .5 0 r
.43504 .34216 Mdot
.628 .126 .941 r
.13154 .29149 Mdot
.34699 .27568 Mdot
1 .5 0 r
.6232 .44964 Mdot
.75406 .60462 Mdot
.50524 .25347 Mdot
.628 .126 .941 r
.20031 .30718 Mdot
.20513 .32274 Mdot
.19839 .329 Mdot
.19819 .31945 Mdot
.19819 .31945 Mdot
.43894 .30996 Mdot
.15298 .28755 Mdot
.18431 .31286 Mdot
.14016 .27483 Mdot
1 .5 0 r
.20261 .3159 Mdot
.628 .126 .941 r
.20849 .32533 Mdot
1 .5 0 r
.18979 .30318 Mdot
.628 .126 .941 r
.23374 .33166 Mdot
.40329 .41704 Mdot
1 .5 0 r
.67946 .58154 Mdot
.20162 .2681 Mdot
.48455 .42635 Mdot
.4419 .22993 Mdot
.26331 .27094 Mdot
.628 .126 .941 r
.21186 .32792 Mdot
1 .5 0 r
.21186 .32792 Mdot
.59025 .4577 Mdot
.35768 .24858 Mdot
.49436 .40358 Mdot
.16623 .27688 Mdot
.628 .126 .941 r
.57605 .43202 Mdot
.20934 .32108 Mdot
1 .5 0 r
.20934 .32108 Mdot
.20934 .32108 Mdot
.20895 .30195 Mdot
.628 .126 .941 r
.20828 .32722 Mdot
.24532 .35242 Mdot
.16959 .27946 Mdot
1 .5 0 r
.34086 .26996 Mdot
.56595 .50115 Mdot
.628 .126 .941 r
.21271 .32367 Mdot
.19988 .31093 Mdot
1 .5 0 r
.2186 .33311 Mdot
.88739 .57065 Mdot
.21232 .30453 Mdot
.21232 .30453 Mdot
.628 .126 .941 r
.262 .33291 Mdot
1 .5 0 r
.21125 .31068 Mdot
.5258 .4944 Mdot
.56961 .51335 Mdot
.22899 .28501 Mdot
.628 .126 .941 r
.20324 .31352 Mdot
1 .5 0 r
.61943 .48778 Mdot
.628 .126 .941 r
.19696 .28494 Mdot
.19629 .31023 Mdot
.21502 .33241 Mdot
.20238 .32924 Mdot
.26472 .3608 Mdot
1 .5 0 r
.75617 .57938 Mdot
.55511 .41454 Mdot
.628 .126 .941 r
.21945 .32885 Mdot
1 .5 0 r
.76921 .48414 Mdot
.628 .126 .941 r
.20661 .31611 Mdot
.20661 .31611 Mdot
.20661 .31611 Mdot
.76294 .45556 Mdot
1 .5 0 r
.21906 .30971 Mdot
.57263 .43331 Mdot
.628 .126 .941 r
.21839 .335 Mdot
1 .5 0 r
.40225 .31909 Mdot
.39597 .2905 Mdot
.19251 .29994 Mdot
.628 .126 .941 r
.22389 .3253 Mdot
.19184 .32524 Mdot
1 .5 0 r
.54547 .44886 Mdot
.78604 .46465 Mdot
.628 .126 .941 r
.22283 .33145 Mdot
.22283 .33145 Mdot
1 .5 0 r
.29309 .29658 Mdot
.49498 .38217 Mdot
.628 .126 .941 r
.19038 .31224 Mdot
1 .5 0 r
.4813 .38515 Mdot
.628 .126 .941 r
.72677 .53416 Mdot
1 .5 0 r
.31058 .31534 Mdot
.22137 .31845 Mdot
.88412 .56253 Mdot
.628 .126 .941 r
.19521 .32783 Mdot
1 .5 0 r
.20786 .331 Mdot
.628 .126 .941 r
.20766 .32143 Mdot
1 .5 0 r
.20766 .32143 Mdot
.628 .126 .941 r
.21336 .3213 Mdot
1 .5 0 r
.22475 .32104 Mdot
.628 .126 .941 r
.19971 .27023 Mdot
1 .5 0 r
.46544 .33684 Mdot
.70445 .50176 Mdot
.86848 .57788 Mdot
.628 .126 .941 r
.19858 .33043 Mdot
1 .5 0 r
.59694 .44778 Mdot
.628 .126 .941 r
.21103 .32402 Mdot
.21103 .32402 Mdot
.21103 .32402 Mdot
.22958 .33665 Mdot
.21673 .32389 Mdot
1 .5 0 r
.62732 .47932 Mdot
.89215 .61572 Mdot
.628 .126 .941 r
.22852 .3428 Mdot
.55646 .48549 Mdot
.21461 .3362 Mdot
.21461 .3362 Mdot
.18929 .32985 Mdot
.26438 .36463 Mdot
.29044 .29159 Mdot
1 .5 0 r
.49204 .41216 Mdot
.628 .126 .941 r
.21315 .32319 Mdot
.21315 .32319 Mdot
1 .5 0 r
.21315 .32319 Mdot
.628 .126 .941 r
.28168 .37384 Mdot
.26293 .35162 Mdot
.23111 .30706 Mdot
.21798 .3388 Mdot
.19903 .307 Mdot
1 .5 0 r
.21778 .32922 Mdot
.628 .126 .941 r
.23635 .34185 Mdot
1 .5 0 r
.26777 .36724 Mdot
.53978 .45293 Mdot
.51445 .44658 Mdot
.26194 .3037 Mdot
.628 .126 .941 r
.22309 .30992 Mdot
1 .5 0 r
.21652 .32579 Mdot
.23489 .32883 Mdot
.37354 .38908 Mdot
.628 .126 .941 r
.22136 .3414 Mdot
.22687 .33169 Mdot
1 .5 0 r
.24563 .35391 Mdot
.628 .126 .941 r
.2199 .32839 Mdot
.226 .34744 Mdot
1 .5 0 r
.24484 .31556 Mdot
.628 .126 .941 r
.23828 .33143 Mdot
.26971 .35684 Mdot
.21274 .31549 Mdot
1 .5 0 r
.65005 .40758 Mdot
.628 .126 .941 r
.19987 .30272 Mdot
1 .5 0 r
.91451 .56947 Mdot
.20577 .31219 Mdot
.20577 .31219 Mdot
.628 .126 .941 r
.19291 .29942 Mdot
.23025 .33429 Mdot
1 .5 0 r
.24902 .35652 Mdot
.628 .126 .941 r
.21061 .32781 Mdot
1 .5 0 r
.1661 .28004 Mdot
.27311 .35944 Mdot
.628 .126 .941 r
.22879 .32126 Mdot
1 .5 0 r
.22879 .32126 Mdot
.628 .126 .941 r
.24757 .3435 Mdot
1 .5 0 r
.22813 .34661 Mdot
.628 .126 .941 r
.20915 .31478 Mdot
.22793 .33702 Mdot
.22793 .33702 Mdot
1 .5 0 r
.45652 .35926 Mdot
.628 .126 .941 r
.18864 .32406 Mdot
.22667 .33359 Mdot
1 .5 0 r
.22667 .33359 Mdot
.27651 .36205 Mdot
.53472 .54951 Mdot
.67462 .54951 Mdot
.628 .126 .941 r
.23131 .33962 Mdot
1 .5 0 r
.23131 .33962 Mdot
.39695 .24727 Mdot
.628 .126 .941 r
.57144 .49191 Mdot
.82437 .58084 Mdot
1 .5 0 r
.24844 .33924 Mdot
.628 .126 .941 r
.32977 .39315 Mdot
.19055 .31362 Mdot
.21591 .31998 Mdot
1 .5 0 r
.18425 .28495 Mdot
.57549 .52335 Mdot
.24041 .3421 Mdot
.24041 .3421 Mdot
.628 .126 .941 r
.22076 .33562 Mdot
.24002 .3229 Mdot
.25223 .36105 Mdot
1 .5 0 r
.30981 .3133 Mdot
.628 .126 .941 r
.22627 .32589 Mdot
1 .5 0 r
.22627 .32589 Mdot
.23895 .32907 Mdot
.628 .126 .941 r
.21272 .33848 Mdot
.21272 .33848 Mdot
.21272 .33848 Mdot
1 .5 0 r
.2438 .34471 Mdot
.628 .126 .941 r
.28797 .37333 Mdot
1 .5 0 r
.36455 .35743 Mdot
.628 .126 .941 r
.23683 .3414 Mdot
.22414 .33822 Mdot
.23683 .3414 Mdot
.22414 .33822 Mdot
1 .5 0 r
.87068 .53538 Mdot
.44479 .47172 Mdot
.628 .126 .941 r
.25523 .34446 Mdot
1 .5 0 r
.25523 .34446 Mdot
.628 .126 .941 r
.22966 .32849 Mdot
1 .5 0 r
.22966 .32849 Mdot
.51067 .25853 Mdot
.36292 .33479 Mdot
.7727 .63056 Mdot
.24148 .34745 Mdot
.24148 .34745 Mdot
.628 .126 .941 r
.36273 .32518 Mdot
.31103 .38243 Mdot
1 .5 0 r
.83597 .63686 Mdot
.628 .126 .941 r
.29157 .38555 Mdot
1 .5 0 r
.27257 .35368 Mdot
.628 .126 .941 r
.21504 .34726 Mdot
.21464 .32804 Mdot
1 .5 0 r
.58202 .44568 Mdot
.628 .126 .941 r
.23305 .3311 Mdot
.23305 .3311 Mdot
1 .5 0 r
.23305 .3311 Mdot
.628 .126 .941 r
.24574 .33428 Mdot
1 .5 0 r
.60063 .45834 Mdot
.628 .126 .941 r
.22016 .31831 Mdot
.23285 .32149 Mdot
.21969 .3533 Mdot
1 .5 0 r
.21357 .33421 Mdot
.628 .126 .941 r
.22607 .32779 Mdot
1 .5 0 r
.22607 .32779 Mdot
.628 .126 .941 r
.20049 .31181 Mdot
.3387 .4518 Mdot
1 .5 0 r
.56811 .43907 Mdot
.628 .126 .941 r
.23092 .34344 Mdot
.19949 .26376 Mdot
1 .5 0 r
.26202 .34968 Mdot
.628 .126 .941 r
.23624 .32409 Mdot
.20407 .32403 Mdot
.24874 .31766 Mdot
.22946 .33039 Mdot
.22288 .3463 Mdot
1 .5 0 r
.26649 .34611 Mdot
.628 .126 .941 r
.19622 .3365 Mdot
.50802 .36196 Mdot
1 .5 0 r
.45629 .41925 Mdot
.28471 .33956 Mdot
.28424 .37457 Mdot
.83593 .56555 Mdot
.628 .126 .941 r
.25253 .33949 Mdot
.27134 .36177 Mdot
1 .5 0 r
.26503 .33306 Mdot
.35468 .2757 Mdot
.23285 .333 Mdot
.23285 .333 Mdot
.628 .126 .941 r
.25166 .35528 Mdot
1 .5 0 r
.21995 .3202 Mdot
.27028 .36795 Mdot
.27028 .36795 Mdot
.628 .126 .941 r
.2762 .37744 Mdot
.2248 .33586 Mdot
.2248 .33586 Mdot
1 .5 0 r
.20599 .31358 Mdot
.26883 .3549 Mdot
.27475 .36439 Mdot
.628 .126 .941 r
.22374 .34204 Mdot
.23032 .32612 Mdot
1 .5 0 r
.50839 .50125 Mdot
.628 .126 .941 r
.23624 .33561 Mdot
1 .5 0 r
.21064 .31962 Mdot
.45202 .38012 Mdot
.45719 .46929 Mdot
.26079 .35777 Mdot
.31772 .38961 Mdot
.628 .126 .941 r
.2411 .35127 Mdot
1 .5 0 r
.86979 .52643 Mdot
.628 .126 .941 r
.30941 .43714 Mdot
1 .5 0 r
.59601 .45625 Mdot
.24662 .34153 Mdot
.628 .126 .941 r
.20172 .33828 Mdot
1 .5 0 r
.23372 .32873 Mdot
.628 .126 .941 r
.29067 .36058 Mdot
1 .5 0 r
.21422 .33185 Mdot
.628 .126 .941 r
.23305 .35414 Mdot
.23964 .33822 Mdot
.25894 .32548 Mdot
1 .5 0 r
.23964 .33822 Mdot
.88491 .71089 Mdot
.628 .126 .941 r
.18814 .35089 Mdot
1 .5 0 r
.2771 .37319 Mdot
.2638 .34115 Mdot
.628 .126 .941 r
.26207 .37275 Mdot
.26207 .37275 Mdot
.24304 .34083 Mdot
1 .5 0 r
.24304 .34083 Mdot
.628 .126 .941 r
.2805 .37581 Mdot
.22247 .35013 Mdot
1 .5 0 r
.26061 .35969 Mdot
.21615 .32139 Mdot
.87632 .5572 Mdot
.20324 .30858 Mdot
.25342 .34676 Mdot
.628 .126 .941 r
.28498 .37225 Mdot
1 .5 0 r
.43755 .41049 Mdot
.22101 .33707 Mdot
.36135 .33707 Mdot
.271 .36563 Mdot
.628 .126 .941 r
.29643 .372 Mdot
1 .5 0 r
.4495 .37519 Mdot
.628 .126 .941 r
.20702 .33044 Mdot
.20682 .32081 Mdot
1 .5 0 r
.45439 .39088 Mdot
.628 .126 .941 r
.25683 .34937 Mdot
1 .5 0 r
.25683 .34937 Mdot
.628 .126 .941 r
.31383 .38125 Mdot
.25663 .33974 Mdot
.2242 .33005 Mdot
1 .5 0 r
.31889 .40657 Mdot
.628 .126 .941 r
.21041 .33305 Mdot
.21654 .35218 Mdot
1 .5 0 r
.26742 .36493 Mdot
.4719 .3458 Mdot
.28587 .368 Mdot
.26023 .35199 Mdot
.628 .126 .941 r
.2918 .3775 Mdot
1 .5 0 r
.444 .45084 Mdot
.628 .126 .941 r
.21527 .34874 Mdot
.24731 .33917 Mdot
1 .5 0 r
.2278 .34229 Mdot
.628 .126 .941 r
.25324 .34867 Mdot
1 .5 0 r
.25324 .34867 Mdot
.87573 .57509 Mdot
.628 .126 .941 r
.19555 .34223 Mdot
.33485 .40276 Mdot
1 .5 0 r
.47481 .43784 Mdot
.5389 .41871 Mdot
.628 .126 .941 r
.24605 .33572 Mdot
.21993 .3548 Mdot
1 .5 0 r
.22633 .32922 Mdot
.628 .126 .941 r
.28929 .37062 Mdot
.32067 .38651 Mdot
1 .5 0 r
.70292 .44711 Mdot
.628 .126 .941 r
.23119 .34491 Mdot
.24946 .33834 Mdot
1 .5 0 r
.79441 .65099 Mdot
.402 .36699 Mdot
.49892 .25845 Mdot
.628 .126 .941 r
.44707 .31588 Mdot
1 .5 0 r
.45178 .44031 Mdot
.628 .126 .941 r
.29271 .37324 Mdot
1 .5 0 r
.29271 .37324 Mdot
.628 .126 .941 r
.17114 .34121 Mdot
1 .5 0 r
.54551 .52309 Mdot
.628 .126 .941 r
.22234 .30924 Mdot
.2478 .31562 Mdot
.23459 .34753 Mdot
1 .5 0 r
.29758 .38895 Mdot
.28465 .37612 Mdot
.628 .126 .941 r
.23946 .36323 Mdot
1 .5 0 r
.27766 .3728 Mdot
.628 .126 .941 r
.29652 .39514 Mdot
.32839 .37593 Mdot
.29613 .37587 Mdot
.29613 .37587 Mdot
.2832 .36304 Mdot
.22074 .23211 Mdot
.25753 .34702 Mdot
.23167 .32136 Mdot
1 .5 0 r
.85474 .54799 Mdot
.628 .126 .941 r
.26967 .32129 Mdot
.28807 .37875 Mdot
1 .5 0 r
.689 .49686 Mdot
.628 .126 .941 r
.25061 .2893 Mdot
.2372 .31159 Mdot
.22427 .29875 Mdot
1 .5 0 r
.70648 .50614 Mdot
.628 .126 .941 r
.22367 .26982 Mdot
.25481 .33048 Mdot
.26094 .34964 Mdot
1 .5 0 r
.26094 .34964 Mdot
.628 .126 .941 r
.23507 .32397 Mdot
1 .5 0 r
.43983 .30481 Mdot
.50258 .39102 Mdot
.62856 .52832 Mdot
.29149 .38138 Mdot
.41322 .35903 Mdot
.628 .126 .941 r
.3951 .25678 Mdot
1 .5 0 r
.2911 .36209 Mdot
.24021 .2949 Mdot
.628 .126 .941 r
.18197 .32358 Mdot
.29051 .33316 Mdot
.27729 .3651 Mdot
1 .5 0 r
.84877 .64933 Mdot
.51966 .381 Mdot
.24461 .34575 Mdot
.30785 .39685 Mdot
.628 .126 .941 r
.65332 .37768 Mdot
1 .5 0 r
.88033 .61084 Mdot
.628 .126 .941 r
.29491 .38401 Mdot
1 .5 0 r
.30746 .37756 Mdot
.628 .126 .941 r
.5628 .40631 Mdot
.21718 .3614 Mdot
1 .5 0 r
.49993 .25598 Mdot
.628 .126 .941 r
.21699 .35175 Mdot
.31128 .39948 Mdot
.31041 .41534 Mdot
.20851 .33533 Mdot
.22814 .27775 Mdot
.30983 .38639 Mdot
1 .5 0 r
.89532 .60368 Mdot
.628 .126 .941 r
.22039 .35438 Mdot
.25985 .24885 Mdot
.25277 .29999 Mdot
1 .5 0 r
.23341 .31277 Mdot
.628 .126 .941 r
.17533 .35112 Mdot
.28393 .3607 Mdot
1 .5 0 r
.28393 .3607 Mdot
.628 .126 .941 r
.32832 .38946 Mdot
1 .5 0 r
.23935 .32229 Mdot
.23935 .32229 Mdot
.628 .126 .941 r
.34701 .40218 Mdot
.24576 .29666 Mdot
.20657 .35738 Mdot
1 .5 0 r
.61316 .56511 Mdot
.49963 .42124 Mdot
.25016 .34754 Mdot
.628 .126 .941 r
.19848 .36026 Mdot
1 .5 0 r
.33215 .4114 Mdot
.59948 .51369 Mdot
.628 .126 .941 r
.30031 .37618 Mdot
.28736 .36333 Mdot
.27393 .38564 Mdot
.34932 .4655 Mdot
1 .5 0 r
.62424 .48149 Mdot
.47147 .39831 Mdot
.628 .126 .941 r
.3048 .37261 Mdot
1 .5 0 r
.30432 .40777 Mdot
.628 .126 .941 r
.24838 .26064 Mdot
.24015 .37248 Mdot
1 .5 0 r
.29098 .37561 Mdot
.628 .126 .941 r
.21337 .36263 Mdot
.22612 .36583 Mdot
1 .5 0 r
.25806 .34658 Mdot
.46928 .34658 Mdot
.628 .126 .941 r
.24518 .27923 Mdot
.25746 .31761 Mdot
1 .5 0 r
.32012 .3943 Mdot
.55576 .46141 Mdot
.628 .126 .941 r
.28145 .36539 Mdot
1 .5 0 r
.24958 .33014 Mdot
.628 .126 .941 r
.43239 .4707 Mdot
1 .5 0 r
.24879 .2915 Mdot
.27932 .37781 Mdot
.628 .126 .941 r
.68019 .56656 Mdot
.34247 .41934 Mdot
1 .5 0 r
.89747 .5761 Mdot
.628 .126 .941 r
.3106 .38408 Mdot
1 .5 0 r
.35598 .34249 Mdot
.628 .126 .941 r
.20166 .36482 Mdot
1 .5 0 r
.29764 .37122 Mdot
.628 .126 .941 r
.28373 .42875 Mdot
.27786 .3647 Mdot
1 .5 0 r
.31548 .39983 Mdot
.53989 .35817 Mdot
.50073 .36444 Mdot
.59465 .50199 Mdot
.628 .126 .941 r
.31403 .38672 Mdot
1 .5 0 r
.33295 .40912 Mdot
.60155 .44113 Mdot
.2883 .37065 Mdot
.628 .126 .941 r
.30107 .37385 Mdot
.22405 .33532 Mdot
1 .5 0 r
.34541 .33846 Mdot
.40906 .34479 Mdot
.47954 .34479 Mdot
.628 .126 .941 r
.28684 .35753 Mdot
.29961 .36074 Mdot
.27359 .38954 Mdot
.31191 .39915 Mdot
.2538 .38302 Mdot
1 .5 0 r
.2361 .2453 Mdot
.628 .126 .941 r
.28558 .35408 Mdot
.29173 .37329 Mdot
.29173 .37329 Mdot
.25956 .38289 Mdot
.21469 .33474 Mdot
1 .5 0 r
.68684 .48842 Mdot
.895 .73495 Mdot
.86927 .71889 Mdot
.628 .126 .941 r
.29046 .36983 Mdot
1 .5 0 r
.27067 .3633 Mdot
.78736 .54582 Mdot
.23857 .31834 Mdot
.628 .126 .941 r
.24425 .37278 Mdot
.26298 .38553 Mdot
1 .5 0 r
.37351 .24456 Mdot
.628 .126 .941 r
.27536 .36939 Mdot
1 .5 0 r
.3525 .35338 Mdot
.43417 .4526 Mdot
.58666 .50693 Mdot
.53611 .40431 Mdot
.628 .126 .941 r
.31157 .39144 Mdot
.32435 .39464 Mdot
.26072 .33371 Mdot
.31137 .38176 Mdot
1 .5 0 r
.58638 .43302 Mdot
.30455 .38811 Mdot
.62322 .48409 Mdot
.74393 .56739 Mdot
.34191 .34935 Mdot
.25176 .35249 Mdot
.25176 .35249 Mdot
.31481 .3844 Mdot
.628 .126 .941 r
.3594 .35864 Mdot
.25076 .3041 Mdot
.35163 .43549 Mdot
1 .5 0 r
.51168 .45792 Mdot
.53062 .48036 Mdot
.42767 .4803 Mdot
.628 .126 .941 r
.26315 .28794 Mdot
.25017 .27506 Mdot
.2999 .39364 Mdot
.31845 .39672 Mdot
.2993 .36461 Mdot
1 .5 0 r
.57969 .50564 Mdot
.628 .126 .941 r
.22833 .34525 Mdot
.27996 .32281 Mdot
1 .5 0 r
.49671 .40289 Mdot
.51566 .42532 Mdot
.64773 .55338 Mdot
.25272 .29356 Mdot
.628 .126 .941 r
.32189 .39937 Mdot
1 .5 0 r
.22519 .30927 Mdot
.61403 .48558 Mdot
.63801 .58814 Mdot
.26203 .36039 Mdot
.32533 .40202 Mdot
.33813 .40522 Mdot
.628 .126 .941 r
.30571 .40516 Mdot
.8221 .64886 Mdot
.24749 .389 Mdot
1 .5 0 r
.61727 .53322 Mdot
.628 .126 .941 r
.80289 .55241 Mdot
1 .5 0 r
.73132 .62298 Mdot
.31021 .40158 Mdot
.628 .126 .941 r
.35552 .35019 Mdot
1 .5 0 r
.89829 .57475 Mdot
.628 .126 .941 r
.24108 .24105 Mdot
1 .5 0 r
.63596 .48166 Mdot
.628 .126 .941 r
.27881 .27627 Mdot
1 .5 0 r
.9169 .57785 Mdot
.628 .126 .941 r
.30875 .38844 Mdot
.37845 .45902 Mdot
1 .5 0 r
.68518 .57132 Mdot
.61436 .56164 Mdot
.628 .126 .941 r
.31452 .38831 Mdot
.23732 .34968 Mdot
.31366 .40423 Mdot
.41655 .3946 Mdot
1 .5 0 r
.70247 .62564 Mdot
.628 .126 .941 r
.35803 .42342 Mdot
.22317 .39769 Mdot
.31923 .39442 Mdot
1 .5 0 r
.35764 .40404 Mdot
.59408 .47138 Mdot
.628 .126 .941 r
.31208 .3267 Mdot
.36188 .44546 Mdot
1 .5 0 r
.73821 .55436 Mdot
.59714 .50936 Mdot
.78831 .62814 Mdot
.628 .126 .941 r
.31612 .35842 Mdot
.42978 .48356 Mdot
.22511 .38718 Mdot
.44808 .53166 Mdot
.29635 .29715 Mdot
.22641 .21682 Mdot
.2302 .41268 Mdot
1 .5 0 r
.83704 .68883 Mdot
.36618 .31308 Mdot
.628 .126 .941 r
.47483 .35803 Mdot
1 .5 0 r
.61433 .49932 Mdot
.74244 .53143 Mdot
.36456 .40935 Mdot
.84949 .67266 Mdot
.24317 .30646 Mdot
.628 .126 .941 r
.26167 .36427 Mdot
.1842 .3159 Mdot
.24711 .39292 Mdot
.40638 .47637 Mdot
1 .5 0 r
.90424 .74296 Mdot
.628 .126 .941 r
.43713 .50831 Mdot
.30972 .39582 Mdot
.4769 .3475 Mdot
1 .5 0 r
.32832 .39891 Mdot
.628 .126 .941 r
.32812 .3892 Mdot
1 .5 0 r
.83227 .67513 Mdot
.628 .126 .941 r
.28235 .42127 Mdot
.25034 .38587 Mdot
.37786 .44364 Mdot
.4672 .44673 Mdot
1 .5 0 r
.60774 .51742 Mdot
.71125 .47244 Mdot
.628 .126 .941 r
.37213 .2698 Mdot
1 .5 0 r
.49892 .40798 Mdot
.628 .126 .941 r
.65287 .39179 Mdot
1 .5 0 r
.23573 .29531 Mdot
.628 .126 .941 r
.31219 .34995 Mdot
.36185 .45916 Mdot
1 .5 0 r
.47897 .33696 Mdot
.628 .126 .941 r
.25915 .36898 Mdot
.2981 .34326 Mdot
1 .5 0 r
.8291 .56505 Mdot
.54679 .48463 Mdot
.67408 .5875 Mdot
.89304 .57142 Mdot
.628 .126 .941 r
.21553 .21455 Mdot
.45141 .35272 Mdot
.31013 .30765 Mdot
.30253 .39444 Mdot
.45169 .30765 Mdot
1 .5 0 r
.36694 .36545 Mdot
.35344 .38789 Mdot
.628 .126 .941 r
.3848 .44897 Mdot
1 .5 0 r
.49358 .49398 Mdot
.628 .126 .941 r
.21785 .39747 Mdot
.19784 .32642 Mdot
1 .5 0 r
.38229 .44206 Mdot
.628 .126 .941 r
.31937 .31014 Mdot
.21557 .34545 Mdot
1 .5 0 r
.3244 .39048 Mdot
.3244 .39048 Mdot
.40043 .48053 Mdot
.628 .126 .941 r
.28598 .32603 Mdot
1 .5 0 r
.75867 .57684 Mdot
.27303 .25828 Mdot
.49547 .47379 Mdot
.74547 .55421 Mdot
.628 .126 .941 r
.28975 .40291 Mdot
.38624 .40934 Mdot
1 .5 0 r
.60974 .49929 Mdot
.59025 .51216 Mdot
.628 .126 .941 r
.2188 .33838 Mdot
.29466 .41874 Mdot
.5528 .37692 Mdot
.4097 .48309 Mdot
.39667 .47016 Mdot
.28721 .39597 Mdot
1 .5 0 r
.53521 .48893 Mdot
.8039 .62732 Mdot
.628 .126 .941 r
.2081 .33432 Mdot
.2081 .33432 Mdot
1 .5 0 r
.46587 .32788 Mdot
.628 .126 .941 r
.74171 .41478 Mdot
.45664 .51128 Mdot
1 .5 0 r
.73772 .68831 Mdot
.628 .126 .941 r
.31091 .30522 Mdot
.3165 .29537 Mdot
.68828 .41441 Mdot
1 .5 0 r
.51447 .37894 Mdot
.628 .126 .941 r
.33922 .4497 Mdot
.21914 .25003 Mdot
.30172 .31435 Mdot
1 .5 0 r
.83199 .63304 Mdot
.628 .126 .941 r
.27353 .42042 Mdot
1 .5 0 r
.40446 .22064 Mdot
.628 .126 .941 r
.21495 .3396 Mdot
.23351 .39756 Mdot
.48553 .32665 Mdot
.27804 .41683 Mdot
.27785 .4071 Mdot
.26718 .21701 Mdot
.30846 .4294 Mdot
.42365 .49382 Mdot
1 .5 0 r
.42365 .49382 Mdot
.628 .126 .941 r
.28256 .41323 Mdot
.51437 .43578 Mdot
.25047 .37774 Mdot
.26285 .41639 Mdot
1 .5 0 r
.63556 .50981 Mdot
.4362 .42271 Mdot
.628 .126 .941 r
.28129 .40976 Mdot
.25662 .27754 Mdot
1 .5 0 r
.34517 .40642 Mdot
.37706 .43219 Mdot
.73079 .50308 Mdot
.628 .126 .941 r
.32069 .28392 Mdot
.32593 .37414 Mdot
.29363 .3289 Mdot
.30601 .36756 Mdot
1 .5 0 r
.39505 .46101 Mdot
.628 .126 .941 r
.36866 .48028 Mdot
1 .5 0 r
.7672 .58018 Mdot
.84386 .63496 Mdot
.628 .126 .941 r
.31208 .32226 Mdot
1 .5 0 r
.54265 .39625 Mdot
.70218 .52516 Mdot
.628 .126 .941 r
.32959 .38652 Mdot
1 .5 0 r
.40674 .40586 Mdot
.28423 .32831 Mdot
.628 .126 .941 r
.30232 .42179 Mdot
.36556 .44417 Mdot
1 .5 0 r
.56018 .34095 Mdot
.49645 .23443 Mdot
.4246 .25042 Mdot
.42413 .28588 Mdot
.628 .126 .941 r
.31884 .43741 Mdot
1 .5 0 r
.30054 .33418 Mdot
.628 .126 .941 r
.30578 .42445 Mdot
.27319 .42439 Mdot
1 .5 0 r
.47834 .50172 Mdot
.628 .126 .941 r
.29145 .40802 Mdot
.40057 .45317 Mdot
1 .5 0 r
.76014 .5692 Mdot
.86926 .61435 Mdot
.61824 .51426 Mdot
.628 .126 .941 r
.29113 .33359 Mdot
1 .5 0 r
.55353 .47867 Mdot
.628 .126 .941 r
.77323 .46254 Mdot
.48118 .53016 Mdot
.32207 .31069 Mdot
.33455 .29443 Mdot
1 .5 0 r
.6218 .51696 Mdot
.26265 .31043 Mdot
.628 .126 .941 r
.27532 .30391 Mdot
1 .5 0 r
.31831 .41993 Mdot
.628 .126 .941 r
.28569 .41987 Mdot
.27452 .26493 Mdot
.30599 .32623 Mdot
1 .5 0 r
.39448 .44556 Mdot
.628 .126 .941 r
.31179 .3261 Mdot
1 .5 0 r
.3565 .29041 Mdot
.42803 .25491 Mdot
.628 .126 .941 r
.56108 .44854 Mdot
1 .5 0 r
.20159 .23218 Mdot
.628 .126 .941 r
.30202 .42577 Mdot
.42411 .47418 Mdot
1 .5 0 r
.32901 .31596 Mdot
.628 .126 .941 r
.37965 .34488 Mdot
.38442 .47077 Mdot
.72699 .41255 Mdot
1 .5 0 r
.93049 .63201 Mdot
.54201 .54773 Mdot
.628 .126 .941 r
.75003 .45732 Mdot
1 .5 0 r
.66463 .56064 Mdot
.628 .126 .941 r
.76321 .41528 Mdot
1 .5 0 r
.3231 .43782 Mdot
.628 .126 .941 r
.27757 .43453 Mdot
.38159 .38932 Mdot
.43169 .5088 Mdot
.62428 .58302 Mdot
.34971 .30846 Mdot
.38645 .46024 Mdot
1 .5 0 r
.48981 .4408 Mdot
.628 .126 .941 r
.86347 .53446 Mdot
.26341 .42782 Mdot
.25033 .41484 Mdot
1 .5 0 r
.84115 .70552 Mdot
.42298 .48249 Mdot
.57075 .52765 Mdot
.41591 .47914 Mdot
.5257 .36899 Mdot
.628 .126 .941 r
.39489 .47884 Mdot
1 .5 0 r
.38896 .41416 Mdot
.33088 .30727 Mdot
.66255 .63036 Mdot
.628 .126 .941 r
.27032 .43318 Mdot
1 .5 0 r
.32858 .42995 Mdot
.85671 .59799 Mdot
.628 .126 .941 r
.37928 .45891 Mdot
1 .5 0 r
.53353 .53324 Mdot
.628 .126 .941 r
.32062 .44263 Mdot
.26454 .25833 Mdot
1 .5 0 r
.39779 .45226 Mdot
.56476 .52008 Mdot
.628 .126 .941 r
.50583 .54911 Mdot
.50583 .54911 Mdot
1 .5 0 r
.5598 .26432 Mdot
.4677 .32885 Mdot
.628 .126 .941 r
.50935 .55183 Mdot
.32378 .37069 Mdot
.63148 .59057 Mdot
.2801 .22512 Mdot
1 .5 0 r
.34986 .33183 Mdot
.628 .126 .941 r
.28994 .43201 Mdot
1 .5 0 r
.65576 .63891 Mdot
.628 .126 .941 r
.69075 .39625 Mdot
.39905 .40265 Mdot
.53286 .56113 Mdot
.25023 .37348 Mdot
.3721 .45757 Mdot
1 .5 0 r
.51451 .45757 Mdot
.41672 .41204 Mdot
.42245 .46703 Mdot
.9165 .77752 Mdot
.51709 .53144 Mdot
.628 .126 .941 r
.24611 .40837 Mdot
.43954 .44714 Mdot
.37002 .295 Mdot
.38054 .4762 Mdot
.51498 .54403 Mdot
.73493 .56345 Mdot
.34743 .4566 Mdot
.46917 .53097 Mdot
1 .5 0 r
.68962 .51479 Mdot
.56434 .55981 Mdot
.4151 .45593 Mdot
.628 .126 .941 r
.57774 .40737 Mdot
1 .5 0 r
.93554 .78289 Mdot
.628 .126 .941 r
.33769 .38135 Mdot
1 .5 0 r
.8599 .55611 Mdot
.628 .126 .941 r
.6056 .57855 Mdot
1 .5 0 r
.77401 .58503 Mdot
.628 .126 .941 r
.39229 .48777 Mdot
.45019 .52015 Mdot
.8459 .49424 Mdot
.27582 .44885 Mdot
1 .5 0 r
.43162 .40669 Mdot
.44434 .40015 Mdot
.628 .126 .941 r
.69701 .40986 Mdot
1 .5 0 r
.43649 .47781 Mdot
.628 .126 .941 r
.28925 .24112 Mdot
1 .5 0 r
.3843 .38033 Mdot
.57672 .53582 Mdot
.628 .126 .941 r
.47582 .27654 Mdot
1 .5 0 r
.46624 .50654 Mdot
.628 .126 .941 r
.31766 .44169 Mdot
.74325 .49971 Mdot
.45771 .48993 Mdot
1 .5 0 r
.71673 .51909 Mdot
.86372 .6811 Mdot
.36175 .36674 Mdot
.628 .126 .941 r
.33426 .45741 Mdot
1 .5 0 r
.43059 .47997 Mdot
.70766 .59333 Mdot
.50443 .24651 Mdot
.628 .126 .941 r
.30043 .46364 Mdot
.3144 .34036 Mdot
.29983 .43429 Mdot
1 .5 0 r
.39657 .47643 Mdot
.628 .126 .941 r
.29532 .26244 Mdot
1 .5 0 r
.78432 .56388 Mdot
.628 .126 .941 r
.39618 .45686 Mdot
.90101 .54762 Mdot
1 .5 0 r
.90658 .59294 Mdot
.628 .126 .941 r
.29185 .44701 Mdot
1 .5 0 r
.42261 .37245 Mdot
.628 .126 .941 r
.74586 .38847 Mdot
1 .5 0 r
.43285 .47919 Mdot
.38004 .47252 Mdot
.60043 .49198 Mdot
.628 .126 .941 r
.30806 .44315 Mdot
1 .5 0 r
.7278 .60205 Mdot
.33977 .44952 Mdot
.628 .126 .941 r
.29452 .41054 Mdot
.76043 .47204 Mdot
1 .5 0 r
.77012 .66977 Mdot
.42197 .46537 Mdot
.28757 .29663 Mdot
.44335 .29988 Mdot
.628 .126 .941 r
.44766 .46206 Mdot
.37078 .36144 Mdot
.27875 .44578 Mdot
1 .5 0 r
.44296 .28028 Mdot
.33251 .26075 Mdot
.628 .126 .941 r
.53633 .50718 Mdot
1 .5 0 r
.67728 .64993 Mdot
.628 .126 .941 r
.32145 .4778 Mdot
1 .5 0 r
.6072 .4778 Mdot
.83301 .58812 Mdot
.53778 .27975 Mdot
.628 .126 .941 r
.37445 .25352 Mdot
1 .5 0 r
.53346 .48062 Mdot
.628 .126 .941 r
.33809 .49355 Mdot
.35792 .36996 Mdot
.55648 .58095 Mdot
.4877 .35691 Mdot
1 .5 0 r
.59706 .43806 Mdot
.5113 .48664 Mdot
.46467 .49944 Mdot
.628 .126 .941 r
.32199 .45393 Mdot
.43166 .48958 Mdot
1 .5 0 r
.85241 .61296 Mdot
.628 .126 .941 r
.38588 .48628 Mdot
.87892 .52843 Mdot
.34807 .34977 Mdot
1 .5 0 r
.47108 .28781 Mdot
.628 .126 .941 r
.39842 .34945 Mdot
.30628 .43389 Mdot
1 .5 0 r
.46186 .41753 Mdot
.85666 .52465 Mdot
.628 .126 .941 r
.80254 .63498 Mdot
.31037 .46601 Mdot
1 .5 0 r
.25401 .28078 Mdot
.9121 .66085 Mdot
.628 .126 .941 r
.34261 .43665 Mdot
.29701 .44314 Mdot
.38926 .30332 Mdot
.48508 .40722 Mdot
.41171 .49482 Mdot
.56775 .49807 Mdot
.48277 .53056 Mdot
.43744 .49151 Mdot
1 .5 0 r
.48959 .45896 Mdot
.628 .126 .941 r
.52079 .55644 Mdot
.26276 .37441 Mdot
.34063 .33854 Mdot
1 .5 0 r
.41842 .35804 Mdot
.628 .126 .941 r
.8261 .51402 Mdot
1 .5 0 r
.67628 .53027 Mdot
.628 .126 .941 r
.53875 .57571 Mdot
.29497 .22445 Mdot
.31754 .48122 Mdot
.5644 .50723 Mdot
.29813 .44866 Mdot
.33644 .42897 Mdot
.57382 .6304 Mdot
1 .5 0 r
.41395 .37345 Mdot
.39454 .34088 Mdot
.628 .126 .941 r
.35475 .34725 Mdot
1 .5 0 r
.66944 .65939 Mdot
.83099 .6983 Mdot
.628 .126 .941 r
.34723 .32423 Mdot
1 .5 0 r
.54616 .5356 Mdot
.628 .126 .941 r
.40911 .4899 Mdot
.50743 .41503 Mdot
.56366 .59066 Mdot
.37795 .33691 Mdot
1 .5 0 r
.49907 .52881 Mdot
.628 .126 .941 r
.43447 .46695 Mdot
.4859 .51574 Mdot
.30066 .22619 Mdot
.81109 .51568 Mdot
1 .5 0 r
.50406 .54483 Mdot
.628 .126 .941 r
.37437 .45688 Mdot
.45801 .53171 Mdot
.45156 .50237 Mdot
1 .5 0 r
.38214 .31361 Mdot
.628 .126 .941 r
.36829 .3265 Mdot
.37935 .47291 Mdot
1 .5 0 r
.46973 .53147 Mdot
.76059 .69415 Mdot
.628 .126 .941 r
.27194 .20279 Mdot
.57896 .59318 Mdot
.34057 .35227 Mdot
1 .5 0 r
.51992 .57679 Mdot
.628 .126 .941 r
.80505 .68418 Mdot
.37259 .36847 Mdot
.50675 .56372 Mdot
.32094 .30983 Mdot
.71073 .36183 Mdot
.35084 .4594 Mdot
1 .5 0 r
.50569 .57006 Mdot
.628 .126 .941 r
.39055 .38774 Mdot
.48173 .3649 Mdot
1 .5 0 r
.44759 .48207 Mdot
.6111 .43324 Mdot
.42286 .35832 Mdot
.44989 .23776 Mdot
.44055 .42323 Mdot
.51078 .53065 Mdot
.39523 .32864 Mdot
.628 .126 .941 r
.89407 .5435 Mdot
.38638 .47833 Mdot
.46431 .49786 Mdot
.45064 .52059 Mdot
1 .5 0 r
.49933 .24372 Mdot
.628 .126 .941 r
.66002 .40977 Mdot
.9052 .56925 Mdot
1 .5 0 r
.59228 .55292 Mdot
.628 .126 .941 r
.4617 .54635 Mdot
.38316 .49732 Mdot
.5126 .56571 Mdot
1 .5 0 r
.35986 .26604 Mdot
.48883 .37025 Mdot
.628 .126 .941 r
.66891 .50366 Mdot
.4998 .45148 Mdot
1 .5 0 r
.66824 .52965 Mdot
.628 .126 .941 r
.49065 .5261 Mdot
1 .5 0 r
.48391 .54239 Mdot
.628 .126 .941 r
.49238 .37293 Mdot
.62187 .44134 Mdot
.53464 .55193 Mdot
.54716 .59103 Mdot
.41939 .36942 Mdot
.35524 .21607 Mdot
.37354 .31057 Mdot
.39694 .48647 Mdot
.51972 .57119 Mdot
1 .5 0 r
.61101 .54832 Mdot
.628 .126 .941 r
.57086 .60041 Mdot
.32283 .48931 Mdot
.40085 .50886 Mdot
1 .5 0 r
.43534 .34583 Mdot
.628 .126 .941 r
.51095 .54466 Mdot
.33881 .2219 Mdot
.3942 .46963 Mdot
1 .5 0 r
.52309 .5641 Mdot
.628 .126 .941 r
.31577 .43039 Mdot
1 .5 0 r
.52897 .56398 Mdot
.4016 .30638 Mdot
.5281 .58017 Mdot
.75451 .72688 Mdot
.628 .126 .941 r
.30341 .28017 Mdot
.45227 .37146 Mdot
1 .5 0 r
.88055 .55077 Mdot
.628 .126 .941 r
.37961 .38763 Mdot
1 .5 0 r
.26828 .29274 Mdot
.628 .126 .941 r
.48878 .3742 Mdot
.32377 .48502 Mdot
.73628 .39045 Mdot
1 .5 0 r
.35209 .24674 Mdot
.3839 .30871 Mdot
.628 .126 .941 r
.456 .26298 Mdot
.29916 .24987 Mdot
1 .5 0 r
.4934 .37056 Mdot
.64032 .54 Mdot
.89386 .62155 Mdot
.628 .126 .941 r
.38734 .36697 Mdot
1 .5 0 r
.41365 .32776 Mdot
.38666 .39301 Mdot
.628 .126 .941 r
.36043 .37663 Mdot
.47854 .33422 Mdot
.49686 .42883 Mdot
.50168 .55608 Mdot
.28964 .24925 Mdot
.41885 .35366 Mdot
1 .5 0 r
.58258 .29487 Mdot
.54719 .47427 Mdot
.628 .126 .941 r
.56503 .60479 Mdot
.31998 .29786 Mdot
1 .5 0 r
.53292 .4675 Mdot
.43348 .50322 Mdot
.628 .126 .941 r
.49945 .38226 Mdot
1 .5 0 r
.60797 .57159 Mdot
.628 .126 .941 r
.51276 .33976 Mdot
.50456 .46381 Mdot
.46405 .56174 Mdot
1 .5 0 r
.58733 .60085 Mdot
.56177 .55841 Mdot
.53215 .30699 Mdot
.628 .126 .941 r
.41184 .48321 Mdot
.5088 .56156 Mdot
.33977 .47336 Mdot
1 .5 0 r
.54093 .57783 Mdot
.54682 .57771 Mdot
.54036 .54827 Mdot
.55965 .57113 Mdot
.4813 .54168 Mdot
.628 .126 .941 r
.49413 .53509 Mdot
1 .5 0 r
.72139 .64611 Mdot
.628 .126 .941 r
.4703 .33911 Mdot
1 .5 0 r
.55985 .45987 Mdot
.628 .126 .941 r
.48631 .55778 Mdot
1 .5 0 r
.49316 .48581 Mdot
.5641 .55766 Mdot
.67732 .37797 Mdot
.714 .5674 Mdot
.628 .126 .941 r
.39143 .2244 Mdot
.66295 .42684 Mdot
1 .5 0 r
.50416 .56729 Mdot
.628 .126 .941 r
.43399 .41371 Mdot
.72212 .37778 Mdot
.48399 .56064 Mdot
.46593 .42012 Mdot
1 .5 0 r
.53592 .56385 Mdot
.91253 .71074 Mdot
.30275 .27605 Mdot
.628 .126 .941 r
.36531 .46222 Mdot
.47538 .5439 Mdot
1 .5 0 r
.51574 .43602 Mdot
.41947 .27585 Mdot
.54046 .49471 Mdot
.628 .126 .941 r
.5395 .56659 Mdot
.57909 .54045 Mdot
.41763 .36394 Mdot
1 .5 0 r
.55186 .59595 Mdot
.3986 .29525 Mdot
.35225 .33774 Mdot
.8386 .60231 Mdot
.55041 .58259 Mdot
.55717 .56625 Mdot
.628 .126 .941 r
.54288 .55948 Mdot
.39972 .4777 Mdot
1 .5 0 r
.60094 .57244 Mdot
.628 .126 .941 r
.76606 .38592 Mdot
.57332 .60823 Mdot
1 .5 0 r
.47052 .41849 Mdot
.628 .126 .941 r
.52231 .41182 Mdot
.52665 .57531 Mdot
1 .5 0 r
.65093 .53268 Mdot
.628 .126 .941 r
.39803 .33315 Mdot
1 .5 0 r
.53216 .55546 Mdot
.53216 .55546 Mdot
.53197 .54559 Mdot
.628 .126 .941 r
.69686 .40484 Mdot
.43377 .47346 Mdot
1 .5 0 r
.56329 .57812 Mdot
.537 .56171 Mdot
.76474 .6172 Mdot
.628 .126 .941 r
.61713 .37182 Mdot
.59007 .43724 Mdot
1 .5 0 r
.5166 .54518 Mdot
.56184 .56475 Mdot
.54812 .58759 Mdot
.628 .126 .941 r
.53487 .57445 Mdot
.72707 .3781 Mdot
.30293 .2439 Mdot
.46922 .53834 Mdot
.85596 .5089 Mdot
1 .5 0 r
.54058 .56446 Mdot
.5662 .60699 Mdot
.54715 .53823 Mdot
.53342 .56107 Mdot
.67683 .58719 Mdot
.628 .126 .941 r
.64975 .65263 Mdot
1 .5 0 r
.51515 .41044 Mdot
.628 .126 .941 r
.89325 .54132 Mdot
1 .5 0 r
.53913 .55108 Mdot
.55218 .55435 Mdot
.56476 .59362 Mdot
.60711 .34159 Mdot
.45992 .54769 Mdot
.628 .126 .941 r
.46263 .32183 Mdot
1 .5 0 r
.43555 .38728 Mdot
.628 .126 .941 r
.90461 .57709 Mdot
.46853 .32169 Mdot
.478 .5671 Mdot
1 .5 0 r
.537 .56382 Mdot
.537 .56382 Mdot
.628 .126 .941 r
.88424 .56055 Mdot
.49957 .40011 Mdot
.52375 .55067 Mdot
1 .5 0 r
.54291 .56371 Mdot
.40148 .33779 Mdot
.38871 .28863 Mdot
.49415 .2428 Mdot
.628 .126 .941 r
.5222 .59305 Mdot
.39867 .49806 Mdot
.41782 .5111 Mdot
.47635 .54383 Mdot
1 .5 0 r
.54213 .52419 Mdot
.54775 .56997 Mdot
.63869 .62889 Mdot
.628 .126 .941 r
.5043 .34067 Mdot
1 .5 0 r
.54059 .56658 Mdot
.54059 .56658 Mdot
.48137 .55997 Mdot
.5134 .5664 Mdot
.628 .126 .941 r
.57823 .61879 Mdot
1 .5 0 r
.49317 .55974 Mdot
.57765 .58915 Mdot
.53091 .55617 Mdot
.53091 .55617 Mdot
.53091 .55617 Mdot
.64125 .63805 Mdot
.55008 .56922 Mdot
.628 .126 .941 r
.77995 .53646 Mdot
1 .5 0 r
.54989 .55933 Mdot
.628 .126 .941 r
.57554 .60191 Mdot
1 .5 0 r
.57554 .60191 Mdot
.51243 .3955 Mdot
.47951 .40533 Mdot
.45928 .39865 Mdot
.56818 .58864 Mdot
.628 .126 .941 r
.83469 .73599 Mdot
1 .5 0 r
.5436 .41818 Mdot
.628 .126 .941 r
.48483 .37553 Mdot
1 .5 0 r
.54776 .57209 Mdot
.53411 .53915 Mdot
.628 .126 .941 r
.41821 .35561 Mdot
.516 .39821 Mdot
1 .5 0 r
.52811 .47357 Mdot
.628 .126 .941 r
.38945 .51938 Mdot
1 .5 0 r
.60489 .59146 Mdot
.59812 .60784 Mdot
.628 .126 .941 r
.55851 .57824 Mdot
.40822 .51264 Mdot
1 .5 0 r
.53314 .48971 Mdot
.5651 .55197 Mdot
.63095 .5323 Mdot
.56462 .58801 Mdot
.628 .126 .941 r
.6356 .65022 Mdot
1 .5 0 r
.53808 .56168 Mdot
.53808 .56168 Mdot
.628 .126 .941 r
.59842 .44037 Mdot
1 .5 0 r
.5377 .5419 Mdot
.40287 .29931 Mdot
.628 .126 .941 r
.53702 .56806 Mdot
1 .5 0 r
.46757 .34185 Mdot
.628 .126 .941 r
.65306 .69583 Mdot
.41177 .51538 Mdot
1 .5 0 r
.53673 .49244 Mdot
.55543 .54155 Mdot
.55494 .57761 Mdot
.628 .126 .941 r
.77775 .59727 Mdot
1 .5 0 r
.61966 .62016 Mdot
.60639 .607 Mdot
.61947 .61027 Mdot
.61947 .61027 Mdot
.628 .126 .941 r
.4662 .27255 Mdot
1 .5 0 r
.56066 .5676 Mdot
.59312 .59383 Mdot
.628 .126 .941 r
.75629 .5871 Mdot
1 .5 0 r
.45727 .30165 Mdot
.628 .126 .941 r
.78674 .69185 Mdot
.3403 .1901 Mdot
.57288 .46554 Mdot
1 .5 0 r
.54526 .56719 Mdot
.628 .126 .941 r
.88637 .58031 Mdot
.31277 .23587 Mdot
1 .5 0 r
.59672 .59659 Mdot
.88262 .81303 Mdot
.628 .126 .941 r
.37508 .4588 Mdot
1 .5 0 r
.54468 .53751 Mdot
.6886 .57358 Mdot
.51541 .24885 Mdot
.53092 .5604 Mdot
.5504 .52749 Mdot
.628 .126 .941 r
.70936 .42254 Mdot
.38959 .23217 Mdot
1 .5 0 r
.49864 .42241 Mdot
.54885 .56995 Mdot
.54885 .56995 Mdot
.628 .126 .941 r
.4333 .35012 Mdot
.57047 .4026 Mdot
1 .5 0 r
.61361 .61254 Mdot
.60033 .59936 Mdot
.628 .126 .941 r
.52404 .38936 Mdot
.56718 .59931 Mdot
1 .5 0 r
.56718 .59931 Mdot
.628 .126 .941 r
.34109 .29743 Mdot
1 .5 0 r
.53451 .56316 Mdot
.61255 .61893 Mdot
.78367 .58941 Mdot
.9194 .75016 Mdot
.38598 .35314 Mdot
.48341 .43188 Mdot
.56728 .54342 Mdot
.628 .126 .941 r
.56776 .50733 Mdot
.3213 .25465 Mdot
1 .5 0 r
.55351 .56633 Mdot
.628 .126 .941 r
.52132 .49409 Mdot
.3209 .23483 Mdot
1 .5 0 r
.55264 .58262 Mdot
.45015 .366 Mdot
.628 .126 .941 r
.61965 .43484 Mdot
1 .5 0 r
.61189 .52344 Mdot
.42988 .35931 Mdot
.628 .126 .941 r
.51453 .38878 Mdot
1 .5 0 r
.80643 .66114 Mdot
.628 .126 .941 r
.36838 .48716 Mdot
1 .5 0 r
.60288 .60853 Mdot
.628 .126 .941 r
.43491 .37546 Mdot
.53752 .53621 Mdot
.53732 .52631 Mdot
1 .5 0 r
.60794 .62471 Mdot
.62084 .61809 Mdot
.54644 .26354 Mdot
.628 .126 .941 r
.58767 .61803 Mdot
1 .5 0 r
.58767 .61803 Mdot
.58767 .61803 Mdot
.60756 .60491 Mdot
.628 .126 .941 r
.40753 .30942 Mdot
1 .5 0 r
.66635 .58181 Mdot
.45302 .27311 Mdot
.40694 .27968 Mdot
.47048 .44054 Mdot
.628 .126 .941 r
.72079 .39458 Mdot
1 .5 0 r
.56071 .57185 Mdot
.59321 .59811 Mdot
.628 .126 .941 r
.73 .68675 Mdot
1 .5 0 r
.58137 .47659 Mdot
.52801 .53568 Mdot
.628 .126 .941 r
.57361 .56523 Mdot
1 .5 0 r
.62446 .62087 Mdot
.62446 .62087 Mdot
.58643 .49276 Mdot
.57867 .58141 Mdot
.61117 .60768 Mdot
.61117 .60768 Mdot
.628 .126 .941 r
.40187 .50912 Mdot
1 .5 0 r
.6302 .61085 Mdot
.62389 .59115 Mdot
.6234 .62727 Mdot
.628 .126 .941 r
.45339 .53855 Mdot
1 .5 0 r
.41049 .28235 Mdot
.54539 .5155 Mdot
.87049 .77821 Mdot
.52627 .44648 Mdot
.36234 .36754 Mdot
.51132 .53175 Mdot
.628 .126 .941 r
.43445 .35762 Mdot
1 .5 0 r
.43396 .39375 Mdot
.64119 .62693 Mdot
.88869 .79772 Mdot
.42843 .29187 Mdot
.5816 .6104 Mdot
.5816 .6104 Mdot
.628 .126 .941 r
.31668 .21611 Mdot
1 .5 0 r
.61373 .61686 Mdot
.61373 .61686 Mdot
.61373 .61686 Mdot
.60063 .61357 Mdot
.628 .126 .941 r
.54364 .42628 Mdot
1 .5 0 r
.60043 .60366 Mdot
.60043 .60366 Mdot
.60043 .60366 Mdot
.60043 .60366 Mdot
.628 .126 .941 r
.43229 .37037 Mdot
.53403 .60355 Mdot
.4785 .30782 Mdot
1 .5 0 r
.87298 .77756 Mdot
.628 .126 .941 r
.41742 .39968 Mdot
1 .5 0 r
.56646 .56395 Mdot
.628 .126 .941 r
.59851 .62637 Mdot
1 .5 0 r
.61841 .61323 Mdot
.61841 .61323 Mdot
.61841 .61323 Mdot
.628 .126 .941 r
.41771 .35362 Mdot
1 .5 0 r
.56608 .54412 Mdot
.628 .126 .941 r
.53889 .60983 Mdot
1 .5 0 r
.61735 .61963 Mdot
.61735 .61963 Mdot
.628 .126 .941 r
.42295 .37971 Mdot
1 .5 0 r
.58414 .61958 Mdot
.63027 .61301 Mdot
.60405 .60644 Mdot
.60405 .60644 Mdot
.60405 .60644 Mdot
.628 .126 .941 r
.61648 .63595 Mdot
1 .5 0 r
.52549 .53074 Mdot
.57065 .59646 Mdot
.628 .126 .941 r
.7375 .39266 Mdot
.52432 .59312 Mdot
1 .5 0 r
.50568 .4879 Mdot
.63533 .62921 Mdot
.628 .126 .941 r
.58949 .58972 Mdot
1 .5 0 r
.62203 .61601 Mdot
.62203 .61601 Mdot
.62203 .61601 Mdot
.58882 .61596 Mdot
.628 .126 .941 r
.58833 .65211 Mdot
.60271 .53702 Mdot
1 .5 0 r
.63428 .63562 Mdot
.65419 .62247 Mdot
.50538 .41206 Mdot
.628 .126 .941 r
.53695 .51066 Mdot
.50422 .47445 Mdot
1 .5 0 r
.60767 .60921 Mdot
.60767 .60921 Mdot
.60767 .60921 Mdot
.628 .126 .941 r
.46322 .56314 Mdot
1 .5 0 r
.52326 .47761 Mdot
.628 .126 .941 r
.71317 .54336 Mdot
1 .5 0 r
.52306 .46769 Mdot
.628 .126 .941 r
.46263 .53338 Mdot
1 .5 0 r
.61953 .60899 Mdot
.61953 .60899 Mdot
.628 .126 .941 r
.44398 .42812 Mdot
1 .5 0 r
.57368 .56948 Mdot
.62566 .61879 Mdot
.62566 .61879 Mdot
.628 .126 .941 r
.79209 .45107 Mdot
1 .5 0 r
.73944 .42799 Mdot
.628 .126 .941 r
.67677 .68443 Mdot
.48954 .39176 Mdot
.49391 .55616 Mdot
.60662 .49369 Mdot
1 .5 0 r
.6246 .6252 Mdot
.46408 .30293 Mdot
.63752 .61857 Mdot
.61129 .61199 Mdot
.61129 .61199 Mdot
.61129 .61199 Mdot
.57806 .61194 Mdot
.628 .126 .941 r
.67553 .68093 Mdot
.73559 .59538 Mdot
1 .5 0 r
.92976 .81565 Mdot
.628 .126 .941 r
.5457 .47359 Mdot
1 .5 0 r
.62928 .62158 Mdot
.62928 .62158 Mdot
.49964 .42414 Mdot
.51227 .4636 Mdot
.628 .126 .941 r
.63668 .51293 Mdot
1 .5 0 r
.54337 .59844 Mdot
.6289 .60173 Mdot
.39447 .3879 Mdot
.628 .126 .941 r
.57185 .41421 Mdot
1 .5 0 r
.5634 .52926 Mdot
.628 .126 .941 r
.60908 .55886 Mdot
1 .5 0 r
.62172 .59833 Mdot
.61491 .61477 Mdot
.61491 .61477 Mdot
.61491 .61477 Mdot
.6084 .58511 Mdot
.6084 .58511 Mdot
.69394 .5884 Mdot
.39533 .24956 Mdot
.628 .126 .941 r
.53045 .48309 Mdot
.53511 .60145 Mdot
.65273 .66723 Mdot
.62708 .56844 Mdot
1 .5 0 r
.63291 .62436 Mdot
.60034 .59804 Mdot
.63291 .62436 Mdot
.63291 .62436 Mdot
.628 .126 .941 r
.64555 .66383 Mdot
1 .5 0 r
.6927 .58489 Mdot
.628 .126 .941 r
.68765 .44666 Mdot
.56758 .5618 Mdot
.4972 .361 Mdot
1 .5 0 r
.61854 .61756 Mdot
.61854 .61756 Mdot
.4691 .44312 Mdot
.628 .126 .941 r
.42826 .54183 Mdot
1 .5 0 r
.59987 .51222 Mdot
.61203 .58789 Mdot
.628 .126 .941 r
.54182 .397 Mdot
.53871 .60423 Mdot
.48747 .47255 Mdot
1 .5 0 r
.63041 .61733 Mdot
.60416 .61075 Mdot
.60416 .61075 Mdot
.60416 .61075 Mdot
.628 .126 .941 r
.42309 .33758 Mdot
1 .5 0 r
.48192 .37048 Mdot
.63654 .62715 Mdot
.84611 .71599 Mdot
.628 .126 .941 r
.60329 .62709 Mdot
1 .5 0 r
.60329 .62709 Mdot
.62216 .62034 Mdot
.62216 .62034 Mdot
.46149 .29775 Mdot
.5889 .62028 Mdot
.628 .126 .941 r
.60233 .57744 Mdot
1 .5 0 r
.58871 .61035 Mdot
.45312 .3568 Mdot
.60778 .61353 Mdot
.60778 .61353 Mdot
.60778 .61353 Mdot
.80573 .59049 Mdot
.64018 .62993 Mdot
.60759 .6036 Mdot
.57432 .60354 Mdot
.57432 .60354 Mdot
.38005 .32698 Mdot
.628 .126 .941 r
.73962 .48815 Mdot
1 .5 0 r
.60585 .63629 Mdot
.628 .126 .941 r
.48112 .57698 Mdot
1 .5 0 r
.57939 .61978 Mdot
.628 .126 .941 r
.75014 .66258 Mdot
1 .5 0 r
.67046 .65917 Mdot
.70306 .68551 Mdot
.628 .126 .941 r
.48881 .42206 Mdot
1 .5 0 r
.67027 .64924 Mdot
.55166 .59974 Mdot
.44248 .3626 Mdot
.628 .126 .941 r
.85508 .55688 Mdot
.40384 .27033 Mdot
1 .5 0 r
.52889 .2835 Mdot
.5396 .46791 Mdot
.55858 .52718 Mdot
.47469 .36906 Mdot
.49415 .39211 Mdot
.62942 .62591 Mdot
.62942 .62591 Mdot
.47984 .45132 Mdot
.628 .126 .941 r
.5397 .4118 Mdot
.5397 .4118 Mdot
1 .5 0 r
.59614 .62586 Mdot
.59614 .62586 Mdot
.628 .126 .941 r
.43176 .5467 Mdot
1 .5 0 r
.55732 .52365 Mdot
.56861 .61575 Mdot
.628 .126 .941 r
.57085 .42466 Mdot
1 .5 0 r
.44606 .36531 Mdot
.628 .126 .941 r
.81012 .74739 Mdot
1 .5 0 r
.60872 .47718 Mdot
.61359 .60564 Mdot
.61359 .60564 Mdot
.63257 .66494 Mdot
.628 .126 .941 r
.61924 .65171 Mdot
.58887 .43423 Mdot
.58059 .55941 Mdot
.69139 .63183 Mdot
1 .5 0 r
.64495 .62848 Mdot
.628 .126 .941 r
.76014 .37474 Mdot
1 .5 0 r
.61847 .61195 Mdot
.61847 .61195 Mdot
.63162 .61524 Mdot
.64427 .65478 Mdot
.628 .126 .941 r
.72996 .65808 Mdot
1 .5 0 r
.53406 .48999 Mdot
.5212 .4405 Mdot
.58498 .60195 Mdot
.628 .126 .941 r
.71498 .74363 Mdot
1 .5 0 r
.63689 .64144 Mdot
.628 .126 .941 r
.36501 .23608 Mdot
1 .5 0 r
.62355 .6282 Mdot
.61722 .60843 Mdot
.628 .126 .941 r
.50874 .28867 Mdot
1 .5 0 r
.53308 .44025 Mdot
.628 .126 .941 r
.57301 .41389 Mdot
1 .5 0 r
.61635 .62479 Mdot
.42917 .29519 Mdot
.628 .126 .941 r
.80996 .42701 Mdot
1 .5 0 r
.93024 .80269 Mdot
.51322 .39729 Mdot
.6223 .62468 Mdot
.6221 .61474 Mdot
.628 .126 .941 r
.50533 .42017 Mdot
.52968 .57178 Mdot
1 .5 0 r
.4988 .39044 Mdot
.83594 .78256 Mdot
.60683 .62429 Mdot
.628 .126 .941 r
.60664 .61434 Mdot
.62593 .62747 Mdot
1 .5 0 r
.62593 .62747 Mdot
.60674 .55818 Mdot
.628 .126 .941 r
.37349 .18881 Mdot
.5552 .4163 Mdot
.51331 .58774 Mdot
1 .5 0 r
.60587 .57455 Mdot
.628 .126 .941 r
.62449 .614 Mdot
.63033 .67005 Mdot
1 .5 0 r
.5975 .63373 Mdot
.63696 .64362 Mdot
.65694 .63043 Mdot
.61065 .63703 Mdot
.85913 .80848 Mdot
.628 .126 .941 r
.41391 .49512 Mdot
1 .5 0 r
.52042 .40273 Mdot
.628 .126 .941 r
.33778 .19154 Mdot
1 .5 0 r
.57753 .52462 Mdot
.56437 .52132 Mdot
.4404 .38935 Mdot
.628 .126 .941 r
.69722 .43552 Mdot
1 .5 0 r
.5827 .60701 Mdot
.63221 .33651 Mdot
.628 .126 .941 r
.70299 .42543 Mdot
1 .5 0 r
.94875 .75846 Mdot
.628 .126 .941 r
.48942 .5242 Mdot
1 .5 0 r
.56156 .56049 Mdot
.628 .126 .941 r
.52393 .33928 Mdot
1 .5 0 r
.53563 .45145 Mdot
.6186 .61628 Mdot
.67759 .64928 Mdot
.4312 .28629 Mdot
.60476 .63932 Mdot
.56634 .50063 Mdot
.628 .126 .941 r
.61228 .47411 Mdot
1 .5 0 r
.63666 .6259 Mdot
.63666 .6259 Mdot
.6035 .6358 Mdot
.6035 .6358 Mdot
.57942 .43775 Mdot
.628 .126 .941 r
.63598 .65224 Mdot
1 .5 0 r
.51973 .43109 Mdot
.628 .126 .941 r
.81036 .43109 Mdot
1 .5 0 r
.59726 .55979 Mdot
.62156 .64542 Mdot
.60839 .64212 Mdot
.60839 .64212 Mdot
.61551 .57936 Mdot
.628 .126 .941 r
.57777 .41427 Mdot
.50861 .59569 Mdot
1 .5 0 r
.59397 .6353 Mdot
.60713 .6386 Mdot
.60713 .6386 Mdot
.6403 .6287 Mdot
.628 .126 .941 r
.48452 .39757 Mdot
1 .5 0 r
.5806 .62204 Mdot
.628 .126 .941 r
.58705 .58561 Mdot
.51397 .56569 Mdot
1 .5 0 r
.61203 .64492 Mdot
.6252 .64822 Mdot
.628 .126 .941 r
.56256 .36754 Mdot
1 .5 0 r
.63818 .64157 Mdot
.73672 .68448 Mdot
.628 .126 .941 r
.43748 .30805 Mdot
1 .5 0 r
.54139 .44341 Mdot
.59262 .56557 Mdot
.69 .67117 Mdot
.628 .126 .941 r
.68951 .70749 Mdot
1 .5 0 r
.50197 .37725 Mdot
.628 .126 .941 r
.59272 .50932 Mdot
1 .5 0 r
.5976 .6381 Mdot
.65663 .67111 Mdot
.55984 .47294 Mdot
.58423 .62483 Mdot
.58423 .62483 Mdot
.62375 .63474 Mdot
.628 .126 .941 r
.7029 .5983 Mdot
1 .5 0 r
.50655 .42983 Mdot
.61049 .56522 Mdot
.628 .126 .941 r
.64221 .66429 Mdot
.68905 .62136 Mdot
1 .5 0 r
.62865 .64106 Mdot
.45424 .31405 Mdot
.628 .126 .941 r
.73972 .71367 Mdot
1 .5 0 r
.70684 .67728 Mdot
.57683 .48897 Mdot
.628 .126 .941 r
.78913 .43282 Mdot
1 .5 0 r
.61441 .6442 Mdot
.61441 .6442 Mdot
.628 .126 .941 r
.74892 .44927 Mdot
.55692 .4459 Mdot
.55702 .38962 Mdot
1 .5 0 r
.56141 .55479 Mdot
.6193 .65053 Mdot
.92927 .70999 Mdot
.628 .126 .941 r
.6977 .69672 Mdot
1 .5 0 r
.6977 .69672 Mdot
.56698 .53473 Mdot
.71051 .6801 Mdot
.63269 .54128 Mdot
.63172 .61396 Mdot
.60487 .6437 Mdot
.60487 .6437 Mdot
.61805 .647 Mdot
.628 .126 .941 r
.65057 .66347 Mdot
1 .5 0 r
.71024 .60388 Mdot
.628 .126 .941 r
.37734 .22706 Mdot
1 .5 0 r
.47549 .30637 Mdot
.628 .126 .941 r
.65029 .58725 Mdot
1 .5 0 r
.60342 .6302 Mdot
.62295 .65333 Mdot
.6625 .66325 Mdot
.40253 .29638 Mdot
.56494 .49129 Mdot
.55059 .55072 Mdot
.64923 .59368 Mdot
.6085 .6465 Mdot
.58389 .4845 Mdot
.59024 .50433 Mdot
.628 .126 .941 r
.42722 .27945 Mdot
.3943 .24302 Mdot
.51787 .40168 Mdot
1 .5 0 r
.68618 .65284 Mdot
.66615 .66606 Mdot
.79754 .73547 Mdot
.628 .126 .941 r
.49501 .57675 Mdot
1 .5 0 r
.69166 .68909 Mdot
.81164 .59978 Mdot
.628 .126 .941 r
.67467 .42781 Mdot
1 .5 0 r
.62533 .65262 Mdot
.62533 .65262 Mdot
.62533 .65262 Mdot
.62533 .65262 Mdot
.50301 .37485 Mdot
.58665 .50367 Mdot
.59174 .51996 Mdot
.628 .126 .941 r
.84876 .60263 Mdot
1 .5 0 r
.6109 .52314 Mdot
.62898 .65542 Mdot
.628 .126 .941 r
.63661 .55616 Mdot
1 .5 0 r
.46049 .33782 Mdot
.91741 .81737 Mdot
.57074 .48328 Mdot
.49235 .38068 Mdot
.49821 .43691 Mdot
.628 .126 .941 r
.55735 .46999 Mdot
.56859 .61882 Mdot
1 .5 0 r
.6287 .57913 Mdot
.72596 .73128 Mdot
.74513 .73448 Mdot
.72472 .72776 Mdot
.41218 .31089 Mdot
.46448 .36051 Mdot
.61943 .65493 Mdot
.61943 .65493 Mdot
.63263 .65824 Mdot
.93569 .77071 Mdot
.628 .126 .941 r
.88467 .60194 Mdot
1 .5 0 r
.61905 .63497 Mdot
.63225 .63828 Mdot
.61837 .66138 Mdot
.64536 .57524 Mdot
.65074 .66789 Mdot
.45694 .28071 Mdot
.4631 .29057 Mdot
.63628 .66105 Mdot
.63628 .66105 Mdot
.63628 .66105 Mdot
.62308 .65774 Mdot
.62308 .65774 Mdot
.62308 .65774 Mdot
.68224 .69083 Mdot
.60969 .64445 Mdot
.43541 .28037 Mdot
.46769 .34325 Mdot
.42083 .32988 Mdot
.44773 .30009 Mdot
.60305 .54824 Mdot
.60334 .50185 Mdot
.628 .126 .941 r
.63562 .56473 Mdot
1 .5 0 r
.64785 .64086 Mdot
.628 .126 .941 r
.62095 .67065 Mdot
.40165 .2039 Mdot
.38747 .27341 Mdot
.55131 .4058 Mdot
.5831 .5051 Mdot
1 .5 0 r
.63445 .62756 Mdot
.628 .126 .941 r
.72591 .72355 Mdot
.63456 .57118 Mdot
1 .5 0 r
.62673 .66055 Mdot
.628 .126 .941 r
.49252 .26989 Mdot
1 .5 0 r
.61333 .64726 Mdot
.439 .28306 Mdot
.628 .126 .941 r
.54642 .64714 Mdot
1 .5 0 r
.50367 .35245 Mdot
.63917 .62392 Mdot
.628 .126 .941 r
.48977 .37556 Mdot
.66588 .58413 Mdot
1 .5 0 r
.49642 .34901 Mdot
.628 .126 .941 r
.74427 .62043 Mdot
1 .5 0 r
.84994 .64692 Mdot
.628 .126 .941 r
.56257 .30914 Mdot
1 .5 0 r
.48869 .38199 Mdot
.628 .126 .941 r
.55474 .39854 Mdot
.35179 .16331 Mdot
1 .5 0 r
.61698 .65007 Mdot
.54564 .48438 Mdot
.628 .126 .941 r
.57207 .491 Mdot
1 .5 0 r
.62932 .66982 Mdot
.48771 .33199 Mdot
.55866 .4777 Mdot
.628 .126 .941 r
.5064 .3716 Mdot
1 .5 0 r
.5064 .3716 Mdot
.51178 .46433 Mdot
.628 .126 .941 r
.65027 .51732 Mdot
1 .5 0 r
.64244 .60674 Mdot
.628 .126 .941 r
.74668 .74252 Mdot
1 .5 0 r
.44111 .27217 Mdot
.628 .126 .941 r
.43231 .43446 Mdot
.56327 .53044 Mdot
1 .5 0 r
.63404 .66618 Mdot
.628 .126 .941 r
.63629 .47402 Mdot
1 .5 0 r
.62063 .65288 Mdot
.62063 .65288 Mdot
.75963 .66944 Mdot
.61339 .64946 Mdot
.628 .126 .941 r
.51824 .30489 Mdot
.53371 .60959 Mdot
.69182 .68578 Mdot
1 .5 0 r
.6185 .6658 Mdot
.628 .126 .941 r
.84252 .74857 Mdot
.55202 .62924 Mdot
1 .5 0 r
.63769 .669 Mdot
.63769 .669 Mdot
.65091 .67231 Mdot
.628 .126 .941 r
.57738 .64233 Mdot
1 .5 0 r
.69666 .6257 Mdot
.50061 .38374 Mdot
.628 .126 .941 r
.65926 .42351 Mdot
.53733 .61239 Mdot
.66366 .5892 Mdot
1 .5 0 r
.54644 .40356 Mdot
.628 .126 .941 r
.73448 .72501 Mdot
.55996 .36041 Mdot
1 .5 0 r
.56583 .41675 Mdot
.628 .126 .941 r
.73361 .74147 Mdot
1 .5 0 r
.61667 .50936 Mdot
.62794 .65851 Mdot
.44702 .27398 Mdot
.63411 .6684 Mdot
.63411 .6684 Mdot
.76077 .59874 Mdot
.628 .126 .941 r
.39422 .20423 Mdot
1 .5 0 r
.51725 .37978 Mdot
.62041 .57862 Mdot
.45122 .30672 Mdot
.628 .126 .941 r
.69939 .5785 Mdot
.67783 .70117 Mdot
.70429 .7078 Mdot
.5297 .34305 Mdot
1 .5 0 r
.63159 .66133 Mdot
.51578 .36619 Mdot
.628 .126 .941 r
.6412 .41592 Mdot
.56801 .40591 Mdot
1 .5 0 r
.61945 .52859 Mdot
.628 .126 .941 r
.6514 .57158 Mdot
1 .5 0 r
.70383 .62132 Mdot
.49442 .37588 Mdot
.628 .126 .941 r
.74804 .74058 Mdot
1 .5 0 r
.7549 .724 Mdot
.628 .126 .941 r
.83605 .58798 Mdot
1 .5 0 r
.8148 .6642 Mdot
.628 .126 .941 r
.80628 .78022 Mdot
1 .5 0 r
.92536 .81007 Mdot
.59027 .50484 Mdot
.68124 .6275 Mdot
.68007 .69046 Mdot
.64047 .62401 Mdot
.628 .126 .941 r
.66008 .64723 Mdot
1 .5 0 r
.63312 .67708 Mdot
.628 .126 .941 r
.55676 .38173 Mdot
.59989 .63053 Mdot
1 .5 0 r
.94302 .78977 Mdot
.5948 .49114 Mdot
.628 .126 .941 r
.64676 .5774 Mdot
.69823 .70014 Mdot
1 .5 0 r
.45783 .28207 Mdot
.628 .126 .941 r
.58088 .5143 Mdot
1 .5 0 r
.75098 .70341 Mdot
.47087 .27537 Mdot
.73069 .70667 Mdot
.628 .126 .941 r
.51558 .35818 Mdot
.69796 .62362 Mdot
.74955 .68987 Mdot
.6918 .49065 Mdot
1 .5 0 r
.60414 .54031 Mdot
.62326 .60005 Mdot
.628 .126 .941 r
.75204 .38427 Mdot
.50341 .59667 Mdot
1 .5 0 r
.62209 .66304 Mdot
.628 .126 .941 r
.85239 .80238 Mdot
1 .5 0 r
.62789 .65292 Mdot
.47908 .3309 Mdot
.628 .126 .941 r
.59709 .42378 Mdot
1 .5 0 r
.58924 .5134 Mdot
.61573 .52004 Mdot
.628 .126 .941 r
.57365 .6361 Mdot
1 .5 0 r
.65243 .68252 Mdot
.628 .126 .941 r
.73152 .68241 Mdot
.52185 .43668 Mdot
1 .5 0 r
.65921 .59936 Mdot
.628 .126 .941 r
.7959 .78855 Mdot
1 .5 0 r
.61988 .48629 Mdot
.628 .126 .941 r
.73597 .7253 Mdot
1 .5 0 r
.6296 .67871 Mdot
.64266 .67201 Mdot
.55316 .38304 Mdot
.628 .126 .941 r
.85378 .74164 Mdot
.57191 .42276 Mdot
.69754 .47258 Mdot
1 .5 0 r
.47896 .38948 Mdot
.56347 .48236 Mdot
.50487 .36604 Mdot
.628 .126 .941 r
.71592 .49226 Mdot
1 .5 0 r
.77856 .75462 Mdot
.628 .126 .941 r
.46962 .46556 Mdot
1 .5 0 r
.57545 .48211 Mdot
.628 .126 .941 r
.66116 .51195 Mdot
.64654 .56166 Mdot
1 .5 0 r
.77694 .73105 Mdot
.43014 .28577 Mdot
.56054 .45516 Mdot
.66345 .69102 Mdot
.93398 .85051 Mdot
.45605 .26231 Mdot
.628 .126 .941 r
.63969 .45503 Mdot
1 .5 0 r
.63674 .67435 Mdot
.63674 .67435 Mdot
.628 .126 .941 r
.74831 .73738 Mdot
1 .5 0 r
.51389 .33853 Mdot
.65041 .57448 Mdot
.628 .126 .941 r
.59767 .51461 Mdot
1 .5 0 r
.58422 .50125 Mdot
.74775 .70731 Mdot
.78065 .73389 Mdot
.628 .126 .941 r
.67193 .38486 Mdot
1 .5 0 r
.68224 .60755 Mdot
.4466 .27172 Mdot
.628 .126 .941 r
.61114 .40468 Mdot
1 .5 0 r
.4187 .31812 Mdot
.628 .126 .941 r
.43835 .34139 Mdot
.52578 .27159 Mdot
1 .5 0 r
.61075 .3846 Mdot
.628 .126 .941 r
.69572 .49762 Mdot
.51114 .32131 Mdot
1 .5 0 r
.64013 .6005 Mdot
.78388 .77331 Mdot
.628 .126 .941 r
.82102 .46075 Mdot
1 .5 0 r
.5354 .39751 Mdot
.628 .126 .941 r
.65312 .52712 Mdot
.67209 .57693 Mdot
1 .5 0 r
.63063 .66665 Mdot
.628 .126 .941 r
.5587 .54689 Mdot
1 .5 0 r
.50248 .24755 Mdot
.54769 .35064 Mdot
.53374 .37385 Mdot
.67034 .60996 Mdot
.90768 .77955 Mdot
.628 .126 .941 r
.44066 .34053 Mdot
1 .5 0 r
.59968 .37039 Mdot
.50661 .33707 Mdot
.49245 .35024 Mdot
.59173 .39348 Mdot
.5244 .45002 Mdot
.6225 .55639 Mdot
.628 .126 .941 r
.41981 .25697 Mdot
.68257 .4964 Mdot
1 .5 0 r
.64227 .52301 Mdot
.6288 .50965 Mdot
.628 .126 .941 r
.7051 .72909 Mdot
1 .5 0 r
.64739 .53941 Mdot
.6995 .6259 Mdot
.628 .126 .941 r
.51693 .31311 Mdot
1 .5 0 r
.65261 .62252 Mdot
.62666 .52259 Mdot
.628 .126 .941 r
.7068 .50595 Mdot
1 .5 0 r
.63797 .67231 Mdot
.56088 .41266 Mdot
.628 .126 .941 r
.44789 .34598 Mdot
1 .5 0 r
.77733 .6122 Mdot
.42851 .27603 Mdot
.55174 .49893 Mdot
.48073 .30585 Mdot
.63662 .60204 Mdot
.628 .126 .941 r
.68825 .72518 Mdot
1 .5 0 r
.53177 .39884 Mdot
.51171 .35544 Mdot
.628 .126 .941 r
.76384 .40863 Mdot
.56444 .34865 Mdot
.59395 .6316 Mdot
.76562 .74811 Mdot
.73886 .73141 Mdot
1 .5 0 r
.6216 .50831 Mdot
.47776 .27854 Mdot
.52991 .36509 Mdot
.628 .126 .941 r
.62928 .40837 Mdot
.75551 .41164 Mdot
1 .5 0 r
.54968 .33167 Mdot
.56248 .37162 Mdot
.628 .126 .941 r
.5792 .61467 Mdot
.77058 .7545 Mdot
1 .5 0 r
.53552 .34485 Mdot
.628 .126 .941 r
.60686 .49136 Mdot
1 .5 0 r
.52056 .44135 Mdot
.628 .126 .941 r
.74049 .44135 Mdot
1 .5 0 r
.5922 .54118 Mdot
.57891 .53785 Mdot
.628 .126 .941 r
.69337 .4279 Mdot
.61425 .31455 Mdot
1 .5 0 r
.53355 .36783 Mdot
.59162 .51103 Mdot
.628 .126 .941 r
.66592 .43777 Mdot
1 .5 0 r
.65805 .52768 Mdot
.55924 .39101 Mdot
.628 .126 .941 r
.63858 .39088 Mdot
.75866 .38422 Mdot
.80492 .4142 Mdot
1 .5 0 r
.61052 .49414 Mdot
.628 .126 .941 r
.7941 .72395 Mdot
.55304 .25752 Mdot
1 .5 0 r
.5175 .34725 Mdot
.628 .126 .941 r
.64992 .41721 Mdot
.64204 .50715 Mdot
.7782 .77027 Mdot
.6643 .29049 Mdot
1 .5 0 r
.60021 .52018 Mdot
.628 .126 .941 r
.65467 .41349 Mdot
1 .5 0 r
.51494 .34006 Mdot
.628 .126 .941 r
.84287 .75325 Mdot
1 .5 0 r
.50834 .31 Mdot
.628 .126 .941 r
.59924 .46989 Mdot
1 .5 0 r
.46117 .29653 Mdot
.628 .126 .941 r
.73545 .7331 Mdot
.68355 .59974 Mdot
1 .5 0 r
.51888 .41971 Mdot
.628 .126 .941 r
.67499 .71633 Mdot
.46599 .35965 Mdot
1 .5 0 r
.63983 .32966 Mdot
.6684 .68628 Mdot
.81417 .7596 Mdot
.628 .126 .941 r
.55936 .33626 Mdot
1 .5 0 r
.57118 .44958 Mdot
.7869 .77955 Mdot
.54488 .39619 Mdot
.64979 .53285 Mdot
.628 .126 .941 r
.73431 .67278 Mdot
1 .5 0 r
.83922 .80945 Mdot
.628 .126 .941 r
.51198 .31272 Mdot
.65728 .42272 Mdot
1 .5 0 r
.4842 .36932 Mdot
.628 .126 .941 r
.597 .41599 Mdot
.79994 .70601 Mdot
.66804 .54255 Mdot
1 .5 0 r
.53533 .46248 Mdot
.89839 .75585 Mdot
.628 .126 .941 r
.46419 .26904 Mdot
1 .5 0 r
.62135 .49242 Mdot
.628 .126 .941 r
.7849 .7358 Mdot
1 .5 0 r
.61425 .49903 Mdot
.628 .126 .941 r
.56332 .29224 Mdot
1 .5 0 r
.65191 .57881 Mdot
.92242 .81223 Mdot
.628 .126 .941 r
.57387 .40201 Mdot
.57268 .46531 Mdot
.71903 .50199 Mdot
.70751 .34186 Mdot
1 .5 0 r
.62699 .34846 Mdot
.628 .126 .941 r
.51168 .4852 Mdot
1 .5 0 r
.80729 .76852 Mdot
.628 .126 .941 r
.65135 .42491 Mdot
.61025 .47822 Mdot
.63717 .43813 Mdot
1 .5 0 r
.6421 .56822 Mdot
.628 .126 .941 r
.85188 .83169 Mdot
.76396 .39463 Mdot
1 .5 0 r
.47105 .25431 Mdot
.628 .126 .941 r
.47598 .38443 Mdot
1 .5 0 r
.49008 .30429 Mdot
.54234 .39104 Mdot
.52291 .3209 Mdot
.49629 .31423 Mdot
.71273 .60784 Mdot
.60259 .33085 Mdot
.628 .126 .941 r
.79684 .78463 Mdot
.71826 .64443 Mdot
1 .5 0 r
.77792 .6778 Mdot
.91561 .82118 Mdot
.628 .126 .941 r
.49481 .30054 Mdot
.73396 .39732 Mdot
.57361 .32704 Mdot
1 .5 0 r
.68358 .59404 Mdot
.628 .126 .941 r
.85471 .78427 Mdot
1 .5 0 r
.52656 .32363 Mdot
.69621 .62402 Mdot
.628 .126 .941 r
.78893 .68409 Mdot
.61267 .35361 Mdot
.71112 .46035 Mdot
1 .5 0 r
.72098 .7207 Mdot
.78165 .68064 Mdot
.8941 .76409 Mdot
.628 .126 .941 r
.69761 .44694 Mdot
1 .5 0 r
.77319 .74057 Mdot
.628 .126 .941 r
.65708 .40669 Mdot
.80556 .79393 Mdot
1 .5 0 r
.51048 .303 Mdot
.53613 .38312 Mdot
.628 .126 .941 r
.64842 .45651 Mdot
1 .5 0 r
.62178 .44983 Mdot
.6346 .4899 Mdot
.628 .126 .941 r
.76682 .59674 Mdot
.89293 .63675 Mdot
1 .5 0 r
.85741 .79367 Mdot
.628 .126 .941 r
.70132 .44971 Mdot
.8299 .80359 Mdot
1 .5 0 r
.51492 .34606 Mdot
.52133 .3661 Mdot
.53416 .40617 Mdot
.61371 .40604 Mdot
.628 .126 .941 r
.70006 .44611 Mdot
.69345 .416 Mdot
1 .5 0 r
.72336 .65305 Mdot
.51393 .29563 Mdot
.66494 .49936 Mdot
.46734 .25549 Mdot
.55233 .34887 Mdot
.628 .126 .941 r
.77522 .65277 Mdot
.82655 .8131 Mdot
1 .5 0 r
.81353 .76295 Mdot
.628 .126 .941 r
.66982 .43874 Mdot
1 .5 0 r
.6094 .43199 Mdot
.628 .126 .941 r
.70232 .43521 Mdot
.59509 .37821 Mdot
.66817 .41497 Mdot
1 .5 0 r
.60053 .47177 Mdot
.57416 .41825 Mdot
.628 .126 .941 r
.70155 .39485 Mdot
1 .5 0 r
.67933 .55525 Mdot
.628 .126 .941 r
.68013 .47165 Mdot
1 .5 0 r
.74432 .67215 Mdot
.628 .126 .941 r
.71648 .7289 Mdot
.61357 .398 Mdot
.78097 .38463 Mdot
1 .5 0 r
.78246 .77229 Mdot
.628 .126 .941 r
.81554 .79903 Mdot
1 .5 0 r
.81554 .79903 Mdot
.628 .126 .941 r
.73437 .34446 Mdot
.75362 .40462 Mdot
.74375 .6419 Mdot
1 .5 0 r
.5875 .29761 Mdot
.628 .126 .941 r
.71374 .33765 Mdot
.83208 .46793 Mdot
1 .5 0 r
.75534 .67845 Mdot
.54602 .27387 Mdot
.628 .126 .941 r
.67198 .36078 Mdot
1 .5 0 r
.49841 .30723 Mdot
.52508 .31391 Mdot
.63573 .54457 Mdot
.628 .126 .941 r
.66369 .43085 Mdot
.57754 .34386 Mdot
.58229 .46415 Mdot
1 .5 0 r
.76655 .69483 Mdot
.51668 .31692 Mdot
.628 .126 .941 r
.77655 .4005 Mdot
1 .5 0 r
.64118 .51418 Mdot
.81786 .78829 Mdot
.6067 .54081 Mdot
.72577 .64446 Mdot
.88418 .78484 Mdot
.628 .126 .941 r
.62094 .40352 Mdot
.66739 .43362 Mdot
.77511 .3868 Mdot
.66187 .2729 Mdot
.71376 .39664 Mdot
.65703 .58381 Mdot
.72634 .35959 Mdot
1 .5 0 r
.841 .79441 Mdot
.67029 .52008 Mdot
.62938 .52665 Mdot
.628 .126 .941 r
.74801 .66714 Mdot
.74386 .45299 Mdot
1 .5 0 r
.79329 .76076 Mdot
.628 .126 .941 r
.52894 .45286 Mdot
1 .5 0 r
.64857 .51977 Mdot
.66093 .59672 Mdot
.52913 .33885 Mdot
.64939 .31194 Mdot
.628 .126 .941 r
.61428 .43241 Mdot
1 .5 0 r
.59401 .44579 Mdot
.628 .126 .941 r
.62743 .42565 Mdot
.58175 .31181 Mdot
1 .5 0 r
.57384 .40216 Mdot
.628 .126 .941 r
.76372 .72677 Mdot
1 .5 0 r
.54081 .31836 Mdot
.91664 .76348 Mdot
.83554 .81702 Mdot
.628 .126 .941 r
.47374 .22437 Mdot
.7883 .74653 Mdot
.8343 .81348 Mdot
1 .5 0 r
.64962 .57242 Mdot
.628 .126 .941 r
.76338 .58246 Mdot
.75497 .70966 Mdot
1 .5 0 r
.83411 .80338 Mdot
.628 .126 .941 r
.67248 .31789 Mdot
1 .5 0 r
.61639 .47851 Mdot
.52884 .51199 Mdot
.5049 .27423 Mdot
.628 .126 .941 r
.67704 .42823 Mdot
1 .5 0 r
.45078 .28756 Mdot
.616 .4583 Mdot
.72088 .63239 Mdot
.83991 .72608 Mdot
.83942 .7629 Mdot
.89186 .84995 Mdot
.628 .126 .941 r
.69626 .42134 Mdot
1 .5 0 r
.84715 .66241 Mdot
.54269 .35431 Mdot
.628 .126 .941 r
.8247 .81302 Mdot
1 .5 0 r
.52914 .34085 Mdot
.65382 .53841 Mdot
.80521 .74266 Mdot
.83836 .76944 Mdot
.628 .126 .941 r
.89081 .8565 Mdot
1 .5 0 r
.47501 .35418 Mdot
.628 .126 .941 r
.87727 .84306 Mdot
1 .5 0 r
.84393 .80617 Mdot
.628 .126 .941 r
.80515 .67552 Mdot
.73785 .69562 Mdot
1 .5 0 r
.50657 .42431 Mdot
.628 .126 .941 r
.82327 .79937 Mdot
.84306 .82282 Mdot
1 .5 0 r
.51429 .32377 Mdot
.628 .126 .941 r
.76073 .44099 Mdot
1 .5 0 r
.7246 .63523 Mdot
.628 .126 .941 r
.85722 .74239 Mdot
1 .5 0 r
.909 .85621 Mdot
.628 .126 .941 r
.57229 .44756 Mdot
.72769 .35713 Mdot
.51914 .38721 Mdot
1 .5 0 r
.49291 .34367 Mdot
.79629 .71544 Mdot
.65208 .44743 Mdot
.67039 .58141 Mdot
.5722 .38038 Mdot
.5915 .44067 Mdot
.628 .126 .941 r
.72662 .36363 Mdot
1 .5 0 r
.72296 .61144 Mdot
.67624 .57118 Mdot
.61022 .47063 Mdot
.628 .126 .941 r
.68496 .39693 Mdot
1 .5 0 r
.60972 .50748 Mdot
.64566 .30306 Mdot
.84063 .6915 Mdot
.628 .126 .941 r
.79688 .43011 Mdot
.80678 .69145 Mdot
1 .5 0 r
.55587 .34956 Mdot
.59994 .56401 Mdot
.746 .67458 Mdot
.628 .126 .941 r
.83196 .74155 Mdot
.76938 .38294 Mdot
.85059 .82862 Mdot
.6043 .66436 Mdot
1 .5 0 r
.54122 .3426 Mdot
.628 .126 .941 r
.76207 .37946 Mdot
.78386 .75479 Mdot
1 .5 0 r
.55439 .33583 Mdot
.628 .126 .941 r
.70989 .74468 Mdot
1 .5 0 r
.66444 .58371 Mdot
.628 .126 .941 r
.90215 .86523 Mdot
1 .5 0 r
.57956 .3859 Mdot
.628 .126 .941 r
.70684 .39931 Mdot
.75388 .3926 Mdot
.89602 .79815 Mdot
.88859 .85178 Mdot
1 .5 0 r
.54548 .37571 Mdot
.88129 .84833 Mdot
.47208 .2716 Mdot
.71609 .56318 Mdot
.628 .126 .941 r
.74829 .66375 Mdot
1 .5 0 r
.66933 .52289 Mdot
.63545 .52283 Mdot
.78704 .72734 Mdot
.88711 .77092 Mdot
.628 .126 .941 r
.83311 .79439 Mdot
.75415 .65353 Mdot
1 .5 0 r
.45572 .36513 Mdot
.628 .126 .941 r
.60385 .32825 Mdot
.696 .46236 Mdot
.91845 .88817 Mdot
.87169 .84789 Mdot
1 .5 0 r
.95839 .88812 Mdot
.687 .55941 Mdot
.87113 .81756 Mdot
.53499 .33461 Mdot
.70644 .56265 Mdot
.628 .126 .941 r
.6889 .34461 Mdot
.84351 .82752 Mdot
1 .5 0 r
.87076 .79734 Mdot
.628 .126 .941 r
.83192 .66649 Mdot
1 .5 0 r
.75789 .65638 Mdot
.628 .126 .941 r
.80349 .76034 Mdot
.69042 .60925 Mdot
.8619 .83733 Mdot
1 .5 0 r
.65751 .5354 Mdot
.628 .126 .941 r
.6246 .46154 Mdot
1 .5 0 r
.61846 .39439 Mdot
.628 .126 .941 r
.70372 .54534 Mdot
1 .5 0 r
.86066 .83378 Mdot
.628 .126 .941 r
.9474 .87403 Mdot
1 .5 0 r
.6954 .61567 Mdot
.628 .126 .941 r
.73189 .37406 Mdot
1 .5 0 r
.662 .57871 Mdot
.628 .126 .941 r
.71713 .42426 Mdot
.70325 .45781 Mdot
.87974 .8168 Mdot
1 .5 0 r
.5102 .30676 Mdot
.628 .126 .941 r
.59013 .30663 Mdot
.86462 .8468 Mdot
.6889 .4038 Mdot
1 .5 0 r
.54194 .31984 Mdot
.50752 .35669 Mdot
.5943 .39696 Mdot
.628 .126 .941 r
.72125 .4473 Mdot
1 .5 0 r
.83084 .7896 Mdot
.628 .126 .941 r
.60135 .323 Mdot
.58845 .28272 Mdot
.56068 .34985 Mdot
.66513 .55115 Mdot
1 .5 0 r
.60423 .53425 Mdot
.81651 .73564 Mdot
.86957 .78599 Mdot
.4731 .26902 Mdot
.628 .126 .941 r
.8684 .84971 Mdot
.85482 .83624 Mdot
.86821 .83959 Mdot
1 .5 0 r
.52527 .33602 Mdot
.628 .126 .941 r
.67805 .46693 Mdot
1 .5 0 r
.98112 .9134 Mdot
.628 .126 .941 r
.73986 .34266 Mdot
1 .5 0 r
.88272 .71193 Mdot
.96754 .89992 Mdot
.96754 .89992 Mdot
.628 .126 .941 r
.761 .74545 Mdot
.89394 .85287 Mdot
1 .5 0 r
.85457 .75882 Mdot
.628 .126 .941 r
.87323 .84606 Mdot
1 .5 0 r
.64186 .53713 Mdot
.628 .126 .941 r
.87218 .85263 Mdot
.87218 .85263 Mdot
.87218 .85263 Mdot
.88588 .80893 Mdot
.87199 .84251 Mdot
.85859 .83915 Mdot
.83875 .81564 Mdot
1 .5 0 r
.97135 .90285 Mdot
.628 .126 .941 r
.7315 .72146 Mdot
.89773 .85579 Mdot
.68764 .45947 Mdot
1 .5 0 r
.5614 .32507 Mdot
.5346 .31835 Mdot
.628 .126 .941 r
.67504 .37208 Mdot
.69439 .43253 Mdot
1 .5 0 r
.81151 .72136 Mdot
.628 .126 .941 r
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
1 .5 0 r
.87056 .82882 Mdot
.79097 .72466 Mdot
.628 .126 .941 r
.70077 .38532 Mdot
.7906 .7044 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
1 .5 0 r
.64747 .3248 Mdot
.55217 .41213 Mdot
.628 .126 .941 r
.66682 .38526 Mdot
.66682 .38526 Mdot
.68668 .40877 Mdot
.84878 .82857 Mdot
1 .5 0 r
.60489 .44223 Mdot
.628 .126 .941 r
.6719 .45902 Mdot
.82279 .73783 Mdot
.91511 .87219 Mdot
1 .5 0 r
.97517 .90578 Mdot
.58583 .33467 Mdot
.58533 .37162 Mdot
.89439 .86538 Mdot
.628 .126 .941 r
.8942 .85525 Mdot
.8808 .85189 Mdot
.8808 .85189 Mdot
.8808 .85189 Mdot
.59845 .29744 Mdot
1 .5 0 r
.51803 .27729 Mdot
.628 .126 .941 r
.60391 .39151 Mdot
.87974 .85846 Mdot
1 .5 0 r
.59557 .46194 Mdot
.628 .126 .941 r
.7331 .73746 Mdot
1 .5 0 r
.83388 .74418 Mdot
.91332 .83825 Mdot
.91332 .83825 Mdot
.628 .126 .941 r
.78386 .41477 Mdot
.77721 .38447 Mdot
1 .5 0 r
.88545 .83811 Mdot
.628 .126 .941 r
.852 .80109 Mdot
1 .5 0 r
.89818 .8683 Mdot
.98507 .90862 Mdot
.56083 .4213 Mdot
.628 .126 .941 r
.81258 .70695 Mdot
1 .5 0 r
.81308 .66998 Mdot
.628 .126 .941 r
.88459 .85481 Mdot
1 .5 0 r
.66292 .30698 Mdot
.628 .126 .941 r
.85969 .63284 Mdot
.88353 .86138 Mdot
.67426 .39079 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
1 .5 0 r
.78433 .68651 Mdot
.78433 .68651 Mdot
.628 .126 .941 r
.62719 .34025 Mdot
1 .5 0 r
.5068 .26287 Mdot
.628 .126 .941 r
.62004 .3469 Mdot
1 .5 0 r
.75067 .63934 Mdot
.90911 .86455 Mdot
.59203 .40398 Mdot
.628 .126 .941 r
.85528 .84097 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
1 .5 0 r
.90179 .86109 Mdot
.51196 .2794 Mdot
.62274 .54834 Mdot
.7961 .66601 Mdot
.628 .126 .941 r
.67799 .39357 Mdot
.69786 .4171 Mdot
.87372 .85081 Mdot
.87372 .85081 Mdot
.645 .31953 Mdot
.70462 .39014 Mdot
.86012 .83731 Mdot
1 .5 0 r
.98662 .91459 Mdot
.51047 .2656 Mdot
.628 .126 .941 r
.74994 .47407 Mdot
1 .5 0 r
.73504 .58167 Mdot
.628 .126 .941 r
.80658 .7666 Mdot
.90179 .66903 Mdot
.89217 .86065 Mdot
1 .5 0 r
.83384 .66892 Mdot
.89161 .83024 Mdot
.628 .126 .941 r
.87751 .85373 Mdot
.87751 .85373 Mdot
.87751 .85373 Mdot
.87751 .85373 Mdot
.84701 .59471 Mdot
.89074 .84695 Mdot
1 .5 0 r
.66642 .48366 Mdot
.99045 .91753 Mdot
.628 .126 .941 r
.64783 .33897 Mdot
1 .5 0 r
.57985 .33883 Mdot
.628 .126 .941 r
.69367 .38592 Mdot
1 .5 0 r
.89646 .82657 Mdot
.89596 .86357 Mdot
.628 .126 .941 r
.84259 .80297 Mdot
.49197 .31515 Mdot
1 .5 0 r
.68483 .49344 Mdot
.628 .126 .941 r
.74398 .60109 Mdot
.78008 .39582 Mdot
1 .5 0 r
.89491 .87015 Mdot
.628 .126 .941 r
.89472 .86001 Mdot
.89472 .86001 Mdot
.8813 .85665 Mdot
.89472 .86001 Mdot
1 .5 0 r
.5381 .31494 Mdot
.628 .126 .941 r
.73198 .41924 Mdot
1 .5 0 r
.91423 .86328 Mdot
.628 .126 .941 r
.71817 .39556 Mdot
.65602 .50995 Mdot
.76689 .77912 Mdot
1 .5 0 r
.92747 .8565 Mdot
.628 .126 .941 r
.70406 .41904 Mdot
.86663 .84972 Mdot
.70635 .72518 Mdot
1 .5 0 r
.89976 .8665 Mdot
.628 .126 .941 r
.69174 .28432 Mdot
1 .5 0 r
.56992 .32806 Mdot
.628 .126 .941 r
.94762 .76545 Mdot
.88559 .82255 Mdot
.89852 .86294 Mdot
.8652 .83601 Mdot
.87167 .85621 Mdot
.88509 .85957 Mdot
.60007 .44209 Mdot
1 .5 0 r
.91767 .84591 Mdot
.90356 .86942 Mdot
.54009 .29372 Mdot
.5396 .33075 Mdot
.628 .126 .941 r
.65877 .46197 Mdot
1 .5 0 r
.903 .83898 Mdot
.628 .126 .941 r
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.90232 .86586 Mdot
1 .5 0 r
.90232 .86586 Mdot
.90213 .85571 Mdot
.83628 .71764 Mdot
.83578 .75467 Mdot
.9885 .923 Mdot
.7366 .58965 Mdot
.80226 .71758 Mdot
.628 .126 .941 r
.93509 .86235 Mdot
1 .5 0 r
.98832 .91285 Mdot
.57771 .35391 Mdot
.628 .126 .941 r
.87421 .85557 Mdot
.88746 .84878 Mdot
.88746 .84878 Mdot
.88746 .84878 Mdot
.90736 .87235 Mdot
.92079 .87572 Mdot
1 .5 0 r
.52388 .2729 Mdot
.628 .126 .941 r
.79305 .80491 Mdot
.80748 .7342 Mdot
.69713 .37041 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.87278 .84185 Mdot
1 .5 0 r
.89268 .86542 Mdot
.89318 .82838 Mdot
.628 .126 .941 r
.87906 .8519 Mdot
.95918 .90915 Mdot
.56787 .41069 Mdot
.78781 .59591 Mdot
1 .5 0 r
.853 .76093 Mdot
.628 .126 .941 r
.7294 .40389 Mdot
.72056 .51154 Mdot
1 .5 0 r
.90469 .85508 Mdot
.628 .126 .941 r
.69498 .38349 Mdot
.65417 .41043 Mdot
1 .5 0 r
.87216 .74388 Mdot
.9911 .92239 Mdot
.70524 .59899 Mdot
.92423 .85834 Mdot
.628 .126 .941 r
.61396 .34294 Mdot
.76726 .4743 Mdot
.89648 .86835 Mdot
.89648 .86835 Mdot
1 .5 0 r
.89648 .86835 Mdot
.61905 .41691 Mdot
.628 .126 .941 r
.88286 .85483 Mdot
.88286 .85483 Mdot
1 .5 0 r
.87122 .69308 Mdot
.53811 .31895 Mdot
.88211 .8142 Mdot
.628 .126 .941 r
.86817 .84789 Mdot
1 .5 0 r
.67034 .49071 Mdot
.53124 .27838 Mdot
.628 .126 .941 r
.78944 .61189 Mdot
.88155 .78373 Mdot
1 .5 0 r
.90097 .84438 Mdot
.63092 .33889 Mdot
.628 .126 .941 r
.88037 .8477 Mdot
1 .5 0 r
.90029 .87128 Mdot
.90029 .87128 Mdot
.55654 .32872 Mdot
.628 .126 .941 r
.88666 .85776 Mdot
.69427 .59486 Mdot
.86655 .82401 Mdot
1 .5 0 r
.50934 .27803 Mdot
.66102 .5105 Mdot
.628 .126 .941 r
.8856 .86435 Mdot
1 .5 0 r
.58214 .33182 Mdot
.9123 .86093 Mdot
.628 .126 .941 r
.73613 .36875 Mdot
1 .5 0 r
.97169 .91139 Mdot
.628 .126 .941 r
.75985 .58777 Mdot
.81214 .71248 Mdot
1 .5 0 r
.57488 .27087 Mdot
.628 .126 .941 r
.73575 .3484 Mdot
.71383 .47311 Mdot
1 .5 0 r
.90409 .87422 Mdot
.57368 .33485 Mdot
.628 .126 .941 r
.73456 .41238 Mdot
.70667 .47979 Mdot
.89843 .76967 Mdot
.89046 .86068 Mdot
.89046 .86068 Mdot
.67391 .35831 Mdot
1 .5 0 r
.56512 .39532 Mdot
.628 .126 .941 r
.8894 .86728 Mdot
.9696 .92459 Mdot
.53155 .35818 Mdot
1 .5 0 r
.6257 .38177 Mdot
.57887 .35143 Mdot
.628 .126 .941 r
.99631 .92117 Mdot
.66535 .41879 Mdot
1 .5 0 r
.63925 .3277 Mdot
.628 .126 .941 r
.69156 .45244 Mdot
1 .5 0 r
.61215 .31077 Mdot
.59751 .3714 Mdot
.94327 .75577 Mdot
.628 .126 .941 r
.88797 .85355 Mdot
.72486 .41179 Mdot
1 .5 0 r
.74379 .50957 Mdot
.89426 .86361 Mdot
.53035 .29708 Mdot
.628 .126 .941 r
.56882 .39811 Mdot
1 .5 0 r
.54919 .32722 Mdot
.71562 .49921 Mdot
.628 .126 .941 r
.86611 .8533 Mdot
1 .5 0 r
.9269 .84993 Mdot
.628 .126 .941 r
.8734 .78918 Mdot
1 .5 0 r
.52886 .28324 Mdot
.91239 .85315 Mdot
.91239 .85315 Mdot
.92585 .85653 Mdot
.628 .126 .941 r
.91171 .88009 Mdot
.71466 .44831 Mdot
.87265 .74849 Mdot
.89806 .86655 Mdot
1 .5 0 r
.89806 .86655 Mdot
.97831 .92388 Mdot
.628 .126 .941 r
.68138 .36385 Mdot
1 .5 0 r
.81196 .69442 Mdot
.93109 .87319 Mdot
.628 .126 .941 r
.76143 .41101 Mdot
.73402 .44137 Mdot
1 .5 0 r
.87738 .80226 Mdot
.94368 .89334 Mdot
.628 .126 .941 r
.59705 .5357 Mdot
1 .5 0 r
.67232 .46148 Mdot
.6783 .51883 Mdot
.50513 .31635 Mdot
.628 .126 .941 r
.77413 .37364 Mdot
.78441 .5895 Mdot
1 .5 0 r
.94294 .85266 Mdot
.628 .126 .941 r
.89558 .85941 Mdot
.91552 .88302 Mdot
.92898 .8864 Mdot
1 .5 0 r
.96288 .87628 Mdot
.72389 .54558 Mdot
.628 .126 .941 r
.90187 .86948 Mdot
1 .5 0 r
.90187 .86948 Mdot
.5507 .34307 Mdot
.628 .126 .941 r
.69079 .47129 Mdot
1 .5 0 r
.64343 .47804 Mdot
.58999 .35974 Mdot
.628 .126 .941 r
.58949 .39686 Mdot
.88218 .73093 Mdot
.91409 .86928 Mdot
.8737 .85916 Mdot
1 .5 0 r
.91409 .86928 Mdot
.628 .126 .941 r
.88717 .86254 Mdot
1 .5 0 r
.93454 .85579 Mdot
.58281 .36643 Mdot
.881 .795 Mdot
.96826 .83549 Mdot
.628 .126 .941 r
.61682 .2988 Mdot
1 .5 0 r
.79435 .6599 Mdot
.628 .126 .941 r
.79915 .78134 Mdot
.75826 .80834 Mdot
1 .5 0 r
.89939 .86234 Mdot
.628 .126 .941 r
.9328 .88934 Mdot
.69672 .33578 Mdot
1 .5 0 r
.57504 .34253 Mdot
.628 .126 .941 r
.90568 .87242 Mdot
.90568 .87242 Mdot
.64896 .32215 Mdot
.64926 .27482 Mdot
1 .5 0 r
.5529 .332 Mdot
.81777 .73372 Mdot
.628 .126 .941 r
.84552 .65602 Mdot
1 .5 0 r
.79744 .68972 Mdot
.628 .126 .941 r
.87626 .85852 Mdot
1 .5 0 r
.89072 .78763 Mdot
.628 .126 .941 r
.9032 .86527 Mdot
1 .5 0 r
.61217 .37231 Mdot
.61716 .50398 Mdot
.91648 .85847 Mdot
.628 .126 .941 r
.68631 .36212 Mdot
1 .5 0 r
.49803 .26751 Mdot
.628 .126 .941 r
.94255 .88201 Mdot
.75976 .37887 Mdot
1 .5 0 r
.54403 .31464 Mdot
.56997 .39568 Mdot
.628 .126 .941 r
.72514 .41594 Mdot
.71117 .44971 Mdot
1 .5 0 r
.93519 .87854 Mdot
.94218 .86165 Mdot
.58325 .38886 Mdot
.628 .126 .941 r
.90807 .8616 Mdot
1 .5 0 r
.90807 .8616 Mdot
.628 .126 .941 r
.63624 .41912 Mdot
1 .5 0 r
.65121 .31106 Mdot
.65121 .31106 Mdot
.628 .126 .941 r
.77197 .3786 Mdot
1 .5 0 r
.99452 .91891 Mdot
.628 .126 .941 r
.70222 .48992 Mdot
1 .5 0 r
.51349 .37489 Mdot
.56769 .34105 Mdot
.7264 .60451 Mdot
.628 .126 .941 r
.83152 .80712 Mdot
1 .5 0 r
.66213 .30713 Mdot
.628 .126 .941 r
.63368 .41185 Mdot
.98557 .89151 Mdot
.63448 .32733 Mdot
1 .5 0 r
.51299 .28673 Mdot
.628 .126 .941 r
.71465 .37456 Mdot
1 .5 0 r
.91713 .88123 Mdot
.628 .126 .941 r
.53805 .38456 Mdot
.58497 .41497 Mdot
1 .5 0 r
.878 .74943 Mdot
.61104 .43849 Mdot
.61104 .43849 Mdot
.628 .126 .941 r
.82771 .41822 Mdot
.90259 .88447 Mdot
1 .5 0 r
.60485 .37085 Mdot
.628 .126 .941 r
.75313 .40802 Mdot
1 .5 0 r
.74963 .66818 Mdot
.628 .126 .941 r
.94934 .90469 Mdot
1 .5 0 r
.92936 .88104 Mdot
.59766 .37754 Mdot
.5705 .36058 Mdot
.94878 .87414 Mdot
.628 .126 .941 r
.9421 .84367 Mdot
1 .5 0 r
.9421 .84367 Mdot
.92163 .85719 Mdot
.9481 .90112 Mdot
.628 .126 .941 r
.86852 .75914 Mdot
.92794 .86728 Mdot
1 .5 0 r
.52257 .27913 Mdot
.628 .126 .941 r
.981 .8976 Mdot
1 .5 0 r
.97401 .9145 Mdot
.628 .126 .941 r
.64114 .41744 Mdot
1 .5 0 r
.53456 .26865 Mdot
.628 .126 .941 r
.66822 .3666 Mdot
.98589 .89393 Mdot
1 .5 0 r
.92545 .86013 Mdot
.628 .126 .941 r
.62707 .38344 Mdot
1 .5 0 r
.61258 .45443 Mdot
.92477 .88712 Mdot
.628 .126 .941 r
.69381 .42732 Mdot
1 .5 0 r
.97785 .91745 Mdot
.9382 .82274 Mdot
.628 .126 .941 r
.7207 .36627 Mdot
1 .5 0 r
.63178 .43727 Mdot
.628 .126 .941 r
.76816 .35951 Mdot
1 .5 0 r
.63128 .47446 Mdot
.54515 .31211 Mdot
.6056 .34592 Mdot
.63099 .39644 Mdot
.94277 .86645 Mdot
.628 .126 .941 r
.87513 .83935 Mdot
.93559 .87316 Mdot
1 .5 0 r
.93622 .77838 Mdot
.62301 .36229 Mdot
.628 .126 .941 r
.96083 .91355 Mdot
1 .5 0 r
.54885 .31487 Mdot
.60932 .34869 Mdot
.70778 .57867 Mdot
.628 .126 .941 r
.79635 .48723 Mdot
.65622 .31128 Mdot
1 .5 0 r
.93311 .86601 Mdot
.628 .126 .941 r
.58704 .39578 Mdot
1 .5 0 r
.93942 .87611 Mdot
.58685 .38556 Mdot
.53366 .2874 Mdot
.58615 .41256 Mdot
.96554 .89969 Mdot
.628 .126 .941 r
.89769 .86238 Mdot
1 .5 0 r
.95817 .89621 Mdot
.57936 .31418 Mdot
.61885 .39877 Mdot
.628 .126 .941 r
.73834 .57808 Mdot
1 .5 0 r
.65865 .43592 Mdot
.628 .126 .941 r
.78664 .48667 Mdot
1 .5 0 r
.77764 .65246 Mdot
.95794 .8182 Mdot
.90325 .83168 Mdot
.628 .126 .941 r
.56307 .41881 Mdot
1 .5 0 r
.55657 .3985 Mdot
.628 .126 .941 r
.75249 .36108 Mdot
.73849 .39492 Mdot
1 .5 0 r
.74949 .58444 Mdot
.628 .126 .941 r
.71779 .39824 Mdot
.63678 .37794 Mdot
1 .5 0 r
.54957 .28988 Mdot
.628 .126 .941 r
.65109 .29664 Mdot
1 .5 0 r
.60308 .34064 Mdot
.628 .126 .941 r
.83512 .71631 Mdot
.78661 .79753 Mdot
.65039 .32365 Mdot
.56887 .34057 Mdot
1 .5 0 r
.90126 .78728 Mdot
.628 .126 .941 r
.76053 .64845 Mdot
1 .5 0 r
.84787 .67886 Mdot
.98691 .91918 Mdot
.628 .126 .941 r
.81417 .64157 Mdot
.65592 .29284 Mdot
.75646 .37409 Mdot
.98655 .89878 Mdot
.98655 .89878 Mdot
.91933 .83441 Mdot
1 .5 0 r
.57949 .38411 Mdot
.628 .126 .941 r
.73606 .32994 Mdot
1 .5 0 r
.60681 .34342 Mdot
.68034 .4179 Mdot
.84642 .66504 Mdot
.628 .126 .941 r
.72117 .38059 Mdot
1 .5 0 r
.93879 .82749 Mdot
.628 .126 .941 r
.63973 .33983 Mdot
.8902 .84088 Mdot
.99058 .91194 Mdot
1 .5 0 r
.61663 .47169 Mdot
.5774 .33956 Mdot
.62424 .35981 Mdot
.628 .126 .941 r
.64976 .47833 Mdot
1 .5 0 r
.64426 .38351 Mdot
.628 .126 .941 r
.73864 .39699 Mdot
.74965 .58664 Mdot
1 .5 0 r
.74915 .62389 Mdot
.628 .126 .941 r
.89527 .8474 Mdot
.98934 .90836 Mdot
.98934 .90836 Mdot
.6849 .33597 Mdot
.74526 .35961 Mdot
1 .5 0 r
.96145 .91843 Mdot
.628 .126 .941 r
.71104 .35954 Mdot
1 .5 0 r
.64948 .40018 Mdot
.55419 .4035 Mdot
.53547 .25779 Mdot
.628 .126 .941 r
.72967 .43731 Mdot
1 .5 0 r
.68763 .53892 Mdot
.64839 .40676 Mdot
.628 .126 .941 r
.7433 .38298 Mdot
1 .5 0 r
.62117 .38976 Mdot
.628 .126 .941 r
.91298 .87416 Mdot
.933 .89787 Mdot
.64249 .29145 Mdot
1 .5 0 r
.8128 .68768 Mdot
.93276 .81975 Mdot
.93226 .85702 Mdot
.61898 .40291 Mdot
.628 .126 .941 r
.72762 .39275 Mdot
1 .5 0 r
.92488 .85353 Mdot
.9454 .83998 Mdot
.53868 .29781 Mdot
.628 .126 .941 r
.6246 .44005 Mdot
1 .5 0 r
.6246 .44005 Mdot
.628 .126 .941 r
.61839 .37222 Mdot
.78963 .75173 Mdot
.90329 .87372 Mdot
.74738 .33827 Mdot
.91762 .79234 Mdot
1 .5 0 r
.66607 .3077 Mdot
.58445 .32465 Mdot
.628 .126 .941 r
.83281 .5178 Mdot
1 .5 0 r
.53698 .27367 Mdot
.94961 .86335 Mdot
.628 .126 .941 r
.7386 .38883 Mdot
1 .5 0 r
.92238 .84636 Mdot
.60319 .34471 Mdot
.60319 .34471 Mdot
.628 .126 .941 r
.65157 .25313 Mdot
.66459 .2938 Mdot
1 .5 0 r
.57595 .32769 Mdot
.628 .126 .941 r
.65658 .38531 Mdot
.98844 .90722 Mdot
1 .5 0 r
.98844 .90722 Mdot
.628 .126 .941 r
.76287 .50381 Mdot
1 .5 0 r
.74834 .57499 Mdot
.76788 .63601 Mdot
.96822 .87328 Mdot
.628 .126 .941 r
.70408 .31054 Mdot
1 .5 0 r
.92145 .79526 Mdot
.628 .126 .941 r
.70839 .46979 Mdot
.90674 .85623 Mdot
.75609 .40525 Mdot
.63336 .44932 Mdot
1 .5 0 r
.71301 .58154 Mdot
.628 .126 .941 r
.63517 .28992 Mdot
.95928 .91371 Mdot
.73497 .38811 Mdot
1 .5 0 r
.91883 .84581 Mdot
.80542 .67623 Mdot
.65392 .30999 Mdot
.61284 .33711 Mdot
.628 .126 .941 r
.92447 .88301 Mdot
.95854 .87284 Mdot
1 .5 0 r
.89172 .77106 Mdot
.89855 .74388 Mdot
.628 .126 .941 r
.98473 .89647 Mdot
1 .5 0 r
.91057 .85917 Mdot
.628 .126 .941 r
.72048 .33352 Mdot
1 .5 0 r
.85057 .73021 Mdot
.628 .126 .941 r
.77321 .40121 Mdot
1 .5 0 r
.77622 .68268 Mdot
.92354 .8319 Mdot
.92267 .84875 Mdot
.65787 .323 Mdot
.59653 .31615 Mdot
.88972 .72655 Mdot
.628 .126 .941 r
.94835 .9097 Mdot
.92812 .87574 Mdot
.98877 .90966 Mdot
1 .5 0 r
.71592 .47544 Mdot
.628 .126 .941 r
.89435 .83838 Mdot
1 .5 0 r
.9144 .86212 Mdot
.628 .126 .941 r
.66861 .43467 Mdot
1 .5 0 r
.65569 .33616 Mdot
.628 .126 .941 r
.98753 .90607 Mdot
.98101 .88572 Mdot
.98101 .88572 Mdot
.74322 .36663 Mdot
.72899 .39031 Mdot
.78294 .39363 Mdot
1 .5 0 r
.69972 .52256 Mdot
.628 .126 .941 r
.89505 .61749 Mdot
.9522 .91267 Mdot
.73423 .40701 Mdot
1 .5 0 r
.73173 .59363 Mdot
.92626 .77346 Mdot
.628 .126 .941 r
.91774 .90239 Mdot
.95133 .92954 Mdot
.74808 .36283 Mdot
.69443 .31193 Mdot
.71379 .36276 Mdot
.68621 .3933 Mdot
1 .5 0 r
.9655 .83783 Mdot
.628 .126 .941 r
.9314 .84801 Mdot
.68 .32537 Mdot
.79433 .4102 Mdot
.77778 .63078 Mdot
1 .5 0 r
.58453 .32869 Mdot
.74399 .59339 Mdot
.59787 .32184 Mdot
.628 .126 .941 r
.61793 .34559 Mdot
.73227 .43044 Mdot
.67942 .29462 Mdot
1 .5 0 r
.67089 .42358 Mdot
.628 .126 .941 r
.98381 .89532 Mdot
.98381 .89532 Mdot
1 .5 0 r
.99033 .91568 Mdot
.628 .126 .941 r
.7725 .42012 Mdot
.95605 .91563 Mdot
1 .5 0 r
.91555 .84766 Mdot
.628 .126 .941 r
.71174 .3181 Mdot
.98258 .89173 Mdot
.9891 .9121 Mdot
.9891 .9121 Mdot
.68998 .3961 Mdot
.77173 .37913 Mdot
1 .5 0 r
.97537 .89847 Mdot
.64143 .41973 Mdot
.628 .126 .941 r
.80094 .68451 Mdot
1 .5 0 r
.70845 .4638 Mdot
.628 .126 .941 r
.98786 .90851 Mdot
1 .5 0 r
.74731 .50768 Mdot
.91939 .8506 Mdot
.73187 .59584 Mdot
.83272 .67733 Mdot
.628 .126 .941 r
.80142 .45317 Mdot
1 .5 0 r
.91112 .86399 Mdot
.59832 .34437 Mdot
.628 .126 .941 r
.7604 .42248 Mdot
1 .5 0 r
.95773 .86384 Mdot
.67802 .4087 Mdot
.95754 .8536 Mdot
.5903 .31007 Mdot
.628 .126 .941 r
.73133 .43914 Mdot
1 .5 0 r
.92304 .84331 Mdot
.628 .126 .941 r
.65566 .45599 Mdot
.9829 .89416 Mdot
1 .5 0 r
.98943 .91454 Mdot
.60206 .34716 Mdot
.628 .126 .941 r
.72453 .34037 Mdot
.71098 .33697 Mdot
1 .5 0 r
.62916 .35395 Mdot
.628 .126 .941 r
.68839 .50002 Mdot
.91427 .89407 Mdot
1 .5 0 r
.92882 .82273 Mdot
.628 .126 .941 r
.98184 .90081 Mdot
.69603 .38779 Mdot
.71611 .41157 Mdot
.8406 .76148 Mdot
.67676 .27901 Mdot
1 .5 0 r
.81381 .70707 Mdot
.628 .126 .941 r
.72978 .35708 Mdot
.73581 .41484 Mdot
.72306 .32644 Mdot
.70831 .38753 Mdot
.78311 .38753 Mdot
1 .5 0 r
.70078 .44189 Mdot
.70078 .44189 Mdot
.86043 .70691 Mdot
.628 .126 .941 r
.74878 .38746 Mdot
1 .5 0 r
.64717 .33303 Mdot
.61955 .36361 Mdot
.94641 .83931 Mdot
.82603 .63872 Mdot
.628 .126 .941 r
.98571 .90378 Mdot
.6742 .27165 Mdot
.6742 .27165 Mdot
.68053 .28178 Mdot
.65291 .31236 Mdot
1 .5 0 r
.93161 .83232 Mdot
.628 .126 .941 r
.72553 .45163 Mdot
1 .5 0 r
.59778 .31562 Mdot
.628 .126 .941 r
.66608 .29523 Mdot
.74643 .39039 Mdot
.85339 .52974 Mdot
.87348 .55353 Mdot
.75257 .39026 Mdot
1 .5 0 r
.95698 .8729 Mdot
.628 .126 .941 r
.72978 .54315 Mdot
.73159 .38333 Mdot
.68399 .33221 Mdot
.78495 .41379 Mdot
.69504 .52257 Mdot
1 .5 0 r
.93665 .77072 Mdot
.628 .126 .941 r
.95523 .9067 Mdot
.96829 .94749 Mdot
1 .5 0 r
.96929 .8727 Mdot
.628 .126 .941 r
.75814 .35933 Mdot
1 .5 0 r
.90161 .79782 Mdot
.95586 .81141 Mdot
.628 .126 .941 r
.9413 .8828 Mdot
1 .5 0 r
.98852 .9134 Mdot
.628 .126 .941 r
.72792 .50873 Mdot
.66894 .31487 Mdot
.92096 .78061 Mdot
1 .5 0 r
.59319 .33173 Mdot
.7193 .56974 Mdot
.55209 .30099 Mdot
.628 .126 .941 r
.73248 .55262 Mdot
1 .5 0 r
.67852 .49135 Mdot
.9594 .86201 Mdot
.9795 .88582 Mdot
.628 .126 .941 r
.63913 .35866 Mdot
1 .5 0 r
.61802 .40967 Mdot
.64566 .37906 Mdot
.628 .126 .941 r
.78837 .39607 Mdot
1 .5 0 r
.92505 .86196 Mdot
.628 .126 .941 r
.70777 .29058 Mdot
1 .5 0 r
.59169 .31778 Mdot
.628 .126 .941 r
.6937 .32458 Mdot
.77461 .3824 Mdot
.89069 .86191 Mdot
.68698 .29391 Mdot
.74024 .38233 Mdot
1 .5 0 r
.87191 .71562 Mdot
.56366 .32785 Mdot
.628 .126 .941 r
.94409 .89242 Mdot
1 .5 0 r
.56929 .36513 Mdot
.628 .126 .941 r
.73966 .35152 Mdot
1 .5 0 r
.61703 .35832 Mdot
.628 .126 .941 r
.93718 .85151 Mdot
.6103 .32764 Mdot
.7445 .4739 Mdot
1 .5 0 r
.96395 .83781 Mdot
.67676 .39894 Mdot
.628 .126 .941 r
.65796 .2526 Mdot
1 .5 0 r
.60217 .35125 Mdot
.64288 .36146 Mdot
.628 .126 .941 r
.74473 .35799 Mdot
.702 .49746 Mdot
1 .5 0 r
.87524 .75596 Mdot
.628 .126 .941 r
.79109 .40548 Mdot
1 .5 0 r
.77984 .71162 Mdot
.628 .126 .941 r
.81906 .8341 Mdot
.71027 .28967 Mdot
1 .5 0 r
.62078 .36112 Mdot
.62078 .36112 Mdot
.628 .126 .941 r
.76306 .41556 Mdot
.89981 .88168 Mdot
1 .5 0 r
.61405 .33043 Mdot
.628 .126 .941 r
.74326 .34404 Mdot
.68796 .40528 Mdot
.66212 .27592 Mdot
.89943 .86117 Mdot
.74941 .3439 Mdot
.59183 .38807 Mdot
1 .5 0 r
.87995 .74197 Mdot
.5856 .31995 Mdot
.628 .126 .941 r
.7621 .36418 Mdot
.72841 .33696 Mdot
.7621 .36418 Mdot
.74852 .36078 Mdot
1 .5 0 r
.75908 .58878 Mdot
.628 .126 .941 r
.91898 .85422 Mdot
.66737 .29265 Mdot
.8851 .81673 Mdot
.66063 .26195 Mdot
.75328 .41497 Mdot
.75378 .37753 Mdot
1 .5 0 r
.65722 .46602 Mdot
.95897 .82339 Mdot
.628 .126 .941 r
.738 .51361 Mdot
.69908 .34336 Mdot
.69939 .29564 Mdot
.67927 .27181 Mdot
.7532 .34669 Mdot
.65694 .38747 Mdot
.72515 .35677 Mdot
.68452 .28855 Mdot
.92177 .86383 Mdot
.75708 .41778 Mdot
1 .5 0 r
.96887 .88421 Mdot
.628 .126 .941 r
.75084 .34962 Mdot
.71694 .3121 Mdot
.77078 .36318 Mdot
.82612 .80921 Mdot
.92706 .88066 Mdot
.92033 .84996 Mdot
1 .5 0 r
.94096 .83634 Mdot
.628 .126 .941 r
.92637 .90785 Mdot
.73598 .34254 Mdot
.72189 .37659 Mdot
.74957 .34595 Mdot
1 .5 0 r
.63999 .3356 Mdot
.628 .126 .941 r
.6883 .29132 Mdot
.68578 .47862 Mdot
1 .5 0 r
.94625 .85317 Mdot
.628 .126 .941 r
.74125 .3593 Mdot
.76138 .38314 Mdot
1 .5 0 r
.62531 .3388 Mdot
.628 .126 .941 r
.86385 .84967 Mdot
.72073 .31489 Mdot
1 .5 0 r
.74589 .47156 Mdot
.85259 .64867 Mdot
.628 .126 .941 r
.76029 .38975 Mdot
.95104 .90747 Mdot
1 .5 0 r
.95859 .85297 Mdot
.628 .126 .941 r
.67303 .26366 Mdot
1 .5 0 r
.64484 .33178 Mdot
.628 .126 .941 r
.92418 .85292 Mdot
.92418 .85292 Mdot
1 .5 0 r
.94431 .87676 Mdot
.94481 .8393 Mdot
.628 .126 .941 r
.7735 .37259 Mdot
.73223 .39984 Mdot
1 .5 0 r
.59663 .31802 Mdot
.66942 .45762 Mdot
.628 .126 .941 r
.65815 .25656 Mdot
1 .5 0 r
.62996 .32469 Mdot
.628 .126 .941 r
.77896 .39964 Mdot
.77877 .38935 Mdot
.75863 .3655 Mdot
.77877 .38935 Mdot
.91569 .85608 Mdot
1 .5 0 r
.58174 .31093 Mdot
.60893 .31774 Mdot
.628 .126 .941 r
.76448 .41313 Mdot
1 .5 0 r
.86315 .68228 Mdot
.628 .126 .941 r
.68928 .40285 Mdot
.71546 .48462 Mdot
.84182 .72311 Mdot
.69059 .28012 Mdot
.73067 .31753 Mdot
.75081 .34138 Mdot
.75585 .47427 Mdot
.73048 .30724 Mdot
.87045 .54917 Mdot
.68245 .30377 Mdot
.84338 .4843 Mdot
.68156 .32067 Mdot
.78277 .40245 Mdot
.78277 .40245 Mdot
.74884 .3649 Mdot
.78258 .39216 Mdot
.74078 .45691 Mdot
.70131 .32394 Mdot
.68097 .28979 Mdot
.78219 .37158 Mdot
.70111 .31364 Mdot
1 .5 0 r
.75903 .57266 Mdot
.628 .126 .941 r
.91917 .83849 Mdot
1 .5 0 r
.63897 .34425 Mdot
.65237 .33736 Mdot
.84476 .74296 Mdot
.59023 .36797 Mdot
.628 .126 .941 r
.75341 .40887 Mdot
.74737 .35093 Mdot
.90551 .76676 Mdot
1 .5 0 r
.9181 .84516 Mdot
.628 .126 .941 r
.74717 .34063 Mdot
1 .5 0 r
.75171 .51106 Mdot
.90375 .80064 Mdot
.628 .126 .941 r
.71819 .36763 Mdot
.85905 .52439 Mdot
.77151 .38789 Mdot
.969 .92658 Mdot
1 .5 0 r
.57433 .3094 Mdot
.628 .126 .941 r
.76477 .35714 Mdot
.76477 .35714 Mdot
.70381 .32304 Mdot
.75117 .35373 Mdot
.75117 .35373 Mdot
1 .5 0 r
.62099 .3673 Mdot
.628 .126 .941 r
.85527 .70827 Mdot
.77004 .37392 Mdot
.77004 .37392 Mdot
.77004 .37392 Mdot
.74264 .3568 Mdot
.72248 .33293 Mdot
.71442 .425 Mdot
.68853 .29535 Mdot
.68814 .27474 Mdot
.68763 .31226 Mdot
.76171 .38729 Mdot
.76222 .34977 Mdot
.77532 .3907 Mdot
1 .5 0 r
.61789 .39746 Mdot
.628 .126 .941 r
.77513 .3804 Mdot
.75497 .35653 Mdot
.94547 .91247 Mdot
1 .5 0 r
.61164 .32917 Mdot
.628 .126 .941 r
.75477 .34623 Mdot
.68704 .28135 Mdot
.72698 .3085 Mdot
.7804 .39719 Mdot
.77385 .37672 Mdot
.73989 .33913 Mdot
.83276 .49251 Mdot
1 .5 0 r
.64352 .32187 Mdot
.628 .126 .941 r
.69192 .27752 Mdot
.74586 .32869 Mdot
.77894 .38321 Mdot
.77238 .36274 Mdot
.74566 .31839 Mdot
.77188 .40027 Mdot
.75171 .37639 Mdot
.77188 .40027 Mdot
1 .5 0 r
.96396 .8438 Mdot
.628 .126 .941 r
.69738 .3046 Mdot
.6634 .267 Mdot
.76405 .37612 Mdot
1 .5 0 r
.78251 .50231 Mdot
.628 .126 .941 r
.72937 .36575 Mdot
.72968 .31791 Mdot
1 .5 0 r
.71456 .42711 Mdot
.628 .126 .941 r
.6957 .2803 Mdot
.6957 .2803 Mdot
1 .5 0 r
.64729 .32466 Mdot
.628 .126 .941 r
.76933 .39292 Mdot
.76258 .36213 Mdot
.76258 .36213 Mdot
.91992 .85359 Mdot
.70036 .39278 Mdot
1 .5 0 r
.91299 .81253 Mdot
.61876 .31415 Mdot
.63894 .33804 Mdot
.62512 .32432 Mdot
.628 .126 .941 r
.76786 .37893 Mdot
.91866 .84997 Mdot
1 .5 0 r
.74446 .57002 Mdot
.86602 .67584 Mdot
.628 .126 .941 r
.69938 .34125 Mdot
.93796 .89084 Mdot
1 .5 0 r
.79805 .60062 Mdot
.63674 .35128 Mdot
.66449 .32056 Mdot
.66449 .32056 Mdot
.628 .126 .941 r
.95707 .92142 Mdot
.86387 .68916 Mdot
.86337 .72671 Mdot
1 .5 0 r
.64271 .34084 Mdot
.67046 .31011 Mdot
.83644 .67203 Mdot
.64201 .36808 Mdot
.628 .126 .941 r
.77167 .38174 Mdot
1 .5 0 r
.63525 .33729 Mdot
.75483 .59338 Mdot
.83536 .67869 Mdot
.628 .126 .941 r
.9499 .80162 Mdot
1 .5 0 r
.6616 .36105 Mdot
.628 .126 .941 r
.71458 .4874 Mdot
.75677 .37465 Mdot
.72277 .33701 Mdot
.79038 .39165 Mdot
.75638 .35402 Mdot
.7695 .395 Mdot
.9219 .7536 Mdot
1 .5 0 r
.74761 .47349 Mdot
.62559 .34699 Mdot
.628 .126 .941 r
.92639 .8559 Mdot
.76166 .37083 Mdot
.76166 .37083 Mdot
.74147 .34692 Mdot
1 .5 0 r
.59138 .29903 Mdot
.628 .126 .941 r
.76046 .43566 Mdot
1 .5 0 r
.59118 .28871 Mdot
.628 .126 .941 r
.7944 .40479 Mdot
.95895 .87962 Mdot
.77401 .37056 Mdot
1 .5 0 r
.77906 .50379 Mdot
.628 .126 .941 r
.74 .33291 Mdot
.76019 .35683 Mdot
1 .5 0 r
.77079 .58572 Mdot
.65025 .34644 Mdot
.65025 .34644 Mdot
.65712 .31904 Mdot
.61623 .30879 Mdot
.64279 .34289 Mdot
.61553 .33605 Mdot
.61553 .33605 Mdot
.628 .126 .941 r
.9437 .85199 Mdot
.67743 .28473 Mdot
1 .5 0 r
.59443 .32908 Mdot
.628 .126 .941 r
.74489 .32908 Mdot
1 .5 0 r
.86203 .7733 Mdot
.628 .126 .941 r
.76439 .38027 Mdot
1 .5 0 r
.93708 .76299 Mdot
.628 .126 .941 r
.77783 .37337 Mdot
.77783 .37337 Mdot
.71654 .32888 Mdot
.764 .35963 Mdot
.764 .35963 Mdot
1 .5 0 r
.87541 .6979 Mdot
.628 .126 .941 r
.78312 .39019 Mdot
.80332 .41411 Mdot
1 .5 0 r
.60616 .29784 Mdot
.628 .126 .941 r
.9203 .84812 Mdot
1 .5 0 r
.94757 .85496 Mdot
.61253 .30802 Mdot
.628 .126 .941 r
.74233 .3217 Mdot
.7487 .33188 Mdot
.7682 .38309 Mdot
.82629 .64287 Mdot
.82559 .67016 Mdot
.76782 .36244 Mdot
.76731 .40004 Mdot
.71933 .40688 Mdot
.73327 .36237 Mdot
.78694 .39301 Mdot
1 .5 0 r
.65034 .34849 Mdot
.67106 .33482 Mdot
.628 .126 .941 r
.77311 .37927 Mdot
.76635 .34843 Mdot
.73906 .34159 Mdot
.7719 .44416 Mdot
.69017 .36539 Mdot
1 .5 0 r
.65632 .33803 Mdot
.64248 .32429 Mdot
.628 .126 .941 r
.75819 .37216 Mdot
1 .5 0 r
.64178 .35157 Mdot
.628 .126 .941 r
.95 .844 Mdot
.825 .44384 Mdot
.77055 .37189 Mdot
.75741 .33085 Mdot
1 .5 0 r
.70839 .41293 Mdot
.628 .126 .941 r
.77584 .38872 Mdot
1 .5 0 r
.64626 .32709 Mdot
.628 .126 .941 r
.762 .37497 Mdot
.78222 .39892 Mdot
.85298 .73756 Mdot
.77495 .40569 Mdot
.75403 .40905 Mdot
1 .5 0 r
.69874 .42267 Mdot
.628 .126 .941 r
.79459 .39865 Mdot
.76053 .36095 Mdot
.78075 .3849 Mdot
.74668 .3472 Mdot
1 .5 0 r
.94536 .85013 Mdot
.96521 .85345 Mdot
.65531 .34672 Mdot
.628 .126 .941 r
.77819 .37752 Mdot
1 .5 0 r
.61396 .31578 Mdot
.628 .126 .941 r
.75758 .3329 Mdot
.74373 .31914 Mdot
.76345 .38074 Mdot
.74322 .35678 Mdot
1 .5 0 r
.90961 .71957 Mdot
.96928 .86674 Mdot
.89526 .74348 Mdot
.628 .126 .941 r
.94868 .82215 Mdot
1 .5 0 r
.61923 .33262 Mdot
.628 .126 .941 r
.74851 .37363 Mdot
.93414 .83574 Mdot
1 .5 0 r
.65252 .32899 Mdot
.68571 .3837 Mdot
.95363 .81842 Mdot
.628 .126 .941 r
.73875 .4417 Mdot
.80755 .42116 Mdot
1 .5 0 r
.65103 .31495 Mdot
.628 .126 .941 r
.70415 .44163 Mdot
1 .5 0 r
.63666 .33885 Mdot
.628 .126 .941 r
.75233 .37645 Mdot
.75031 .52711 Mdot
1 .5 0 r
.80293 .69147 Mdot
.628 .126 .941 r
.68951 .38652 Mdot
.75833 .36597 Mdot
.75833 .36597 Mdot
.78211 .63651 Mdot
1 .5 0 r
.83018 .62966 Mdot
.71492 .4857 Mdot
.64115 .31433 Mdot
.628 .126 .941 r
.77729 .38625 Mdot
1 .5 0 r
.65461 .30741 Mdot
.64044 .34166 Mdot
.628 .126 .941 r
.75615 .37927 Mdot
.77581 .37221 Mdot
1 .5 0 r
.67306 .36536 Mdot
.628 .126 .941 r
.66426 .4852 Mdot
.77492 .38921 Mdot
.78111 .38907 Mdot
.79351 .38881 Mdot
1 .5 0 r
.68363 .39909 Mdot
.66369 .32706 Mdot
.628 .126 .941 r
.76597 .37161 Mdot
.76597 .37161 Mdot
1 .5 0 r
.62906 .32699 Mdot
.628 .126 .941 r
.75849 .36804 Mdot
1 .5 0 r
.64872 .31993 Mdot
.66239 .32336 Mdot
.628 .126 .941 r
.78494 .3919 Mdot
1 .5 0 r
.61408 .31986 Mdot
.63434 .34385 Mdot
.628 .126 .941 r
.77747 .38834 Mdot
.79773 .41233 Mdot
1 .5 0 r
.63931 .40877 Mdot
.61936 .33672 Mdot
.628 .126 .941 r
.7154 .31266 Mdot
1 .5 0 r
.61896 .31601 Mdot
.8136 .59014 Mdot
.628 .126 .941 r
.96083 .84379 Mdot
1 .5 0 r
.61766 .31231 Mdot
.66579 .30545 Mdot
.67167 .35338 Mdot
.83158 .68591 Mdot
.81213 .57613 Mdot
.6503 .33603 Mdot
.628 .126 .941 r
.76614 .37369 Mdot
1 .5 0 r
.75784 .45592 Mdot
.86577 .59652 Mdot
.6563 .32554 Mdot
.628 .126 .941 r
.75118 .36656 Mdot
.9354 .86366 Mdot
.73398 .5 Mdot
1 .5 0 r
.74798 .45534 Mdot
.628 .126 .941 r
.70676 .30741 Mdot
1 .5 0 r
.65149 .33143 Mdot
.628 .126 .941 r
.76081 .34852 Mdot
1 .5 0 r
.65738 .3794 Mdot
.628 .126 .941 r
.76062 .33816 Mdot
.7738 .37933 Mdot
.75992 .36554 Mdot
1 .5 0 r
.65 .31736 Mdot
.628 .126 .941 r
.77911 .39622 Mdot
1 .5 0 r
.92516 .77374 Mdot
.87781 .69475 Mdot
.66239 .31708 Mdot
.70144 .4784 Mdot
.628 .126 .941 r
.75095 .3479 Mdot
.76375 .36836 Mdot
.76375 .36836 Mdot
1 .5 0 r
.68138 .3374 Mdot
.63738 .36782 Mdot
.80735 .50517 Mdot
.62288 .32291 Mdot
.628 .126 .941 r
.75208 .40183 Mdot
1 .5 0 r
.65648 .32964 Mdot
.65648 .32964 Mdot
.628 .126 .941 r
.88485 .72803 Mdot
1 .5 0 r
.93255 .75894 Mdot
.628 .126 .941 r
.82325 .68332 Mdot
1 .5 0 r
.65609 .30889 Mdot
.628 .126 .941 r
.93065 .85156 Mdot
.77141 .37401 Mdot
1 .5 0 r
.65498 .31555 Mdot
.63296 .39449 Mdot
.628 .126 .941 r
.76322 .39786 Mdot
.94323 .79286 Mdot
1 .5 0 r
.66028 .33245 Mdot
.628 .126 .941 r
.89317 .765 Mdot
.74623 .41444 Mdot
1 .5 0 r
.79021 .6996 Mdot
.67049 .34551 Mdot
.65017 .32145 Mdot
.64797 .33478 Mdot
.64797 .33478 Mdot
.64646 .32068 Mdot
.70653 .40994 Mdot
.628 .126 .941 r
.75292 .36821 Mdot
1 .5 0 r
.81136 .62959 Mdot
.628 .126 .941 r
.75824 .38514 Mdot
.75824 .38514 Mdot
1 .5 0 r
.64094 .35404 Mdot
.628 .126 .941 r
.94332 .83548 Mdot
1 .5 0 r
.65957 .35363 Mdot
.67742 .31164 Mdot
.66238 .30448 Mdot
.628 .126 .941 r
.95792 .87248 Mdot
1 .5 0 r
.80392 .49024 Mdot
.6677 .32141 Mdot
.628 .126 .941 r
.94147 .85137 Mdot
.96183 .87548 Mdot
1 .5 0 r
.67261 .31755 Mdot
.628 .126 .941 r
.92755 .83755 Mdot
1 .5 0 r
.67151 .32423 Mdot
.65757 .31038 Mdot
.65615 .36535 Mdot
.628 .126 .941 r
.75728 .38562 Mdot
.96429 .86445 Mdot
.93534 .84352 Mdot
1 .5 0 r
.64923 .32594 Mdot
.628 .126 .941 r
.93276 .76712 Mdot
1 .5 0 r
.80412 .48419 Mdot
.92487 .74278 Mdot
.628 .126 .941 r
.72171 .40476 Mdot
1 .5 0 r
.65304 .32876 Mdot
.67282 .32165 Mdot
.628 .126 .941 r
.96745 .87664 Mdot
.91999 .73851 Mdot
.96492 .86935 Mdot
.95343 .84443 Mdot
1 .5 0 r
.88973 .63654 Mdot
.67666 .31816 Mdot
.628 .126 .941 r
.73293 .38625 Mdot
1 .5 0 r
.66922 .31662 Mdot
.628 .126 .941 r
.95259 .83523 Mdot
.95923 .85597 Mdot
.73587 .40626 Mdot
.95828 .85476 Mdot
1 .5 0 r
.8218 .57759 Mdot
.628 .126 .941 r
.94021 .80096 Mdot
.95352 .84254 Mdot
.95225 .83887 Mdot
.92209 .74701 Mdot
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.567362 0.97619 1.05965 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.96078 .96078 Mdot
.71373 .72157 Mdot
.52941 .52549 Mdot
.13725 .14902 Mdot
.87843 .88235 Mdot
.11373 .1098 Mdot
.1098 .11373 Mdot
.77647 .78039 Mdot
.15294 .14902 Mdot
.13725 .12549 Mdot
.13333 .1451 Mdot
.1451 .13333 Mdot
.20784 .18824 Mdot
.17255 .15686 Mdot
.4902 .49804 Mdot
.1451 .13333 Mdot
.26275 .23137 Mdot
.23529 .21569 Mdot
.47451 .48235 Mdot
.89804 .82745 Mdot
1 .96863 Mdot
.13333 .12941 Mdot
.20784 .18824 Mdot
.24706 .20784 Mdot
.11373 .11765 Mdot
.3451 .16863 Mdot
.49804 .32941 Mdot
.65098 .53725 Mdot
.84314 .74902 Mdot
.94902 .89412 Mdot
.1451 .14118 Mdot
.18431 .16863 Mdot
.20392 .17647 Mdot
.20784 .20784 Mdot
.55294 .39216 Mdot
.41176 .14118 Mdot
.42353 .22745 Mdot
.36078 .2 Mdot
.38824 .25882 Mdot
.21569 .19608 Mdot
.21569 .20392 Mdot
.18824 .16863 Mdot
.22353 .20784 Mdot
.25098 .25098 Mdot
.52941 .17647 Mdot
.47843 .16863 Mdot
.41961 .19608 Mdot
.44706 .25882 Mdot
.33725 .17647 Mdot
.1451 .12941 Mdot
.14902 .11765 Mdot
.17647 .1451 Mdot
.24706 .23529 Mdot
1 .93725 Mdot
.58824 .18824 Mdot
.51373 .18039 Mdot
.45882 .22353 Mdot
.43137 .21569 Mdot
.43529 .26667 Mdot
.15686 .13725 Mdot
.21961 .19216 Mdot
.18039 .14902 Mdot
.26667 .26667 Mdot
1 .96471 Mdot
.77647 .36078 Mdot
.61176 .25882 Mdot
.45098 .2 Mdot
.4549 .25882 Mdot
.42745 .18824 Mdot
.18039 .14902 Mdot
.25098 .20784 Mdot
.14902 .11765 Mdot
.21961 .2 Mdot
.50196 .50196 Mdot
.73725 .32157 Mdot
.58039 .21176 Mdot
.4549 .18431 Mdot
.51765 .32157 Mdot
.46275 .18431 Mdot
.21176 .11765 Mdot
.18824 .15294 Mdot
.19608 .16471 Mdot
.18431 .16471 Mdot
.16471 .16078 Mdot
.82353 .72549 Mdot
.65882 .25098 Mdot
.53725 .16863 Mdot
.54118 .28627 Mdot
.54118 .34118 Mdot
.50588 .18824 Mdot
.23137 .07059 Mdot
.16471 .13725 Mdot
.23922 .21176 Mdot
.25882 .24706 Mdot
.14118 .13725 Mdot
.52941 .44314 Mdot
.37255 .12549 Mdot
.57647 .18824 Mdot
.5451 .17255 Mdot
.77255 .5451 Mdot
.64706 .43922 Mdot
.52549 .17255 Mdot
.28235 .09804 Mdot
.16863 .14118 Mdot
.27843 .25098 Mdot
.18431 .18039 Mdot
.15294 .10588 Mdot
.2902 .17255 Mdot
.96078 .92549 Mdot
.63922 .23922 Mdot
.54902 .16471 Mdot
.55686 .2 Mdot
.58039 .38039 Mdot
.49804 .2549 Mdot
.67059 .27059 Mdot
.23529 .11765 Mdot
.17255 .14118 Mdot
.22353 .21176 Mdot
.16863 .14902 Mdot
.29804 .12157 Mdot
.33725 .22353 Mdot
.8902 .82353 Mdot
.62353 .22353 Mdot
.56471 .16471 Mdot
.58824 .15686 Mdot
.55294 .33725 Mdot
.71373 .49412 Mdot
.53725 .2 Mdot
.5098 .2549 Mdot
.2 .13725 Mdot
.18431 .1451 Mdot
.18039 .14902 Mdot
.20392 .01961 Mdot
.67059 .51373 Mdot
.35294 .24706 Mdot
.88627 .83529 Mdot
.63137 .21961 Mdot
.59216 .16078 Mdot
.64706 .18039 Mdot
.78431 .55294 Mdot
.83137 .61569 Mdot
.67059 .41176 Mdot
.47451 .24706 Mdot
.27059 .15686 Mdot
.2 .13725 Mdot
.19216 .1098 Mdot
.33725 .10196 Mdot
.63529 .47843 Mdot
.61569 .50196 Mdot
.34902 .23529 Mdot
1 .97255 Mdot
.63137 .19216 Mdot
.64314 .17647 Mdot
.67059 .2 Mdot
.80392 .57255 Mdot
.41961 .21176 Mdot
.68627 .47059 Mdot
.8 .62745 Mdot
.25098 .12549 Mdot
.21961 .11765 Mdot
.26275 .08235 Mdot
.42745 .18039 Mdot
.66275 .52549 Mdot
.61569 .5098 Mdot
.41569 .29412 Mdot
.76078 .7098 Mdot
.53333 .19608 Mdot
.72549 .25882 Mdot
.66275 .19216 Mdot
.64314 .19216 Mdot
.83529 .63922 Mdot
.67059 .43922 Mdot
.58431 .40392 Mdot
.52157 .39608 Mdot
.37647 .18431 Mdot
.28235 .09412 Mdot
.49412 .18039 Mdot
.46667 .27451 Mdot
.56471 .47451 Mdot
.6 .49412 Mdot
.50588 .40392 Mdot
.63137 .56078 Mdot
.44706 .16863 Mdot
.67451 .23137 Mdot
.90196 .44706 Mdot
.76471 .27451 Mdot
.90588 .65098 Mdot
.48235 .26667 Mdot
.93333 .76078 Mdot
.61569 .50588 Mdot
.59216 .40784 Mdot
.38431 .20392 Mdot
.61176 .2549 Mdot
.63922 .44314 Mdot
.72549 .60392 Mdot
.58824 .48627 Mdot
.64706 .54118 Mdot
.39608 .29412 Mdot
.78824 .74902 Mdot
.60784 .21569 Mdot
.73725 .38039 Mdot
.83922 .38824 Mdot
.83922 .34902 Mdot
.9451 .69412 Mdot
.57647 .35294 Mdot
.76471 .61569 Mdot
.66275 .54902 Mdot
.39608 .2549 Mdot
.56471 .38824 Mdot
.6549 .29804 Mdot
.62745 .41569 Mdot
.72549 .6 Mdot
.54902 .38824 Mdot
.61961 .51765 Mdot
.62745 .52941 Mdot
.34118 .23922 Mdot
.98039 .9098 Mdot
.71373 .2549 Mdot
.92157 .57255 Mdot
.67843 .25098 Mdot
.8549 .38824 Mdot
.98431 .74902 Mdot
.54118 .27843 Mdot
.72941 .60784 Mdot
1 .88627 Mdot
1 .89804 Mdot
.84706 .64314 Mdot
.63922 .32157 Mdot
.67059 .44314 Mdot
.68627 .5451 Mdot
.49804 .32941 Mdot
.61569 .51373 Mdot
.65882 .55294 Mdot
.27059 .17255 Mdot
.91373 .87843 Mdot
.64314 .18431 Mdot
.85098 .54902 Mdot
.8902 .59216 Mdot
.67059 .25882 Mdot
.82745 .41961 Mdot
1 .85098 Mdot
.95294 .78431 Mdot
.85098 .73333 Mdot
.83529 .71765 Mdot
.81961 .67059 Mdot
.53333 .22353 Mdot
.67451 .37647 Mdot
.47843 .2549 Mdot
.51373 .32549 Mdot
.53333 .35686 Mdot
.64314 .56078 Mdot
.63922 .5451 Mdot
.23922 .13333 Mdot
.92941 .89412 Mdot
.5451 .54118 Mdot
.38431 .38824 Mdot
.56078 .18824 Mdot
.69412 .26667 Mdot
.56863 .29412 Mdot
.84314 .56471 Mdot
.74118 .29412 Mdot
.77647 .43137 Mdot
.67451 .38431 Mdot
.75294 .63529 Mdot
.95686 .75686 Mdot
.50588 .3451 Mdot
.86275 .6549 Mdot
.47451 .16471 Mdot
.66667 .33725 Mdot
.64314 .4902 Mdot
.52157 .3098 Mdot
.63529 .4902 Mdot
.63137 .58431 Mdot
.63529 .54118 Mdot
.20784 .12549 Mdot
.93725 .90196 Mdot
.18431 .16863 Mdot
.21569 .20392 Mdot
.83137 .83137 Mdot
.74902 .25098 Mdot
.93725 .70196 Mdot
1 .86667 Mdot
.83529 .53333 Mdot
.77647 .3451 Mdot
.57647 .2549 Mdot
.69804 .38824 Mdot
.89804 .74118 Mdot
.91765 .58431 Mdot
.98431 .79216 Mdot
.90196 .66667 Mdot
.48235 .18039 Mdot
.53333 .21569 Mdot
.55686 .43529 Mdot
.5098 .2902 Mdot
.61961 .47059 Mdot
.60392 .58824 Mdot
.61569 .5451 Mdot
.31373 .22353 Mdot
.66275 .60392 Mdot
.11373 .1098 Mdot
.24706 .21569 Mdot
.23137 .21961 Mdot
.86275 .76863 Mdot
.73333 .23529 Mdot
.98431 .84314 Mdot
.95686 .84706 Mdot
.66667 .3098 Mdot
.94902 .49412 Mdot
.61176 .26667 Mdot
.81569 .4902 Mdot
.86667 .68627 Mdot
.7451 .33333 Mdot
.9098 .67059 Mdot
.77647 .53725 Mdot
.56078 .25882 Mdot
.48235 .17255 Mdot
.58431 .47843 Mdot
.50196 .23529 Mdot
.56471 .41176 Mdot
.47843 .48235 Mdot
.61961 .56863 Mdot
.52941 .41176 Mdot
.22745 .15294 Mdot
.71373 .71765 Mdot
.27059 .25098 Mdot
.30196 .26667 Mdot
.1098 .1098 Mdot
.66275 .23529 Mdot
.6 .27059 Mdot
.98431 .85098 Mdot
.72157 .59608 Mdot
.8 .28627 Mdot
.95294 .48627 Mdot
.71373 .29804 Mdot
.80784 .52941 Mdot
.78039 .43922 Mdot
.86667 .49804 Mdot
.92157 .62745 Mdot
.82745 .56863 Mdot
.69412 .30196 Mdot
.81569 .63922 Mdot
.47451 .27059 Mdot
.5451 .22353 Mdot
.65098 .60784 Mdot
.42353 .41961 Mdot
.58039 .52157 Mdot
.51373 .38039 Mdot
.19216 .12157 Mdot
.12157 .12157 Mdot
.21176 .18039 Mdot
.21961 .17647 Mdot
.15294 .14118 Mdot
.59608 .21176 Mdot
.65882 .35294 Mdot
.83922 .68627 Mdot
.78431 .67059 Mdot
.80784 .32157 Mdot
.83137 .32549 Mdot
.9451 .51373 Mdot
.63922 .34902 Mdot
1 .78431 Mdot
.79608 .38824 Mdot
.64314 .29412 Mdot
.58431 .27843 Mdot
.60392 .25098 Mdot
.41176 .11765 Mdot
.41176 .24314 Mdot
.55294 .18824 Mdot
.40784 .27059 Mdot
.40392 .41569 Mdot
.52549 .46667 Mdot
.46667 .33725 Mdot
.4549 .3451 Mdot
.1098 .09804 Mdot
.22353 .20392 Mdot
.27843 .23529 Mdot
.27059 .2549 Mdot
.46667 .27843 Mdot
.6 .22353 Mdot
.76863 .60392 Mdot
.94902 .79216 Mdot
.64314 .4 Mdot
.81569 .30196 Mdot
.81569 .32157 Mdot
.74118 .47843 Mdot
.69804 .46667 Mdot
.75686 .29804 Mdot
.6902 .42353 Mdot
.69412 .34118 Mdot
1 .75686 Mdot
.59608 .16078 Mdot
.70588 .56471 Mdot
.54118 .19608 Mdot
.53333 .22353 Mdot
.49804 .50196 Mdot
.52549 .41569 Mdot
.4902 .40784 Mdot
.43922 .31765 Mdot
.34118 .30196 Mdot
.13333 .10196 Mdot
.21176 .18431 Mdot
.21961 .18431 Mdot
.35686 .36471 Mdot
.73333 .24706 Mdot
.83529 .65098 Mdot
.86275 .66667 Mdot
.8902 .77255 Mdot
.73333 .42353 Mdot
.83137 .28627 Mdot
.64706 .32941 Mdot
.70196 .60392 Mdot
.76078 .36471 Mdot
.70588 .41176 Mdot
.74118 .46275 Mdot
.61961 .38431 Mdot
.62353 .20784 Mdot
.47843 .13333 Mdot
.64706 .45098 Mdot
.55686 .18431 Mdot
.3451 .18824 Mdot
.43137 .38824 Mdot
.4549 .33725 Mdot
.49412 .40784 Mdot
.38039 .2902 Mdot
.18039 .15294 Mdot
.18431 .16471 Mdot
.20392 .17255 Mdot
.28627 .27451 Mdot
.56078 .41176 Mdot
.7451 .26275 Mdot
.90196 .73333 Mdot
.82353 .67451 Mdot
.83922 .70588 Mdot
.94118 .55686 Mdot
.78431 .33333 Mdot
.73333 .61569 Mdot
.63137 .53333 Mdot
.74118 .28235 Mdot
.63137 .4549 Mdot
.68627 .4902 Mdot
.57647 .34118 Mdot
.66275 .18824 Mdot
.52941 .26275 Mdot
.41569 .16863 Mdot
.4902 .18431 Mdot
.5451 .47843 Mdot
.6902 .58431 Mdot
.38431 .26275 Mdot
.43922 .35686 Mdot
.50588 .45098 Mdot
.17647 .14118 Mdot
.15294 .12549 Mdot
.15686 .12157 Mdot
.14118 .1451 Mdot
.63529 .24706 Mdot
.50196 .19216 Mdot
.6902 .5098 Mdot
.94118 .8 Mdot
.8 .68627 Mdot
.8 .28627 Mdot
.59216 .37647 Mdot
.63137 .58039 Mdot
.6902 .53333 Mdot
.74118 .28627 Mdot
.54902 .45882 Mdot
.58824 .46275 Mdot
.72157 .40784 Mdot
.66275 .21176 Mdot
.9098 .72157 Mdot
.5098 .21961 Mdot
.47451 .22353 Mdot
.67843 .64706 Mdot
.38039 .21176 Mdot
.52157 .38431 Mdot
.36471 .26667 Mdot
.13333 .09412 Mdot
.15294 .11765 Mdot
.22353 .19608 Mdot
.21961 .20392 Mdot
.81176 .80784 Mdot
.69412 .21176 Mdot
.9098 .74118 Mdot
.95294 .78824 Mdot
.82745 .67843 Mdot
1 .83922 Mdot
.72941 .31373 Mdot
.63529 .56863 Mdot
.61569 .57255 Mdot
.81961 .56471 Mdot
.66667 .28235 Mdot
.53725 .46667 Mdot
.52941 .45098 Mdot
.70196 .3098 Mdot
.63529 .25882 Mdot
.75294 .61961 Mdot
.5451 .24314 Mdot
.57647 .35686 Mdot
.54902 .53725 Mdot
.59608 .37647 Mdot
.49804 .32157 Mdot
.52549 .40392 Mdot
.1451 .11765 Mdot
.16471 .12941 Mdot
.19608 .16863 Mdot
.18824 .18431 Mdot
.44314 .21569 Mdot
.63137 .24706 Mdot
.96471 .79216 Mdot
.83922 .67451 Mdot
.83529 .70196 Mdot
.67451 .3098 Mdot
.65098 .45882 Mdot
.59216 .54902 Mdot
.60784 .56471 Mdot
.76471 .40392 Mdot
.56863 .29804 Mdot
.52941 .4902 Mdot
.61176 .4549 Mdot
.61176 .27843 Mdot
.60784 .31765 Mdot
.74118 .61176 Mdot
.49412 .2 Mdot
.58824 .38039 Mdot
.23922 .19608 Mdot
.5451 .31373 Mdot
.55294 .36471 Mdot
.38824 .28235 Mdot
.19216 .16471 Mdot
.15686 .12157 Mdot
.24314 .22353 Mdot
.12549 .10588 Mdot
.57647 .4549 Mdot
.7451 .25882 Mdot
.83922 .67451 Mdot
.61176 .43922 Mdot
.80392 .6549 Mdot
.89412 .70588 Mdot
.66667 .47059 Mdot
.63137 .58039 Mdot
.59608 .55294 Mdot
.81176 .59608 Mdot
.69804 .31373 Mdot
.54902 .50588 Mdot
.56078 .46275 Mdot
.54118 .24314 Mdot
.63137 .43529 Mdot
.83922 .7451 Mdot
.40392 .18431 Mdot
.4902 .19608 Mdot
.69412 .64706 Mdot
.54902 .37647 Mdot
.53725 .31373 Mdot
.59608 .48235 Mdot
.1451 .10588 Mdot
.26667 .23137 Mdot
.15294 .13333 Mdot
.17255 .14118 Mdot
.85882 .79216 Mdot
.68235 .23137 Mdot
.5451 .21569 Mdot
.70588 .51765 Mdot
.71373 .52941 Mdot
.92549 .8 Mdot
.64706 .33333 Mdot
.65882 .60392 Mdot
.61961 .57647 Mdot
.61961 .56078 Mdot
.72941 .37255 Mdot
.63137 .43529 Mdot
.52941 .4902 Mdot
.67451 .38824 Mdot
.57647 .45882 Mdot
.49804 .4 Mdot
.79216 .69804 Mdot
.43529 .20392 Mdot
.37647 .18431 Mdot
.24314 .2 Mdot
.59608 .42745 Mdot
.36863 .19216 Mdot
.77647 .70588 Mdot
.18039 .14902 Mdot
.24314 .2 Mdot
.15686 .12157 Mdot
.15686 .08627 Mdot
.8549 .79608 Mdot
.67843 .20784 Mdot
.65882 .27843 Mdot
.77255 .58431 Mdot
.76471 .58431 Mdot
.7451 .62353 Mdot
.58431 .32157 Mdot
.60392 .55294 Mdot
.68235 .63137 Mdot
.62353 .56863 Mdot
.76863 .4902 Mdot
.57255 .32549 Mdot
.54118 .49412 Mdot
.61176 .31765 Mdot
.54902 .46667 Mdot
.53333 .46275 Mdot
.74902 .67451 Mdot
.72941 .58824 Mdot
.36863 .20784 Mdot
.37255 .34902 Mdot
.47843 .36471 Mdot
.51765 .38039 Mdot
.79216 .72549 Mdot
.18824 .15294 Mdot
.32941 .27843 Mdot
.21569 .17647 Mdot
.18824 .11765 Mdot
.55686 .43922 Mdot
.84314 .73333 Mdot
.77255 .23529 Mdot
.38431 .17647 Mdot
.76471 .57647 Mdot
.75294 .58824 Mdot
.93725 .77647 Mdot
.68627 .56471 Mdot
.63922 .58824 Mdot
.67059 .63137 Mdot
.61569 .55686 Mdot
.7098 .36863 Mdot
.65098 .48235 Mdot
.57255 .47451 Mdot
.49412 .25098 Mdot
.52157 .47843 Mdot
.53333 .47843 Mdot
.67843 .60784 Mdot
.80392 .70196 Mdot
.2549 .16863 Mdot
.42353 .4 Mdot
.39216 .30196 Mdot
.64706 .54118 Mdot
.85882 .81961 Mdot
.17255 .13333 Mdot
.24706 .19216 Mdot
.2 .14902 Mdot
.62353 .53725 Mdot
.55686 .41569 Mdot
1 .96863 Mdot
.75294 .22745 Mdot
.56471 .22353 Mdot
.87059 .68235 Mdot
.6902 .53333 Mdot
.85882 .72549 Mdot
.68235 .51765 Mdot
.60784 .56471 Mdot
.78431 .7451 Mdot
.63137 .58824 Mdot
.76078 .56078 Mdot
.59608 .2902 Mdot
.56863 .48235 Mdot
.55686 .2902 Mdot
.54118 .49412 Mdot
.50588 .45882 Mdot
.54118 .48627 Mdot
.72549 .6549 Mdot
.77255 .6902 Mdot
.56078 .57647 Mdot
.48627 .38039 Mdot
.34902 .2549 Mdot
.8549 .81569 Mdot
.43137 .40784 Mdot
.20784 .15294 Mdot
.19216 .13333 Mdot
.46275 .40392 Mdot
.57255 .43137 Mdot
.5451 .43922 Mdot
.68627 .53725 Mdot
.75686 .21961 Mdot
.77647 .47059 Mdot
.87843 .68235 Mdot
.9098 .76863 Mdot
1 .87451 Mdot
.37647 .29412 Mdot
.59608 .55294 Mdot
.7098 .67059 Mdot
.61961 .58431 Mdot
.78824 .57255 Mdot
.59216 .30196 Mdot
.62745 .46667 Mdot
.57647 .4 Mdot
.52157 .47451 Mdot
.52157 .47451 Mdot
.52549 .47059 Mdot
.56863 .51373 Mdot
.83137 .76863 Mdot
.36863 .37647 Mdot
.57255 .45882 Mdot
.53725 .44706 Mdot
.87451 .84706 Mdot
.73725 .71765 Mdot
.18431 .13725 Mdot
.21961 .16863 Mdot
.42353 .35686 Mdot
.64314 .50196 Mdot
.56471 .46667 Mdot
.99216 .98039 Mdot
.68627 .18824 Mdot
.78039 .25098 Mdot
.84706 .51765 Mdot
.71373 .57647 Mdot
.93725 .67059 Mdot
.72549 .56471 Mdot
.61569 .57647 Mdot
.61961 .57647 Mdot
.82353 .78431 Mdot
.63529 .57647 Mdot
.73725 .34118 Mdot
.63137 .49412 Mdot
.56471 .28235 Mdot
.52941 .48235 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.53333 .48235 Mdot
.57647 .51765 Mdot
.77647 .78039 Mdot
.66667 .54902 Mdot
.5451 .46667 Mdot
.74118 .68627 Mdot
.8902 .89804 Mdot
.71373 .69804 Mdot
.56471 .52549 Mdot
.64314 .58039 Mdot
.49804 .38824 Mdot
.54902 .47451 Mdot
.3451 .26667 Mdot
.53333 .23529 Mdot
.77647 .25098 Mdot
.6902 .17647 Mdot
.93333 .7451 Mdot
.75686 .59608 Mdot
.75686 .45098 Mdot
.49804 .4549 Mdot
.61961 .56863 Mdot
.62745 .58431 Mdot
.6902 .6549 Mdot
.73725 .57647 Mdot
.6 .2549 Mdot
.76078 .47843 Mdot
.57647 .48235 Mdot
.52157 .48235 Mdot
.52941 .48235 Mdot
.52549 .47843 Mdot
.52157 .47843 Mdot
.58824 .52941 Mdot
.42353 .44314 Mdot
.8902 .74118 Mdot
.76471 .70196 Mdot
.86667 .8549 Mdot
.91765 .92549 Mdot
.8549 .8549 Mdot
.83529 .78431 Mdot
.35294 .24314 Mdot
.51373 .42745 Mdot
.6 .53333 Mdot
.4549 .43137 Mdot
.67451 .2 Mdot
.69804 .21176 Mdot
.78824 .27843 Mdot
.99216 .82353 Mdot
.70588 .38039 Mdot
.69804 .4902 Mdot
.44706 .40392 Mdot
.62745 .58431 Mdot
.61961 .57647 Mdot
.71373 .67451 Mdot
.80392 .55686 Mdot
.63922 .32549 Mdot
.62745 .31373 Mdot
.52549 .48627 Mdot
.5451 .50588 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.54902 .49412 Mdot
.58039 .53725 Mdot
.47451 .44314 Mdot
.83137 .76078 Mdot
.78431 .7451 Mdot
.9098 .9098 Mdot
.88235 .88627 Mdot
.90588 .90196 Mdot
.75686 .69804 Mdot
.47843 .33725 Mdot
.40784 .37647 Mdot
.6 .54902 Mdot
.81569 .72157 Mdot
.74118 .24706 Mdot
.78824 .2549 Mdot
.7451 .2902 Mdot
.52941 .2549 Mdot
.79216 .28627 Mdot
.61569 .54118 Mdot
.41569 .37255 Mdot
.61569 .57647 Mdot
.63922 .6 Mdot
.75686 .70588 Mdot
.7098 .36863 Mdot
.69804 .34118 Mdot
.67843 .46275 Mdot
.55686 .50196 Mdot
.52941 .4902 Mdot
.53725 .4902 Mdot
.53333 .4902 Mdot
.56471 .50196 Mdot
.76471 .77255 Mdot
.93333 .83922 Mdot
.85882 .82745 Mdot
.82353 .8 Mdot
.88627 .8902 Mdot
.87451 .8902 Mdot
.8549 .83137 Mdot
.49412 .40392 Mdot
.45882 .31765 Mdot
.41569 .39216 Mdot
.67451 .64706 Mdot
.56471 .23529 Mdot
.67843 .22745 Mdot
.78431 .24706 Mdot
.6549 .23922 Mdot
1 .65098 Mdot
.63529 .27843 Mdot
.60392 .56078 Mdot
.41176 .36863 Mdot
.61569 .57255 Mdot
.62353 .58039 Mdot
.80784 .72549 Mdot
.77255 .39608 Mdot
.71765 .31373 Mdot
.66275 .47451 Mdot
.56863 .49804 Mdot
.54118 .49804 Mdot
.53725 .49804 Mdot
.56078 .50588 Mdot
.57255 .5098 Mdot
.87843 .87843 Mdot
.66667 .54118 Mdot
.91765 .87843 Mdot
.8549 .85098 Mdot
.87059 .88235 Mdot
.88235 .89804 Mdot
.82353 .78039 Mdot
.50588 .38824 Mdot
.49804 .38824 Mdot
.43922 .41176 Mdot
.66275 .67451 Mdot
.66275 .23529 Mdot
.83529 .44314 Mdot
.7451 .25098 Mdot
.73725 .27843 Mdot
.83137 .35686 Mdot
.68235 .45098 Mdot
.60392 .56078 Mdot
.53725 .49804 Mdot
.63137 .58824 Mdot
.63922 .59608 Mdot
.92157 .76863 Mdot
.85882 .50196 Mdot
.75294 .34902 Mdot
.68627 .44706 Mdot
.63137 .51765 Mdot
.57647 .50588 Mdot
.55686 .50196 Mdot
.59608 .52549 Mdot
.78039 .74118 Mdot
.61176 .58431 Mdot
.64706 .53725 Mdot
.94118 .87059 Mdot
.8902 .87451 Mdot
.88235 .8902 Mdot
.87451 .88235 Mdot
.8 .74902 Mdot
.51373 .41569 Mdot
.4549 .35294 Mdot
.46275 .42353 Mdot
.97255 .97647 Mdot
.66667 .2 Mdot
.6902 .32941 Mdot
.69412 .27059 Mdot
.76863 .27059 Mdot
.81569 .28627 Mdot
.67451 .5451 Mdot
.60392 .56078 Mdot
.61569 .58824 Mdot
.63922 .58431 Mdot
.63529 .59216 Mdot
.95686 .70196 Mdot
.98039 .62353 Mdot
.82745 .44314 Mdot
.62353 .29412 Mdot
.67843 .47843 Mdot
.60784 .50588 Mdot
.61176 .54902 Mdot
.58039 .51373 Mdot
.84706 .81569 Mdot
.62745 .60392 Mdot
.41961 .27451 Mdot
.95686 .83529 Mdot
.95294 .9098 Mdot
.86275 .87843 Mdot
.86275 .87059 Mdot
.82745 .77647 Mdot
.61176 .54902 Mdot
.46275 .38431 Mdot
.45882 .40392 Mdot
.89804 .84314 Mdot
.72157 .25098 Mdot
.70588 .39216 Mdot
.56078 .23137 Mdot
.77647 .26667 Mdot
.78431 .27059 Mdot
.61961 .5451 Mdot
.61961 .56471 Mdot
.62745 .6 Mdot
.5451 .4902 Mdot
.64314 .58824 Mdot
.78431 .40392 Mdot
.83137 .45882 Mdot
.90588 .50588 Mdot
.64706 .2549 Mdot
.69804 .40784 Mdot
.65882 .50196 Mdot
.60392 .53333 Mdot
.77255 .73725 Mdot
.63137 .60784 Mdot
.63137 .6 Mdot
.44314 .27843 Mdot
.78824 .6549 Mdot
.94118 .86275 Mdot
.8902 .86275 Mdot
.8549 .84706 Mdot
.82353 .78431 Mdot
.66275 .61961 Mdot
.64314 .58824 Mdot
.47059 .43529 Mdot
.45098 .32157 Mdot
.72549 .25882 Mdot
.58824 .36471 Mdot
.67451 .47059 Mdot
.77647 .26667 Mdot
.7451 .29804 Mdot
.58824 .5451 Mdot
.6 .55686 Mdot
.61569 .58039 Mdot
.39608 .34118 Mdot
.65882 .56471 Mdot
.85882 .37255 Mdot
.66275 .24706 Mdot
.9098 .5098 Mdot
.77255 .36471 Mdot
.65098 .26667 Mdot
.71373 .47843 Mdot
.62745 .56471 Mdot
.77647 .75686 Mdot
.62745 .60784 Mdot
.62353 .59216 Mdot
.22745 .11765 Mdot
.62745 .49804 Mdot
.91765 .77255 Mdot
.92549 .8549 Mdot
.87451 .85098 Mdot
.83529 .81176 Mdot
.77255 .7451 Mdot
.82745 .79216 Mdot
.73333 .72157 Mdot
.49804 .26667 Mdot
.7098 .26667 Mdot
.8902 .73333 Mdot
.90196 .76078 Mdot
.79216 .26667 Mdot
.61961 .2902 Mdot
.60392 .56078 Mdot
.61961 .57647 Mdot
.61961 .58431 Mdot
.29412 .25098 Mdot
.71765 .53725 Mdot
.83922 .30196 Mdot
.65098 .19608 Mdot
.87843 .46275 Mdot
.8902 .43922 Mdot
.70196 .27451 Mdot
.58039 .33333 Mdot
.80784 .76471 Mdot
.63137 .61569 Mdot
.62745 .60392 Mdot
.66667 .62745 Mdot
.29412 .23922 Mdot
.87451 .76471 Mdot
.73333 .58431 Mdot
.92549 .81569 Mdot
.93725 .86667 Mdot
.85098 .81569 Mdot
.77255 .74902 Mdot
.8 .77647 Mdot
.69412 .70196 Mdot
.57647 .26667 Mdot
.65882 .24706 Mdot
.94118 .81569 Mdot
.63529 .47451 Mdot
.78431 .25098 Mdot
.71765 .50196 Mdot
.60392 .56078 Mdot
.62745 .58431 Mdot
.61176 .56863 Mdot
.36863 .32549 Mdot
.86275 .56078 Mdot
.8549 .30588 Mdot
.79608 .2902 Mdot
.75686 .31765 Mdot
.8549 .40784 Mdot
.82745 .41961 Mdot
.66275 .4549 Mdot
.72941 .68627 Mdot
.64314 .61961 Mdot
.63529 .60784 Mdot
.72157 .68627 Mdot
.84706 .82745 Mdot
.94902 .90588 Mdot
.69804 .60392 Mdot
.78824 .61569 Mdot
1 .8549 Mdot
.89412 .83137 Mdot
.80784 .77647 Mdot
.89804 .87059 Mdot
.64706 .65882 Mdot
.62745 .21569 Mdot
.69412 .38039 Mdot
.21569 .10196 Mdot
.57255 .30588 Mdot
.76471 .26667 Mdot
.61569 .54118 Mdot
.6 .55686 Mdot
.61176 .57647 Mdot
.6 .56471 Mdot
.43529 .37255 Mdot
.78824 .31373 Mdot
.83529 .29412 Mdot
.81961 .29804 Mdot
.67451 .21961 Mdot
.81569 .36863 Mdot
.87451 .46667 Mdot
.92549 .83922 Mdot
.63137 .6 Mdot
.64314 .61961 Mdot
.61569 .59216 Mdot
.17255 .14902 Mdot
.90196 .89804 Mdot
.93333 .89412 Mdot
.91765 .82745 Mdot
.58431 .39608 Mdot
.89412 .73725 Mdot
.93725 .84314 Mdot
.8 .76471 Mdot
.94902 .92157 Mdot
.90588 .86275 Mdot
.74118 .28235 Mdot
.55294 .34118 Mdot
.97647 .87059 Mdot
.65882 .29804 Mdot
.65882 .28627 Mdot
.6 .55686 Mdot
.60784 .56471 Mdot
.59608 .55294 Mdot
.60784 .57255 Mdot
.54902 .36471 Mdot
.72549 .27059 Mdot
.81961 .29412 Mdot
.83922 .30588 Mdot
.68235 .18824 Mdot
.80784 .39608 Mdot
.72941 .35686 Mdot
.64706 .59608 Mdot
.62353 .6 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.15686 .14118 Mdot
.92549 .89412 Mdot
.94118 .89804 Mdot
.96078 .9098 Mdot
.7451 .61569 Mdot
.67059 .45098 Mdot
.92549 .76471 Mdot
.87843 .80784 Mdot
.51765 .51373 Mdot
.60392 .41176 Mdot
.69804 .2902 Mdot
.82353 .68627 Mdot
.6549 .45098 Mdot
.70196 .23922 Mdot
.58039 .46667 Mdot
.60784 .56471 Mdot
.6 .55686 Mdot
.60784 .57255 Mdot
.61961 .57647 Mdot
.75686 .30588 Mdot
.60392 .23922 Mdot
.81176 .30196 Mdot
.82745 .28627 Mdot
.74902 .2549 Mdot
.81176 .38039 Mdot
.56471 .38039 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.61961 .59216 Mdot
.59608 .57647 Mdot
.96471 .9451 Mdot
.92157 .82353 Mdot
.93333 .90588 Mdot
.94902 .91765 Mdot
.92157 .78431 Mdot
.51765 .28235 Mdot
.8902 .81176 Mdot
.58039 .51373 Mdot
.97255 .98039 Mdot
.6902 .28235 Mdot
.68627 .41176 Mdot
.84314 .68627 Mdot
.90196 .60392 Mdot
.64706 .29412 Mdot
.6 .55686 Mdot
.61961 .56863 Mdot
.60784 .56471 Mdot
.61176 .56863 Mdot
.80392 .55686 Mdot
.62353 .2902 Mdot
.57647 .27451 Mdot
.8 .3098 Mdot
.83529 .28627 Mdot
.78039 .25882 Mdot
.68627 .26275 Mdot
.63137 .58431 Mdot
.61569 .59216 Mdot
.60784 .58824 Mdot
.61961 .60784 Mdot
.16471 .14118 Mdot
.97647 .87451 Mdot
.91373 .78431 Mdot
.92549 .91765 Mdot
.95686 .91373 Mdot
.97255 .8902 Mdot
.48627 .32941 Mdot
.64314 .5451 Mdot
.48627 .4902 Mdot
.33333 .25882 Mdot
.70196 .28627 Mdot
.55294 .28627 Mdot
.90588 .67451 Mdot
.63529 .16471 Mdot
.62745 .51373 Mdot
.60784 .55294 Mdot
.61569 .57255 Mdot
.61569 .57255 Mdot
.64706 .57647 Mdot
.80784 .30196 Mdot
.94118 .80392 Mdot
.58431 .29412 Mdot
.8 .32157 Mdot
.85098 .28235 Mdot
.81961 .28235 Mdot
.56863 .35294 Mdot
.60392 .58039 Mdot
.61176 .59216 Mdot
.62353 .60392 Mdot
.56863 .54118 Mdot
.98824 .92549 Mdot
.69804 .50588 Mdot
.96471 .89804 Mdot
.38431 .36471 Mdot
.91765 .89804 Mdot
.97255 .87059 Mdot
.90196 .81176 Mdot
.88235 .82745 Mdot
.97647 .98431 Mdot
.61176 .25882 Mdot
.58824 .23529 Mdot
.52157 .16471 Mdot
.55686 .16471 Mdot
.61961 .34118 Mdot
.31765 .26275 Mdot
.61961 .56471 Mdot
.60784 .57255 Mdot
.61961 .56471 Mdot
.7451 .32157 Mdot
.63137 .36471 Mdot
.9451 .84314 Mdot
.57255 .29804 Mdot
.83529 .30196 Mdot
.8549 .26667 Mdot
.74902 .34118 Mdot
.60784 .58431 Mdot
.62353 .60392 Mdot
.60392 .59216 Mdot
.6549 .63529 Mdot
.1098 .06275 Mdot
.56471 .36471 Mdot
.81176 .69412 Mdot
.59608 .57647 Mdot
.65882 .62745 Mdot
.9098 .8902 Mdot
.72549 .60392 Mdot
.57647 .52157 Mdot
.66667 .68627 Mdot
.41569 .3098 Mdot
.62353 .23529 Mdot
.59216 .16471 Mdot
.52549 .15294 Mdot
.74118 .28627 Mdot
.63922 .56863 Mdot
.6 .5451 Mdot
.61961 .57647 Mdot
.61569 .57255 Mdot
.78431 .53725 Mdot
.81176 .31373 Mdot
.95294 .81569 Mdot
.93725 .82745 Mdot
.66667 .29804 Mdot
.86275 .27451 Mdot
.82353 .27451 Mdot
.65098 .57255 Mdot
.62353 .60392 Mdot
.62745 .60392 Mdot
.61569 .60392 Mdot
.20392 .16471 Mdot
.51373 .34118 Mdot
.94902 .76471 Mdot
.10588 .06667 Mdot
.87451 .8549 Mdot
.52941 .5098 Mdot
.99608 .88627 Mdot
.52941 .48235 Mdot
.8549 .84706 Mdot
.77647 .76471 Mdot
.61961 .30196 Mdot
.73725 .26275 Mdot
.76078 .30196 Mdot
.79216 .28235 Mdot
.61961 .52549 Mdot
.29412 .23922 Mdot
.62353 .58039 Mdot
.60784 .57255 Mdot
.69412 .51765 Mdot
.83922 .27843 Mdot
.78431 .44706 Mdot
.94902 .83137 Mdot
.95294 .76471 Mdot
.86275 .27843 Mdot
.83529 .26667 Mdot
.69804 .57647 Mdot
.62353 .59608 Mdot
.60392 .59216 Mdot
.64314 .62353 Mdot
.16863 .12941 Mdot
.77255 .66275 Mdot
.70588 .47059 Mdot
.90196 .86667 Mdot
.87843 .85098 Mdot
.8 .76078 Mdot
.96078 .86667 Mdot
.87451 .83529 Mdot
.88627 .88627 Mdot
.97647 .97255 Mdot
.58039 .2902 Mdot
.74118 .25098 Mdot
.76863 .27059 Mdot
.77647 .28627 Mdot
.62745 .56078 Mdot
.40392 .34902 Mdot
.63137 .58824 Mdot
.61176 .57647 Mdot
.83922 .55686 Mdot
.83137 .27059 Mdot
.60392 .22353 Mdot
.95294 .82745 Mdot
1 .81961 Mdot
.8549 .27843 Mdot
.81176 .26667 Mdot
.63922 .57647 Mdot
.62745 .60784 Mdot
.61569 .60392 Mdot
.52549 .50588 Mdot
.21176 .14902 Mdot
.93333 .8 Mdot
.80392 .57647 Mdot
.58824 .5451 Mdot
.52157 .4902 Mdot
.66275 .63137 Mdot
1 .89804 Mdot
.75294 .72549 Mdot
.88627 .88235 Mdot
.82353 .75294 Mdot
.67451 .31765 Mdot
.77647 .25098 Mdot
.81569 .27843 Mdot
.73725 .52941 Mdot
.60392 .56078 Mdot
.4 .35686 Mdot
.61961 .58431 Mdot
.69804 .5451 Mdot
.82745 .28235 Mdot
.78824 .3098 Mdot
.57255 .27843 Mdot
.9098 .85098 Mdot
.82745 .30588 Mdot
.8549 .27843 Mdot
.61569 .42353 Mdot
.57255 .5451 Mdot
.43137 .41961 Mdot
.27843 .26667 Mdot
.21961 .17647 Mdot
.76078 .62745 Mdot
.92157 .72549 Mdot
.9098 .87843 Mdot
.68627 .66667 Mdot
.63137 .6 Mdot
.94118 .88235 Mdot
.93333 .83137 Mdot
.86275 .85882 Mdot
.96863 .97647 Mdot
.55686 .3098 Mdot
.64706 .18824 Mdot
.81569 .27843 Mdot
.74118 .4902 Mdot
.60392 .56078 Mdot
.34902 .30588 Mdot
.63137 .59608 Mdot
.7098 .53333 Mdot
.82745 .28235 Mdot
.75294 .34118 Mdot
.49804 .23137 Mdot
.90196 .8549 Mdot
.82353 .31765 Mdot
.83922 .26275 Mdot
.63529 .44706 Mdot
.27843 .25098 Mdot
.30196 .27843 Mdot
.4549 .44314 Mdot
.20784 .16471 Mdot
.36471 .23137 Mdot
.93333 .73725 Mdot
.8902 .87059 Mdot
.94118 .92157 Mdot
.97255 .95294 Mdot
.92549 .88235 Mdot
.96863 .84706 Mdot
.87451 .86667 Mdot
.96863 .97647 Mdot
.53725 .3451 Mdot
.72549 .22745 Mdot
.8 .29412 Mdot
.57647 .48627 Mdot
.6 .55686 Mdot
.25882 .21569 Mdot
.63922 .58431 Mdot
.72157 .28235 Mdot
.80392 .30196 Mdot
.76078 .61569 Mdot
.48235 .41176 Mdot
.99216 .83922 Mdot
.84706 .27451 Mdot
.75686 .28627 Mdot
.45882 .43529 Mdot
.55294 .53333 Mdot
.61176 .58824 Mdot
.59216 .56863 Mdot
.19608 .12549 Mdot
1 .8902 Mdot
.78431 .67451 Mdot
.24706 .21961 Mdot
.22745 .20784 Mdot
.6902 .67843 Mdot
.98824 .89412 Mdot
.90196 .84314 Mdot
.4 .43137 Mdot
.69412 .63529 Mdot
.69412 .31373 Mdot
.77647 .24706 Mdot
.70588 .49804 Mdot
.59608 .55294 Mdot
.62353 .58039 Mdot
.62745 .58431 Mdot
.82353 .42353 Mdot
.80784 .28235 Mdot
.94118 .86667 Mdot
.91765 .85882 Mdot
.91373 .83922 Mdot
.84706 .2902 Mdot
.81176 .28235 Mdot
.63529 .59608 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.59216 .56863 Mdot
.15294 .11373 Mdot
.87843 .74118 Mdot
.55686 .42745 Mdot
.81176 .78431 Mdot
.28627 .2549 Mdot
.2902 .27059 Mdot
.92157 .87843 Mdot
.81569 .69804 Mdot
.89412 .90588 Mdot
.73333 .69804 Mdot
.71765 .31373 Mdot
.76471 .25882 Mdot
.60392 .46667 Mdot
.59608 .55294 Mdot
.61961 .58039 Mdot
.63922 .54118 Mdot
.82353 .29804 Mdot
.70588 .3451 Mdot
.88235 .85882 Mdot
.91373 .83529 Mdot
.98824 .79608 Mdot
.84706 .26275 Mdot
.65882 .31765 Mdot
.58431 .56471 Mdot
.6 .57255 Mdot
.6 .58039 Mdot
.67451 .65098 Mdot
.98431 .90588 Mdot
.91373 .70588 Mdot
.95686 .91373 Mdot
.34902 .32157 Mdot
.97647 .94118 Mdot
.9451 .94118 Mdot
.93333 .87059 Mdot
.21176 .1451 Mdot
.46275 .5098 Mdot
.54118 .38039 Mdot
.76078 .30196 Mdot
.68235 .32549 Mdot
.54902 .4902 Mdot
.61176 .56863 Mdot
.37255 .32941 Mdot
.77255 .33333 Mdot
.81176 .30196 Mdot
.89412 .86667 Mdot
.93725 .83922 Mdot
.97255 .79216 Mdot
.83529 .29412 Mdot
.79608 .29412 Mdot
.62353 .58824 Mdot
.59608 .57255 Mdot
.59216 .57255 Mdot
.58431 .56078 Mdot
.13333 .07843 Mdot
.91765 .69412 Mdot
.67059 .56471 Mdot
.81961 .8 Mdot
.33725 .28627 Mdot
.5098 .4902 Mdot
.89412 .89412 Mdot
.36078 .25098 Mdot
.87059 .8902 Mdot
.92157 .85882 Mdot
.64706 .27843 Mdot
.68235 .2549 Mdot
.54902 .47451 Mdot
.59608 .56078 Mdot
.61176 .57255 Mdot
.77255 .31373 Mdot
.81176 .28627 Mdot
.87843 .84314 Mdot
.94902 .77647 Mdot
.85098 .51373 Mdot
.83529 .2902 Mdot
.79216 .29804 Mdot
.61569 .57255 Mdot
.61176 .59216 Mdot
.58431 .56471 Mdot
.59216 .57647 Mdot
.20392 .12941 Mdot
.74118 .49412 Mdot
.96471 .86667 Mdot
.59216 .56078 Mdot
.82353 .78039 Mdot
.50196 .48627 Mdot
.8902 .8902 Mdot
.32941 .22745 Mdot
.86667 .89412 Mdot
.88235 .78431 Mdot
.67451 .24706 Mdot
.70588 .45098 Mdot
.55686 .50588 Mdot
.60392 .57647 Mdot
.65098 .46667 Mdot
.82745 .27059 Mdot
.47451 .16078 Mdot
.89804 .86275 Mdot
.66667 .2549 Mdot
.72941 .3098 Mdot
.84706 .27843 Mdot
.61176 .40784 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.59608 .57647 Mdot
.16471 .12549 Mdot
.85882 .70196 Mdot
.67451 .44706 Mdot
.93725 .91765 Mdot
.48235 .44706 Mdot
.44314 .41569 Mdot
.89804 .89804 Mdot
.93725 .87451 Mdot
.53333 .4902 Mdot
.4902 .5451 Mdot
.62353 .30196 Mdot
.61176 .32157 Mdot
.56078 .47843 Mdot
.58824 .56078 Mdot
.7098 .52549 Mdot
.82353 .26667 Mdot
.63922 .25098 Mdot
.89804 .87059 Mdot
.75294 .36078 Mdot
.72941 .22353 Mdot
.83137 .27059 Mdot
.64706 .4549 Mdot
.61176 .58431 Mdot
.60392 .58039 Mdot
.6 .57647 Mdot
.17647 .13725 Mdot
.49412 .33725 Mdot
1 .80392 Mdot
.39216 .37255 Mdot
.9098 .86667 Mdot
.84706 .81961 Mdot
.90196 .90196 Mdot
.94118 .87843 Mdot
.54902 .51373 Mdot
.73725 .77647 Mdot
.83137 .55686 Mdot
.72157 .4902 Mdot
.56078 .44706 Mdot
.56863 .53333 Mdot
.8 .52549 Mdot
.81961 .26667 Mdot
.54118 .18431 Mdot
.88627 .84314 Mdot
.69412 .31765 Mdot
.81961 .30588 Mdot
.80784 .27843 Mdot
.67059 .57255 Mdot
.60392 .57647 Mdot
.59608 .57647 Mdot
.59608 .57255 Mdot
.21569 .16863 Mdot
.72941 .59608 Mdot
.60392 .42745 Mdot
.20784 .17647 Mdot
.40784 .36863 Mdot
.48235 .46275 Mdot
.89412 .89412 Mdot
.94902 .86667 Mdot
.88627 .87451 Mdot
.75686 .72941 Mdot
.63922 .38039 Mdot
.54118 .33725 Mdot
.56078 .46275 Mdot
.61569 .55686 Mdot
.78824 .29804 Mdot
.82353 .27059 Mdot
.94118 .73725 Mdot
.96471 .88235 Mdot
.63529 .28627 Mdot
.81176 .30196 Mdot
.62745 .32157 Mdot
.60392 .57647 Mdot
.62353 .58431 Mdot
.59216 .56863 Mdot
.52941 .51373 Mdot
.9451 .90588 Mdot
.6 .43922 Mdot
.96863 .9098 Mdot
.15294 .13725 Mdot
.54902 .51373 Mdot
.94902 .9451 Mdot
.90196 .88627 Mdot
.2549 .16471 Mdot
.33333 .37255 Mdot
.78431 .69412 Mdot
.72941 .53333 Mdot
.60392 .40784 Mdot
.56863 .49412 Mdot
.79216 .48235 Mdot
.82353 .27059 Mdot
.77255 .31373 Mdot
.92549 .82353 Mdot
.83137 .67059 Mdot
.59216 .23529 Mdot
.76078 .31373 Mdot
.61176 .58431 Mdot
.60784 .58039 Mdot
.61569 .59216 Mdot
.6 .56471 Mdot
.36078 .34118 Mdot
.97647 .88235 Mdot
.96078 .83922 Mdot
.44314 .42745 Mdot
.83922 .8 Mdot
.52157 .50588 Mdot
.89804 .89804 Mdot
.4 .30588 Mdot
.87451 .90196 Mdot
.38824 .39216 Mdot
.84706 .67843 Mdot
.70196 .47843 Mdot
.62745 .45098 Mdot
.63922 .48235 Mdot
.79608 .28235 Mdot
.81961 .27451 Mdot
.7098 .36471 Mdot
.92941 .83922 Mdot
.85098 .72157 Mdot
.79608 .32157 Mdot
.65098 .59608 Mdot
.59216 .57255 Mdot
.58039 .56078 Mdot
.56863 .55294 Mdot
.20392 .17255 Mdot
.94118 .88627 Mdot
.85098 .66275 Mdot
.78039 .73725 Mdot
.15686 .13333 Mdot
.55294 .52157 Mdot
.89412 .90196 Mdot
.97647 .91373 Mdot
.78431 .78431 Mdot
.83529 .83922 Mdot
.81569 .69804 Mdot
.86275 .67059 Mdot
.49412 .30196 Mdot
.62745 .46667 Mdot
.78824 .29804 Mdot
.82745 .28235 Mdot
.63137 .18431 Mdot
.97255 .81176 Mdot
.93725 .8549 Mdot
.77647 .33725 Mdot
.61961 .58039 Mdot
.61569 .59608 Mdot
.59216 .57255 Mdot
.56471 .5451 Mdot
.18824 .15686 Mdot
.93725 .87451 Mdot
.74902 .52941 Mdot
.98824 .94902 Mdot
.78039 .76471 Mdot
.26667 .24314 Mdot
.8902 .89804 Mdot
.99216 .92157 Mdot
.85098 .85882 Mdot
.73725 .73725 Mdot
.72157 .61569 Mdot
.8 .65098 Mdot
.43922 .31373 Mdot
.76078 .4549 Mdot
.77647 .28627 Mdot
.81961 .28627 Mdot
.68235 .22353 Mdot
.97647 .72941 Mdot
.97647 .80392 Mdot
.68627 .35686 Mdot
.61961 .59608 Mdot
.57255 .5451 Mdot
.47059 .45098 Mdot
.45882 .44314 Mdot
.93333 .91765 Mdot
.79216 .63529 Mdot
.55294 .40784 Mdot
.90196 .90196 Mdot
.91765 .9098 Mdot
.85882 .8549 Mdot
.89804 .8902 Mdot
.28627 .2 Mdot
.90196 .93333 Mdot
.63137 .58039 Mdot
.88235 .79216 Mdot
.86275 .76471 Mdot
.68627 .47059 Mdot
.70196 .27059 Mdot
.8 .29412 Mdot
.83529 .31373 Mdot
.60392 .20784 Mdot
.95294 .70196 Mdot
.71373 .36471 Mdot
.49412 .47059 Mdot
.2902 .26275 Mdot
.3451 .32549 Mdot
.47843 .47059 Mdot
.56863 .5451 Mdot
.94902 .82745 Mdot
.61961 .43529 Mdot
.92157 .8902 Mdot
.90588 .8902 Mdot
.78039 .78039 Mdot
.89804 .89804 Mdot
.43137 .34118 Mdot
.89412 .92157 Mdot
.66667 .63922 Mdot
.93725 .89804 Mdot
.55294 .42353 Mdot
.63529 .25098 Mdot
.77255 .30588 Mdot
.80784 .30196 Mdot
.76078 .27843 Mdot
.63137 .22353 Mdot
.71373 .37255 Mdot
.36471 .34118 Mdot
.41176 .37255 Mdot
.53725 .5098 Mdot
.67451 .65882 Mdot
.83529 .81961 Mdot
.93725 .81961 Mdot
.97647 .82353 Mdot
.96863 .87843 Mdot
.92549 .8902 Mdot
.61569 .61569 Mdot
.90196 .89412 Mdot
.2902 .19216 Mdot
.92157 .95294 Mdot
.98039 .97647 Mdot
.58039 .37255 Mdot
.61569 .23137 Mdot
.74118 .28627 Mdot
.80784 .30196 Mdot
.80392 .29412 Mdot
.71373 .28627 Mdot
.58039 .53333 Mdot
.59608 .56078 Mdot
.61176 .58824 Mdot
.57255 .55686 Mdot
.08627 .07059 Mdot
.94118 .87843 Mdot
.86667 .69412 Mdot
1 .88627 Mdot
.8902 .73725 Mdot
.9098 .90588 Mdot
.8902 .89804 Mdot
.96863 .87843 Mdot
.83922 .87059 Mdot
.79216 .69412 Mdot
.57255 .24706 Mdot
.69804 .26667 Mdot
.78824 .31765 Mdot
.81569 .30196 Mdot
.72549 .36471 Mdot
.57647 .55294 Mdot
.58431 .56078 Mdot
.57255 .55686 Mdot
.63529 .61569 Mdot
.64706 .63137 Mdot
.96078 .85882 Mdot
.77255 .59608 Mdot
.89804 .68627 Mdot
.62353 .44314 Mdot
.9098 .9098 Mdot
.89412 .88627 Mdot
.26275 .18039 Mdot
.9451 .96863 Mdot
.66275 .48627 Mdot
.60784 .26275 Mdot
.70588 .28235 Mdot
.79608 .29804 Mdot
.73725 .34118 Mdot
.58039 .5451 Mdot
.57647 .55294 Mdot
.56863 .5451 Mdot
.56078 .54118 Mdot
.23137 .20784 Mdot
.97255 .88627 Mdot
.63137 .45098 Mdot
.94902 .71373 Mdot
.56471 .33725 Mdot
.93725 .9451 Mdot
.8902 .89412 Mdot
.5098 .43529 Mdot
.91373 .93725 Mdot
.71373 .58431 Mdot
.58431 .27451 Mdot
.71373 .27451 Mdot
.76078 .30196 Mdot
.64314 .52549 Mdot
.56471 .54118 Mdot
.56471 .52941 Mdot
.55294 .52941 Mdot
.19216 .16078 Mdot
.9451 .87059 Mdot
.76078 .61176 Mdot
.86275 .69412 Mdot
.74902 .42353 Mdot
.52157 .52157 Mdot
.87451 .91765 Mdot
.93333 .87059 Mdot
.83529 .84314 Mdot
.98824 .92941 Mdot
.54902 .3098 Mdot
.62745 .23529 Mdot
.70196 .29804 Mdot
.57647 .52157 Mdot
.56078 .52549 Mdot
.57647 .53333 Mdot
.54902 .52941 Mdot
.19608 .16078 Mdot
.65882 .5451 Mdot
.58824 .4549 Mdot
.48627 .2 Mdot
.62353 .45882 Mdot
.54902 .54902 Mdot
.71765 .76863 Mdot
.89412 .83529 Mdot
.86667 .89412 Mdot
.90588 .82353 Mdot
.53333 .27843 Mdot
.63529 .25882 Mdot
.60392 .54118 Mdot
.55686 .52549 Mdot
.56471 .52941 Mdot
.54118 .50588 Mdot
.20784 .16471 Mdot
.94118 .85882 Mdot
.82353 .68627 Mdot
.82353 .6549 Mdot
.56078 .35294 Mdot
.47059 .41961 Mdot
.40392 .46275 Mdot
.6 .52157 Mdot
.83137 .86667 Mdot
.93725 .82353 Mdot
.57255 .29412 Mdot
.59608 .52941 Mdot
.54902 .52941 Mdot
.53333 .51373 Mdot
.55294 .51765 Mdot
.22745 .18824 Mdot
.92157 .87843 Mdot
.77647 .65882 Mdot
.97647 .87843 Mdot
.63922 .36471 Mdot
.44314 .38039 Mdot
.57647 .58431 Mdot
.41961 .34902 Mdot
.83922 .86667 Mdot
.98431 .90196 Mdot
.90588 .84314 Mdot
.55686 .55294 Mdot
.52157 .5098 Mdot
.55686 .50588 Mdot
.22353 .17255 Mdot
.90196 .89804 Mdot
.5098 .43529 Mdot
.96078 .90196 Mdot
.73725 .33725 Mdot
.51765 .4902 Mdot
.61569 .54118 Mdot
.48627 .43137 Mdot
.83922 .8549 Mdot
.97647 .98824 Mdot
.75686 .76078 Mdot
.59608 .6 Mdot
.49804 .47451 Mdot
.53333 .46667 Mdot
.80392 .77647 Mdot
.92157 .8902 Mdot
.91765 .90196 Mdot
.41961 .23922 Mdot
.54902 .4 Mdot
.63137 .53725 Mdot
.4549 .40392 Mdot
.83137 .80392 Mdot
.87451 .90196 Mdot
.83137 .84706 Mdot
.63529 .65882 Mdot
.8 .6902 Mdot
.30588 .22353 Mdot
.94118 .91373 Mdot
.93725 .9098 Mdot
.91373 .8902 Mdot
.6902 .42353 Mdot
.57255 .55686 Mdot
.53725 .47451 Mdot
.70196 .63137 Mdot
.84314 .87843 Mdot
.98039 .99608 Mdot
.65098 .67059 Mdot
.63529 .52941 Mdot
.4902 .42353 Mdot
.94902 .89412 Mdot
.94118 .89804 Mdot
.92549 .8902 Mdot
.49412 .33333 Mdot
.69804 .68235 Mdot
.87059 .80784 Mdot
.81176 .77647 Mdot
.87059 .9098 Mdot
.86667 .83529 Mdot
.87059 .84314 Mdot
.72549 .66275 Mdot
.88235 .8 Mdot
.96863 .89804 Mdot
1 .91373 Mdot
.91765 .90588 Mdot
.7451 .69804 Mdot
.61961 .53725 Mdot
.83922 .87451 Mdot
1 .99216 Mdot
.84706 .84706 Mdot
.81961 .74902 Mdot
.62745 .53725 Mdot
.86667 .79216 Mdot
.97255 .9098 Mdot
.92941 .89804 Mdot
.48627 .42745 Mdot
.83529 .78431 Mdot
.87059 .92549 Mdot
.98824 .99216 Mdot
.85098 .84706 Mdot
.91765 .86275 Mdot
.66667 .59608 Mdot
.73725 .63529 Mdot
.95294 .87059 Mdot
.98824 .90588 Mdot
.79608 .71765 Mdot
.82745 .87059 Mdot
.99216 1 Mdot
.80784 .78039 Mdot
.92157 .87451 Mdot
.8549 .77647 Mdot
.61569 .5451 Mdot
.77255 .67059 Mdot
.49804 .43922 Mdot
.82353 .85882 Mdot
.98824 1 Mdot
.78824 .77255 Mdot
.82745 .79608 Mdot
.88235 .85098 Mdot
.82353 .78824 Mdot
.63922 .56863 Mdot
.85882 .83137 Mdot
.76078 .83529 Mdot
.62353 .62745 Mdot
.8 .79216 Mdot
.75294 .74902 Mdot
.75686 .76078 Mdot
.87451 .83922 Mdot
.84706 .83137 Mdot
.56863 .63137 Mdot
.96078 .96471 Mdot
.75294 .77255 Mdot
.8 .80392 Mdot
.87451 .87843 Mdot
.9451 .92941 Mdot
.92549 .92157 Mdot
.85098 .88235 Mdot
.8902 .90588 Mdot
.93725 .9451 Mdot
.99216 1 Mdot
.99216 .99216 Mdot
.98824 .99608 Mdot
.628 .126 .941 r
.90588 .90588 Mdot
.49412 .4902 Mdot
.8 .8 Mdot
.17647 .16471 Mdot
.18039 .18431 Mdot
.13333 .11373 Mdot
.32157 .29412 Mdot
.36863 .37255 Mdot
.20784 .19216 Mdot
.28627 .25098 Mdot
.24314 .23922 Mdot
.21569 .2 Mdot
.26275 .21961 Mdot
.23529 .22353 Mdot
.17255 .16078 Mdot
.20392 .16863 Mdot
.3098 .27843 Mdot
.83922 .83922 Mdot
.2902 .2549 Mdot
.23922 .20392 Mdot
.2902 .27451 Mdot
1 .96471 Mdot
.79608 .7451 Mdot
.27451 .23137 Mdot
.26667 .22353 Mdot
.27059 .24314 Mdot
.9098 .81961 Mdot
.83529 .73333 Mdot
.72549 .51765 Mdot
.1451 .09412 Mdot
.18431 .14118 Mdot
.24706 .21176 Mdot
.16863 .15686 Mdot
.41569 .41569 Mdot
.55686 .55686 Mdot
.53725 .30196 Mdot
.64314 .4549 Mdot
.62353 .24706 Mdot
.15686 .08235 Mdot
.21569 .17647 Mdot
.27843 .25098 Mdot
.17647 .1451 Mdot
.90196 .85098 Mdot
.67451 .68235 Mdot
.11765 .11373 Mdot
.39216 .4 Mdot
.61176 .28627 Mdot
.60392 .40392 Mdot
.78431 .30196 Mdot
.25882 .09412 Mdot
.16863 .12941 Mdot
.25098 .22353 Mdot
.19216 .16078 Mdot
.34902 .23529 Mdot
.53725 .46275 Mdot
.85882 .76863 Mdot
.94902 .94902 Mdot
.1098 .10588 Mdot
.09412 .09804 Mdot
.83922 .83922 Mdot
.61176 .23922 Mdot
.67843 .42745 Mdot
.80784 .30588 Mdot
.21176 .0549 Mdot
.18824 .1451 Mdot
.24314 .22353 Mdot
.18824 .13333 Mdot
.47843 .30196 Mdot
.34902 .2 Mdot
.40392 .18431 Mdot
.55294 .43529 Mdot
.85098 .75294 Mdot
.99608 .95294 Mdot
.12549 .12157 Mdot
.22353 .22353 Mdot
.07059 .0902 Mdot
.71373 .27451 Mdot
.72549 .49804 Mdot
.74902 .30588 Mdot
.73725 .25098 Mdot
.22745 .12549 Mdot
.2 .15686 Mdot
.16078 .12941 Mdot
.22353 .02353 Mdot
.45882 .29412 Mdot
.43529 .2 Mdot
.35294 .16471 Mdot
.32941 .16863 Mdot
.37647 .27059 Mdot
.61176 .52941 Mdot
.89804 .81569 Mdot
1 1 Mdot
.10196 .10588 Mdot
.21961 .2 Mdot
.20392 .20392 Mdot
.31373 .32157 Mdot
.82353 .27451 Mdot
.56471 .2902 Mdot
.81961 .2902 Mdot
.83529 .36471 Mdot
.21961 .12157 Mdot
.20392 .16078 Mdot
.19216 .13725 Mdot
.54118 .27451 Mdot
.59608 .43922 Mdot
.55294 .24314 Mdot
.52157 .39216 Mdot
.32157 .17255 Mdot
.29804 .16078 Mdot
.31373 .16078 Mdot
.4902 .28627 Mdot
.61569 .59608 Mdot
.11373 .11765 Mdot
.26275 .25098 Mdot
.19216 .17255 Mdot
.0902 .09412 Mdot
.86275 .62745 Mdot
.69412 .22353 Mdot
.81961 .41569 Mdot
.86667 .30588 Mdot
.72941 .27059 Mdot
.25098 .12157 Mdot
.22745 .15686 Mdot
.27843 .08235 Mdot
.68235 .46275 Mdot
.53725 .37255 Mdot
.58431 .30196 Mdot
.72157 .57255 Mdot
.59216 .45882 Mdot
.4902 .32941 Mdot
.41176 .18431 Mdot
.40784 .18039 Mdot
.36471 .35294 Mdot
.12157 .12549 Mdot
.16078 .14902 Mdot
.16863 .14902 Mdot
.1098 .1098 Mdot
.82745 .28627 Mdot
.99216 .54118 Mdot
.80392 .26667 Mdot
.86667 .28627 Mdot
.69412 .2549 Mdot
.28627 .09804 Mdot
.2549 .09804 Mdot
.47843 .06667 Mdot
.51373 .31765 Mdot
.47843 .28627 Mdot
.42353 .23922 Mdot
.35686 .20392 Mdot
.71373 .55294 Mdot
.62745 .50196 Mdot
.48235 .15294 Mdot
.53333 .39216 Mdot
.39608 .39216 Mdot
.12549 .11373 Mdot
.13725 .11765 Mdot
.13725 .11765 Mdot
.09412 .10196 Mdot
.83922 .25098 Mdot
.84706 .32157 Mdot
.84706 .26667 Mdot
.8549 .2549 Mdot
.79608 .31373 Mdot
.34902 .07059 Mdot
.32157 .03137 Mdot
.77255 .27059 Mdot
.64706 .42745 Mdot
.49804 .26667 Mdot
.78431 .63922 Mdot
.30196 .16863 Mdot
.55294 .33725 Mdot
.64706 .54118 Mdot
.61961 .23529 Mdot
.55294 .44314 Mdot
.0549 .0549 Mdot
.12549 .11373 Mdot
.34902 .32941 Mdot
.1451 .12549 Mdot
.12549 .13333 Mdot
.86275 .27451 Mdot
.87059 .29804 Mdot
.85098 .2549 Mdot
.85098 .24706 Mdot
.87059 .32157 Mdot
.51373 .0902 Mdot
.50588 .08235 Mdot
.81176 .27451 Mdot
.64314 .38039 Mdot
.63922 .38039 Mdot
.68627 .54118 Mdot
.4 .25882 Mdot
.46667 .19216 Mdot
.67451 .56078 Mdot
.61176 .24706 Mdot
.55686 .45098 Mdot
.08627 .07843 Mdot
.12941 .12549 Mdot
.34118 .32157 Mdot
.11765 .10588 Mdot
.0902 .09804 Mdot
.86275 .27451 Mdot
.88627 .28235 Mdot
.85098 .24706 Mdot
.86667 .26275 Mdot
.93333 .35686 Mdot
.88235 .36863 Mdot
.85098 .34118 Mdot
.84314 .28627 Mdot
.60784 .34902 Mdot
.58431 .33725 Mdot
.67843 .54118 Mdot
.52549 .38431 Mdot
.51373 .2 Mdot
.72549 .61176 Mdot
.6 .28235 Mdot
.59216 .4902 Mdot
.12157 .11373 Mdot
.1451 .14118 Mdot
.29804 .28627 Mdot
.11373 .10196 Mdot
.07451 .07451 Mdot
.83922 .2902 Mdot
.8902 .28627 Mdot
.8902 .28627 Mdot
.88235 .27843 Mdot
.90196 .3098 Mdot
.92157 .36078 Mdot
.87059 .33333 Mdot
.89804 .30196 Mdot
.63922 .38431 Mdot
.59608 .37647 Mdot
.66275 .53333 Mdot
.38431 .23137 Mdot
.73333 .46275 Mdot
.67059 .52549 Mdot
.52941 .32941 Mdot
.58824 .44706 Mdot
.59608 .57255 Mdot
.14118 .13725 Mdot
.14118 .14118 Mdot
.09804 .09804 Mdot
.12941 .12549 Mdot
.81961 .82745 Mdot
.86275 .28235 Mdot
.87059 .27451 Mdot
.87843 .28235 Mdot
.88235 .28627 Mdot
.87059 .31765 Mdot
.91373 .36863 Mdot
.92157 .36863 Mdot
.86667 .27451 Mdot
.53725 .3098 Mdot
.54118 .36471 Mdot
.74902 .62745 Mdot
.53725 .41569 Mdot
.51373 .16863 Mdot
.69412 .56471 Mdot
.39608 .19608 Mdot
.35686 .23922 Mdot
.72941 .7098 Mdot
.12941 .12549 Mdot
.22745 .21569 Mdot
.21961 .21569 Mdot
.11373 .1098 Mdot
.52157 .52549 Mdot
.81961 .30196 Mdot
.86667 .28627 Mdot
.88235 .30588 Mdot
.87451 .29412 Mdot
.83137 .30196 Mdot
.89412 .40784 Mdot
.92549 .38039 Mdot
.90588 .31373 Mdot
.54118 .20392 Mdot
.50588 .32549 Mdot
.34902 .24706 Mdot
.38824 .24706 Mdot
.81569 .55686 Mdot
.68627 .52549 Mdot
.46275 .23137 Mdot
.52549 .36078 Mdot
.45882 .38824 Mdot
.12157 .12549 Mdot
.12157 .11765 Mdot
.20392 .20392 Mdot
.14902 .14118 Mdot
.43529 .43922 Mdot
.73725 .74118 Mdot
.81961 .28627 Mdot
.90196 .32941 Mdot
.92157 .36471 Mdot
.89804 .33333 Mdot
.87059 .38824 Mdot
.89412 .46667 Mdot
.90588 .4 Mdot
.87451 .29412 Mdot
.67843 .28235 Mdot
.63137 .41961 Mdot
.41176 .31373 Mdot
.31373 .17647 Mdot
.65098 .39216 Mdot
.79608 .64706 Mdot
.55686 .28235 Mdot
.7098 .50196 Mdot
.57647 .47843 Mdot
.08235 .08235 Mdot
.11373 .1098 Mdot
.13725 .13725 Mdot
.12157 .11373 Mdot
.47843 .47843 Mdot
.44706 .4549 Mdot
.61176 .38824 Mdot
.92157 .33333 Mdot
.98824 .4902 Mdot
.96078 .41961 Mdot
.91373 .37647 Mdot
.95294 .56863 Mdot
.86275 .48627 Mdot
.82353 .32549 Mdot
.84706 .28235 Mdot
.79216 .40784 Mdot
.52941 .40784 Mdot
.73333 .56863 Mdot
.78039 .65882 Mdot
.53725 .30196 Mdot
.84706 .61569 Mdot
.64706 .35686 Mdot
.6 .35686 Mdot
.95294 .9451 Mdot
.19608 .18039 Mdot
.13333 .12941 Mdot
.13333 .13333 Mdot
.05098 .0549 Mdot
.50588 .5098 Mdot
.41961 .42745 Mdot
.69412 .28627 Mdot
.89804 .3098 Mdot
.97647 .45882 Mdot
.95686 .41569 Mdot
.95294 .43137 Mdot
.96863 .56863 Mdot
.91765 .54118 Mdot
.99216 .50196 Mdot
.86275 .29804 Mdot
.80784 .37647 Mdot
.78431 .64706 Mdot
.44314 .26667 Mdot
.85098 .71765 Mdot
.38039 .23137 Mdot
.46667 .13333 Mdot
.64314 .32941 Mdot
.63529 .38824 Mdot
.89412 .8902 Mdot
.09412 .0902 Mdot
.13725 .13333 Mdot
.12941 .12941 Mdot
.51373 .51373 Mdot
.53333 .53333 Mdot
.47451 .48235 Mdot
.96078 .96078 Mdot
.93725 .34902 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.94902 .39216 Mdot
.92157 .42745 Mdot
.94118 .5098 Mdot
.91765 .44706 Mdot
.87059 .2902 Mdot
.8902 .33725 Mdot
.65098 .38039 Mdot
.89412 .71765 Mdot
.82353 .70588 Mdot
.45098 .30196 Mdot
.8549 .67059 Mdot
.70196 .33725 Mdot
.68627 .37255 Mdot
.7451 .67843 Mdot
.34902 .33725 Mdot
.08235 .06667 Mdot
.11765 .12157 Mdot
.18824 .18824 Mdot
.54118 .54118 Mdot
.51373 .51373 Mdot
.47843 .48627 Mdot
1 .97647 Mdot
.94902 .36078 Mdot
.95294 .38039 Mdot
.88235 .34902 Mdot
.93333 .38431 Mdot
.93333 .39608 Mdot
.89412 .40784 Mdot
.93725 .43529 Mdot
.88235 .31765 Mdot
.88627 .30588 Mdot
.62353 .28235 Mdot
.99608 .74902 Mdot
.88235 .72549 Mdot
.78431 .65098 Mdot
.95294 .72941 Mdot
.77255 .38431 Mdot
.72549 .39216 Mdot
.76863 .69804 Mdot
.2549 .24314 Mdot
.3451 .33725 Mdot
.11373 .12941 Mdot
.21569 .22353 Mdot
.56078 .55294 Mdot
.35686 .35294 Mdot
.47451 .48235 Mdot
.55294 .54902 Mdot
.85882 .29804 Mdot
.93333 .3451 Mdot
.97255 .4549 Mdot
.91373 .38039 Mdot
.92941 .38039 Mdot
.94902 .41176 Mdot
.91373 .39608 Mdot
.96863 .43529 Mdot
.90196 .3451 Mdot
.84706 .33725 Mdot
.73725 .38431 Mdot
.82353 .52157 Mdot
.91765 .71373 Mdot
.92157 .72941 Mdot
.78824 .3098 Mdot
.80392 .43922 Mdot
.71765 .5451 Mdot
.35294 .34902 Mdot
.21961 .21176 Mdot
.28235 .3098 Mdot
.17255 .17647 Mdot
.63137 .62745 Mdot
.33333 .33725 Mdot
.36471 .36863 Mdot
.49804 .48627 Mdot
.6549 .31765 Mdot
.91765 .32941 Mdot
.93725 .37647 Mdot
.94902 .43922 Mdot
.9451 .42353 Mdot
.91373 .36471 Mdot
.94902 .40392 Mdot
.94902 .41176 Mdot
.95686 .41569 Mdot
.90196 .3451 Mdot
.76078 .29412 Mdot
.74902 .31765 Mdot
.6902 .37255 Mdot
.82745 .56863 Mdot
.76078 .27059 Mdot
.82745 .37647 Mdot
.7098 .39608 Mdot
.81176 .80392 Mdot
.27451 .26667 Mdot
.42745 .43137 Mdot
.21569 .23529 Mdot
.09804 .10588 Mdot
.63529 .63529 Mdot
.54118 .5451 Mdot
.54902 .54902 Mdot
.76471 .7451 Mdot
.94902 .36078 Mdot
.95294 .36078 Mdot
.93725 .4 Mdot
.92157 .41569 Mdot
.95294 .43529 Mdot
.89804 .36078 Mdot
.92549 .37647 Mdot
.93725 .39608 Mdot
.9451 .41176 Mdot
.88235 .32549 Mdot
.83137 .37647 Mdot
.76863 .33725 Mdot
.67451 .28235 Mdot
.69804 .26275 Mdot
.83922 .30196 Mdot
.85882 .41961 Mdot
.75294 .67843 Mdot
.15294 .15294 Mdot
.83922 .82353 Mdot
.15686 .19216 Mdot
.14902 .16863 Mdot
.6902 .67843 Mdot
.38431 .38824 Mdot
.60392 .58824 Mdot
.57255 .49412 Mdot
.80392 .3098 Mdot
.91765 .34118 Mdot
.9451 .38431 Mdot
.87843 .41176 Mdot
.88235 .41961 Mdot
.94902 .42745 Mdot
.94118 .38431 Mdot
.90588 .35686 Mdot
.93333 .39216 Mdot
.96863 .44314 Mdot
.85882 .38431 Mdot
.8549 .40784 Mdot
.82745 .38039 Mdot
.79608 .3451 Mdot
.8549 .3098 Mdot
.86667 .32549 Mdot
.83529 .64314 Mdot
.85098 .8549 Mdot
.50196 .4902 Mdot
.89804 .90196 Mdot
.51765 .52941 Mdot
.12941 .12549 Mdot
.66275 .66667 Mdot
.31765 .31373 Mdot
.60392 .55686 Mdot
.97647 .92157 Mdot
.93725 .34118 Mdot
.93725 .35686 Mdot
.88235 .40784 Mdot
.83922 .47843 Mdot
.87059 .45098 Mdot
.93333 .39608 Mdot
.95294 .40392 Mdot
.91765 .37647 Mdot
.8902 .39608 Mdot
.92549 .35294 Mdot
.70588 .38824 Mdot
.87059 .47059 Mdot
.8549 .44314 Mdot
.87059 .39216 Mdot
.86667 .34118 Mdot
.82745 .34118 Mdot
.81961 .77647 Mdot
.60392 .6 Mdot
.34118 .33333 Mdot
.96078 .97647 Mdot
.5098 .50588 Mdot
.7451 .72941 Mdot
.61961 .61961 Mdot
.30588 .30196 Mdot
.93725 .70196 Mdot
.75294 .31765 Mdot
.91765 .33725 Mdot
.90196 .39216 Mdot
.81176 .49412 Mdot
.77647 .4902 Mdot
.81176 .40784 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.95294 .42745 Mdot
.84314 .37647 Mdot
.81176 .37647 Mdot
.47843 .21961 Mdot
.66275 .3451 Mdot
.82353 .45098 Mdot
.86667 .43922 Mdot
.87843 .32549 Mdot
.72941 .48235 Mdot
.84314 .82745 Mdot
.27843 .26667 Mdot
.94902 .94118 Mdot
.25098 .24314 Mdot
.66667 .65882 Mdot
.71765 .71373 Mdot
.66275 .66275 Mdot
.59216 .51765 Mdot
.54118 .3098 Mdot
.94902 .36863 Mdot
.90196 .34902 Mdot
.8 .47843 Mdot
.76863 .58431 Mdot
.91765 .69412 Mdot
.87451 .43922 Mdot
.9451 .39216 Mdot
.9451 .38824 Mdot
.83529 .45098 Mdot
.92941 .39216 Mdot
.33725 .14902 Mdot
.36863 .18039 Mdot
.4549 .24706 Mdot
.58039 .2902 Mdot
.71373 .34118 Mdot
.79216 .32941 Mdot
.86667 .78039 Mdot
.67451 .67451 Mdot
.96078 .93725 Mdot
.88235 .88235 Mdot
.91373 .90196 Mdot
.79216 .78824 Mdot
.72941 .71765 Mdot
.63922 .63529 Mdot
.67059 .31373 Mdot
.90588 .78431 Mdot
.93333 .35294 Mdot
.87843 .41176 Mdot
.82745 .67843 Mdot
.82353 .70588 Mdot
.69804 .53333 Mdot
.90196 .45098 Mdot
.93725 .38039 Mdot
.92941 .38039 Mdot
.58039 .32549 Mdot
.89804 .37255 Mdot
.22745 .12941 Mdot
.25882 .16078 Mdot
.3098 .17255 Mdot
.40392 .21176 Mdot
.57647 .16863 Mdot
.57647 .2902 Mdot
.5451 .51373 Mdot
.23922 .23529 Mdot
.76471 .74118 Mdot
.9451 .95686 Mdot
.84706 .83922 Mdot
.82353 .80784 Mdot
.76863 .75294 Mdot
.73333 .71373 Mdot
.78431 .31373 Mdot
.76471 .31765 Mdot
.93333 .37255 Mdot
.82353 .53725 Mdot
.7451 .67843 Mdot
.42745 .3451 Mdot
.36863 .22353 Mdot
.90588 .46275 Mdot
.9451 .39216 Mdot
.8902 .40784 Mdot
.43922 .21176 Mdot
.88235 .40392 Mdot
.18039 .11765 Mdot
.2 .12941 Mdot
.22745 .1451 Mdot
.28235 .16471 Mdot
.79216 .35294 Mdot
.27059 .16471 Mdot
.23529 .23529 Mdot
.19216 .19608 Mdot
.4549 .44314 Mdot
.49412 .49804 Mdot
.8549 .8549 Mdot
.83137 .82745 Mdot
.77255 .76863 Mdot
.75686 .67059 Mdot
.71765 .36471 Mdot
.92941 .36863 Mdot
.85882 .39216 Mdot
.85882 .71765 Mdot
.9098 .86275 Mdot
.34118 .2902 Mdot
1 .8549 Mdot
.92549 .4549 Mdot
.95294 .4 Mdot
.63529 .3451 Mdot
.34118 .06667 Mdot
.79608 .38039 Mdot
.15294 .12157 Mdot
.18039 .14118 Mdot
.2 .16078 Mdot
.27843 .16471 Mdot
.78431 .39608 Mdot
.21176 .18039 Mdot
.19608 .19216 Mdot
.10196 .11373 Mdot
.27451 .25882 Mdot
.81961 .81961 Mdot
.87059 .87059 Mdot
.85882 .85098 Mdot
.81176 .80784 Mdot
.89804 .65882 Mdot
.62745 .52157 Mdot
.90588 .33333 Mdot
.84314 .47843 Mdot
.83529 .74902 Mdot
.39216 .36078 Mdot
.37255 .33725 Mdot
.92549 .7098 Mdot
.92941 .46667 Mdot
.9451 .38824 Mdot
.32549 .15686 Mdot
.32157 .08235 Mdot
.79608 .38039 Mdot
.14118 .1098 Mdot
.20784 .17647 Mdot
.15686 .13725 Mdot
.21569 .05098 Mdot
.70588 .38039 Mdot
.14118 .13725 Mdot
.13725 .12941 Mdot
.2902 .29412 Mdot
.51765 .50588 Mdot
.88627 .87843 Mdot
.87843 .87843 Mdot
.87451 .87451 Mdot
.85098 .85098 Mdot
.7451 .41961 Mdot
1 .96471 Mdot
.88235 .32941 Mdot
.83922 .55686 Mdot
.85882 .81176 Mdot
.2549 .23922 Mdot
.81961 .78824 Mdot
.94902 .6902 Mdot
.93725 .47059 Mdot
.93725 .4 Mdot
.23922 .16078 Mdot
.32157 .10196 Mdot
.80784 .39216 Mdot
.15294 .13333 Mdot
.1451 .12549 Mdot
.13333 .11373 Mdot
.34118 .08235 Mdot
.56863 .34118 Mdot
.12157 .12157 Mdot
.1451 .12157 Mdot
.72157 .72941 Mdot
.86275 .85882 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.88235 .88235 Mdot
.87451 .87451 Mdot
.52157 .13333 Mdot
1 .96863 Mdot
.89412 .35686 Mdot
.86275 .61176 Mdot
.86667 .82745 Mdot
.25098 .23922 Mdot
.48627 .4549 Mdot
.80784 .47843 Mdot
.90196 .48235 Mdot
.92157 .38824 Mdot
.21961 .16078 Mdot
.55686 .40784 Mdot
.86275 .40784 Mdot
.1451 .10588 Mdot
.1451 .13333 Mdot
.1451 .12549 Mdot
.35294 .07451 Mdot
.54902 .32549 Mdot
.12549 .12549 Mdot
.1098 .07059 Mdot
.84706 .84706 Mdot
.87059 .86667 Mdot
.85098 .85098 Mdot
.87451 .87451 Mdot
.87059 .87059 Mdot
.87059 .87059 Mdot
.69804 .32549 Mdot
1 .96863 Mdot
.85882 .35294 Mdot
.89804 .65882 Mdot
.8902 .8549 Mdot
.30196 .28235 Mdot
.34118 .30196 Mdot
.73725 .41569 Mdot
.89804 .51373 Mdot
.9098 .39608 Mdot
.19216 .14902 Mdot
.75686 .66275 Mdot
.88235 .42353 Mdot
.16471 .07059 Mdot
.17255 .14118 Mdot
.14118 .12157 Mdot
.37647 .0902 Mdot
.54118 .31765 Mdot
.12549 .1098 Mdot
.29412 .24706 Mdot
.86667 .86275 Mdot
.91373 .91373 Mdot
.69412 .6902 Mdot
.87451 .87451 Mdot
.85882 .85882 Mdot
.86275 .86275 Mdot
.86275 .49804 Mdot
1 .97255 Mdot
.86667 .39216 Mdot
.97255 .73333 Mdot
.86275 .81961 Mdot
.26667 .23922 Mdot
.21176 .16078 Mdot
.83529 .58824 Mdot
.86275 .52157 Mdot
.87843 .38824 Mdot
.17255 .12941 Mdot
.43922 .36471 Mdot
.86275 .44314 Mdot
.23529 .03529 Mdot
.20784 .14902 Mdot
.15686 .12549 Mdot
.37255 .07059 Mdot
.52941 .30588 Mdot
.13725 .09804 Mdot
.8 .75686 Mdot
.87059 .86667 Mdot
.7451 .74902 Mdot
.4549 .45098 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.85882 .86667 Mdot
.79608 .43137 Mdot
1 .97255 Mdot
.83137 .39608 Mdot
.97647 .74118 Mdot
.79216 .7451 Mdot
.31765 .28627 Mdot
.50588 .45098 Mdot
1 .81569 Mdot
.87059 .56471 Mdot
.8902 .41961 Mdot
.17647 .14118 Mdot
.26667 .20784 Mdot
.72549 .37255 Mdot
.40392 .0902 Mdot
.27843 .12157 Mdot
.20392 .09412 Mdot
.38824 .0549 Mdot
.52941 .27059 Mdot
.2 .08627 Mdot
.56471 .52549 Mdot
.88627 .87843 Mdot
.27451 .28235 Mdot
.30588 .29412 Mdot
.87451 .85882 Mdot
.88627 .88627 Mdot
.87059 .87843 Mdot
.76471 .4 Mdot
1 .96471 Mdot
.81176 .41176 Mdot
.94118 .69804 Mdot
.76863 .71765 Mdot
.78824 .75294 Mdot
.80784 .75686 Mdot
.58039 .45098 Mdot
.94902 .67843 Mdot
.87059 .43137 Mdot
.19608 .16078 Mdot
.24314 .2 Mdot
.64706 .36863 Mdot
.73725 .29804 Mdot
.42745 .09804 Mdot
.31373 .06667 Mdot
.43137 .04314 Mdot
.56078 .23922 Mdot
.29412 .05882 Mdot
.57647 .54118 Mdot
.90588 .88627 Mdot
.26275 .28235 Mdot
.20392 .17255 Mdot
.90196 .87843 Mdot
.87843 .87843 Mdot
.86667 .87451 Mdot
.72941 .37255 Mdot
1 .96471 Mdot
.76863 .40392 Mdot
.86667 .61569 Mdot
.83922 .79608 Mdot
.51765 .4902 Mdot
.47843 .43922 Mdot
.4902 .40392 Mdot
.99608 .73725 Mdot
.86667 .44706 Mdot
.18431 .15686 Mdot
.20392 .17647 Mdot
.80784 .59216 Mdot
.81961 .35686 Mdot
.65098 .21961 Mdot
.47451 .12157 Mdot
.46667 .02353 Mdot
.60392 .20392 Mdot
.47451 .12549 Mdot
.64314 .61176 Mdot
.51373 .50196 Mdot
.26667 .28627 Mdot
.16863 .12549 Mdot
.96078 .93725 Mdot
.88235 .87843 Mdot
.87059 .87843 Mdot
.68627 .33333 Mdot
1 .95686 Mdot
.75294 .41176 Mdot
.77647 .52941 Mdot
.94902 .92549 Mdot
.35294 .3451 Mdot
.43529 .42353 Mdot
.74118 .67843 Mdot
1 .75686 Mdot
.84314 .44706 Mdot
.18039 .14902 Mdot
.17647 .1451 Mdot
.62353 .44706 Mdot
.8902 .5098 Mdot
.82745 .36471 Mdot
.73725 .2902 Mdot
.61176 .13333 Mdot
.7451 .26667 Mdot
.74902 .3098 Mdot
.84314 .80784 Mdot
.27059 .26667 Mdot
.22353 .23529 Mdot
.15294 .09804 Mdot
.8902 .87451 Mdot
.91373 .8902 Mdot
.87451 .88235 Mdot
.66275 .32549 Mdot
1 .95294 Mdot
.75294 .41569 Mdot
.66667 .43922 Mdot
.92549 .91373 Mdot
.19216 .18431 Mdot
.21569 .22353 Mdot
.91765 .87451 Mdot
.98039 .72941 Mdot
.83922 .46667 Mdot
.16471 .1451 Mdot
.18039 .14902 Mdot
.36863 .20392 Mdot
1 .68627 Mdot
.83529 .39216 Mdot
.88235 .41961 Mdot
.81176 .35294 Mdot
.85098 .32549 Mdot
.83922 .36863 Mdot
.68627 .64706 Mdot
.25882 .2549 Mdot
.15294 .15686 Mdot
.13725 .08235 Mdot
.63137 .61569 Mdot
.87451 .83922 Mdot
.86667 .87059 Mdot
.60392 .28627 Mdot
1 .9451 Mdot
.77255 .43529 Mdot
.61569 .42745 Mdot
.70196 .68627 Mdot
.56078 .5451 Mdot
.66275 .6549 Mdot
.9451 .91373 Mdot
.91765 .67059 Mdot
.80784 .46275 Mdot
.24706 .21961 Mdot
.18824 .15686 Mdot
.35294 .18824 Mdot
.99608 .58039 Mdot
1 .61961 Mdot
.86275 .45882 Mdot
.91373 .52157 Mdot
.90588 .36863 Mdot
.83922 .40392 Mdot
.30588 .28627 Mdot
.20392 .19608 Mdot
.16078 .16078 Mdot
.16471 .1098 Mdot
.57255 .55686 Mdot
.3451 .32157 Mdot
.86667 .87451 Mdot
.54118 .23922 Mdot
1 .9451 Mdot
.76078 .41176 Mdot
.66667 .52941 Mdot
.49412 .47059 Mdot
.90196 .87843 Mdot
.97255 .95294 Mdot
.93725 .90588 Mdot
.83529 .58824 Mdot
.80392 .46275 Mdot
.52157 .48627 Mdot
.18431 .15294 Mdot
.34118 .14902 Mdot
.9098 .44706 Mdot
.96078 .57255 Mdot
.98431 .58824 Mdot
1 .60784 Mdot
.92549 .38824 Mdot
.74902 .38431 Mdot
.26275 .24706 Mdot
.15294 .1451 Mdot
.14902 .1451 Mdot
.17255 .11765 Mdot
.59216 .56863 Mdot
.73333 .7098 Mdot
.87059 .87843 Mdot
.52157 .21961 Mdot
1 .94902 Mdot
.81176 .43529 Mdot
.82745 .73333 Mdot
.36863 .33725 Mdot
.52157 .49412 Mdot
.92941 .90588 Mdot
.95294 .9098 Mdot
.76863 .51765 Mdot
.80784 .46667 Mdot
.47059 .42745 Mdot
.15294 .13333 Mdot
.33333 .1098 Mdot
.93725 .42745 Mdot
.92549 .4549 Mdot
.94902 .49804 Mdot
.97647 .53725 Mdot
.95294 .41176 Mdot
.52941 .24706 Mdot
.19216 .18824 Mdot
.14902 .14902 Mdot
.15294 .14902 Mdot
.16471 .1098 Mdot
.62745 .60392 Mdot
.6902 .65882 Mdot
.86667 .87451 Mdot
.51373 .21176 Mdot
1 .96863 Mdot
.83137 .42353 Mdot
.86275 .8 Mdot
.34902 .30196 Mdot
.38431 .35686 Mdot
.91765 .89412 Mdot
.93725 .89412 Mdot
.72941 .47843 Mdot
.81569 .48235 Mdot
.29804 .24314 Mdot
.23137 .2 Mdot
.32941 .07451 Mdot
.95294 .41176 Mdot
.94902 .43137 Mdot
.91373 .41569 Mdot
.92157 .43529 Mdot
.95294 .4 Mdot
.43137 .19608 Mdot
.15294 .14902 Mdot
.16078 .16863 Mdot
.16078 .15294 Mdot
.17647 .12157 Mdot
.58431 .56863 Mdot
.20392 .17255 Mdot
.87059 .87059 Mdot
.5098 .21176 Mdot
.85098 .72157 Mdot
.85882 .49412 Mdot
.89804 .8549 Mdot
.31373 .26667 Mdot
.25882 .21569 Mdot
.93725 .90196 Mdot
.59216 .53725 Mdot
.95294 .72941 Mdot
.57255 .32941 Mdot
.27843 .23529 Mdot
.39608 .36863 Mdot
.47059 .09412 Mdot
.93725 .39608 Mdot
.93725 .40392 Mdot
.94118 .40784 Mdot
.93725 .4 Mdot
.92157 .35686 Mdot
.23922 .09412 Mdot
.12941 .13725 Mdot
.22353 .23137 Mdot
.14902 .14902 Mdot
.59608 .54902 Mdot
.35294 .32941 Mdot
.45882 .43922 Mdot
.86275 .87059 Mdot
.83137 .45098 Mdot
.62353 .34902 Mdot
.79608 .48235 Mdot
.77647 .71373 Mdot
.7098 .65882 Mdot
.73725 .6902 Mdot
.95294 .91765 Mdot
.58039 .51373 Mdot
1 .75686 Mdot
.29412 .14902 Mdot
.25098 .21176 Mdot
.54902 .5098 Mdot
.85098 .37255 Mdot
.93725 .38431 Mdot
.9451 .39216 Mdot
.9451 .39216 Mdot
.94118 .38039 Mdot
.92941 .36471 Mdot
.21176 .14118 Mdot
.15294 .17647 Mdot
.24314 .26275 Mdot
.12941 .12549 Mdot
.95686 .92941 Mdot
.55294 .52941 Mdot
.73725 .71373 Mdot
.86667 .85882 Mdot
.60392 .21176 Mdot
.88627 .40392 Mdot
.80392 .6549 Mdot
.81176 .71765 Mdot
.6 .55294 Mdot
.94902 .90196 Mdot
.78824 .77647 Mdot
1 .84314 Mdot
.8549 .50196 Mdot
.24706 .20392 Mdot
.27059 .23922 Mdot
.59216 .49804 Mdot
.9451 .39216 Mdot
.95294 .39216 Mdot
.9451 .38431 Mdot
.9451 .38431 Mdot
.93725 .36078 Mdot
.87451 .37255 Mdot
.18039 .17647 Mdot
.27059 .28627 Mdot
.13333 .14118 Mdot
.24314 .21569 Mdot
.88627 .88627 Mdot
.64314 .61961 Mdot
.83922 .80784 Mdot
.9098 .85098 Mdot
.5451 .33333 Mdot
.87059 .37255 Mdot
.87843 .80784 Mdot
.36078 .28627 Mdot
.28627 .23529 Mdot
.38039 .32549 Mdot
.4 .38039 Mdot
.7451 .46667 Mdot
.77255 .4549 Mdot
.24706 .22745 Mdot
.25098 .22353 Mdot
.66667 .41569 Mdot
.94118 .38431 Mdot
.90588 .40392 Mdot
.93333 .38824 Mdot
.93333 .38824 Mdot
.93333 .37255 Mdot
.79216 .45098 Mdot
.18824 .18824 Mdot
.20392 .21569 Mdot
.25882 .24706 Mdot
.39216 .34118 Mdot
.48627 .48235 Mdot
.37255 .32549 Mdot
.88235 .87451 Mdot
.81569 .62353 Mdot
1 .95686 Mdot
.86275 .49412 Mdot
.81176 .7451 Mdot
.44706 .4 Mdot
.3098 .2549 Mdot
.4549 .42745 Mdot
.83922 .77255 Mdot
1 .76471 Mdot
.39216 .23529 Mdot
.27843 .24706 Mdot
.25098 .21176 Mdot
.83137 .38039 Mdot
.92941 .39608 Mdot
.69804 .31765 Mdot
.88235 .37255 Mdot
.90196 .37647 Mdot
.90588 .36078 Mdot
.23922 .10196 Mdot
.14118 .14118 Mdot
.2902 .28235 Mdot
.42353 .40392 Mdot
.71373 .68627 Mdot
.35686 .34902 Mdot
.81961 .76078 Mdot
.86667 .87451 Mdot
.75686 .42745 Mdot
.67843 .38824 Mdot
.8902 .7098 Mdot
.90588 .86275 Mdot
.87059 .82745 Mdot
.89804 .85882 Mdot
.53333 .51765 Mdot
.98431 .78824 Mdot
.85098 .47843 Mdot
.26667 .20784 Mdot
.27059 .23529 Mdot
.27843 .18431 Mdot
.93725 .40392 Mdot
.88627 .47451 Mdot
.77255 .40784 Mdot
.63922 .25882 Mdot
.71373 .30196 Mdot
.84314 .35294 Mdot
.15294 .12941 Mdot
.36471 .35686 Mdot
.38039 .36078 Mdot
.18039 .15686 Mdot
.88627 .88627 Mdot
.89412 .8902 Mdot
.43137 .39216 Mdot
.88235 .86667 Mdot
.56863 .36078 Mdot
.92549 .52941 Mdot
.52157 .47059 Mdot
.48627 .47059 Mdot
.47843 .44314 Mdot
.56078 .53333 Mdot
.23529 .16078 Mdot
.84706 .59608 Mdot
.78824 .49412 Mdot
.23529 .19608 Mdot
.24314 .21569 Mdot
.44706 .09804 Mdot
.92157 .38824 Mdot
1 .87059 Mdot
.5451 .26275 Mdot
.74902 .54902 Mdot
.58824 .3451 Mdot
.77255 .43922 Mdot
.42745 .43922 Mdot
.26275 .25098 Mdot
.16471 .14902 Mdot
.14902 .12549 Mdot
.88235 .88235 Mdot
.8 .7451 Mdot
.87451 .87451 Mdot
.72549 .50588 Mdot
.91373 .78431 Mdot
.96863 .81961 Mdot
.43137 .4 Mdot
.37647 .34118 Mdot
.38039 .35294 Mdot
.40392 .38431 Mdot
.86667 .60392 Mdot
.83137 .46667 Mdot
.29412 .21176 Mdot
.25098 .22353 Mdot
.25098 .19216 Mdot
.92157 .38431 Mdot
.80392 .47059 Mdot
1 .85098 Mdot
.97255 .87451 Mdot
.96863 .85098 Mdot
1 .74118 Mdot
.42353 .35294 Mdot
.23922 .24314 Mdot
.18824 .17647 Mdot
.18431 .16863 Mdot
.9098 .9098 Mdot
.92941 .92549 Mdot
.51373 .46667 Mdot
.87843 .87059 Mdot
.61961 .36863 Mdot
.86667 .50196 Mdot
.37255 .32157 Mdot
.34902 .31765 Mdot
.35686 .32549 Mdot
.3451 .33725 Mdot
.90588 .72549 Mdot
.98039 .72157 Mdot
.80392 .52157 Mdot
.27059 .23137 Mdot
.23529 .21569 Mdot
.48627 .11765 Mdot
.90588 .41176 Mdot
.9451 .8549 Mdot
.87451 .75294 Mdot
.94902 .76078 Mdot
.96078 .85098 Mdot
.79608 .45098 Mdot
.21961 .23137 Mdot
.23529 .22745 Mdot
.18039 .16078 Mdot
.12941 .10588 Mdot
.87843 .88627 Mdot
.66667 .60392 Mdot
.87451 .87451 Mdot
.57647 .3451 Mdot
.63137 .46275 Mdot
.61961 .44706 Mdot
.3098 .21176 Mdot
.29412 .2 Mdot
.28235 .20392 Mdot
.40392 .32941 Mdot
.78431 .49412 Mdot
.92549 .47843 Mdot
.25098 .19608 Mdot
.23922 .21961 Mdot
.27059 .16078 Mdot
.93725 .39608 Mdot
.50588 .36863 Mdot
.54902 .36471 Mdot
1 .8549 Mdot
.9098 .81961 Mdot
.60392 .20392 Mdot
.24706 .22353 Mdot
.25882 .26667 Mdot
.17255 .15686 Mdot
.16863 .1451 Mdot
.88627 .88627 Mdot
.89804 .88235 Mdot
.69412 .67059 Mdot
.90196 .8549 Mdot
.58824 .50196 Mdot
.73333 .33333 Mdot
.88627 .6549 Mdot
.77647 .63922 Mdot
.83137 .62353 Mdot
.55686 .52549 Mdot
.7451 .47451 Mdot
.9451 .55686 Mdot
.68235 .50588 Mdot
.25098 .20784 Mdot
.23922 .2 Mdot
.85882 .40784 Mdot
.81176 .47059 Mdot
.99216 .88235 Mdot
.94118 .85882 Mdot
.78824 .47451 Mdot
.99608 .84706 Mdot
.48235 .24314 Mdot
.21176 .22353 Mdot
.17255 .16471 Mdot
.15686 .15294 Mdot
.50588 .4902 Mdot
.88627 .88627 Mdot
.41569 .37647 Mdot
.87059 .87843 Mdot
.70588 .47451 Mdot
.81176 .43529 Mdot
.87843 .51373 Mdot
.91765 .68235 Mdot
.82745 .55686 Mdot
.95294 .88235 Mdot
.60392 .39216 Mdot
.9451 .55686 Mdot
.77255 .50588 Mdot
.21176 .16863 Mdot
.28235 .25098 Mdot
.62353 .24314 Mdot
.83137 .44706 Mdot
.96078 .86667 Mdot
.93725 .87059 Mdot
.8549 .46275 Mdot
.96471 .83137 Mdot
.77647 .45098 Mdot
.20392 .21176 Mdot
.14902 .14118 Mdot
.14902 .1451 Mdot
.15294 .11765 Mdot
.8902 .8902 Mdot
.52549 .48627 Mdot
.87843 .87843 Mdot
.45098 .25098 Mdot
.72941 .41569 Mdot
.90588 .43137 Mdot
.85882 .52549 Mdot
.78824 .50588 Mdot
.77255 .69412 Mdot
.81176 .60784 Mdot
.95294 .51765 Mdot
.78824 .52157 Mdot
.43922 .39608 Mdot
.27451 .23922 Mdot
.67059 .28627 Mdot
.82353 .47059 Mdot
.98824 .87843 Mdot
.93333 .86667 Mdot
.83137 .4549 Mdot
1 .83137 Mdot
.73725 .43529 Mdot
.22353 .22353 Mdot
.14902 .13333 Mdot
.14902 .13333 Mdot
.17647 .13333 Mdot
.88627 .88627 Mdot
.45098 .39608 Mdot
.87843 .87843 Mdot
.44706 .26275 Mdot
.6 .35686 Mdot
.96078 .42745 Mdot
.8902 .48235 Mdot
1 .72157 Mdot
.54118 .45882 Mdot
.97647 .74118 Mdot
.93725 .4549 Mdot
.77647 .5098 Mdot
.53333 .4902 Mdot
.25882 .22353 Mdot
.69412 .29804 Mdot
.81569 .50588 Mdot
1 .87451 Mdot
.94902 .86667 Mdot
.84706 .49412 Mdot
1 .83529 Mdot
.72157 .43922 Mdot
.23137 .22353 Mdot
.14902 .13333 Mdot
.15294 .13333 Mdot
.21961 .17647 Mdot
.88627 .88627 Mdot
.62745 .56863 Mdot
.87451 .87451 Mdot
.58039 .41176 Mdot
.63137 .3451 Mdot
.97255 .42353 Mdot
.89412 .46667 Mdot
.96471 .67059 Mdot
.32549 .22745 Mdot
.9098 .56863 Mdot
.94118 .42353 Mdot
.51373 .3451 Mdot
.37255 .33725 Mdot
.21176 .17255 Mdot
.9098 .43529 Mdot
.40784 .23529 Mdot
.49804 .32941 Mdot
.97647 .85098 Mdot
.47451 .2549 Mdot
.63922 .27843 Mdot
.36863 .18431 Mdot
.23137 .21961 Mdot
.16078 .14902 Mdot
.1451 .1098 Mdot
.88235 .84706 Mdot
.8902 .8902 Mdot
.58824 .53333 Mdot
.87451 .87451 Mdot
.51765 .38431 Mdot
.9098 .42353 Mdot
.95686 .42353 Mdot
.90196 .48627 Mdot
.8549 .63529 Mdot
.98039 .75294 Mdot
.93725 .46275 Mdot
.92157 .40392 Mdot
.26667 .23922 Mdot
.47451 .43529 Mdot
.27059 .12941 Mdot
.87059 .43529 Mdot
.9451 .87059 Mdot
.98039 .90588 Mdot
.83922 .40392 Mdot
.9451 .8549 Mdot
.88235 .38039 Mdot
.21569 .17647 Mdot
.16078 .15294 Mdot
.17647 .15294 Mdot
.19216 .14902 Mdot
.88627 .88627 Mdot
.93333 .92941 Mdot
.51765 .49412 Mdot
.96078 .88235 Mdot
1 .96863 Mdot
.89412 .36863 Mdot
.95294 .41961 Mdot
.9098 .47059 Mdot
.94118 .65882 Mdot
.93333 .48235 Mdot
.9451 .40784 Mdot
.80784 .52157 Mdot
.26667 .24706 Mdot
.52549 .49412 Mdot
.75294 .33725 Mdot
.36078 .22745 Mdot
.45882 .28627 Mdot
.98431 .84314 Mdot
.47451 .26275 Mdot
.65882 .31765 Mdot
.53725 .31373 Mdot
.22745 .21569 Mdot
.14902 .14118 Mdot
.16471 .12549 Mdot
.45098 .43137 Mdot
.88627 .88627 Mdot
.85098 .81176 Mdot
.88235 .87451 Mdot
.7098 .61569 Mdot
.77255 .42745 Mdot
.92157 .39608 Mdot
.94902 .44314 Mdot
.8902 .49412 Mdot
.9098 .4549 Mdot
.9451 .40784 Mdot
.87451 .39608 Mdot
.28235 .24314 Mdot
.2549 .23137 Mdot
.63529 .39216 Mdot
.45882 .23922 Mdot
1 .87451 Mdot
.94118 .86667 Mdot
.83529 .48627 Mdot
1 .83529 Mdot
.83137 .42745 Mdot
.19608 .18431 Mdot
.15686 .15294 Mdot
.12157 .09804 Mdot
.44706 .41961 Mdot
.8902 .8902 Mdot
.86667 .85098 Mdot
.89412 .8902 Mdot
.5451 .45098 Mdot
.69804 .56471 Mdot
.86275 .43137 Mdot
.91765 .39608 Mdot
.95686 .46275 Mdot
.9451 .4549 Mdot
.94902 .40784 Mdot
.94902 .41569 Mdot
.30588 .22353 Mdot
.25882 .24314 Mdot
.46667 .30588 Mdot
.48235 .24706 Mdot
1 .88235 Mdot
.93725 .87843 Mdot
.80784 .45882 Mdot
.97255 .83922 Mdot
.87843 .40784 Mdot
.16078 .14902 Mdot
.15686 .1451 Mdot
.2549 .24314 Mdot
.33725 .31373 Mdot
.88627 .88627 Mdot
.91373 .91373 Mdot
.8902 .87451 Mdot
.94118 .87059 Mdot
.96471 .89804 Mdot
.76863 .42353 Mdot
.90196 .41176 Mdot
.94902 .42745 Mdot
.96471 .43137 Mdot
.95686 .40784 Mdot
.9098 .41176 Mdot
.30588 .23529 Mdot
.27059 .24706 Mdot
.38431 .13725 Mdot
.95686 .79216 Mdot
.65098 .43529 Mdot
.94118 .86275 Mdot
.45882 .2549 Mdot
.85882 .6 Mdot
.81176 .46275 Mdot
.16471 .16078 Mdot
.20784 .2 Mdot
.45882 .45098 Mdot
.15294 .12549 Mdot
.88627 .88627 Mdot
.69804 .68235 Mdot
.88235 .87843 Mdot
.36863 .29804 Mdot
.84706 .71373 Mdot
.81569 .43529 Mdot
.91765 .38431 Mdot
.95686 .40784 Mdot
.95686 .40784 Mdot
.94118 .40784 Mdot
.3098 .17255 Mdot
.27059 .23529 Mdot
.34902 .19608 Mdot
.7098 .41176 Mdot
.89412 .6549 Mdot
.9451 .87059 Mdot
.58824 .45098 Mdot
1 .79608 Mdot
.82353 .42353 Mdot
.18039 .17255 Mdot
.47843 .46275 Mdot
.21961 .21176 Mdot
.18039 .14118 Mdot
.88627 .88627 Mdot
.90196 .89412 Mdot
.90196 .89804 Mdot
.57647 .50588 Mdot
.93725 .81961 Mdot
.78824 .42745 Mdot
.96078 .41569 Mdot
.92941 .38039 Mdot
.9451 .40784 Mdot
.91765 .43922 Mdot
.21569 .15686 Mdot
.26275 .22745 Mdot
.75686 .37255 Mdot
.82353 .51373 Mdot
.64706 .36863 Mdot
.99216 .85098 Mdot
.98431 .87059 Mdot
.93333 .38431 Mdot
.39608 .2902 Mdot
.48627 .47059 Mdot
.16471 .14902 Mdot
.16471 .16078 Mdot
.95686 .94902 Mdot
.8902 .8902 Mdot
.32941 .30588 Mdot
.8902 .87451 Mdot
.74118 .73725 Mdot
.70588 .50196 Mdot
.92157 .40392 Mdot
.93333 .38039 Mdot
.92157 .37255 Mdot
.9451 .43529 Mdot
.22745 .12157 Mdot
.23137 .19608 Mdot
.74902 .37255 Mdot
.87451 .45098 Mdot
.74902 .36471 Mdot
.9098 .63922 Mdot
1 .78039 Mdot
.92941 .37647 Mdot
.43137 .35294 Mdot
.20392 .2 Mdot
.17255 .15686 Mdot
.16863 .15294 Mdot
.93333 .92549 Mdot
.8902 .8902 Mdot
.40784 .37255 Mdot
.8902 .87451 Mdot
.92157 .91765 Mdot
.83922 .42353 Mdot
.94118 .41569 Mdot
.9451 .42353 Mdot
.89804 .37647 Mdot
.43137 .14902 Mdot
.18824 .1098 Mdot
.34902 .13333 Mdot
.93725 .42745 Mdot
.91373 .41569 Mdot
.78824 .39608 Mdot
.78824 .4549 Mdot
.91765 .4 Mdot
.61569 .43137 Mdot
.16471 .14902 Mdot
.15294 .14902 Mdot
.17255 .15294 Mdot
.38039 .35294 Mdot
.8902 .8902 Mdot
.47843 .43922 Mdot
.88235 .87843 Mdot
.73725 .72157 Mdot
.80392 .45098 Mdot
.94118 .43529 Mdot
.90196 .44314 Mdot
.9098 .43529 Mdot
.55686 .20784 Mdot
.22745 .10588 Mdot
.38431 .07451 Mdot
.93725 .41961 Mdot
.93333 .41961 Mdot
.92157 .4549 Mdot
.88235 .42745 Mdot
.93725 .38431 Mdot
.26275 .18431 Mdot
.16078 .1451 Mdot
.15686 .1451 Mdot
.16078 .14118 Mdot
.96078 .95294 Mdot
.89412 .89412 Mdot
.81569 .76078 Mdot
.89412 .87843 Mdot
.91373 .91765 Mdot
.75686 .43529 Mdot
.84706 .43137 Mdot
.76471 .43922 Mdot
.81569 .4549 Mdot
.65098 .33333 Mdot
.24314 .06667 Mdot
.9098 .44314 Mdot
.94902 .41569 Mdot
.93725 .41961 Mdot
.94118 .42745 Mdot
.93333 .40392 Mdot
.90196 .4 Mdot
.20392 .2 Mdot
.16863 .14902 Mdot
.14902 .13725 Mdot
.15686 .13333 Mdot
.88627 .88627 Mdot
.90588 .8902 Mdot
.56078 .54118 Mdot
.94902 .92941 Mdot
.76471 .69804 Mdot
.6902 .43922 Mdot
.7451 .58039 Mdot
.65098 .47059 Mdot
.65882 .43137 Mdot
.53725 .25098 Mdot
.42745 .0549 Mdot
.95686 .44314 Mdot
.92941 .41176 Mdot
.92941 .41176 Mdot
.95294 .41569 Mdot
.93725 .38431 Mdot
.30196 .18431 Mdot
.16863 .15294 Mdot
.17255 .14118 Mdot
.1451 .12941 Mdot
.89804 .8902 Mdot
.8902 .8902 Mdot
.62353 .58039 Mdot
.88235 .87843 Mdot
.84314 .86275 Mdot
.73725 .60784 Mdot
1 .96471 Mdot
.91765 .8549 Mdot
.58431 .47451 Mdot
.6549 .40784 Mdot
.67059 .30196 Mdot
.93333 .44314 Mdot
.94902 .43922 Mdot
.94118 .41961 Mdot
.94902 .41176 Mdot
.94902 .4 Mdot
.3098 .16471 Mdot
.18039 .16078 Mdot
.17255 .13725 Mdot
.14902 .13333 Mdot
.95294 .9451 Mdot
.89412 .89412 Mdot
.49412 .46275 Mdot
.88235 .87843 Mdot
.96471 .98431 Mdot
.99216 .96471 Mdot
.70588 .63137 Mdot
.67059 .45098 Mdot
.81569 .41176 Mdot
.89412 .41176 Mdot
.95686 .45098 Mdot
.96471 .44314 Mdot
.95686 .4 Mdot
.8 .46275 Mdot
.18431 .13333 Mdot
.14902 .1451 Mdot
.16863 .1451 Mdot
.24314 .22353 Mdot
.89412 .8902 Mdot
.89804 .89412 Mdot
.88627 .88627 Mdot
.39216 .41569 Mdot
.8902 .78824 Mdot
.76078 .49804 Mdot
.78039 .41569 Mdot
.84314 .40784 Mdot
.8902 .41961 Mdot
.92549 .41569 Mdot
.86275 .43137 Mdot
.21176 .11373 Mdot
.05098 .04314 Mdot
.07059 .04706 Mdot
.24314 .23922 Mdot
.90588 .89804 Mdot
.88627 .88627 Mdot
.87451 .87451 Mdot
.39216 .39216 Mdot
1 .95294 Mdot
.85098 .70196 Mdot
.70588 .45882 Mdot
.76078 .41961 Mdot
.80392 .38824 Mdot
.84314 .38431 Mdot
.53725 .30196 Mdot
.4902 .48235 Mdot
.42745 .41961 Mdot
.44706 .44706 Mdot
.56078 .58039 Mdot
.89412 .8902 Mdot
.88627 .8902 Mdot
.9451 .91765 Mdot
1 .96471 Mdot
.93333 .77647 Mdot
.83529 .60392 Mdot
.77255 .46667 Mdot
.72941 .39216 Mdot
.77255 .6549 Mdot
.91765 .90196 Mdot
.90588 .89804 Mdot
.21569 .25098 Mdot
.31765 .33725 Mdot
.89804 .89412 Mdot
.88627 .89804 Mdot
.28235 .27059 Mdot
1 .94902 Mdot
.95686 .83529 Mdot
.81961 .67059 Mdot
.81961 .78431 Mdot
.87451 .86667 Mdot
.60392 .59608 Mdot
.27059 .32157 Mdot
.28627 .32941 Mdot
.8 .80784 Mdot
.78431 .80392 Mdot
.82745 .82353 Mdot
.62353 .60392 Mdot
.2549 .26275 Mdot
.61176 .61569 Mdot
.53725 .58039 Mdot
.6902 .73333 Mdot
.87451 .87843 Mdot
.89804 .9098 Mdot
.95686 .96863 Mdot
.39608 .44314 Mdot
.23922 .28627 Mdot
.9098 .93725 Mdot
.62353 .66667 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002OoooolH00000003oomo0000
0000000000@0000000?oogl000000?ooO`0010000002oomo00H0000000?oogl00000000000006000
00000oooO`0000000000000;00000004oomo000000000000oomo05/000004OoooolAo`0000030?mo
0?l0003o000000Co00000`3oO`03o`0000040?mo0?l0003o00000?mo00So000000<0ogl0o`000?l0
00007Ol000000`3oO`3o0000o`00001Yo`0000[ooooo0009ooooo`0300000?oooooooooo00Oooooo
00<0X23`ooooooooool03Oooool00oooO`3oooooooooo`0Yooooo`03oomo0?oooooooooo06cooooo
00<00000ooooooooool03oooool00ol0003oooooooooo`07ooooo`030:0Pl?oooooooooo00Kooooo
00<0ogl0ooooooooool07Oooool00`3oO`3oooooooooo`1oooooo`03o`000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo03cooooo00?oogl0ooooooooool0;?ooool00oooO`3ooooooooo
o`14ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00`3oO`3ooooooooo
o`0Nooooo`030?mo0?oooooooooo06?ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool09Oooool00`2P8?3ooooo0:0Pl02:ooooo`0300000?oooooooooo00oooooo00Oo0000
oooooooooooooooo0:0Pl?ooool0X23`0:kooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool08oooool00`2P8?3oooooooooo`0Kooooo`03oomo0?oooooooooo06kooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`030:0Pl?oooooooooo01Cooooo00<0
ogl0ooooooooool0TOooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0S
ooooo`030:0Pl?oooooooooo00cooooo00<0X23`ooooooooool02_ooool00oooO`3oooooooooo`0R
ooooo`03oomo0?oooooooooo04_ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`07
ooooo`030:0Pl?oooooooooo00Oooooo00<0X23`ooooooooool03_ooool00`3oO`3oooooooooo`0>
ooooo`030?mo0?oooooooooo07cooooo00?o0000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool03?ooool00`2P8?3oooooooooo`0@ooooo`03oomo0?oooooooooo01Gooooo00<0X23`oooo
ooooool04Oooool00oooO`3oooooooooo`03ooooo`030:0Pl?ooO`3ooooo05kooooo00<00000oooo
ooooool03oooool01?l0003oooooooooooooool20:0Pl0Sooooo00<0X23`ooooooooool01Oooool0
0`3oO`3oooooooooo`02ooooo`030?mo0?ooool0ogl000Oooooo00<0ogl0ooooooooool0SOooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0[ooooo`03oomo0?oooooooooo
01cooooo00<0X23`ooooooooool0IOooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo
00Oooooo00<0X23`ooooooooool04Oooool00`3oO`3oooooooooo`2Dooooo`03o`000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo00Kooooo00<0X23`ooooooooool03_ooool00oooO`3o
oooooomo000=ooooo`03oomo0?ooool0X23`00;ooooo00<0X23`ooooooooool01Oooool00`3oO`00
X23`ooooo`08ooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool04Oooool00oooO`3o
ooooooooo`07ooooo`03oomo0?oooooooooo04Wooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`05ooooo`0:0:0Pl?ooooooooooooooo`2P8?00ogl0ooooo`3oO`3ooooo0:0Pl0?ooooo
00<0ogl0ooooooooool01_ooool00`3oO`3oooooooooo`07ooooo`030?mo0?oooooooooo00Gooooo
00<0ogl0ooooooooool00_ooool00`3oO`3oooooooooo`0Oooooo`030?mo0?oooooooooo05_ooooo
00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool07oooool01?ooO`3ooooooooo
ooooO`05ooooo`03oomo0?oooooooooo013ooooo00?oogl0ooooooooool05Oooool00`2P8?3ooooo
ooooo`0Booooo`03oomo0?oooooooooo04Oooooo00<00000ooooooooool03oooool01?l0003ooooo
ooooo`3oO`08ooooo`030:0Pl?oooooooooo00Oooooo00<0ogl0ooooo`3oO`000_ooool00`3oO`3o
ooooooooo`04ooooo`030?mo0?oooooooooo00Gooooo00<0ogl0ooooooooool0R?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`0:ooooo`030:0Pl?oooooooooo00cooooo
00<0X23`ooooo`2P8?008?ooool00`2P8?3oooooooooo`0;ooooo`80X23`6?ooool2oomo01gooooo
00?oogl0ooooooooool0;?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo
00<0X23`ooooooooool00_ooool01@2P8?3ooooo0:0Pl?ooool0X23`01;ooooo00<0X23`oooooooo
ool02_ooool20?mo04Wooooo00<0ogl0ooooooooool0=_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0<ooooo`060?mo0?ooooooooooooooooooO`00X23`5_ooool00`2P
8?3oooooooooo`0?ooooo`030:0Pl?ooool0X23`00Wooooo00<0X23`ooooooooool0JOooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo0P2P8?02ooooo`80X23`Xoooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0:ooooo`050:0Pl?oooooooooooooo
o`2P8?001?ooool00`2P8?3oooooooooo`0>ooooo`030:0Pl?oooooooooo02;ooooo00<0ogl0oooo
ooooool0I_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00D0X23`oooo
oooooooooooo0:0Pl003ooooo`040:0Pl?oooooooooo0:0Pl2[ooooo00<0ogl0ooooooooool0Looo
ool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`06ooooo`060:0Pl?oooooo
ooooooooo`2P8?3ooooo0`2P8?02ooooo`030:0Pl?oooooooooo00?ooooo00<0X23`ooooooooool0
0oooool01OooO`3ooooooomo0?ooool0X23`00Kooooo00Googl0oooooooooooooooo0?mo0003oooo
o`03oomo0?oooooooooo00Cooooo00<0X23`ooooooooool01Oooool01OooO`3oooooooooooooool0
X23`00Oooooo00?oogl0ooooooooool01?ooool0102P8?3oooooooooooooO`08ooooo`03oomo0?oo
oooooooo057ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`07ooooo`030:0Pl03o
O`00X23`00;ooooo102P8?001?ooool0ogl00?mo002P8?04ooooo`030?mo0?oooooooooo00;ooooo
00@0ogl0ooooo`3oO`00ogl09Oooool00`3oO`3oooooooooo`05ooooo`030?mo0?oooooooooo067o
oooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool04_ooool0102P8?3ooooo
ooooooooO`0aooooo`03oomo0?oooooooooo00cooooo00Googl0oooooooooooooooo0:0Pl004oooo
o`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool0AOooool00`00003oooooooooo`0?oooo
o`03o`000?oooooooooo00_ooooo00<0ogl0ooooo`2P8?000_ooool00`2P8?3oooooooooo`0;oooo
o`040?mo0?oooooooooo0?mo00Kooooo0P3oO`0Wooooo`030?mo0?oooooooooo05kooooo00?o0000
ooooooooool02?ooool000Wooooo00<00000ooooooooool03_ooool0102P8?3oooooooooooooO`0@
ooooo`030:0Pl?oooooooooo00Cooooo00?oogl0ooooooooool00_ooool00`2P8?3oooooooooo`0W
ooooo`030:0Pl?oooooooooo02?ooooo00?oogl0ooooooooool0<Oooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo00cooooo0`2P8?02ooooo`030?mo0?oooooooooo00Oooooo00<0X23`
ooooooooool00oooool00`3oO`3oooooooooo`0hooooo`030?mo0?oooooooooo05?ooooo00?o0000
ooooooooool02?ooool000Wooooo00<00000ooooooooool03Oooool30:0Pl006ooooo`2P8?3ooooo
oomo0?ooool0X23`0_ooool00oooO`3oooooooooo`0;ooooo`030:0Pl?ooool0X23`00Gooooo00?o
ogl00:0Pl02P8?004?ooool2oomo00?ooooo00<0X23`ooooooooool00_ooool00`2P8?3ooooooooo
o`04ooooo`030:0Pl?oooooooooo01Gooooo00?oogl0ooooooooool0AOooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo00cooooo00<0X23`ooooo`2P8?000`2P8?000`3oO`00X23`oooo
o`03ooooo`060:0Pl?ooooooooooooooo`3oO`00X23`1oooool00`3oO`3oooooooooo`04ooooo`03
0?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool0O_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`0Aooooo`<0X23`0_ooool0102P8?3oooooooooooooO`0<ooooo`03
0:0Pl?oooooooooo01Oooooo00<0X23`ooooo`2P8?001?ooool00oooO`3oooooooooo`0Kooooo`03
oomo0?oooooooooo00gooooo00?oogl0ooooooooool0>_ooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo00[ooooo00D0X23`oooooooooooooooo0:0Pl002ooooo`<0X23`7oooool00`3o
O`3oooooooooo`0Uooooo`030?mo0?oooooooooo05Cooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool04Oooool0102P8?3ooooo0:0Pl?ooool30:0Pl004oomo0?oooooooooo
oomo00;ooooo00<0X23`oomo0?ooool00_ooool01?ooO`3oooooooooooooO`03ooooo`80X23`2Ooo
ool01_ooO`3ooooo0:0Pl02P8?3ooooo0:0Pl0;ooooo00@0X23`ooooooooooooogl03oooool00`2P
8?3ooooo0:0Pl00Gooooo`03oomo0?oooooooooo04Gooooo00<00000ooooooooool03oooool00ol0
003oooooooooo`0:ooooo`040:0Pl?ooool0X23`ooooo`H0X23`00D0ogl00:0Pl?oooooooooo0?mo
0002ooooo`030?mo0?oooooooooo00Cooooo00@0ogl0ooooooooool0ogl03?ooool00`2P8?3ooooo
ooooo`1mooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01?ooooo0P2P
8?001?ooool0X23`ooooooooO`03ooooo`040:0Pl?oooooooooo0:0Pl0Cooooo00<0X23`oooooooo
ool07_ooool00oooO`3oooooooooo`06ooooo`030:0Pl?oooooooooo00Gooooo00?oogl0oooooooo
ool0FOooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00D0X23`oooooooo
ool0X23`ooooo`020:0Pl003ooooo`2P8?3ooooo02kooooo00<0ogl0ooooooooool00_ooool00`3o
O`3oooooooooo`1Tooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Co
oooo1P2P8?000oooooooogl0ooooo`04ooooo`03oomo0?oooooooooo00;ooooo00<0X23`oomo0?oo
ool01oooool00oooO`00ogl0ooooo`07ooooo`030:0Pl?oooooooooo00Wooooo0_ooO`0:ooooo`03
oomo0?oooooooooo00[ooooo00<0X23`ooooo`2P8?003Oooool00`3oO`3oooooooooo`10ooooo`03
00000?oooooooooo00oooooo00?o0000ooooooooool04?ooool20:0Pl0030?mo002P8?00X23`0080
X23`00?ooooo0:0Pl?ooool01Oooool0103oO`3ooooo0?mo002P8?02ooooo`050?mo0?oooooooooo
ooooo`2P8?001?ooool00`3oO`3oooooooooo`21ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo01Gooooo00Coogl00:0Pl02P8?00X23`0_ooool00oooO`3ooooo0:0Pl006
ooooo`03oomo0?oooooooooo00_ooooo00<0X23`ooooooooool03?ooool00`2P8?3oooooooooo`0?
ooooo`03oomo0?oooooooooo03Cooooo00?oogl0ooooooooool09Oooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo00gooooo00L0X23`ooooo`3oO`3ooooo0?mo002P8?3ooooo00<0X23`
00<0ogl00:0Pl?ooool0JOooool00`3oO`3oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo01?ooooo00<0X23`ooooooooool01P2P8?000oooool0X23`oooo
o`02ooooo`80X23`0oooool00`2P8?3oooooooooo`0?ooooo`030:0Pl?oooooooooo00Oooooo00?o
ogl0ooooooooool04?ooool01@2P8?3oooooooooooooooooogl001Kooooo00?oogl0ooooooooool0
?oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo202P8?03ooooo`030?mo
0?oooooooooo00Cooooo00<0ogl0ooooooooool02Oooool00`3oO`3oooooooooo`1oooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01;ooooo102P8?000oooO`00X23`0:0P
l0020:0Pl003oomo002P8?3oogl00080X23`00Googl0ooooooooool0X23`oomo0007ooooo`03oomo
0?oooooooooo00kooooo00<0X23`ooooooooool04oooool00`2P8?3oooooooooo`0Eooooo`030:0P
l?oooooooooo00Oooooo00?oogl0ooooooooool0>_ooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo00cooooo00<0ogl0ooooooooool00_ooool80:0Pl005ooooo`2P8?00X23`ooooo`2P
8?002_ooool0102P8?3oooooooooo`3oO`04ooooo`030:0Pl?oooooooooo07oooooo00?o0000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool06?ooool20:0Pl003ooooo`2P8?00X23`00<0
X23`1?ooool01@2P8?3ooooo0:0Pl?ooool0X23`00cooooo00H0X23`oooooooooooooooo0:0Pl?oo
O`0;ooooo`030:0Pl?oooooooooo00cooooo00?oogl0ooooo`2P8?001oooool00oooO`3ooooooooo
o`0Uooooo`03oomo0?oooooooooo02Sooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`0?ooooo`030?mo0?ooool0X23`00?ooooo1`2P8?02ooooo`030:0Pl?oooooooooo00Sooooo00D0
ogl0oooooooooooooooo0:0Pl01>ooooo`030?mo0?oooooooooo03?ooooo00?o0000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool04oooool01`2P8?3oooooooooo`2P8?3ooooo0:0Pl?oo
O`00102P8?000oooO`00X23`0:0Pl002oomo00;ooooo00<0ogl0ooooooooool01_ooool00`2P8?3o
ooooooooo`02ooooo`07oomo0?ooooooooooooooo`2P8?3ooooooomo0003ooooo`05oomo0?oooooo
ooooooooooooO`000_ooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo00Kooooo00?o
ogl0ooooooooool01oooool01OooO`3ooooo0:0Pl?ooooooogl000_ooooo00?oogl0ooooooooool0
@?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00<0X23`ooooo`2P8?00
1?ooool20:0Pl0030?mo002P8?00X23`00<0X23`00Wooooo0:0Pl?ooool0ogl0ooooo`3oO`3ooooo
0:0Pl03oO`001Oooool00`3oO`3oooooooooo`07ooooo`060?mo0?oooooooooo0?mo0?ooool0ogl0
1oooool00`3oO`3oooooooooo`0Iooooo`030?mo0?oooooooooo05?ooooo00?o0000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool05?ooool0102P8?3oooooooooooooool20:0Pl003oooo
o`2P8?00X23`0080X23`00?ooooooomo0?ooool00_ooool00`2P8?3oooooooooo`03ooooo`03oomo
0?ooool0X23`00Kooooo00<0X23`ooooooooool00_ooool0102P8?3oooooooooooooO`03ooooo`03
0:0Pl?oooooooooo00kooooo00Soogl0oooooooooooooooo0:0Pl03oO`3ooooooomo03Gooooo00?o
ogl0ooooooooool08_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo0P2P
8?000oooool0X23`0:0Pl0040:0Pl0;ooooo00<0X23`ooooooooool01_ooool00`3oO`3ooooooooo
o`0Hooooo`030?mo0?oooooooooo00Kooooo00<0ogl0ooooooooool0=_ooool00`3oO`3ooooooooo
o`0[ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Kooooo00<0X23`
ooooooooool00_ooool01_ooO`3ooooo0:0Pl?ooO`00X23`ooooo`80X23`00?oogl0ooooooooool0
0oooool01?ooO`3oooooooooo`2P8?03ooooo`03oomo0?oooooooooo00[ooooo00?oogl0oooooooo
ool03?ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo037ooooo00?oogl0oooooooo
ool0:?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00<0ogl0oooooooo
ool00oooool01@2P8?3ooooo0?mo0?ooool0ogl000@0X23`00?ooooo0:0Pl03oO`002Oooool00`3o
O`3oooooooooo`0Aooooo`030?mo0?oooooooooo02Kooooo00<0ogl0ooooooooool0BOooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0>ooooo`030:0Pl?oooooooooo00?o
oooo00H0X23`oooooooooooooooo0:0Pl?ooool40:0Pl003oomo002P8?3oogl000<0X23`00?oogl0
ooooo`2P8?001oooool00`2P8?3oooooooooo`02ooooo`030:0Pl?ooool0X23`00Cooooo00?oogl0
ooooo`2P8?000oooool00oooO`3oooooooooo`08ooooo`030:0Pl?oooooooooo00;oogl01?ooool0
0oooO`00ogl0ooooo`03ooooo`03oomo002P8?3oogl000Cooooo00<0X23`ooooooooO`000_ooool0
1OooO`3ooooooomo0?ooool0X23`00Kooooo00?oogl0ooooooooool01_ooool00`2P8?3ooooooooo
o`0eooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00`2P8?3ooooo0:0P
l002ooooo`030:0Pl?ooool0X23`00;ooooo2@2P8?001Oooool0X23`ooooooooool0X23`013ooooo
00<0ogl0ooooooooool00oooool00`3oO`3oooooooooo`07ooooo`040?mo0?ooool0ogl00?mo00?o
oooo00<0X23`ooooooooool02_ooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo053o
oooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool07Oooool00`2P8?3oogl0
ooooo`02ooooo`;oogl05_ooool00oooO`3oooooooooo`0Dooooo`030:0Pl?oooooooooo00?ooooo
00?oogl0ooooooooO`001?ooool00`2P8?3oooooooooo`06ooooo`03oomo0?oooooooooo00Cooooo
00<0ogl0ooooooooO`00@Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo
00H0X23`ooooooooool0X23`0?mo0?ooool40?mo00Kooooo00<0ogl0ooooooooool00_ooool00`3o
O`3oooooooooo`04ooooo`030?mo0?ooool0X23`00Cooooo00<0ogl0ooooooooool08oooool00`3o
O`3oooooooooo`1Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo017o
oooo00<0X23`ooooooooool01?ooool00`2P8?3ooooo0:0Pl0040:0Pl003oomo002P8?3ooooo00<0
X23`00?oogl0ooooooooool01_ooool00oooO`3ooooo0:0Pl002ooooo`030:0Pl?ooool0X23`00Co
oooo00<0X23`oomo0?ooO`001Oooool00`2P8?3oooooooooo`02ooooo`040:0Pl?ooooooogl0oomo
00?ooooo00Coogl0ooooooooO`3oogl01Oooool0103oO`3oooooooooo`2P8?02oomo00030:0Pl?oo
ooooogl000;oogl00oooool00oooO`3oooooooooo`03ooooo`030:0Pl?ooooooogl000Cooooo00@0
X23`ooooooooool0ogl0??ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo
00D0X23`ooooooooool0X23`ooooo`040:0Pl0030?mo002P8?00X23`0080X23`0P3oO`020:0Pl006
ooooo`2P8?3oooooooooo`3oO`00X23`1?ooool20?mo00;ooooo00H0ogl0oooooooooooooooo0?mo
0?ooool20?mo0003ooooo`3oO`3ooooo00Sooooo00<0X23`ooooooooool01Oooool00`3oO`3ooooo
ooooo`0Iooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool0@_ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0?ooooo`030:0Pl?oooooooooo00Oooooo00L0
X23`oooooooooooooooo0:0Pl?ooool0X23`00;ooooo00@0X23`ooooooooooooogl02Oooool00`2P
8?3ooooooomo0002ooooo`030:0Pl?oooooooooo02?ooooo00Coogl0ooooooooO`3oogl00oooool0
1@2P8?3oooooooooooooool0X23`02cooooo00?oogl0ooooooooool07Oooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo017ooooo00<0X23`ooooo`2P8?000_ooool30:0Pl0;ooooo00D0
X23`0?mo003oO`3ooooo0:0Pl002ooooo`040:0Pl?oooooooooo0?mo00[ooooo00<0X23`oooooooo
ool06oooool00`2P8?3oooooooooo`0hooooo`050?mo0?ooooooooooooooo`3oO`009?ooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Jooooo`030:0Pl?ooool0X23`00Go
oooo00?oogl0ooooo`2P8?001?ooool00`2P8?3oooooooooo`03ooooo`030:0Pl?oooooooooo00Ko
oooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0Gooooo`0:oomo0?oooooooooooooo
ooooO`3ooooo0:0Pl?ooO`3ooooooomo00Kooooo00Coogl0ooooooooooooogl03Oooool00oooO`3o
ooooooooo`09ooooo`03oomo0?oooooooooo017ooooo00?oogl0ooooooooool05_ooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00<0X23`ooooooooool00oooool00`2P8?3o
ooooooooo`03ooooo`090:0Pl03oO`3ooooo0:0Pl03oO`00X23`0?mo0?ooool0ogl001Wooooo00<0
X23`ooooooooool04Oooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00Cooooo00<0
ogl0ooooooooool07Oooool00`3oO`3oooooooooo`0Dooooo`030?mo0?oooooooooo01Sooooo00?o
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool05?ooool01@2P8?3ooooo0:0Pl?oo
ool0X23`00;ooooo00D0X23`ooooo`2P8?3ooooo0:0Pl002ooooo`040?mo0?ooooooogl00:0Pl0;o
oooo0`2P8?07ooooo`030:0Pl?oooooooooo00Gooooo00?oogl0ooooo`2P8?000_ooool00`2P8?3o
ooooooooo`02ooooo`050:0Pl?ooooooooooooooooooO`002?ooool00`2P8?3oogl0ooooo`06oooo
o`030:0Pl?ooO`3ooooo00;ooooo00Coogl0ooooooooO`00X23`1?ooool00oooO`3oooooooooo`05
ooooo`03oomo0?ooooooogl000Kooooo00?oogl0ooooooooool05oooool00oooO`00X23`ooooo`06
ooooo`03oomo0?oooooooooo01Cooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0C
ooooo`060:0Pl?oooooooooo0:0Pl?ooool0X23`0_ooool0103oO`00X23`0:0Pl?ooool40:0Pl0;o
oooo00@0X23`ooooo`2P8?00X23`2Oooool01@3oO`00X23`ooooooooool0X23`00Sooooo00<0ogl0
ooooo`3oO`00B?ooool00`3oO`3oooooooooo`09ooooo`030?mo0?oooooooooo01Wooooo00?o0000
ooooooooool02?ooool000Wooooo00<00000ooooooooool06?ooool00`2P8?3oooooooooo`0<oooo
o`030:0Pl?ooO`00X23`00?ooooo00<0X23`ooooooooool03?ooool00`2P8?3oooooooooo`05oooo
o`030:0Pl?oooooooooo00Cooooo00Googl0oooooooooooooooo0?mo0003ooooo`030:0Pl?oooooo
oooo01;ooooo00?oogl0ooooooooool01?ooool01?ooO`3oooooooooooooO`0Tooooo`03oomo0?oo
oooooooo01Sooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`090:0Pl?oo
ool0ogl00?mo0?ooool0ogl0ooooo`3oO`3ooooo0080X23`0P3oO`001@2P8?3ooooo0:0Pl?ooool0
X23`00Sooooo00<0ogl00:0Pl?ooool04Oooool00`3oO`3oooooooooo`17ooooo`030?mo0?oooooo
oooo01oooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool05Oooool00`2P
8?3oooooooooo`03ooooo`030:0Pl?oooooooooo00Cooooo00@0X23`ooooo`2P8?3oogl01@2P8?02
ooooo`030:0Pl?oooooooooo00;ooooo00@0X23`ooooooooool0X23`1oooool00`2P8?3ooooooomo
0006ooooo`030:0Pl?oooooooooo00Kooooo0_ooO`04ooooo`0:oomo0?oooooooooo0:0Pl?ooool0
X23`ooooo`2P8?3oogl00:0Pl0Cooooo00?oogl0ooooooooool04oooool00oooO`3oooooooooo`0F
ooooo`030:0Pl?ooool0X23`01gooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0F
ooooo`050:0Pl?ooooooooooooooo`2P8?000_ooool00`2P8?3ooooo0:0Pl0060:0Pl0?ooooo0P2P
8?0=ooooo`030:0Pl?ooool0ogl000;ooooo00L0ogl0oooooooooooooooo0?mo0?ooool0ogl0017o
oooo00<0ogl0ooooooooool01Oooool00`3oO`3oooooooooo`0Zooooo`030?mo0?oooooooooo02Go
oooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool07Oooool00`2P8?3ooooo
ooooo`04ooooo`050:0Pl?oooooooooo0:0Pl?ooool00P2P8?000oooool0X23`0:0Pl004ooooo`03
0:0Pl?oooooooooo01Cooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0=ooooo`03
0:0Pl?oooooooooo00_ooooo00H0X23`ooooooooooooogl0ooooooooO`02ooooo`03oomo0?oooooo
oooo00;ooooo00<0X23`ooooooooool01?ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooo
oooo00cooooo00<0X23`ooooooooool06?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooo
oooo01_ooooo00`0ogl0ooooo`2P8?3ooooo0?mo002P8?3ooooo0:0Pl?ooool0ogl00:0Pl03oO`02
ooooo`030:0Pl?ooool0X23`00;ooooo00<0X23`ooooooooool02_ooool00`3oO`3oooooooooo`16
ooooo`030?mo0?oooooooooo02_ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool07oooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo0080X23`00Koogl00:0P
l?ooool0X23`oomo002P8?0;ooooo`08oomo0?oooooooooo0:0Pl?ooO`00X23`ooooooooO`04oooo
o`040?mo0?oooooooooo0:0Pl0;ooooo00<0X23`ooooooooool01Oooool00oooO`3oooooooooo`05
ooooo`040:0Pl?ooO`3oogl0ooooo`?oogl000Cooooooomo0?ooool0X23`1Oooool01P3oO`3ooooo
ooooooooO`3ooooooomo00Cooooo00?oogl00:0Pl?ooO`002?ooool20:0Pl0;ooooo00?oogl0oooo
ooooool01?ooool2oomo00Cooooo00<0X23`ooooooooool00_ooool01@2P8?3ooooooomo0?oooooo
ogl001Kooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`030?mo0?ooool0
X23`0080ogl000?ooooo0?mo002P8?000`2P8?000oooool0X23`0:0Pl0020:0Pl0?ooooo00<0X23`
ooooo`2P8?000_ooool00`2P8?3oooooooooo`0=ooooo`030?mo0?oooooooooo00[ooooo00D0ogl0
oooooooooooooooo0:0Pl004ooooo`030?mo0?oooooooooo00?ooooo00<0ogl0ooooooooool01Ooo
ool00`3oO`3oooooooooo`0Fooooo`030?mo0?oooooooooo00Kooooo00<0ogl0ooooooooool03_oo
ool01@3oO`3oooooooooooooool0ogl001?ooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0:Oooool00`2P8?3oooooooooo`02ooooo`03oomo002P8?00X23`01Sooooo0_oo
O`02ooooo`04oomo0?oooooooooooomo00;ooooo00?oogl0ooooooooool04?ooool01OooO`3ooooo
ooooooooool0X23`00;ooooo00<0ogl0ooooooooool04?ooool00oooO`3oooooooooo`0:ooooo`03
oomo0?oooooooooo00Cooooo00Coogl0ooooooooool0X23`0_ooool00`2P8?3oooooooooo`0Eoooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00`3oO`3oooooooooo`02oooo
o`80X23`00<0ogl0ooooo`2P8?000oooool20:0Pl0;ooooo00<0X23`ooooooooool01Oooool00`2P
8?3oooooooooo`0<ooooo`80ogl05oooool00`3oO`3oooooooooo`0Fooooo`030?mo0?oooooooooo
00gooooo00<0ogl0ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`0Pooooo`050:0Pl?ooool0X23`ooooo`2P8?001?ooool01?ooO`3oooooooooooooool2
0:0Pl0gooooo00<0X23`ooooooooool04?ooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooo
oooo00Gooooo00<0X23`ooooooooool01?ooool0102P8?3oooooooooooooO`04ooooo`03oomo0?oo
oooooooo00Gooooo00Googl0oooooooooooooooooomo0003ooooo`03oomo0?oooooooooo01Wooooo
00<0X23`ooooooooool05_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo
0P2P8?001P3oO`3ooooo0:0Pl?ooool0ogl0ooooo`80X23`0oooool00`2P8?3oooooooooo`02oooo
o`050:0Pl?ooooooooooooooo`2P8?001oooool00`3oO`3ooooo0?mo0006ooooo`030?mo0?oooooo
oooo06Wooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool08_ooool00`2P
8?3ooooo0:0Pl004ooooo`090:0Pl?oooooooooooomo0?ooool0X23`oomo0?ooool0X23`00;ooooo
0P2P8?09ooooo`03oomo0?ooool0X23`00cooooo00Koogl00:0Pl?oooooooooooomo002P8?02oooo
o`03oomo0?oooooooooo00;ooooo0_ooO`04ooooo`05oomo0?ooooooooooooooooooO`001?ooool0
102P8?3oogl00?mo002P8?04ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool02Ooo
ool20:0Pl0?ooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`07ooooo`040:0Pl?oo
ool0X23`0:0Pl0;oogl05Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo
00L0X23`0?mo0?ooool0ogl0ooooo`2P8?3ooooo00<0X23`00Oooooo0:0Pl02P8?00X23`ooooo`2P
8?00ogl00080X23`1_ooool00`2P8?3oooooooooo`05ooooo`030?mo0?ooool0ogl000;ooooo00<0
ogl0ooooo`2P8?001_ooool00`3oO`3oooooooooo`0eooooo`030?mo0?oooooooooo013ooooo00<0
ogl0ooooooooool00oooool0103oO`3oooooooooo`3oO`0Booooo`03o`000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo01[ooooo00<0X23`ooooooooool00_ooool20:0Pl0;ooooo00<0
X23`ooooooooool01_ooool01?ooO`3ooooo0:0Pl02P8?0Uooooo`030?mo0?oooooooooo00kooooo
00Koogl0ooooooooooooogl0ooooo`2P8?0;ooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooo
ooooool01_ooool00oooO`3oooooooooo`0:ooooo`050?mo002P8?3oooooooooo`2P8?000_ooool0
0`2P8?3oooooooooo`05ooooo`03oomo0?oooooooooo00kooooo00<00000ooooooooool03oooool0
0ol0003oooooooooo`0Jooooo`80X23`0_ooool20:0Pl003ooooo`3oO`3ooooo00;ooooo00<0ogl0
ooooo`2P8?000P2P8?00103oO`3oooooooooo`2P8?02ooooo`030:0Pl?oooooooooo00_ooooo00<0
ogl0ooooooooool04?ooool00`2P8?3oooooooooo`06ooooo`050?mo0?ooooooooooooooo`3oO`00
;_ooool00`3oO`3oooooooooo`0Aooooo`030?mo0?oooooooooo00kooooo00?o0000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool07oooool00`2P8?3oooooooooo`09ooooo`<0X23`00Go
ogl00:0Pl02P8?00X23`oomo00030:0Pl0?ooooo00?oogl0ooooooooool00_ooool20:0Pl0;ooooo
00<0X23`ooooooooool00_ooool00`2P8?3ooooooomo0003ooooo`04oomo0?oooooooooo0:0Pl0;o
oooo00?oogl00:0Pl?ooO`001_ooool00`2P8?3oogl0ooooo`04ooooo`04oomo003oO`3ooooooomo
00Cooooo00H0X23`0?mo0?ooool0ogl0oomo003oO`04ooooo`03oomo0?oooooooooo00;ooooo00Go
ogl0oooooooooooooooo0:0Pl002ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooool0
0_ooool00oooO`00X23`0:0Pl002ooooo`030:0Pl?ooooooogl000Cooooo00<0X23`oomo0?ooool0
0P2P8?0Dooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool07oooool0102P8?3ooooo
ooooooooool20?mo0003ooooo`2P8?00X23`00<0X23`00?ooooo0?mo002P8?000`2P8?03ooooo`80
X23`0P3oO`05ooooo`030:0Pl?ooool0ogl000Kooooo00@0ogl0ooooooooool0ogl01_ooool01P3o
O`3oooooooooo`2P8?3ooooo0?mo00Cooooo00<0ogl0ooooooooool00_ooool01@3oO`3ooooooooo
ooooool0ogl002Gooooo00<0ogl0ooooooooool00oooool00`3oO`3oooooooooo`0:ooooo`80ogl0
5?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Hooooo`030:0Pl?oo
oooooooo00cooooo00<0X23`ooooooooool00_ooool01@2P8?3ooooo0:0Pl?ooool0X23`00Oooooo
00<0X23`ooooooooool02?ooool01?ooO`3oooooooooo`2P8?02ooooo`08oomo0?ooooooogl0oomo
0?ooool0X23`ooooo`2P8?0=ooooo`03oomo0?oooooooooo00Oooooo00<0X23`ooooooooool01Ooo
ool01OooO`3oooooooooooooooooogl000Oooooo00<0ogl0ooooooooool01oooool00oooO`3ooooo
ooooo`08ooooo`80X23`00?ooooo0:0Pl?ooool01Oooool0102P8?3ooooooomo002P8?0Cooooo`03
00000?oooooooooo00oooooo00?o0000ooooooooool06_ooool0102P8?3oooooooooo`2P8?08oooo
o`80X23`0_ooool0102P8?3ooooo0:0Pl03oO`02ooooo`80X23`0oooool00`3oO`3oooooooooo`02
ooooo`040:0Pl?oooooooooo0?mo00Wooooo00<0ogl0ooooooooool00_ooool00`2P8?3ooooooooo
o`0Pooooo`030?mo0?oooooooooo00Gooooo00D0ogl0oooooooooooooooo0?mo000Rooooo`030?mo
0?oooooooooo017ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool06?oo
ool00`2P8?3oooooooooo`0>ooooo`050:0Pl?ooO`3oooooooooooooO`000_ooool00oooO`3ooooo
oomo000>ooooo`030:0Pl?oooooooooo00kooooo00@0ogl0ooooo`2P8?00X23`1?ooool00oooO`3o
ooooooooo`02ooooo`050:0Pl?ooooooooooooooooooO`004?ooool01?ooO`3oooooooooooooO`02
ooooo`030:0Pl?oooooooooo00cooooo00?oogl0ooooooooool03?ooool00`2P8?3ooooo0:0Pl004
ooooo`80X23`4Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00<0X23`
ooooooooool01?ooool00`3oO`3ooooo0:0Pl004ooooo`030:0Pl03oO`00ogl000;ooooo00L0X23`
0?mo002P8?00X23`ooooo`2P8?3ooooo0080X23`0oooool00`3oO`3oooooooooo`04ooooo`030?mo
0?oooooooooo00?ooooo00<0ogl0ooooo`3oO`00Aoooool00`3oO`3oooooooooo`0Nooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01cooooo00<0X23`ooooooooool02_oo
ool01`2P8?3ooooo0:0Pl02P8?3ooooo0:0Pl?ooool00_ooO`000oooooooogl0ooooo`03ooooo`03
oomo0?oooooooooo00Cooooo00<0X23`ooooooooool02oooool00`3oO`3oooooooooo`07ooooo`04
oomo0?ooool0X23`0:0Pl0?ooooo00L0X23`ooooooooO`3oogl0ooooo`2P8?3ooooo00;oogl000Oo
oooo0:0Pl?ooO`00X23`0?mo0?ooool0X23`00Gooooo00Coogl0ooooooooO`00X23`1_ooool01P2P
8?3oooooooooooooooooogl00:0Pl0?ooooo00<0ogl0ooooooooool01?ooool00`2P8?3ooooooomo
0002ooooo`03oomo0?ooool0ogl00080X23`00?oogl0ooooo`2P8?000P2P8?000oooO`00X23`oooo
o`0Cooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00`2P8?3ooooooooo
o`02ooooo`80X23`00<0ogl00:0Pl?ooool00P3oO`001`2P8?3ooooo0?mo002P8?00ogl00:0Pl03o
O`001P2P8?0;ooooo`040?mo0?oooooooooo0:0Pl0Kooooo00<0ogl0ooooooooool01oooool00`2P
8?3oooooooooo`02ooooo`030?mo002P8?3ooooo01[ooooo00<0ogl0ooooooooool03oooool00`3o
O`3oooooooooo`07ooooo`050?mo0?ooooooooooooooo`3oO`001_ooool00`3oO`3oooooooooo`0A
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo03[ooooo00?oogl0oooo
ooooool01Oooool00oooO`3oooooooooo`0Aooooo`05oomo0?ooooooooooooooooooO`002oooool0
0`3oO`3oogl0ooooo`02ooooo`03oomo0?ooooooogl000Oooooo00Ooogl0ooooooooO`3ooooooomo
0?ooooooogl000Kooooo00<0X23`ooooooooool01Oooool0102P8?3oooooooooooooO`03ooooo`05
0:0Pl?ooool0ogl0oomo002P8?001Oooool00`2P8?3oooooooooo`0Dooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool08_ooool20?mo00;ooooo0P3oO`02ooooo`080?mo0?ooool0ogl0
ooooo`3oO`3ooooo0?mo0?ooool20:0Pl0?ooooo00<0ogl0ooooooooool01oooool00`3oO`3ooooo
ooooo`0:ooooo`030?mo0?oooooooooo00;ooooo00@0X23`ooooo`3oO`00X23`=oooool00`3oO`3o
ooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Wooooo
00<0X23`ooooooooool02_ooool20:0Pl003ooooo`2P8?3ooooo00Sooooo00@0X23`oooooooooooo
ogl02?ooool0102P8?3oooooooooooooool30:0Pl0[ooooo00?oogl0ooooo`2P8?001?ooool2oomo
00;ooooo00H0X23`oomo003oO`00X23`oomo002P8?04ooooo`03oomo0?oooooooooo00?ooooo00?o
ogl0ooooooooool00_ooool00`3oO`3ooooooomo0003ooooo`030:0Pl?ooooooogl000;ooooo00D0
ogl0oooooooooooooooooomo0003ooooo`06oomo0?ooooooogl0oomo0?ooooooogl01Oooool0102P
8?3oooooooooooooO`05ooooo`@0X23`00Gooooo0:0Pl?oooooooooooomo000Booooo`0300000?oo
oooooooo00oooooo00?o0000ooooooooool07oooool00`2P8?3oooooooooo`02ooooo`80X23`0P3o
O`000oooool0X23`0?mo00020:0Pl0<0ogl00P2P8?001@3oO`00X23`0?mo002P8?00ogl00080X23`
2_ooool20:0Pl003ooooo`3oO`3ooooo00_ooooo00<0X23`ooooooooool00oooool00`3oO`3ooooo
ooooo`0@ooooo`030?mo0?oooooooooo00Cooooo00<0ogl0ooooooooool06_ooool00`3oO`3ooooo
ooooo`04ooooo`<0ogl000?ooooo0?mo0?ooool05Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`0Wooooo`030:0Pl?oooooooooo03oooooo00<0X23`ooooooooO`001?oo
ool01OooO`3ooooo0:0Pl02P8?3oogl000;ooooo0_ooO`000oooool0X23`ooooo`02ooooo`030?mo
0?oooooooooo00;ooooo00?oogl0ooooooooO`000_ooool0102P8?3oooooooooooooO`05ooooo`04
0:0Pl?ooooooogl00:0Pl0;ooooo00<0X23`oomo0?ooool00_ooool0102P8?3ooooo0:0Pl02P8?03
ooooo`030:0Pl?oooooooooo00cooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0U
ooooo`060:0Pl?ooooooooooooooo`3oO`3ooooo0P3oO`03ooooo`80X23`00Gooooo0:0Pl02P8?00
ogl00:0Pl002ooooo`030:0Pl03oO`3ooooo00[ooooo00<0X23`ooooooooool03_ooool0102P8?3o
ooooooooo`2P8?06ooooo`030:0Pl?oooooooooo01Oooooo00<0ogl0ooooooooool02?ooool00`3o
O`3oooooooooo`09ooooo`030?mo0?oooooooooo01gooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool07oooool01@2P8?3oooooooooo`2P8?3ooooo0080X23`0_ooool20:0P
l0gooooo00<0X23`ooooooooool02_ooool00oooO`3oooooooooo`05ooooo`06oomo0?oooooooooo
ooooo`2P8?3oogl02_ooool00oooO`3oooooooooo`07ooooo`;oogl000?ooooooomo0?ooool01?oo
ool01P2P8?3oooooooooooooO`3ooooooomo00Wooooo00@0ogl0ooooooooO`3oogl00_ooool00ooo
O`3oooooooooo`03ooooo`030:0Pl?oooooooooo00;ooooo00H0X23`ooooooooool0X23`ooooo`2P
8?07ooooo`05oomo0?ooool0X23`ooooo`2P8?000_ooool00`2P8?3oooooooooo`0<ooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool07_ooool00`2P8?3oooooooooo`02ooooo`040:0P
l?ooool0X23`0?mo0080X23`00Cooooo0:0Pl02P8?3ooooo0`3oO`000`2P8?3ooooo0:0Pl0020:0P
l0060?mo0?oooooooooo0:0Pl?ooool0X23`3?ooool00`3oO`3ooooo0:0Pl009ooooo`030?mo002P
8?3ooooo00Sooooo00<0X23`0?mo0?ooool0:Oooool00`3oO`3oooooooooo`0;ooooo`030?mo0?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool07oooool0
0`2P8?3oooooooooo`02ooooo`040:0Pl?oooooooooo0:0Pl0?ooooo0P2P8?02ooooo`03oomo0?oo
oooooooo00oooooo00?oogl0ooooooooool01?ooool01?ooO`3oooooooooooooO`04ooooo`03oomo
0?oooooooooo00Gooooo00?oogl0ooooo`2P8?001?ooool02@2P8?3oooooooooooooooooogl00:0P
l?ooool0X23`ooooo`02oomo00;ooooo0_ooO`03ooooo`07oomo0?ooooooooooooooooooO`3ooooo
oomo0004ooooo`070?mo0?ooooooogl0ooooooooO`00X23`ooooo`02oomo00;ooooo00@0X23`oomo
0?ooO`3oogl00P2P8?04ooooo`07oomo0?ooooooogl00:0Pl?ooool0X23`ooooo`030:0Pl003oooo
o`2P8?3ooooo00;oogl000@0X23`ooooo`2P8?00X23`3_ooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo023ooooo00@0X23`oooooooooooooooo0`2P8?000oooool0X23`0:0Pl0030?mo
0005ooooo`3oO`00ogl00?mo002P8?000P3oO`000`2P8?00ogl00:0Pl0050:0Pl004ooooo`2P8?3o
oooo0:0Pl0?ooooo00@0ogl0ooooo`2P8?00ogl01oooool0103oO`3oooooooooooooool20?mo00;o
oooo00D0ogl0ooooo`2P8?3ooooo0?mo0008ooooo`040:0Pl?oooooooooo0?mo01Gooooo00<0ogl0
ooooooooool06?ooool0103oO`3oooooooooo`3oO`04ooooo`030?mo0?oooooooooo013ooooo00?o
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool09?ooool00`2P8?3oooooooooo`05
ooooo`030:0Pl?oooooooooo00Gooooo00<0X23`ooooooooool04_ooool00`3oO`3oooooooooo`0B
ooooo`060?mo0?oooooooooo0:0Pl?ooO`00ogl01Oooool01@3oO`3oooooooooooooooooogl000Co
oooo00?oogl0ooooooooool00_ooool00`2P8?3oooooooooo`06ooooo`04oomo0?oooooooooooooo
o`80X23`3_ooool01P2P8?3oooooooooo`2P8?3ooooo0:0Pl0Gooooo0P2P8?02ooooo`040:0Pl?oo
oooooooo0:0Pl0_ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Uooooo`050:0P
l?ooool0ogl00?mo002P8?000_ooool01`3oO`3oooooooooo`3oO`00X23`0?mo0?ooool0102P8?00
1_ooool0X23`ooooo`2P8?3ooooo0:0Pl13ooooo00<0ogl0ooooooooool00_ooool00`3oO`3ooooo
ooooo`06ooooo`030?mo0?oooooooooo01?ooooo00<0X23`ooooooooool05_ooool00`3oO`3ooooo
ooooo`0>ooooo`030?mo0?oooooooooo01Cooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool08_ooool00`2P8?3oooooooooo`06ooooo`80X23`00?ooooo0:0Pl?ooool03?oo
ool00oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo00Kooooo00Koogl0ooooooooO`3oogl0
ooooooooO`08ooooo`070:0Pl03oO`3oogl0oomo002P8?3ooooo0:0Pl002ooooo`06oomo0?oooooo
ogl0oomo0?ooooooogl00_ooool01oooO`3oooooooooooooooooogl0ooooooooO`000oooool01?oo
O`00X23`oomo0?ooO`02ooooo`040?mo0?ooooooogl00:0Pl0;ooooo00<0X23`oomo0?ooool00_oo
O`001@2P8?3ooooo0:0Pl?ooO`00X23`00;ooooo00Coogl0ooooo`2P8?3ooooo0P2P8?000oooool0
X23`ooooo`020:0Pl004oomo002P8?3ooooo0:0Pl0?ooooo0`2P8?0;ooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool09?ooool01`2P8?3oooooooooooooool0ogl00:0Pl03oO`000P2P
8?000`3oO`00X23`0?mo00050?mo00030:0Pl03oO`00X23`00@0X23`00Kooooo0:0Pl?ooool0X23`
ooooo`2P8?02ooooo`040:0Pl?ooool0X23`0:0Pl0Wooooo00D0X23`ooooo`2P8?3ooooo0:0Pl009
ooooo`030:0Pl?oooooooooo00?ooooo0P3oO`0>ooooo`030?mo0?oooooooooo01Cooooo00<0ogl0
ooooooooool01_ooool00`3oO`3oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo037ooooo00?oogl0ooooooooool06Oooool00`2P8?3oooooooooo`0:oooo
o`03oomo0?ooool0X23`00Kooooo00?oogl0ooooooooool01Oooool00`2P8?3oogl0oomo0002oooo
o`80X23`2Oooool2oomo00Kooooo00Ooogl0ooooo`3oO`3ooooooomo0?ooooooogl000Cooooo00<0
ogl0oomo0?ooool01?ooO`04ooooo`04oomo0?ooool0X23`0:0Pl0Sooooo00<0X23`ooooooooool0
2_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00@0ogl0ooooo`3oO`00
X23`1@3oO`04ooooo`040?mo002P8?3oooooooooo`<0X23`0oooool00`2P8?3oooooooooo`02oooo
o`80X23`4Oooool20?mo01[ooooo00<0ogl0ooooooooool03?ooool00`3oO`3oooooooooo`0[oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02?ooooo0P2P8?03ooooo`03
0:0Pl?oooooooooo00?ooooo00<0X23`oomo0?ooool01Oooool01`2P8?3oooooooooooooool0X23`
ooooooooO`002Oooool00oooO`3oooooooooo`05ooooo`030:0Pl?ooool0X23`00cooooo00?oogl0
0:0Pl?ooool00_ooool00`3oO`00X23`oomo000;ooooo`030:0Pl?oooooooooo00_ooooo00Coogl0
oooooooooooooooo0_ooO`02ooooo`0?0:0Pl?oooooooooooomo0?ooooooogl00:0Pl?ooO`3ooooo
oomo0?ooool0X23`oomo0?ooooooogl000;ooooo00Googl0oooooooooooooooooomo0002ooooo`<0
X23`00?oogl0ooooooooO`000`2P8?000oooool0X23`ooooo`08ooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool09Oooool00`2P8?3ooooo0:0Pl002ooooo`80ogl00P2P8?040?mo0080
X23`00Wooooo0:0Pl?ooool0X23`0?mo002P8?3ooooo0:0Pl?ooool00P2P8?001@3oO`3ooooo0?mo
0?ooool0X23`00;ooooo00<0X23`ooooooooool02?ooool00`2P8?3oooooooooo`11ooooo`050?mo
0?ooool0ogl0ooooo`3oO`002_ooool00`3oO`3oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo02_ooooo00<0X23`ooooooooool01oooool0102P8?3ooooo
ooooo`2P8?03ooooo`030:0Pl?oooooooooo01Kooooo00<0X23`ooooooooO`001oooool00oooO`3o
ooooooooo`04ooooo`03oomo0?oooooooooo01?ooooo00<0X23`ooooooooO`001?ooool00oooO`3o
ooooooooo`02ooooo`;oogl00_ooool2oomo00Kooooo00?oogl0ooooooooO`000_ooool00`2P8?3o
oooooomo0004ooooo`060:0Pl?ooool0X23`0:0Pl?ooool0X23`0_ooool00`2P8?3oooooooooo`07
ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool01@2P8?3oooooooooo`2P
8?3ooooo00D0ogl000?ooooo0?mo002P8?000oooool0102P8?00ogl00:0Pl02P8?02ooooo`@0X23`
00?ooooo0?mo0?ooool02oooool00`2P8?3oooooooooo`0looooo`030?mo0?oooooooooo023ooooo
00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0;Oooool20:0Pl0;ooooo00<0
X23`ooooooooool02oooool00oooO`3oooooooooo`04ooooo`04oomo0?oooooooooooomo00oooooo
00<0ogl0ooooooooool00oooool01@2P8?3ooooooomo0?ooooooogl000;ooooo00<0X23`oooooooo
O`001?ooool01OooO`3ooooo0:0Pl?ooooooogl000Oooooo00?oogl0ooooooooO`004?ooool02Ooo
O`00ogl0ooooo`2P8?3ooooooomo002P8?3ooooo0:0Pl002ooooo`06oomo0?ooooooogl00:0Pl?oo
O`00X23`1_ooool01@3oO`3ooooo0:0Pl?ooool0X23`00[ooooo00<00000ooooooooool03oooool0
0ol0003oooooooooo`0Xooooo`040:0Pl?ooooooooooooooo`80X23`0`3oO`001Oooool0X23`0?mo
0?ooool0ogl000;ooooo0P2P8?000`3oO`00X23`ooooo`02ooooo`030:0Pl?ooool0X23`00Kooooo
0P2P8?000oooool0ogl0ooooo`05ooooo`030?mo0?oooooooooo03Oooooo00<0ogl0ooooooooool0
2?ooool01@3oO`3ooooo0?mo0?ooool0ogl001Kooooo00?o0000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0;?ooool01@2P8?3ooooo0:0Pl?ooool0X23`00Cooooo00D0X23`oooooooo
oooooooo0:0Pl006ooooo`030:0Pl?oooooooooo00Sooooo00<0X23`ooooooooool03_ooool00`2P
8?3ooooooomo0008ooooo`090:0Pl?ooool0X23`ooooooooO`3ooooo0:0Pl?ooO`3ooooo0080X23`
00Coogl0oooooooooooooooo0_ooO`001oooooooogl0ooooooooool0ogl0ooooooooO`001?ooool2
0:0Pl005ooooooooO`3ooooo0?mo0?ooO`000oooool01OooO`3ooooo0:0Pl?ooO`3ooooo00;oogl0
00Cooooo0:0Pl?ooooooogl00_ooool20:0Pl0;ooooo0P2P8?02ooooo`D0X23`00?ooooo0:0Pl02P
8?002?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00D0X23`oooooooo
ool0X23`ooooo`020:0Pl0<0ogl000?ooooo0?mo003oO`000`3oO`020:0Pl003ooooo`2P8?00ogl0
00T0X23`00?ooooo0:0Pl?ooool01_ooool20:0Pl003ooooo`2P8?00X23`00?ooooo00<0X23`oooo
ooooool02Oooool00`3oO`3oooooooooo`0Aooooo`030?mo0?oooooooooo00Kooooo00<0ogl0oooo
ooooool05oooool30?mo01Kooooo00?o0000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool09?ooool20:0Pl0;ooooo00<0X23`ooooo`2P8?005Oooool01OooO`3oooooooooooooool0X23`
01[ooooo00<0X23`ooooooooool02?ooool01@2P8?3oogl0ooooo`2P8?3oogl000?ooooo00<0X23`
ooooooooool00oooool00oooO`3oooooooooo`06ooooo`;oogl00oooool01OooO`3ooooooooooooo
ool0X23`00;oogl00_ooool00oooO`00ogl0ooooo`02ooooo`03oomo0?oooooooooo00Cooooo00@0
X23`ooooooooool0X23`0_ooool02@2P8?3ooooo0:0Pl?ooool0X23`ooooo`2P8?3ooooo0:0Pl008
ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool09oooool30:0Pl0Kooooo00H0X23`
ooooooooool0ogl0ooooo`2P8?030?mo00Cooooo00<0X23`ooooo`2P8?000`2P8?000oooool0X23`
ooooo`05ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooool01Oooool00`2P8?3ooooo
ooooo`06ooooo`030?mo0?oooooooooo01Kooooo00<0ogl0ooooooooool05Oooool00`3oO`3ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02[ooooo00<0
X23`ooooooooool01_ooool00oooO`00X23`ooooo`04ooooo`80X23`00?ooooo0:0Pl?ooO`001Ooo
ool00oooO`3oooooooooo`0:ooooo`030:0Pl?oooooooooo00?ooooo00Koogl0ooooooooooooogl0
ooooo`2P8?02ooooo`;oogl000<0X23`ooooooooool01?ooool00`2P8?3oooooooooo`02oomo00?o
oooo0`2P8?02ooooo`0:0:0Pl?oooooooooo0:0Pl?ooooooogl0ooooo`2P8?3ooooo0:0Pl0?ooooo
00Googl0ooooo`2P8?3ooooooomo0004ooooo`030?mo0?ooool0X23`00Gooooo0P2P8?001?ooool0
X23`oomo0?ooool20:0Pl0Gooooo102P8?000oooool0X23`0:0Pl0020:0Pl0Wooooo00<00000oooo
ooooool03oooool00ol0003oooooooooo`0Yooooo`030:0Pl?ooool0ogl000;ooooo0P3oO`02oooo
o`030:0Pl03oO`00X23`00@0X23`00?ooooo0:0Pl02P8?000_ooool20:0Pl003ooooo`2P8?00X23`
00@0X23`00?ooooo0:0Pl02P8?000P2P8?02ooooo`<0X23`1_ooool0103oO`3oooooooooo`3oO`0<
ooooo`050:0Pl?ooooooooooooooo`2P8?004_ooool00`3oO`3oooooooooo`0<ooooo`030?mo0?oo
oooooooo00Oooooo00<0ogl0ooooooooool06?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`0_ooooo`030:0Pl?ooool0X23`00_ooooo00@0X23`ooooooooool0X23`8_oo
ool00`2P8?3oooooooooo`0:ooooo`030?mo0?ooooooogl000Kooooo00<0X23`ooooooooool00_oo
ool00`2P8?3oooooooooo`020:0Pl0Gooooo00<0X23`ooooooooool00oooool20:0Pl006oomo0?oo
ooooooooooooooooO`00X23`2_ooool00`2P8?3oooooooooo`030:0Pl004ooooo`2P8?00X23`0:0P
l0Sooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`040:0Pl?oooooooooo
0:0Pl0Cooooo00H0ogl0ooooo`3oO`00X23`ooooo`2P8?02ooooo`030:0Pl?ooool0X23`00?ooooo
102P8?000oooool0X23`ooooo`02ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooo`2P8?00
1_ooool01P2P8?3oooooooooo`3oO`3ooooo0:0Pl0Cooooo00<0ogl0ooooooooool0BOooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0oooooo`050:0Pl?oooooooooooooo
ooooO`004Oooool00`3oO`3oooooooooo`02ooooo`030:0Pl?ooooooogl000?ooooo00?oogl0oooo
ooooool02?ooool00oooO`3oooooooooo`02ooooo`060:0Pl?ooooooooooooooo`2P8?3oogl01Ooo
ool01_ooO`3oooooooooo`3oO`3oogl00:0Pl0Cooooo00@0X23`0?mo0?ooool0X23`1_ooool00`2P
8?3oooooooooo`02ooooo`040:0Pl?oooooooooo0?mo00?ooooo0P2P8?001_ooool0X23`0:0Pl02P
8?3ooooooomo00Cooooo0P2P8?09ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
;oooool01@2P8?00ogl0ooooooooool0ogl000;ooooo00L0ogl0oooooooooooooooo0:0Pl?ooool0
ogl000;ooooo0P2P8?001_ooool0X23`ooooo`2P8?3ooooo0:0Pl0;ooooo00<0X23`0?mo002P8?00
1Oooool0102P8?3oooooooooo`2P8?09ooooo`030?mo0?oooooooooo02Sooooo00<0ogl0oooooooo
ool00oooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo01_ooooo00?o0000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0:Oooool00`2P8?3oooooooooo`0:ooooo`030:0P
l?oooooooooo00;ooooo0P2P8?000oooO`3oooooooooo`04ooooo`030:0Pl?ooO`3oogl000Gooooo
00<0X23`ooooooooool01oooool2oomo00Wooooo0oooO`0<ooooo`0=0?mo0?ooool0X23`0:0Pl?oo
ooooogl0ooooo`2P8?3ooooo0:0Pl?ooO`3ooooooomo0004ooooo`04oomo003oO`3oooooooooo`80
X23`00?ooooo0:0Pl?ooO`000_ooO`020:0Pl0;ooooo00@0X23`ooooooooO`3oogl00oooool20:0P
l0?ooooo00D0X23`oooooooooooooooo0:0Pl002ooooo`030:0Pl?oooooooooo00D0X23`1oooool0
0`00003oooooooooo`0?ooooo`03o`000?oooooooooo02cooooo00D0X23`oooooooooooooooo0:0P
l002ooooo`030:0Pl?ooool0ogl000;ooooo0P3oO`001@2P8?00ogl00?mo002P8?3ooooo00H0X23`
00?ooooo0:0Pl02P8?000P2P8?000oooool0X23`ooooo`02ooooo`80X23`0oooool00`2P8?3ooooo
ooooo`03ooooo`080:0Pl?ooool0ogl0ooooo`3oO`00X23`ooooo`2P8?03ooooo`030?mo0?ooool0
ogl000Sooooo00<0ogl0ooooooooool08Oooool00`3oO`3oooooooooo`09ooooo`030?mo0?oooooo
oooo00oooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0;?ooool00`2P
8?3oooooooooo`07ooooo`030:0Pl?oooooooooo00Kooooo00<0X23`ooooooooool04Oooool01?oo
O`3oooooooooo`3oO`09ooooo`04oomo0?oooooooooooomo00;ooooo00<0ogl0ooooooooool02?oo
ool00oooO`3oooooooooo`02ooooo`060:0Pl?ooO`3oooooooooooooO`00X23`1?ooool01?ooO`3o
ooooooooooooO`06ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool03?ooool00`2P
8?3ooooo0:0Pl002ooooo`030:0Pl?ooool0X23`00<0X23`00?ooooo0:0Pl?ooool01_ooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo02gooooo00<0X23`ooooooooool01Oooool01P2P
8?3ooooo0?mo002P8?00ogl00:0Pl0Cooooo00D0ogl00:0Pl02P8?00X23`ooooo`060:0Pl003oooo
o`2P8?3ooooo00Cooooo0P3oO`000oooool0ogl0ooooo`0Dooooo`030?mo0?oooooooooo02cooooo
00<0ogl0ooooo`3oO`005_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`0jooooo`060:0Pl?ooO`3ooooo0:0Pl?ooool0ogl00_ooool00oooO`3ooooooomo0003ooooo`03
oomo002P8?3ooooo00Gooooo00<0X23`ooooooooool02?ooool01P2P8?3ooooo0?mo0?ooooooogl0
0?mo00Oooooo00?oogl0ooooooooool01Oooool01OooO`3oooooooooooooooooogl000Kooooo00@0
X23`ooooooooool0X23`0oooool00`3oO`3oooooooooo`020:0Pl0;ooooo00@0X23`ooooooooO`3o
oooo0`2P8?000oooO`00ogl00:0Pl002ooooo`80X23`00?ooooo0:0Pl02P8?000`2P8?000oooool0
X23`ooooo`0;0:0Pl0Oooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`80
X23`00Gooooo0:0Pl?oooooooooo0:0Pl0020?mo00030:0Pl03oO`00X23`0080X23`00?ooooo0?mo
002P8?002@2P8?000`3oO`00X23`ooooo`020:0Pl0;ooooo00D0ogl0oooooooooooooooo0:0Pl00:
ooooo`040?mo0?oooooooooo0:0Pl0Cooooo00<0X23`ooooooooool06Oooool00`3oO`3ooooooooo
o`08ooooo`040?mo0?ooooooooooooooo`80ogl00oooool00`3oO`3ooooo0?mo000Gooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02gooooo00<0X23`ooooooooool03?oo
ool01@2P8?3ooooo0:0Pl?ooool0X23`00Gooooo0_ooO`0:ooooo`03oomo0?oooooooooo00?ooooo
00?oogl0ooooooooool01_ooool01OooO`3oooooooooooooool0X23`00?ooooo00?oogl0ooooo`2P
8?001Oooool01OooO`3oooooooooooooool0X23`00gooooo00?oogl0ooooooooool00_ooool00`2P
8?3oogl0ooooo`05ooooo`040:0Pl?oooooooooo0:0Pl0Wooooo00?oogl0ooooooooool00oooool0
0oooO`00X23`0:0Pl0040:0Pl0Sooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0`
ooooo`030:0Pl?oooooooooo00?ooooo0`2P8?02ooooo`030:0Pl?oooooooooo0080ogl000?ooooo
0:0Pl02P8?002@2P8?000oooool0ogl0ooooo`05ooooo`030:0Pl03oO`3ooooo00Kooooo00<0ogl0
ooooooooool03Oooool00`3oO`3oooooooooo`0[ooooo`030?mo0?ooool0ogl001Cooooo00?o0000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0@_ooool00`2P8?3oooooooooo`0Joooo
o`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooO`002?ooool01@3oO`3ooooooooooooooooo
ogl000cooooo00<0X23`ooooooooO`003?ooool01_ooO`3ooooo0:0Pl02P8?3ooooooomo00?ooooo
0P2P8?000oooool0X23`0?mo0003ooooo`80X23`0oooool00`2P8?3oooooooooo`030:0Pl0Oooooo
00<00000ooooooooool03oooool00ol0003oooooooooo`0cooooo`80ogl00_ooool01P3oO`3ooooo
ooooo`3oO`3ooooo0?mo00Cooooo00<0ogl0ooooo`2P8?000P2P8?02ooooo`80X23`00Kooooo0:0P
l02P8?00X23`ooooo`2P8?0<ooooo`030:0Pl?ooool0ogl002[ooooo00<0X23`ooooo`3oO`002ooo
ool00`3oO`3oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo02cooooo00<0X23`ooooooooool01?ooool00`2P8?3oooooooooo`06ooooo`80X23`3?ooool0
0`2P8?3oogl00:0Pl00=ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooo`3oO`000_ooool4
oomo0007ooooooooO`3oooooooooo`2P8?3ooooooomo0003ooooo`03oomo0?oooooooooo00Cooooo
00@0X23`ooooooooO`00X23`0oooool01@3oO`00X23`ooooooooO`00X23`00;ooooo0P2P8?000ooo
ool0X23`0:0Pl003ooooo`080?mo002P8?3oooooooooo`2P8?3ooooo0:0Pl?ooool30:0Pl0;ooooo
0P2P8?03ooooo`050:0Pl?oooooooooooomo0?ooool01`2P8?05ooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool0<?ooool00`2P8?3oooooooooo`04ooooo`030?mo002P8?00X23`00@0
X23`00Gooooo0:0Pl02P8?00ogl0ooooo`020:0Pl003ooooo`2P8?00X23`00D0X23`00?ooooo0:0P
l02P8?001_ooool01@2P8?3oooooooooo`2P8?3ooooo0080ogl00oooool20?mo02Sooooo00<0ogl0
ooooooooool02_ooool00`3oO`3oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo047ooooo00H0X23`ooooooooool0X23`ooooo`2P8?08ooooo`03oomo0?oo
oooooooo00oooooo00?oogl0ooooooooool01_ooool01OooO`3oooooooooooooooooogl001Gooooo
00D0X23`ooooo`2P8?3ooooo0:0Pl002ooooo`05oomo0?ooool0ogl0ooooooooO`000_ooool20:0P
l17ooooo0P2P8?001?ooool0X23`ooooo`2P8?05ooooo`030:0Pl?ooool00000017ooooo00?o0000
ooooooooool0>?ooool00`2P8?3oooooooooo`05ooooo`80X23`00Kooooo0:0Pl03oO`3ooooo0?mo
0?ooool50:0Pl004ooooo`2P8?3ooooo0:0Pl0Kooooo00<0X23`ooooooooool00oooool00`3oO`3o
ooooooooo`0<ooooo`030?mo0?oooooooooo00Sooooo00<0X23`ooooooooool01?ooool00`3oO`3o
ooooooooo`0Hooooo`030?mo0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0;_ooool00`2P8?3ooooo0:0Pl00>ooooo`030:0Pl?ooool0X23`00;ooooo
00@0X23`oooooooooooooooo0P2P8?0=ooooo`06oomo002P8?3oooooooooo`3oO`00X23`1_ooool0
1P3oO`3ooooooomo002P8?3ooooooomo00Cooooo00@0ogl0ooooooooooooogl00oooool0102P8?3o
ooooooooooooO`07ooooo`040:0Pl?oooooooooo0?mo00;ooooo00@0X23`ooooooooooooogl01Ooo
ool20:0Pl0?ooooo00?oogl0ooooooooool00_ooool01`2P8?3oooooooooooooool0X23`ooooo`2P
8?000_ooool01@2P8?3oooooooooooooool0X23`00;ooooo0P2P8?000oooool0X23`0:0Pl005oooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool00`2P8?3oooooooooo`02oooo
o`80X23`0oooool00`2P8?3oooooooooo`030:0Pl004ooooo`2P8?00X23`ooooo`80ogl0202P8?00
0oooool0X23`0:0Pl005ooooo`030:0Pl?oooooooooo00;ooooo0P3oO`04ooooo`030?mo0?oooooo
oooo00Oooooo00D0X23`oooooooooooooooo0?mo0007ooooo`030:0Pl?oooooooooo00gooooo00<0
ogl0ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`14
ooooo`030:0Pl?oooooooooo00Oooooo00?oogl0ooooooooool03oooool00`3oO`3oooooooooo`03
ooooo`030:0Pl?oooooooooo00?ooooo00Coogl0ooooooooooooogl01oooool00oooO`3ooooooooo
o`02ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool01_ooool00`2P8?3ooooo0:0P
l008ooooo`030:0Pl?oooooooooo00?ooooo00<0X23`ooooooooool00`2P8?000oooool0X23`oomo
0009ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0?_ooool01P2P8?00ogl0oooo
ooooool0ogl0ooooo`<0X23`00<0ogl00:0Pl?ooool00`2P8?02ooooo`040:0Pl?ooool0X23`0:0P
l0cooooo00<0ogl0ooooooooool01?ooool00`3oO`3oooooooooo`0Pooooo`030?mo0?oooooooooo
00Kooooo00<0ogl0ooooooooool07Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`0kooooo`030:0Pl?oooooooooo00oooooo00?oogl00:0Pl?ooool06_ooool00`2P8?3o
ooooooooo`03ooooo`03oomo0?ooool0X23`00;ooooo00?oogl00:0Pl?ooool00_ooool00oooO`3o
ooooooooo`07ooooo`030?mo0?oooooooooo00Kooooo00?oogl0ooooooooool04Oooool30:0Pl0Go
oooo00<0X23`ooooooooool01_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo03[o
oooo00<0X23`ooooooooool00_ooool01@2P8?3ooooo0?mo0?ooool0ogl000<0X23`00D0ogl00:0P
l03oO`3ooooo0:0Pl002ooooo`030:0Pl03oO`3ooooo00kooooo00D0ogl0oooooooooooooooo0:0P
l00dooooo`030?mo0?oooooooooo01Oooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0>_ooool00`2P8?3oooooooooo`0>ooooo`030:0Pl?oooooooooo00Wooooo00D0X23`
oooooooooooooooooomo0002ooooo`040:0Pl?oooooooooo0:0Pl0?ooooo00<0X23`ooooo`2P8?00
2?ooool00oooO`3oooooooooo`06ooooo`060:0Pl?oooooooooo0:0Pl?ooO`00X23`0_ooool00ooo
O`00X23`ooooo`04ooooo`03oomo0?oooooooooo00Gooooo00D0X23`oooooooooooooooo0:0Pl002
ooooo`04oomo0?ooool0X23`0:0Pl0[ooooo00Coogl0ooooooooooooogl00oooool00`2P8?3ooooo
ooooo`03ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00`2P8?3ooooo
ooooo`02ooooo`040:0Pl03oO`3ooooo0:0Pl0?ooooo00P0ogl00:0Pl03oO`3ooooo0?mo002P8?3o
oooo0:0Pl0;ooooo0P3oO`00102P8?00ogl00:0Pl?ooool30:0Pl005ooooo`2P8?00X23`ooooo`2P
8?002?ooool00`2P8?3oooooooooo`04ooooo`030?mo0?oooooooooo02[ooooo0P3oO`0Mooooo`03
o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo043ooooo00D0X23`oooooooooooo
oooo0:0Pl002ooooo`030?mo0?oooooooooo00_ooooo00?oogl0ooooooooool01_ooool00`2P8?3o
ooooooooo`02ooooo`03oomo0?oooooooooo00Cooooo00Coogl0ooooooooool0ogl00_ooool00`2P
8?3oooooooooo`04ooooo`05oomo0?ooooooooooooooooooO`001oooool00oooO`3oooooooooo`05
ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooool00_ooool00`2P8?3oogl00:0Pl002
ooooo`030:0Pl?oooooooooo00Oooooo00?oogl0ooooooooool02Oooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo03[ooooo00<0X23`ooooooooool00oooool02@2P8?3ooooooooooooo
ool0X23`ooooo`2P8?3ooooo0:0Pl004ooooo`040:0Pl?oooooooooo0?mo00Gooooo00<0X23`0?mo
0?ooool01_ooool01@3oO`3ooooo0:0Pl?ooool0ogl000Oooooo00<0ogl0ooooooooool01?ooool2
0?mo02?ooooo00<0ogl0ooooooooool06?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0oooooo`030:0Pl?oooooooooo00Kooooo00<0X23`ooooooooool00oooool01@2P
8?3oooooooooooooool0X23`00oooooo0_ooO`02ooooo`03oomo0?oooooooooo00?ooooo0_ooO`00
1Oooooooogl0ooooooooool0X23`00;ooooo00<0X23`ooooooooool01Oooool01@2P8?3ooooooooo
ooooool0X23`00Kooooo00@0X23`ooooooooO`3ooooo102P8?03ooooo`80X23`0_ooool00oooO`3o
oooo0:0Pl005ooooo`80X23`0_ooool01P2P8?3oogl0ooooooooO`3ooooooomo00?ooooo0P2P8?04
ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool00`2P8?3oooooooooo`02
0:0Pl004ooooo`3oO`00X23`ooooo`<0X23`00D0ogl00:0Pl03oO`00X23`ooooo`030:0Pl003oooo
o`2P8?3ooooo00Kooooo00<0ogl0ooooooooool01_ooool00`2P8?3oooooooooo`04ooooo`030?mo
0?oooooooooo00Oooooo00<0X23`ooooo`2P8?003?ooool01@3oO`3oooooooooooooool0ogl000[o
oooo00@0ogl0ooooooooool0ogl07?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`16ooooo`030:0Pl?oooooooooo027ooooo0_ooO`02ooooo`03oomo0?oooooooooo00Go
oooo0_ooO`0@ooooo`030:0Pl?oooooooooo00Oooooo00?oogl0ooooo`3oO`001oooool00oooO`3o
ooooooooo`0:ooooo`03oomo0?ooool0X23`00Kooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`0hooooo`030:0Pl?oooooooooo00Sooooo00<0ogl0ooooooooool01@3oO`06ooooo`03
0:0Pl?oooooooooo02;ooooo00<0X23`ooooooooool00oooool00`3oO`3oooooooooo`0Aooooo`03
0?mo0?ooool0ogl000;ooooo00<0ogl0ooooooooool01?ooool00`3oO`3oooooooooo`0Cooooo`03
o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo047ooooo00@0X23`ooooooooool0
X23`1?ooool00`2P8?3ooooo0:0Pl00;ooooo`040?mo0?oooooooooo0?mo00gooooo00D0X23`oomo
0?oooooooooo0:0Pl005ooooo`03oomo0?oooooooooo00;ooooo00<0X23`oomo0?ooO`000_ooool0
0oooO`3oooooooooo`03ooooo`060:0Pl?ooooooooooooooo`2P8?3ooooo0P2P8?000oooool0ogl0
ooooo`0:ooooo`03oomo0?oooooooooo00Oooooo00<0X23`ooooooooool00_ooool01?ooO`3ooooo
oomo002P8?04ooooo`050:0Pl?ooooooooooooooo`0000004Oooool00ol0003oooooooooo`0joooo
o`030:0Pl?oooooooooo0080X23`0_ooool00`3oO`00X23`ooooo`02ooooo`060:0Pl03oO`3ooooo
ooooo`2P8?00ogl00`2P8?001?ooool0X23`ooooo`3oO`02ooooo`040?mo0?oooooooooo0:0Pl2?o
oooo00H0ogl0ooooooooool0X23`ooooo`2P8?06ooooo`050?mo0?ooooooooooooooo`3oO`001Ooo
ool00`3oO`3oooooooooo`020?mo01_ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0@_ooool00`2P8?3oooooooooo`0;ooooo`050:0Pl?ooool0X23`ooooooooO`002ooo
ool20:0Pl0?ooooo00?oogl0ooooooooool02_ooool00oooO`3oooooooooo`04ooooo`03oomo0?oo
oooooooo00;ooooo00?oogl0ooooooooool03Oooool00`2P8?3oooooooooo`06ooooo`80X23`1Ooo
ool00oooO`3oooooooooo`07ooooo`030:0Pl?oooooooooo00Gooooo00?oogl0ooooo`0000004Ooo
ool00ol0003oooooooooo`0mooooo`030:0Pl?ooool0X23`00Wooooo00<0ogl0ooooo`2P8?000P2P
8?000`3oO`3oooooooooo`06ooooo`050:0Pl?oooooooooo0?mo002P8?002Oooool00`3oO`3ooooo
ooooo`03ooooo`030?mo0?oooooooooo013ooooo00<0X23`ooooooooool01oooool00`3oO`3ooooo
ooooo`09ooooo`030?mo0?oooooooooo01_ooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0?Oooool00`2P8?3oooooooooo`0:ooooo`040:0Pl?oooooooooooomo00Wooooo
00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`09ooooo`?oogl000Gooooooomo0?oooooo
oooo0:0Pl002ooooo`050:0Pl?ooooooooooooooooooO`002_ooool0102P8?00ogl0ooooooooO`07
ooooo`030?mo0?ooool0X23`00Cooooo00@0X23`ooooooooool0X23`1_ooool00`2P8?3ooooooooo
o`09ooooo`040:0Pl?oooooooooo0000017ooooo00?o0000ooooooooool0>oooool00`2P8?3ooooo
ooooo`07ooooo`80X23`0_ooool20:0Pl006ooooo`2P8?3ooooo0?mo002P8?00ogl00_ooool0103o
O`3ooooo0:0Pl?ooool20:0Pl0[ooooo00<0ogl0ooooooooool04?ooool00`3oO`3oooooooooo`0A
ooooo`80ogl09_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Boooo
o`040:0Pl?oooooooooo0:0Pl0Gooooo00@0ogl0oooooooooooooooo0_ooO`07ooooo`030?mo0?oo
ooooogl000;ooooo00<0X23`ooooo`2P8?000_ooO`03ooooo`;oogl00_ooool0102P8?3ooooooooo
ooooO`09ooooo`050:0Pl?ooooooogl00:0Pl?ooO`000_ooool00`2P8?3oooooooooo`02ooooo`03
0:0Pl?oooooooooo00Kooooo00H0X23`ooooooooool0X23`ooooooooO`03ooooo`04oomo0?oooooo
ogl0oomo00[ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`16ooooo`030?mo0?oo
oooooooo00;ooooo00l0ogl0ooooo`3oO`00X23`ooooo`2P8?3ooooo0:0Pl?ooool0X23`0?mo0?oo
ool0X23`ooooo`2P8?003Oooool00`3oO`3ooooo0?mo0008ooooo`050:0Pl?ooooooooooooooo`3o
O`000_ooool00`3oO`3oooooooooo`06ooooo`030?mo0?oooooooooo00_ooooo00<0ogl0oooooooo
ool00_ooool0103oO`3oooooooooooooool20?mo01Oooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0Doooool00`2P8?3oooooooooo`09ooooo`040:0Pl?oooooooooooomo
01;ooooo00Googl0ooooooooO`3ooooooomo0002ooooo`06oomo0?oooooooooooomo0?ooooooogl0
1?ooool3oomo00Kooooo00@0X23`ooooooooool0X23`1_ooool00`2P8?3oooooooooo`0;ooooo`03
oomo0?oooooooooo00Oooooo00<0X23`00000?ooool04?ooool00ol0003oooooooooo`14ooooo`03
0?mo0?ooool0ogl000;ooooo00X0ogl0ooooooooool0X23`ooooo`2P8?3ooooo0?mo0?ooool0X23`
0_ooool00`2P8?3oooooooooo`07ooooo`030?mo0?oooooooooo01Oooooo00<0ogl0ooooooooool0
2_ooool01@2P8?3ooooo0?mo0?ooool0X23`00?ooooo00<0ogl0ooooooooool08Oooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`1:ooooo`070:0Pl?ooooooooooooooo`2P
8?3ooooooomo0003ooooo`03oomo002P8?00X23`00;ooooo00@0ogl0ooooooooooooogl00oooool0
0oooO`3oooooooooo`02ooooo`;oogl000@0X23`ooooooooooooogl00_ooool00`2P8?3oogl00?mo
0005ooooo`04oomo0?ooooooogl0ooooo`;oogl000?ooooo0:0Pl?ooool00_ooool0202P8?3ooooo
ooooo`2P8?3ooooo0?mo0?ooooooogl00oooool01@2P8?3oooooooooooooool0X23`00?ooooo00Go
ogl0oooooooooooooooo0:0Pl006ooooo`03oomo0?ooooooogl000Kooooo00?oogl0ooooooooO`00
0_ooool00oooO`3oooooooooo`02ooooo`030:0Pl000003ooooo013ooooo00?o0000ooooooooool0
A_ooool01P2P8?3oooooooooo`2P8?3ooooo0:0Pl080ogl000H0X23`0?mo002P8?00ogl00:0Pl03o
O`03ooooo`060:0Pl?ooooooooooooooo`2P8?00ogl00oooool00`3oO`3oooooooooo`08ooooo`03
0?mo0?oooooooooo00;ooooo00<0X23`ooooo`3oO`003oooool00`2P8?00ogl0ooooo`03ooooo`03
0?mo0?oooooooooo00Cooooo00<0ogl0ooooooooool03oooool00`3oO`3oooooooooo`0>ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04kooooo00<0X23`ooooooooool0
1oooool0102P8?3oooooooooooooool2oomo0003ooooo`2P8?00ogl000cooooo00Koogl0oooooooo
ooooogl00:0Pl?ooO`0Cooooo`04oomo0?oooooooooooomo013ooooo00<0X23`oomo0?ooool02_oo
ool00oooO`3oooooooooo`02ooooo`;oogl00oooool00`2P8?000000ooooo`0@ooooo`03o`000?oo
oooooooo04Gooooo00<0X23`ooooooooool00oooool0102P8?3ooooo0?mo003oO`020:0Pl0040?mo
002P8?3ooooo0?mo00Cooooo00H0X23`ooooooooool0ogl0ooooo`3oO`0Pooooo`030:0Pl?oooooo
oooo00[ooooo00<0ogl0ooooo`3oO`002_ooool00`3oO`3oooooooooo`0Fooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo04_ooooo00D0X23`oooooooooooooooo0:0Pl007
ooooo`050:0Pl?ooO`3oooooooooo`2P8?000oooO`03ooooo`03oomo0?oooooooooo00?ooooo00<0
ogl0ooooooooool00oooool00`2P8?3oooooooooo`04ooooo`03oomo0?oooooooooo013ooooo00<0
X23`ooooooooool00_ooool00oooO`00X23`ooooo`0=ooooo`030:0Pl?oooooooooo00;ooooo00<0
X23`ooooo`2P8?002?ooool01_ooO`3oooooooooooooooooogl00000017ooooo00?o0000oooooooo
ool0AOooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00?ooooo0P3oO`001P2P8?00
ogl00?mo002P8?3ooooo0:0Pl0?ooooo0P2P8?0Fooooo`030:0Pl?oooooooooo00?ooooo00<0ogl0
ooooooooool01Oooool00`3oO`3oooooooooo`0=ooooo`030?mo0?oooooooooo01kooooo00?o0000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0AOooool00`2P8?3oooooooooo`03oooo
o`03oomo0?oooooooooo00Gooooo00<0X23`ooooooooool01?ooool0102P8?3oooooooooooooO`05
ooooo`05oomo0?ooooooogl0ooooo`2P8?002_ooool01?ooO`3oooooooooo`3oO`02oomo00?ooooo
0_ooO`09ooooo`030?mo0?ooool0X23`00?ooooo00Googl00:0Pl?oooooooooooomo0003ooooo`03
oomo0?oooooooooo00Cooooo00?oogl0ooooooooO`005?ooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo047ooooo00<0X23`ooooo`3oO`001Oooool01`3oO`3ooooo0:0Pl03oO`3ooooo
0:0Pl03oO`000P2P8?040?mo013ooooo00<0X23`ooooooooool04?ooool00`3oO`3ooooo0?mo000:
ooooo`030?mo0?oooooooooo01?ooooo00<0ogl0ooooooooool04oooool00ol0003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`1@ooooo`040:0Pl?oooooooooo0:0Pl0Oooooo00?oogl0
ooooooooool00_ooool01?ooO`00ogl0oomo0?ooO`09ooooo`030?mo0?oooooooooo00gooooo00<0
X23`ooooooooool03_ooool00oooO`3oooooooooo`02ooooo`030:0Pl?oooooooooo01[ooooo00<0
X23`ooooo`0000004Oooool00ol0003oooooooooo`1>ooooo`80X23`0oooool01P2P8?3ooooo0?mo
003oO`00X23`0?mo00Kooooo00<0X23`ooooooooool03?ooool00`3oO`3oooooooooo`0;ooooo`03
0?mo0?oooooooooo03?ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
A_ooool01@2P8?3oooooooooooooool0X23`00Cooooo00@0X23`ooooooooooooogl00_ooool01P2P
8?3ooooooomo0?ooooooogl0ooooo`;oogl000<0X23`ooooooooO`002?ooool01@2P8?3ooooooooo
ooooool0X23`00Wooooo0_ooO`000oooool0ogl0ooooo`03ooooo`06oomo0?oooooooooo0:0Pl?oo
ooooogl01_ooool00oooO`3oooooooooo`03ooooo`060:0Pl?ooooooogl00:0Pl03oO`3ooooo0_oo
O`000oooool0ogl00?mo000Cooooo`050:0Pl?oooooooooo0:0Pl00000004Oooool00ol0003ooooo
ooooo`12ooooo`030:0Pl?oooooooooo00Cooooo00/0ogl0ooooooooool0X23`0?mo002P8?3ooooo
0:0Pl?ooool0X23`0?mo00020:0Pl080ogl000<0X23`ooooo`3oO`002Oooool01@2P8?3ooooooooo
ooooool0X23`00Wooooo00<0ogl0ooooooooool03?ooool00`2P8?3oooooooooo`03ooooo`030:0P
l?oooooooooo00kooooo00<0ogl0ooooo`3oO`000oooool00`3oO`3oooooooooo`03ooooo`030?mo
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0Dooo
ool0102P8?3oooooooooo`2P8?03ooooo`040:0Pl?ooO`00X23`oomo00;ooooo0_ooO`0>ooooo`03
oomo0?oooooooooo00Kooooo00Coogl0ooooooooO`3oogl01_ooool01_ooO`3ooooooomo003oO`3o
oooo0:0Pl0;ooooo00D0X23`oooooooooooooooo0:0Pl004ooooo`03oomo0?oooooooooo00Cooooo
00<0X23`ooooooooool02Oooool01?ooO`3oooooooooooooO`02ooooo`030:0Pl?oooooooooo00;o
oooo00<00000ooooooooool03oooool00ol0003oooooooooo`16ooooo`030:0Pl?oooooooooo00?o
oooo00<0X23`0?mo0?ooool00P2P8?020?mo0004ooooo`3oO`00X23`0:0Pl080ogl000?ooooo0:0P
l?ooool00_ooool00`2P8?3oooooooooo`0<ooooo`030?mo0?oooooooooo02Cooooo00<0ogl0oooo
ooooool00_ooool00`3oO`3oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo04kooooo00<0X23`ooooooooool01?ooool2oomo00Gooooo00Ooogl00:0Pl?oo
oooooooooomo0?ooooooogl000Sooooo00Googl0ooooooooool0X23`oomo000;ooooo`03oomo0?oo
oooooooo01;ooooo00?oogl0ooooooooool05Oooool00`2P8?3oooooooooo`07ooooo`0300000?oo
oooooooo00oooooo00?o0000ooooooooool0C_ooool0102P8?00ogl00?mo0?ooool20?mo0003oooo
o`3oO`00ogl00080ogl000Gooooo0?mo002P8?3ooooo0:0Pl002ooooo`030?mo0?oooooooooo01Ko
oooo00<0X23`ooooo`3oO`00=_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`1;ooooo`030:0Pl?oooooooooo00Wooooo00Ooogl00:0Pl?ooool0X23`oomo002P8?3ooooo
00Coogl000?ooooooomo002P8?000P2P8?002?ooool0X23`ooooo`3oO`3ooooooomo002P8?3oogl0
1oooool00`2P8?3oooooooooo`07ooooo`030:0Pl?oooooooooo00?ooooo00?oogl0ooooooooool0
2oooool0102P8?3oooooooooooooool4oomo0003ooooooooO`3oogl000;ooooo00Googl0oooooooo
oooooooooomo0003ooooo`03oomo0?oooooooooo00Kooooo00<00000ooooooooool03oooool00ol0
003oooooooooo`19ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool0103oO`040:0P
l0040?mo002P8?3ooooo0:0Pl0;ooooo00<0ogl0ooooooooool02?ooool00`2P8?3oooooooooo`0E
ooooo`030?mo0?oooooooooo00kooooo00<0ogl0ooooooooool01Oooool01P3oO`3oooooooooo`3o
O`3ooooo0?mo017ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0HOoo
ool01@3oO`3oooooooooooooooooogl000cooooo00<0X23`oomo0?ooool02Oooool3oomo01oooooo
00Coogl0ooooooooooooogl01?ooool00oooO`3ooooo0:0Pl004ooooo`04oomo0?ooool0X23`0000
017ooooo00?o0000ooooooooool0C_ooool0103oO`3oooooooooo`3oO`03ooooo`@0ogl000?ooooo
0?mo0?ooool00oooool00`2P8?3oooooooooo`02ooooo`050:0Pl?ooooooooooooooo`3oO`002_oo
ool00`3oO`3oooooooooo`0@ooooo`030:0Pl?ooool0ogl000Cooooo00<0ogl0ooooooooool08_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Hooooo`070:0Pl?oooooo
oooo0:0Pl?ooool0ogl0ooooo`020:0Pl003ooooo`2P8?3ooooo00Oooooo00Googl0oooooooooooo
oooooomo0004ooooo`03oomo002P8?3ooooo00;ooooo00Coogl0ooooooooooooogl03?ooool01?oo
O`3oooooooooooooO`09ooooo`80X23`00?ooooooomo0?ooool00oooool00oooO`3oooooooooo`07
ooooo`03oomo0?oooooooooo00;ooooo00<0X23`ooooooooool00_ooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo04kooooo00D0X23`ooooo`2P8?3ooooo0:0Pl0030?mo00070:0Pl03o
O`00ogl00:0Pl03oO`3ooooo0:0Pl002ooooo`030:0Pl?ooool0X23`027ooooo00<0X23`oooooooo
ool01?ooool00`3oO`3oooooooooo`0Cooooo`040?mo0?oooooooooo0?mo00kooooo00?o0000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0Coooool00`2P8?3oooooooooo`0:ooooo`04
oomo0?oooooooooo0?mo00Gooooo00<0ogl0ooooooooool00oooool00`2P8?3ooooooomo0004oooo
o`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooO`002?ooool00oooO`3oooooooooo`02oooo
o`030:0Pl?ooool0X23`01cooooo00?oogl0ooooooooool01oooool00`00003oooooooooo`0?oooo
o`03o`000?oooooooooo04_ooooo00<0X23`ooooo`2P8?001?ooool00`2P8?3oooooooooo`03oooo
o`050?mo0?ooool0ogl00?mo002P8?002Oooool01@3oO`3oooooooooooooool0ogl000cooooo00<0
ogl0ooooooooool0>?ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1C
ooooo`040:0Pl?oooooooooo0:0Pl0Gooooo00Soogl0oooooooooooooooo0:0Pl03oO`3ooooooomo
00Kooooo00?oogl0ooooooooO`000_ooool00oooO`3oooooooooo`03ooooo`060:0Pl?ooooooogl0
ooooo`2P8?3oogl01Oooool00`2P8?3oogl0oomo000;ooooo`030:0Pl?oooooooooo00?ooooo00Go
ogl0oooooooooooooooo0?mo000;ooooo`03oomo0?oooooooooo00Sooooo00@0X23`ooooo`2P8?00
00004Oooool00ol0003oooooooooo`1=ooooo`030:0Pl?oooooooooo00;ooooo00<0ogl0oooooooo
ool00_ooool20:0Pl0;ooooo0P3oO`001@2P8?3ooooo0:0Pl02P8?00ogl000Cooooo0P2P8?000ooo
ool0ogl0ooooo`08ooooo`050:0Pl?ooooooooooooooo`3oO`001?ooool0103oO`3oooooooooo`3o
O`0=ooooo`030?mo0?oooooooooo00?ooooo00<0ogl0ooooooooool07?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`1Tooooo`040?mo0?oooooooooo0:0Pl0Gooooo00?o
ogl0ooooooooO`000_ooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo00Gooooo00?o
ogl0ooooooooool01?ooool00oooO`3oooooooooo`0Pooooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool0EOooool00`3oO`3oooooooooo`04ooooo`050?mo002P8?00ogl00?mo0?ooool0
0P3oO`07ooooo`030?mo0?oooooooooo01[ooooo00<0ogl0ooooooooool0:?ooool00ol0003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`1Fooooo`80X23`1oooool00`2P8?3ooooooooo
o`06ooooo`030:0Pl?oooooooooo00Kooooo00<0ogl0ooooooooool00oooool00`2P8?3oogl0oomo
0009ooooo`030:0Pl?ooO`3ooooo00cooooo00<0X23`oomo0?ooool01Oooool00oooO`3ooooooooo
o`03ooooo`;oogl04?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo00@0
X23`ooooooooool0X23`1?ooool01`2P8?3ooooo0?mo0?ooool0ogl00:0Pl03oO`001Oooool00`2P
8?3oooooooooo`0>ooooo`030:0Pl03oO`3ooooo00Oooooo00<0ogl0ooooooooool01?ooool00`3o
O`3oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05co
oooo00Googl0ooooooooooooogl0ooooo`020:0Pl0Cooooo0oooO`04ooooo`03oomo0?ooooooogl0
00Kooooo00D0X23`oooooooooooooooo0:0Pl002ooooo`030:0Pl?oooooooooo00Oooooo00?oogl0
0:0Pl?ooO`001oooool00`2P8?3oooooooooo`04ooooo`030:0Pl03oO`3ooooo01Kooooo00<00000
ooooooooool03oooool00ol0003oooooooooo`1Booooo`030?mo0?oooooooooo00;ooooo00H0X23`
0?mo0?ooool0X23`ooooo`2P8?02ooooo`D0X23`3?ooool00`2P8?3oooooooooo`0Iooooo`030?mo
0?oooooooooo01;ooooo00<0ogl0ooooooooool03_ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`1Eooooo`040:0Pl?ooooooooooooooo`80X23`0oooool00`3oO`3ooooo
ooooo`06ooooo`Coogl01Oooool00oooO`3ooooooomo0003ooooo`05oomo0?oooooooooooomo002P
8?001_ooool00oooO`3oooooooooo`09ooooo`030?mo0?oooooooooo00_ooooo0P3oO`06ooooo`03
0:0Pl?oooooooooo00_ooooo00?oogl000000?ooool04?ooool00ol0003oooooooooo`1Booooo`03
0:0Pl?oooooooooo00;ooooo0P2P8?020?mo00;ooooo00@0ogl0oooooooooooooooo0P3oO`000`2P
8?3oooooooooo`0>ooooo`050?mo0?ooooooooooooooo`2P8?005?ooool20?mo00Gooooo00@0ogl0
ooooooooool0ogl06_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1J
ooooo`030:0Pl?oooooooooo00Kooooo00D0ogl0ooooooooool0ogl0ooooo`06oomo0003oooooooo
O`3ooooo017ooooo00<0X23`ooooooooool02?ooool00`3oO`3oooooooooo`02ooooo`040:0Pl?oo
oooooooo0:0Pl0Gooooo00?oogl0ooooooooool03Oooool00oooO`3oooooooooo`03ooooo`030:0P
l000003ooooo013ooooo00?o0000ooooooooool0F?ooool0102P8?3ooooo0:0Pl02P8?020?mo0003
ooooo`3oO`3ooooo00H0ogl01?ooool00`2P8?3ooooo0:0Pl00:ooooo`80ogl04_ooool0103oO`3o
ooooooooo`2P8?0Rooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05Go
oooo00<0X23`ooooooooool01_ooool01`2P8?3oooooooooo`2P8?3ooooo0?mo0?ooool00P3oO`00
1?ooooooogl0oomo0?ooool3oomo0003ooooooooO`00ogl000[ooooo00@0X23`ooooooooO`3oogl0
1?ooool00oooO`3oooooooooo`0:ooooo`05oomo0?ooooooooooooooo`2P8?003oooool00`2P8?3o
ooooooooo`05ooooo`030:0Pl?oooooooooo00?ooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`1?ooooo`030:0Pl?oooooooooo00[ooooo00H0ogl00:0Pl03oO`00ogl0ooooo`2P8?03
0?mo0003ooooo`2P8?3ooooo00;ooooo00<0X23`ooooo`3oO`000oooool01@3oO`3ooooooooooooo
ool0ogl000Sooooo00D0X23`oooooooooooooooo0:0Pl00`ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo06Cooooo00<0X23`0?mo0?ooool00oooool4oomo00;ooooo00?o
ogl0ooooooooool01_ooool01OooO`3oooooooooooooooooogl001Kooooo00<0X23`ooooooooool0
6oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo05gooooo00D0ogl0ooooo`3oO`3o
oooo0:0Pl0050?mo01gooooo00<0X23`ooooooooool0:oooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1Jooooo`030:0Pl?oooooooooo00Cooooo00Googl0ooooooooO`3o
oooo0?mo0002ooooo`03oomo0?ooool0X23`00?oogl000<0X23`oomo0?ooO`000oooool00`3oO`3o
ogl0ooooo`08ooooo`030:0Pl?ooO`3ooooo00cooooo00?oogl0ooooooooool00_ooool00`2P8?3o
ooooooooo`0Looooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0EOooool00`2P8?3o
ooooooooo`05ooooo`060?mo0?ooool0ogl00?mo002P8?3ooooo0P2P8?030?mo00;ooooo0P3oO`00
0oooool0X23`ooooo`13ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
05_ooooo00<0X23`ooooooooool02?ooool00`2P8?3oooooooooo`03ooooo`;oogl000?ooooooomo
0?ooO`002_ooool01?ooO`3oooooooooo`3oO`0:ooooo`05oomo0?ooooooooooooooooooO`000_oo
ool0102P8?3oooooooooooooO`0Nooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
E_ooool00`2P8?3oooooooooo`03ooooo`080?mo0?ooool0ogl00?mo0?ooool0X23`ooooo`2P8?02
ooooo`80ogl000?ooooo0?mo0?ooool0Aoooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`1Qooooo`0=0:0Pl?ooooooogl0oomo0?ooool0ogl0ooooo`2P8?3oogl0oooooooo
O`3ooooo0:0Pl003oomo0005ooooooooO`3oooooooooooooO`001Oooool00oooO`3ooooo0:0Pl008
ooooo`05oomo0?ooooooooooooooo`2P8?000oooool01oooO`3oooooooooooooooooogl0ooooo`2P
8?000_ooool00oooO`3ooooo0:0Pl00=ooooo`030:0Pl?oooooooooo00Sooooo00<00000oooooooo
ool03oooool00ol0003oooooooooo`1Looooo`030:0Pl03oO`00ogl00080ogl000?ooooo0?mo002P
8?000P3oO`020:0Pl0050?mo0?ooool0X23`ooooo`2P8?001Oooool00`2P8?3ooooo0:0Pl002oooo
o`030?mo0?oooooooooo03Sooooo00?o0000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0I_ooool01@2P8?3oooooooooooooool0X23`00?ooooo00?oogl0ooooooooool00_ooO`02oooo
o`03oomo0?oooooooooo00Cooooo00<0X23`ooooooooool00_ooool01?ooO`3oooooooooo`2P8?0=
ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`0?mo0?ooool05_ooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo05[ooooo00<0X23`ooooooooool00oooool02@2P8?3oooooooooo`2P
8?3ooooo0?mo0?ooool0X23`ooooo`020?mo0005ooooo`2P8?3oooooooooo`2P8?002Oooool00`3o
O`3oooooooooo`0Iooooo`030?mo0?oooooooooo01[ooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0I_ooool00oooO`3ooooo0?mo0007ooooo`03oomo0?ooooooogl000co
oooo00?oogl00:0Pl?ooool01?ooool00oooO`3oooooooooo`06ooooo`030:0Pl?oooooooooo00Co
oooo00<0ogl0ooooooooool06Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo06;o
oooo103oO`02ooooo`050:0Pl?oooooooooo0:0Pl03oO`009_ooool00`3oO`3oooooooooo`0Loooo
o`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo05gooooo00<0X23`oooooooo
ool01_ooool01?ooO`3ooooo0:0Pl?ooO`02ooooo`07oomo002P8?3ooooooomo002P8?3ooooo0?mo
0003ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool00_ooool00`2P8?3ooooooooo
o`04ooooo`030?mo0?oooooooooo00?ooooo00Coogl0ooooooooooooogl00oooool00oooO`3ooooo
ooooo`0;ooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool00oooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo05[ooooo00<0X23`ooooooooool00oooool0102P8?00ogl0
0?mo002P8?030?mo0003ooooo`3oO`00ogl00080ogl000Gooooo0:0Pl?oooooooooo0:0Pl005oooo
o`030?mo0?oooooooooo01gooooo00<0ogl0ooooooooool06Oooool00ol0003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`1Xooooo`03oomo0?oooooooooo00;ooooo00Coogl0oooooooo
O`3oogl04?ooool2oomo00Kooooo00?oogl0ooooooooO`000_ooool00oooO`3oooooooooo`08oooo
o`03oomo0?oooooooooo01Kooooo00<00000ooooooooool03oooool00ol0003oooooooooo`1Qoooo
o`80ogl000?ooooo0?mo003oO`00103oO`0Looooo`030?mo0?oooooooooo02Wooooo00?o0000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0H_ooool00`2P8?3oooooooooo`03ooooo`05
0:0Pl?ooO`00X23`0?mo0?ooO`001Oooool01oooO`3oooooooooooooooooogl0ooooooooO`001Ooo
ool00`3oO`3oooooooooo`0Cooooo`03oomo0?ooool0ogl000;ooooo00<0X23`ooooooooool05_oo
ool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo05gooooo0`2P8?001?ooool0ogl0oooo
ooooool20?mo00030:0Pl03oO`00X23`00Gooooo00<0X23`0?mo0?ooool05oooool00`3oO`3ooooo
ooooo`0;ooooo`030?mo0?oooooooooo01Wooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0F_ooool00`2P8?3oooooooooo`0=ooooo`;oogl00_ooool00`2P8?3ooooo0?mo
000Sooooo`03oomo0?oooooooooo00Oooooo00H0ogl0ooooooooooooogl0ooooooooO`0>ooooo`03
00000?oooooooooo00oooooo00?o0000ooooooooool0G?ooool00`2P8?3oooooooooo`06ooooo`<0
ogl00_ooool00`2P8?3ooooo0?mo000Fooooo`030?mo0?oooooooooo00kooooo00<0ogl0oooooooo
ool06oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Zooooo`Coogl0
00?ooooo0:0Pl?ooool01?ooool00`2P8?3oooooooooo`02ooooo`03oomo0?oooooooooo00Kooooo
00H0X23`ooooooooool0ogl0oomo002P8?0Eooooo`03oomo0?oooooooooo00Kooooo00?oogl0oooo
ooooool00oooool00`2P8?3oogl0ooooo`02ooooo`0300000?oooooooooo00oooooo00?o0000oooo
ooooool0HOooool0103oO`3oooooooooooooool40?mo0003ooooo`2P8?00ogl00080ogl000<0X23`
ooooo`3oO`001_ooool01@2P8?3oooooooooooooool0X23`00Oooooo00<0X23`ooooooooool07Ooo
ool00`3oO`3oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo06_ooooo00?oogl00?mo0?ooO`000_ooool00`2P8?3oooooooooo`0Aooooo`030:0Pl?oooooo
oooo00?ooooo00<0X23`ooooooooool01?ooool00`2P8?3oooooooooo`0Cooooo`030:0Pl?oooooo
oooo00Oooooo00<0X23`00000?ooool04?ooool00ol0003oooooooooo`1Vooooo`040?mo0?ooool0
ogl00?mo00;ooooo00D0ogl0ooooo`2P8?3ooooo0:0Pl008ooooo`030:0Pl?ooool0X23`00kooooo
00<0X23`ooooooooool09Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`1Zooooo`03oomo0?ooooooogl000;oogl000<0X23`ooooo`2P8?000_ooool00oooO`3ooooooooo
o`0?ooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool08?ooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo06Sooooo00@0ogl0ooooo`3oO`3ooooo0P2P8?000`3oO`3ooooo
ooooo`11ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo06[ooooo00Co
ogl00:0Pl?ooooooogl00oooool01OooO`00ogl0ooooooooooooogl000?ooooo00?oogl0oooooooo
ool02Oooool00oooO`00ogl0ooooo`05ooooo`05oomo0?ooooooooooooooo`2P8?001Oooool01@3o
O`3oogl0ooooooooool0ogl001Kooooo00<00000ooooooooool03oooool00ol0003oooooooooo`1W
ooooo`80ogl000Cooooo0?mo0?ooool0X23`103oO`02ooooo`040?mo0?oooooooooo0:0Pl0Wooooo
00<0ogl0ooooooooool00oooool00`3oO`3oooooooooo`0=ooooo`030?mo0?oooooooooo00Oooooo
00<0ogl0ooooooooool03oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`1Zooooo`030:0Pl?ooooooogl000;oogl01_ooool00`2P8?3oooooooooo`0Booooo`03oomo0?oo
oooooooo00Wooooo00<0X23`ooooooooool06Oooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo06Wooooo00@0X23`0?mo003oO`00X23`2?ooool00`2P8?3oooooooooo`02ooooo`030?mo
0?oooooooooo01?ooooo00<0ogl0ooooooooool07oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`1]ooooo`03oomo0?oooooooooo00;oogl00oooool00`2P8?3ooooooooo
o`03ooooo`040?mo0?ooooooogl0oomo00;ooooo00<0X23`ooooooooool02Oooool00`2P8?3ooooo
ooooo`03ooooo`03oomo0?oooooooooo00Oooooo00<0X23`ooooooooool04_ooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo06Sooooo00<0ogl0ooooooooool00`3oO`04ooooo`80X23`
00?ooooo0:0Pl03oO`000P3oO`04ooooo`030:0Pl?oooooooooo00Kooooo00<0X23`ooooooooool0
:Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1]ooooo`030:0Pl?oo
O`3oogl001?ooooo00<0ogl0ooooooooool06_ooool2oomo013ooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`1Yooooo`<0ogl01_ooool0103oO`3oooooooooo`2P8?05ooooo`050?mo
0?ooooooooooooooo`3oO`00<_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`1Yooooo`040:0Pl?oooooooooooomo01Wooooo00D0X23`oooooooooooooooo0:0Pl005oooo
o`030:0Pl?oooooooooo00gooooo00Coogl0ooooooooooooogl03_ooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo067ooooo00<0X23`ooooooooool01_ooool01@3oO`3oooooooooo`2P
8?00ogl000?ooooo00@0X23`ooooo`2P8?00X23`;oooool00`3oO`3oooooooooo`0:ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo077ooooo00?oogl0ooooooooool00ooo
ool00`3oO`3ooooo0:0Pl009ooooo`030:0Pl?oooooooooo00;ooooo00?oogl0ooooooooool01?oo
ool00oooO`3oooooooooo`02ooooo`05oomo0?ooooooogl0oomo002P8?001Oooool00`2P8?3ooooo
oomo0002ooooo`030:0Pl?oooooooooo00?ooooo00<0ogl0ooooooooool01_ooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo06Wooooo00D0X23`0?mo0?oooooooooo0?mo0002ooooo`08
0?mo0?ooooooooooooooo`2P8?00ogl0ooooo`2P8?02ooooo`040:0Pl?oooooooooo0:0Pl1cooooo
00<0ogl0ooooooooool05Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`1gooooo`03oomo0?ooool0X23`00gooooo00@0X23`ooooo`3oO`3oogl01Oooool00oooO`3ooooo
ooooo`04ooooo`030:0Pl?ooool0ogl000Cooooo00Coogl0ooooooooool0X23`1?ooool00oooO`3o
ooooooooo`05ooooo`050:0Pl?ooooooooooooooo`0000004Oooool00ol0003oooooooooo`1`oooo
o`080:0Pl?ooool0ogl0ooooo`3oO`3ooooo0?mo002P8?02ooooo`030?mo002P8?00X23`00Sooooo
00<0X23`ooooooooool0:_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`1cooooo`03oomo0?ooooooogl001Kooooo00?oogl0ooooooooool00oooool00`2P8?3ooooooooo
o`0=ooooo`030?mo0?ooO`3ooooo00gooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`1^ooooo`030?mo0?ooool0ogl000Wooooo00<0ogl0ooooo`2P8?00:Oooool00`3oO`3ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo07Gooooo00<0X23`
ooooo`2P8?000_ooool00`2P8?3oooooooooo`05ooooo`03oomo0?oooooooooo02cooooo00?oogl0
00000?ooool04?ooool00ol0003oooooooooo`1booooo`070?mo0?ooool0X23`ooooo`2P8?3ooooo
0:0Pl00@ooooo`030?mo0?oooooooooo02Kooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0Q_ooool00oooO`3oooooooooo`0Aooooo`030?mo0?oooooooooo01;ooooo00Co
ogl0ooooooooool000004Oooool00ol0003oooooooooo`1mooooo`030?mo0?oooooooooo00oooooo
00<0ogl0ooooooooool01Oooool00`3oO`3oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo07_ooooo00<0X23`ooooooooool00oooool00oooO`00X23`oooo
o`02ooooo`030:0Pl?oooooooooo00?ooooo00<0ogl0ooooooooool00oooool01@3oO`3ooooooooo
ooooool0X23`00;ooooo00?oogl0ooooooooool00_ooool01@3oO`3oooooooooooooooooogl000oo
oooo00<00000ooooooooool03oooool00ol0003oooooooooo`1fooooo`030:0Pl?ooool0X23`00@0
ogl000?ooooo0:0Pl02P8?000_ooool00`3oO`3oooooooooo`0]ooooo`03o`000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo09;ooooo00<0X23`ooooooooool02_ooool00`3oO`3ooooo
ooooo`0@ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0NOooool00`3oO`3ooooo
ooooo`05ooooo`030:0Pl?oooooooooo02kooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0O_ooool00`2P8?3oooooooooo`0Aooooo`060?mo0?oooooooooo0:0Pl?ooool0
X23`0_ooO`05ooooo`030:0Pl?ooooooogl000?ooooo00Coogl0ooooooooooooogl02Oooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo07?ooooo00@0ogl00:0Pl?ooool0X23`0_ooool2
0?mo0004ooooo`3oO`3ooooo0:0Pl0Cooooo00<0ogl0ooooooooool03?ooool00`2P8?3ooooooooo
o`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo07Gooooo00<0X23`
ooooooooool01_ooool01?ooO`3oooooooooo`2P8?04ooooo`03oomo0?ooool0X23`00Wooooo00<0
X23`ooooooooool02oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00Wooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`1cooooo`050:0Pl?ooooooooooooooo`3oO`00
0_ooool01@2P8?3ooooo0:0Pl?ooool0X23`00;ooooo00<0ogl0ooooooooool0;_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`1gooooo`030:0Pl?oooooooooo00Cooooo
0_ooO`000oooool0X23`oomo000;ooooo`050?mo002P8?3oooooooooooooO`001?ooool00`2P8?3o
ooooooooo`0<ooooo`03oomo0?oooooooooo00Wooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`1gooooo`030:0Pl?ooool0ogl000Cooooo0P2P8?00103oO`3ooooo0?mo002P8?05oooo
o`030?mo0?oooooooooo02Kooooo00?o0000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0NOooool20:0Pl0oooooo00?oogl0ooooooooool06Oooool00`2P8?3ooooo0?mo0009ooooo`03
00000?oooooooooo00oooooo00?o0000ooooooooool0NOooool0102P8?3oooooooooo`2P8?04oooo
o`030:0Pl?ooool0ogl001[ooooo00<0ogl0ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`22ooooo`030:0Pl?oooooooooo00Kooooo00Googl0oooooooo
oooooooo0:0Pl007ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooO`004Oooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo07?ooooo00<0X23`ooooo`3oO`002?ooool00`2P
8?3oooooooooo`03ooooo`030?mo0?oooooooooo00Oooooo00<0X23`ooooooooool08Oooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1nooooo`80X23`00Cooooo0:0Pl02P
8?00X23`1Oooool01P2P8?3oooooooooooooool0X23`ooooo`;oogl00oooool2oomo00?ooooo00<0
ogl0ooooo`2P8?001oooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00Oooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`1cooooo`080?mo0?ooooooooooooooo`2P8?3o
oooo0:0Pl03oO`02ooooo`80X23`0P3oO`030:0Pl0?ooooo00<0ogl0ooooooooool01Oooool00`2P
8?3oooooooooo`0Gooooo`030?mo0?oooooooooo00Kooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0OOooool00`2P8?3oooooooooo`0Hooooo`050:0Pl?oooooooooooooo
o`2P8?002oooool00`3oO`3ooooooomo0007ooooo`0300000?oooooooooo00oooooo00?o0000oooo
ooooool0M?ooool00`2P8?3oooooooooo`05ooooo`050?mo0?ooooooooooooooo`2P8?003_ooool0
0`2P8?3oooooooooo`0Jooooo`030?mo0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0Qoooool0102P8?3oooooooooooooO`06ooooo`04oomo0?oooooo
ooooooooo`;oogl03?ooool00`2P8?3ooooooomo0009ooooo`040?mo0?oooooooooo0000017ooooo
00?o0000ooooooooool0LOooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00Gooooo
00L0X23`oooooooooooooooo0?mo002P8?00ogl001_ooooo00<0ogl0ooooooooool03oooool00ol0
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`22ooooo`030:0Pl?oooooooooo00Co
oooo00?oogl0ooooooooool01_ooool00oooO`3ooooo0:0Pl002ooooo`80X23`1Oooool00`2P8?3o
ooooooooo`04ooooo`030:0Pl?oooooooooo00[ooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`1iooooo`030:0Pl?oooooooooo00Gooooo00L0X23`oooooooooooooooo0:0Pl?ooool0
ogl00080X23`00?ooooo0:0Pl?ooool09Oooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`1looooo`030:0Pl?oooooooooo00Wooooo00<0X23`ooooooooool00_ooool00`2P
8?3oooooooooo`07ooooo`03oomo0?ooool0X23`00kooooo00?oogl0ooooooooool01oooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo07Wooooo00<0X23`ooooooooool01Oooool01`3o
O`3ooooo0:0Pl?ooool0X23`ooooo`3oO`001Oooool00`2P8?3oooooooooo`0Rooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo08Sooooo00<0X23`ooooooooool01oooool0
0oooO`3oooooooooo`04ooooo`03oomo0?ooool0ogl000;ooooo00D0X23`oomo0?oooooooooooomo
0002ooooo`03oomo0?oooooooooo00Cooooo00@0ogl0ooooooooooooogl00_ooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo07kooooo00<0X23`ooooooooool00_ooool20?mo00;ooooo
00@0ogl0ooooooooool0ogl02Oooool00`3oO`3oooooooooo`04ooooo`050?mo0?oooooooooooooo
o`3oO`004_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2<ooooo`03
0:0Pl?oooooooooo01Cooooo00<0X23`ooooooooool03?ooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo087ooooo00<0X23`ooooo`2P8?00;_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`28ooooo`030:0Pl?ooO`3ooooo00;ooooo00Ooogl0ooooooooO`00
X23`ooooooooO`00ogl000Cooooo0_ooO`02ooooo`03oomo0?oooooooooo00?ooooo00<0X23`oomo
0?ooO`001?ooool2oomo00Oooooo00<00000ooooooooool03oooool00ol0003oooooooooo`26oooo
o`070:0Pl?ooool0X23`ooooo`2P8?3ooooo0?mo0007ooooo`030?mo0?ooool0ogl001_ooooo00?o
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0SOooool00`2P8?3oooooooooo`0E
ooooo`05oomo0?ooooooooooooooo`2P8?001oooool00oooO`000000ooooo`0@ooooo`03o`000?oo
oooooooo087ooooo00<0X23`ooooooooool00_ooool00`3oO`3oooooooooo`06ooooo`030:0Pl?oo
oooooooo00;ooooo00<0ogl0ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`2:ooooo`03oomo0?oooooooooo00;ooooo00<0X23`ooooooooool01Oooool0
0oooO`3oooooooooo`02ooooo`05oomo0?ooool0ogl0ooooo`2P8?001?ooool00`3oO`3ooooooooo
o`0:ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0O_ooool0102P8?3ooooo0:0P
l03oO`05ooooo`040?mo0?oooooooooo0?mo00;ooooo00<0ogl0ooooooooool02_ooool00`3oO`3o
ooooooooo`03ooooo`030?mo0?oooooooooo00oooooo00?o0000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0R_ooool00`2P8?3oooooooooo`04ooooo`030:0Pl?oooooooooo00cooooo
00@0X23`ooooooooooooogl01_ooool00oooO`3ooooo0?mo0004ooooo`030:0Pl000003ooooo013o
oooo00?o0000ooooooooool0Q_ooool01@2P8?3oooooooooooooool0X23`00?ooooo00D0X23`oooo
oooooooooooo0?mo0004ooooo`030:0Pl?oooooooooo00Oooooo00<0ogl0ooooooooool03_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2<ooooo`030:0Pl?oooooooooo
00[ooooo00<0X23`ooooooooool01oooool01_ooO`3oooooooooo`2P8?3ooooo0?mo00Wooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`28ooooo`040?mo0?oooooooooo0:0Pl0Gooooo
0P2P8?0Booooo`030?mo0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00<0
0000ooooooooool0Qoooool00`2P8?3oooooooooo`07ooooo`03oomo0?oooooooooo00?ooooo00D0
ogl0oooooooooooooooo0:0Pl004ooooo`030?mo0?oooooooooo00cooooo00@0X23`ooooo`2P8?00
00004Oooool00ol0003oooooooooo`23ooooo`<0X23`00<0ogl0ooooooooool00_ooool00`2P8?3o
oooo0?mo0007ooooo`030?mo0?oooooooooo00Cooooo00<0ogl0ooooooooool01?ooool00`3oO`3o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo08gooooo
00<0X23`ooooooooool01oooool00`2P8?3ooooo0?mo0004ooooo`03oomo0?oooooooooo00Cooooo
00?oogl00?mo0?ooool02_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo08gooooo
00<0X23`ooooooooool00_ooool00`3oO`3ooooo0?mo0002ooooo`030:0Pl?oooooooooo00kooooo
00<0ogl0ooooooooool01oooool00ol0003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`2?ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooO`002_ooool00`2P8?3ooooooooo
o`03ooooo`040?mo0?oooooooooo0:0Pl0;ooooo00<0ogl0ooooooooO`000_ooO`000`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo08Kooooo00L0X23`oooooooooooooooo0?mo0?ooool0X23`
0080ogl000@0X23`ooooo`2P8?00ogl00_ooool00`3oO`3oooooooooo`0:ooooo`030?mo0?oooooo
oooo00gooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0T_ooool00`2P
8?3oooooooooo`08ooooo`03oomo0?ooool0X23`00?ooooo00<0X23`0?mo0?ooool02oooool00`2P
8?000000ooooo`0@ooooo`03o`000?oooooooooo08?ooooo00<0X23`ooooooooool02Oooool20:0P
l004ooooo`2P8?3ooooo0?mo00;ooooo00<0X23`ooooooooool02Oooool00`3oO`3oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo09Cooooo00<0ogl0oooo
ooooool02Oooool00oooO`3oooooooooo`03ooooo`030?mo0?ooool0X23`00?ooooo00<0X23`oooo
ooooool00oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo08Kooooo00<0X23`oooo
ooooool02?ooool0102P8?00ogl0ooooo`3oO`0Mooooo`03o`000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo097ooooo00<0X23`ooooooooool00_ooool01?ooO`00X23`ooooo`2P8?06
ooooo`030?mo0?oooooooooo00Cooooo00@0ogl0ooooooooool0X23`1?ooool01?ooO`3ooooo0:0P
l000000Aooooo`03o`000?oooooooooo08[ooooo00<0X23`ooooo`3oO`000_ooool01P2P8?3ooooo
0:0Pl02P8?3ooooo0:0Pl0[ooooo00<0ogl0ooooooooool04?ooool00ol0003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`2;ooooo`030:0Pl?oooooooooo00?ooooo00<0X23`ooooo`2P
8?002oooool00oooO`00X23`ooooo`08ooooo`03oomo0?oooooooooo00Gooooo00<00000oooooooo
ool03oooool00ol0003oooooooooo`25ooooo`050:0Pl?ooooooooooooooo`2P8?001oooool20:0P
l005ooooo`3oO`3oooooooooo`2P8?006_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`23ooooo`030:0Pl?oooooooooo00gooooo00?oogl00:0Pl?ooool01Oooool01?oo
O`3oooooooooo`2P8?06ooooo`80ogl02oooool00`00003oooooooooo`0?ooooo`03o`000?oooooo
oooo08Cooooo00<0X23`ooooooooool01_ooool01`2P8?3oooooooooooooool0ogl00:0Pl03oO`00
0oooool00`2P8?3oooooooooo`05ooooo`030?mo0?oooooooooo013ooooo00?o0000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0U?ooool00`2P8?3oooooooooo`08ooooo`03oomo0?oo
oooooooo013ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`030:0Pl03o
O`3ooooo01_ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0UOooool0
0`2P8?3oooooooooo`0?ooooo`03oomo0?oooooooooo00Sooooo00<00000ooooooooool03oooool0
0ol0003oooooooooo`2@ooooo`030?mo0?oooooooooo00Kooooo00<0X23`ooooooooool05_ooool0
0ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2Dooooo`030:0Pl?ooool0X23`
00Cooooo00L0X23`oooooooooooooooo0:0Pl?ooooooogl000oooooo00<0X23`00000?ooool04?oo
ool00ol0003oooooooooo`28ooooo`030:0Pl?oooooooooo00Gooooo00@0X23`oooooooooooooooo
102P8?000oooool0ogl0ooooo`02ooooo`030?mo0?oooooooooo01;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0V?ooool00oooO`3oooooooooo`05ooooo`03oomo0?oo
oooooooo00Sooooo00?oogl00?mo0?ooool01?ooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo09Oooooo00D0ogl0ooooo`3oO`3ooooo0?mo000Fooooo`03o`000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo09Oooooo0`2P8?001Oooool0X23`ooooooooooooogl000;ooooo
00`0X23`ooooooooool0ogl0ooooo`3oO`3ooooooomo0?ooool0ogl0ooooo`3oO`05ooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool0TOooool00`2P8?00ogl0ooooo`03ooooo`<0X23`
00D0ogl00:0Pl?oooooooooo0?mo0009ooooo`030?mo0?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0Uoooool0102P8?3oooooooooo`2P8?07ooooo`;o
ogl03Oooool00`3oO`000000ooooo`0@ooooo`03o`000?oooooooooo09Oooooo00D0X23`0?mo002P
8?3ooooo0?mo0006ooooo`030?mo0?oooooooooo00gooooo00?o0000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0V?ooool40:0Pl0;ooooo00<0ogl0ooooooooool01_ooool00`2P8?3o
ogl0ooooo`07ooooo`030:0Pl000003ooooo013ooooo00?o0000ooooooooool0SOooool00`2P8?3o
ooooooooo`07ooooo`030?mo002P8?00X23`0080X23`00<0ogl0ooooo`3oO`004oooool00ol0003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2Aooooo`030:0Pl?oooooooooo00Gooooo
1P2P8?000oooool0X23`0:0Pl003ooooo`03oomo0?oooooooooo00;ooooo00?oogl00:0Pl?ooO`00
0oooool00`2P8?3oogl00000000Aooooo`03o`000?oooooooooo08_ooooo00<0X23`ooooooooool0
2?ooool60:0Pl0;ooooo0P2P8?000oooool0ogl0ooooo`0?ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo09[ooooo0`2P8?000oooool0X23`0:0Pl007ooooo`03oomo0?oo
oooooooo00;ooooo0_ooO`03ooooo`03oomo0000003ooooo013ooooo00?o0000ooooooooool0V_oo
ool30:0Pl003ooooo`2P8?00ogl001;ooooo00?o0000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0VOooool80:0Pl005oomo0?ooool0ogl0ooooooooO`000P3oO`020:0Pl004oomo0?oo
ool0X23`oomo00Cooooo00<00000ooooooooool03oooool00ol0003oooooooooo`2Gooooo`P0X23`
0P3oO`000`2P8?3oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo09[ooooo0P2P8?002?ooool0X23`0:0Pl02P8?3ooooo0?mo0?ooool0ogl00oooO`000`3o
O`00X23`ooooo`07ooooo`030?mo0000003ooooo013ooooo00?o0000ooooooooool0V?ooool0103o
O`00X23`ooooo`3oO`030:0Pl080ogl00_ooool00`2P8?3oooooooooo`0<ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo09[ooooo00<0X23`ooooo`2P8?00102P8?000ooo
ool0X23`0:0Pl002ooooo`H0X23`00L0ogl0ooooooooool0X23`ooooo`2P8?000000017ooooo00?o
0000ooooooooool0T_ooool20:0Pl003ooooo`2P8?3ooooo00T0X23`00@0ogl0ooooo`3oO`00X23`
1?ooool00`2P8?3oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo09oooooo00Koogl00:0Pl?oooooooooo0:0Pl?ooO`030:0Pl006oomo0?ooooooogl0oooo
o`2P8?3oogl00oooool00`2P8?000000ooooo`0@ooooo`03o`000?oooooooooo09Cooooo00<0X23`
ooooooooool00_ooool0202P8?00ogl00:0Pl03oO`3ooooo0:0Pl03oO`00X23`0P3oO`0?ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo09oooooo0`2P8?001?ooool0X23`
ooooooooool2oomo00060:0Pl?ooooooooooooooo`2P8?00ogl00_ooO`000oooooooogl00000000A
ooooo`03o`000?oooooooooo09Cooooo00@0X23`oooooooooooooooo0P2P8?001_ooool0ogl00?mo
003oO`3ooooo0:0Pl080ogl000?ooooo0:0Pl?ooool03Oooool00ol0003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`2Pooooo`80X23`00Wooooo0:0Pl?oooooooooo0:0Pl?ooO`00X23`
ooooo`2P8?000_ooool01P2P8?3ooooo0?mo0?ooool0X23`0000017ooooo00?o0000ooooooooool0
Toooool20:0Pl003ooooo`2P8?00X23`00?ooooo00@0X23`ooooo`2P8?00X23`0_ooool30:0Pl080
ogl000<0X23`0?mo0?ooool00_ooool00`3oO`3oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo0:;ooooo00L0X23`oomo0?ooooooogl00:0Pl?ooool0X23`
00Cooooo00Koogl0ooooooooooooogl0ooooo`00000Aooooo`03o`000?oooooooooo0:3ooooo00H0
X23`0?mo002P8?00ogl0ooooo`2P8?0<ooooo`03o`000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo09oooooo00<0X23`ooooooooool00_ooool00oooO`00X23`ooooo`03ooooo`030:0P
l?oooooooooo00Cooooo00<0X23`00000?ooool04?ooool00ol0003oooooooooo`2Gooooo`030:0P
l?ooool0X23`00Gooooo00D0ogl00:0Pl?oooooooooo0?mo00020:0Pl0cooooo00?o0000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0X?ooool00`2P8?3oooooooooo`03ooooo`040:0P
l?ooooooogl00:0Pl0;ooooo00?oogl0ooooooooool00_ooool00`2P8?000000ooooo`0@ooooo`03
o`000?oooooooooo09_ooooo00@0X23`ooooooooool0X23`0_ooool00`2P8?3oooooooooo`03oooo
o`070?mo002P8?3oooooooooo`2P8?3ooooo0?mo0004ooooo`03o`000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo0:cooooo00Ooogl0ooooo`2P8?3oogl0ooooo`2P8?000000017ooooo
00?o0000ooooooooool0X?ooool01`2P8?3oooooooooooooool0ogl0ooooo`3oO`001?ooool0102P
8?3oooooooooo`3oO`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
0:;ooooo00@0X23`ooooooooool0X23`0_ooool00oooO`00X23`ooooo`03oomo0005ooooo`2P8?00
X23`0:0Pl00000004Oooool00ol0003oooooooooo`2Kooooo`80X23`0oooool00`2P8?3ooooooooo
o`020:0Pl0?ooooo102P8?03ooooo`80ogl000?oooooo`000?ooool02Oooool000Wooooo00<00000
ooooooooool0Z?ooool00`2P8?3ooooo0:0Pl003ooooo`050?mo0?ooO`3ooooo0:0Pl00000004Ooo
ool00ol0003oooooooooo`2Looooo`050:0Pl?ooooooooooooooo`2P8?001oooool01@2P8?3ooooo
ooooooooool0X23`00Cooooo00<0ogl0o`000?ooool02Oooool000Wooooo00<00000ooooooooool0
X_ooool00`2P8?3oooooooooo`07ooooo`03oomo0?oooooooooo0080ogl000<0X23`00000?ooool0
4?ooool00ol0003oooooooooo`2Rooooo`030:0Pl?oooooooooo00Cooooo102P8?000`3oO`3ooooo
ooooo`020?mo0003o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0:Sooooo00<0
X23`ooooo`2P8?000_ooool01_ooO`3oooooooooooooool0X23`0000017ooooo00?o0000oooooooo
ool0Y_ooool20:0Pl0;ooooo102P8?04ooooo`03o`000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0:Cooooo00<0X23`ooooooooool00_ooool20:0Pl0?ooooo0`3oO`000`2P8?000000
ooooo`0@ooooo`03o`000?oooooooooo0:;ooooo00@0X23`ooooooooool0X23`0_ooool20:0Pl0;o
oooo00L0X23`0?mo0?oooooooooo0?mo002P8?3o000000[ooooo0009ooooo`0300000?oooooooooo
0:Sooooo00H0X23`ooooo`2P8?00X23`ooooo`3oO`02ooooo`;oogl000<00000ooooooooool03ooo
ool00ol0003oooooooooo`2Tooooo`060:0Pl?ooooooooooooooo`2P8?3ooooo0`3oO`000oooool0
ogl00:0Pl002ooooo`03o`000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0:Sooooo00<0X23`ooooo`2P8?001oooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo0:Kooooo00D0X23`oooooooooooooooo0:0Pl007ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0:cooooo00<0X23`ooooooooool00ooo
ool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo0:Wooooo00<0X23`ooooooooool01_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`08ooooo`002Ooooonf0000017ooooo]_l0000:ooooo`00]_ooool00`2P8?3ooooo
ooooo`37ooooo`030:0Pl?oooooooooo00gooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0022ooooo`;o0000ooooool=
ooooo`00Ooooool3o`000003ooooool0003ooooo0?oooooo3?ooool007gooooo0_l00004ooooo`;o
0000ooooool<ooooo`00Noooool2o`0000Kooooo00?o0000ooooool00000ooooool;ooooo`00N?oo
ool3o`0000Sooooo00?o0000ooooool00000ooooool;ooooo`00M_ooool2o`0000_ooooo00Co0000
oooooooooooo0000ooooool:ooooo`00Loooool3o`0000gooooo00Co0000oooooooooooo0000oooo
ool:ooooo`00LOooool2o`00013ooooo00Go0000ooooooooooooooooo`00003oooooo`Wooooo001_
ooooo`;o00004_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Gooooo]_l0000:
ooooo`00K?ooool3o`0001Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool006[ooooo0_l0000Hooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00Sooooo001Wooooo`?o00006_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00IOoo
ool2o`0001gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo02;ooooo00@0ogl0ooooooooool0X23`:oooool00`2P8?3oooooooooo`1Nooooo`03o`00
0?oooooooooo00Sooooo001Rooooo`?o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo04;ooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00H?ooool2
o`0002;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooo
oooo02Oooooo00<0X23`ooooooooool03Oooool00`2P8?3oooooooooo`1hooooo`03o`000?oooooo
oooo00Sooooo001Nooooo`;o00009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`00Foooool3o`0002Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Ko
oooo00<0X23`ooooooooool0@_ooool00`2P8?3oooooooooo`1Tooooo`03o`000?oooooooooo00So
oooo001Iooooo`;o0000:Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool02_ooool00`2P8?3oooooooooo`0Gooooo`030:0Pl?oooooooooo08_ooooo
00?o0000ooooooooool02?ooool005Kooooo0ol0000[ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`06ooooo`80X23`6oooool00`2P8?3ooooooooo
o`0Mooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooool0IOooool00ol0003ooooooooo
o`08ooooo`00E?ooool2o`0002kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo017ooooo00<0ogl0ooooooooool07_ooool00`2P8?3oooooooooo`1m
ooooo`03o`000?oooooooooo00Sooooo001Booooo`;o0000<?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool01@2P8?3oooooooooooooool0
ogl001Sooooo00<0X23`ooooooooool02Oooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooo
oooo01Kooooo00<0X23`ooooooooool0G?ooool00ol0003oooooooooo`08ooooo`00Coooool3o`00
03;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
00[ooooo00<0X23`ooooo`3oO`001?ooool00`2P8?3oooooooooo`07ooooo`030:0Pl?oooooooooo
00Wooooo00<0ogl0ooooooooool03_ooool0102P8?3oooooooooooooool20:0Pl0;ooooo00<0X23`
ooooo`2P8?00Koooool00ol0003oooooooooo`08ooooo`00COooool2o`0003Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00cooooo00<0X23`oooo
ooooool01_ooool00`3oO`3oooooooooo`2Jooooo`03o`000?oooooooooo00Sooooo001:ooooo`?o
0000=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool03?ooool00`2P8?3oooooooooo`07ooooo`040:0Pl?oooooooooo0:0Pl1;ooooo00@0ogl0oooo
ooooool0X23`1oooool0102P8?3oooooooooo`2P8?0Mooooo`030:0Pl?oooooooooo05Oooooo00?o
0000ooooooooool02?ooool004Sooooo0_l0000jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0:ooooo`050:0Pl?ooooooooooooooo`2P8?002_oo
ool00`3oO`3oooooooooo`05ooooo`030:0Pl?oooooooooo01gooooo00<0X23`ooooooooool00_oo
ool00`2P8?3oooooooooo`0Aooooo`030:0Pl?oooooooooo05Gooooo00?o0000ooooooooool02?oo
ool004Kooooo0_l0000looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0=ooooo`030:0Pl?oooooooooo00Gooooo00<0ogl0ooooo`2P8?002_ooool0
0`2P8?3oooooooooo`03ooooo`050:0Pl?ooooooooooooooo`2P8?000oooool00`3oO`3ooooooooo
o`0Oooooo`030:0Pl?oooooooooo05gooooo00?o0000ooooooooool02?ooool004?ooooo0ol0000n
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0=
ooooo`80X23`0_ooool0202P8?3ooooo0:0Pl?ooool0ogl00:0Pl?ooool0X23`2oooool01@3oO`3o
ooooooooooooool0X23`00;ooooo00<0X23`ooooooooool00_ooool00`2P8?3oooooooooo`04oooo
o`040:0Pl?oooooooooo0?mo00oooooo00D0X23`oooooooooooooooo0:0Pl01Sooooo`03o`000?oo
oooooooo00Sooooo0011ooooo`;o0000@_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03_ooool20:0Pl005ooooo`2P8?00X23`0?mo002P8?000_oo
ool00`2P8?00ogl0ooooo`0<ooooo`030:0Pl?oooooooooo08Wooooo00?o0000ooooooooool02?oo
ool003kooooo0ol00014ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0Aooooo`030:0Pl?ooool0X23`00;ooooo0P2P8?03ooooo`050:0Pl?oooooo
ooooooooo`2P8?006Oooool00`2P8?3oooooooooo`1fooooo`03o`000?oooooooooo00Sooooo000l
ooooo`;o0000Aoooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool03oooool00`2P8?3ooooo0:0Pl0020:0Pl005ooooo`2P8?00X23`0?mo002P8?000ooo
ool20:0Pl003ooooo`3oO`3ooooo00;ooooo00<0X23`0?mo0?ooool00P3oO`0Oooooo`030?mo0?oo
oooooooo00_ooooo00<0X23`ooooooooool0F_ooool00ol0003oooooooooo`08ooooo`00>_ooool2
o`0000cooooo00<0X23`ooooooooool0>_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool04_ooool20:0Pl0;ooooo0`2P8?001`3oO`3ooooooooooooo
ool0X23`ooooo`3oO`001?ooool00`2P8?3ooooo0:0Pl003ooooo`030:0Pl?oooooooooo00;ooooo
00D0X23`oooooooooooooooo0?mo000Nooooo`030:0Pl?oooooooooo05gooooo00?o0000oooooooo
ool02?ooool003Oooooo0ol0001;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Aooooo`030:0Pl?ooool0X23`00T0X23`0oooool00`3oO`00X23`
0?mo0003ooooo`050:0Pl?ooooooooooooooo`3oO`000oooool00`2P8?3oooooooooo`0?ooooo`03
0?mo0?oooooooooo00oooooo00<0X23`ooooooooool0GOooool00ol0003oooooooooo`08ooooo`00
=Oooool2o`0004kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo01?ooooo00<0X23`ooooo`2P8?00102P8?02ooooo`040?mo002P8?00X23`0:0Pl0So
oooo00<0ogl0ooooooooool04Oooool00`2P8?3oooooooooo`0Booooo`030:0Pl?ooool0ogl000Oo
oooo00<0X23`ooooooooool03Oooool00`2P8?3oooooooooo`14ooooo`03o`000?oooooooooo00So
oooo000booooo`?o0000D?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool05?ooool0102P8?3ooooo0:0Pl?ooool20:0Pl003ooooo`3oO`00X23`0080
ogl000<0X23`ooooo`3oO`008?ooool00`2P8?3oooooooooo`1]ooooo`03o`000?oooooooooo00So
oooo000`ooooo`;o00006_ooool00`2P8?3oooooooooo`0fooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Eooooo`/0X23`0oooool0102P8?3ooooo
ooooo`2P8?0Pooooo`030?mo0?oooooooooo06Sooooo00?o0000ooooooooool02?ooool002gooooo
0ol0000Fooooo`030:0Pl?oooooooooo03cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo01Kooooo00@0ogl0ooooo`2P8?3ooooo0P2P8?00203oO`00
X23`ooooo`2P8?3ooooo0?mo002P8?00ogl03_ooool00`2P8?3oooooooooo`05ooooo`030:0Pl?oo
oooooooo00kooooo00<0X23`ooooooooool0I?ooool00ol0003oooooooooo`08ooooo`00:oooool2
o`0005Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo01Sooooo202P8?001oooool0X23`0?mo0?ooool0X23`ooooo`2P8?001oooool00`3oO`3ooooo
ooooo`07ooooo`030:0Pl?oooooooooo01Wooooo00<0X23`ooooooooool01Oooool00`3oO`3ooooo
ooooo`08ooooo`030?mo0?oooooooooo04Sooooo00?o0000ooooooooool02?ooool002Wooooo0_l0
000?ooooo`030:0Pl?oooooooooo01?ooooo0P2P8?0cooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Jooooo`@0X23`00?ooooo0:0Pl02P8?00102P
8?02ooooo`80X23`0oooool00`2P8?3ooooo0:0Pl004ooooo`030:0Pl?ooool0X23`01cooooo00<0
ogl0ooooooooool04oooool00`3oO`3oooooooooo`17ooooo`03o`000?oooooooooo00Sooooo000V
ooooo`?o0000G?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool06?ooool0102P8?3ooooo0:0Pl?ooool30:0Pl080ogl000Cooooo0:0Pl02P8?00ogl0
1_ooool00`3oO`3oooooooooo`030:0Pl0;ooooo00<0X23`ooooo`2P8?000_ooool01P2P8?3ooooo
ooooo`3oO`3ooooo0:0Pl0[ooooo00<0ogl0ooooooooool00oooool0103oO`3oooooooooooooool2
0?mo00Kooooo00H0X23`0?mo0?oooooooooo0?mo0?ooool20?mo0004ooooo`3oO`3ooooo0:0Pl0;o
oooo00<0ogl0ooooooooool01Oooool00`3oO`3oooooooooo`0oooooo`03o`000?oooooooooo00So
oooo000Tooooo`;o00002_ooool00`2P8?3ooooo0:0Pl006ooooo`030:0Pl?oooooooooo00Kooooo
00<0X23`ooooooooool01?ooool00`2P8?3oooooooooo`0iooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Mooooo`030:0Pl?ooool0X23`00;ooooo
0P2P8?000oooool0ogl0ooooo`07ooooo`040?mo0?oooooooooo0?mo00?ooooo00<0X23`ooooo`2P
8?007?ooool00`3oO`3oooooooooo`05ooooo`040?mo0?oooooooooo0?mo05;ooooo00?o0000oooo
ooooool02?ooool0027ooooo0ol0000Rooooo`030:0Pl?oooooooooo00Wooooo00<0ogl0oooooooo
ool0<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool06?ooool0102P8?3oooooooooooooool20:0Pl007ooooo`2P8?3oooooooooo`2P8?3ooooo0:0P
l00@ooooo`030:0Pl?oooooooooo00;ooooo00<0ogl0ooooooooool01Oooool00`3oO`3ooooooooo
o`0Gooooo`030?mo0?oooooooooo01;ooooo00<0ogl0ooooooooool01Oooool00`3oO`3ooooooooo
o`0fooooo`03o`000?oooooooooo00Sooooo000Oooooo`;o00006_ooool00`2P8?3oooooooooo`02
0:0Pl0gooooo00<0X23`ooooo`2P8?003_ooool00`2P8?3oooooooooo`0Tooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Mooooo`040:0Pl03oO`00
X23`0:0Pl0;ooooo00<0X23`0?mo0?ooool01_ooool0102P8?3oooooooooo`2P8?03ooooo`030:0P
l?oooooooooo00Wooooo00<0X23`ooooo`3oO`001?ooool20:0Pl0;ooooo00<0ogl0ooooooooool0
0_ooool20?mo00?ooooo0`3oO`03ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooo`3oO`00
3Oooool0103oO`3ooooo0?mo003oO`0oooooo`03o`000?oooooooooo00Sooooo000Mooooo`;o0000
3_ooool01@3oO`3oooooooooooooool0X23`01[ooooo00@0ogl0ooooooooool0X23`2Oooool00`3o
O`3oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Oooooo`040:0Pl?oooooooooo0?mo00?ooooo00<0ogl0ooooooooool04_ooool0
0`3oO`3ooooo0:0Pl00<ooooo`030?mo0?oooooooooo00_ooooo00<0ogl0ooooooooool01_ooool2
0?mo00;ooooo00<0ogl0ooooo`3oO`002_ooool0103oO`3oooooooooo`3oO`02ooooo`80ogl0>?oo
ool00ol0003oooooooooo`08ooooo`006_ooool3o`0002Cooooo00<0X23`ooooo`2P8?001oooool0
0`2P8?3oooooooooo`0<ooooo`030?mo0?oooooooooo00Gooooo00<0ogl0ooooooooool08?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06Oooool0
0`2P8?3oooooooooo`03ooooo`80X23`00?ooooo0:0Pl?ooool00P3oO`001Oooool0X23`0?mo003o
O`00X23`00Kooooo00<0ogl0ooooooooool02?ooool0102P8?3oooooooooo`3oO`04ooooo`030:0P
l?oooooooooo00;ooooo00<0ogl0ooooo`2P8?001Oooool01`2P8?3oooooooooooooool0ogl0oooo
o`3oO`001Oooool00`3oO`3ooooo0?mo000?ooooo`040?mo0?ooool0ogl00?mo00;ooooo00<0ogl0
ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`006Oooool00ol0003oooooooooo`0Hoooo
o`030:0Pl?oooooooooo00Kooooo00<0X23`ooooo`2P8?003?ooool01@3oO`3oooooooooooooool0
X23`017ooooo0P3oO`0Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0Rooooo`030:0Pl?ooool0X23`00;ooooo0`2P8?06ooooo`030?mo0?ooool0
X23`00Wooooo00<0X23`ooooo`3oO`003?ooool0102P8?3oooooooooo`3oO`06ooooo`80ogl00ooo
ool01@2P8?3oooooooooooooool0ogl000;ooooo00<0ogl0ooooooooool04Oooool30?mo03[ooooo
00?o0000ooooooooool02?ooool001Wooooo00?o0000ooooooooool05?ooool0102P8?3ooooooooo
o`3oO`04ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooo`2P8?002?ooool20?mo00Kooooo
00<0ogl0ooooooooool00_ooool00`3oO`3oooooooooo`0<ooooo`030?mo0?ooool0ogl001oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02;ooooo
00@0X23`ooooo`3oO`00ogl00_ooool20:0Pl0Kooooo00<0X23`ooooooooool02_ooool00`2P8?3o
oooo0:0Pl002ooooo`030?mo0?oooooooooo00Kooooo00<0ogl0ooooooooool04Oooool00`2P8?3o
ooooooooo`08ooooo`030:0Pl?oooooooooo04Gooooo00?o0000ooooooooool02?ooool001Wooooo
0_l0000Aooooo`030?mo0?oooooooooo01Cooooo00<0X23`ooooooooool01_ooool00`2P8?3ooooo
ooooo`07ooooo`030?mo0?oooooooooo00Cooooo0P3oO`04ooooo`80ogl06_ooool20:0Pl0Gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02;ooooo
00<0X23`ooooo`2P8?00103oO`020:0Pl0;ooooo00<0X23`ooooooooool00_ooool0102P8?3ooooo
ooooo`2P8?09ooooo`030?mo0?ooool0ogl000Cooooo00@0X23`ooooooooool0ogl00_ooool00`2P
8?3oooooooooo`0:ooooo`80X23`1_ooool00`2P8?3oooooooooo`02ooooo`050?mo0?ooool0ogl0
ooooo`2P8?000_ooool00`3oO`3oooooooooo`05ooooo`030?mo0?ooool0ogl000;ooooo0P3oO`0f
ooooo`03o`000?oooooooooo00Sooooo000Iooooo`03o`000?oooooo000000Kooooo00<0X23`oooo
ooooool02Oooool03`3oO`3oooooooooooooool0ogl0ooooo`2P8?3ooooo0:0Pl03oO`00X23`oooo
o`3oO`3ooooo0?mo0008ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool00oooool0
0`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00_ooooo00<0ogl0ooooo`3oO`001?ooool0
103oO`3oooooooooo`2P8?0Booooo`030:0Pl?oooooooooo00?ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02;ooooo00@0X23`ooooo`2P8?3ooooo
0P2P8?001Oooool0X23`ooooooooool0X23`01kooooo00<0ogl0ooooo`3oO`003oooool00`3oO`3o
oooo0?mo000;ooooo`040?mo0?oooooooooo0?mo04?ooooo00?o0000ooooooooool02?ooool001So
oooo00Go0000ooooooooooooooooo`00000@ooooo`030:0Pl?oooooooooo00Wooooo00<0ogl00:0P
l?ooool00_ooool00`2P8?3oooooooooo`09ooooo`030?mo0?oooooooooo00kooooo00<0ogl0oooo
ooooool01_ooool20?mo00Gooooo00@0ogl0ooooooooool0ogl04Oooool30:0Pl0?ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02?ooooo0`2P8?00
0oooool0X23`0:0Pl0020:0Pl003ooooo`2P8?00X23`00Kooooo00<0X23`0?mo0?ooool00oooool0
0`3oO`3oooooooooo`02ooooo`030:0Pl?oooooooooo00kooooo00@0ogl0ooooo`3oO`00X23`1Ooo
ool01`3oO`3ooooo0:0Pl?ooool0ogl0ooooo`3oO`000oooool00`3oO`3oooooooooo`03ooooo`80
ogl00_ooool00`3oO`3ooooo0?mo0002ooooo`030:0Pl?oooooooooo00;ooooo0P3oO`000oooool0
X23`ooooo`05ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool0:Oooool00ol0003o
ooooooooo`08ooooo`006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo
00L0X23`oooooooooooooooo0:0Pl?ooool0ogl000Cooooo00<0ogl0ooooooooool02oooool00`3o
O`3oooooooooo`03ooooo`030:0Pl?oooooooooo00?ooooo00<0X23`ooooooooool00oooool20?mo
00?ooooo00<0X23`0?mo0?ooool00_ooool00`2P8?00ogl0ooooo`03ooooo`030:0Pl03oO`3ooooo
00Kooooo00<0ogl0ooooooooool03oooool20:0Pl003ooooool0003ooooo01Wooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0Wooooo`030:0Pl?ooool0X23`00;ooooo00<0X23`oooo
ooooool02Oooool00`2P8?3oooooooooo`03ooooo`030:0Pl?oooooooooo00Sooooo00<0ogl0oooo
ooooool0:oooool00`3oO`3oooooooooo`06ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0oooo
ooooool0:_ooool00ol0003oooooooooo`08ooooo`006?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooool0X23`ooooo`2P8?000oooool00`2P8?00ogl0ooooo`09ooooo`040:0Pl?oooooooooo
0?mo0080X23`0oooool01@2P8?00ogl0ooooooooool0ogl000Oooooo00D0X23`ooooo`3oO`3ooooo
0?mo0003ooooo`030:0Pl?ooool0ogl000?ooooo0P3oO`03ooooo`80ogl00_ooool00`3oO`00X23`
ooooo`03ooooo`@0ogl00_ooool20?mo01;ooooo00<0X23`ooooo`2P8?001?ooool00`2P8?3o0000
ooooo`0Iooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool09?ooool20:0Pl0Gooooo
00@0X23`0?mo003oO`00X23`4?ooool0103oO`3ooooo0:0Pl02P8?0=ooooo`030:0Pl?oooooooooo
00Cooooo00<0ogl0ooooooooool02?ooool00`3oO`3oooooooooo`07ooooo`030?mo0?oooooooooo
00Sooooo0P3oO`0iooooo`03o`000?oooooooooo00Sooooo000Hooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00`3oO`3ooooo0?mo0006ooooo`030?mo0?oooooooooo00?o
oooo00@0ogl00:0Pl?ooool0ogl02?ooool00`2P8?3oooooooooo`0?ooooo`80ogl00_ooool01P2P
8?00ogl00?mo003oO`3ooooo0?mo00?ooooo00<0ogl0ooooooooool00oooool00`3oO`3ooooo0?mo
00030?mo00Sooooo00<0X23`ooooooooool03Oooool30:0Pl003o`00002P8?3ooooo01Wooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0Tooooo`80X23`00?ooooo0:0Pl02P8?000`2P
8?000oooool0X23`0:0Pl0020:0Pl004ooooo`3oO`3ooooo0:0Pl0Gooooo00@0ogl0ooooo`2P8?00
X23`1_ooool00`2P8?3ooooo0:0Pl002ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`oooooooo
ool01?ooool00`3oO`3oooooooooo`03ooooo`030?mo0?ooool0X23`00;ooooo00<0X23`0?mo0?oo
ool00_ooool20?mo0008ooooo`3oO`00X23`ooooo`2P8?00ogl0ooooo`3oO`02ooooo`030?mo0?oo
ool0ogl000Kooooo00<0ogl0ooooooooool00_ooool00`3oO`3oooooooooo`04ooooo`030?mo0?oo
oooooooo02Oooooo00?o0000ooooooooool02?ooool001Sooooo00?o0000ooooooooool01Oooool0
1Ol0003oooooooooooooool0X23`00Gooooo00<0ogl0ooooo`2P8?001Oooool01`3oO`3ooooooooo
ooooool0X23`ooooo`2P8?002_ooool00`2P8?3oooooooooo`09ooooo`030?mo0?oooooooooo00?o
oooo0`3oO`02ooooo`050?mo0?ooooooooooooooo`3oO`001_ooool01@3oO`3oooooooooooooool0
ogl000[ooooo00<0ogl0ooooooooool03?ooool20:0Pl003ooooool0003ooooo01_ooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`0Xooooo`030:0Pl?ooool0X23`0080X23`00@0ogl0
0:0Pl?ooool0X23`0_ooool00`2P8?3oooooooooo`07ooooo`030?mo0?oooooooooo00Oooooo00<0
ogl0ooooooooool02_ooool00`2P8?3oooooooooo`08ooooo`030?mo0?ooool0X23`00_ooooo00<0
X23`ooooooooool0@_ooool00ol0003oooooooooo`08ooooo`006?ooool00ol0003oooooooooo`05
ooooo`050:0Pl?l0003oooooooooo`2P8?000oooool00`2P8?00ogl0ooooo`09ooooo`030?mo0?oo
ool0ogl000;ooooo00D0ogl0oooooooooooooooo0:0Pl007ooooo`050:0Pl?ooooooooooooooo`3o
O`001_ooool00`3oO`3oooooooooo`03ooooo`030?mo0?oooooooooo00?ooooo00<0ogl0oooooooo
ool02oooool00`3oO`3ooooo0?mo0002ooooo`040:0Pl03oO`3ooooo0?mo00Wooooo0P2P8?001?oo
ool0X23`ooooo`2P8?02ooooo`80X23`00Co0000ooooooooool0X23`6Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo02Cooooo00<0X23`ooooooooool00oooool00`3oO`3ooooo0:0P
l0040:0Pl003ooooo`2P8?3ooooo00Sooooo00<0X23`0?mo003oO`001?ooool00`2P8?3ooooooooo
o`08ooooo`80X23`0_ooool01@3oO`3ooooo0:0Pl?ooool0ogl000Gooooo00<0X23`ooooo`2P8?00
1Oooool00`3oO`3oooooooooo`03ooooo`050?mo002P8?3ooooo0:0Pl?ooool00P3oO`03ooooo`80
ogl000?ooooo0?mo0?ooool01_ooool0103oO`3ooooo0?mo002P8?020?mo00Cooooo0P3oO`09oooo
o`040:0Pl?oooooooooo0:0Pl1[ooooo00?o0000ooooooooool02?ooool001Oooooo00?o0000oooo
ooooool02?ooool01Ol0003oooooooooo`2P8?3ooooo0080X23`00Cooooo0:0Pl03oO`00X23`1?oo
ool0102P8?3ooooo0?mo0?ooool20:0Pl0Kooooo00<0ogl00:0Pl?ooool00_ooool20:0Pl0;ooooo
00<0X23`ooooooooool00oooool00`2P8?00ogl0ooooo`02ooooo`80ogl00oooool00`3oO`3ooooo
ooooo`020?mo0003ooooo`3oO`3ooooo00Sooooo00<0ogl0ooooooooool00P3oO`08ooooo`80ogl0
00@0X23`0?mo0?ooool0X23`1Oooool0102P8?3oooooooooo`2P8?03ooooo`030:0Pl?l00000X23`
01cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0/ooooo`060:0Pl?ooool0ogl0
ooooo`3oO`00X23`0oooool00`2P8?3oooooooooo`04ooooo`030?mo0?oooooooooo00Gooooo00<0
ogl0ooooooooool02Oooool0102P8?3ooooo0:0Pl03oO`03ooooo`030?mo0?ooool0ogl000;ooooo
00<0ogl0ooooooooool01_ooool01`3oO`3oooooooooooooool0ogl0ooooo`3oO`001_ooool0103o
O`3oooooooooo`3oO`02ooooo`030?mo0?ooool0X23`00?ooooo00<0ogl0ooooooooool00oooool0
0`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo00Wooooo00<0X23`ooooooooool06?ooool0
0ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`09ooooo`07o`000?ooool0X23`
ooooo`2P8?3ooooo0:0Pl0020?mo0080X23`0P3oO`03ooooo`0:0?mo0?oooooooooo0:0Pl?ooool0
ogl0ooooo`2P8?3ooooo0?mo00Cooooo00<0X23`ooooooooool02oooool00`2P8?3oooooooooo`06
ooooo`060?mo0?oooooooooo0?mo0?ooool0ogl00_ooool20?mo00050:0Pl?oooooooooo0?mo002P
8?001_ooool00`3oO`3oooooooooo`0=ooooo`030?mo0?oooooooooo0080ogl00_ooool0102P8?3o
ooooo`00002P8?0Looooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00`2P
8?3ooooo0:0Pl002ooooo`040:0Pl?oooooooooo0?mo00Cooooo00@0ogl0ooooooooool0ogl02?oo
ool20?mo0003ooooo`2P8?3ooooo00Oooooo00D0X23`0?mo0?oooooooooo0:0Pl009ooooo`040?mo
0?oooooooooo0:0Pl0;ooooo00<0ogl0ooooooooool01_ooool00`3oO`3oooooooooo`02ooooo`03
0:0Pl?oooooooooo00?ooooo00H0ogl0ooooooooool0ogl0ooooo`2P8?04ooooo`040?mo0?ooool0
ogl00?mo00?ooooo00@0ogl0ooooooooool0ogl02Oooool00`3oO`3ooooo0?mo0002ooooo`030:0P
l?oooooooooo01Kooooo00?o0000ooooooooool02?ooool001Oooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooooooool20:0Pl0050?mo002P8?00X23`0?mo0?ooool00`3oO`00102P8?3o
ooooooooo`3oO`02ooooo`030?mo0?oooooooooo00;ooooo00@0ogl0oooooooooooooooo0`2P8?00
1@3oO`3oooooooooooooool0X23`00?ooooo00P0X23`ooooo`3oO`00ogl0ooooo`3oO`00X23`0?mo
00Cooooo00<0X23`ooooo`3oO`001?ooool01`3oO`3oooooooooooooool0ogl0ooooo`3oO`000ooo
ool00`3oO`3oooooooooo`02ooooo`030:0Pl?oooooooooo00<0ogl00oooool20?mo00Gooooo1@3o
O`03ooooo`04o`000?ooool0X23`0:0Pl0;ooooo0P2P8?0Gooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0;?ooool0102P8?00ogl00:0Pl02P8?03ooooo`030?mo0?ooool0X23`00Go
oooo00D0ogl0oooooooooooooooo0?mo000;ooooo`030?mo0?ooool0X23`00Kooooo00@0ogl0oooo
ooooool0X23`3Oooool00`3oO`3oooooooooo`03ooooo`030?mo0?oooooooooo00Cooooo00<0ogl0
ooooooooool01Oooool20?mo0003ooooo`3oO`3ooooo00Cooooo00L0X23`oooooooooooooooo0?mo
0?ooool0ogl000;ooooo00D0ogl0ooooo`2P8?00ogl0ooooo`020?mo0005ooooo`3oO`3ooooo0:0P
l03oO`006_ooool00ol0003oooooooooo`08ooooo`005oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo102P8?000`3oO`00X23`ooooo`02ooooo`030?mo002P8?00X23`00Wo
oooo00<0X23`ooooo`3oO`000_ooool20?mo00Gooooo00@0ogl0ooooooooool0ogl02oooool00`2P
8?00ogl0ooooo`05ooooo`080:0Pl?ooool0ogl00:0Pl03oO`3ooooo0?mo0?ooool30?mo00Cooooo
00D0ogl00:0Pl?oooooooooo0?mo0002ooooo`80ogl00oooool30?mo00;ooooo0P3oO`001?ooool0
X23`o`00002P8?02ooooo`80X23`6_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
033ooooo00<0X23`0?mo0?ooool03_ooool00`2P8?3oooooooooo`02ooooo`030?mo0?oooooooooo
00Wooooo00<0ogl0ooooooooool01oooool00`2P8?3oooooooooo`0:ooooo`030?mo0?oooooooooo
00[ooooo00L0ogl0oooooooooooooooo0?mo0?ooool0ogl000?ooooo00<0ogl00:0Pl?ooool00ooo
ool01@2P8?3ooooo0:0Pl?ooool0ogl000Oooooo0P3oO`0Nooooo`03o`000?oooooooooo00Sooooo
000Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00`2P8?00ogl00:0P
l0040?mo00030:0Pl03oO`00ogl00080X23`00?ooooo0:0Pl?ooool01_ooool00`2P8?3ooooooooo
o`0<ooooo`80ogl00_ooool00`3oO`3oooooooooo`05ooooo`80X23`1oooool0102P8?3ooooo0?mo
0?ooool30?mo00Oooooo0`3oO`000oooool0ogl00?mo0004ooooo`80ogl000?ooooo0?mo003oO`00
0P3oO`000`2P8?3oooooo`000002ooooo`060:0Pl?ooooooooooooooo`2P8?3ooooo0P2P8?0Eoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0<?ooool01P3oO`00X23`ooooo`3oO`3o
oooo0:0Pl0;ooooo00<0ogl0ooooooooool03_ooool01@3oO`3oooooooooooooool0ogl000?ooooo
00<0ogl0ooooooooool02Oooool00`3oO`3ooooo0:0Pl004ooooo`<0ogl01?ooool00`3oO`3ooooo
ooooo`02ooooo`050:0Pl?ooool0ogl0ooooo`3oO`001oooool00`3oO`3ooooo0:0Pl003ooooo`04
0?mo0?ooooooooooooooo`80ogl00oooool01@3oO`3oooooooooooooool0X23`0080ogl000@0X23`
ooooo`3oO`3ooooo0P3oO`001Oooool0X23`0:0Pl?ooool0X23`01Gooooo00?o0000ooooooooool0
2?ooool001Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`030:0Pl004ooooo`2P
8?00X23`0?mo00@0X23`0_ooool0102P8?3oooooooooooooool20:0Pl0?ooooo0P2P8?05ooooo`03
0:0Pl?oooooooooo0080X23`00?ooooo0?mo0?ooool01?ooool01@3oO`3oooooooooooooool0ogl0
00Gooooo00@0ogl0ooooooooool0X23`1Oooool00`3oO`3ooooo0?mo0003ooooo`030?mo0?ooool0
ogl000@0ogl00_ooool0102P8?3ooooo0:0Pl?ooool:0?mo0006ooooo`2P8?3oooooo`000?ooool0
X23`0_ooool00`2P8?3oooooooooo`0Iooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0;?ooool00`2P8?3ooooo0:0Pl002ooooo`030:0Pl?ooool0X23`00oooooo00<0ogl0oooooooo
ool05?ooool00`3oO`3oooooooooo`04ooooo`030:0Pl?ooool0ogl000Gooooo00D0X23`oooooooo
oooooooo0:0Pl007ooooo`050?mo0?ooool0X23`ooooo`3oO`000_ooool0103oO`3oooooooooo`3o
O`03ooooo`030?mo0?oooooooooo00Kooooo0P3oO`000oooool0ogl0ooooo`020?mo00?ooooo00P0
X23`0?mo0?ooool0X23`ooooo`2P8?3ooooo0:0Pl1Cooooo00?o0000ooooooooool02?ooool001Oo
oooo00?o0000ooooooooool03_ooool01Ol0003oooooooooo`2P8?3ooooo00D0X23`0`3oO`001Ooo
ool0ogl00:0Pl02P8?00ogl000;ooooo00<0ogl00:0Pl02P8?002Oooool00`3oO`3oooooooooo`05
ooooo`030?mo002P8?3ooooo00;ooooo00<0ogl0ooooooooool01Oooool01@3oO`3ooooo0?mo0?oo
ool0ogl000Sooooo00@0ogl0ooooo`3oO`00ogl01?ooool01@3oO`3ooooo0?mo0?ooool0X23`00<0
ogl00_ooool50?mo00?ooooo00<0X23`ooooool000000oooool20:0Pl0;ooooo0`2P8?000oooool0
X23`ooooo`0Cooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0:?ooool00`2P8?3o
ooooooooo`02ooooo`80X23`1?ooool20:0Pl003ooooo`2P8?3ooooo00;ooooo00D0X23`oooooooo
oooooooo0:0Pl002ooooo`040?mo0?oooooooooo0:0Pl0_ooooo00H0X23`ooooooooool0X23`oooo
o`2P8?03ooooo`030?mo0?oooooooooo00?ooooo00H0ogl0ooooo`3oO`3ooooo0:0Pl?ooool20:0P
l003ooooo`3oO`3ooooo0080X23`00Gooooo0?mo0?oooooooooo0?mo0003ooooo`030?mo0?ooool0
X23`00?ooooo00D0X23`0?mo003oO`3ooooo0?mo0003ooooo`050:0Pl03oO`3oooooooooo`3oO`00
0_ooool00`3oO`3oooooooooo`020?mo0003ooooo`3oO`00ogl00080X23`00@0ogl00:0Pl02P8?00
ogl00_ooool20:0Pl004ooooo`2P8?3ooooo0:0Pl1?ooooo00?o0000ooooooooool02?ooool001Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`080:0Pl0050?mo002P8?00X23`oooo
o`2P8?001_ooool00`3oO`3oooooooooo`04ooooo`050:0Pl03oO`00ogl0ooooo`3oO`000_ooool0
1@2P8?3oooooooooooooool0ogl000?ooooo00<0X23`ooooooooool01?ooool20?mo0080X23`1?oo
ool0103oO`3ooooo0?mo0?ooool20?mo00?ooooo00D0ogl00:0Pl?ooool0ogl0ooooo`020?mo00Co
oooo1@3oO`000oooool0ogl00?mo0002ooooo`070?mo0?ooool0ogl00:0Pl?l00000X23`ooooo`04
0:0Pl0;ooooo0P2P8?000oooool0X23`ooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0<Oooool0102P8?3oooooooooo`2P8?02ooooo`030:0Pl?oooooooooo00Oooooo00@0
ogl0ooooooooool0ogl00oooool00`3oO`3oooooooooo`05ooooo`030:0Pl?oooooooooo013ooooo
0P3oO`000oooool0ogl0ooooo`05ooooo`040?mo0?ooooooooooooooo`80ogl04?ooool0103oO`3o
ooooooooo`2P8?06ooooo`80ogl00_ooool0103oO`3oooooooooo`3oO`06ooooo`030:0Pl?oooooo
oooo01Cooooo00?o0000ooooooooool02?ooool001Kooooo00?o0000ooooooooool03oooool01@2P
8?3oooooo`000?ooool0X23`00?ooooo0P2P8?000`3oO`00X23`0?mo00030:0Pl0050?mo0?oooooo
ooooooooo`3oO`000_ooool0102P8?3oooooooooo`2P8?06ooooo`030?mo0?oooooooooo00Cooooo
00<0ogl0ooooooooool01?ooool00`3oO`00X23`ooooo`03ooooo`030?mo0?oooooooooo00;ooooo
00H0ogl0ooooo`2P8?00X23`0?mo002P8?050?mo0005ooooo`3oO`00ogl00:0Pl03oO`000oooool2
0?mo0004ooooo`2P8?3ooooo0:0Pl0<0ogl000?ooooo0?mo0?ooool01?ooool01@2P8?3o00000:0P
l?ooool0X23`00;ooooo00<0X23`ooooo`2P8?000P2P8?0Hooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0?oooool00`2P8?3oooooooooo`0Qooooo`80ogl03_ooool30?mo00Cooooo
00D0X23`ooooo`3oO`3ooooo0?mo0003ooooo`050:0Pl03oO`3oooooooooo`3oO`001?ooool30?mo
00?ooooo0P3oO`05ooooo`<0X23`5oooool00ol0003oooooooooo`08ooooo`005_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00;ooooo1@2P8?050?mo00Oooooo00<0X23`oooooooo
ool00_ooool0103oO`3ooooo0:0Pl02P8?03ooooo`050:0Pl?ooooooooooooooo`2P8?000P3oO`03
ooooo`090:0Pl?oooooooooo0:0Pl?ooool0ogl0ooooo`3oO`00X23`00;ooooo00D0ogl0oooooooo
oooooooo0?mo0003ooooo`80ogl000Cooooo0?mo002P8?00X23`1_ooool20?mo0080X23`00@0ogl0
oooooooooooooooo0P3oO`02ooooo`030?mo0?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool60:0Pl1Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0dooooo`090:0Pl?oo
ooooooooooooo`2P8?3ooooo0:0Pl?ooool0X23`00Oooooo0P3oO`08ooooo`060:0Pl?oooooooooo
0:0Pl?ooool0X23`0_ooool00`3oO`3oooooooooo`03ooooo`030:0Pl?ooool0X23`00Gooooo00D0
ogl0ooooo`2P8?3ooooo0?mo0004ooooo`030?mo0?oooooooooo00Kooooo00D0X23`oooooooooooo
oooo0?mo0003ooooo`030:0Pl?oooooooooo00?ooooo00L0X23`ooooo`3oO`3ooooo0?mo0?ooool0
X23`00?ooooo00D0ogl00:0Pl03oO`00X23`0?mo00020:0Pl0;ooooo00<0ogl0ooooo`2P8?000_oo
ool20:0Pl003ooooo`2P8?3ooooo017ooooo00?o0000ooooooooool02?ooool001Kooooo00?o0000
ooooooooool03oooool01@2P8?3oooooooooo`2P8?3o000000?ooooo0P2P8?000oooool0X23`0:0P
l0020?mo0006ooooo`3oO`00ogl00?mo0?ooool0X23`2Oooool0102P8?3ooooo0?mo002P8?04oooo
o`030?mo0?oooooooooo00?ooooo00<0X23`ooooooooool00oooool00`2P8?3oooooooooo`02oooo
o`050?mo0?oooooooooo0?mo0?ooool00P3oO`05ooooo`80ogl01?ooool00`3oO`3oooooooooo`02
ooooo`060?mo002P8?3oooooooooo`3oO`3ooooo0P3oO`02ooooo`030?mo0?ooool0ogl000Cooooo
00?o0000ooooooooool01?ooool0102P8?3ooooo0:0Pl02P8?0Hooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0<?ooool00`2P8?3oooooooooo`0Eooooo`030?mo0?oooooooooo013o
oooo00<0ogl0ooooooooool00P2P8?020?mo01?ooooo00<0ogl0ooooo`3oO`001?ooool00`3oO`3o
ooooooooo`02ooooo`040?mo0?oooooooooo0:0Pl0Kooooo00@0X23`ooooo`3oO`00X23`2?ooool0
0`2P8?3oooooooooo`05ooooo`80X23`4Oooool00ol0003oooooooooo`08ooooo`005_ooool00ol0
003oooooooooo`0Dooooo`80X23`1oooool02P2P8?3ooooo0?mo002P8?00ogl0ooooo`3oO`00X23`
ooooo`2P8?02ooooo`030:0Pl?oooooooooo00Gooooo00<0X23`0?mo0?ooool01_ooool40?mo000@
0:0Pl?ooooooooooooooo`3oO`3ooooo0:0Pl?ooool0X23`ooooo`2P8?3ooooo0:0Pl03oO`3ooooo
0:0Pl0;ooooo00<0X23`0?mo0?ooool00_ooool00`2P8?3ooooo0?mo0002ooooo`030?mo0?oooooo
oooo00;ooooo0`3oO`000oooool0X23`ooooo`02ooooo`040?mo0?ooool0X23`0:0Pl0?ooooo00?o
0000ooooo`2P8?000_ooool20:0Pl003ooooo`2P8?00X23`00@0X23`5_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03Kooooo00L0X23`oooooooooooooooo0:0Pl?ooool0X23`00[o
oooo00<0X23`ooooooooool00_ooool01@3oO`3oooooooooooooool0ogl000Wooooo00@0X23`oooo
oooooooooooo0P2P8?0;ooooo`040?mo0?oooooooooo0?mo00Cooooo0P2P8?000oooool0X23`0?mo
0002ooooo`050?mo002P8?3oooooooooo`3oO`000_ooool00`3oO`3oooooooooo`020:0Pl00:0?mo
002P8?00ogl0ooooo`2P8?00ogl0ooooo`2P8?3ooooo0?mo00;ooooo00<0ogl0ooooo`3oO`001Ooo
ool00`2P8?3ooooo0:0Pl003ooooo`030:0Pl?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool001Kooooo00?o0000ooooooooool05?ooool0202P8?3o00000:0Pl02P8?3ooooo0:0Pl?ooool0
X23`0oooool00`2P8?00ogl00?mo00030:0Pl003ooooo`2P8?3ooooo00Wooooo0P3oO`000`2P8?3o
ooooooooo`05ooooo`030:0Pl?oooooooooo00;ooooo0`3oO`02ooooo`030?mo0?ooool0X23`00;o
oooo0P3oO`001@2P8?00ogl00?mo0?ooool0ogl000Kooooo00<0ogl0ooooo`3oO`001_ooool01`3o
O`3oooooooooooooool0ogl0ooooo`3oO`000_ooool00`3oO`3ooooo0:0Pl0020:0Pl003o`000?oo
ool0X23`00@0X23`00?ooooo0:0Pl02P8?00102P8?0Fooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0;_ooool00`2P8?3oooooooooo`04ooooo`030:0Pl?oooooooooo00;ooooo0P2P
8?001@3oO`3oooooooooooooool0X23`00gooooo00<0ogl0ooooooooool01_ooool0103oO`3ooooo
ooooo`3oO`0;ooooo`030?mo0?oooooooooo00;ooooo00H0ogl0ooooooooool0ogl0ooooo`3oO`0A
ooooo`80ogl02Oooool0103oO`3ooooo0?mo003oO`05ooooo`050:0Pl?ooooooooooooooo`2P8?00
5oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Kooooo00T0X23`0?mo002P8?3ooooo0?mo002P8?00ogl0ooooo`2P8?000_ooool00`2P
8?3oooooooooo`03ooooo`040:0Pl03oO`3ooooo0:0Pl0;ooooo00<0X23`ooooo`3oO`000oooool0
0`2P8?3ooooo0:0Pl002ooooo`030:0Pl?oooooooooo00;ooooo103oO`000oooool0ogl00?mo0002
ooooo`80ogl01?ooool01`3oO`3oooooooooo`3oO`3ooooo0?mo0?ooool00P3oO`000oooool0X23`
0?mo0002ooooo`80ogl01Oooool01@2P8?3ooooooooooooooooo000000?ooooo00@0X23`oooooooo
ool0X23`0_ooool60:0Pl1Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0koooo
o`050?mo0?ooool0X23`ooooo`3oO`000P2P8?0Fooooo`030:0Pl?ooool0ogl000Gooooo00L0X23`
oooooooooooooooo0?mo0?ooool0X23`00Wooooo00<0ogl0ooooooooool00_ooool0102P8?3ooooo
ooooo`3oO`02ooooo`030:0Pl?oooooooooo01Cooooo00<0X23`0?mo0?ooool00_ooool0102P8?3o
oooo0:0Pl?ooool20:0Pl1Gooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000oooooooo
ool06?ooool01?l0003oooooooooooooool30:0Pl004ooooo`2P8?3oooooooooo`80ogl0102P8?03
ooooo`070:0Pl?ooooooooooooooo`2P8?3ooooo0:0Pl007ooooo`060?mo0?ooool0ogl00?mo0?oo
ool0X23`0_ooool00`3oO`3oooooooooo`03ooooo`80X23`0`3oO`002Oooool0ogl0ooooooooool0
ogl00:0Pl03oO`3ooooo0:0Pl007ooooo`030?mo0?ooool0ogl000Oooooo00<0X23`ooooooooool0
1Oooool00ol0003oooooooooo`020:0Pl004ooooo`2P8?3oooooooooo`H0X23`5_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo033ooooo00<0X23`ooooooooool01oooool0102P8?3o
oooo0:0Pl02P8?02ooooo`030?mo0?oooooooooo00?ooooo00<0X23`ooooooooool03?ooool00`2P
8?00ogl00:0Pl004ooooo`040:0Pl?oooooooooo0:0Pl0Cooooo00<0X23`ooooo`3oO`002_ooool2
0:0Pl0Kooooo00<0X23`ooooooooool01Oooool00`2P8?3ooooo0?mo0004ooooo`050?mo0?ooool0
ogl0ooooo`2P8?003Oooool00`2P8?3ooooo0:0Pl002ooooo`80X23`0_ooool00`2P8?3ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00oooool20:0Pl0Cooooo00D0ogl0oooooooooooooooo0:0Pl004ooooo`030:0Pl?oo
oooooooo00Gooooo00<0ogl0ooooooooool01?ooool00`2P8?3oooooooooo`02ooooo`030?mo0?oo
oooooooo00Cooooo0P3oO`000`2P8?3oooooooooo`020?mo00;ooooo00@0ogl0ooooooooool0ogl0
0_ooool01@3oO`3oooooooooooooool0X23`00Gooooo00@0ogl0ooooo`2P8?00ogl00_ooool0103o
O`3oooooooooo`3oO`03ooooo`04o`000?ooool0ogl0ooooo`<0X23`00?ooooo0:0Pl?ooool01P2P
8?0Fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0=_ooool01@2P8?3ooooooooo
o`2P8?3ooooo0080X23`0_ooool20:0Pl0kooooo00D0ogl0ooooo`3oO`3ooooo0?mo0002ooooo`03
0?mo0?oooooooooo00Kooooo00D0ogl0ooooo`2P8?3ooooo0?mo0002ooooo`030:0Pl?oooooooooo
00cooooo00<0ogl0ooooooooool01?ooool00`2P8?3oooooooooo`03ooooo`040?mo0?oooooooooo
0:0Pl0;ooooo00<0X23`0?mo0?ooool02oooool00`2P8?3oooooooooo`05ooooo`030:0Pl?oooooo
oooo00;ooooo00<0X23`ooooooooool03?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0
003oooooooooo`0Iooooo`030:0Pl?l0003ooooo00;ooooo00D0X23`ooooo`2P8?3ooooo0:0Pl002
ooooo`80X23`00?ooooo0:0Pl02P8?000`2P8?04ooooo`080?mo0?ooooooooooooooo`2P8?3ooooo
0:0Pl03oO`06ooooo`030?mo0?oooooooooo00Gooooo00D0X23`0?mo0?oooooooooo0?mo0002oooo
o`80X23`0_ooool20:0Pl0Gooooo0`3oO`00102P8?3oooooooooo`3oO`02ooooo`070:0Pl?oooooo
oooo0?mo0?ooool0X23`ooooo`020:0Pl0;ooooo0P2P8?000ol0003ooooo0:0Pl003ooooo`80X23`
00?ooooo0:0Pl02P8?001@2P8?000oooool0X23`ooooo`0Dooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0?Oooool01@2P8?00ogl00?mo0?ooool0X23`00;ooooo00<0X23`oooooooo
ool00oooool00`2P8?00ogl0ooooo`02ooooo`030?mo0?oooooooooo00Kooooo00<0ogl0ooooo`2P
8?000oooool20?mo0008ooooo`3oO`3ooooo0:0Pl?ooool0X23`ooooo`2P8?05ooooo`040?mo0?oo
ool0X23`0:0Pl0Cooooo00<0X23`ooooooooool00_ooool30?mo0003ooooo`2P8?3ooooo00;ooooo
00@0ogl0ooooo`3oO`00ogl00oooool01@3oO`3oooooooooooooool0X23`00Cooooo00<0X23`oooo
ooooool00_ooool00`2P8?3ooooo0:0Pl006ooooo`050:0Pl?oooooooooo0:0Pl?ooool00P2P8?0;
ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
o`2P8?001?ooool0202P8?3oooooooooooooool0ogl00:0Pl?ooool0X23`0P3oO`000`2P8?3ooooo
ooooo`05ooooo`040?mo0?ooool0X23`0?mo00Oooooo0P3oO`02ooooo`070?mo0?oooooooooooooo
o`3oO`3ooooo0:0Pl0030?mo00;ooooo00P0X23`oooooooooooooooo0?mo0?ooool0X23`0?mo00;o
oooo00H0ogl0ooooooooool0ogl0ooooo`2P8?02ooooo`040?mo0?oooooooooo0:0Pl0;ooooo00X0
X23`oooooooooooooooo0:0Pl?ooool0X23`ooooool00000X23`0oooool30:0Pl005ooooo`2P8?00
X23`0:0Pl?ooool01@2P8?0Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Ooo
ool0102P8?3oooooooooo`3oO`05ooooo`040?mo0?oooooooooo0?mo027ooooo00<0X23`ooooo`2P
8?000_ooool00`3oO`3oooooooooo`0Booooo`030?mo0?oooooooooo00cooooo00<0ogl0oooooooo
ool01Oooool01@2P8?3oooooooooooooool0X23`00Gooooo00<0X23`ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Hooooo`80X23`00?ooooo0:0Pl?l0
00002?ooool30:0Pl0050?mo002P8?00X23`0:0Pl03oO`003oooool00`2P8?3oooooooooo`05oooo
o`050?mo0?ooool0ogl0ooooo`2P8?001?ooool0103oO`00X23`ooooooooool30?mo0003ooooo`3o
O`3ooooo00<0ogl000?ooooo0:0Pl03oO`000_ooool30?mo0004ooooo`3oO`3ooooo0?mo00Gooooo
0P3oO`020:0Pl003o`00002P8?00X23`0080X23`00?ooooo0:0Pl02P8?001?ooool20:0Pl004oooo
o`2P8?00X23`0:0Pl1Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0mooooo`04
0:0Pl?ooool0X23`ooooo`80X23`0_ooool0203oO`3oooooooooooooool0X23`ooooo`2P8?00ogl0
0_ooool00`3oO`3oooooooooo`0;ooooo`030?mo0?oooooooooo00;ooooo0P3oO`000oooool0ogl0
ooooo`02ooooo`030:0Pl?oooooooooo00Kooooo00<0X23`ooooo`3oO`001?ooool00`3oO`3ooooo
ooooo`05ooooo`030?mo0?oooooooooo00Sooooo00X0X23`ooooooooool0X23`ooooo`2P8?3ooooo
0?mo0?ooool0X23`0_ooool00`2P8?3oooooooooo`03ooooo`030:0Pl?ooool0X23`00;ooooo102P
8?0;ooooo`03o`000?oooooooooo00Sooooo000Dooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01Oooool00`2P8?3oooooooooo`020:0Pl008ooooo`3oO`3ooooo0:0Pl03oO`00X23`
ooooo`3oO`07ooooo`030:0Pl?oooooooooo00Gooooo00<0ogl0ooooooooool00oooool01@3oO`3o
ooooooooo`3oO`00X23`00;ooooo00@0X23`0?mo0?oooooooooo0P3oO`001Oooool0ogl0oooooooo
ool0ogl000?ooooo00H0ogl0ooooooooool0X23`ooooo`3oO`04ooooo`030?mo0?oooooooooo00Co
oooo00<0X23`ooooool000000oooool00`2P8?3ooooo0:0Pl003ooooo`030:0Pl?ooool0X23`00<0
X23`00?ooooo0:0Pl?ooool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo047o
oooo00@0X23`ooooooooool0X23`5oooool00`2P8?3oooooooooo`04ooooo`030:0Pl?oooooooooo
01oooooo00D0ogl0oooooooooooooooo0?mo000Eooooo`80X23`0_ooool01@2P8?3oooooooooo`2P
8?3ooooo0080X23`2?ooool00ol0003oooooooooo`08ooooo`005?ooool00ol0003oooooooooo`0N
ooooo`030:0Pl?l0003ooooo00?ooooo102P8?001?ooool0ogl0ooooo`3oO`02ooooo`030?mo0?oo
ool0ogl000?ooooo00D0ogl0oooooooooooooooo0:0Pl002ooooo`030?mo0?ooool0ogl000;ooooo
0P3oO`05ooooo`030?mo0?ooool0X23`00;ooooo00@0ogl0ooooooooool0ogl00_ooool01@3oO`3o
ooooooooo`2P8?3ooooo0080X23`00?ooooo0:0Pl?ooool01Oooool01`3oO`3ooooo0:0Pl?ooool0
ogl0ooooo`3oO`000P2P8?02ooooo`060?mo0?ooool0X23`ooooool00000ogl00_ooool0102P8?3o
oooo0:0Pl02P8?02ooooo`050:0Pl?ooool0X23`ooooo`2P8?000_ooool00`2P8?3oooooooooo`0E
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?Oooool00`3oO`3oooooooooo`02
ooooo`030?mo0?oooooooooo00Oooooo00<0X23`ooooooooool01?ooool00`3oO`3oooooooooo`09
ooooo`80X23`00<0ogl0ooooo`3oO`000oooool00`3oO`3oooooooooo`05ooooo`80ogl03?ooool0
103oO`00X23`ooooo`3oO`03ooooo`050:0Pl?ooool0ogl0ooooo`3oO`002Oooool00`2P8?3ooooo
0:0Pl00=ooooo`80X23`00?ooooo0:0Pl?ooool02oooool00ol0003oooooooooo`08ooooo`005?oo
ool00ol0003oooooooooo`0Kooooo`070:0Pl?ooooooooooooooo`2P8?3o00000:0Pl003ooooo`03
0:0Pl?oooooooooo00;ooooo00D0X23`oooooooooooooooo0?mo0009ooooo`030?mo0?oooooooooo
00;ooooo00@0ogl0ooooooooool0X23`0_ooool00`3oO`3oooooooooo`05ooooo`030?mo0?ooool0
ogl000;ooooo00@0X23`ooooooooool0X23`0_ooool20?mo0008ooooo`2P8?00X23`0:0Pl03oO`3o
oooo0:0Pl03oO`04ooooo`050:0Pl?ooool0X23`0?mo002P8?000_ooool00`2P8?3oooooooooo`02
0:0Pl007o`000?ooool0ogl00:0Pl?ooool0X23`ooooo`060:0Pl0;ooooo0P2P8?000oooool0X23`
0:0Pl00Dooooo`?o00007_ooool00ol0003oooooooooo`0iooooo`030?mo0?oooooooooo00?ooooo
00<0X23`ooooooooool00_ooool00`2P8?3ooooo0:0Pl0020?mo00;ooooo00<0ogl0ooooooooool0
2_ooool00`2P8?3oooooooooo`03ooooo`030:0Pl?oooooooooo00Gooooo00<0ogl0ooooooooool0
1?ooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00Cooooo00@0X23`oooooooooooo
oooo0P3oO`000oooool0X23`0:0Pl002ooooo`030:0Pl?ooool0X23`00Wooooo00D0ogl0oooooooo
oooooooo0:0Pl002ooooo`030:0Pl03oO`3ooooo00<0X23`00Gooooo0:0Pl02P8?00X23`ooooo`02
0:0Pl005ooooo`2P8?3oooooooooo`2P8?002Oooool00ol0003oooooooooo`08ooooo`005?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?ooool0X23`0080X23`00?ooooo0:0Pl02P8?000_ooool0
0`3oO`3oooooooooo`02ooooo`030:0Pl?oooooooooo00Sooooo00<0X23`ooooooooool01_ooool2
0?mo00080:0Pl03oO`3oooooooooo`3oO`3ooooo0?mo002P8?02ooooo`030?mo0?oooooooooo0080
ogl00_ooool0103oO`00X23`0?mo003oO`07ooooo`060?mo0?oooooooooo0:0Pl03oO`00X23`0_oo
ool0102P8?3oooooooooo`3oO`02ooooo`03o`00002P8?3ooooo00?ooooo00P0X23`oooooooooooo
oooo0?mo002P8?3ooooo0:0Pl0Kooooo00@0X23`ooooooooool0X23`3Oooool3o`0000;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0oooooo`030?mo0?oooooooooo00Cooooo00<0
ogl0ooooo`2P8?005oooool00`3oO`3oooooooooo`05ooooo`030:0Pl?oooooooooo00cooooo00<0
ogl0ooooooooool05Oooool00`2P8?3oooooooooo`020:0Pl003ooooo`2P8?3ooooo00Sooooo0P2P
8?000oooool0X23`0:0Pl0030:0Pl0_ooooo00?o0000ooooooooool02?ooool001Cooooo00?o0000
ooooooooool08_ooool00ol00000X23`ooooo`03ooooo`80X23`2?ooool00`2P8?3oooooooooo`0<
ooooo`030?mo0?oooooooooo00Gooooo00<0ogl00:0Pl?ooool00P3oO`000oooool0ogl0ooooo`03
ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool00_ooool00`2P8?00ogl0ooooo`02
ooooo`060:0Pl?ooooooooooooooo`2P8?00ogl00P2P8?001P3oO`3oooooooooooooool0X23`o`00
0080X23`00<0ogl0ooooooooool01Oooool00`2P8?3oooooooooo`06ooooo`030:0Pl?oooooooooo
00_ooooo0ol00005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0AOooool20:0P
l0Kooooo00@0ogl0ooooooooool0ogl01?ooool00`3oO`3oooooooooo`02ooooo`030:0Pl03oO`00
X23`00;ooooo00D0ogl0oooooooooooooooo0?mo0002ooooo`80ogl01Oooool00`3oO`3ooooooooo
o`030:0Pl0Cooooo00H0ogl0ooooooooool0ogl0ooooo`2P8?05ooooo`030:0Pl?ooool0X23`00?o
oooo00<0X23`ooooooooool00_ooool00`2P8?3ooooo0?mo0002ooooo`80X23`00Gooooo0:0Pl?oo
oooooooo0:0Pl003ooooo`030:0Pl?oooooooooo00?ooooo202P8?08ooooo`03o`000?oooooooooo
00Sooooo000Dooooo`03o`000?oooooooooo027ooooo00@0X23`ooooool0003ooooo0P2P8?02oooo
o`070:0Pl?ooool0X23`ooooo`3oO`3ooooo0:0Pl006ooooo`030?mo0?oooooooooo00Wooooo00D0
X23`oooooooooooooooo0?mo0002ooooo`050?mo0?oooooooooo0:0Pl03oO`000_ooool00`3oO`3o
ooooooooo`07ooooo`030:0Pl?ooool0ogl000?ooooo00<0ogl00:0Pl?ooool01oooool00`2P8?3o
oooo0:0Pl002ooooo`030:0Pl?l0003ooooo00Cooooo00<0X23`0?mo0?ooool00oooool20?mo00;o
oooo00D0X23`ooooo`2P8?3ooooo0:0Pl00:ooooo`?o00002?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo04;ooooo00<0X23`ooooooooool01_ooool00`3oO`3oooooooooo`02oooo
o`030:0Pl?oooooooooo00Cooooo0P3oO`07ooooo`040?mo0?oooooooooo0?mo00Oooooo00<0X23`
ooooooooool00_ooool00`2P8?3oooooooooo`04ooooo`060:0Pl?ooooooooooooooo`3oO`00X23`
4?ooool00`3oO`00X23`ooooo`04ooooo`040?mo0?oooooooooo0?mo00;ooooo0P2P8?07ooooo`<0
X23`0_ooool00`2P8?3oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000Dooooo`03o`00
0?oooooooooo02?ooooo0P2P8?03ooooo`@0X23`00@0ogl0oooooooooooooooo0P2P8?0>ooooo`03
0:0Pl?oooooooooo00;ooooo00@0ogl0ooooooooool0ogl00oooool01@3oO`3oooooooooo`3oO`00
X23`00?ooooo00<0ogl0ooooooooool00_ooool20?mo0003ooooo`2P8?3ooooo00<0ogl000Gooooo
0:0Pl?ooool0ogl00:0Pl003ooooo`030?mo002P8?00X23`00Cooooo00?o00000:0Pl?ooool00ooo
ool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00kooooo0ol0000;ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool0@oooool00`3oO`00X23`ooooo`02ooooo`040?mo0?oo
oooooooo0:0Pl0oooooo00<0X23`ooooo`2P8?000oooool00`3oO`3oooooooooo`06ooooo`030:0P
l?oooooooooo00?ooooo00<0X23`ooooo`2P8?002Oooool0103oO`3oooooooooooooool20:0Pl0go
oooo00<0X23`ooooooooool00_ooool0102P8?3oooooooooooooool30:0Pl0Gooooo00<0X23`oooo
ooooool00_ooool00`2P8?3ooooo0:0Pl0020:0Pl0Sooooo00?o0000ooooooooool02?ooool001?o
oooo00?o0000ooooooooool09_ooool01_l0003ooooo0:0Pl?ooool0X23`ooooo`80X23`2Oooool0
0`2P8?00ogl0ooooo`0:ooooo`050?mo0?ooooooooooooooo`3oO`000_ooool00`3oO`3ooooooooo
o`03ooooo`050?mo0?ooool0ogl0ooooo`3oO`000oooool0203oO`3oooooooooo`3oO`3ooooo0?mo
002P8?00ogl00_ooool00`2P8?00ogl0ooooo`06ooooo`030:0Pl?oooooooooo00;ooooo00<0ogl0
o`000?ooool00oooool30:0Pl0;ooooo00<0X23`ooooooooool02Oooool00`2P8?3oooooo`000002
o`0000oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`14ooooo`030:0Pl?oooooo
oooo00;ooooo00H0ogl0ooooo`2P8?00X23`ooooo`2P8?08ooooo`050?mo0?ooooooooooooooo`3o
O`001?ooool00`3oO`3oooooooooo`02ooooo`80ogl02_ooool00`3oO`3oooooooooo`09ooooo`03
0:0Pl?oooooooooo00Oooooo00<0X23`0?mo0?ooool00P2P8?03ooooo`050?mo0?oooooooooooooo
o`2P8?001oooool01@2P8?3oooooooooo`2P8?3ooooo00@0X23`00Cooooo0:0Pl02P8?3ooooo0`2P
8?07ooooo`03o`000?oooooooooo00Sooooo000Cooooo`03o`000?oooooooooo02Gooooo00D0X23`
ooooo`2P8?3ooooo0:0Pl006ooooo`040?mo0?ooooooooooooooo`80X23`0_ooool00`2P8?3ooooo
0?mo0007ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool01_ooool00`3oO`3ooooo
0?mo0002ooooo`090?mo0?ooool0X23`0:0Pl?ooool0X23`ooooo`3oO`3ooooo0080ogl00oooool0
0`3oO`3ooooo0:0Pl003ooooo`030?mo0?oooooooooo00?ooooo00D0X23`ooooo`2P8?3o00000?mo
00020:0Pl005ooooo`3oO`3oooooooooo`2P8?000_ooool00`3oO`00X23`ooooo`07ooooo`?o0000
4_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Wooooo00<0X23`ooooooooool0
0_ooool30?mo00Cooooo00@0X23`0?mo0?ooool0ogl00oooool00`3oO`3oooooooooo`07ooooo`05
0?mo0?ooooooooooooooo`2P8?007?ooool0103oO`00X23`ooooo`3oO`09ooooo`030:0Pl?oooooo
oooo00Gooooo0P2P8?02ooooo`050:0Pl?oooooooooo0:0Pl?ooool00P2P8?000oooool0X23`0:0P
l008ooooo`03o`000?oooooooooo00Sooooo000Cooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool00_ooool0102P8?3oooooooooo`2P8?0:ooooo`030?mo0?oooooooooo00?ooooo00<0
ogl0ooooo`3oO`001Oooool01@3oO`3oooooooooooooool0X23`00Cooooo00<0X23`ooooo`3oO`00
0oooool00`3oO`3oooooooooo`06ooooo`030?mo0?ooool0ogl000;ooooo00<0X23`ooooooooool0
1oooool0102P8?3oooooo`00002P8?02ooooo`050:0Pl?oooooooooo0:0Pl03oO`000_ooool0203o
O`3oooooooooooooool0ogl00:0Pl?ooool0X23`0_l0000Eooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0Boooool20?mo00Oooooo0`3oO`05ooooo`030:0Pl?oooooooooo00;ooooo
00<0X23`0?mo003oO`000_ooool0102P8?3ooooo0?mo0?ooool20?mo00Oooooo00@0X23`oooooooo
ool0ogl00_ooool01`3oO`3ooooo0?mo003oO`00X23`ooooo`3oO`001Oooool20:0Pl003ooooo`2P
8?3ooooo00;ooooo00<0X23`ooooooooool00P2P8?04ooooo`030:0Pl?ooool0X23`0080X23`00Ko
oooo0:0Pl02P8?3ooooo0:0Pl?ooool20:0Pl0?ooooo00<0X23`ooooo`2P8?000`2P8?07ooooo`03
o`000?oooooooooo00Sooooo000Cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool01`2P8?3ooooo0:0Pl02P8?3ooooo0:0Pl?ooool00P2P8?000oooool0X23`0:0Pl003oooo
o`030?mo0?oooooooooo00[ooooo00@0ogl0oooooooooooooooo0P3oO`03ooooo`050?mo0?oooooo
ooooooooo`3oO`001?ooool30?mo00;ooooo00<0ogl0ooooooooool00oooool20:0Pl0;ooooo00@0
ogl0ooooo`3oO`00X23`0_ooool00ol00000X23`ooooo`04ooooo`050:0Pl03oO`00ogl00?mo002P
8?000oooool20?mo0003o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`14ooooo`050:0Pl?ooool0ogl0ooooo`2P8?001?ooool00`3oO`3oooooooooo`0:oooo
o`050?mo0?ooool0ogl0ooooo`2P8?000_ooool00`3oO`3oooooooooo`0:ooooo`030?mo0?oooooo
oooo00Cooooo00<0X23`ooooooooool02Oooool20:0Pl0;ooooo00<0X23`ooooooooool00_ooool0
0`2P8?3oooooooooo`04ooooo`030:0Pl?oooooooooo00kooooo0`2P8?02ooooo`@0X23`1oooool0
0ol0003oooooooooo`08ooooo`004oooool00ol0003oooooooooo`0Yooooo`030:0Pl?l00000X23`
00Kooooo00@0X23`ooooooooool0X23`1?ooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooo
oooo00;ooooo00D0X23`ooooooooool0ogl00:0Pl005ooooo`030:0Pl03oO`3ooooo00;ooooo00D0
ogl0oooooooooooooooo0?mo0002ooooo`050:0Pl?ooool0X23`ooooo`3oO`001Oooool00`2P8?3o
ooooooooo`03ooooo`030?mo0?ooool0ogl000Cooooo00<0X23`o`00003oO`001_ooool0203oO`3o
oooooooooooooooo00000:0Pl?l00000ogl01Oooool00`2P8?3oooooooooo`0Booooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0BOooool00`3oO`00X23`0?mo0002ooooo`050:0Pl?oo
ooooooooooooo`3oO`007?ooool00`2P8?3oooooooooo`0Aooooo`040:0Pl?oooooooooo0:0Pl0_o
oooo00<0ogl0ooooooooool00oooool01`2P8?3oooooooooooooool0X23`ooooo`2P8?001_ooool3
0:0Pl003ooooo`2P8?00X23`00Oooooo00?o0000ooooooooool02?ooool001?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0:ooooo`030:0Pl?ooool0X23`00Cooooo00L0ogl0oooo
o`2P8?3ooooo0?mo0?ooool0ogl000Wooooo00@0ogl0ooooo`3oO`3ooooo0P3oO`02ooooo`030:0P
l?oooooooooo00;ooooo00D0X23`ooooo`3oO`00ogl0ooooo`020?mo00;ooooo00<0ogl0oooooooo
ool01Oooool20:0Pl005ooooo`2P8?3oooooo`00002P8?000oooool0103oO`3oooooooooo`3oO`03
o`000080ogl01_ooool0103oO`3oooooooooo`2P8?0Booooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0BOooool02P2P8?3ooooo0:0Pl?ooool0ogl0ooooo`2P8?00ogl0ooooo`2P8?02
ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool01?ooool00`3oO`3oooooooooo`04
ooooo`050?mo0?ooool0ogl0ooooo`2P8?001Oooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oo
ool0ogl000Oooooo00P0ogl0ooooooooool0ogl0ooooo`2P8?3ooooo0:0Pl0;ooooo00<0X23`oooo
ooooool01?ooool30:0Pl0Oooooo00<0X23`ooooooooool00_ooool00`2P8?3ooooo0:0Pl002oooo
o`D0X23`00?ooooo0:0Pl?ooool01?ooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003o
ooooooooo`0]ooooo`05o`000?ooooooooooooooo`2P8?001_ooool01P2P8?3oooooooooo`3oO`3o
oooo0:0Pl0;ooooo00<0X23`ooooo`2P8?002Oooool0102P8?00ogl0ooooo`2P8?03ooooo`070?mo
0?oooooooooo0:0Pl03oO`3ooooo0?mo0003ooooo`030?mo0?oooooooooo00;ooooo00H0X23`oooo
oooooooooooo0?mo002P8?0:ooooo`040:0Pl?l00000ogl00?mo00?ooooo00?o00000:0Pl03oO`00
0`2P8?0;ooooo`030?mo0?oooooooooo013ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`15ooooo`030?mo0?oooooooooo00;ooooo00H0X23`oooooooooooooooo0:0Pl03oO`05oooo
o`030?mo0?oooooooooo00cooooo00<0ogl0ooooooooool01Oooool00`2P8?3oooooooooo`05oooo
o`030:0Pl?oooooooooo01;ooooo00D0ogl0oooooooooooooooo0:0Pl008ooooo`030:0Pl?oooooo
oooo0080X23`1Oooool00`2P8?3oooooooooo`05ooooo`80X23`00?ooooo0:0Pl?ooool01Oooool0
0ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0]ooooo`80X23`1oooool0102P
8?3oooooooooooooool30:0Pl0;ooooo1@3oO`000oooool0ogl0ooooo`0;ooooo`030?mo0?ooool0
ogl000?ooooo0`3oO`000oooool0ogl0ooooo`03ooooo`060?mo002P8?00ogl0ooooo`3oO`3ooooo
0P3oO`000`2P8?3oooooooooo`04ooooo`040:0Pl?ooooooooooo`0000;ooooo0ol00008ooooo`03
0?mo0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1:ooooo`80
X23`1?ooool0102P8?3ooooo0:0Pl02P8?03ooooo`030?mo0?ooool0ogl000Gooooo00<0ogl0oooo
o`2P8?001_ooool0202P8?00ogl0ooooo`3oO`3ooooo0?mo0?ooool0ogl00_ooool01@2P8?3ooooo
ooooo`2P8?00ogl000;ooooo00<0X23`ooooooooool00oooool0102P8?3oooooooooo`2P8?03oooo
o`<0X23`00?ooooo0?mo0?ooool00_ooool30:0Pl0Sooooo0`2P8?02ooooo`060?mo0?oooooooooo
0:0Pl?ooool0X23`0_ooool40:0Pl0;ooooo00<0X23`ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`004_ooool00ol0003oooooooooo`0^ooooo`030:0Pl?l0003ooooo00Gooooo00H0X23`
ooooooooool0X23`ooooo`2P8?02ooooo`040:0Pl?oooooooooo0:0Pl0_ooooo00@0ogl0ooooo`3o
O`00X23`0oooool01@2P8?3ooooo0?mo003oO`00X23`00;ooooo00<0ogl0ooooo`3oO`001Oooool2
0?mo00Oooooo00<0X23`ooooooooool01?ooool2o`0000060?mo0?ooooooooooooooo`2P8?00ogl0
1?ooool01`3oO`3oooooooooo`2P8?00ogl00:0Pl03oO`001_ooool00`2P8?3oooooooooo`0?oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00`2P8?3oooooooooo`02oooo
o`030?mo0?oooooooooo00?ooooo00D0X23`0?mo0?ooool0ogl00:0Pl008ooooo`030?mo0?oooooo
oooo00;ooooo00<0X23`ooooooooool02Oooool0103oO`3oooooooooo`3oO`05ooooo`030?mo0?oo
oooooooo01Wooooo00<0ogl0ooooo`3oO`000_ooool00`2P8?3ooooo0:0Pl006ooooo`80X23`0ooo
ool01@2P8?3oooooooooo`2P8?3ooooo00<0X23`1Oooool00ol0003oooooooooo`08ooooo`004_oo
ool00ol0003oooooooooo`0^ooooo`040:0Pl?oooooo00000:0Pl0cooooo00@0X23`ooooo`3oO`3o
oooo0P2P8?02ooooo`030:0Pl?oooooooooo00_ooooo0P3oO`04ooooo`040?mo002P8?00ogl0oooo
o`<0ogl000H0X23`ooooooooool0ogl0ooooo`3oO`06ooooo`80ogl000?ooooo0?mo002P8?000_l0
00000oooool0X23`ooooo`0:ooooo`050?mo0?ooool0ogl0ooooo`3oO`000_ooool00`3oO`3ooooo
0:0Pl00Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0C_ooool30:0Pl004oooo
o`3oO`3ooooo0?mo00?ooooo00/0X23`oooooooooooooooo0?mo0?ooool0ogl00:0Pl?ooool0X23`
0?mo0003ooooo`80X23`1Oooool01@2P8?00ogl00?mo003oO`3ooooo0080ogl00_ooool0102P8?00
ogl00?mo003oO`02ooooo`030?mo0?oooooooooo00Oooooo00H0ogl0ooooooooool0X23`0?mo0?oo
ool30:0Pl0?ooooo102P8?03ooooo`<0X23`1?ooool20:0Pl003ooooo`2P8?3ooooo00Gooooo00<0
X23`ooooooooool01Oooool00ol0003oooooooooo`08ooooo`004_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Gooooo00D0X23`ooooooooool0X23`ooooo`020:0Pl0Sooooo00<0
X23`ooooooooool00_ooool00`3oO`3oooooooooo`02ooooo`060:0Pl03oO`3ooooo0?mo0?ooool0
ogl00_ooool00`2P8?3oooooooooo`05ooooo`80ogl02?ooool02P3oO`3o0000o`00002P8?00ogl0
ooooo`2P8?3o0000ooooo`3oO`0;ooooo`030?mo0?ooool0ogl000Cooooo00H0ogl0oooooooooooo
oooo0?mo002P8?0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0C_ooool00`2P
8?3oooooooooo`04ooooo`030:0Pl?ooool0ogl000gooooo00<0ogl0ooooo`3oO`000oooool0203o
O`3oooooooooooooool0ogl0ooooo`2P8?00ogl00_ooool00`3oO`3oooooooooo`0>ooooo`030?mo
0?ooool0X23`00;ooooo00<0X23`ooooooooool00_ooool0102P8?3oooooooooo`2P8?0=ooooo`08
0:0Pl?ooool0X23`0:0Pl?ooool0X23`ooooo`2P8?03ooooo`030:0Pl?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool001;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0=
ooooo`040?mo0?oooooooooo0:0Pl0;ooooo00<0ogl0ooooo`3oO`001Oooool00`3oO`3ooooooooo
o`07ooooo`030?mo0?oooooooooo00<0ogl000Cooooo0?mo0?ooool0ogl01Oooool3o`000005oooo
o`2P8?3oooooooooo`2P8?000_ooool02?l0003oooooooooo`2P8?3ooooo0:0Pl?ooool0X23`0ooo
ool0102P8?3oooooooooo`3oO`02ooooo`030?mo0?oooooooooo0080ogl00oooool00`3oO`3ooooo
ooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0F?ooool00`3oO`3ooooo
ooooo`04ooooo`030:0Pl03oO`3ooooo00;ooooo0P3oO`02ooooo`030:0Pl?oooooooooo00;ooooo
00<0ogl0ooooooooool00_ooool00`3oO`3oooooooooo`07ooooo`030:0Pl?oooooooooo013ooooo
00D0X23`oooooooooooooooo0?mo0005ooooo`030:0Pl?oooooooooo017ooooo00<0X23`oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`004Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00<0X23`ooooooooool00oooool20:0Pl0Cooooo00<0ogl0ooooooooool0
2_ooool00`2P8?3oooooooooo`02ooooo`080:0Pl?oooooooooo0:0Pl03oO`00X23`0?mo0?ooool4
0?mo0005o`00003oO`00X23`ooooo`2P8?002?ooool01Ol00000X23`ooooooooool0X23`00;ooooo
0P3oO`08ooooo`050?mo0?ooool0ogl0ooooo`3oO`000oooool30?mo00030:0Pl?ooool0ogl000co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`16ooooo`030?mo0?oooooooooo00[o
oooo00@0X23`0?mo0?ooool0X23`0oooool01@2P8?3ooooo0?mo003oO`00X23`0080ogl000?ooooo
0?mo003oO`000_ooool20?mo00;ooooo00H0ogl0oooooooooooooooo0?mo002P8?02ooooo`030?mo
0?oooooooooo00;ooooo00D0ogl00:0Pl?oooooooooo0?mo0005ooooo`030:0Pl?ooool0X23`00Co
oooo00<0X23`ooooooooool00_ooool30:0Pl0?ooooo0P2P8?02ooooo`050:0Pl?oooooooooooooo
o`3oO`000_ooool00`2P8?3ooooo0:0Pl004ooooo`80X23`0oooool00`2P8?3oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo000Aooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool01_ooool30:0Pl0Kooooo00<0X23`ooooooooool00oooool00`2P8?3oooooooooo`04ooooo`04
0?mo0?ooool0X23`0?mo00Cooooo00<0ogl0ooooo`2P8?000P3oO`00102P8?3oooooooooo`3oO`02
o`000003ooooo`2P8?00ogl000;ooooo00<0ogl0ooooooooool00_ooool0103oO`3oooooooooool0
0002ooooo`070:0Pl?oooooooooo0:0Pl03oO`3ooooo0?mo0007ooooo`060?mo0?ooool0X23`0?mo
0?ooool0X23`1?ooool0103oO`3oooooooooo`3oO`0<ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0Doooool0103oO`3ooooo0:0Pl02P8?04ooooo`030:0Pl03oO`3ooooo00oooooo
00<0ogl0ooooooooool00_ooool0202P8?3oooooooooo`3oO`3ooooo0?mo0?ooool0ogl00_ooool0
0`3oO`3oooooooooo`0:ooooo`030?mo0?oooooooooo00;ooooo0P2P8?02ooooo`030:0Pl?oooooo
oooo00Gooooo00<0X23`ooooooooool01?ooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool0017ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`02ooooo`030:0Pl?oooooooooo00Sooooo00<0X23`ooooooooool04_ooool01@3o
O`3oooooooooo`3oO`3ooooo0080ogl000Co00000?mo003oO`00ogl01?ooool0103oO`3ooooooooo
ooooool20?mo00Cooooo00?o0000ooooo`3oO`005?ooool01P2P8?3ooooo0?mo003oO`3ooooo0?mo
00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Cooooo`050:0Pl?oooooooooo
ooooo`3oO`000oooool60?mo0004ooooo`3oO`00ogl00?mo0080X23`2Oooool00`3oO`3ooooooooo
o`02ooooo`030?mo0?ooool0ogl000Cooooo00<0X23`ooooo`3oO`000_ooool00`2P8?3ooooo0:0P
l002ooooo`030?mo0?oooooooooo00;ooooo00D0X23`ooooo`2P8?3ooooo0:0Pl004ooooo`80X23`
00?ooooo0:0Pl?ooool01?ooool00`2P8?3oooooooooo`04ooooo`030:0Pl?oooooooooo00_ooooo
00?o0000ooooooooool02?ooool0017ooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0Cooooo`030:0Pl?oooooooooo00Kooooo00@0X23`0?mo0?ooool0ogl00oooool0103oO`3o0000
o`000?l00002ooooo`030?mo0?oooooooooo00@0ogl01?ooool01`3oO`3oooooooooooooool0X23`
0?mo0?l000000oooool00`3oO`3oooooooooo`0<ooooo`030?mo0?oooooooooo00;ooooo00H0ogl0
oooooooooooooooo0:0Pl?ooool20?mo00cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1Booooo`040:0Pl03oO`3ooooo0:0Pl0Gooooo0`3oO`05ooooo`030?mo0?ooool0ogl000;o
oooo00<0ogl0ooooooooool01Oooool00`3oO`3ooooo0?mo000>ooooo`030:0Pl?oooooooooo00So
oooo00D0ogl00:0Pl?oooooooooo0:0Pl00=ooooo`030:0Pl?ooool0X23`00Cooooo00<0X23`oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`004Oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00_ooooo0P2P8?02ooooo`030?mo0?ooool0X23`00;ooooo00H0ogl0ooooo`3o
O`00ogl0ooooo`3oO`03ooooo`060?mo0?ooool0ogl00:0Pl03oO`3o00001oooool30?mo00?ooooo
00<0X23`0?mo0?ooool00P3oO`04ooooo`03o`000?oooooooooo00Cooooo00<0ogl00:0Pl?ooool0
1?ooool00`3oO`3oooooooooo`08ooooo`040?mo0?ooool0X23`0?mo00?ooooo00<0X23`oooooooo
ool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05?ooooo00D0X23`oooooooo
oooooooo0:0Pl003ooooo`80X23`0_ooool00`3oO`3oooooooooo`03ooooo`030?mo0?ooool0ogl0
00gooooo00<0ogl0ooooooooool07?ooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo
00Cooooo00<0X23`ooooooooool01_ooool00`3oO`3oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo000Aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool03?ooool00`2P8?3o
ooooooooo`03ooooo`030:0Pl?oooooooooo00?ooooo0P3oO`000`2P8?00ogl0o`000002o`000003
0?mo0?ooool0ogl000?ooooo00@0X23`0?mo0?ooool0ogl01?ooool20?mo0003ooooo`3oO`3ooooo
00Kooooo00Go0000oooooooooooooooo0:0Pl006ooooo`040?mo0?oooooooooo0:0Pl0Oooooo00@0
ogl0ooooo`3oO`00ogl00_ooool0103oO`00X23`0?mo003oO`0<ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0EOooool01@3oO`00X23`0:0Pl02P8?00ogl000@0X23`0`3oO`02oooo
o`030?mo002P8?3ooooo00;ooooo00<0X23`0?mo0?ooool01?ooool30?mo00Oooooo00<0ogl0oooo
o`3oO`000_ooool20?mo00?ooooo00<0ogl0ooooooooool00_ooool0103oO`00X23`0:0Pl02P8?03
ooooo`030:0Pl03oO`3ooooo00Cooooo00@0X23`ooooo`2P8?00X23`1?ooool00`2P8?3ooooooooo
o`07ooooo`030?mo0?oooooooooo00Cooooo00@0X23`oooooooooooo00002_ooool0017ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`030:0Pl?oooooooooo00;ooooo00H0
X23`ooooooooool0X23`ooooo`3oO`08ooooo`80ogl000Oo00000?mo003oO`3ooooo0?mo0?ooool0
X23`00;ooooo00<0ogl0ooooo`3oO`001?ooool20?mo0003ooooo`3oO`00ogl000;ooooo00@0X23`
ooooooooool0ogl00oooool01Ol00000X23`ooooooooool0X23`01Cooooo0`3oO`05ooooo`030:0P
l?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Eooooo`030?mo
002P8?3ooooo00Kooooo0P3oO`03ooooo`030?mo0?oooooooooo00;ooooo00<0X23`ooooooooool0
0oooool00`3oO`3oooooooooo`0;ooooo`050?mo0?ooooooooooooooo`2P8?001Oooool00`2P8?3o
ooooooooo`0@ooooo`030:0Pl?oooooooooo00cooooo00<0X23`ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`004?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Gooooo
00<0X23`ooooooooool00_ooool0103oO`3oooooooooo`2P8?04ooooo`030?mo002P8?00ogl000;o
00000`3oO`02ooooo`030:0Pl03oO`3ooooo00Gooooo0P3oO`001Oooool0ogl0ooooooooool0ogl0
00_ooooo00D0X23`o`000?oooooooooo0?mo000:ooooo`030?mo002P8?3ooooo00?ooooo00<0ogl0
ooooooooool00_ooool30?mo00?ooooo00D0ogl0oooooooooooooooo0:0Pl007ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0Eoooool0103oO`3ooooo0:0Pl02P8?020?mo00;ooooo
1@3oO`001?ooool0X23`ooooo`2P8?03ooooo`80ogl000Gooooo0:0Pl?oooooooooo0?mo0002oooo
o`050?mo0?ooooooooooooooo`2P8?000_ooool01P3oO`00X23`0:0Pl03oO`3ooooo0:0Pl0Oooooo
00@0X23`ooooooooool0X23`1?ooool00`2P8?3oooooooooo`04ooooo`030:0Pl03oO`00X23`00Ko
oooo00<0ogl0ooooooooool03Oooool00`2P8?3oooooo`00000:ooooo`004?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo013ooooo0_l000001`2P8?3ooooo0:0Pl?ooool0X23`0?mo
0?ooool00P3oO`000oooool0ogl0ooooo`03ooooo`030?mo0?ooool0ogl000Oooooo00H0ogl0oooo
ooooool0X23`ooooo`3oO`05ooooo`08o`000?ooooooooooooooo`2P8?00ogl0ooooo`3oO`09oooo
o`040:0Pl?ooooooooooooooo`80ogl01_ooool20:0Pl0030?mo0?oooooooooo00Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`1@ooooo`030?mo0?oooooooooo00Gooooo00<0X23`
ooooooooool00P3oO`001?ooool0ogl0ooooo`2P8?03ooooo`030?mo0?oooooooooo00Gooooo00<0
ogl0ooooooooool02_ooool00`3oO`3oooooooooo`0=ooooo`030:0Pl?oooooooooo01;ooooo00@0
X23`ooooooooool0ogl01Oooool00`2P8?3oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
000@ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03?ooool0103oO`00X23`0:0P
l02P8?03ooooo`070:0Pl?ooool0ogl0ooooo`2P8?00ogl0ooooo`020?mo00;ooooo00<0X23`oooo
ooooool00P3oO`000`2P8?3ooooo0?mo0002ooooo`030:0Pl?oooooooooo00Gooooo0P3oO`03oooo
o`03o`000?oooooooooo00_ooooo00<0ogl0ooooooooool02Oooool00`2P8?00ogl0ooooo`020?mo
00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Jooooo`070:0Pl?ooool0ogl0
0?mo0?ooool0X23`0?mo0002ooooo`040?mo0?oooooooooo0:0Pl0Gooooo00<0ogl0ooooo`3oO`00
1oooool00`3oO`3oooooooooo`0Iooooo`030:0Pl?oooooooooo00;ooooo00D0ogl0oooooooooooo
oooo0:0Pl003ooooo`030:0Pl?oooooooooo00Kooooo00<0ogl0ooooooooool01oooool00ol0003o
ooooooooo`08ooooo`004?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Oooooo
0P2P8?02o`0000040:0Pl?ooooooooooooooo`<0X23`1@3oO`02ooooo`030?mo002P8?00X23`00?o
oooo0P3oO`000oooool0ogl00?mo0003ooooo`030:0Pl?ooool0X23`00;ooooo00<0ogl0oooooooo
ool01?ooool00`3oO`3o00000?mo0003ooooo`050:0Pl?ooooooooooooooo`3oO`001?ooool00`3o
O`3oooooooooo`05ooooo`80ogl000?ooooo0?mo0?ooool00_ooool20?mo0003ooooo`2P8?3ooooo
00[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Kooooo`030?mo0?ooool0X23`
00?ooooo00@0ogl0oooooooooooooooo0P3oO`000oooool0X23`0?mo0003ooooo`030?mo002P8?00
ogl000Sooooo00D0ogl0ooooo`3oO`3ooooo0?mo0003ooooo`030:0Pl?oooooooooo00Gooooo00@0
X23`ooooooooool0X23`0_ooool20:0Pl0;ooooo00D0X23`oooooooooooooooo0?mo0002ooooo`03
0:0Pl?oooooooooo00Kooooo00<0X23`ooooooooool01?ooool00`2P8?3oooooooooo`06ooooo`03
o`000?oooooooooo00Sooooo000@ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
1?ooool3o`0000;ooooo00<0X23`ooooooooool00_ooool0103oO`3ooooo0?mo002P8?02ooooo`03
0:0Pl03oO`00ogl00080ogl000?ooooo0?mo0?ooool02?ooool20:0Pl003ooooo`3oO`3ooooo00Co
oooo00<0ogl00:0Pl?ooool00oooool00ol00000ogl00?mo0003ooooo`040?mo0?oooooooooo0?mo
00Wooooo00<0ogl0ooooooooool01Oooool01P3oO`3oooooooooo`3oO`3ooooo0?mo00;ooooo00<0
X23`ooooo`3oO`001_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05_ooooo00<0
X23`0?mo0?ooool00oooool00`2P8?00ogl00:0Pl004ooooo`030?mo0?oooooooooo00;ooooo00D0
ogl0oooooooooooooooo0?mo0003ooooo`050?mo002P8?3oooooooooo`2P8?000oooool00`3oO`3o
ooooooooo`0=ooooo`030?mo0?oooooooooo00Sooooo00<0X23`ooooooooool05oooool00ol0003o
ooooooooo`08ooooo`004?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00?o0000
2?ooool00`2P8?3oooooooooo`03ooooo`<0X23`00Cooooo0?mo0?ooool0ogl01_ooool30?mo00Go
oooo0P3oO`06ooooo`050?mo0?ooooooooooooooool000001_ooool00`3oO`3ooooo0?mo0009oooo
o`80ogl02?ooool60?mo00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Joooo
o`040:0Pl?oooooooooo0:0Pl0;ooooo00D0ogl00:0Pl02P8?00ogl0ooooo`020?mo00050:0Pl03o
O`00ogl00?mo002P8?000_ooool30?mo00Cooooo00P0X23`oooooooooooooooo0?mo0?ooool0X23`
ooooo`80ogl00_ooool20?mo0003ooooo`3oO`3ooooo00?ooooo00<0X23`ooooooooool00oooool0
0`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00gooooo00<0X23`ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`003oooool00ol0003oooooooooo`13ooooo`;o00002Oooool00`2P
8?3oooooooooo`04ooooo`80ogl00_ooool30?mo00040:0Pl03oO`3ooooo0?mo00Cooooo00<0X23`
ooooo`3oO`000P3oO`03ooooo`030:0Pl03oO`00ogl00080ogl000Sooooo0?mo0?oooooooooo0:0P
l?oooooo00000?mo00?ooooo00<0X23`ooooooooool00`3oO`000oooool0ogl0ooooo`06ooooo`05
0?mo002P8?3oooooooooo`3oO`001?ooool0103oO`3ooooo0?mo002P8?02ooooo`040:0Pl?oooooo
oooo0?mo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Pooooo`030?mo0?oo
oooooooo00?ooooo00<0ogl0ooooo`2P8?001?ooool30?mo00;ooooo00<0ogl0ooooooooool01?oo
ool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00Sooooo0P3oO`07ooooo`030:0Pl?oo
oooooooo01Sooooo00<0X23`ooooooooool00_ooool00ol0003oooooooooo`08ooooo`003oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo00kooooo00<0X23`ooooooooool00oooool2
0?mo00Gooooo00D0X23`oooooooooooooooo0?mo0002ooooo`0:0:0Pl?ooooooooooooooo`2P8?3o
oooo0:0Pl03oO`3ooooo0?mo00;ooooo00@0ogl0o`000?l0003o00001_ooool40:0Pl080ogl00ooo
ool00`3oO`3oooooooooo`0Aooooo`030?mo0?oooooooooo00Gooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`1Eooooo`030?mo0?oooooooooo00Oooooo00@0X23`ooooooooool0X23`
0P3oO`00102P8?00ogl00?mo0?ooool20?mo0003ooooo`3oO`00ogl000;ooooo0P3oO`002P2P8?3o
oooo0?mo003oO`3ooooo0:0Pl?ooool0X23`ooooo`3oO`02ooooo`030:0Pl?oooooooooo00Oooooo
00<0ogl0ooooooooool06?ooool00`2P8?3oooooooooo`0:ooooo`030:0Pl?oooooo000000[ooooo
000?ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03oooool00`2P8?3ooooooooo
o`02ooooo`080:0Pl?oooooooooo0?mo0?ooool0ogl0ooooo`2P8?02ooooo`80ogl00_ooool00`3o
O`00X23`0?mo0004ooooo`030:0Pl?oooooooooo00?o00000_ooool00ol0003oooooooooo`02oooo
o`050?mo0?ooooooooooooooo`3oO`000_ooool20?mo00050:0Pl?oooooooooo0?mo0?ooool00P3o
O`000oooool0ogl00:0Pl008ooooo`050?mo0?ooooooooooooooo`3oO`001oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo063ooooo0P2P8?06ooooo`040:0Pl03oO`3ooooo0?mo00Wo
oooo00<0ogl0ooooooooool03?ooool00`2P8?3oooooooooo`0@ooooo`030?mo0?oooooooooo01So
oooo00?o0000ooooooooool02?ooool000oooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0<ooooo`80X23`1Oooool20?mo00;ooooo0P3oO`03ooooo`80ogl00oooool00`3oO`3ooooo
ooooo`02ooooo`030?mo0?ooool0ogl000?o000000L0ogl0ooooo`2P8?3ooooo0:0Pl?oooooo0000
00;ooooo00@0ogl00:0Pl03oO`3ooooo0P3oO`001@2P8?3ooooo0:0Pl?ooool0X23`00[ooooo00@0
X23`ooooo`3oO`00ogl01?ooool00`3oO`3oooooooooo`08ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0HOooool01@3oO`00X23`0?mo0?ooool0ogl000;ooooo00@0ogl00:0Pl03o
O`00ogl02?ooool00`3oO`3oooooooooo`07ooooo`030:0Pl?oooooooooo00Wooooo00<0ogl0oooo
ooooool09Oooool00ol0003oooooooooo`08ooooo`003oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo017ooooo0P2P8?001_ooool0ogl0ooooooooool0ogl00:0Pl0<0ogl000Gooooo
0?mo0?ooool0ogl0ooooo`020?mo0003ooooo`3oO`3ooooo00?o00000oooool0102P8?3ooooooooo
ooooool20?mo0003ooooool00000ogl000;ooooo00<0X23`ooooo`3oO`001oooool00`3oO`3ooooo
0?mo0004ooooo`030?mo0?ooool0X23`00Kooooo00<0X23`0?mo003oO`002_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo067ooooo00D0X23`ooooooooool0X23`ooooo`040?mo0003
0:0Pl?ooool0ogl000<0ogl000?ooooo0?mo0?ooool01?ooool00`2P8?3oooooooooo`0<ooooo`03
0?mo0?oooooooooo00Gooooo00L0ogl0ooooo`2P8?3ooooo0:0Pl03oO`00X23`00Cooooo00<0ogl0
ooooooooool02oooool00`3oO`00X23`ooooo`08ooooo`03o`000?oooooooooo00Sooooo000?oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04Oooool20:0Pl0Cooooo00@0ogl00:0P
l?ooool0ogl00_ooool50?mo00Co00001_ooool00`3oO`3ooooo0:0Pl003ooooo`030?mo0?oooooo
000000Cooooo00<0ogl0ooooooooool08_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo06Kooooo00L0ogl0ooooooooool0ogl0ooooo`3oO`3ooooo0080ogl01Oooool00`3oO`3ooooo
0?mo0002ooooo`040?mo002P8?00X23`0?mo00?ooooo00<0ogl0ooooooooool03_ooool01@3oO`3o
ooooooooooooool0ogl000Cooooo00<0X23`ooooooooool05Oooool00ol0003oooooooooo`08oooo
o`003_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01;ooooo00<0X23`oooooooo
ool01?ooool01P2P8?00ogl00?mo0?ooool0ogl00:0Pl0?o000000<0X23`0?mo0?ooool01Oooool0
0`3oO`3oooooooooo`06ooooo`030?mo0?oooooo000000Oooooo00<0ogl0ooooo`2P8?002oooool0
1P3oO`3oooooooooo`3oO`3ooooo0?mo00Cooooo00<0ogl0ooooooooool01_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo06Kooooo00D0X23`ooooo`2P8?00ogl0ooooo`030?mo0005
0:0Pl?ooool0ogl0ooooo`3oO`000oooool00`3oO`3oooooooooo`06ooooo`030:0Pl?ooool0X23`
00Wooooo00@0ogl0ooooooooool0ogl00oooool00`2P8?3oooooooooo`0<ooooo`030:0Pl?ooool0
ogl000Gooooo0P2P8?000oooool0X23`ooooo`04ooooo`03o`000?oooooooooo00Sooooo000>oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06?ooool0102P8?00ogl00?mo003oO`03
o`0000H0ogl02Oooool00`3oO`3oooooooooo`04ooooo`03o`000?ooool0X23`00?ooooo00<0ogl0
ooooooooool05?ooool00`3oO`00X23`ooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0H_ooool00`3oO`3oooooooooo`03ooooo`H0ogl00_ooool00`3oO`3ooooo0?mo0008
ooooo`040?mo0?oooooooooo0?mo00?ooooo00<0ogl0ooooooooool00_ooool00`3oO`3ooooooooo
o`04ooooo`030?mo0?oooooooooo027ooooo00?o0000ooooooooool02?ooool000kooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`Co000000<0ogl00:0Pl03oO`001`3oO`00
0oooool0ogl0ooooo`04ooooo`040:0Pl?ooool0ogl00?mo00Cooooo00@0ogl0o`000?ooool0ogl0
5?ooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1Nooooo`050:0Pl?ooooooooooooooo`2P8?001_ooool40?mo0005
0:0Pl?ooool0ogl0ooooo`3oO`004Oooool00`2P8?3oooooooooo`0[ooooo`030:0Pl?l0003ooooo
00Wooooo000>ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool05Oooool3o`000004
0:0Pl?ooooooooooooooo`80X23`00<0ogl0ooooooooool01@3oO`001?ooool0ogl0ooooo`3oO`02
ooooo`030?mo0?ooool0X23`00Sooooo00?o0000ooooooooool00_ooool0103oO`00X23`ooooo`3o
O`02ooooo`80ogl00oooool20?mo013ooooo00<0ogl0ooooooooool00_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo06Gooooo00<0ogl0ooooooooool00_ooool00`2P8?00ogl00?mo
00050?mo00Oooooo00<0ogl0ooooooooool00_ooool0103oO`3oooooooooo`3oO`03ooooo`040?mo
0?ooool0ogl00:0Pl0_ooooo00<0X23`ooooooooool03?ooool00`3oO`3oooooooooo`09ooooo`04
0:0Pl?ooooooooooo`0000[ooooo000>ooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool04_ooool3o`0000?ooooo00@0X23`oooooooooooooooo103oO`00102P8?00ogl0ooooo`3oO`0?
ooooo`80ogl00oooool01ol0003oooooooooooooool0ogl0ooooo`2P8?000oooool00`2P8?3ooooo
ooooo`02ooooo`<0ogl000Cooooo0?mo002P8?00ogl01?ooool00`3oO`3oooooooooo`09ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0J_ooool40?mo00;ooooo00<0ogl0oooooooo
ool07?ooool00`2P8?3oooooooooo`0<ooooo`030?mo0?oooooooooo017ooooo00?o0000oooooooo
ool02?ooool000kooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`?o0000
1oooool0102P8?3oooooooooooooool30?mo00;ooooo1P3oO`0?ooooo`030:0Pl03oO`3o000000?o
oooo00<0ogl0ooooooooool01?ooool00`2P8?3ooooo0:0Pl005ooooo`030?mo0?oooooooooo00oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Xooooo`050?mo0?ooool0X23`oooo
o`2P8?00103oO`001Oooool0ogl0ooooooooool0ogl000Wooooo0`3oO`04ooooo`030?mo0?ooool0
ogl000Kooooo00<0ogl0ooooooooool01?ooool00`2P8?3ooooo0:0Pl00Iooooo`03o`000?oooooo
oooo00Sooooo000>ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool03?ooool4o`00
00Cooooo00<0X23`ooooooooool02?ooool50?mo0003ooooo`3oO`3ooooo00;ooooo00<0X23`oooo
ooooool02?ooool00`2P8?00ogl0ooooo`04ooooo`03o`000?oooooooooo00gooooo0P3oO`001?oo
ool0ogl0ooooo`3oO`06ooooo`030?mo0?oooooooooo00Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`1/ooooo`030?mo002P8?00X23`00Gooooo00<0ogl00:0Pl?ooool01?ooool2
0?mo00?ooooo00<0ogl0ooooooooool01Oooool00`3oO`3oooooooooo`09ooooo`030:0Pl?oooooo
oooo00;ooooo00<0X23`ooooooooool01?ooool00`3oO`3oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo000=ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool02Oooool3o`00
013ooooo00<0X23`ooooooooool00_ooool30?mo0004ooooo`2P8?3ooooo0:0Pl0?ooooo0P3oO`00
0oooool0ogl0ooooo`05ooooo`030?mo0?oooooooooo00;ooooo00D0X23`o`000?oooooooooo0?mo
0002ooooo`030?mo0?oooooooooo00;ooooo00<0X23`ooooooooool00_ooool20?mo01?ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1]ooooo`@0ogl000?ooooo0?mo0?ooool00ooo
ool00`3oO`3oooooooooo`07ooooo`030?mo002P8?3ooooo00_ooooo00<0X23`ooooooooool07ooo
ool00`2P8?3o0000ooooo`09ooooo`003Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo00Kooooo0ol0000Iooooo`<0ogl000?ooooo0?mo0?ooool00oooool00`3oO`3oooooooooo`08
ooooo`030:0Pl?oooooooooo00;ooooo00<0ogl0o`000?ooool03Oooool00`2P8?3oooooooooo`0B
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Joooool01`2P8?00ogl0oooooooo
ool0X23`0?mo002P8?002oooool01`2P8?3ooooo0?mo002P8?00ogl0ooooo`3oO`000_ooool20?mo
00?ooooo00<0ogl0ooooooooool01Oooool0103oO`3oooooooooo`2P8?02ooooo`030:0Pl?oooooo
oooo01Kooooo00?o0000ooooooooool02?ooool000gooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`02ooooo`Co00006Oooool00`2P8?3oooooooooo`040?mo0080X23`00?ooooo0?mo
0?ooool03_ooool01@2P8?3ooooooooooooooooo000000?ooooo00<0ogl0ooooooooool00P3oO`05
ooooo`030?mo0?oooooooooo00Wooooo00<0ogl0ooooooooool01_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo06gooooo00D0X23`oooooooooooooooo0:0Pl003ooooo`030?mo0?oo
oooooooo00gooooo00<0ogl0ooooooooool0:Oooool00`2P8?3o0000ooooo`09ooooo`003Oooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooo000000;o00008?ooool40?mo0005ooooo`3oO`00
X23`ooooo`3oO`003_ooool01P3oO`3ooooo0?mo0?ooool0ogl0o`0000?ooooo00L0ogl0oooooooo
ool0ogl0ooooo`2P8?00ogl000Gooooo00<0ogl0ooooooooool01?ooool00`2P8?3oooooooooo`08
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0KOooool01@3oO`3ooooo0:0Pl?oo
ool0ogl000;ooooo0P3oO`0=ooooo`040?mo002P8?3ooooo0?mo00Kooooo00@0ogl0ooooooooool0
X23`0_ooool00`2P8?3oooooooooo`03ooooo`030:0Pl?oooooooooo00Oooooo00<0ogl0oooooooo
ool02?ooool01@3oO`3ooooooooooooooooo000000[ooooo000=ooooo`03o`000?oooooooooo04?o
oooo0ol0000Vooooo`@0ogl01Oooool00`3oO`3oooooooooo`05ooooo`040:0Pl?ooool0ogl00?mo
00Gooooo00Go0000oooooooooooooooo0?mo0004ooooo`80ogl000Gooooo0?mo0?oooooooooo0?mo
000Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Hoooool00`3oO`3ooooooooo
o`0<ooooo`030?mo0?oooooooooo0080ogl000?ooooo0?mo0?ooool00_ooool00`2P8?3ooooooooo
o`0cooooo`03o`000?oooooooooo00Sooooo000=ooooo`03o`000?oooooooooo043ooooo0ol00000
0ooooooo0000ooooo`0Uooooo`030?mo0?oooooooooo00Gooooo00<0X23`ooooooooool00oooool0
0`3oO`3oooooooooo`05ooooo`060?mo0?ooooooooooooooo`3oO`3o00002?ooool20?mo0005oooo
o`3oO`3oooooooooo`3oO`004Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo073o
oooo00H0X23`ooooooooool0ogl0ooooo`3oO`04ooooo`030?mo0?oooooooooo00Gooooo00@0ogl0
ooooooooool0ogl00oooool20:0Pl003ooooo`3oO`3ooooo00;ooooo00D0ogl0oooooooooooooooo
0?mo0002ooooo`030:0Pl?oooooooooo00Oooooo00<0X23`ooooooooool03_ooool00ol0003ooooo
ooooo`08ooooo`003?ooool00ol0003oooooooooo`0mooooo`Co00001?ooool00ol0003ooooooooo
o`0Xooooo`050?mo0?oooooooooo0?mo002P8?000_ooool00`2P8?3ooooo0?mo0004ooooo`030:0P
l03oO`3ooooo00Gooooo00<0ogl0ooooool000000_ooool01P2P8?3oooooooooooooool0X23`0?mo
00Gooooo00<0ogl0ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
09Cooooo00<0X23`ooooo`3oO`006oooool00ol0003oooooooooo`08ooooo`003?ooool00ol0003o
ooooooooo`0jooooo`?o00002?ooool00ol0003oooooooooo`0Zooooo`060?mo0?oooooooooo0?mo
0?ooool0ogl01oooool00`3oO`3ooooo0:0Pl006ooooo`060:0Pl?l00000ogl00?mo002P8?00ogl0
0oooool20?mo00?ooooo00<0X23`ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo07Oooooo00@0ogl0ooooo`2P8?00ogl03oooool0102P8?3oooooooooo`2P8?0Toooo
o`03o`000?oooooooooo00Sooooo000<ooooo`03o`000?oooooooooo03Oooooo0ol0000;ooooo`03
o`000?oooooooooo02Sooooo00<0X23`ooooooooool01Oooool00`3oO`3oooooooooo`04ooooo`04
0:0Pl?ooooooooooooooo`80ogl01Oooool01?l0003oooooooooo`3oO`02ooooo`030?mo0?oooooo
oooo00Cooooo0P3oO`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0MOooool0
1@2P8?3ooooo0?mo0?ooool0ogl000Kooooo00<0ogl0ooooooooool01Oooool01`2P8?3ooooo0:0P
l03oO`3ooooo0?mo002P8?000oooool00`3oO`3ooooo0?mo0004ooooo`040?mo0?oooooooooooooo
o`80X23`00?ooooo0?mo0?ooool03oooool00`3oO`3o0000ooooo`09ooooo`003?ooool00ol0003o
ooooooooo`0cooooo`Co00003_ooool00ol0003oooooooooo`0/ooooo`050:0Pl?oooooooooooooo
o`2P8?002Oooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooo000001gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1`ooooo`030?mo0?ooool0ogl000;ooooo00D0X23`oooo
o`3oO`3ooooo0:0Pl003ooooo`030:0Pl?oooooooooo00Wooooo00<0ogl00:0Pl?ooool04oooool0
0`2P8?3oooooooooo`05ooooo`030:0Pl?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
00cooooo00?o0000ooooooooool0<?ooool3o`0001;ooooo00?o0000ooooooooool0;_ooool0102P
8?3oooooooooo`2P8?04ooooo`040?mo0?oooooooooo0?mo00Oooooo0P2P8?000ooooooo00000?mo
0004ooooo`040?mo0?ooool0X23`0?mo01?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1]ooooo`030:0Pl?oooooooooo00Gooooo00D0X23`oooooooooooooooo0?mo0006ooooo`03
0?mo0?oooooooooo00?ooooo00<0X23`ooooo`3oO`003_ooool00`3oO`3ooooo0?mo0006ooooo`03
0?mo0?oooooooooo00oooooo00?o0000ooooooooool02?ooool000cooooo00?o0000ooooooooool0
;Oooool3o`0001Gooooo00?o0000ooooooooool0=oooool0102P8?3oooooooooo`2P8?04ooooo`03
0?mo0?oooooooooo00;ooooo00?o00000:0Pl?ooool02_ooool20?mo00Cooooo00@0ogl0oooooooo
ool0ogl01_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07;ooooo00<0ogl0oooo
ooooool01Oooool0102P8?3oooooooooo`3oO`08ooooo`050:0Pl?ooool0ogl0ooooo`3oO`001_oo
ool00`2P8?3ooooo0?mo0003ooooo`030:0Pl?ooool0ogl000Oooooo00<0ogl0ooooo`2P8?000_oo
ool00`3oO`3oooooooooo`02ooooo`030:0Pl?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool000_ooooo00?o0000ooooooooool0:oooool3o`0001Sooooo00?o0000ooooooooool0;?ooool0
0`2P8?3oooooooooo`0Cooooo`80ogl000?oooooo`000?ooool00_ooool00`2P8?3ooooo0?mo0003
ooooo`030?mo0?oooooooooo00Cooooo00<0ogl0ooooooooool02?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo07Gooooo00<0ogl0ooooo`2P8?001_ooool00`3oO`3oooooooooo`03
ooooo`030?mo0?oooooooooo00?ooooo00<0ogl0ooooooooool01Oooool00`3oO`3ooooo0?mo000;
ooooo`030?mo0?oooooooooo00oooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000oooo
ooooool09oooool4o`0001_ooooo00?o0000ooooooooool0;_ooool0102P8?3oooooooooo`2P8?02
ooooo`040?mo002P8?00X23`0:0Pl0;ooooo00<0ogl0ooooooooool01?ooool01P3oO`3ooooooooo
o`3oO`3oooooo`0000?ooooo00<0X23`ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo07Oooooo00D0X23`ooooo`2P8?3ooooo0:0Pl007ooooo`030:0Pl?ooool0X23`
00cooooo00D0X23`oooooooooooooooo0?mo0003ooooo`80ogl01oooool00`2P8?3oooooooooo`02
ooooo`030:0Pl?oooooooooo00Oooooo00?o0000ooooooooool02?ooool000_ooooo00?o0000oooo
ooooool09?ooool3o`0001oooooo00?o0000ooooooooool0<Oooool01`2P8?3ooooo0:0Pl?ooool0
ogl0ooooo`2P8?000_ooool01`3oO`3ooooo0:0Pl?ooool0ogl0ooooo`3oO`001_ooool02?l0003o
ooooooooo`3oO`3ooooo0?mo0?ooool0X23`0_ooool20:0Pl0030?mo0?oooooooooo00cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1eooooo`030?mo0?oooooooooo00Cooooo00P0
X23`ooooo`2P8?00ogl0ooooo`3oO`3ooooo0?mo00Wooooo00<0ogl0ooooooooool00_ooool0103o
O`3ooooo0?mo003oO`03ooooo`030?mo0?oooooooooo00?ooooo00<0ogl0ooooooooool03oooool0
0`2P8?3o0000ooooo`09ooooo`002oooool00ol0003oooooooooo`0Qooooo`?o00008_ooool00ol0
003oooooooooo`0gooooo`030:0Pl03oO`3ooooo00Gooooo00H0ogl00:0Pl?ooool0ogl0ooooo`2P
8?020?mo0003ooooool00000X23`00[ooooo00<0ogl0ooooooooool02oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo07[ooooo00<0X23`ooooooooool01Oooool00`2P8?3ooooooooo
o`03ooooo`040:0Pl?ooool0ogl0ooooo`80ogl000?ooooo0?mo0?ooool02?ooool00`3oO`3ooooo
ooooo`07ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`002oooool00ol0003oooooooooo`0Mooooo`Co00009Oooool00ol0003ooooooooo
o`0fooooo`040:0Pl?oooooooooo0:0Pl0Cooooo00<0ogl0ooooooooool01Oooool00`2P8?3ooooo
o`000003ooooo`80X23`0oooool00`3oO`3oooooooooo`04ooooo`030:0Pl?oooooooooo00Oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1nooooo`060?mo0?oooooooooo0?mo0?oo
ool0ogl00_ooool00`3oO`00X23`0:0Pl003ooooo`050?mo0?ooooooooooooooo`3oO`005_ooool0
0`2P8?3oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo
01[ooooo0ol0000Yooooo`03o`000?oooooooooo03;ooooo0P2P8?07ooooo`80X23`0oooool01@2P
8?3oooooooooo`3oO`00X23`00Cooooo00?o00000?mo0?ooool00oooool00`3oO`3oooooooooo`02
ooooo`80ogl00_ooool00`2P8?00ogl0ooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0N_ooool00`3oO`3oooooooooo`0:ooooo`030?mo0?oooooooooo00Cooooo00<0ogl0
ooooooooool00oooool01@3oO`3oooooooooo`2P8?00ogl000gooooo00<0X23`ooooooooool00P3o
O`07ooooo`03o`000?oooooooooo00Sooooo000;ooooo`03o`000?oooooooooo01Oooooo0ol0000/
ooooo`03o`000?oooooooooo047ooooo00<0X23`ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`030?mo0?oooooooooo00Gooooo00<0X23`ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo087ooooo00<0X23`ooooooooool00_ooool0103oO`3oooooooooo`3o
O`08ooooo`030:0Pl?ooool0ogl000Wooooo00L0X23`oooooooooooooooo0?mo0?ooool0X23`00go
oooo00?o0000ooooooooool02?ooool000[ooooo00?o0000ooooooooool05Oooool3o`0002oooooo
00?o0000ooooooooool0?Oooool00`2P8?00ogl00:0Pl009ooooo`040?mo0?oooooo00000?mo00;o
oooo00<0X23`0?mo0?ooool00_ooool00`3oO`3oooooooooo`03ooooo`040?mo0?ooool0ogl00?mo
00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1nooooo`030:0Pl?oooooooooo
0080X23`1_ooool00`2P8?3oooooooooo`0:ooooo`030:0Pl?oooooooooo00[ooooo00<0X23`oooo
ooooool00_ooool00`3oO`3oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo000:ooooo`03
o`000?oooooooooo017ooooo1?l0000booooo`03o`000?oooooooooo047ooooo00D0ogl0ooooo`2P
8?3ooooo0?mo0004ooooo`030:0Pl?oooooo000000Kooooo00D0ogl0oooooooooooooooo0?mo0003
ooooo`030?mo0?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1n
ooooo`030?mo0?oooooooooo0080X23`1Oooool00`2P8?3oooooooooo`02ooooo`040?mo0?ooool0
X23`0?mo00?ooooo00<0ogl0ooooooooool00P2P8?05ooooo`040:0Pl?oooooooooo0?mo00cooooo
00D0X23`ooooooooool0X23`o`00000:ooooo`002_ooool00ol0003oooooooooo`0>ooooo`?o0000
=_ooool00ol0003oooooooooo`14ooooo`030:0Pl?oooooooooo00;ooooo00D0ogl0oooooooooooo
ooooo`000005ooooo`<0X23`1?ooool0102P8?3oooooooooo`2P8?05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0QOooool00`3oO`3oooooooooo`04ooooo`040?mo0?oooooooooo
0?mo00;ooooo00<0ogl0ooooooooool00oooool01@3oO`3oooooooooooooool0X23`00?ooooo00@0
X23`ooooooooool0ogl03_ooool00ol0003oooooooooo`08ooooo`002_ooool00ol0003ooooooooo
o`0;ooooo`?o0000>?ooool00ol0003oooooooooo`0oooooo`030:0Pl03oO`3ooooo00cooooo00?o
00000?mo0?ooool00_ooool20?mo00Gooooo00<0ogl0ooooo`3oO`001oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo07oooooo00D0X23`oooooooooooooooo0:0Pl002ooooo`030?mo
0?oooooooooo01[ooooo00<0X23`ooooooooool00oooool01P2P8?3oooooooooooooool0ogl00:0P
l0?ooooo00?o0000ooooooooool02?ooool000[ooooo00?o0000ooooooooool01oooool4o`0003_o
oooo00?o0000ooooooooool0?Oooool01@2P8?3oooooooooooooool0ogl000?ooooo00<0X23`oooo
ooooool01oooool00ol00000ogl00?mo0005ooooo`80ogl000@0X23`ooooooooool0ogl01oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo07Wooooo00<0X23`ooooooooool01_ooool0
0`3oO`00X23`ooooo`03ooooo`030?mo0?ooool0ogl000Oooooo00H0X23`ooooo`2P8?00ogl0oooo
o`3oO`06ooooo`030?mo0?ooool0ogl000Cooooo00<0ogl0ooooo`3oO`001?ooool00`2P8?3ooooo
ooooo`02ooooo`030:0Pl?l0003ooooo00Wooooo000:ooooo`03o`000?oooooooooo00Cooooo0ol0
000oooooo`03o`000?oooooooooo04?ooooo00<0X23`ooooooooool01?ooool0103oO`3ooooooooo
o`2P8?02ooooo`04o`000?ooool0X23`0?mo00Sooooo00<0ogl0ooooooooool01Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo08;ooooo00<0X23`ooooooooool00_ooool0102P8?3o
ooooooooo`3oO`0@ooooo`030?mo0?oooooooooo0080ogl000?ooooo0?mo0?ooool02_ooool01P2P
8?3oooooooooooooool0X23`o`0000[ooooo0009ooooo`03o`000?oooooooooo00;ooooo0ol00012
ooooo`03o`000?oooooooooo04?ooooo00L0X23`oooooooooooooooo0?mo0?ooool0ogl000Oooooo
00Ko0000ooooooooool0ogl0ooooo`3oO`06ooooo`030?mo0?oooooooooo00Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`23ooooo`070:0Pl?ooool0ogl0ooooo`2P8?00ogl0oooo
o`020?mo0080X23`00Cooooo0:0Pl?ooool0ogl00_ooool00`2P8?00ogl0ooooo`0>ooooo`030?mo
0?oooooooooo00Oooooo00@0ogl0ooooo`2P8?3o00002_ooool000Wooooo00?o0000ooooool00000
0_l00015ooooo`03o`000?oooooooooo047ooooo00@0X23`ooooooooool0X23`1?ooool00`2P8?3o
oooo0?mo0002ooooo`060?mo0?ooool0ogl0ooooool00000ogl00_ooool0103oO`3oooooooooo`3o
O`03ooooo`030:0Pl?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`28ooooo`040:0Pl?oooooooooo0:0Pl0Kooooo00<0ogl0ooooooooool00_ooool01@2P8?3ooooo
ooooooooool0X23`01;ooooo00D0X23`ooooooooooooooooo`00000:ooooo`002Oooool2o`0004So
oooo00?o0000ooooooooool0A_ooool0203oO`3ooooo0:0Pl?ooool0ogl00:0Pl?ooool0X23`0ooo
ool01P3oO`3o0000ooooooooool0X23`0?mo00Cooooo00@0ogl0ooooo`2P8?00X23`1Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo08Kooooo00@0ogl0ooooooooool0ogl00oooool0
0`2P8?3ooooo0:0Pl0020:0Pl003ooooo`3oO`3ooooo00_ooooo00<0ogl0ooooooooool00_ooool0
1P3oO`3oooooooooo`2P8?3ooooo0?mo00Kooooo00<0X23`o`000?ooool02Oooool000_ooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0looooo`030:0Pl?oooooooooo00?ooooo00<0
X23`ooooooooool01?ooool00`2P8?3ooooo0?mo0002ooooo`030?mo0?oooooooooo00;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08Wooooo0P3o
O`02ooooo`030?mo0?ooool0ogl000Wooooo00<0ogl0ooooo`3oO`002?ooool0103oO`3ooooooooo
ooooool20?mo00Oooooo00<0X23`o`000?ooool02Oooool000cooooo0_l00015ooooo`03o`000?oo
oooooooo04Sooooo00<0X23`ooooo`2P8?001oooool00`3oO`00X23`o`000003ooooo`030?mo0?oo
ool0ogl000Gooooo00<0ogl0ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo07kooooo00<0ogl0ooooooooool01oooool00`2P8?3oooooooooo`08ooooo`030?mo0?oo
oooooooo00;ooooo00<0X23`0?mo0?ooool01_ooool00`3oO`3ooooo0?mo000>ooooo`03o`000?oo
oooooooo00Sooooo000>ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0B_ooool0
0`2P8?3oooooooooo`03ooooo`060?mo0?ooool0X23`0:0Pl?oooooo00000oooool00`3oO`3ooooo
0?mo0003ooooo`80ogl01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo08;ooooo
00H0ogl0ooooooooool0ogl0ooooo`3oO`03ooooo`030:0Pl?ooool0ogl00080ogl000Gooooo0:0P
l03oO`3ooooo0:0Pl002ooooo`030?mo0?oooooooooo00Cooooo00<0ogl0ooooooooool00_ooool0
1P3oO`3ooooo0:0Pl03oO`3ooooo0?mo00Wooooo00?o0000ooooooooool02?ooool000oooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`1;ooooo`050:0Pl?ooooooooooooooo`2P8?00
0oooool01P2P8?3oooooooooool0003ooooo0?mo00;ooooo0P3oO`001?ooool0X23`ooooo`3oO`04
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0ROooool20?mo00Cooooo00@0ogl0
ooooooooool0ogl01_ooool00`2P8?3oooooooooo`0Eooooo`030:0Pl?l0003ooooo00Wooooo000@
ooooo`;o0000@Oooool00ol0003oooooooooo`1;ooooo`<0X23`0_ooool0103oO`3ooooooooooooo
ool20?mo0003o`000?oooooooooo00?ooooo00<0ogl0ooooooooool01_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo08[ooooo00<0ogl0ooooo`2P8?000_ooool01P3oO`3ooooo0:0P
l03oO`3ooooo0?mo00Oooooo00P0ogl0ooooo`2P8?3ooooo0:0Pl?ooool0X23`0?mo00Gooooo00<0
ogl0ooooooooool00oooool0102P8?3ooooo0?mo0?l0000:ooooo`004_ooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo04Oooooo00<0X23`ooooooooool00oooool00`2P8?00ogl00:0P
l006ooooo`040?mo0?l0003ooooo0:0Pl080ogl00P2P8?001Oooool0X23`ooooooooool0ogl000;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2=ooooo`030?mo0?oooooooooo00;o
oooo00<0ogl0ooooooooool00oooool20?mo00;ooooo00<0ogl0ooooooooool02Oooool00`3oO`3o
oooo0:0Pl0020?mo00;ooooo00@0ogl0oooooooooooo00002_ooool001?ooooo0_l0000nooooo`03
o`000?oooooooooo04gooooo1@2P8?001oooool0ogl00:0Pl?ooool0ogl0ooooool000000P2P8?03
ooooo`040?mo002P8?3ooooo0?mo00?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`2Booooo`030?mo0?ooool0X23`00;ooooo00<0ogl0ooooooooool05Oooool0103oO`3ooooo0:0P
l?l0000:ooooo`005Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo04oooooo0`2P
8?02ooooo`80X23`00T0ogl0oooooooooooo00000?mo0?ooool0X23`0?mo0?ooool00P2P8?001@3o
O`3ooooooooooooooooo000001Cooooo00?o0000ooooooooool0R_ooool01`2P8?3oooooooooo`2P
8?3ooooo0:0Pl?ooool0103oO`04ooooo`040:0Pl?oooooooooo0?mo00Oooooo0P3oO`000oooool0
ogl0ooooo`04ooooo`060?mo0?ooooooooooooooo`3oO`3o00002_ooool001Kooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`1?ooooo`H0X23`0oooool00`3oO`00X23`o`0000030:0P
l0030?mo0?ooool0ogl000Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2=oooo
o`030:0Pl?ooool0X23`00;ooooo00@0X23`ooooo`2P8?00X23`1?ooool00`3oO`00X23`ooooo`0E
ooooo`03o`000?oooooooooo00Sooooo000Gooooo`;o0000>_ooool00ol0003oooooooooo`1?oooo
o`L0X23`00<0ogl00:0Pl02P8?000P2P8?001ol00000ogl0ooooo`3oO`3ooooo0:0Pl03oO`001?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09Cooooo00<0ogl0ooooo`3oO`000P2P
8?05ooooo`030?mo002P8?00ogl000?ooooo00H0ogl0ooooooooool0ogl0ooooo`3oO`02ooooo`03
0?mo0?oooooooooo00;ooooo00<0X23`o`000?ooool02Oooool001Wooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`1Aooooo`D0X23`0`3oO`00102P8?00ogl0o`00002P8?020?mo0003
ooooo`3oO`3ooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Aooooo`09
0:0Pl?oooooooooo0?mo0?ooool0ogl0ooooo`3oO`00X23`00Oooooo00<0X23`ooooooooool00_oo
ool00`2P8?3oooooooooo`03ooooo`030:0Pl?oooooooooo00;ooooo00<0ogl0o`000?ooool02Ooo
ool001[ooooo0_l0000gooooo`03o`000?oooooooooo05?ooooo0P2P8?00103oO`00X23`0?mo003o
O`02ooooo`030?mo0?l00000ogl000?ooooo00<0X23`0?mo0?ooool00_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo09;ooooo00<0X23`ooooo`2P8?002Oooool00`3oO`3ooooo0?mo
0002ooooo`80ogl000?ooooo0?mo0?ooool01Oooool01P3oO`3oooooooooo`3oO`3oooooo`0000[o
oooo000Looooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0EOooool0103oO`00X23`
0:0Pl02P8?02ooooo`080?mo002P8?3o00000?mo0?ooool0X23`ooooo`3oO`03ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0TOooool01@2P8?3ooooo0:0Pl?ooool0X23`00<0ogl0
0P2P8?000oooool0ogl0ooooo`020?mo00?ooooo00D0ogl0ooooo`3oO`00ogl0ooooo`020?mo0003
ooooo`2P8?3ooooo00Cooooo00<0X23`o`000?ooool02Oooool001gooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`1Hooooo`@0X23`0P3oO`000ol0003ooooo0:0Pl0020:0Pl0?ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`26ooooo`030?mo0?oooooooooo013ooooo
00@0ogl0ooooo`3oO`3ooooo0P3oO`03ooooo`030?mo0?oooooooooo00Gooooo00<0X23`oooooooo
ool01?ooool00`2P8?3o0000ooooo`09ooooo`007_ooool2o`0003?ooooo00?o0000ooooooooool0
EOooool20:0Pl009ooooo`2P8?00ogl00:0Pl03oO`3ooooo0:0Pl?oooooo000000;ooooo00D0ogl0
ooooo`3oO`3oooooo`00000Cooooo`03o`000?oooooooooo09Cooooo00<0X23`ooooo`2P8?000ooo
ool01@3oO`00X23`ooooo`3oO`3ooooo0080ogl000?ooooo0?mo0?ooool00`3oO`001_ooool0ogl0
ooooo`3oO`3ooooo0:0Pl0;ooooo00@0X23`0?mo002P8?3o00002_ooool0023ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Iooooo`040:0Pl03oO`00X23`0:0Pl0;ooooo00?o0000
0?mo0?ooool00_ooool20:0Pl003ooooool0003ooooo017ooooo00?o0000ooooooooool0Toooool0
1@3oO`3oooooooooo`2P8?00ogl000?ooooo00<0ogl00:0Pl?ooool03?ooool00`3oO`3ooooo0?mo
0004ooooo`030:0Pl?l0003ooooo00Wooooo000Qooooo`;o0000<?ooool00ol0003oooooooooo`1H
ooooo`030:0Pl?oooooooooo00;ooooo00@0X23`oooooooooooo00000oooool20:0Pl003ooooool0
003ooooo017ooooo00?o0000ooooooooool0U?ooool00`3oO`3oooooooooo`030:0Pl004ooooo`3o
O`00ogl0ooooo`@0X23`00[ooooo0:0Pl03oO`3ooooo0?mo0?ooool0X23`ooooo`2P8?3ooooo0P2P
8?001Oooool0ogl00:0Pl02P8?3o000000[ooooo000Sooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0F_ooool00`2P8?3ooooo0:0Pl002ooooo`040?mo0?ooooooooooo`000080ogl0
0P2P8?000ooooooo0000ooooo`0Aooooo`03o`000?oooooooooo09;ooooo00<0ogl0ooooooooool0
0_ooool01P3oO`00X23`0:0Pl?ooool0X23`0?mo00;ooooo00D0X23`oooooooooooooooo0?mo0003
ooooo`040:0Pl?oooooooooo0?mo00Oooooo00?o0000ooooooooool02?ooool002Cooooo0_l0000/
ooooo`03o`000?oooooooooo05_ooooo00@0X23`oooooooooooooooo0P2P8?02ooooo`03o`00003o
O`3ooooo0080X23`00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Eooooo`050:0Pl?oo
ooooooooooooo`2P8?001?ooool20?mo0080X23`00?ooooo0?mo0?ooool00_ooool00`2P8?3ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0Goooool30:0Pl003ooooo`3oO`3o00000080ogl000<0X23`o`000?ooool04Ooo
ool00ol0003oooooooooo`2Booooo`<0ogl00oooool50:0Pl003ooooo`3oO`00ogl00080ogl00ooo
ool40:0Pl0030?mo002P8?00ogl00080ogl000Gooooo0:0Pl?ooool0X23`o`00000:ooooo`009ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo067ooooo00D0X23`0?mo0?ooool0ogl0
o`0000020?mo0003o`000?oooooooooo013ooooo00?o0000ooooooooool0U?ooool00`3oO`3ooooo
ooooo`02ooooo`060:0Pl?ooool0X23`0:0Pl03oO`00X23`1?ooool0102P8?3oooooooooo`3oO`05
ooooo`030:0Pl03oO`3ooooo00;ooooo00<0X23`o`000?ooool02Oooool002Sooooo0_l0000Xoooo
o`03o`000?oooooooooo067ooooo00D0X23`ooooo`2P8?3oooooo`0000020?mo0003o`000?oooooo
oooo013ooooo00?o0000ooooooooool0UOooool01@3oO`3ooooo0?mo0?ooool0ogl000L0X23`103o
O`001?ooool0X23`0?mo0?ooool20:0Pl0<0ogl000Gooooo0:0Pl02P8?00X23`o`00000:ooooo`00
:_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo063ooooo00@0X23`ooooooooool0
X23`0_ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo09_ooooo00H0X23`0?mo
002P8?00ogl0ooooo`2P8?06ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool00_oo
ool00`3oO`3o0000ooooo`09ooooo`00:oooool2o`0002Gooooo00?o0000ooooooooool0Ioooool0
0ol0003oooooo`00000Aooooo`03o`000?oooooooooo09[ooooo0`3oO`040:0Pl0040?mo002P8?00
ogl00?mo00Oooooo00<0ogl0ooooooooool00_ooool00`3oO`3o0000ooooo`09ooooo`00;Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06Sooooo0_l0000Aooooo`03o`000?oooooo
oooo09Wooooo00@0ogl0ooooooooool0ogl0102P8?02ooooo`040:0Pl03oO`00ogl00:0Pl080ogl0
0_ooool0202P8?00ogl0ooooooooool0ogl0ooooo`3oO`3o00002_ooool002kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1Wooooo`?o00004Oooool00ol0003oooooooooo`2Koooo
o`070?mo0?oooooooooo0?mo002P8?00ogl0ooooo`020:0Pl0;ooooo00D0X23`ooooo`2P8?3ooooo
0?mo0004ooooo`040?mo0?ooooooooooo`0000[ooooo000_ooooo`;o00008Oooool00ol0003ooooo
ooooo`1Rooooo`03o`00002P8?3o000000;o00005?ooool00ol0003oooooooooo`2Jooooo`050?mo
0?ooooooooooooooo`3oO`000`2P8?000oooool0ogl0ooooo`020:0Pl009ooooo`3oO`00X23`0?mo
0?ooool0ogl0ooooo`2P8?00ogl000;ooooo00?o0000ooooooooool02?ooool0037ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1Nooooo`Co00006Oooool00ol0003oooooooooo`2R
ooooo`030:0Pl?ooool0X23`00;ooooo00@0ogl00:0Pl?ooool0ogl00_ooool01P3oO`3ooooooooo
ooooool0ogl0o`0000[ooooo000booooo`;o00007_ooool00ol0003oooooooooo`1Jooooo`Co0000
7Oooool00ol0003oooooooooo`2Kooooo`030?mo0?oooooooooo00Cooooo0P2P8?030?mo0003oooo
o`2P8?00X23`00Sooooo00?o0000ooooooooool02?ooool003Cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1Eooooo`Go00008Oooool00ol0003oooooooooo`2Jooooo`050?mo0?oo
ooooooooooooo`3oO`001?ooool20?mo00060:0Pl?ooool0ogl00:0Pl?ooool0ogl00_ooool01P2P
8?3ooooo0?mo003oO`3oooooo`0000[ooooo000eooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0DOooool4o`0002Kooooo00?o0000ooooooooool0YOooool01P2P8?3oooooooooo`2P
8?3ooooo0:0Pl0Cooooo00@0ogl0oooooooooooo00002_ooool003Kooooo0_l0000Jooooo`03o`00
0?oooooooooo04gooooo1?l0000Zooooo`03o`000?oooooooooo0:3ooooo00<0ogl00:0Pl03oO`00
1oooool00`2P8?3oooooooooo`04ooooo`030?mo0?l0003ooooo00Wooooo000hooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0B?ooool5o`0002kooooo00?o0000ooooooooool0Z?oo
ool00`2P8?3oooooooooo`02ooooo`030?mo0?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool003Wooooo0_l0000Gooooo`03o`000?oooooooooo04Cooooo1?l0000cooooo`03o`000?oooooo
oooo0:Kooooo00<0ogl0ooooo`2P8?000P2P8?00203oO`3oooooooooooooool0ogl0ooooo`2P8?3o
00002_ooool003_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`10ooooo`Co0000
=oooool00ol0003oooooooooo`2Sooooo`030?mo0?oooooooooo00Cooooo00<0X23`ooooo`2P8?00
1?ooool00`2P8?3o0000ooooo`09ooooo`00??ooool2o`0001Cooooo00?o0000ooooooooool0>ooo
ool5o`0003_ooooo00?o0000ooooooooool0Z?ooool00`2P8?3oooooooooo`06ooooo`030:0Pl?l0
003ooooo00Wooooo000nooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0=oooool4
o`00043ooooo00?o0000ooooooooool0Z_ooool00`2P8?3oooooooooo`03ooooo`80X23`00?o0000
ooooooooool02?ooool003oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0boooo
o`Go0000A?ooool00ol0003oooooooooo`2Xooooo`030?mo0?ooool0X23`00Kooooo00<0X23`o`00
0?ooool02Oooool0043ooooo0_l0000@ooooo`03o`000?oooooooooo02kooooo1?l00019ooooo`03
o`000?oooooooooo0:[ooooo00<0X23`ooooo`3oO`000P3oO`02ooooo`030:0Pl?l0003ooooo00Wo
oooo0012ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:_ooool4o`0004gooooo
00?o0000ooooooooool0[?ooool01`3oO`3oooooooooooooool0ogl0ooooool000002_ooool004?o
oooo0_l0000<ooooo`03o`000?oooooooooo02Kooooo1Ol0001Aooooo`03o`000?oooooooooo0:_o
oooo00<0X23`ooooo`3oO`001?ooool00ol0003oooooooooo`08ooooo`00AOooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0001Fooooo`03o`000?oooooooooo0:gooooo
00<0ogl0ooooo`3oO`000P3oO`000ol0003oooooooooo`08ooooo`00A_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01kooooo1?l0001Joooook7o00000P3oO`03o`0000[ooooo0017
ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Go0000oooooolAooooo`80ogl000<0X23`
ooooooooool02Oooool004Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eoooo
o`Co0000oooooolTooooo`00B_ooool2o`0000Gooooo00?o0000ooooooooool04Oooool4o`000?oo
oooo:?ooool004cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`Go0000
ooooool/ooooo`00COooool01Ol0003ooooooooooooooooo000000[ooooo1?l0003ooooooc7ooooo
001>ooooo`;o000000?oooooo`000?ooool01Oooool4o`000?oooooo=Oooool0053ooooo0_l00000
0ooooooo0000o`000003o`000?oooooo>Oooool0057ooooo0_l0003oooooockooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0500105, -0.0544783, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {422.812, 226.375}} -> {-13.5849, \
-25.7573, 1.41129, 1.41129}, {{208.5, 389.438}, {422.812, 226.375}} -> \
{-294.432, -25.7573, 1.41129, 1.41129}, {{9.5, 190.438}, {206.75, 10.3125}} -> \
{0.00361344, -1.07331, 0.00473966, 0.00473966}, {{208.5, 389.438}, {206.75, \
10.3125}} -> {-294.432, -330.684, 1.41129, 1.41129}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2d Gaussian classification (RG plane)", "Section"],

Cell[CellGroupData[{

Cell["Visualize distributions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(which = {1, 2};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Show[gobj1, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Show[gobj2, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(gbase = Show[g1, g2, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{g1, g2}], \ imSize, \ yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.96078 .96078 Mdot
.71373 .72157 Mdot
.52941 .52549 Mdot
.13725 .14902 Mdot
.87843 .88235 Mdot
.11373 .1098 Mdot
.1098 .11373 Mdot
.77647 .78039 Mdot
.15294 .14902 Mdot
.13725 .12549 Mdot
.13333 .1451 Mdot
.1451 .13333 Mdot
.20784 .18824 Mdot
.17255 .15686 Mdot
.4902 .49804 Mdot
.1451 .13333 Mdot
.26275 .23137 Mdot
.23529 .21569 Mdot
.47451 .48235 Mdot
.89804 .82745 Mdot
1 .96863 Mdot
.13333 .12941 Mdot
.20784 .18824 Mdot
.24706 .20784 Mdot
.11373 .11765 Mdot
.3451 .16863 Mdot
.49804 .32941 Mdot
.65098 .53725 Mdot
.84314 .74902 Mdot
.94902 .89412 Mdot
.1451 .14118 Mdot
.18431 .16863 Mdot
.20392 .17647 Mdot
.20784 .20784 Mdot
.55294 .39216 Mdot
.41176 .14118 Mdot
.42353 .22745 Mdot
.36078 .2 Mdot
.38824 .25882 Mdot
.21569 .19608 Mdot
.21569 .20392 Mdot
.18824 .16863 Mdot
.22353 .20784 Mdot
.25098 .25098 Mdot
.52941 .17647 Mdot
.47843 .16863 Mdot
.41961 .19608 Mdot
.44706 .25882 Mdot
.33725 .17647 Mdot
.1451 .12941 Mdot
.14902 .11765 Mdot
.17647 .1451 Mdot
.24706 .23529 Mdot
1 .93725 Mdot
.58824 .18824 Mdot
.51373 .18039 Mdot
.45882 .22353 Mdot
.43137 .21569 Mdot
.43529 .26667 Mdot
.15686 .13725 Mdot
.21961 .19216 Mdot
.18039 .14902 Mdot
.26667 .26667 Mdot
1 .96471 Mdot
.77647 .36078 Mdot
.61176 .25882 Mdot
.45098 .2 Mdot
.4549 .25882 Mdot
.42745 .18824 Mdot
.18039 .14902 Mdot
.25098 .20784 Mdot
.14902 .11765 Mdot
.21961 .2 Mdot
.50196 .50196 Mdot
.73725 .32157 Mdot
.58039 .21176 Mdot
.4549 .18431 Mdot
.51765 .32157 Mdot
.46275 .18431 Mdot
.21176 .11765 Mdot
.18824 .15294 Mdot
.19608 .16471 Mdot
.18431 .16471 Mdot
.16471 .16078 Mdot
.82353 .72549 Mdot
.65882 .25098 Mdot
.53725 .16863 Mdot
.54118 .28627 Mdot
.54118 .34118 Mdot
.50588 .18824 Mdot
.23137 .07059 Mdot
.16471 .13725 Mdot
.23922 .21176 Mdot
.25882 .24706 Mdot
.14118 .13725 Mdot
.52941 .44314 Mdot
.37255 .12549 Mdot
.57647 .18824 Mdot
.5451 .17255 Mdot
.77255 .5451 Mdot
.64706 .43922 Mdot
.52549 .17255 Mdot
.28235 .09804 Mdot
.16863 .14118 Mdot
.27843 .25098 Mdot
.18431 .18039 Mdot
.15294 .10588 Mdot
.2902 .17255 Mdot
.96078 .92549 Mdot
.63922 .23922 Mdot
.54902 .16471 Mdot
.55686 .2 Mdot
.58039 .38039 Mdot
.49804 .2549 Mdot
.67059 .27059 Mdot
.23529 .11765 Mdot
.17255 .14118 Mdot
.22353 .21176 Mdot
.16863 .14902 Mdot
.29804 .12157 Mdot
.33725 .22353 Mdot
.8902 .82353 Mdot
.62353 .22353 Mdot
.56471 .16471 Mdot
.58824 .15686 Mdot
.55294 .33725 Mdot
.71373 .49412 Mdot
.53725 .2 Mdot
.5098 .2549 Mdot
.2 .13725 Mdot
.18431 .1451 Mdot
.18039 .14902 Mdot
.20392 .01961 Mdot
.67059 .51373 Mdot
.35294 .24706 Mdot
.88627 .83529 Mdot
.63137 .21961 Mdot
.59216 .16078 Mdot
.64706 .18039 Mdot
.78431 .55294 Mdot
.83137 .61569 Mdot
.67059 .41176 Mdot
.47451 .24706 Mdot
.27059 .15686 Mdot
.2 .13725 Mdot
.19216 .1098 Mdot
.33725 .10196 Mdot
.63529 .47843 Mdot
.61569 .50196 Mdot
.34902 .23529 Mdot
1 .97255 Mdot
.63137 .19216 Mdot
.64314 .17647 Mdot
.67059 .2 Mdot
.80392 .57255 Mdot
.41961 .21176 Mdot
.68627 .47059 Mdot
.8 .62745 Mdot
.25098 .12549 Mdot
.21961 .11765 Mdot
.26275 .08235 Mdot
.42745 .18039 Mdot
.66275 .52549 Mdot
.61569 .5098 Mdot
.41569 .29412 Mdot
.76078 .7098 Mdot
.53333 .19608 Mdot
.72549 .25882 Mdot
.66275 .19216 Mdot
.64314 .19216 Mdot
.83529 .63922 Mdot
.67059 .43922 Mdot
.58431 .40392 Mdot
.52157 .39608 Mdot
.37647 .18431 Mdot
.28235 .09412 Mdot
.49412 .18039 Mdot
.46667 .27451 Mdot
.56471 .47451 Mdot
.6 .49412 Mdot
.50588 .40392 Mdot
.63137 .56078 Mdot
.44706 .16863 Mdot
.67451 .23137 Mdot
.90196 .44706 Mdot
.76471 .27451 Mdot
.90588 .65098 Mdot
.48235 .26667 Mdot
.93333 .76078 Mdot
.61569 .50588 Mdot
.59216 .40784 Mdot
.38431 .20392 Mdot
.61176 .2549 Mdot
.63922 .44314 Mdot
.72549 .60392 Mdot
.58824 .48627 Mdot
.64706 .54118 Mdot
.39608 .29412 Mdot
.78824 .74902 Mdot
.60784 .21569 Mdot
.73725 .38039 Mdot
.83922 .38824 Mdot
.83922 .34902 Mdot
.9451 .69412 Mdot
.57647 .35294 Mdot
.76471 .61569 Mdot
.66275 .54902 Mdot
.39608 .2549 Mdot
.56471 .38824 Mdot
.6549 .29804 Mdot
.62745 .41569 Mdot
.72549 .6 Mdot
.54902 .38824 Mdot
.61961 .51765 Mdot
.62745 .52941 Mdot
.34118 .23922 Mdot
.98039 .9098 Mdot
.71373 .2549 Mdot
.92157 .57255 Mdot
.67843 .25098 Mdot
.8549 .38824 Mdot
.98431 .74902 Mdot
.54118 .27843 Mdot
.72941 .60784 Mdot
1 .88627 Mdot
1 .89804 Mdot
.84706 .64314 Mdot
.63922 .32157 Mdot
.67059 .44314 Mdot
.68627 .5451 Mdot
.49804 .32941 Mdot
.61569 .51373 Mdot
.65882 .55294 Mdot
.27059 .17255 Mdot
.91373 .87843 Mdot
.64314 .18431 Mdot
.85098 .54902 Mdot
.8902 .59216 Mdot
.67059 .25882 Mdot
.82745 .41961 Mdot
1 .85098 Mdot
.95294 .78431 Mdot
.85098 .73333 Mdot
.83529 .71765 Mdot
.81961 .67059 Mdot
.53333 .22353 Mdot
.67451 .37647 Mdot
.47843 .2549 Mdot
.51373 .32549 Mdot
.53333 .35686 Mdot
.64314 .56078 Mdot
.63922 .5451 Mdot
.23922 .13333 Mdot
.92941 .89412 Mdot
.5451 .54118 Mdot
.38431 .38824 Mdot
.56078 .18824 Mdot
.69412 .26667 Mdot
.56863 .29412 Mdot
.84314 .56471 Mdot
.74118 .29412 Mdot
.77647 .43137 Mdot
.67451 .38431 Mdot
.75294 .63529 Mdot
.95686 .75686 Mdot
.50588 .3451 Mdot
.86275 .6549 Mdot
.47451 .16471 Mdot
.66667 .33725 Mdot
.64314 .4902 Mdot
.52157 .3098 Mdot
.63529 .4902 Mdot
.63137 .58431 Mdot
.63529 .54118 Mdot
.20784 .12549 Mdot
.93725 .90196 Mdot
.18431 .16863 Mdot
.21569 .20392 Mdot
.83137 .83137 Mdot
.74902 .25098 Mdot
.93725 .70196 Mdot
1 .86667 Mdot
.83529 .53333 Mdot
.77647 .3451 Mdot
.57647 .2549 Mdot
.69804 .38824 Mdot
.89804 .74118 Mdot
.91765 .58431 Mdot
.98431 .79216 Mdot
.90196 .66667 Mdot
.48235 .18039 Mdot
.53333 .21569 Mdot
.55686 .43529 Mdot
.5098 .2902 Mdot
.61961 .47059 Mdot
.60392 .58824 Mdot
.61569 .5451 Mdot
.31373 .22353 Mdot
.66275 .60392 Mdot
.11373 .1098 Mdot
.24706 .21569 Mdot
.23137 .21961 Mdot
.86275 .76863 Mdot
.73333 .23529 Mdot
.98431 .84314 Mdot
.95686 .84706 Mdot
.66667 .3098 Mdot
.94902 .49412 Mdot
.61176 .26667 Mdot
.81569 .4902 Mdot
.86667 .68627 Mdot
.7451 .33333 Mdot
.9098 .67059 Mdot
.77647 .53725 Mdot
.56078 .25882 Mdot
.48235 .17255 Mdot
.58431 .47843 Mdot
.50196 .23529 Mdot
.56471 .41176 Mdot
.47843 .48235 Mdot
.61961 .56863 Mdot
.52941 .41176 Mdot
.22745 .15294 Mdot
.71373 .71765 Mdot
.27059 .25098 Mdot
.30196 .26667 Mdot
.1098 .1098 Mdot
.66275 .23529 Mdot
.6 .27059 Mdot
.98431 .85098 Mdot
.72157 .59608 Mdot
.8 .28627 Mdot
.95294 .48627 Mdot
.71373 .29804 Mdot
.80784 .52941 Mdot
.78039 .43922 Mdot
.86667 .49804 Mdot
.92157 .62745 Mdot
.82745 .56863 Mdot
.69412 .30196 Mdot
.81569 .63922 Mdot
.47451 .27059 Mdot
.5451 .22353 Mdot
.65098 .60784 Mdot
.42353 .41961 Mdot
.58039 .52157 Mdot
.51373 .38039 Mdot
.19216 .12157 Mdot
.12157 .12157 Mdot
.21176 .18039 Mdot
.21961 .17647 Mdot
.15294 .14118 Mdot
.59608 .21176 Mdot
.65882 .35294 Mdot
.83922 .68627 Mdot
.78431 .67059 Mdot
.80784 .32157 Mdot
.83137 .32549 Mdot
.9451 .51373 Mdot
.63922 .34902 Mdot
1 .78431 Mdot
.79608 .38824 Mdot
.64314 .29412 Mdot
.58431 .27843 Mdot
.60392 .25098 Mdot
.41176 .11765 Mdot
.41176 .24314 Mdot
.55294 .18824 Mdot
.40784 .27059 Mdot
.40392 .41569 Mdot
.52549 .46667 Mdot
.46667 .33725 Mdot
.4549 .3451 Mdot
.1098 .09804 Mdot
.22353 .20392 Mdot
.27843 .23529 Mdot
.27059 .2549 Mdot
.46667 .27843 Mdot
.6 .22353 Mdot
.76863 .60392 Mdot
.94902 .79216 Mdot
.64314 .4 Mdot
.81569 .30196 Mdot
.81569 .32157 Mdot
.74118 .47843 Mdot
.69804 .46667 Mdot
.75686 .29804 Mdot
.6902 .42353 Mdot
.69412 .34118 Mdot
1 .75686 Mdot
.59608 .16078 Mdot
.70588 .56471 Mdot
.54118 .19608 Mdot
.53333 .22353 Mdot
.49804 .50196 Mdot
.52549 .41569 Mdot
.4902 .40784 Mdot
.43922 .31765 Mdot
.34118 .30196 Mdot
.13333 .10196 Mdot
.21176 .18431 Mdot
.21961 .18431 Mdot
.35686 .36471 Mdot
.73333 .24706 Mdot
.83529 .65098 Mdot
.86275 .66667 Mdot
.8902 .77255 Mdot
.73333 .42353 Mdot
.83137 .28627 Mdot
.64706 .32941 Mdot
.70196 .60392 Mdot
.76078 .36471 Mdot
.70588 .41176 Mdot
.74118 .46275 Mdot
.61961 .38431 Mdot
.62353 .20784 Mdot
.47843 .13333 Mdot
.64706 .45098 Mdot
.55686 .18431 Mdot
.3451 .18824 Mdot
.43137 .38824 Mdot
.4549 .33725 Mdot
.49412 .40784 Mdot
.38039 .2902 Mdot
.18039 .15294 Mdot
.18431 .16471 Mdot
.20392 .17255 Mdot
.28627 .27451 Mdot
.56078 .41176 Mdot
.7451 .26275 Mdot
.90196 .73333 Mdot
.82353 .67451 Mdot
.83922 .70588 Mdot
.94118 .55686 Mdot
.78431 .33333 Mdot
.73333 .61569 Mdot
.63137 .53333 Mdot
.74118 .28235 Mdot
.63137 .4549 Mdot
.68627 .4902 Mdot
.57647 .34118 Mdot
.66275 .18824 Mdot
.52941 .26275 Mdot
.41569 .16863 Mdot
.4902 .18431 Mdot
.5451 .47843 Mdot
.6902 .58431 Mdot
.38431 .26275 Mdot
.43922 .35686 Mdot
.50588 .45098 Mdot
.17647 .14118 Mdot
.15294 .12549 Mdot
.15686 .12157 Mdot
.14118 .1451 Mdot
.63529 .24706 Mdot
.50196 .19216 Mdot
.6902 .5098 Mdot
.94118 .8 Mdot
.8 .68627 Mdot
.8 .28627 Mdot
.59216 .37647 Mdot
.63137 .58039 Mdot
.6902 .53333 Mdot
.74118 .28627 Mdot
.54902 .45882 Mdot
.58824 .46275 Mdot
.72157 .40784 Mdot
.66275 .21176 Mdot
.9098 .72157 Mdot
.5098 .21961 Mdot
.47451 .22353 Mdot
.67843 .64706 Mdot
.38039 .21176 Mdot
.52157 .38431 Mdot
.36471 .26667 Mdot
.13333 .09412 Mdot
.15294 .11765 Mdot
.22353 .19608 Mdot
.21961 .20392 Mdot
.81176 .80784 Mdot
.69412 .21176 Mdot
.9098 .74118 Mdot
.95294 .78824 Mdot
.82745 .67843 Mdot
1 .83922 Mdot
.72941 .31373 Mdot
.63529 .56863 Mdot
.61569 .57255 Mdot
.81961 .56471 Mdot
.66667 .28235 Mdot
.53725 .46667 Mdot
.52941 .45098 Mdot
.70196 .3098 Mdot
.63529 .25882 Mdot
.75294 .61961 Mdot
.5451 .24314 Mdot
.57647 .35686 Mdot
.54902 .53725 Mdot
.59608 .37647 Mdot
.49804 .32157 Mdot
.52549 .40392 Mdot
.1451 .11765 Mdot
.16471 .12941 Mdot
.19608 .16863 Mdot
.18824 .18431 Mdot
.44314 .21569 Mdot
.63137 .24706 Mdot
.96471 .79216 Mdot
.83922 .67451 Mdot
.83529 .70196 Mdot
.67451 .3098 Mdot
.65098 .45882 Mdot
.59216 .54902 Mdot
.60784 .56471 Mdot
.76471 .40392 Mdot
.56863 .29804 Mdot
.52941 .4902 Mdot
.61176 .4549 Mdot
.61176 .27843 Mdot
.60784 .31765 Mdot
.74118 .61176 Mdot
.49412 .2 Mdot
.58824 .38039 Mdot
.23922 .19608 Mdot
.5451 .31373 Mdot
.55294 .36471 Mdot
.38824 .28235 Mdot
.19216 .16471 Mdot
.15686 .12157 Mdot
.24314 .22353 Mdot
.12549 .10588 Mdot
.57647 .4549 Mdot
.7451 .25882 Mdot
.83922 .67451 Mdot
.61176 .43922 Mdot
.80392 .6549 Mdot
.89412 .70588 Mdot
.66667 .47059 Mdot
.63137 .58039 Mdot
.59608 .55294 Mdot
.81176 .59608 Mdot
.69804 .31373 Mdot
.54902 .50588 Mdot
.56078 .46275 Mdot
.54118 .24314 Mdot
.63137 .43529 Mdot
.83922 .7451 Mdot
.40392 .18431 Mdot
.4902 .19608 Mdot
.69412 .64706 Mdot
.54902 .37647 Mdot
.53725 .31373 Mdot
.59608 .48235 Mdot
.1451 .10588 Mdot
.26667 .23137 Mdot
.15294 .13333 Mdot
.17255 .14118 Mdot
.85882 .79216 Mdot
.68235 .23137 Mdot
.5451 .21569 Mdot
.70588 .51765 Mdot
.71373 .52941 Mdot
.92549 .8 Mdot
.64706 .33333 Mdot
.65882 .60392 Mdot
.61961 .57647 Mdot
.61961 .56078 Mdot
.72941 .37255 Mdot
.63137 .43529 Mdot
.52941 .4902 Mdot
.67451 .38824 Mdot
.57647 .45882 Mdot
.49804 .4 Mdot
.79216 .69804 Mdot
.43529 .20392 Mdot
.37647 .18431 Mdot
.24314 .2 Mdot
.59608 .42745 Mdot
.36863 .19216 Mdot
.77647 .70588 Mdot
.18039 .14902 Mdot
.24314 .2 Mdot
.15686 .12157 Mdot
.15686 .08627 Mdot
.8549 .79608 Mdot
.67843 .20784 Mdot
.65882 .27843 Mdot
.77255 .58431 Mdot
.76471 .58431 Mdot
.7451 .62353 Mdot
.58431 .32157 Mdot
.60392 .55294 Mdot
.68235 .63137 Mdot
.62353 .56863 Mdot
.76863 .4902 Mdot
.57255 .32549 Mdot
.54118 .49412 Mdot
.61176 .31765 Mdot
.54902 .46667 Mdot
.53333 .46275 Mdot
.74902 .67451 Mdot
.72941 .58824 Mdot
.36863 .20784 Mdot
.37255 .34902 Mdot
.47843 .36471 Mdot
.51765 .38039 Mdot
.79216 .72549 Mdot
.18824 .15294 Mdot
.32941 .27843 Mdot
.21569 .17647 Mdot
.18824 .11765 Mdot
.55686 .43922 Mdot
.84314 .73333 Mdot
.77255 .23529 Mdot
.38431 .17647 Mdot
.76471 .57647 Mdot
.75294 .58824 Mdot
.93725 .77647 Mdot
.68627 .56471 Mdot
.63922 .58824 Mdot
.67059 .63137 Mdot
.61569 .55686 Mdot
.7098 .36863 Mdot
.65098 .48235 Mdot
.57255 .47451 Mdot
.49412 .25098 Mdot
.52157 .47843 Mdot
.53333 .47843 Mdot
.67843 .60784 Mdot
.80392 .70196 Mdot
.2549 .16863 Mdot
.42353 .4 Mdot
.39216 .30196 Mdot
.64706 .54118 Mdot
.85882 .81961 Mdot
.17255 .13333 Mdot
.24706 .19216 Mdot
.2 .14902 Mdot
.62353 .53725 Mdot
.55686 .41569 Mdot
1 .96863 Mdot
.75294 .22745 Mdot
.56471 .22353 Mdot
.87059 .68235 Mdot
.6902 .53333 Mdot
.85882 .72549 Mdot
.68235 .51765 Mdot
.60784 .56471 Mdot
.78431 .7451 Mdot
.63137 .58824 Mdot
.76078 .56078 Mdot
.59608 .2902 Mdot
.56863 .48235 Mdot
.55686 .2902 Mdot
.54118 .49412 Mdot
.50588 .45882 Mdot
.54118 .48627 Mdot
.72549 .6549 Mdot
.77255 .6902 Mdot
.56078 .57647 Mdot
.48627 .38039 Mdot
.34902 .2549 Mdot
.8549 .81569 Mdot
.43137 .40784 Mdot
.20784 .15294 Mdot
.19216 .13333 Mdot
.46275 .40392 Mdot
.57255 .43137 Mdot
.5451 .43922 Mdot
.68627 .53725 Mdot
.75686 .21961 Mdot
.77647 .47059 Mdot
.87843 .68235 Mdot
.9098 .76863 Mdot
1 .87451 Mdot
.37647 .29412 Mdot
.59608 .55294 Mdot
.7098 .67059 Mdot
.61961 .58431 Mdot
.78824 .57255 Mdot
.59216 .30196 Mdot
.62745 .46667 Mdot
.57647 .4 Mdot
.52157 .47451 Mdot
.52157 .47451 Mdot
.52549 .47059 Mdot
.56863 .51373 Mdot
.83137 .76863 Mdot
.36863 .37647 Mdot
.57255 .45882 Mdot
.53725 .44706 Mdot
.87451 .84706 Mdot
.73725 .71765 Mdot
.18431 .13725 Mdot
.21961 .16863 Mdot
.42353 .35686 Mdot
.64314 .50196 Mdot
.56471 .46667 Mdot
.99216 .98039 Mdot
.68627 .18824 Mdot
.78039 .25098 Mdot
.84706 .51765 Mdot
.71373 .57647 Mdot
.93725 .67059 Mdot
.72549 .56471 Mdot
.61569 .57647 Mdot
.61961 .57647 Mdot
.82353 .78431 Mdot
.63529 .57647 Mdot
.73725 .34118 Mdot
.63137 .49412 Mdot
.56471 .28235 Mdot
.52941 .48235 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.53333 .48235 Mdot
.57647 .51765 Mdot
.77647 .78039 Mdot
.66667 .54902 Mdot
.5451 .46667 Mdot
.74118 .68627 Mdot
.8902 .89804 Mdot
.71373 .69804 Mdot
.56471 .52549 Mdot
.64314 .58039 Mdot
.49804 .38824 Mdot
.54902 .47451 Mdot
.3451 .26667 Mdot
.53333 .23529 Mdot
.77647 .25098 Mdot
.6902 .17647 Mdot
.93333 .7451 Mdot
.75686 .59608 Mdot
.75686 .45098 Mdot
.49804 .4549 Mdot
.61961 .56863 Mdot
.62745 .58431 Mdot
.6902 .6549 Mdot
.73725 .57647 Mdot
.6 .2549 Mdot
.76078 .47843 Mdot
.57647 .48235 Mdot
.52157 .48235 Mdot
.52941 .48235 Mdot
.52549 .47843 Mdot
.52157 .47843 Mdot
.58824 .52941 Mdot
.42353 .44314 Mdot
.8902 .74118 Mdot
.76471 .70196 Mdot
.86667 .8549 Mdot
.91765 .92549 Mdot
.8549 .8549 Mdot
.83529 .78431 Mdot
.35294 .24314 Mdot
.51373 .42745 Mdot
.6 .53333 Mdot
.4549 .43137 Mdot
.67451 .2 Mdot
.69804 .21176 Mdot
.78824 .27843 Mdot
.99216 .82353 Mdot
.70588 .38039 Mdot
.69804 .4902 Mdot
.44706 .40392 Mdot
.62745 .58431 Mdot
.61961 .57647 Mdot
.71373 .67451 Mdot
.80392 .55686 Mdot
.63922 .32549 Mdot
.62745 .31373 Mdot
.52549 .48627 Mdot
.5451 .50588 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.54902 .49412 Mdot
.58039 .53725 Mdot
.47451 .44314 Mdot
.83137 .76078 Mdot
.78431 .7451 Mdot
.9098 .9098 Mdot
.88235 .88627 Mdot
.90588 .90196 Mdot
.75686 .69804 Mdot
.47843 .33725 Mdot
.40784 .37647 Mdot
.6 .54902 Mdot
.81569 .72157 Mdot
.74118 .24706 Mdot
.78824 .2549 Mdot
.7451 .2902 Mdot
.52941 .2549 Mdot
.79216 .28627 Mdot
.61569 .54118 Mdot
.41569 .37255 Mdot
.61569 .57647 Mdot
.63922 .6 Mdot
.75686 .70588 Mdot
.7098 .36863 Mdot
.69804 .34118 Mdot
.67843 .46275 Mdot
.55686 .50196 Mdot
.52941 .4902 Mdot
.53725 .4902 Mdot
.53333 .4902 Mdot
.56471 .50196 Mdot
.76471 .77255 Mdot
.93333 .83922 Mdot
.85882 .82745 Mdot
.82353 .8 Mdot
.88627 .8902 Mdot
.87451 .8902 Mdot
.8549 .83137 Mdot
.49412 .40392 Mdot
.45882 .31765 Mdot
.41569 .39216 Mdot
.67451 .64706 Mdot
.56471 .23529 Mdot
.67843 .22745 Mdot
.78431 .24706 Mdot
.6549 .23922 Mdot
1 .65098 Mdot
.63529 .27843 Mdot
.60392 .56078 Mdot
.41176 .36863 Mdot
.61569 .57255 Mdot
.62353 .58039 Mdot
.80784 .72549 Mdot
.77255 .39608 Mdot
.71765 .31373 Mdot
.66275 .47451 Mdot
.56863 .49804 Mdot
.54118 .49804 Mdot
.53725 .49804 Mdot
.56078 .50588 Mdot
.57255 .5098 Mdot
.87843 .87843 Mdot
.66667 .54118 Mdot
.91765 .87843 Mdot
.8549 .85098 Mdot
.87059 .88235 Mdot
.88235 .89804 Mdot
.82353 .78039 Mdot
.50588 .38824 Mdot
.49804 .38824 Mdot
.43922 .41176 Mdot
.66275 .67451 Mdot
.66275 .23529 Mdot
.83529 .44314 Mdot
.7451 .25098 Mdot
.73725 .27843 Mdot
.83137 .35686 Mdot
.68235 .45098 Mdot
.60392 .56078 Mdot
.53725 .49804 Mdot
.63137 .58824 Mdot
.63922 .59608 Mdot
.92157 .76863 Mdot
.85882 .50196 Mdot
.75294 .34902 Mdot
.68627 .44706 Mdot
.63137 .51765 Mdot
.57647 .50588 Mdot
.55686 .50196 Mdot
.59608 .52549 Mdot
.78039 .74118 Mdot
.61176 .58431 Mdot
.64706 .53725 Mdot
.94118 .87059 Mdot
.8902 .87451 Mdot
.88235 .8902 Mdot
.87451 .88235 Mdot
.8 .74902 Mdot
.51373 .41569 Mdot
.4549 .35294 Mdot
.46275 .42353 Mdot
.97255 .97647 Mdot
.66667 .2 Mdot
.6902 .32941 Mdot
.69412 .27059 Mdot
.76863 .27059 Mdot
.81569 .28627 Mdot
.67451 .5451 Mdot
.60392 .56078 Mdot
.61569 .58824 Mdot
.63922 .58431 Mdot
.63529 .59216 Mdot
.95686 .70196 Mdot
.98039 .62353 Mdot
.82745 .44314 Mdot
.62353 .29412 Mdot
.67843 .47843 Mdot
.60784 .50588 Mdot
.61176 .54902 Mdot
.58039 .51373 Mdot
.84706 .81569 Mdot
.62745 .60392 Mdot
.41961 .27451 Mdot
.95686 .83529 Mdot
.95294 .9098 Mdot
.86275 .87843 Mdot
.86275 .87059 Mdot
.82745 .77647 Mdot
.61176 .54902 Mdot
.46275 .38431 Mdot
.45882 .40392 Mdot
.89804 .84314 Mdot
.72157 .25098 Mdot
.70588 .39216 Mdot
.56078 .23137 Mdot
.77647 .26667 Mdot
.78431 .27059 Mdot
.61961 .5451 Mdot
.61961 .56471 Mdot
.62745 .6 Mdot
.5451 .4902 Mdot
.64314 .58824 Mdot
.78431 .40392 Mdot
.83137 .45882 Mdot
.90588 .50588 Mdot
.64706 .2549 Mdot
.69804 .40784 Mdot
.65882 .50196 Mdot
.60392 .53333 Mdot
.77255 .73725 Mdot
.63137 .60784 Mdot
.63137 .6 Mdot
.44314 .27843 Mdot
.78824 .6549 Mdot
.94118 .86275 Mdot
.8902 .86275 Mdot
.8549 .84706 Mdot
.82353 .78431 Mdot
.66275 .61961 Mdot
.64314 .58824 Mdot
.47059 .43529 Mdot
.45098 .32157 Mdot
.72549 .25882 Mdot
.58824 .36471 Mdot
.67451 .47059 Mdot
.77647 .26667 Mdot
.7451 .29804 Mdot
.58824 .5451 Mdot
.6 .55686 Mdot
.61569 .58039 Mdot
.39608 .34118 Mdot
.65882 .56471 Mdot
.85882 .37255 Mdot
.66275 .24706 Mdot
.9098 .5098 Mdot
.77255 .36471 Mdot
.65098 .26667 Mdot
.71373 .47843 Mdot
.62745 .56471 Mdot
.77647 .75686 Mdot
.62745 .60784 Mdot
.62353 .59216 Mdot
.22745 .11765 Mdot
.62745 .49804 Mdot
.91765 .77255 Mdot
.92549 .8549 Mdot
.87451 .85098 Mdot
.83529 .81176 Mdot
.77255 .7451 Mdot
.82745 .79216 Mdot
.73333 .72157 Mdot
.49804 .26667 Mdot
.7098 .26667 Mdot
.8902 .73333 Mdot
.90196 .76078 Mdot
.79216 .26667 Mdot
.61961 .2902 Mdot
.60392 .56078 Mdot
.61961 .57647 Mdot
.61961 .58431 Mdot
.29412 .25098 Mdot
.71765 .53725 Mdot
.83922 .30196 Mdot
.65098 .19608 Mdot
.87843 .46275 Mdot
.8902 .43922 Mdot
.70196 .27451 Mdot
.58039 .33333 Mdot
.80784 .76471 Mdot
.63137 .61569 Mdot
.62745 .60392 Mdot
.66667 .62745 Mdot
.29412 .23922 Mdot
.87451 .76471 Mdot
.73333 .58431 Mdot
.92549 .81569 Mdot
.93725 .86667 Mdot
.85098 .81569 Mdot
.77255 .74902 Mdot
.8 .77647 Mdot
.69412 .70196 Mdot
.57647 .26667 Mdot
.65882 .24706 Mdot
.94118 .81569 Mdot
.63529 .47451 Mdot
.78431 .25098 Mdot
.71765 .50196 Mdot
.60392 .56078 Mdot
.62745 .58431 Mdot
.61176 .56863 Mdot
.36863 .32549 Mdot
.86275 .56078 Mdot
.8549 .30588 Mdot
.79608 .2902 Mdot
.75686 .31765 Mdot
.8549 .40784 Mdot
.82745 .41961 Mdot
.66275 .4549 Mdot
.72941 .68627 Mdot
.64314 .61961 Mdot
.63529 .60784 Mdot
.72157 .68627 Mdot
.84706 .82745 Mdot
.94902 .90588 Mdot
.69804 .60392 Mdot
.78824 .61569 Mdot
1 .8549 Mdot
.89412 .83137 Mdot
.80784 .77647 Mdot
.89804 .87059 Mdot
.64706 .65882 Mdot
.62745 .21569 Mdot
.69412 .38039 Mdot
.21569 .10196 Mdot
.57255 .30588 Mdot
.76471 .26667 Mdot
.61569 .54118 Mdot
.6 .55686 Mdot
.61176 .57647 Mdot
.6 .56471 Mdot
.43529 .37255 Mdot
.78824 .31373 Mdot
.83529 .29412 Mdot
.81961 .29804 Mdot
.67451 .21961 Mdot
.81569 .36863 Mdot
.87451 .46667 Mdot
.92549 .83922 Mdot
.63137 .6 Mdot
.64314 .61961 Mdot
.61569 .59216 Mdot
.17255 .14902 Mdot
.90196 .89804 Mdot
.93333 .89412 Mdot
.91765 .82745 Mdot
.58431 .39608 Mdot
.89412 .73725 Mdot
.93725 .84314 Mdot
.8 .76471 Mdot
.94902 .92157 Mdot
.90588 .86275 Mdot
.74118 .28235 Mdot
.55294 .34118 Mdot
.97647 .87059 Mdot
.65882 .29804 Mdot
.65882 .28627 Mdot
.6 .55686 Mdot
.60784 .56471 Mdot
.59608 .55294 Mdot
.60784 .57255 Mdot
.54902 .36471 Mdot
.72549 .27059 Mdot
.81961 .29412 Mdot
.83922 .30588 Mdot
.68235 .18824 Mdot
.80784 .39608 Mdot
.72941 .35686 Mdot
.64706 .59608 Mdot
.62353 .6 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.15686 .14118 Mdot
.92549 .89412 Mdot
.94118 .89804 Mdot
.96078 .9098 Mdot
.7451 .61569 Mdot
.67059 .45098 Mdot
.92549 .76471 Mdot
.87843 .80784 Mdot
.51765 .51373 Mdot
.60392 .41176 Mdot
.69804 .2902 Mdot
.82353 .68627 Mdot
.6549 .45098 Mdot
.70196 .23922 Mdot
.58039 .46667 Mdot
.60784 .56471 Mdot
.6 .55686 Mdot
.60784 .57255 Mdot
.61961 .57647 Mdot
.75686 .30588 Mdot
.60392 .23922 Mdot
.81176 .30196 Mdot
.82745 .28627 Mdot
.74902 .2549 Mdot
.81176 .38039 Mdot
.56471 .38039 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.61961 .59216 Mdot
.59608 .57647 Mdot
.96471 .9451 Mdot
.92157 .82353 Mdot
.93333 .90588 Mdot
.94902 .91765 Mdot
.92157 .78431 Mdot
.51765 .28235 Mdot
.8902 .81176 Mdot
.58039 .51373 Mdot
.97255 .98039 Mdot
.6902 .28235 Mdot
.68627 .41176 Mdot
.84314 .68627 Mdot
.90196 .60392 Mdot
.64706 .29412 Mdot
.6 .55686 Mdot
.61961 .56863 Mdot
.60784 .56471 Mdot
.61176 .56863 Mdot
.80392 .55686 Mdot
.62353 .2902 Mdot
.57647 .27451 Mdot
.8 .3098 Mdot
.83529 .28627 Mdot
.78039 .25882 Mdot
.68627 .26275 Mdot
.63137 .58431 Mdot
.61569 .59216 Mdot
.60784 .58824 Mdot
.61961 .60784 Mdot
.16471 .14118 Mdot
.97647 .87451 Mdot
.91373 .78431 Mdot
.92549 .91765 Mdot
.95686 .91373 Mdot
.97255 .8902 Mdot
.48627 .32941 Mdot
.64314 .5451 Mdot
.48627 .4902 Mdot
.33333 .25882 Mdot
.70196 .28627 Mdot
.55294 .28627 Mdot
.90588 .67451 Mdot
.63529 .16471 Mdot
.62745 .51373 Mdot
.60784 .55294 Mdot
.61569 .57255 Mdot
.61569 .57255 Mdot
.64706 .57647 Mdot
.80784 .30196 Mdot
.94118 .80392 Mdot
.58431 .29412 Mdot
.8 .32157 Mdot
.85098 .28235 Mdot
.81961 .28235 Mdot
.56863 .35294 Mdot
.60392 .58039 Mdot
.61176 .59216 Mdot
.62353 .60392 Mdot
.56863 .54118 Mdot
.98824 .92549 Mdot
.69804 .50588 Mdot
.96471 .89804 Mdot
.38431 .36471 Mdot
.91765 .89804 Mdot
.97255 .87059 Mdot
.90196 .81176 Mdot
.88235 .82745 Mdot
.97647 .98431 Mdot
.61176 .25882 Mdot
.58824 .23529 Mdot
.52157 .16471 Mdot
.55686 .16471 Mdot
.61961 .34118 Mdot
.31765 .26275 Mdot
.61961 .56471 Mdot
.60784 .57255 Mdot
.61961 .56471 Mdot
.7451 .32157 Mdot
.63137 .36471 Mdot
.9451 .84314 Mdot
.57255 .29804 Mdot
.83529 .30196 Mdot
.8549 .26667 Mdot
.74902 .34118 Mdot
.60784 .58431 Mdot
.62353 .60392 Mdot
.60392 .59216 Mdot
.6549 .63529 Mdot
.1098 .06275 Mdot
.56471 .36471 Mdot
.81176 .69412 Mdot
.59608 .57647 Mdot
.65882 .62745 Mdot
.9098 .8902 Mdot
.72549 .60392 Mdot
.57647 .52157 Mdot
.66667 .68627 Mdot
.41569 .3098 Mdot
.62353 .23529 Mdot
.59216 .16471 Mdot
.52549 .15294 Mdot
.74118 .28627 Mdot
.63922 .56863 Mdot
.6 .5451 Mdot
.61961 .57647 Mdot
.61569 .57255 Mdot
.78431 .53725 Mdot
.81176 .31373 Mdot
.95294 .81569 Mdot
.93725 .82745 Mdot
.66667 .29804 Mdot
.86275 .27451 Mdot
.82353 .27451 Mdot
.65098 .57255 Mdot
.62353 .60392 Mdot
.62745 .60392 Mdot
.61569 .60392 Mdot
.20392 .16471 Mdot
.51373 .34118 Mdot
.94902 .76471 Mdot
.10588 .06667 Mdot
.87451 .8549 Mdot
.52941 .5098 Mdot
.99608 .88627 Mdot
.52941 .48235 Mdot
.8549 .84706 Mdot
.77647 .76471 Mdot
.61961 .30196 Mdot
.73725 .26275 Mdot
.76078 .30196 Mdot
.79216 .28235 Mdot
.61961 .52549 Mdot
.29412 .23922 Mdot
.62353 .58039 Mdot
.60784 .57255 Mdot
.69412 .51765 Mdot
.83922 .27843 Mdot
.78431 .44706 Mdot
.94902 .83137 Mdot
.95294 .76471 Mdot
.86275 .27843 Mdot
.83529 .26667 Mdot
.69804 .57647 Mdot
.62353 .59608 Mdot
.60392 .59216 Mdot
.64314 .62353 Mdot
.16863 .12941 Mdot
.77255 .66275 Mdot
.70588 .47059 Mdot
.90196 .86667 Mdot
.87843 .85098 Mdot
.8 .76078 Mdot
.96078 .86667 Mdot
.87451 .83529 Mdot
.88627 .88627 Mdot
.97647 .97255 Mdot
.58039 .2902 Mdot
.74118 .25098 Mdot
.76863 .27059 Mdot
.77647 .28627 Mdot
.62745 .56078 Mdot
.40392 .34902 Mdot
.63137 .58824 Mdot
.61176 .57647 Mdot
.83922 .55686 Mdot
.83137 .27059 Mdot
.60392 .22353 Mdot
.95294 .82745 Mdot
1 .81961 Mdot
.8549 .27843 Mdot
.81176 .26667 Mdot
.63922 .57647 Mdot
.62745 .60784 Mdot
.61569 .60392 Mdot
.52549 .50588 Mdot
.21176 .14902 Mdot
.93333 .8 Mdot
.80392 .57647 Mdot
.58824 .5451 Mdot
.52157 .4902 Mdot
.66275 .63137 Mdot
1 .89804 Mdot
.75294 .72549 Mdot
.88627 .88235 Mdot
.82353 .75294 Mdot
.67451 .31765 Mdot
.77647 .25098 Mdot
.81569 .27843 Mdot
.73725 .52941 Mdot
.60392 .56078 Mdot
.4 .35686 Mdot
.61961 .58431 Mdot
.69804 .5451 Mdot
.82745 .28235 Mdot
.78824 .3098 Mdot
.57255 .27843 Mdot
.9098 .85098 Mdot
.82745 .30588 Mdot
.8549 .27843 Mdot
.61569 .42353 Mdot
.57255 .5451 Mdot
.43137 .41961 Mdot
.27843 .26667 Mdot
.21961 .17647 Mdot
.76078 .62745 Mdot
.92157 .72549 Mdot
.9098 .87843 Mdot
.68627 .66667 Mdot
.63137 .6 Mdot
.94118 .88235 Mdot
.93333 .83137 Mdot
.86275 .85882 Mdot
.96863 .97647 Mdot
.55686 .3098 Mdot
.64706 .18824 Mdot
.81569 .27843 Mdot
.74118 .4902 Mdot
.60392 .56078 Mdot
.34902 .30588 Mdot
.63137 .59608 Mdot
.7098 .53333 Mdot
.82745 .28235 Mdot
.75294 .34118 Mdot
.49804 .23137 Mdot
.90196 .8549 Mdot
.82353 .31765 Mdot
.83922 .26275 Mdot
.63529 .44706 Mdot
.27843 .25098 Mdot
.30196 .27843 Mdot
.4549 .44314 Mdot
.20784 .16471 Mdot
.36471 .23137 Mdot
.93333 .73725 Mdot
.8902 .87059 Mdot
.94118 .92157 Mdot
.97255 .95294 Mdot
.92549 .88235 Mdot
.96863 .84706 Mdot
.87451 .86667 Mdot
.96863 .97647 Mdot
.53725 .3451 Mdot
.72549 .22745 Mdot
.8 .29412 Mdot
.57647 .48627 Mdot
.6 .55686 Mdot
.25882 .21569 Mdot
.63922 .58431 Mdot
.72157 .28235 Mdot
.80392 .30196 Mdot
.76078 .61569 Mdot
.48235 .41176 Mdot
.99216 .83922 Mdot
.84706 .27451 Mdot
.75686 .28627 Mdot
.45882 .43529 Mdot
.55294 .53333 Mdot
.61176 .58824 Mdot
.59216 .56863 Mdot
.19608 .12549 Mdot
1 .8902 Mdot
.78431 .67451 Mdot
.24706 .21961 Mdot
.22745 .20784 Mdot
.6902 .67843 Mdot
.98824 .89412 Mdot
.90196 .84314 Mdot
.4 .43137 Mdot
.69412 .63529 Mdot
.69412 .31373 Mdot
.77647 .24706 Mdot
.70588 .49804 Mdot
.59608 .55294 Mdot
.62353 .58039 Mdot
.62745 .58431 Mdot
.82353 .42353 Mdot
.80784 .28235 Mdot
.94118 .86667 Mdot
.91765 .85882 Mdot
.91373 .83922 Mdot
.84706 .2902 Mdot
.81176 .28235 Mdot
.63529 .59608 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.59216 .56863 Mdot
.15294 .11373 Mdot
.87843 .74118 Mdot
.55686 .42745 Mdot
.81176 .78431 Mdot
.28627 .2549 Mdot
.2902 .27059 Mdot
.92157 .87843 Mdot
.81569 .69804 Mdot
.89412 .90588 Mdot
.73333 .69804 Mdot
.71765 .31373 Mdot
.76471 .25882 Mdot
.60392 .46667 Mdot
.59608 .55294 Mdot
.61961 .58039 Mdot
.63922 .54118 Mdot
.82353 .29804 Mdot
.70588 .3451 Mdot
.88235 .85882 Mdot
.91373 .83529 Mdot
.98824 .79608 Mdot
.84706 .26275 Mdot
.65882 .31765 Mdot
.58431 .56471 Mdot
.6 .57255 Mdot
.6 .58039 Mdot
.67451 .65098 Mdot
.98431 .90588 Mdot
.91373 .70588 Mdot
.95686 .91373 Mdot
.34902 .32157 Mdot
.97647 .94118 Mdot
.9451 .94118 Mdot
.93333 .87059 Mdot
.21176 .1451 Mdot
.46275 .5098 Mdot
.54118 .38039 Mdot
.76078 .30196 Mdot
.68235 .32549 Mdot
.54902 .4902 Mdot
.61176 .56863 Mdot
.37255 .32941 Mdot
.77255 .33333 Mdot
.81176 .30196 Mdot
.89412 .86667 Mdot
.93725 .83922 Mdot
.97255 .79216 Mdot
.83529 .29412 Mdot
.79608 .29412 Mdot
.62353 .58824 Mdot
.59608 .57255 Mdot
.59216 .57255 Mdot
.58431 .56078 Mdot
.13333 .07843 Mdot
.91765 .69412 Mdot
.67059 .56471 Mdot
.81961 .8 Mdot
.33725 .28627 Mdot
.5098 .4902 Mdot
.89412 .89412 Mdot
.36078 .25098 Mdot
.87059 .8902 Mdot
.92157 .85882 Mdot
.64706 .27843 Mdot
.68235 .2549 Mdot
.54902 .47451 Mdot
.59608 .56078 Mdot
.61176 .57255 Mdot
.77255 .31373 Mdot
.81176 .28627 Mdot
.87843 .84314 Mdot
.94902 .77647 Mdot
.85098 .51373 Mdot
.83529 .2902 Mdot
.79216 .29804 Mdot
.61569 .57255 Mdot
.61176 .59216 Mdot
.58431 .56471 Mdot
.59216 .57647 Mdot
.20392 .12941 Mdot
.74118 .49412 Mdot
.96471 .86667 Mdot
.59216 .56078 Mdot
.82353 .78039 Mdot
.50196 .48627 Mdot
.8902 .8902 Mdot
.32941 .22745 Mdot
.86667 .89412 Mdot
.88235 .78431 Mdot
.67451 .24706 Mdot
.70588 .45098 Mdot
.55686 .50588 Mdot
.60392 .57647 Mdot
.65098 .46667 Mdot
.82745 .27059 Mdot
.47451 .16078 Mdot
.89804 .86275 Mdot
.66667 .2549 Mdot
.72941 .3098 Mdot
.84706 .27843 Mdot
.61176 .40784 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.59608 .57647 Mdot
.16471 .12549 Mdot
.85882 .70196 Mdot
.67451 .44706 Mdot
.93725 .91765 Mdot
.48235 .44706 Mdot
.44314 .41569 Mdot
.89804 .89804 Mdot
.93725 .87451 Mdot
.53333 .4902 Mdot
.4902 .5451 Mdot
.62353 .30196 Mdot
.61176 .32157 Mdot
.56078 .47843 Mdot
.58824 .56078 Mdot
.7098 .52549 Mdot
.82353 .26667 Mdot
.63922 .25098 Mdot
.89804 .87059 Mdot
.75294 .36078 Mdot
.72941 .22353 Mdot
.83137 .27059 Mdot
.64706 .4549 Mdot
.61176 .58431 Mdot
.60392 .58039 Mdot
.6 .57647 Mdot
.17647 .13725 Mdot
.49412 .33725 Mdot
1 .80392 Mdot
.39216 .37255 Mdot
.9098 .86667 Mdot
.84706 .81961 Mdot
.90196 .90196 Mdot
.94118 .87843 Mdot
.54902 .51373 Mdot
.73725 .77647 Mdot
.83137 .55686 Mdot
.72157 .4902 Mdot
.56078 .44706 Mdot
.56863 .53333 Mdot
.8 .52549 Mdot
.81961 .26667 Mdot
.54118 .18431 Mdot
.88627 .84314 Mdot
.69412 .31765 Mdot
.81961 .30588 Mdot
.80784 .27843 Mdot
.67059 .57255 Mdot
.60392 .57647 Mdot
.59608 .57647 Mdot
.59608 .57255 Mdot
.21569 .16863 Mdot
.72941 .59608 Mdot
.60392 .42745 Mdot
.20784 .17647 Mdot
.40784 .36863 Mdot
.48235 .46275 Mdot
.89412 .89412 Mdot
.94902 .86667 Mdot
.88627 .87451 Mdot
.75686 .72941 Mdot
.63922 .38039 Mdot
.54118 .33725 Mdot
.56078 .46275 Mdot
.61569 .55686 Mdot
.78824 .29804 Mdot
.82353 .27059 Mdot
.94118 .73725 Mdot
.96471 .88235 Mdot
.63529 .28627 Mdot
.81176 .30196 Mdot
.62745 .32157 Mdot
.60392 .57647 Mdot
.62353 .58431 Mdot
.59216 .56863 Mdot
.52941 .51373 Mdot
.9451 .90588 Mdot
.6 .43922 Mdot
.96863 .9098 Mdot
.15294 .13725 Mdot
.54902 .51373 Mdot
.94902 .9451 Mdot
.90196 .88627 Mdot
.2549 .16471 Mdot
.33333 .37255 Mdot
.78431 .69412 Mdot
.72941 .53333 Mdot
.60392 .40784 Mdot
.56863 .49412 Mdot
.79216 .48235 Mdot
.82353 .27059 Mdot
.77255 .31373 Mdot
.92549 .82353 Mdot
.83137 .67059 Mdot
.59216 .23529 Mdot
.76078 .31373 Mdot
.61176 .58431 Mdot
.60784 .58039 Mdot
.61569 .59216 Mdot
.6 .56471 Mdot
.36078 .34118 Mdot
.97647 .88235 Mdot
.96078 .83922 Mdot
.44314 .42745 Mdot
.83922 .8 Mdot
.52157 .50588 Mdot
.89804 .89804 Mdot
.4 .30588 Mdot
.87451 .90196 Mdot
.38824 .39216 Mdot
.84706 .67843 Mdot
.70196 .47843 Mdot
.62745 .45098 Mdot
.63922 .48235 Mdot
.79608 .28235 Mdot
.81961 .27451 Mdot
.7098 .36471 Mdot
.92941 .83922 Mdot
.85098 .72157 Mdot
.79608 .32157 Mdot
.65098 .59608 Mdot
.59216 .57255 Mdot
.58039 .56078 Mdot
.56863 .55294 Mdot
.20392 .17255 Mdot
.94118 .88627 Mdot
.85098 .66275 Mdot
.78039 .73725 Mdot
.15686 .13333 Mdot
.55294 .52157 Mdot
.89412 .90196 Mdot
.97647 .91373 Mdot
.78431 .78431 Mdot
.83529 .83922 Mdot
.81569 .69804 Mdot
.86275 .67059 Mdot
.49412 .30196 Mdot
.62745 .46667 Mdot
.78824 .29804 Mdot
.82745 .28235 Mdot
.63137 .18431 Mdot
.97255 .81176 Mdot
.93725 .8549 Mdot
.77647 .33725 Mdot
.61961 .58039 Mdot
.61569 .59608 Mdot
.59216 .57255 Mdot
.56471 .5451 Mdot
.18824 .15686 Mdot
.93725 .87451 Mdot
.74902 .52941 Mdot
.98824 .94902 Mdot
.78039 .76471 Mdot
.26667 .24314 Mdot
.8902 .89804 Mdot
.99216 .92157 Mdot
.85098 .85882 Mdot
.73725 .73725 Mdot
.72157 .61569 Mdot
.8 .65098 Mdot
.43922 .31373 Mdot
.76078 .4549 Mdot
.77647 .28627 Mdot
.81961 .28627 Mdot
.68235 .22353 Mdot
.97647 .72941 Mdot
.97647 .80392 Mdot
.68627 .35686 Mdot
.61961 .59608 Mdot
.57255 .5451 Mdot
.47059 .45098 Mdot
.45882 .44314 Mdot
.93333 .91765 Mdot
.79216 .63529 Mdot
.55294 .40784 Mdot
.90196 .90196 Mdot
.91765 .9098 Mdot
.85882 .8549 Mdot
.89804 .8902 Mdot
.28627 .2 Mdot
.90196 .93333 Mdot
.63137 .58039 Mdot
.88235 .79216 Mdot
.86275 .76471 Mdot
.68627 .47059 Mdot
.70196 .27059 Mdot
.8 .29412 Mdot
.83529 .31373 Mdot
.60392 .20784 Mdot
.95294 .70196 Mdot
.71373 .36471 Mdot
.49412 .47059 Mdot
.2902 .26275 Mdot
.3451 .32549 Mdot
.47843 .47059 Mdot
.56863 .5451 Mdot
.94902 .82745 Mdot
.61961 .43529 Mdot
.92157 .8902 Mdot
.90588 .8902 Mdot
.78039 .78039 Mdot
.89804 .89804 Mdot
.43137 .34118 Mdot
.89412 .92157 Mdot
.66667 .63922 Mdot
.93725 .89804 Mdot
.55294 .42353 Mdot
.63529 .25098 Mdot
.77255 .30588 Mdot
.80784 .30196 Mdot
.76078 .27843 Mdot
.63137 .22353 Mdot
.71373 .37255 Mdot
.36471 .34118 Mdot
.41176 .37255 Mdot
.53725 .5098 Mdot
.67451 .65882 Mdot
.83529 .81961 Mdot
.93725 .81961 Mdot
.97647 .82353 Mdot
.96863 .87843 Mdot
.92549 .8902 Mdot
.61569 .61569 Mdot
.90196 .89412 Mdot
.2902 .19216 Mdot
.92157 .95294 Mdot
.98039 .97647 Mdot
.58039 .37255 Mdot
.61569 .23137 Mdot
.74118 .28627 Mdot
.80784 .30196 Mdot
.80392 .29412 Mdot
.71373 .28627 Mdot
.58039 .53333 Mdot
.59608 .56078 Mdot
.61176 .58824 Mdot
.57255 .55686 Mdot
.08627 .07059 Mdot
.94118 .87843 Mdot
.86667 .69412 Mdot
1 .88627 Mdot
.8902 .73725 Mdot
.9098 .90588 Mdot
.8902 .89804 Mdot
.96863 .87843 Mdot
.83922 .87059 Mdot
.79216 .69412 Mdot
.57255 .24706 Mdot
.69804 .26667 Mdot
.78824 .31765 Mdot
.81569 .30196 Mdot
.72549 .36471 Mdot
.57647 .55294 Mdot
.58431 .56078 Mdot
.57255 .55686 Mdot
.63529 .61569 Mdot
.64706 .63137 Mdot
.96078 .85882 Mdot
.77255 .59608 Mdot
.89804 .68627 Mdot
.62353 .44314 Mdot
.9098 .9098 Mdot
.89412 .88627 Mdot
.26275 .18039 Mdot
.9451 .96863 Mdot
.66275 .48627 Mdot
.60784 .26275 Mdot
.70588 .28235 Mdot
.79608 .29804 Mdot
.73725 .34118 Mdot
.58039 .5451 Mdot
.57647 .55294 Mdot
.56863 .5451 Mdot
.56078 .54118 Mdot
.23137 .20784 Mdot
.97255 .88627 Mdot
.63137 .45098 Mdot
.94902 .71373 Mdot
.56471 .33725 Mdot
.93725 .9451 Mdot
.8902 .89412 Mdot
.5098 .43529 Mdot
.91373 .93725 Mdot
.71373 .58431 Mdot
.58431 .27451 Mdot
.71373 .27451 Mdot
.76078 .30196 Mdot
.64314 .52549 Mdot
.56471 .54118 Mdot
.56471 .52941 Mdot
.55294 .52941 Mdot
.19216 .16078 Mdot
.9451 .87059 Mdot
.76078 .61176 Mdot
.86275 .69412 Mdot
.74902 .42353 Mdot
.52157 .52157 Mdot
.87451 .91765 Mdot
.93333 .87059 Mdot
.83529 .84314 Mdot
.98824 .92941 Mdot
.54902 .3098 Mdot
.62745 .23529 Mdot
.70196 .29804 Mdot
.57647 .52157 Mdot
.56078 .52549 Mdot
.57647 .53333 Mdot
.54902 .52941 Mdot
.19608 .16078 Mdot
.65882 .5451 Mdot
.58824 .4549 Mdot
.48627 .2 Mdot
.62353 .45882 Mdot
.54902 .54902 Mdot
.71765 .76863 Mdot
.89412 .83529 Mdot
.86667 .89412 Mdot
.90588 .82353 Mdot
.53333 .27843 Mdot
.63529 .25882 Mdot
.60392 .54118 Mdot
.55686 .52549 Mdot
.56471 .52941 Mdot
.54118 .50588 Mdot
.20784 .16471 Mdot
.94118 .85882 Mdot
.82353 .68627 Mdot
.82353 .6549 Mdot
.56078 .35294 Mdot
.47059 .41961 Mdot
.40392 .46275 Mdot
.6 .52157 Mdot
.83137 .86667 Mdot
.93725 .82353 Mdot
.57255 .29412 Mdot
.59608 .52941 Mdot
.54902 .52941 Mdot
.53333 .51373 Mdot
.55294 .51765 Mdot
.22745 .18824 Mdot
.92157 .87843 Mdot
.77647 .65882 Mdot
.97647 .87843 Mdot
.63922 .36471 Mdot
.44314 .38039 Mdot
.57647 .58431 Mdot
.41961 .34902 Mdot
.83922 .86667 Mdot
.98431 .90196 Mdot
.90588 .84314 Mdot
.55686 .55294 Mdot
.52157 .5098 Mdot
.55686 .50588 Mdot
.22353 .17255 Mdot
.90196 .89804 Mdot
.5098 .43529 Mdot
.96078 .90196 Mdot
.73725 .33725 Mdot
.51765 .4902 Mdot
.61569 .54118 Mdot
.48627 .43137 Mdot
.83922 .8549 Mdot
.97647 .98824 Mdot
.75686 .76078 Mdot
.59608 .6 Mdot
.49804 .47451 Mdot
.53333 .46667 Mdot
.80392 .77647 Mdot
.92157 .8902 Mdot
.91765 .90196 Mdot
.41961 .23922 Mdot
.54902 .4 Mdot
.63137 .53725 Mdot
.4549 .40392 Mdot
.83137 .80392 Mdot
.87451 .90196 Mdot
.83137 .84706 Mdot
.63529 .65882 Mdot
.8 .6902 Mdot
.30588 .22353 Mdot
.94118 .91373 Mdot
.93725 .9098 Mdot
.91373 .8902 Mdot
.6902 .42353 Mdot
.57255 .55686 Mdot
.53725 .47451 Mdot
.70196 .63137 Mdot
.84314 .87843 Mdot
.98039 .99608 Mdot
.65098 .67059 Mdot
.63529 .52941 Mdot
.4902 .42353 Mdot
.94902 .89412 Mdot
.94118 .89804 Mdot
.92549 .8902 Mdot
.49412 .33333 Mdot
.69804 .68235 Mdot
.87059 .80784 Mdot
.81176 .77647 Mdot
.87059 .9098 Mdot
.86667 .83529 Mdot
.87059 .84314 Mdot
.72549 .66275 Mdot
.88235 .8 Mdot
.96863 .89804 Mdot
1 .91373 Mdot
.91765 .90588 Mdot
.7451 .69804 Mdot
.61961 .53725 Mdot
.83922 .87451 Mdot
1 .99216 Mdot
.84706 .84706 Mdot
.81961 .74902 Mdot
.62745 .53725 Mdot
.86667 .79216 Mdot
.97255 .9098 Mdot
.92941 .89804 Mdot
.48627 .42745 Mdot
.83529 .78431 Mdot
.87059 .92549 Mdot
.98824 .99216 Mdot
.85098 .84706 Mdot
.91765 .86275 Mdot
.66667 .59608 Mdot
.73725 .63529 Mdot
.95294 .87059 Mdot
.98824 .90588 Mdot
.79608 .71765 Mdot
.82745 .87059 Mdot
.99216 1 Mdot
.80784 .78039 Mdot
.92157 .87451 Mdot
.8549 .77647 Mdot
.61569 .5451 Mdot
.77255 .67059 Mdot
.49804 .43922 Mdot
.82353 .85882 Mdot
.98824 1 Mdot
.78824 .77255 Mdot
.82745 .79608 Mdot
.88235 .85098 Mdot
.82353 .78824 Mdot
.63922 .56863 Mdot
.85882 .83137 Mdot
.76078 .83529 Mdot
.62353 .62745 Mdot
.8 .79216 Mdot
.75294 .74902 Mdot
.75686 .76078 Mdot
.87451 .83922 Mdot
.84706 .83137 Mdot
.56863 .63137 Mdot
.96078 .96471 Mdot
.75294 .77255 Mdot
.8 .80392 Mdot
.87451 .87843 Mdot
.9451 .92941 Mdot
.92549 .92157 Mdot
.85098 .88235 Mdot
.8902 .90588 Mdot
.93725 .9451 Mdot
.99216 1 Mdot
.99216 .99216 Mdot
.98824 .99608 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.90588 .90588 Mdot
.49412 .4902 Mdot
.8 .8 Mdot
.17647 .16471 Mdot
.18039 .18431 Mdot
.13333 .11373 Mdot
.32157 .29412 Mdot
.36863 .37255 Mdot
.20784 .19216 Mdot
.28627 .25098 Mdot
.24314 .23922 Mdot
.21569 .2 Mdot
.26275 .21961 Mdot
.23529 .22353 Mdot
.17255 .16078 Mdot
.20392 .16863 Mdot
.3098 .27843 Mdot
.83922 .83922 Mdot
.2902 .2549 Mdot
.23922 .20392 Mdot
.2902 .27451 Mdot
1 .96471 Mdot
.79608 .7451 Mdot
.27451 .23137 Mdot
.26667 .22353 Mdot
.27059 .24314 Mdot
.9098 .81961 Mdot
.83529 .73333 Mdot
.72549 .51765 Mdot
.1451 .09412 Mdot
.18431 .14118 Mdot
.24706 .21176 Mdot
.16863 .15686 Mdot
.41569 .41569 Mdot
.55686 .55686 Mdot
.53725 .30196 Mdot
.64314 .4549 Mdot
.62353 .24706 Mdot
.15686 .08235 Mdot
.21569 .17647 Mdot
.27843 .25098 Mdot
.17647 .1451 Mdot
.90196 .85098 Mdot
.67451 .68235 Mdot
.11765 .11373 Mdot
.39216 .4 Mdot
.61176 .28627 Mdot
.60392 .40392 Mdot
.78431 .30196 Mdot
.25882 .09412 Mdot
.16863 .12941 Mdot
.25098 .22353 Mdot
.19216 .16078 Mdot
.34902 .23529 Mdot
.53725 .46275 Mdot
.85882 .76863 Mdot
.94902 .94902 Mdot
.1098 .10588 Mdot
.09412 .09804 Mdot
.83922 .83922 Mdot
.61176 .23922 Mdot
.67843 .42745 Mdot
.80784 .30588 Mdot
.21176 .0549 Mdot
.18824 .1451 Mdot
.24314 .22353 Mdot
.18824 .13333 Mdot
.47843 .30196 Mdot
.34902 .2 Mdot
.40392 .18431 Mdot
.55294 .43529 Mdot
.85098 .75294 Mdot
.99608 .95294 Mdot
.12549 .12157 Mdot
.22353 .22353 Mdot
.07059 .0902 Mdot
.71373 .27451 Mdot
.72549 .49804 Mdot
.74902 .30588 Mdot
.73725 .25098 Mdot
.22745 .12549 Mdot
.2 .15686 Mdot
.16078 .12941 Mdot
.22353 .02353 Mdot
.45882 .29412 Mdot
.43529 .2 Mdot
.35294 .16471 Mdot
.32941 .16863 Mdot
.37647 .27059 Mdot
.61176 .52941 Mdot
.89804 .81569 Mdot
1 1 Mdot
.10196 .10588 Mdot
.21961 .2 Mdot
.20392 .20392 Mdot
.31373 .32157 Mdot
.82353 .27451 Mdot
.56471 .2902 Mdot
.81961 .2902 Mdot
.83529 .36471 Mdot
.21961 .12157 Mdot
.20392 .16078 Mdot
.19216 .13725 Mdot
.54118 .27451 Mdot
.59608 .43922 Mdot
.55294 .24314 Mdot
.52157 .39216 Mdot
.32157 .17255 Mdot
.29804 .16078 Mdot
.31373 .16078 Mdot
.4902 .28627 Mdot
.61569 .59608 Mdot
.11373 .11765 Mdot
.26275 .25098 Mdot
.19216 .17255 Mdot
.0902 .09412 Mdot
.86275 .62745 Mdot
.69412 .22353 Mdot
.81961 .41569 Mdot
.86667 .30588 Mdot
.72941 .27059 Mdot
.25098 .12157 Mdot
.22745 .15686 Mdot
.27843 .08235 Mdot
.68235 .46275 Mdot
.53725 .37255 Mdot
.58431 .30196 Mdot
.72157 .57255 Mdot
.59216 .45882 Mdot
.4902 .32941 Mdot
.41176 .18431 Mdot
.40784 .18039 Mdot
.36471 .35294 Mdot
.12157 .12549 Mdot
.16078 .14902 Mdot
.16863 .14902 Mdot
.1098 .1098 Mdot
.82745 .28627 Mdot
.99216 .54118 Mdot
.80392 .26667 Mdot
.86667 .28627 Mdot
.69412 .2549 Mdot
.28627 .09804 Mdot
.2549 .09804 Mdot
.47843 .06667 Mdot
.51373 .31765 Mdot
.47843 .28627 Mdot
.42353 .23922 Mdot
.35686 .20392 Mdot
.71373 .55294 Mdot
.62745 .50196 Mdot
.48235 .15294 Mdot
.53333 .39216 Mdot
.39608 .39216 Mdot
.12549 .11373 Mdot
.13725 .11765 Mdot
.13725 .11765 Mdot
.09412 .10196 Mdot
.83922 .25098 Mdot
.84706 .32157 Mdot
.84706 .26667 Mdot
.8549 .2549 Mdot
.79608 .31373 Mdot
.34902 .07059 Mdot
.32157 .03137 Mdot
.77255 .27059 Mdot
.64706 .42745 Mdot
.49804 .26667 Mdot
.78431 .63922 Mdot
.30196 .16863 Mdot
.55294 .33725 Mdot
.64706 .54118 Mdot
.61961 .23529 Mdot
.55294 .44314 Mdot
.0549 .0549 Mdot
.12549 .11373 Mdot
.34902 .32941 Mdot
.1451 .12549 Mdot
.12549 .13333 Mdot
.86275 .27451 Mdot
.87059 .29804 Mdot
.85098 .2549 Mdot
.85098 .24706 Mdot
.87059 .32157 Mdot
.51373 .0902 Mdot
.50588 .08235 Mdot
.81176 .27451 Mdot
.64314 .38039 Mdot
.63922 .38039 Mdot
.68627 .54118 Mdot
.4 .25882 Mdot
.46667 .19216 Mdot
.67451 .56078 Mdot
.61176 .24706 Mdot
.55686 .45098 Mdot
.08627 .07843 Mdot
.12941 .12549 Mdot
.34118 .32157 Mdot
.11765 .10588 Mdot
.0902 .09804 Mdot
.86275 .27451 Mdot
.88627 .28235 Mdot
.85098 .24706 Mdot
.86667 .26275 Mdot
.93333 .35686 Mdot
.88235 .36863 Mdot
.85098 .34118 Mdot
.84314 .28627 Mdot
.60784 .34902 Mdot
.58431 .33725 Mdot
.67843 .54118 Mdot
.52549 .38431 Mdot
.51373 .2 Mdot
.72549 .61176 Mdot
.6 .28235 Mdot
.59216 .4902 Mdot
.12157 .11373 Mdot
.1451 .14118 Mdot
.29804 .28627 Mdot
.11373 .10196 Mdot
.07451 .07451 Mdot
.83922 .2902 Mdot
.8902 .28627 Mdot
.8902 .28627 Mdot
.88235 .27843 Mdot
.90196 .3098 Mdot
.92157 .36078 Mdot
.87059 .33333 Mdot
.89804 .30196 Mdot
.63922 .38431 Mdot
.59608 .37647 Mdot
.66275 .53333 Mdot
.38431 .23137 Mdot
.73333 .46275 Mdot
.67059 .52549 Mdot
.52941 .32941 Mdot
.58824 .44706 Mdot
.59608 .57255 Mdot
.14118 .13725 Mdot
.14118 .14118 Mdot
.09804 .09804 Mdot
.12941 .12549 Mdot
.81961 .82745 Mdot
.86275 .28235 Mdot
.87059 .27451 Mdot
.87843 .28235 Mdot
.88235 .28627 Mdot
.87059 .31765 Mdot
.91373 .36863 Mdot
.92157 .36863 Mdot
.86667 .27451 Mdot
.53725 .3098 Mdot
.54118 .36471 Mdot
.74902 .62745 Mdot
.53725 .41569 Mdot
.51373 .16863 Mdot
.69412 .56471 Mdot
.39608 .19608 Mdot
.35686 .23922 Mdot
.72941 .7098 Mdot
.12941 .12549 Mdot
.22745 .21569 Mdot
.21961 .21569 Mdot
.11373 .1098 Mdot
.52157 .52549 Mdot
.81961 .30196 Mdot
.86667 .28627 Mdot
.88235 .30588 Mdot
.87451 .29412 Mdot
.83137 .30196 Mdot
.89412 .40784 Mdot
.92549 .38039 Mdot
.90588 .31373 Mdot
.54118 .20392 Mdot
.50588 .32549 Mdot
.34902 .24706 Mdot
.38824 .24706 Mdot
.81569 .55686 Mdot
.68627 .52549 Mdot
.46275 .23137 Mdot
.52549 .36078 Mdot
.45882 .38824 Mdot
.12157 .12549 Mdot
.12157 .11765 Mdot
.20392 .20392 Mdot
.14902 .14118 Mdot
.43529 .43922 Mdot
.73725 .74118 Mdot
.81961 .28627 Mdot
.90196 .32941 Mdot
.92157 .36471 Mdot
.89804 .33333 Mdot
.87059 .38824 Mdot
.89412 .46667 Mdot
.90588 .4 Mdot
.87451 .29412 Mdot
.67843 .28235 Mdot
.63137 .41961 Mdot
.41176 .31373 Mdot
.31373 .17647 Mdot
.65098 .39216 Mdot
.79608 .64706 Mdot
.55686 .28235 Mdot
.7098 .50196 Mdot
.57647 .47843 Mdot
.08235 .08235 Mdot
.11373 .1098 Mdot
.13725 .13725 Mdot
.12157 .11373 Mdot
.47843 .47843 Mdot
.44706 .4549 Mdot
.61176 .38824 Mdot
.92157 .33333 Mdot
.98824 .4902 Mdot
.96078 .41961 Mdot
.91373 .37647 Mdot
.95294 .56863 Mdot
.86275 .48627 Mdot
.82353 .32549 Mdot
.84706 .28235 Mdot
.79216 .40784 Mdot
.52941 .40784 Mdot
.73333 .56863 Mdot
.78039 .65882 Mdot
.53725 .30196 Mdot
.84706 .61569 Mdot
.64706 .35686 Mdot
.6 .35686 Mdot
.95294 .9451 Mdot
.19608 .18039 Mdot
.13333 .12941 Mdot
.13333 .13333 Mdot
.05098 .0549 Mdot
.50588 .5098 Mdot
.41961 .42745 Mdot
.69412 .28627 Mdot
.89804 .3098 Mdot
.97647 .45882 Mdot
.95686 .41569 Mdot
.95294 .43137 Mdot
.96863 .56863 Mdot
.91765 .54118 Mdot
.99216 .50196 Mdot
.86275 .29804 Mdot
.80784 .37647 Mdot
.78431 .64706 Mdot
.44314 .26667 Mdot
.85098 .71765 Mdot
.38039 .23137 Mdot
.46667 .13333 Mdot
.64314 .32941 Mdot
.63529 .38824 Mdot
.89412 .8902 Mdot
.09412 .0902 Mdot
.13725 .13333 Mdot
.12941 .12941 Mdot
.51373 .51373 Mdot
.53333 .53333 Mdot
.47451 .48235 Mdot
.96078 .96078 Mdot
.93725 .34902 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.94902 .39216 Mdot
.92157 .42745 Mdot
.94118 .5098 Mdot
.91765 .44706 Mdot
.87059 .2902 Mdot
.8902 .33725 Mdot
.65098 .38039 Mdot
.89412 .71765 Mdot
.82353 .70588 Mdot
.45098 .30196 Mdot
.8549 .67059 Mdot
.70196 .33725 Mdot
.68627 .37255 Mdot
.7451 .67843 Mdot
.34902 .33725 Mdot
.08235 .06667 Mdot
.11765 .12157 Mdot
.18824 .18824 Mdot
.54118 .54118 Mdot
.51373 .51373 Mdot
.47843 .48627 Mdot
1 .97647 Mdot
.94902 .36078 Mdot
.95294 .38039 Mdot
.88235 .34902 Mdot
.93333 .38431 Mdot
.93333 .39608 Mdot
.89412 .40784 Mdot
.93725 .43529 Mdot
.88235 .31765 Mdot
.88627 .30588 Mdot
.62353 .28235 Mdot
.99608 .74902 Mdot
.88235 .72549 Mdot
.78431 .65098 Mdot
.95294 .72941 Mdot
.77255 .38431 Mdot
.72549 .39216 Mdot
.76863 .69804 Mdot
.2549 .24314 Mdot
.3451 .33725 Mdot
.11373 .12941 Mdot
.21569 .22353 Mdot
.56078 .55294 Mdot
.35686 .35294 Mdot
.47451 .48235 Mdot
.55294 .54902 Mdot
.85882 .29804 Mdot
.93333 .3451 Mdot
.97255 .4549 Mdot
.91373 .38039 Mdot
.92941 .38039 Mdot
.94902 .41176 Mdot
.91373 .39608 Mdot
.96863 .43529 Mdot
.90196 .3451 Mdot
.84706 .33725 Mdot
.73725 .38431 Mdot
.82353 .52157 Mdot
.91765 .71373 Mdot
.92157 .72941 Mdot
.78824 .3098 Mdot
.80392 .43922 Mdot
.71765 .5451 Mdot
.35294 .34902 Mdot
.21961 .21176 Mdot
.28235 .3098 Mdot
.17255 .17647 Mdot
.63137 .62745 Mdot
.33333 .33725 Mdot
.36471 .36863 Mdot
.49804 .48627 Mdot
.6549 .31765 Mdot
.91765 .32941 Mdot
.93725 .37647 Mdot
.94902 .43922 Mdot
.9451 .42353 Mdot
.91373 .36471 Mdot
.94902 .40392 Mdot
.94902 .41176 Mdot
.95686 .41569 Mdot
.90196 .3451 Mdot
.76078 .29412 Mdot
.74902 .31765 Mdot
.6902 .37255 Mdot
.82745 .56863 Mdot
.76078 .27059 Mdot
.82745 .37647 Mdot
.7098 .39608 Mdot
.81176 .80392 Mdot
.27451 .26667 Mdot
.42745 .43137 Mdot
.21569 .23529 Mdot
.09804 .10588 Mdot
.63529 .63529 Mdot
.54118 .5451 Mdot
.54902 .54902 Mdot
.76471 .7451 Mdot
.94902 .36078 Mdot
.95294 .36078 Mdot
.93725 .4 Mdot
.92157 .41569 Mdot
.95294 .43529 Mdot
.89804 .36078 Mdot
.92549 .37647 Mdot
.93725 .39608 Mdot
.9451 .41176 Mdot
.88235 .32549 Mdot
.83137 .37647 Mdot
.76863 .33725 Mdot
.67451 .28235 Mdot
.69804 .26275 Mdot
.83922 .30196 Mdot
.85882 .41961 Mdot
.75294 .67843 Mdot
.15294 .15294 Mdot
.83922 .82353 Mdot
.15686 .19216 Mdot
.14902 .16863 Mdot
.6902 .67843 Mdot
.38431 .38824 Mdot
.60392 .58824 Mdot
.57255 .49412 Mdot
.80392 .3098 Mdot
.91765 .34118 Mdot
.9451 .38431 Mdot
.87843 .41176 Mdot
.88235 .41961 Mdot
.94902 .42745 Mdot
.94118 .38431 Mdot
.90588 .35686 Mdot
.93333 .39216 Mdot
.96863 .44314 Mdot
.85882 .38431 Mdot
.8549 .40784 Mdot
.82745 .38039 Mdot
.79608 .3451 Mdot
.8549 .3098 Mdot
.86667 .32549 Mdot
.83529 .64314 Mdot
.85098 .8549 Mdot
.50196 .4902 Mdot
.89804 .90196 Mdot
.51765 .52941 Mdot
.12941 .12549 Mdot
.66275 .66667 Mdot
.31765 .31373 Mdot
.60392 .55686 Mdot
.97647 .92157 Mdot
.93725 .34118 Mdot
.93725 .35686 Mdot
.88235 .40784 Mdot
.83922 .47843 Mdot
.87059 .45098 Mdot
.93333 .39608 Mdot
.95294 .40392 Mdot
.91765 .37647 Mdot
.8902 .39608 Mdot
.92549 .35294 Mdot
.70588 .38824 Mdot
.87059 .47059 Mdot
.8549 .44314 Mdot
.87059 .39216 Mdot
.86667 .34118 Mdot
.82745 .34118 Mdot
.81961 .77647 Mdot
.60392 .6 Mdot
.34118 .33333 Mdot
.96078 .97647 Mdot
.5098 .50588 Mdot
.7451 .72941 Mdot
.61961 .61961 Mdot
.30588 .30196 Mdot
.93725 .70196 Mdot
.75294 .31765 Mdot
.91765 .33725 Mdot
.90196 .39216 Mdot
.81176 .49412 Mdot
.77647 .4902 Mdot
.81176 .40784 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.95294 .42745 Mdot
.84314 .37647 Mdot
.81176 .37647 Mdot
.47843 .21961 Mdot
.66275 .3451 Mdot
.82353 .45098 Mdot
.86667 .43922 Mdot
.87843 .32549 Mdot
.72941 .48235 Mdot
.84314 .82745 Mdot
.27843 .26667 Mdot
.94902 .94118 Mdot
.25098 .24314 Mdot
.66667 .65882 Mdot
.71765 .71373 Mdot
.66275 .66275 Mdot
.59216 .51765 Mdot
.54118 .3098 Mdot
.94902 .36863 Mdot
.90196 .34902 Mdot
.8 .47843 Mdot
.76863 .58431 Mdot
.91765 .69412 Mdot
.87451 .43922 Mdot
.9451 .39216 Mdot
.9451 .38824 Mdot
.83529 .45098 Mdot
.92941 .39216 Mdot
.33725 .14902 Mdot
.36863 .18039 Mdot
.4549 .24706 Mdot
.58039 .2902 Mdot
.71373 .34118 Mdot
.79216 .32941 Mdot
.86667 .78039 Mdot
.67451 .67451 Mdot
.96078 .93725 Mdot
.88235 .88235 Mdot
.91373 .90196 Mdot
.79216 .78824 Mdot
.72941 .71765 Mdot
.63922 .63529 Mdot
.67059 .31373 Mdot
.90588 .78431 Mdot
.93333 .35294 Mdot
.87843 .41176 Mdot
.82745 .67843 Mdot
.82353 .70588 Mdot
.69804 .53333 Mdot
.90196 .45098 Mdot
.93725 .38039 Mdot
.92941 .38039 Mdot
.58039 .32549 Mdot
.89804 .37255 Mdot
.22745 .12941 Mdot
.25882 .16078 Mdot
.3098 .17255 Mdot
.40392 .21176 Mdot
.57647 .16863 Mdot
.57647 .2902 Mdot
.5451 .51373 Mdot
.23922 .23529 Mdot
.76471 .74118 Mdot
.9451 .95686 Mdot
.84706 .83922 Mdot
.82353 .80784 Mdot
.76863 .75294 Mdot
.73333 .71373 Mdot
.78431 .31373 Mdot
.76471 .31765 Mdot
.93333 .37255 Mdot
.82353 .53725 Mdot
.7451 .67843 Mdot
.42745 .3451 Mdot
.36863 .22353 Mdot
.90588 .46275 Mdot
.9451 .39216 Mdot
.8902 .40784 Mdot
.43922 .21176 Mdot
.88235 .40392 Mdot
.18039 .11765 Mdot
.2 .12941 Mdot
.22745 .1451 Mdot
.28235 .16471 Mdot
.79216 .35294 Mdot
.27059 .16471 Mdot
.23529 .23529 Mdot
.19216 .19608 Mdot
.4549 .44314 Mdot
.49412 .49804 Mdot
.8549 .8549 Mdot
.83137 .82745 Mdot
.77255 .76863 Mdot
.75686 .67059 Mdot
.71765 .36471 Mdot
.92941 .36863 Mdot
.85882 .39216 Mdot
.85882 .71765 Mdot
.9098 .86275 Mdot
.34118 .2902 Mdot
1 .8549 Mdot
.92549 .4549 Mdot
.95294 .4 Mdot
.63529 .3451 Mdot
.34118 .06667 Mdot
.79608 .38039 Mdot
.15294 .12157 Mdot
.18039 .14118 Mdot
.2 .16078 Mdot
.27843 .16471 Mdot
.78431 .39608 Mdot
.21176 .18039 Mdot
.19608 .19216 Mdot
.10196 .11373 Mdot
.27451 .25882 Mdot
.81961 .81961 Mdot
.87059 .87059 Mdot
.85882 .85098 Mdot
.81176 .80784 Mdot
.89804 .65882 Mdot
.62745 .52157 Mdot
.90588 .33333 Mdot
.84314 .47843 Mdot
.83529 .74902 Mdot
.39216 .36078 Mdot
.37255 .33725 Mdot
.92549 .7098 Mdot
.92941 .46667 Mdot
.9451 .38824 Mdot
.32549 .15686 Mdot
.32157 .08235 Mdot
.79608 .38039 Mdot
.14118 .1098 Mdot
.20784 .17647 Mdot
.15686 .13725 Mdot
.21569 .05098 Mdot
.70588 .38039 Mdot
.14118 .13725 Mdot
.13725 .12941 Mdot
.2902 .29412 Mdot
.51765 .50588 Mdot
.88627 .87843 Mdot
.87843 .87843 Mdot
.87451 .87451 Mdot
.85098 .85098 Mdot
.7451 .41961 Mdot
1 .96471 Mdot
.88235 .32941 Mdot
.83922 .55686 Mdot
.85882 .81176 Mdot
.2549 .23922 Mdot
.81961 .78824 Mdot
.94902 .6902 Mdot
.93725 .47059 Mdot
.93725 .4 Mdot
.23922 .16078 Mdot
.32157 .10196 Mdot
.80784 .39216 Mdot
.15294 .13333 Mdot
.1451 .12549 Mdot
.13333 .11373 Mdot
.34118 .08235 Mdot
.56863 .34118 Mdot
.12157 .12157 Mdot
.1451 .12157 Mdot
.72157 .72941 Mdot
.86275 .85882 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.88235 .88235 Mdot
.87451 .87451 Mdot
.52157 .13333 Mdot
1 .96863 Mdot
.89412 .35686 Mdot
.86275 .61176 Mdot
.86667 .82745 Mdot
.25098 .23922 Mdot
.48627 .4549 Mdot
.80784 .47843 Mdot
.90196 .48235 Mdot
.92157 .38824 Mdot
.21961 .16078 Mdot
.55686 .40784 Mdot
.86275 .40784 Mdot
.1451 .10588 Mdot
.1451 .13333 Mdot
.1451 .12549 Mdot
.35294 .07451 Mdot
.54902 .32549 Mdot
.12549 .12549 Mdot
.1098 .07059 Mdot
.84706 .84706 Mdot
.87059 .86667 Mdot
.85098 .85098 Mdot
.87451 .87451 Mdot
.87059 .87059 Mdot
.87059 .87059 Mdot
.69804 .32549 Mdot
1 .96863 Mdot
.85882 .35294 Mdot
.89804 .65882 Mdot
.8902 .8549 Mdot
.30196 .28235 Mdot
.34118 .30196 Mdot
.73725 .41569 Mdot
.89804 .51373 Mdot
.9098 .39608 Mdot
.19216 .14902 Mdot
.75686 .66275 Mdot
.88235 .42353 Mdot
.16471 .07059 Mdot
.17255 .14118 Mdot
.14118 .12157 Mdot
.37647 .0902 Mdot
.54118 .31765 Mdot
.12549 .1098 Mdot
.29412 .24706 Mdot
.86667 .86275 Mdot
.91373 .91373 Mdot
.69412 .6902 Mdot
.87451 .87451 Mdot
.85882 .85882 Mdot
.86275 .86275 Mdot
.86275 .49804 Mdot
1 .97255 Mdot
.86667 .39216 Mdot
.97255 .73333 Mdot
.86275 .81961 Mdot
.26667 .23922 Mdot
.21176 .16078 Mdot
.83529 .58824 Mdot
.86275 .52157 Mdot
.87843 .38824 Mdot
.17255 .12941 Mdot
.43922 .36471 Mdot
.86275 .44314 Mdot
.23529 .03529 Mdot
.20784 .14902 Mdot
.15686 .12549 Mdot
.37255 .07059 Mdot
.52941 .30588 Mdot
.13725 .09804 Mdot
.8 .75686 Mdot
.87059 .86667 Mdot
.7451 .74902 Mdot
.4549 .45098 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.85882 .86667 Mdot
.79608 .43137 Mdot
1 .97255 Mdot
.83137 .39608 Mdot
.97647 .74118 Mdot
.79216 .7451 Mdot
.31765 .28627 Mdot
.50588 .45098 Mdot
1 .81569 Mdot
.87059 .56471 Mdot
.8902 .41961 Mdot
.17647 .14118 Mdot
.26667 .20784 Mdot
.72549 .37255 Mdot
.40392 .0902 Mdot
.27843 .12157 Mdot
.20392 .09412 Mdot
.38824 .0549 Mdot
.52941 .27059 Mdot
.2 .08627 Mdot
.56471 .52549 Mdot
.88627 .87843 Mdot
.27451 .28235 Mdot
.30588 .29412 Mdot
.87451 .85882 Mdot
.88627 .88627 Mdot
.87059 .87843 Mdot
.76471 .4 Mdot
1 .96471 Mdot
.81176 .41176 Mdot
.94118 .69804 Mdot
.76863 .71765 Mdot
.78824 .75294 Mdot
.80784 .75686 Mdot
.58039 .45098 Mdot
.94902 .67843 Mdot
.87059 .43137 Mdot
.19608 .16078 Mdot
.24314 .2 Mdot
.64706 .36863 Mdot
.73725 .29804 Mdot
.42745 .09804 Mdot
.31373 .06667 Mdot
.43137 .04314 Mdot
.56078 .23922 Mdot
.29412 .05882 Mdot
.57647 .54118 Mdot
.90588 .88627 Mdot
.26275 .28235 Mdot
.20392 .17255 Mdot
.90196 .87843 Mdot
.87843 .87843 Mdot
.86667 .87451 Mdot
.72941 .37255 Mdot
1 .96471 Mdot
.76863 .40392 Mdot
.86667 .61569 Mdot
.83922 .79608 Mdot
.51765 .4902 Mdot
.47843 .43922 Mdot
.4902 .40392 Mdot
.99608 .73725 Mdot
.86667 .44706 Mdot
.18431 .15686 Mdot
.20392 .17647 Mdot
.80784 .59216 Mdot
.81961 .35686 Mdot
.65098 .21961 Mdot
.47451 .12157 Mdot
.46667 .02353 Mdot
.60392 .20392 Mdot
.47451 .12549 Mdot
.64314 .61176 Mdot
.51373 .50196 Mdot
.26667 .28627 Mdot
.16863 .12549 Mdot
.96078 .93725 Mdot
.88235 .87843 Mdot
.87059 .87843 Mdot
.68627 .33333 Mdot
1 .95686 Mdot
.75294 .41176 Mdot
.77647 .52941 Mdot
.94902 .92549 Mdot
.35294 .3451 Mdot
.43529 .42353 Mdot
.74118 .67843 Mdot
1 .75686 Mdot
.84314 .44706 Mdot
.18039 .14902 Mdot
.17647 .1451 Mdot
.62353 .44706 Mdot
.8902 .5098 Mdot
.82745 .36471 Mdot
.73725 .2902 Mdot
.61176 .13333 Mdot
.7451 .26667 Mdot
.74902 .3098 Mdot
.84314 .80784 Mdot
.27059 .26667 Mdot
.22353 .23529 Mdot
.15294 .09804 Mdot
.8902 .87451 Mdot
.91373 .8902 Mdot
.87451 .88235 Mdot
.66275 .32549 Mdot
1 .95294 Mdot
.75294 .41569 Mdot
.66667 .43922 Mdot
.92549 .91373 Mdot
.19216 .18431 Mdot
.21569 .22353 Mdot
.91765 .87451 Mdot
.98039 .72941 Mdot
.83922 .46667 Mdot
.16471 .1451 Mdot
.18039 .14902 Mdot
.36863 .20392 Mdot
1 .68627 Mdot
.83529 .39216 Mdot
.88235 .41961 Mdot
.81176 .35294 Mdot
.85098 .32549 Mdot
.83922 .36863 Mdot
.68627 .64706 Mdot
.25882 .2549 Mdot
.15294 .15686 Mdot
.13725 .08235 Mdot
.63137 .61569 Mdot
.87451 .83922 Mdot
.86667 .87059 Mdot
.60392 .28627 Mdot
1 .9451 Mdot
.77255 .43529 Mdot
.61569 .42745 Mdot
.70196 .68627 Mdot
.56078 .5451 Mdot
.66275 .6549 Mdot
.9451 .91373 Mdot
.91765 .67059 Mdot
.80784 .46275 Mdot
.24706 .21961 Mdot
.18824 .15686 Mdot
.35294 .18824 Mdot
.99608 .58039 Mdot
1 .61961 Mdot
.86275 .45882 Mdot
.91373 .52157 Mdot
.90588 .36863 Mdot
.83922 .40392 Mdot
.30588 .28627 Mdot
.20392 .19608 Mdot
.16078 .16078 Mdot
.16471 .1098 Mdot
.57255 .55686 Mdot
.3451 .32157 Mdot
.86667 .87451 Mdot
.54118 .23922 Mdot
1 .9451 Mdot
.76078 .41176 Mdot
.66667 .52941 Mdot
.49412 .47059 Mdot
.90196 .87843 Mdot
.97255 .95294 Mdot
.93725 .90588 Mdot
.83529 .58824 Mdot
.80392 .46275 Mdot
.52157 .48627 Mdot
.18431 .15294 Mdot
.34118 .14902 Mdot
.9098 .44706 Mdot
.96078 .57255 Mdot
.98431 .58824 Mdot
1 .60784 Mdot
.92549 .38824 Mdot
.74902 .38431 Mdot
.26275 .24706 Mdot
.15294 .1451 Mdot
.14902 .1451 Mdot
.17255 .11765 Mdot
.59216 .56863 Mdot
.73333 .7098 Mdot
.87059 .87843 Mdot
.52157 .21961 Mdot
1 .94902 Mdot
.81176 .43529 Mdot
.82745 .73333 Mdot
.36863 .33725 Mdot
.52157 .49412 Mdot
.92941 .90588 Mdot
.95294 .9098 Mdot
.76863 .51765 Mdot
.80784 .46667 Mdot
.47059 .42745 Mdot
.15294 .13333 Mdot
.33333 .1098 Mdot
.93725 .42745 Mdot
.92549 .4549 Mdot
.94902 .49804 Mdot
.97647 .53725 Mdot
.95294 .41176 Mdot
.52941 .24706 Mdot
.19216 .18824 Mdot
.14902 .14902 Mdot
.15294 .14902 Mdot
.16471 .1098 Mdot
.62745 .60392 Mdot
.6902 .65882 Mdot
.86667 .87451 Mdot
.51373 .21176 Mdot
1 .96863 Mdot
.83137 .42353 Mdot
.86275 .8 Mdot
.34902 .30196 Mdot
.38431 .35686 Mdot
.91765 .89412 Mdot
.93725 .89412 Mdot
.72941 .47843 Mdot
.81569 .48235 Mdot
.29804 .24314 Mdot
.23137 .2 Mdot
.32941 .07451 Mdot
.95294 .41176 Mdot
.94902 .43137 Mdot
.91373 .41569 Mdot
.92157 .43529 Mdot
.95294 .4 Mdot
.43137 .19608 Mdot
.15294 .14902 Mdot
.16078 .16863 Mdot
.16078 .15294 Mdot
.17647 .12157 Mdot
.58431 .56863 Mdot
.20392 .17255 Mdot
.87059 .87059 Mdot
.5098 .21176 Mdot
.85098 .72157 Mdot
.85882 .49412 Mdot
.89804 .8549 Mdot
.31373 .26667 Mdot
.25882 .21569 Mdot
.93725 .90196 Mdot
.59216 .53725 Mdot
.95294 .72941 Mdot
.57255 .32941 Mdot
.27843 .23529 Mdot
.39608 .36863 Mdot
.47059 .09412 Mdot
.93725 .39608 Mdot
.93725 .40392 Mdot
.94118 .40784 Mdot
.93725 .4 Mdot
.92157 .35686 Mdot
.23922 .09412 Mdot
.12941 .13725 Mdot
.22353 .23137 Mdot
.14902 .14902 Mdot
.59608 .54902 Mdot
.35294 .32941 Mdot
.45882 .43922 Mdot
.86275 .87059 Mdot
.83137 .45098 Mdot
.62353 .34902 Mdot
.79608 .48235 Mdot
.77647 .71373 Mdot
.7098 .65882 Mdot
.73725 .6902 Mdot
.95294 .91765 Mdot
.58039 .51373 Mdot
1 .75686 Mdot
.29412 .14902 Mdot
.25098 .21176 Mdot
.54902 .5098 Mdot
.85098 .37255 Mdot
.93725 .38431 Mdot
.9451 .39216 Mdot
.9451 .39216 Mdot
.94118 .38039 Mdot
.92941 .36471 Mdot
.21176 .14118 Mdot
.15294 .17647 Mdot
.24314 .26275 Mdot
.12941 .12549 Mdot
.95686 .92941 Mdot
.55294 .52941 Mdot
.73725 .71373 Mdot
.86667 .85882 Mdot
.60392 .21176 Mdot
.88627 .40392 Mdot
.80392 .6549 Mdot
.81176 .71765 Mdot
.6 .55294 Mdot
.94902 .90196 Mdot
.78824 .77647 Mdot
1 .84314 Mdot
.8549 .50196 Mdot
.24706 .20392 Mdot
.27059 .23922 Mdot
.59216 .49804 Mdot
.9451 .39216 Mdot
.95294 .39216 Mdot
.9451 .38431 Mdot
.9451 .38431 Mdot
.93725 .36078 Mdot
.87451 .37255 Mdot
.18039 .17647 Mdot
.27059 .28627 Mdot
.13333 .14118 Mdot
.24314 .21569 Mdot
.88627 .88627 Mdot
.64314 .61961 Mdot
.83922 .80784 Mdot
.9098 .85098 Mdot
.5451 .33333 Mdot
.87059 .37255 Mdot
.87843 .80784 Mdot
.36078 .28627 Mdot
.28627 .23529 Mdot
.38039 .32549 Mdot
.4 .38039 Mdot
.7451 .46667 Mdot
.77255 .4549 Mdot
.24706 .22745 Mdot
.25098 .22353 Mdot
.66667 .41569 Mdot
.94118 .38431 Mdot
.90588 .40392 Mdot
.93333 .38824 Mdot
.93333 .38824 Mdot
.93333 .37255 Mdot
.79216 .45098 Mdot
.18824 .18824 Mdot
.20392 .21569 Mdot
.25882 .24706 Mdot
.39216 .34118 Mdot
.48627 .48235 Mdot
.37255 .32549 Mdot
.88235 .87451 Mdot
.81569 .62353 Mdot
1 .95686 Mdot
.86275 .49412 Mdot
.81176 .7451 Mdot
.44706 .4 Mdot
.3098 .2549 Mdot
.4549 .42745 Mdot
.83922 .77255 Mdot
1 .76471 Mdot
.39216 .23529 Mdot
.27843 .24706 Mdot
.25098 .21176 Mdot
.83137 .38039 Mdot
.92941 .39608 Mdot
.69804 .31765 Mdot
.88235 .37255 Mdot
.90196 .37647 Mdot
.90588 .36078 Mdot
.23922 .10196 Mdot
.14118 .14118 Mdot
.2902 .28235 Mdot
.42353 .40392 Mdot
.71373 .68627 Mdot
.35686 .34902 Mdot
.81961 .76078 Mdot
.86667 .87451 Mdot
.75686 .42745 Mdot
.67843 .38824 Mdot
.8902 .7098 Mdot
.90588 .86275 Mdot
.87059 .82745 Mdot
.89804 .85882 Mdot
.53333 .51765 Mdot
.98431 .78824 Mdot
.85098 .47843 Mdot
.26667 .20784 Mdot
.27059 .23529 Mdot
.27843 .18431 Mdot
.93725 .40392 Mdot
.88627 .47451 Mdot
.77255 .40784 Mdot
.63922 .25882 Mdot
.71373 .30196 Mdot
.84314 .35294 Mdot
.15294 .12941 Mdot
.36471 .35686 Mdot
.38039 .36078 Mdot
.18039 .15686 Mdot
.88627 .88627 Mdot
.89412 .8902 Mdot
.43137 .39216 Mdot
.88235 .86667 Mdot
.56863 .36078 Mdot
.92549 .52941 Mdot
.52157 .47059 Mdot
.48627 .47059 Mdot
.47843 .44314 Mdot
.56078 .53333 Mdot
.23529 .16078 Mdot
.84706 .59608 Mdot
.78824 .49412 Mdot
.23529 .19608 Mdot
.24314 .21569 Mdot
.44706 .09804 Mdot
.92157 .38824 Mdot
1 .87059 Mdot
.5451 .26275 Mdot
.74902 .54902 Mdot
.58824 .3451 Mdot
.77255 .43922 Mdot
.42745 .43922 Mdot
.26275 .25098 Mdot
.16471 .14902 Mdot
.14902 .12549 Mdot
.88235 .88235 Mdot
.8 .7451 Mdot
.87451 .87451 Mdot
.72549 .50588 Mdot
.91373 .78431 Mdot
.96863 .81961 Mdot
.43137 .4 Mdot
.37647 .34118 Mdot
.38039 .35294 Mdot
.40392 .38431 Mdot
.86667 .60392 Mdot
.83137 .46667 Mdot
.29412 .21176 Mdot
.25098 .22353 Mdot
.25098 .19216 Mdot
.92157 .38431 Mdot
.80392 .47059 Mdot
1 .85098 Mdot
.97255 .87451 Mdot
.96863 .85098 Mdot
1 .74118 Mdot
.42353 .35294 Mdot
.23922 .24314 Mdot
.18824 .17647 Mdot
.18431 .16863 Mdot
.9098 .9098 Mdot
.92941 .92549 Mdot
.51373 .46667 Mdot
.87843 .87059 Mdot
.61961 .36863 Mdot
.86667 .50196 Mdot
.37255 .32157 Mdot
.34902 .31765 Mdot
.35686 .32549 Mdot
.3451 .33725 Mdot
.90588 .72549 Mdot
.98039 .72157 Mdot
.80392 .52157 Mdot
.27059 .23137 Mdot
.23529 .21569 Mdot
.48627 .11765 Mdot
.90588 .41176 Mdot
.9451 .8549 Mdot
.87451 .75294 Mdot
.94902 .76078 Mdot
.96078 .85098 Mdot
.79608 .45098 Mdot
.21961 .23137 Mdot
.23529 .22745 Mdot
.18039 .16078 Mdot
.12941 .10588 Mdot
.87843 .88627 Mdot
.66667 .60392 Mdot
.87451 .87451 Mdot
.57647 .3451 Mdot
.63137 .46275 Mdot
.61961 .44706 Mdot
.3098 .21176 Mdot
.29412 .2 Mdot
.28235 .20392 Mdot
.40392 .32941 Mdot
.78431 .49412 Mdot
.92549 .47843 Mdot
.25098 .19608 Mdot
.23922 .21961 Mdot
.27059 .16078 Mdot
.93725 .39608 Mdot
.50588 .36863 Mdot
.54902 .36471 Mdot
1 .8549 Mdot
.9098 .81961 Mdot
.60392 .20392 Mdot
.24706 .22353 Mdot
.25882 .26667 Mdot
.17255 .15686 Mdot
.16863 .1451 Mdot
.88627 .88627 Mdot
.89804 .88235 Mdot
.69412 .67059 Mdot
.90196 .8549 Mdot
.58824 .50196 Mdot
.73333 .33333 Mdot
.88627 .6549 Mdot
.77647 .63922 Mdot
.83137 .62353 Mdot
.55686 .52549 Mdot
.7451 .47451 Mdot
.9451 .55686 Mdot
.68235 .50588 Mdot
.25098 .20784 Mdot
.23922 .2 Mdot
.85882 .40784 Mdot
.81176 .47059 Mdot
.99216 .88235 Mdot
.94118 .85882 Mdot
.78824 .47451 Mdot
.99608 .84706 Mdot
.48235 .24314 Mdot
.21176 .22353 Mdot
.17255 .16471 Mdot
.15686 .15294 Mdot
.50588 .4902 Mdot
.88627 .88627 Mdot
.41569 .37647 Mdot
.87059 .87843 Mdot
.70588 .47451 Mdot
.81176 .43529 Mdot
.87843 .51373 Mdot
.91765 .68235 Mdot
.82745 .55686 Mdot
.95294 .88235 Mdot
.60392 .39216 Mdot
.9451 .55686 Mdot
.77255 .50588 Mdot
.21176 .16863 Mdot
.28235 .25098 Mdot
.62353 .24314 Mdot
.83137 .44706 Mdot
.96078 .86667 Mdot
.93725 .87059 Mdot
.8549 .46275 Mdot
.96471 .83137 Mdot
.77647 .45098 Mdot
.20392 .21176 Mdot
.14902 .14118 Mdot
.14902 .1451 Mdot
.15294 .11765 Mdot
.8902 .8902 Mdot
.52549 .48627 Mdot
.87843 .87843 Mdot
.45098 .25098 Mdot
.72941 .41569 Mdot
.90588 .43137 Mdot
.85882 .52549 Mdot
.78824 .50588 Mdot
.77255 .69412 Mdot
.81176 .60784 Mdot
.95294 .51765 Mdot
.78824 .52157 Mdot
.43922 .39608 Mdot
.27451 .23922 Mdot
.67059 .28627 Mdot
.82353 .47059 Mdot
.98824 .87843 Mdot
.93333 .86667 Mdot
.83137 .4549 Mdot
1 .83137 Mdot
.73725 .43529 Mdot
.22353 .22353 Mdot
.14902 .13333 Mdot
.14902 .13333 Mdot
.17647 .13333 Mdot
.88627 .88627 Mdot
.45098 .39608 Mdot
.87843 .87843 Mdot
.44706 .26275 Mdot
.6 .35686 Mdot
.96078 .42745 Mdot
.8902 .48235 Mdot
1 .72157 Mdot
.54118 .45882 Mdot
.97647 .74118 Mdot
.93725 .4549 Mdot
.77647 .5098 Mdot
.53333 .4902 Mdot
.25882 .22353 Mdot
.69412 .29804 Mdot
.81569 .50588 Mdot
1 .87451 Mdot
.94902 .86667 Mdot
.84706 .49412 Mdot
1 .83529 Mdot
.72157 .43922 Mdot
.23137 .22353 Mdot
.14902 .13333 Mdot
.15294 .13333 Mdot
.21961 .17647 Mdot
.88627 .88627 Mdot
.62745 .56863 Mdot
.87451 .87451 Mdot
.58039 .41176 Mdot
.63137 .3451 Mdot
.97255 .42353 Mdot
.89412 .46667 Mdot
.96471 .67059 Mdot
.32549 .22745 Mdot
.9098 .56863 Mdot
.94118 .42353 Mdot
.51373 .3451 Mdot
.37255 .33725 Mdot
.21176 .17255 Mdot
.9098 .43529 Mdot
.40784 .23529 Mdot
.49804 .32941 Mdot
.97647 .85098 Mdot
.47451 .2549 Mdot
.63922 .27843 Mdot
.36863 .18431 Mdot
.23137 .21961 Mdot
.16078 .14902 Mdot
.1451 .1098 Mdot
.88235 .84706 Mdot
.8902 .8902 Mdot
.58824 .53333 Mdot
.87451 .87451 Mdot
.51765 .38431 Mdot
.9098 .42353 Mdot
.95686 .42353 Mdot
.90196 .48627 Mdot
.8549 .63529 Mdot
.98039 .75294 Mdot
.93725 .46275 Mdot
.92157 .40392 Mdot
.26667 .23922 Mdot
.47451 .43529 Mdot
.27059 .12941 Mdot
.87059 .43529 Mdot
.9451 .87059 Mdot
.98039 .90588 Mdot
.83922 .40392 Mdot
.9451 .8549 Mdot
.88235 .38039 Mdot
.21569 .17647 Mdot
.16078 .15294 Mdot
.17647 .15294 Mdot
.19216 .14902 Mdot
.88627 .88627 Mdot
.93333 .92941 Mdot
.51765 .49412 Mdot
.96078 .88235 Mdot
1 .96863 Mdot
.89412 .36863 Mdot
.95294 .41961 Mdot
.9098 .47059 Mdot
.94118 .65882 Mdot
.93333 .48235 Mdot
.9451 .40784 Mdot
.80784 .52157 Mdot
.26667 .24706 Mdot
.52549 .49412 Mdot
.75294 .33725 Mdot
.36078 .22745 Mdot
.45882 .28627 Mdot
.98431 .84314 Mdot
.47451 .26275 Mdot
.65882 .31765 Mdot
.53725 .31373 Mdot
.22745 .21569 Mdot
.14902 .14118 Mdot
.16471 .12549 Mdot
.45098 .43137 Mdot
.88627 .88627 Mdot
.85098 .81176 Mdot
.88235 .87451 Mdot
.7098 .61569 Mdot
.77255 .42745 Mdot
.92157 .39608 Mdot
.94902 .44314 Mdot
.8902 .49412 Mdot
.9098 .4549 Mdot
.9451 .40784 Mdot
.87451 .39608 Mdot
.28235 .24314 Mdot
.2549 .23137 Mdot
.63529 .39216 Mdot
.45882 .23922 Mdot
1 .87451 Mdot
.94118 .86667 Mdot
.83529 .48627 Mdot
1 .83529 Mdot
.83137 .42745 Mdot
.19608 .18431 Mdot
.15686 .15294 Mdot
.12157 .09804 Mdot
.44706 .41961 Mdot
.8902 .8902 Mdot
.86667 .85098 Mdot
.89412 .8902 Mdot
.5451 .45098 Mdot
.69804 .56471 Mdot
.86275 .43137 Mdot
.91765 .39608 Mdot
.95686 .46275 Mdot
.9451 .4549 Mdot
.94902 .40784 Mdot
.94902 .41569 Mdot
.30588 .22353 Mdot
.25882 .24314 Mdot
.46667 .30588 Mdot
.48235 .24706 Mdot
1 .88235 Mdot
.93725 .87843 Mdot
.80784 .45882 Mdot
.97255 .83922 Mdot
.87843 .40784 Mdot
.16078 .14902 Mdot
.15686 .1451 Mdot
.2549 .24314 Mdot
.33725 .31373 Mdot
.88627 .88627 Mdot
.91373 .91373 Mdot
.8902 .87451 Mdot
.94118 .87059 Mdot
.96471 .89804 Mdot
.76863 .42353 Mdot
.90196 .41176 Mdot
.94902 .42745 Mdot
.96471 .43137 Mdot
.95686 .40784 Mdot
.9098 .41176 Mdot
.30588 .23529 Mdot
.27059 .24706 Mdot
.38431 .13725 Mdot
.95686 .79216 Mdot
.65098 .43529 Mdot
.94118 .86275 Mdot
.45882 .2549 Mdot
.85882 .6 Mdot
.81176 .46275 Mdot
.16471 .16078 Mdot
.20784 .2 Mdot
.45882 .45098 Mdot
.15294 .12549 Mdot
.88627 .88627 Mdot
.69804 .68235 Mdot
.88235 .87843 Mdot
.36863 .29804 Mdot
.84706 .71373 Mdot
.81569 .43529 Mdot
.91765 .38431 Mdot
.95686 .40784 Mdot
.95686 .40784 Mdot
.94118 .40784 Mdot
.3098 .17255 Mdot
.27059 .23529 Mdot
.34902 .19608 Mdot
.7098 .41176 Mdot
.89412 .6549 Mdot
.9451 .87059 Mdot
.58824 .45098 Mdot
1 .79608 Mdot
.82353 .42353 Mdot
.18039 .17255 Mdot
.47843 .46275 Mdot
.21961 .21176 Mdot
.18039 .14118 Mdot
.88627 .88627 Mdot
.90196 .89412 Mdot
.90196 .89804 Mdot
.57647 .50588 Mdot
.93725 .81961 Mdot
.78824 .42745 Mdot
.96078 .41569 Mdot
.92941 .38039 Mdot
.9451 .40784 Mdot
.91765 .43922 Mdot
.21569 .15686 Mdot
.26275 .22745 Mdot
.75686 .37255 Mdot
.82353 .51373 Mdot
.64706 .36863 Mdot
.99216 .85098 Mdot
.98431 .87059 Mdot
.93333 .38431 Mdot
.39608 .2902 Mdot
.48627 .47059 Mdot
.16471 .14902 Mdot
.16471 .16078 Mdot
.95686 .94902 Mdot
.8902 .8902 Mdot
.32941 .30588 Mdot
.8902 .87451 Mdot
.74118 .73725 Mdot
.70588 .50196 Mdot
.92157 .40392 Mdot
.93333 .38039 Mdot
.92157 .37255 Mdot
.9451 .43529 Mdot
.22745 .12157 Mdot
.23137 .19608 Mdot
.74902 .37255 Mdot
.87451 .45098 Mdot
.74902 .36471 Mdot
.9098 .63922 Mdot
1 .78039 Mdot
.92941 .37647 Mdot
.43137 .35294 Mdot
.20392 .2 Mdot
.17255 .15686 Mdot
.16863 .15294 Mdot
.93333 .92549 Mdot
.8902 .8902 Mdot
.40784 .37255 Mdot
.8902 .87451 Mdot
.92157 .91765 Mdot
.83922 .42353 Mdot
.94118 .41569 Mdot
.9451 .42353 Mdot
.89804 .37647 Mdot
.43137 .14902 Mdot
.18824 .1098 Mdot
.34902 .13333 Mdot
.93725 .42745 Mdot
.91373 .41569 Mdot
.78824 .39608 Mdot
.78824 .4549 Mdot
.91765 .4 Mdot
.61569 .43137 Mdot
.16471 .14902 Mdot
.15294 .14902 Mdot
.17255 .15294 Mdot
.38039 .35294 Mdot
.8902 .8902 Mdot
.47843 .43922 Mdot
.88235 .87843 Mdot
.73725 .72157 Mdot
.80392 .45098 Mdot
.94118 .43529 Mdot
.90196 .44314 Mdot
.9098 .43529 Mdot
.55686 .20784 Mdot
.22745 .10588 Mdot
.38431 .07451 Mdot
.93725 .41961 Mdot
.93333 .41961 Mdot
.92157 .4549 Mdot
.88235 .42745 Mdot
.93725 .38431 Mdot
.26275 .18431 Mdot
.16078 .1451 Mdot
.15686 .1451 Mdot
.16078 .14118 Mdot
.96078 .95294 Mdot
.89412 .89412 Mdot
.81569 .76078 Mdot
.89412 .87843 Mdot
.91373 .91765 Mdot
.75686 .43529 Mdot
.84706 .43137 Mdot
.76471 .43922 Mdot
.81569 .4549 Mdot
.65098 .33333 Mdot
.24314 .06667 Mdot
.9098 .44314 Mdot
.94902 .41569 Mdot
.93725 .41961 Mdot
.94118 .42745 Mdot
.93333 .40392 Mdot
.90196 .4 Mdot
.20392 .2 Mdot
.16863 .14902 Mdot
.14902 .13725 Mdot
.15686 .13333 Mdot
.88627 .88627 Mdot
.90588 .8902 Mdot
.56078 .54118 Mdot
.94902 .92941 Mdot
.76471 .69804 Mdot
.6902 .43922 Mdot
.7451 .58039 Mdot
.65098 .47059 Mdot
.65882 .43137 Mdot
.53725 .25098 Mdot
.42745 .0549 Mdot
.95686 .44314 Mdot
.92941 .41176 Mdot
.92941 .41176 Mdot
.95294 .41569 Mdot
.93725 .38431 Mdot
.30196 .18431 Mdot
.16863 .15294 Mdot
.17255 .14118 Mdot
.1451 .12941 Mdot
.89804 .8902 Mdot
.8902 .8902 Mdot
.62353 .58039 Mdot
.88235 .87843 Mdot
.84314 .86275 Mdot
.73725 .60784 Mdot
1 .96471 Mdot
.91765 .8549 Mdot
.58431 .47451 Mdot
.6549 .40784 Mdot
.67059 .30196 Mdot
.93333 .44314 Mdot
.94902 .43922 Mdot
.94118 .41961 Mdot
.94902 .41176 Mdot
.94902 .4 Mdot
.3098 .16471 Mdot
.18039 .16078 Mdot
.17255 .13725 Mdot
.14902 .13333 Mdot
.95294 .9451 Mdot
.89412 .89412 Mdot
.49412 .46275 Mdot
.88235 .87843 Mdot
.96471 .98431 Mdot
.99216 .96471 Mdot
.70588 .63137 Mdot
.67059 .45098 Mdot
.81569 .41176 Mdot
.89412 .41176 Mdot
.95686 .45098 Mdot
.96471 .44314 Mdot
.95686 .4 Mdot
.8 .46275 Mdot
.18431 .13333 Mdot
.14902 .1451 Mdot
.16863 .1451 Mdot
.24314 .22353 Mdot
.89412 .8902 Mdot
.89804 .89412 Mdot
.88627 .88627 Mdot
.39216 .41569 Mdot
.8902 .78824 Mdot
.76078 .49804 Mdot
.78039 .41569 Mdot
.84314 .40784 Mdot
.8902 .41961 Mdot
.92549 .41569 Mdot
.86275 .43137 Mdot
.21176 .11373 Mdot
.05098 .04314 Mdot
.07059 .04706 Mdot
.24314 .23922 Mdot
.90588 .89804 Mdot
.88627 .88627 Mdot
.87451 .87451 Mdot
.39216 .39216 Mdot
1 .95294 Mdot
.85098 .70196 Mdot
.70588 .45882 Mdot
.76078 .41961 Mdot
.80392 .38824 Mdot
.84314 .38431 Mdot
.53725 .30196 Mdot
.4902 .48235 Mdot
.42745 .41961 Mdot
.44706 .44706 Mdot
.56078 .58039 Mdot
.89412 .8902 Mdot
.88627 .8902 Mdot
.9451 .91765 Mdot
1 .96471 Mdot
.93333 .77647 Mdot
.83529 .60392 Mdot
.77255 .46667 Mdot
.72941 .39216 Mdot
.77255 .6549 Mdot
.91765 .90196 Mdot
.90588 .89804 Mdot
.21569 .25098 Mdot
.31765 .33725 Mdot
.89804 .89412 Mdot
.88627 .89804 Mdot
.28235 .27059 Mdot
1 .94902 Mdot
.95686 .83529 Mdot
.81961 .67059 Mdot
.81961 .78431 Mdot
.87451 .86667 Mdot
.60392 .59608 Mdot
.27059 .32157 Mdot
.28627 .32941 Mdot
.8 .80784 Mdot
.78431 .80392 Mdot
.82745 .82353 Mdot
.62353 .60392 Mdot
.2549 .26275 Mdot
.61176 .61569 Mdot
.53725 .58039 Mdot
.6902 .73333 Mdot
.87451 .87843 Mdot
.89804 .9098 Mdot
.95686 .96863 Mdot
.39608 .44314 Mdot
.23922 .28627 Mdot
.9098 .93725 Mdot
.62353 .66667 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
0000017ooooo]Ol0000;ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`2aooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003ooooooooo
o`0Qooooo`03oomo0?oooooooooo08gooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`0Uooooo`03oj0Pl?oooooooooo02Wooooo00?oX23`ooooooooool0GOooool00ol0003ooooooooo
o`09ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2aoooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool09oooool00onP8?3oooooooooo`0=oooo
o`03oj0Pl?oooooooooo07Oooooo00?o0000ooooooooool02Oooool000[ooooo00<00000oooooooo
ool0/Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool02Oooool000[ooooo00<00000ooooooooool0/Oooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Kooooo00?oX23`ooooooooool0@Oooool00onP8?3oooooooooo`1Tooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo0;7ooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03oj0Pl?oooooooooo01Sooooo00?oX23`ooooooooool0R_oo
ool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2aooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool2oj0Pl1_ooooo00?oX23`ooooooooool07Oooool0
0onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo06Cooooo00?o0000ooooooooool02Oooool0
00[ooooo00<00000ooooooooool04?ooool00oooO`3oooooooooo`2Nooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0<_ooool00onP8?3oooooooooo`1looooo`03o`000?oooooooooo
00Wooooo000:ooooo`0300000?oooooooooo00oooooo00?oogl0ooooooooool0Woooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?oX23`ooooooooool06_ooool00onP8?3o
ooooooooo`09ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool05_ooool00onP8?3o
ooooooooo`1Kooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo00cooooo
00?oogl0ooooooooool05oooool00oooO`3oooooooooo`28ooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool04Oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo01oooooo
00GoX23`oooooooooooooooooj0Pl01`ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000
0?oooooooooo01Cooooo00?oogl0ooooooooool0V_ooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo00[ooooo00?oX23`oooooonP8?00:oooool01OnP8?3oooooooooooooooooX23`00Go
oooo00?oX23`ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003ooooo
ooooo`0/ooooo`03oomo0?oooooooooo08;ooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`0<ooooo`03oj0Pl?oooooooooo00Kooooo00GoX23`oooooooooooooooooj0Pl00Eooooo`03
oj0Pl?oooooooooo00Gooooo00CoX23`ooooooooooooX23`7Oooool00onP8?3oooooooooo`1Foooo
o`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo01Wooooo00?oogl0oooooooo
ool0UOooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?oX23`oooooooo
ool00_ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo01gooooo00?oX23`oooooooo
ool00_ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo05Gooooo00?o0000oooooooo
ool02Oooool000[ooooo00<00000ooooooooool05?ooool00oooO`3oooooooooo`0Hooooo`03oomo
0?oooooooooo07oooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03oj0P
l?oooooooooo00Oooooo00?oX23`ooooooooool01oooool00onP8?3oooooooooo`04ooooo`04oj0P
l?oooooooooooj0Pl2Kooooo00?oX23`ooooooooool0G?ooool00ol0003oooooooooo`09ooooo`00
2_ooool00`00003oooooooooo`0@ooooo`05oomo0?ooooooooooooooooooO`003_ooool00oooO`3o
ooooooooo`09ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool0MOooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0_nP8?02ooooo`05oj0Pl?ooooooX23`oooo
oonP8?000_ooool00onP8?3oooooooooo`0=ooooo`04oj0Pl?oooooooooooj0Pl0Cooooo00?oX23`
ooooooooool01?ooool00onP8?3oooooooooo`0@ooooo`04oj0Pl?oooooooooooj0Pl6?ooooo00?o
0000ooooooooool02Oooool000[ooooo00<00000ooooooooool04oooool01_ooO`3ooooooooooooo
O`3ooooooomo09Sooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`;oX23`
00Gooooooj0Pl?nP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`oooooooo
ool0R?ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`0@ooooo`;oogl0
3Oooool00oooO`3oooooooooo`2?ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
4Oooool00onP8?3ooooooj0Pl002ooooo`;oX23`0_ooool00onP8?3oooooooooo`02ooooo`03oj0P
l?oooooooooo01Oooooo00?oX23`ooooooooool0MOooool00ol0003oooooooooo`09ooooo`002_oo
ool00`00003oooooooooo`0@ooooo`;oogl01?ooool3oomo00Gooooo00Koogl0oooooooooooooooo
oomo0?ooool2oomo0003ooooooooO`3ooooo01gooooo00?oogl0ooooooooool0J?ooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?oX23`oooooonP8?000_nP8?001Ooooooo
X23`ooooooooooooX23`00?ooooo0_nP8?05ooooo`03oj0Pl?oooooooooo02kooooo00?oX23`oooo
ooooool0F_ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`0Booooo`03
oomo0?oooooooooo00Cooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0@ooooo`03
oomo0?oooooooooo07cooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Booooo`;o
X23`0_ooool3oj0Pl0Cooooo00?oX23`ooooooooool01?ooool00onP8?3ooooooj0Pl003ooooo`03
oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool08?ooool00onP8?3oooooooooo`1Looooo`03
o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo01Cooooo0oooO`000oooooooogl0
ooooo`02oomo00Cooooo0oooO`07ooooo`03oomo0?oooooooooo01;ooooo00?oogl0ooooooooool0
Koooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?oX23`oooooonP8?00
0_nP8?000oooooooX23`oj0Pl004oj0Pl0Cooooo00?oX23`ooooooooool00_ooool00onP8?3ooooo
ooooo`05ooooo`03oj0Pl?oooooooooo027ooooo00?oX23`ooooooooool0G?ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`00003oooooooooo`0Fooooo`06oomo0?ooooooogl0oomo0?oooooo
ogl00oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo02Sooooo00?oogl0oooooooo
ool0G?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00CoX23`oooooonP
8?3ooooo0onP8?03ooooo`?oX23`7?ooool00onP8?3oooooooooo`0Booooo`03oj0Pl?oooooooooo
00Oooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`13ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`0300000?oooooooooo01Kooooo00?oogl0ooooooooO`000_ooO`001_oooooo
ogl0ooooooooO`3ooooooomo093ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0D
ooooo`?oX23`00?ooooooj0Pl?nP8?000_ooool01?nP8?3ooooooooooonP8?0Rooooo`03oj0Pl?oo
oooooooo06cooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool05?ooool0
1?ooO`3ooooooomo0?ooool5oomo0003ooooooooO`3ooooo00;ooooo00?oogl0ooooooooool08Ooo
ool00oooO`3oooooooooo`1Xooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool05Ooo
ool;oj0Pl0?ooooo00CoX23`ooooooooooooX23`R_ooool00ol0003oooooooooo`09ooooo`002_oo
ool00`00003oooooooooo`0Eooooo`04oomo0?oooooooooooomo00;ooooo00?oogl0ooooooooO`00
0_ooool00oooO`3ooooooomo002>ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
6?ooool02?nP8?3ooooooj0Pl?nP8?3ooooooj0Pl?ooooooX23`0_ooool00onP8?3oooooooooo`0=
ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`1T
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo01_ooooo00Coogl0oooo
ooooO`3oogl00oooool01?ooO`3oooooooooooooO`07ooooo`03oomo0?oooooooooo02_ooooo00?o
ogl0ooooooooool02?ooool00oooO`3oooooooooo`18ooooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool06?ooool8oj0Pl007oooooonP8?3ooooooooooonP8?3ooooooj0Pl00@ooooo`03
oj0Pl?oooooooooo01[ooooo00?oX23`ooooooooool0F_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00`00003oooooooooo`0Jooooo`03oomo0?oooooooooo00;ooooo0_ooO`0aooooo`03oomo
0?oooooooooo01;ooooo0_ooO`18ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0
6_ooool01OnP8?3ooooooj0Pl?nP8?3ooooo00?oX23`00?ooooooj0Pl?nP8?000_ooool2oj0Pl0;o
oooo00CoX23`ooooooooooooX23`0oooool01?nP8?3ooooooooooonP8?1kooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0300000?oooooooooo01kooooo1oooO`05ooooo`03oomo0?oooooooooo
00gooooo00?oogl0ooooooooool02_ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo
00;ooooo00?oogl0ooooooooool01Oooool01oooO`3oooooooooooooO`3ooooooomo0?ooool00_oo
O`04ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool0?oooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Sooooo00CoX23`oooooonP8?3ooooo0onP8?02ooooo`03oj0P
l?ooooooX23`00[ooooo0onP8?02ooooo`03oj0Pl?ooooooX23`00;ooooo00GoX23`oooooooooooo
oooooj0Pl00Looooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool0BOooool00ol0003o
ooooooooo`09ooooo`002_ooool00`00003oooooooooo`0Qooooo`05oomo0?oooooooooooooooooo
O`001oooool01OooO`3oooooooooooooooooogl0027ooooo00?oogl0ooooooooool01Oooool01Ooo
O`3oooooooooooooooooogl0057ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0M
ooooo`07oj0Pl?ooooooX23`oooooonP8?3ooooooj0Pl00Aooooo`03oj0Pl?ooooooX23`07Wooooo
00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool08Oooool4oomo01Cooooo00?o
ogl0ooooooooool01_ooool00oooO`3oooooooooo`0Gooooo`03oomo0?oooooooooo017ooooo00?o
ogl0ooooooooool01_ooool00oooO`3oooooooooo`0eooooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool06?ooool01?nP8?3oooooooooooooool2oj0Pl003oooooonP8?3ooooo00;oX23`
00?ooooooj0Pl?ooool03oooool00onP8?3oooooooooo`1iooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0300000?oooooooooo01kooooo00Ooogl0oooooooooooooooooomo0?ooooooogl000Oo
oooo00?oogl0ooooooooool04Oooool00oooO`3oooooooooo`02ooooo`05oomo0?oooooooooooooo
ooooO`001?ooool00oooO`3ooooooomo0002ooooo`03oomo0?ooooooogl000?ooooo00?oogl0oooo
ooooool00_ooool01?ooO`3oooooooooooooO`0<ooooo`04oomo0?ooooooogl0oomo03oooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo
00?oX23`ooooooooool01_ooool01?nP8?3ooooooooooonP8?03ooooo`03oj0Pl?oooooooooo00Wo
oooo00?oX23`ooooooooool01?ooool2oj0Pl6Wooooo00?o0000ooooooooool02Oooool000[ooooo
00<00000ooooooooool08_ooool01?ooO`3oooooooooooooO`0Dooooo`03oomo0?oooooooooo00co
oooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`06ooooo`;oogl00_ooool00oooO`3o
oooooomo000:ooooo`04oomo0?oooooooooooomo00;ooooo0_ooO`0hooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool07oooool00onP8?3oooooooooo`0Jooooo`03oj0Pl?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool08oooool3oomo0004
ooooooooO`3ooooooomo00Oooooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`06oooo
o`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooO`001?ooool00oooO`3ooooooomo000?oooo
o`07oomo0?ooooooogl0ooooooooO`3ooooooomo000looooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool06Oooool00onP8?3oooooooooo`03ooooo`CoX23`0oooool2oj0Pl0;ooooo00?o
X23`ooooooooool03oooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00?ooooo00?o
X23`ooooooooool01?ooool00onP8?3oooooooooo`1Mooooo`03o`000?oooooooooo00Wooooo000:
ooooo`0300000?oooooooooo02Cooooo00Googl0oooooooooooooooooomo0007ooooo`03oomo0?oo
oooooooo00[ooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`03ooooo`;oogl01ooo
ool01OooO`3oooooooooooooooooogl001;ooooo0oooO`0jooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool08Oooool2oj0Pl005oooooonP8?3ooooooj0Pl?ooool00_nP8?08ooooo`03
oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`0;ooooo`03
oj0Pl?oooooooooo05Gooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0
8oooool3oomo01cooooo00?oogl0ooooooooool01_ooool00oooO`3oooooooooo`1Sooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool08Oooool00onP8?3oooooooooo`04ooooo`;oX23`
1_ooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?ooooooX23`01kooooo00?oX23`ooooooooool0
2Oooool00onP8?3oooooooooo`14ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oo
oooooooo02;ooooo00?oogl0ooooooooool00oooO`000oooooooogl0oomo000Dooooo`03oomo0?oo
ooooogl000Kooooo00?oogl0ooooooooool06_ooool00oooO`3oooooooooo`02oomo00?ooooo00?o
ogl0ooooooooool01?ooool01OooO`3oooooooooooooO`3ooooo00;oogl0=_ooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo027ooooo00CoX23`ooooooooooooX23`1?ooool2oj0Pl0;o
oooo00?oX23`ooooooooool00_ooool01?nP8?3ooooooooooonP8?0@ooooo`03oj0Pl?oooooooooo
00?ooooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo
00Kooooo00?oX23`ooooooooool0A?ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`0Wooooo`05oomo0?ooooooogl0ooooooooO`007_ooool00oooO`3ooooooomo000?oooo
o`04oomo0?oooooooooooomo00[ooooo00Coogl0ooooooooooooogl0@oooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo027ooooo00GoX23`ooooooooooooX23`ooooo`02oj0Pl004oooo
oonP8?3ooooooj0Pl8Gooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0
9_ooool01?ooO`3ooooooomo0?ooO`09ooooo`03oomo0?ooooooogl000?ooooo00?oogl0oooooooo
ool04oooool01?ooO`3oooooooooooooO`05ooooo`05oomo0?ooooooooooooooooooO`000_ooool0
1?ooO`3oooooooooooooO`05ooooo`;oogl00oooool2oomo00Oooooo0_ooO`08ooooo`03oomo0?oo
oooooooo00;ooooo00?oogl0ooooooooool0:Oooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo02?ooooo2onP8?06ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`ooooooooool04Ooo
ool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`ooooooooool01Ooo
ool00onP8?3oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooo
oooo03Sooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`0[ooooo`03oomo0?oooooo
oooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`0Zooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool09oooool00onP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooo
oooo00Sooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`1`ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0300000?oooooooooo02cooooo00?oogl0ooooooooool03oooool00ooo
O`3oooooooooo`0Eooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool01oooool00ooo
O`3oooooooooo`08ooooo`;oogl0>Oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo
02Cooooo0_nP8?000oooooooX23`oj0Pl002ooooo`03oj0Pl?oooooooooo00?oX23`0oooool00onP
8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00;ooooo0onP8?02ooooo`03oj0Pl?oooooooooo
00Oooooo00?oX23`ooooooooool06Oooool00onP8?3oooooooooo`12ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`0300000?oooooooooo02Wooooo00?oogl0ooooooooool00_ooool01?ooO`3o
ooooooooooooO`08ooooo`;oogl03?ooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooooooo
00;ooooo00?oogl0ooooooooool00oooool01?ooO`3oooooooooooooool2oomo0003ooooooooO`3o
oooo00;ooooo00?oogl0ooooooooO`000_ooool00oooO`3ooooooomo0006ooooo`03oomo0?oooooo
oooo00;ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Wooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool0:Oooool3oj0Pl003oooooonP8?3oX23`00kooooo00?oX23`
ooooooooool02Oooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00cooooo00GoX23`
oooooooooooooooooj0Pl008ooooo`03oj0Pl?oooooooooo04?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00<00000ooooooooool0;?ooool00oooO`3oooooooooo`0=ooooo`03oomo0?oooooo
oooo00Oooooo00?oogl0ooooooooool05Oooool2oomo057ooooo00<00000ooooooooool03oooool0
0ol0003oooooooooo`0Xooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo00GoX23`oooooonP8?3ooooo
oj0Pl00Qooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool02_ooool00onP8?3ooooo
ooooo`11ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo02[ooooo0_oo
O`000oooooooogl0oomo0002ooooo`03oomo0?oooooooooo00Sooooo0_ooO`0Dooooo`04oomo0?oo
oooooooooomo00gooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`02ooooo`;oogl0
0oooool2oomo0003ooooooooO`3oogl000Kooooo00Coogl0ooooooooO`3ooooo0_ooO`04ooooo`?o
ogl09_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?oX23`oooooooo
ool01?ooool6oj0Pl003oooooonP8?3ooooo00Sooooo00?oX23`ooooooooool01?ooool00onP8?3o
ooooooooo`08ooooo`;oX23`1?ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?ooooooX23`00co
oooo00?oX23`oooooonP8?005?ooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?ooooooX23`01[o
oooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0;Oooool01?ooO`3ooooo
ooooooooO`0:ooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool02oooool01oooO`3o
ooooooooooooooooogl0ooooooooO`000oooool00oooO`3oooooooooo`05ooooo`05oomo0?oooooo
ooooooooooooO`000_ooool00oooO`3oooooooooo`03ooooo`04oomo0?oooooooooooomo00;ooooo
00?oogl0ooooooooool00oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00Cooooo
00?oogl0ooooooooool09?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo
00?oX23`ooooooooool00oooool01OnP8?3oooooooooooooooooX23`01Wooooo00CoX23`oooooooo
ooooX23`9oooool00onP8?3oooooooooo`0Iooooo`;oX23`6Oooool00ol0003oooooooooo`09oooo
o`002_ooool00`00003oooooooooo`0aooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
O`002Oooool00oooO`3oooooooooo`08ooooo`;oogl03Oooool00oooO`3oooooooooo`02ooooo`03
oomo0?oooooooooo00Kooooo0_ooO`03ooooo`03oomo0?oooooooooo00?ooooo00Coogl0oooooooo
ooooogl01_ooool01OooO`3ooooooomo0?ooooooogl000;ooooo00Coogl0ooooooooooooogl02Ooo
ool00oooO`3ooooooomo000Kooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0:Ooo
ool00onP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`ooooooooool01Ooo
ool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool03_oo
ool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo01_ooooo00?oX23`ooooooooool05Ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`0/ooooo`03oomo0?oooooo
ogl000Cooooo00?oogl0ooooooooool01?ooool01OooO`3oooooooooooooooooogl000cooooo00?o
ogl0ooooooooool01Oooool01?ooO`3oooooooooooooO`0=ooooo`03oomo0?oooooooooo00Cooooo
00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`04ooooo`;oogl000?ooooooomo0?ooool0
2?ooool00oooO`3ooooooomo0002ooooo`04oomo0?ooooooooooooooo`?oogl000Gooooooomo0?oo
oooooooooomo000Jooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00onP
8?3oooooooooo`02oj0Pl0Gooooo00?oX23`ooooooooool05Oooool00onP8?3oooooooooo`06oooo
o`03oj0Pl?oooooooooo02[ooooo00?oX23`ooooooooool02?ooool00onP8?3oooooooooo`04oooo
o`03oj0Pl?oooooooooo01Wooooo00?o0000ooooooooool02Oooool000[ooooo00<00000oooooooo
ool0<Oooool00oooO`3oooooooooo`0Booooo`03oomo0?oooooooooo00Wooooo00?oogl0oooooooo
ool04oooool00oooO`3oooooooooo`0:ooooo`07oomo0?ooooooooooooooooooO`3ooooooomo0003
ooooo`03oomo0?oooooooooo00Gooooo00Coogl0ooooooooooooogl01_ooool2oomo01kooooo00<0
0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`03oj0Pl?oooooooooo00kooooo00?o
X23`ooooooooool06?ooool00onP8?3oooooooooo`0Qooooo`03oj0Pl?oooooooooo00?ooooo00?o
X23`oooooonP8?00:?ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`0`
ooooo`04oomo0?oooooooooooomo00Cooooo00?oogl0ooooooooool03Oooool01OooO`3ooooooooo
ooooooooogl000?ooooo00?oogl0ooooooooool02Oooool00oooO`3ooooooomo0004ooooo`;oogl0
00?ooooooomo0?ooool00oooool02OooO`3oooooooooooooooooogl0ooooooooO`3ooooooomo0007
ooooo`03oomo0?ooooooogl000?ooooo00Coogl0oooooooooooooooo0_ooO`03ooooo`04oomo0?oo
ooooooooooooo`Coogl000?ooooooomo0?ooool00_ooO`000oooooooogl0ooooo`0Gooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool0<Oooool01OnP8?3oooooooooooooooooX23`02So
oooo00?oX23`ooooooooool03oooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?oooooooooo00oo
oooo00?oX23`oooooonP8?001_ooool3oj0Pl003oooooonP8?3ooooo01?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00<00000ooooooooool0@_ooool00oooO`3oooooooooo`0Eooooo`03oomo
0?oooooooooo00Gooooo00?oogl0ooooooooool03oooool00oooO`3oooooooooo`02ooooo`03oomo
0?ooooooogl000;ooooo00Googl0oooooooooooooooooomo0008ooooo`;oogl000?ooooooomo0?oo
O`000_ooO`04ooooo`03oomo0?oooooooooo01Sooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`0/ooooo`03oj0Pl?ooooooX23`00;ooooo00?oX23`oooooonP8?00;Oooool00onP8?3o
ooooooooo`05ooooo`05oj0Pl?oooooooooooooooonP8?002?ooool2oj0Pl1gooooo00CoX23`oooo
ooooooooX23`0_ooool2oj0Pl1Cooooo00?o0000ooooooooool02Oooool000[ooooo00<00000oooo
ooooool0>Oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo01Cooooo00?oogl0oooo
ooooool00oooool01?ooO`3ooooooomo0?ooO`03ooooo`04oomo0?oooooooooooomo00?ooooo0_oo
O`000oooooooogl0ooooo`02ooooo`03oomo0?oooooooooo00Cooooo0_ooO`000oooooooogl0oooo
o`03ooooo`;oogl000Gooooooomo0?oooooooooooomo0002ooooo`;oogl00_ooool5oomo0003oooo
ooooO`3ooooo01[ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03oj0P
l?oooooooooo00;ooooo0_nP8?03ooooo`05oj0Pl?ooooooX23`oooooonP8?000oooool01OnP8?3o
ooooooooooooooooX23`00Gooooo00?oX23`ooooooooool02?ooool01onP8?3ooooooooooooooooo
X23`oooooonP8?003Oooool00onP8?3ooooooj0Pl004ooooo`;oX23`2_ooool01OnP8?3ooooooooo
ooooooooX23`00Oooooo00?oX23`ooooooooool02oooool01?nP8?3ooooooj0Pl?ooool2oj0Pl0?o
oooo0_nP8?000oooooooX23`oj0Pl00Cooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000
0?oooooooooo043ooooo00Googl0oooooooooooooooooomo0002ooooo`03oomo0?oooooooooo01Wo
oooo00Coogl0ooooooooooooogl01_ooool00oooO`3oooooooooo`02oomo013ooooo00?oogl0oooo
ooooool01oooool2oomo00;ooooo00Coogl0ooooooooooooogl07Oooool00`00003oooooooooo`0?
ooooo`03o`000?oooooooooo037ooooo00CoX23`ooooooooooooX23`0_ooool00onP8?3ooooooooo
o`0Eooooo`03oj0Pl?oooooooooo03Cooooo00?oX23`ooooooooool04Oooool00onP8?3ooooooooo
o`0Dooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo06?ooooo00?oogl0
ooooooooool03?ooool3oomo00Kooooo00?oogl0ooooooooO`001Oooool00oooO`3ooooooomo0004
ooooo`?oogl00oooool2oomo01oooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0o
ooooo`03oj0Pl?oooooooooo03Sooooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`0B
ooooo`;oX23`00?ooooooj0Pl?ooool05Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00
003oooooooooo`0jooooo`;oogl01oooool2oomo013ooooo00?oogl0ooooooooool02oooool01Ooo
O`3oooooooooooooooooogl000Cooooo0_ooO`0;ooooo`03oomo0?oooooooooo00Wooooo00?oogl0
ooooooooO`001Oooool5oomo0005ooooooooO`3oooooooooooooO`006_ooool00`00003ooooooooo
o`0?ooooo`03o`000?oooooooooo03Cooooo00WoX23`oooooooooooooooooj0Pl?ooooooX23`oooo
oonP8?004Oooool01_nP8?3ooooooooooonP8?3ooooooj0Pl0Sooooo00?oX23`oooooonP8?001ooo
ool00onP8?3oooooooooo`0=ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01?oo
ool00onP8?3oooooooooo`03ooooo`07oj0Pl?oooooooooooooooonP8?3ooooooj0Pl002ooooo`;o
X23`1?ooool01?nP8?3ooooooooooonP8?02ooooo`03oj0Pl?oooooooooo00oooooo00?o0000oooo
ooooool02Oooool000[ooooo00<00000ooooooooool0Aoooool00oooO`3oooooooooo`0@ooooo`03
oomo0?oooooooooo00;ooooo00?oogl0ooooooooO`004_ooool00oooO`3ooooooomo0004ooooo`03
oomo0?oooooooooo00;ooooo00?oogl0ooooooooool01oooool00oooO`3ooooooomo000Tooooo`03
00000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool00onP8?3oooooooooo`0[ooooo`03
oj0Pl?oooooooooo02?ooooo00?oX23`ooooooooool01?ooool01?nP8?3ooooooooooonP8?08oooo
o`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool03oooool00ol0003oooooooooo`09oooo
o`002_ooool00`00003oooooooooo`1;ooooo`05oomo0?ooooooooooooooooooO`003Oooool00ooo
O`3ooooooomo000:ooooo`;oogl000?ooooooomo0?ooool01?ooool01?ooO`3oooooooooooooO`02
ooooo`;oogl00oooool00oooO`3ooooooomo0004ooooo`03oomo0?ooooooogl000;ooooo00?oogl0
ooooooooool00_ooool01OooO`3ooooooomo0?ooooooogl001gooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`0fooooo`07oj0Pl?oooooooooooooooonP8?3ooooooj0Pl00:ooooo`03
oj0Pl?oooooooooo00oooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0Booooo`04
oj0Pl?oooooooooooj0Pl0Cooooo00?oX23`ooooooooool01_ooool01?nP8?3ooooooooooonP8?02
ooooo`03oj0Pl?ooooooX23`00gooooo00?oX23`oooooonP8?000oooool00onP8?3oooooooooo`0>
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo03_ooooo00?oogl0oooo
ooooool04?ooool00oooO`3oooooooooo`05ooooo`05oomo0?ooooooooooooooooooO`002oooool0
0oooO`3oooooooooo`02ooooo`05oomo0?ooooooogl0ooooooooO`004Oooool00oooO`3ooooooomo
0008ooooo`04oomo0?ooooooogl0oomo027ooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`0^ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool00_ooool2oj0Pl0Cooooo
00?oX23`ooooooooool0D_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo01Cooooo
00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0>_ooool00oooO`3ooooooooo
o`02ooooo`03oomo0?oooooooooo01;ooooo00?oogl0ooooooooO`000_ooool00oooO`3ooooooooo
o`07ooooo`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooO`001Oooool00oooO`3ooooooomo
000Hooooo`03oomo0?oooooooooo01cooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`0`ooooo`03oj0Pl?oooooooooo00Wooooo0_nP8?02ooooo`;oX23`1?ooool00onP8?3ooooooooo
o`0<ooooo`;oX23`00?ooooooj0Pl?ooool00_ooool01OnP8?3oooooooooooooooooX23`00?ooooo
0_nP8?0;ooooo`04oj0Pl?oooooooooooj0Pl0Kooooo00?oX23`ooooooooool03Oooool00onP8?3o
ooooooooo`03ooooo`03oj0Pl?oooooooooo00;ooooo00GoX23`ooooooooooooX23`ooooo`02oj0P
l0;ooooo00CoX23`ooooooooooooX23`3_ooool00ol0003oooooooooo`09ooooo`002_ooool00`00
003oooooooooo`1Eooooo`03oomo0?oooooooooo00gooooo00?oogl0ooooooooool02Oooool00ooo
O`3oooooooooo`0?ooooo`05oomo0?ooooooooooooooooooO`000_ooool00oooO`3oooooooooo`0T
ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00onP8?3oooooooooo`0R
ooooo`03oj0Pl?oooooooooo013ooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`06
ooooo`03oj0Pl?oooooooooo01Kooooo00?oX23`ooooooooool00_ooool2oj0Pl0;ooooo00?oX23`
ooooooooool02oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`1>oooo
o`05oomo0?ooooooogl0ooooooooO`000_ooool00oooO`3oooooooooo`06ooooo`05oomo0?oooooo
ogl0ooooooooO`004Oooool00oooO`3oooooooooo`0:ooooo`03oomo0?oooooooooo00Cooooo00?o
ogl0ooooooooool09_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo00Go
X23`ooooooooooooX23`ooooo`02oj0Pl0;ooooo0_nP8?0Oooooo`03oj0Pl?oooooooooo00?ooooo
00?oX23`ooooooooool04_ooool00onP8?3oooooooooo`06ooooo`04oj0Pl?oooooooooooj0Pl0go
oooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00co
oooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0?Oooool2oomo00Gooooo
00?oogl0ooooooooool00oooool01OooO`3oooooooooooooooooogl000Sooooo00?oogl0oooooooo
O`000oooool2oomo0003ooooooooO`3ooooo00;ooooo00?oogl0ooooooooool01Oooool00oooO`3o
ooooooooo`0:ooooo`?oogl01Oooool01?ooO`3ooooooomo0?ooO`03ooooo`03oomo0?oooooooooo
02Kooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oj0Pl?oooooooooo
00;ooooo00?oX23`oooooonP8?001_ooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo
00Oooooo00GoX23`oooooonP8?3ooooooj0Pl007ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`
ooooooooool01_ooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo00?ooooo00GoX23`
oooooooooooooooooj0Pl002ooooo`03oj0Pl?oooooooooo00?ooooo00CoX23`ooooooooooooX23`
0_ooool2oj0Pl0[ooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0?ooo
ool00oooO`3oooooooooo`03ooooo`04oomo0?oooooooooooomo02Kooooo00?oogl0ooooooooool0
4_ooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooooooo01_ooooo00<00000ooooooooool0
3oooool00ol0003oooooooooo`0looooo`;oX23`;?ooool01?nP8?3ooooooooooonP8?0^ooooo`04
oj0Pl?oooooooooooj0Pl0Kooooo00?oX23`ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`002_ooool00`00003oooooooooo`14ooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
O`000_ooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo00;ooooo00Coogl0oooooooo
O`3oogl03_ooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo00Gooooo00?oogl0oooo
ooooool03oooool00oooO`3oooooooooo`0Looooo`0300000?oooooooooo00oooooo00?o0000oooo
ooooool0?Oooool2oj0Pl0;ooooo0_nP8?06ooooo`;oX23`7_ooool00onP8?3oooooooooo`05oooo
o`03oj0Pl?oooooooooo01Oooooo00CoX23`oooooooooooooooo0_nP8?04ooooo`03oj0Pl?oooooo
X23`00Kooooo00?oX23`oooooonP8?000_ooool4oj0Pl0[ooooo00?o0000ooooooooool02Oooool0
00[ooooo00<00000ooooooooool0Q?ooool01OooO`3oooooooooooooooooogl002Sooooo00<00000
ooooooooool03oooool00ol0003oooooooooo`11ooooo`03oj0Pl?ooooooX23`01Oooooo00?oX23`
ooooooooool01Oooool00onP8?3oooooooooo`0iooooo`;oX23`0_ooool01_nP8?3ooooooooooonP
8?3ooooooj0Pl0Sooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0?Ooo
ool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo00gooooo00?oogl0ooooooooool02_oo
ool2oomo0003ooooooooO`3ooooo00;ooooo00?oogl0ooooooooool01Oooool2oomo00cooooo0_oo
O`000oooooooogl0ooooo`04ooooo`03oomo0?ooooooogl002Wooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`1<ooooo`03oj0Pl?oooooooooo00oooooo00?oX23`oooooonP8?007Ooo
ool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00_ooooo0_nP8?0=ooooo`04oj0Pl?oo
ooooX23`oj0Pl0cooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0>?oo
ool00oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00;oogl00oooool00oooO`3ooooooooo
o`0Gooooo`03oomo0?oooooooooo01Cooooo0_ooO`02ooooo`03oomo0?oooooooooo00cooooo00?o
ogl0ooooooooool01Oooool00oooO`3oooooooooo`0Gooooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool0?_ooool2oj0Pl0Cooooo00?oX23`oooooonP8?004Oooool00onP8?3ooooooooo
o`03ooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`ooooooooool00_ooool00onP8?3ooooooooo
o`04ooooo`;oX23`1Oooool2oj0Pl0?ooooo0_nP8?0>ooooo`03oj0Pl?ooooooX23`00?ooooo00Co
X23`oooooonP8?3ooooo1?nP8?001?ooooooX23`oj0Pl?nP8?02ooooo`03oj0Pl?oooooooooo00Ko
oooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0?oooool00oooO`3ooooo
ooooo`04ooooo`03oomo0?oooooooooo01Kooooo00?oogl0ooooooooool01Oooool2oomo00gooooo
00?oogl0ooooooooool0>?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo
00?oX23`ooooooooool07Oooool00onP8?3oooooooooo`0Sooooo`;oX23`0_ooool2oj0Pl003oooo
oonP8?3ooooo00Sooooo00SoX23`oooooonP8?3oX23`oooooonP8?3ooooooj0Pl0[ooooo00?o0000
ooooooooool02Oooool000[ooooo00<00000ooooooooool0C?ooool01OooO`3ooooooooooooooooo
ogl000?ooooo00?oogl0ooooooooool00_ooool2oomo00?ooooo00Googl0oooooooooooooooooomo
0002ooooo`;oogl01Oooool01?ooO`3oooooooooooooO`06ooooo`06oomo0?oooooooooooomo0?oo
ooooogl01Oooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo01oooooo00<00000oooo
ooooool03oooool00ol0003oooooooooo`15ooooo`;oX23`4oooool2oj0Pl1Cooooo0onP8?09oooo
o`03oj0Pl?oooooooooo00?ooooo00?oX23`oooooonP8?000oooool01OnP8?3ooooooooooooooooo
X23`00Gooooo0_nP8?001?ooooooX23`oooooonP8?04ooooo`03oj0Pl?oooooooooo00;ooooo2?nP
8?08ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo04;ooooo00?oogl0
ooooooooool01Oooool00oooO`3oooooooooo`09ooooo`;oogl01oooool01?ooO`3ooooooooooooo
O`0Cooooo`05oomo0?ooooooooooooooooooO`004Oooool00oooO`3oooooooooo`04ooooo`04oomo
0?oooooooooooomo01[ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`12ooooo`03
oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool06Oooool01OnP8?3oooooooooooooooooX23`
00Oooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?oooooooooo
00Wooooo0_nP8?07ooooo`?oX23`00?ooooooj0Pl?ooool02?ooool00ol0003oooooooooo`09oooo
o`002_ooool00`00003oooooooooo`12ooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
ool04?ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00?ooooo00?oogl0oooooooo
ool04_ooool00oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo00Cooooo00?oogl0oooooooo
ool08?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo04?ooooo0_nP8?05ooooo`05
oj0Pl?ooooooX23`oooooonP8?003?ooool00onP8?3ooooooj0Pl00<ooooo`03oj0Pl?oooooooooo
00;ooooo00CoX23`ooooooooooooX23`2_ooool01?nP8?3ooooooj0Pl?nP8?09ooooo`;oX23`0_oo
ool00onP8?3oooooooooo`02ooooo`06oj0Pl?oooooooooooooooonP8?3ooooo0_nP8?02ooooo`04
oj0Pl?ooooooX23`ooooo`SoX23`2?ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`19ooooo`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooool01_ooool00oooO`3o
ooooooooo`02ooooo`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooool0?_ooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo04?ooooo00?oX23`ooooooooool01?ooool01?nP8?3o
oooooooooonP8?0iooooo`03oj0Pl?oooooooooo01Gooooo0_nP8?000oooooooX23`ooooo`02oooo
o`04oj0Pl?ooooooX23`oj0Pl0Oooooo00?o0000ooooooooool02Oooool000[ooooo00<00000oooo
ooooool0COooool4oomo00Cooooo00?oogl0ooooooooO`000oooool00oooO`3oooooooooo`08oooo
o`03oomo0?oooooooooo01gooooo00Googl0oooooooooooooooooomo000Vooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool0BOooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooo
oooo01;ooooo00?oX23`ooooooooool06_ooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?oooooo
oooo00Gooooo00GoX23`oooooooooooooooooj0Pl002ooooo`06oj0Pl?ooooooX23`oj0Pl?oooooo
X23`2?ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`1:ooooo`;oogl0
1oooool00oooO`3ooooooomo0006ooooo`04oomo0?ooooooooooooooo`?oogl01?ooool01OooO`3o
oooooomo0?ooooooogl000Wooooo00Googl0ooooooooooooogl0ooooo`02oomo00;ooooo00?oogl0
ooooooooool05Oooool00oooO`3oooooooooo`0Hooooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0G?ooool00onP8?3oooooooooo`02ooooo`05oj0Pl?oooooooooooooooonP8?003Ooo
ool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo00Cooooo00GoX23`oooooonP8?3ooooo
oj0Pl002ooooo`04oj0Pl?ooooooooooooooo`;oX23`1?ooool01?nP8?3ooooooj0Pl?nP8?02oooo
o`OoX23`0_ooool00onP8?3ooooooj0Pl003oj0Pl0Oooooo00?o0000ooooooooool02Oooool000[o
oooo00<00000ooooooooool0AOooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo00[o
oooo00?oogl0ooooooooO`001Oooool00oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo047o
oooo00<00000ooooooooool03oooool00ol0003oooooooooo`13ooooo`03oj0Pl?oooooooooo00;o
oooo00?oX23`ooooooooool04oooool00onP8?3oooooooooo`0Dooooo`03oj0Pl?oooooooooo00So
oooo00GoX23`oooooonP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`oooo
ooooool03_ooool01onP8?3ooooooj0Pl?nP8?3ooooooj0Pl?ooool00onP8?06ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`0300000?oooooooooo04Wooooo0_ooO`05ooooo`;oogl00oooool0
0oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool02oooool0
0oooO`3oooooooooo`04ooooo`04oomo0?oooooooooooomo00gooooo00?oogl0ooooooooool07Ooo
ool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo04[ooooo0_nP8?000oooooooX23`oooo
o`0Pooooo`03oj0Pl?oooooooooo017ooooo00?oX23`ooooooooool00_nP8?09ooooo`04oj0Pl?oo
ooooX23`oj0Pl0;ooooo00?oX23`ooooooooool00_ooool2oj0Pl0?ooooo00CoX23`oooooooooooo
oooo1_nP8?000oooooooX23`ooooo`03ooooo`03o`000?oooooooooo00Wooooo000:ooooo`030000
0?oooooooooo04cooooo00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`02ooooo`03oomo
0?oooooooooo00Gooooo00?oogl0ooooooooool01?ooool2oomo04Oooooo00<00000ooooooooool0
3oooool00ol0003oooooooooo`18ooooo`03oj0Pl?oooooooooo00Cooooo00CoX23`oooooooooooo
X23`6Oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`oooooooo
ool02oooool01?nP8?3ooooooooooonP8?02ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`oooo
ooooool01_ooool00onP8?3oooooooooo`04ooooo`08oj0Pl?oooooooooooj0Pl?ooooooX23`oooo
oonP8?06ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo04Cooooo00?o
ogl0ooooooooool01oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00cooooo00?o
ogl0ooooooooool08_ooool00oooO`3oooooooooo`0Vooooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool0B_ooool01OnP8?3oooooooooooooooooX23`01gooooo00?oX23`ooooooooool0
1?ooool00onP8?3oooooooooo`0Fooooo`03oj0Pl?oooooooooo00Kooooo00KoX23`oooooooooooo
X23`oooooonP8?05ooooo`03oj0Pl?oooooooooo00Gooooo00CoX23`ooooooooooooX23`1Oooool0
0ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`1?ooooo`03oomo0?ooooooogl0
00Cooooo00?oogl0ooooooooO`001_ooool00oooO`3ooooooomo0006ooooo`03oomo0?oooooooooo
00;oogl000Gooooooomo0?oooooooooooomo0003ooooo`03oomo0?oooooooooo017ooooo00?oogl0
ooooooooool04Oooool00oooO`3oooooooooo`0Aooooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0B_ooool2oj0Pl0?ooooo00?oX23`ooooooooool00_nP8?0<ooooo`03oj0Pl?oooooo
oooo00Gooooo00?oX23`ooooooooool01oooool01?nP8?3ooooooooooonP8?03ooooo`03oj0Pl?oo
oooooooo00?ooooo00CoX23`ooooooooooooX23`0_ooool01?nP8?3ooooooj0Pl?nP8?05ooooo`?o
X23`2?ooool2oj0Pl0Kooooo0onP8?02ooooo`?oX23`0_ooool00onP8?3oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo04Wooooo00?oogl0ooooooooool0
0_ooool2oomo00;ooooo00?oogl0ooooooooool01oooool00oooO`3oooooooooo`0>ooooo`03oomo
0?ooooooogl000Gooooo00?oogl0ooooooooool06Oooool00oooO`3ooooooomo000Mooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool0A?ooool00onP8?3oooooooooo`08ooooo`05oj0P
l?oooooooooooooooonP8?003?ooool00onP8?3oooooooooo`0dooooo`;oX23`1_ooool00onP8?3o
oooooj0Pl003ooooo`03oj0Pl?oooooooooo00;oX23`00?ooooooj0Pl?ooool01?ooool00ol0003o
ooooooooo`09ooooo`002_ooool00`00003oooooooooo`1Aooooo`03oomo0?ooooooogl000?ooooo
00?oogl0ooooooooool00_ooool2oomo00?ooooo00?oogl0ooooooooool02Oooool3oomo0003oooo
ooooO`3oogl000;ooooo1?ooO`02ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool0
0_ooool00oooO`3oooooooooo`0Booooo`03oomo0?oooooooooo00oooooo00<00000ooooooooool0
3oooool00ol0003oooooooooo`1=ooooo`03oj0Pl?ooooooX23`00Sooooo00?oX23`ooooooooool0
1?ooool00onP8?3ooooooj0Pl003ooooo`03oj0Pl?ooooooX23`00Cooooo0_nP8?08ooooo`03oj0P
l?oooooooooo013ooooo00KoX23`oooooonP8?3oX23`oooooonP8?02ooooo`05oj0Pl?ooooooX23`
oooooonP8?000oooool2oj0Pl0Cooooo00CoX23`oooooonP8?3oX23`1_ooool00onP8?3ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo05Kooooo00?oogl0
ooooooooool02oooool00oooO`3ooooooomo0004ooooo`04oomo0?oooooooooooomo00;ooooo00Co
ogl0ooooooooooooogl04?ooool00oooO`3oooooooooo`0Yooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool0COooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo01[ooooo
00?oX23`ooooooooool05?ooool01?nP8?3ooooooooooonP8?04ooooo`04oj0Pl?oooooooooooj0P
l0gooooo00GoX23`oooooonP8?3oX23`ooooo`02oj0Pl0Cooooo00?oX23`ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`15ooooo`03oomo0?oooooooooo
00_ooooo00Googl0oooooooooooooooooomo0004ooooo`07oomo0?oooooooooooomo0?ooooooogl0
ooooo`02oomo0003ooooooooO`3ooooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3ooooo
ooooo`02ooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool03Oooool00oooO`3ooooo
ooooo`06ooooo`03oomo0?oooooooooo01?ooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`1Cooooo`04oj0Pl?oooooooooooj0Pl0Oooooo00?oX23`ooooooooool01_ooool00onP8?3o
ooooooooo`05ooooo`03oj0Pl?oooooooooo00Kooooo00GoX23`oooooooooooooooooj0Pl004oooo
o`03oj0Pl?oooooooooo00Wooooo0onP8?07ooooo`;oX23`1oooool00onP8?3oooooooooo`03oooo
o`04oj0Pl?oooooooooooj0Pl0?ooooo00GoX23`ooooooooooooooooo`00000;ooooo`002_ooool0
0`00003oooooooooo`1Kooooo`?oogl000Gooooooomo0?oooooooooooomo0002ooooo`05oomo0?oo
ooooooooooooooooO`000oooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo00Gooooo
00?oogl0ooooooooool07Oooool00oooO`3oooooooooo`0Dooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool0FOooool00onP8?3oooooooooo`0Wooooo`03oj0Pl?oooooooooo00;ooooo
00?oX23`ooooooooool00oooool00onP8?3oooooooooo`02ooooo`;oX23`2Oooool00onP8?3ooooo
ooooo`03ooooo`03oj0Pl?oooooooooo00[ooooo00?o0000ooooooooool02Oooool000[ooooo00<0
0000ooooooooool0D_ooool01?ooO`3oooooooooooooO`05ooooo`03oomo0?oooooooooo00kooooo
00?oogl0ooooooooool01Oooool01OooO`3ooooooomo0?ooooooogl000;ooooo00?oogl0oooooooo
ool02_ooool00oooO`3oooooooooo`0Vooooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool0E?ooool00onP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`oooooooo
ool06Oooool2oj0Pl003oooooonP8?3ooooo00Oooooo00?oX23`ooooooooool01?ooool00onP8?3o
ooooooooo`02ooooo`03oj0Pl?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000[ooooo
00<00000ooooooooool0E_ooool01?ooO`3oooooooooooooool4oomo0003ooooooooO`3ooooo00?o
ogl00_ooool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo00;ooooo00Coogl0oooooooo
ooooogl00oooool00oooO`3ooooooomo0004ooooo`04oomo0?oooooooooooomo02_ooooo00<00000
ooooooooool03oooool00ol0003oooooooooo`1Cooooo`03oj0Pl?oooooooooo00oooooo0_nP8?0E
ooooo`05oj0Pl?oooooooooooooooonP8?000_ooool00onP8?3oooooooooo`05ooooo`04oj0Pl?oo
ooooX23`oj0Pl0Gooooo0onP8?05ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`1Booooo`03oomo0?oo
oooooooo00Gooooo00?oogl0ooooooooO`001_ooool2oomo00?ooooo00?oogl0ooooooooool01?oo
ool01?ooO`3oooooooooooooO`0Hooooo`03oomo0?oooooooooo02?ooooo00<00000ooooooooool0
3oooool00ol0003oooooooooo`1Booooo`04oj0Pl?ooooooX23`oj0Pl2[ooooo00?oX23`oooooooo
ool02Oooool01OnP8?3oooooooooooooooooX23`00cooooo00?oX23`oooooonP8?001Oooool00onP
8?3oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo05Co
oooo00?oogl0ooooooooool00_ooO`000oooooooogl0oomo0004oomo00Cooooo00?oogl0oooooooo
O`002?ooool2oomo00?ooooo00Ooogl0oooooooooooooooooomo0?ooooooogl000?ooooo00Googl0
oooooooooooooooooomo0004ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool05_oo
ool00oooO`3oooooooooo`06ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0Dooo
ool00onP8?3oooooooooo`03oj0Pl005oooooonP8?3oX23`oooooonP8?002Oooool00onP8?3ooooo
ooooo`0Oooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool00_ooool00onP8?3ooooo
ooooo`04ooooo`03oj0Pl?oooooooooo00gooooo00?oX23`ooooool000002oooool000[ooooo00<0
0000ooooooooool0G_ooool2oomo00?ooooo00?oogl0ooooooooool00_ooool00oooO`3ooooooooo
o`03ooooo`03oomo0?oooooooooo00cooooo00?oogl0ooooooooool00_ooool00oooO`3ooooooooo
o`0Rooooo`03oomo0?oooooooooo00Oooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`1Jooooo`;oX23`2?ooool00onP8?3oooooooooo`0Sooooo`;oX23`0oooool00onP8?3ooooooooo
o`03ooooo`04oj0Pl?ooooooX23`oj0Pl0Cooooo00?oX23`ooooooooool04Oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`00003oooooooooo`1Eooooo`03oomo0?oooooooooo00Gooooo0_oo
O`04ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool02oooool00oooO`3ooooooooo
o`0Jooooo`03oomo0?oooooooooo01Kooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`1Fooooo`03oj0Pl?oooooooooo00kooooo00?oX23`ooooooooool05Oooool00onP8?3ooooooooo
o`04ooooo`03oj0Pl?oooooooooo00oooooo00?oX23`ooooooooool03Oooool00onP8?3ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo05Kooooo0_ooO`02
ooooo`;oogl00_ooool2oomo0005ooooooooO`3oogl0ooooooooO`001Oooool2oomo00Cooooo00Co
ogl0ooooooooooooogl01_ooool01OooO`3oooooooooooooooooogl001Sooooo00?oogl0oooooooo
ool01Oooool00oooO`3oooooooooo`0?ooooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool0FOooool2oj0Pl0[ooooo00?oX23`oooooonP8?001_ooool00onP8?3oooooooooo`07ooooo`04
oj0Pl?ooooooooooooooo`;oX23`00?ooooooj0Pl?ooool01oooool01?nP8?3ooooooooooonP8?04
ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`oooooonP8?005_ooool00onP8?3o0000ooooo`0:
ooooo`002_ooool00`00003oooooooooo`1@ooooo`03oomo0?oooooooooo00Oooooo00Coogl0oooo
ooooO`3oogl01Oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo00_ooooo00?oogl0
ooooooooool09?ooool00oooO`3oooooooooo`0>ooooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0F?ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo02Kooooo00?oX23`
ooooooooool04Oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool000[ooooo00<00000ooooooooool0F_ooool00oooO`3ooooooomo0002oooo
o`;oogl00_ooool3oomo00Gooooo1?ooO`06ooooo`07oomo0?ooooooogl0ooooooooO`3ooooooomo
000Iooooo`;oogl04?ooool00oooO`3oooooooooo`07ooooo`0300000?oooooooooo00oooooo00?o
0000ooooooooool0FOooool01onP8?3oooooooooooooooooX23`oooooonP8?001Oooool00onP8?3o
oooooj0Pl00Gooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool01oooool00onP8?3o
ooooooooo`07ooooo`05oj0Pl?oooooooooooooooonP8?002?ooool00onP8?3oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo05[ooooo00?oogl0oooooooo
ool00oooool01?ooO`3oooooooooooooool2oomo00;ooooo00?oogl0ooooooooool0A_ooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo06kooooo00?oX23`ooooooooool06_ooool01?nP
8?3ooooooooooonP8?02ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01_ooool0
0onP8?3oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo
05cooooo00?oogl0ooooooooool01?ooO`03ooooo`03oomo0?ooooooogl000?ooooo0_ooO`000ooo
ooooogl0oomo0003ooooo`03oomo0?oooooooooo00Gooooo0_ooO`03ooooo`03oomo0?ooooooogl0
00Sooooo00?oogl0ooooooooO`008_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo
05[ooooo0_nP8?04ooooo`;oX23`00?ooooooj0Pl?ooool01_ooool00onP8?3oooooooooo`07oooo
o`;oX23`00?ooooooj0Pl?ooool03oooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?oooooooooo
00[ooooo00?oX23`ooooooooool02_ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`1Pooooo`03oomo0?oooooooooo00?oogl00_ooool2oomo00Cooooo00?oogl0oooooooo
ool02?ooool01?ooO`3oooooooooooooO`03ooooo`03oomo0?oooooooooo013ooooo00?oogl0oooo
ooooool06oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo05gooooo00?oX23`oooo
ooooool00_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00[ooooo00?oX23`oooo
ooooool01?ooool00onP8?3oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
00000?oooooooooo05oooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`04ooooo`?o
ogl00_ooool2oomo00Gooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`07ooooo`03
oomo0?ooooooogl002Kooooo00<00000ooooooooool03oooool00ol0003oooooooooo`1Wooooo`03
oj0Pl?oooooooooo02Oooooo00?oX23`ooooooooool06Oooool01OnP8?3ooooooooooooooooo0000
00_ooooo000:ooooo`0300000?oooooooooo05Gooooo00?oogl0ooooooooool01oooool00oooO`3o
oooooomo0002oomo0004ooooooooO`3oogl0ooooo`;oogl000?ooooooomo0?ooO`000_ooool3oomo
0009ooooooooO`3oogl0ooooooooO`3ooooooomo0?ooooooogl000cooooo00?oogl0ooooooooool0
9oooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo05kooooo00GoX23`oooooooooooo
oooooj0Pl002ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool00oooool2oj0Pl0Go
oooo00?oX23`ooooooooool08Oooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?l0003ooooo00[o
oooo000:ooooo`0300000?oooooooooo05oooooo00?oogl0ooooooooool01Oooool2oomo00;ooooo
00?oogl0ooooooooool01_ooool00oooO`3oooooooooo`0Oooooo`03oomo0?oooooooooo01Sooooo
00<00000ooooooooool03oooool00ol0003oooooooooo`1Pooooo`03oj0Pl?oooooooooo00Gooooo
00?oX23`ooooooooool06Oooool00onP8?3oooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo
000:ooooo`0300000?oooooooooo067ooooo00Coogl0ooooooooO`3oogl00oooool4oomo00Oooooo
00?oogl0ooooooooool05?ooool01?ooO`3oooooooooooooO`04ooooo`;oogl04_ooool00oooO`3o
ooooooooo`08ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0HOooool2oj0Pl003
oooooonP8?3ooooo00?ooooo0_nP8?0Booooo`03oj0Pl?oooooooooo013ooooo00GoX23`oooooonP
8?3ooooooj0Pl00Booooo`03oj0Pl?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000[o
oooo00<00000ooooooooool0IOooool5oomo00;ooooo0oooO`000oooooooogl0ooooo`0Cooooo`03
oomo0?oooooooooo013ooooo00?oogl0ooooooooool05_ooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo07Kooooo00?oX23`ooooooooool0>?ooool00ol0003oooooooooo`09ooooo`00
2_ooool00`00003oooooooooo`1Vooooo`06oomo0?ooooooogl0ooooooooO`3ooooo0_ooO`05oooo
o`03oomo0?ooooooogl000;ooooo00Coogl0ooooooooooooogl00oooool00oooO`3oooooooooo`0>
ooooo`05oomo0?ooooooooooooooooooO`007?ooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo07[ooooo0_nP8?0Nooooo`03oj0Pl?oooooooooo01Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00<00000ooooooooool0Ioooool2oomo0003ooooooooO`3oogl000;oogl000Gooooo
oomo0?oooooooooooomo0002ooooo`03oomo0?oooooooooo01;ooooo00Coogl0ooooooooooooogl0
0oooool00oooO`3oooooooooo`0>ooooo`03oomo0?oooooooooo00cooooo00<00000ooooooooool0
3oooool00ol0003oooooooooo`1Vooooo`?oX23`1Oooool00onP8?3oooooooooo`0>ooooo`03oj0P
l?ooooooX23`013ooooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`04ooooo`04oj0P
l?ooooooX23`oj0Pl0Gooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0
HOooool00oooO`3oooooooooo`03ooooo`?oogl000?ooooooomo0?ooO`000_ooool00oooO`3ooooo
oomo0008ooooo`04oomo0?oooooooooooomo00?ooooo00?oogl0ooooooooool00_ooool00oooO`3o
ooooooooo`04ooooo`03oomo0?oooooooooo027ooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo06Cooooo
00Coogl0oooooooooooooooo2OooO`08ooooo`05oomo0?ooooooooooooooooooO`000_ooool00ooo
O`3oooooooooo`03ooooo`;oogl06_ooool00oooO`3oooooooooo`0<ooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0G_ooool01OnP8?3oooooooooooooooooX23`00[ooooo00?oX23`
ooooooooool04oooool01OnP8?3oooooooooooooooooX23`02Sooooo00?oX23`o`000?ooool02_oo
ool000[ooooo00<00000ooooooooool0JOooool3oomo0003ooooooooO`3oogl000;oogl03oooool0
1OooO`3oooooooooooooooooogl002cooooo00<00000ooooooooool03oooool00ol0003ooooooooo
o`1Zooooo`03oj0Pl?oooooooooo02Kooooo00?oX23`ooooooooool06?ooool01?nP8?3ooooooooo
ool0000;ooooo`002_ooool00`00003oooooooooo`1Yooooo`03oomo0?ooooooogl000Coogl000Go
oooooomo0?ooO`3ooooooomo0009ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooO`00
1oooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo017ooooo00<00000ooooooooool0
3oooool00ol0003oooooooooo`1Zooooo`03oj0Pl?ooooooX23`027ooooo00?oX23`ooooooooool0
1?ooool00onP8?3oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oo
oooooooo06Sooooo00?oogl0ooooooooool00_ooool3oomo00oooooo00?oogl0ooooooooool0;ooo
ool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo06[ooooo00?oX23`ooooooooool0:_oo
ool00onP8?3oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooo
oooo06_ooooo00?oogl0ooooooooO`001Oooool2oomo00Gooooo0_ooO`03ooooo`03oomo0?oooooo
oooo00Gooooo00?oogl0ooooooooool05Oooool00oooO`3oooooooooo`0?ooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool0KOooool2oj0Pl0Kooooo00?oX23`ooooooooool06oooool0
0onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo01Gooooo00?o0000ooooooooool02Oooool0
00[ooooo00<00000ooooooooool0K?ooool4oomo00;ooooo00?oogl0ooooooooool00_ooool00ooo
O`3oooooooooo`06ooooo`03oomo0?ooooooogl000;ooooo00?oogl0ooooooooool0:Oooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo077ooooo00?oX23`ooooooooool02oooool01?nP
8?3ooooooooooonP8?0<ooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool05_ooool0
0onP8?3oooooooooo`09ooooo`002_ooool00`00003oooooooooo`1[ooooo`03oomo0?oooooooooo
00;oogl03_ooool00oooO`3ooooooomo0002ooooo`04oomo0?ooooooogl0oomo00?ooooo00?oogl0
ooooooooool01Oooool00oooO`3oooooooooo`0Looooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0Joooool01OnP8?3oooooooooooooooooX23`00gooooo00?oX23`ooooooooool05Ooo
ool01OnP8?3oooooooooooooooooX23`01Oooooo00?o0000ooooooooool02Oooool000[ooooo00<0
0000ooooooooool0L?ooool01OooO`3oooooooooooooooooogl000kooooo0_ooO`0Xooooo`05oomo
0?ooooooooooooooo`0000004Oooool00ol0003oooooooooo`1/ooooo`03oj0Pl?oooooooooo00;o
oooo00?oX23`ooooooooool07?ooool01?nP8?3ooooooooooonP8?0Mooooo`03oj0Pl?oooooooooo
00Wooooo000:ooooo`0300000?oooooooooo06gooooo00?oogl0ooooooooool00oooool2oomo013o
oooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Cooooo`03oomo0?oooooooooo00co
oooo00<00000ooooooooool03oooool00ol0003oooooooooo`1_ooooo`03oj0Pl?oooooooooo01;o
oooo00?oX23`ooooooooool04Oooool00onP8?3oooooooooo`0Fooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`0300000?oooooooooo06?ooooo00?oogl0ooooooooool02oooool00oooO`3ooooo
ooooo`02oomo0003ooooooooO`3ooooo00;ooooo00?oogl0ooooooooool0<oooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo07cooooo00?oX23`ooooooooool0<_ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`00003oooooooooo`1booooo`03oomo0?ooooooogl000Cooooo00?o
ogl0ooooooooool01Oooool01?ooO`3oooooooooooooO`06ooooo`05oomo0?oooooooooooooooooo
O`000oooool00oooO`3oooooooooo`0Kooooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool0Koooool2oj0Pl1Sooooo0_nP8?0<ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2Eooooo`03oomo
0?oooooooooo01Wooooo00<00000ooooooooool03oooool00ol0003oooooooooo`2Cooooo`03oj0P
l?oooooooooo01_ooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0M_oo
ool2oomo0003ooooooooO`3ooooo017ooooo00?oogl0ooooooooool01?ooool00oooO`3ooooooooo
o`09ooooo`03oomo0?oooooooooo00kooooo00?oogl000000?ooool04?ooool00ol0003ooooooooo
o`1hooooo`03oj0Pl?oooooooooo00oooooo00?oX23`oooooonP8?009?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00`00003oooooooooo`1iooooo`03oomo0?oooooooooo00?ooooo00?oogl0
ooooooooool02?ooool01?ooO`3oooooooooooooO`03ooooo`03oomo0?oooooooooo00Cooooo00?o
ogl0ooooooooool05_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo07Cooooo00?o
X23`ooooooooool04Oooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00_ooooo00?o
X23`oooooonP8?004_ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`1_
ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooool03oooool00oooO`3oooooooooo`0V
ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0MOooool01OnP8?3ooooooooooooo
ooooX23`00?ooooo00?oX23`ooooooooool02Oooool00onP8?3oooooooooo`0Cooooo`03oj0Pl?oo
oooooooo00Cooooo00?oX23`ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0`00003oooooooooo`1hooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool01Oooool0
0oooO`3oooooooooo`0<ooooo`03oomo0?ooooooogl000Kooooo00?oogl0ooooooooool03oooool0
0`00003oooooooooo`0?ooooo`03o`000?oooooooooo06gooooo00?oX23`ooooooooool01?ooool0
0onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooooooo02Wooooo00?o0000ooooooooool02Oooool0
00[ooooo00<00000ooooooooool0L_ooool00oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo
00Sooooo00Coogl0ooooooooooooogl01Oooool00oooO`3ooooooomo0005ooooo`03oomo0?oooooo
oooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`09ooooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool0N_ooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooo
oooo00Sooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooo
oooo00Kooooo00?oX23`ooooooooool00oooool00ol0003oooooooooo`09ooooo`002_ooool00`00
003oooooooooo`1dooooo`03oomo0?oooooooooo00;ooooo00Googl0oooooooooooooooooomo0005
ooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool01?ooool01OooO`3ooooooomo0?oo
ooooogl000Wooooo00?oogl0ooooooooool03oooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo07Kooooo00CoX23`ooooooooooooX23`2?ooool3oj0Pl0gooooo00?oX23`ooooooooool0
4oooool00onP8?3oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oo
oooooooo07[ooooo00?oogl0ooooooooool07?ooool00oooO`3ooooooomo000Eooooo`0300000?oo
oooooooo00oooooo00?o0000ooooooooool0M_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oo
oooooooo02Cooooo00?oX23`ooooooooool03?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0`00003oooooooooo`1dooooo`03oomo0?oooooooooo00Oooooo00Googl0ooooooooO`3ooooooomo
0004ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool00_ooool01?ooO`3ooooooomo
0?ooO`03ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool04?ooool00`00003ooooo
ooooo`0?ooooo`03o`000?oooooooooo07[ooooo0_nP8?000oooooooX23`ooooo`03ooooo`03oj0P
l?oooooooooo02?ooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`09ooooo`002_oo
ool00`00003oooooooooo`2:ooooo`;oogl00oooool00oooO`3oooooooooo`06ooooo`03oomo0?oo
oooooooo00Oooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`07ooooo`0300000?oo
oooooooo00oooooo00?o0000ooooooooool0R?ooool00onP8?3oooooooooo`0Gooooo`03oj0Pl?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0OOooool0
1?ooO`3oooooooooooooO`02ooooo`03oomo0?ooooooogl000Gooooo00Googl0oooooooooooooooo
oomo000Qooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0Qoooool00onP8?3ooooo
ooooo`0Looooo`03oj0Pl?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000[ooooo00<0
0000ooooooooool0NOooool00oooO`3oooooooooo`09ooooo`;oogl000?ooooooomo0?ooool00ooo
ool00oooO`3oooooooooo`03ooooo`05oomo0?ooooooooooooooooooO`001Oooool01OooO`3ooooo
ooooooooooooogl000?ooooo00?oogl0ooooooooool00_ooO`07ooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool0TOooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00go
oooo00?oX23`ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003ooooo
ooooo`25ooooo`03oomo0?oooooooooo02Wooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`20ooooo`;oX23`6oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0OOooool01OooO`3ooooooooo
ooooooooogl000[ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Aooooo`03oomo
0?oooooooooo00Oooooo00<00000ooooooooool03oooool00ol0003oooooooooo`1nooooo`03oj0P
l?ooooooX23`00;oX23`1?ooool00onP8?3ooooooj0Pl005ooooo`03oj0Pl?oooooooooo00?ooooo
0onP8?06ooooo`05oj0Pl?oooooooooooooooonP8?003_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00`00003oooooooooo`1mooooo`04oomo0?oooooooooooomo00kooooo00?oogl0oooooooo
ool01?ooool00oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo00kooooo00<00000oooooooo
ool03oooool00ol0003oooooooooo`22ooooo`03oj0Pl?oooooooooo017ooooo00?oX23`oooooooo
ool05?ooool01OnP8?3oooooooooooooooooX23`00_ooooo000:ooooo`0300000?oooooooooo08Co
oooo00?oogl0ooooooooool01?ooool01?ooO`3oooooooooooooO`02ooooo`03oomo0?oooooooooo
00?ooooo00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`0<ooooo`0300000?oooooooooo
00oooooo00?o0000ooooooooool0W?ooool01OnP8?3oooooooooooooooooX23`013ooooo00?o0000
ooooooooool02Oooool000[ooooo00<00000ooooooooool0QOooool00oooO`3oooooooooo`0<oooo
o`03oomo0?ooooooogl000Kooooo00?oogl0ooooooooO`003?ooool00oooO`3oooooooooo`02oooo
o`0300000?oooooooooo00oooooo00?o0000ooooooooool0NOooool00onP8?3oooooooooo`03oooo
o`05oj0Pl?oooooooooooooooonP8?003_ooool2oj0Pl0oooooo00?oX23`ooooooooool00_ooool0
1?nP8?3oooooooooooooool2oj0Pl0?ooooo00?o0000ooooooooool02Oooool000[ooooo00<00000
ooooooooool0POooool00oooO`3oooooooooo`03ooooo`03oomo0?ooooooogl001?ooooo00?oogl0
ooooooooool01?ooool00oooO`3ooooooomo000:ooooo`0300000?oooooooooo00oooooo00?o0000
ooooooooool0P_ooool00onP8?3oooooooooo`0[ooooo`03oj0Pl?l0003ooooo00[ooooo000:oooo
o`0300000?oooooooooo08Oooooo00Coogl0ooooooooO`3oogl02?ooool00oooO`3oooooooooo`05
ooooo`06oomo0?ooooooogl0oomo0?ooooooogl00oooool00oooO`3oooooooooo`0:ooooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool0P_ooool00onP8?3oooooooooo`02ooooo`04oj0P
l?ooooooooooooooo`?oX23`00?ooooooj0Pl?ooool07?ooool01OnP8?3oooooooooooooooooX23`
00_ooooo000:ooooo`0300000?oooooooooo08Cooooo00Coogl0ooooooooooooogl00_ooool00ooo
O`3ooooooomo0003ooooo`05oomo0?ooooooooooooooooooO`006Oooool01?ooO`3oooooooooo`00
000Aooooo`03o`000?oooooooooo08?ooooo00?oX23`ooooooooool03Oooool00onP8?3ooooooooo
o`0Jooooo`03oj0Pl?l0003ooooo00[ooooo000:ooooo`0300000?oooooooooo08Sooooo00?oogl0
ooooooooool01_ooool00oooO`3oooooooooo`0Eooooo`03oomo0?oooooooooo00Cooooo00?oogl0
00000?ooool04?ooool00ol0003oooooooooo`27ooooo`06oj0Pl?oooooooooooooooonP8?3ooooo
0_nP8?07ooooo`05oj0Pl?oooooooooooooooonP8?004_ooool01OnP8?3oooooooooooooooooX23`
00_ooooo000:ooooo`0300000?oooooooooo08Gooooo00?oogl0ooooooooool01?ooool00oooO`3o
ooooooooo`03ooooo`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooool00_ooool00oooO`3o
ooooooooo`0:ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0T?ooool00onP8?3o
ooooooooo`0Eooooo`03oj0Pl?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000[ooooo
00<00000ooooooooool0R?ooool2oomo00;ooooo00?oogl0ooooooooO`002Oooool00oooO`3ooooo
oomo0008ooooo`04oomo0?ooooooooooooooo`;oogl02?ooool00`00003oooooooooo`0?ooooo`03
o`000?oooooooooo0;7ooooo00?oX23`ooooooooool02Oooool000[ooooo00<00000ooooooooool0
O_ooool00oooO`3oooooooooo`03ooooo`03oomo0?ooooooogl000?ooooo00?oogl0ooooooooool0
1Oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00;ooooo00Koogl0oooooooooooo
ogl0ooooooooO`0>ooooo`0300000?oooooooooo00oooooo00?o0000ooooooooool0R?ooool00onP
8?3oooooooooo`09ooooo`04oj0Pl?oooooooooooj0Pl1Wooooo00?o0000ooooooooool02Oooool0
00[ooooo00<00000ooooooooool0POooool00oooO`3oooooooooo`08ooooo`Coogl000?ooooooomo
0?ooool00oooool00oooO`3oooooooooo`0<ooooo`03oomo0?ooooooogl000Wooooo00<00000oooo
ooooool03oooool00ol0003oooooooooo`2;ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooo
ooooool04_ooool00onP8?3oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
00000?oooooooooo08Sooooo0oooO`03ooooo`;oogl000Cooooooomo0?ooooooogl01oooool00ooo
O`3oooooooooo`03ooooo`;oogl01Oooool00oooO`3oooooooooo`05ooooo`03oomo0000003ooooo
013ooooo00?o0000ooooooooool0T?ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo
00Cooooo0_nP8?0?ooooo`03oj0Pl?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo097o
oooo00?oogl0ooooooooool05?ooool00oooO`3oooooooooo`06ooooo`0300000?oooooooooo00oo
oooo00?o0000ooooooooool0Roooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00[o
oooo00?oX23`ooooooooool03_ooool01?nP8?3oooooooooool0000;ooooo`002_ooool00`00003o
ooooooooo`2<ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool00oooool2oomo00;o
oooo00?oogl0ooooooooool02Oooool00oooO`3oooooooooo`02oomo00;ooooo00Coogl0oooooooo
ool000004Oooool00ol0003oooooooooo`2Yooooo`03oj0Pl?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool000[ooooo00<00000ooooooooool0T?ooool2oomo0005ooooooooO`3ooooooooo
ooooO`001?ooool00oooO`3oooooooooo`05ooooo`;oogl000?ooooooomo0?ooool01_ooool01?oo
O`3oooooooooo`00000Aooooo`03o`000?oooooooooo08gooooo00?oX23`ooooooooool01?ooool0
1OnP8?3oooooooooooooooooX23`01Sooooo00?oX23`ooooooooool02Oooool000[ooooo00<00000
ooooooooool0S?ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo017ooooo00?oogl0
ooooooooool00oooool01_ooO`3oooooooooooooooooogl00000017ooooo00?o0000ooooooooool0
R_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo01oooooo00?o0000ooooooooool0
2Oooool000[ooooo00<00000ooooooooool0Soooool01OooO`3oooooooooooooooooogl000Gooooo
00Ooogl0ooooooooO`3ooooooomo0?ooooooogl000_ooooo00?oogl0ooooooooool00oooool00`00
003oooooooooo`0?ooooo`03o`000?oooooooooo08gooooo00GoX23`oooooonP8?3ooooooj0Pl002
ooooo`CoX23`0oooool00onP8?3oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo000:oooo
o`0300000?oooooooooo09Gooooo0_ooO`0<ooooo`06oomo0?oooooooooooomo0?ooooooogl02?oo
ool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo09oooooo00?oX23`ooooooooool03ooo
ool00onP8?3oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2Cooooo`05oomo0?oooooo
ogl0ooooooooO`001Oooool00oooO`3ooooooomo0002ooooo`;oogl000?ooooooomo0?ooool01Ooo
ool00oooO`3oooooooooo`02oomo000300000?oooooooooo00oooooo00?o0000ooooooooool0T?oo
ool01OnP8?3ooooooj0Pl?ooooooX23`00?ooooo00?oX23`ooooooooool01_ooool00onP8?3ooooo
ooooo`02ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00`00003oooooooooo`2Eooooo`03oomo0?ooooooogl000?ooooo00Co
ogl0ooooooooooooogl00oooool01OooO`3oooooooooooooO`3ooooo00;oogl02?ooool00`00003o
ooooooooo`0?ooooo`03o`000?oooooooooo093ooooo00KoX23`ooooooooooooX23`oooooonP8?03
ooooo`;oX23`5_ooool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2Boooo
o`03oomo0?oooooooooo00?oogl01Oooool00oooO`3oooooooooo`04ooooo`04oomo0?oooooooooo
oomo00Wooooo00<00000ooooooooool03oooool00ol0003oooooooooo`2[ooooo`03oj0Pl?oooooo
oooo00?ooooo00?oX23`ooooooooool02Oooool000[ooooo00<00000ooooooooool0QOooool00ooo
O`3oooooooooo`0;ooooo`03oomo0?oooooooooo00;ooooo00Coogl0ooooooooO`3ooooo0_ooO`03
ooooo`03oomo0?ooooooogl000;oogl00oooool00oooO`3oooooooooo`03ooooo`;oogl000<00000
ooooooooool03oooool00ol0003oooooooooo`2Dooooo`;oX23`1?ooool00onP8?3oooooooooo`0<
ooooo`04oj0Pl?oooooooooooj0Pl0Cooooo00?oX23`ooooooooool02Oooool000[ooooo00<00000
ooooooooool0Toooool00oooO`3oooooooooo`03ooooo`05oomo0?ooooooogl0oomo0?ooool00_oo
O`05ooooo`03oomo0?ooooooogl000Kooooo00Coogl0ooooooooool000004Oooool00ol0003ooooo
ooooo`2^ooooo`04oj0Pl?oooooooooooj0Pl0_ooooo000:ooooo`0300000?oooooooooo09;ooooo
00?oogl0ooooooooool00_ooO`03ooooo`;oogl01?ooool00oooO`3oooooooooo`06ooooo`03oomo
0?ooooooogl000;ooooo00Coogl0ooooooooO`0000004Oooool00ol0003oooooooooo`2Eooooo`?o
X23`00Gooooooj0Pl?oooooooooooj0Pl002ooooo`03oj0Pl?ooooooX23`00Sooooo0_nP8?001?oo
ooooX23`ooooooooool2oj0Pl0_ooooo000:ooooo`0300000?oooooooooo09?ooooo00?oogl0oooo
ooooool00oooO`000oooooooogl0ooooo`03ooooo`07oomo0?ooooooooooooooooooO`3ooooooomo
000:ooooo`03oomo0000003ooooo013ooooo00?o0000ooooooooool0U_ooool2oj0Pl0Gooooo00?o
X23`oooooonP8?000_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00Oooooo00?o
X23`ooooooooool02Oooool000[ooooo00<00000ooooooooool0TOooool00oooO`3oooooooooo`02
ooooo`03oomo0?ooooooogl000;ooooo00?oogl0ooooooooool01?ooool01OooO`3ooooooooooooo
ooooogl000;ooooo00?oogl0ooooooooool01Oooool00`00003oooooooooo`0?ooooo`03o`000?oo
oooooooo09Oooooo1?nP8?04ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2Booooo`;oogl01_ooool0
0oooO`3oooooooooo`04oomo0004ooooooooO`3oooooooooo`?oogl000?ooooooomo0?ooO`001Ooo
ool00oooO`000000ooooo`0@ooooo`03o`000?oooooooooo09Gooooo00?oX23`oooooonP8?000onP
8?000oooooooX23`ooooo`02ooooo`;oX23`0oooool2oj0Pl004oooooonP8?3ooooooj0Pl0Kooooo
00?o0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0TOooool00oooO`3ooooooomo
0004ooooo`03oomo0?oooooooooo00;ooooo0_ooO`05ooooo`03oomo0?ooooooogl000;oogl00_oo
ool2oomo00Cooooo00<00000ooooooooool03oooool00ol0003oooooooooo`2Hooooo`CoX23`2_oo
ool2oj0Pl0Kooooo00CoX23`ooooooooooooX23`2oooool000[ooooo00<00000ooooooooool0Tooo
ool2oomo00?ooooo00?oogl0ooooooooO`000oooO`02ooooo`?oogl00_ooool2oomo00Cooooo0_oo
O`03ooooo`03oomo0000003ooooo013ooooo00?o0000ooooooooool0VOooool7oj0Pl0;ooooo00Go
X23`oooooooooooooooooj0Pl005ooooo`06oj0Pl?oooooooooooj0Pl?ooooooX23`2oooool000[o
oooo00<00000ooooooooool0U_ooool00oooO`3oooooooooo`04oomo00Kooooo00Coogl0oooooooo
ooooogl00oooool00oooO`3ooooooomo0004ooooo`0300000?oooooooooo00oooooo00?o0000oooo
ooooool0V_ooool01_nP8?3ooooooj0Pl?nP8?3ooooooj0Pl0Sooooo00?oX23`oooooonP8?001Ooo
ool2oj0Pl0_ooooo000:ooooo`0300000?oooooooooo09Wooooo2oooO`02ooooo`03oomo0?oooooo
oooo00;ooooo00?oogl0ooooooooool00_ooool00oooO`000000ooooo`0@ooooo`03o`000?oooooo
oooo09_ooooo1onP8?0?ooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo
09Sooooo00?oogl0ooooooooool00_ooool00oooO`3ooooooomo0003ooooo`;oogl00_ooool00ooo
O`3oooooooooo`04ooooo`04oomo0?oooooooooo0000017ooooo00?o0000ooooooooool0W_ooool2
oj0Pl0;ooooo00GoX23`oooooooooooooooooj0Pl00:ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`0300000?oooooooooo09_ooooo00?oogl0ooooooooO`000_ooO`02ooooo`03oomo0?oooooo
ogl000;oogl00oooool2oomo00Cooooo00?oogl000000?ooool04?ooool00ol0003oooooooooo`2L
ooooo`03oj0Pl?oooooooooo00;oX23`2_ooool00onP8?3oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`0300000?oooooooooo09[ooooo00Googl0ooooooooooooogl0ooooo`02
oomo0003ooooooooO`3ooooo00;oogl000Cooooooomo0?ooooooogl01?ooool01?ooO`3ooooooooo
o`00000Aooooo`03o`000?oooooooooo09oooooo1?nP8?001_ooooooX23`oooooonP8?3ooooooj0P
l0Cooooo00GoX23`ooooooooooooooooo`00000;ooooo`002_ooool00`00003oooooooooo`2Ioooo
o`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooO`000_ooool00oooO`3oooooooooo`02oomo
0004ooooooooO`3ooooooomo00?ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`2O
ooooo`03oj0Pl?ooooooX23`00Kooooo00?oX23`ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`002_ooool00`00003oooooooooo`2Jooooo`03oomo0?oooooooooo00Kooooo1OooO`001Ooo
ooooogl0ooooooooooooogl000?ooooo00?oogl000000?ooool04?ooool00ol0003oooooooooo`2Q
ooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo0_nP8?08ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`0300000?oooooooooo09gooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`02
oomo00Oooooo00?oogl0ooooo`0000004Oooool00ol0003oooooooooo`2]ooooo`05oj0Pl?oooooo
ooooooooool000002oooool000[ooooo00<00000ooooooooool0VOooool00oooO`3oooooooooo`06
ooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool00_ooool01?ooO`3oooooooooo`00
000Aooooo`03o`000?oooooooooo0:Cooooo0_nP8?02ooooo`03oj0Pl?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool000[ooooo00<00000ooooooooool0Woooool00oooO`3oooooooooo`05
ooooo`03oomo0?oooooooooo00Cooooo00Coogl0ooooooooool000004Oooool00ol0003ooooooooo
o`2Uooooo`03oj0Pl?oooooooooo00;oX23`1oooool00ol0003oooooooooo`09ooooo`002_ooool0
0`00003oooooooooo`2Qooooo`03oomo0?oooooooooo00cooooo00?oogl000000?ooool04?ooool0
0ol0003oooooooooo`2Qooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`002_ooool00`00003oooooooooo`2Uooooo`03oomo0?ooooooogl0
00;ooooo00?oogl0ooooooooO`001?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo
0:Sooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`09ooooo`002_ooool00`00003o
ooooooooo`2^ooooo`04oomo0?oooooooooo0000017ooooo00?o0000ooooooooool0Z?ooool2oj0P
l0Oooooo00?oX23`ooooooooool02Oooool000[ooooo00<00000ooooooooool0X_ooool00oooO`3o
ooooooooo`06ooooo`03oomo0?oooooooooo00?ooooo00<00000ooooooooool03oooool00ol0003o
ooooooooo`2Zooooo`03oj0Pl?ooooooX23`00?ooooo0_nP8?0;ooooo`002_ooool00`00003ooooo
ooooo`2Yooooo`03oomo0?oooooooooo00Gooooo00<00000ooooooooool03oooool00ol0003ooooo
ooooo`2Wooooo`04oj0Pl?oooooooooooj0Pl0Kooooo00?oX23`ooooooooool02Oooool000[ooooo
00<00000ooooooooool0ZOooool00oooO`3oooooooooo`04ooooo`03oomo0000003ooooo013ooooo
00?o0000ooooooooool0/?ooool2oj0Pl0_ooooo000:ooooo`0300000?oooooooooo0:Oooooo00?o
ogl0ooooooooool00_ooool01_ooO`3oooooooooooooooooogl00000017ooooo00?o0000oooooooo
ool0ZOooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00Wooooo000:ooooo`030000
0?oooooooooo0:_ooooo00?oogl0ooooooooO`000oooool00`00003oooooooooo`0?ooooo`03o`00
0?oooooooooo0:[ooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`09ooooo`002_oo
ool00`00003oooooooooo`2[ooooo`;oogl00_ooool00oooO`3ooooo0000000Aooooo`03o`000?oo
oooooooo0:_ooooo00?oX23`ooooooooool00oooool00ol0003oooooooooo`09ooooo`002_ooool0
0`00003oooooooooo`2/ooooo`03oomo0?oooooooooo00;ooooo00<00000ooooooooool03oooool0
0ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`0300000?oooooooooo
0:kooooo0oooO`000`00003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooo
ooooool02Oooool000[ooooo/0000003oomo008000004Ooooondo`000003oj0Pl?oooooooooo00Wo
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-14.4237, \
-6.63736, 1.4157, 1.4157}, {{208.5, 388.938}, {184.875, 4.5}} -> {-295.249, \
-6.59083, 1.41521, 1.41521}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gaussian models", "Subsection"],

Cell[CellGroupData[{

Cell["Extract 2d data", "Subsubsection"],

Cell[BoxData[{
    \(\(d2d1 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ data1)\);\)\), "\[IndentingNewLine]", 
    \(\(d2d2 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ data2)\);\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute pdfs", "Subsubsection"],

Cell[BoxData[{
    \(\(pdf1\  = \ gaussian[d2d1, {x, y}];\)\), "\[IndentingNewLine]", 
    \(\(pdf2\  = \ gaussian[d2d2, {x, y}];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualize pdfs", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoGaussianPDFs[pdf1, pdf2, pr, x, y, yS, imSize];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
%%ImageSize: 400 324.454 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0193128 0.47619 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0193128 0.477324 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.85249 .98077 m
.83284 .97108 L
.80819 .95759 L
.80564 .95611 L
.78353 .94287 L
.76526 .93146 L
.75888 .92725 L
.73422 .91048 L
.72892 .9068 L
.70957 .89265 L
.69548 .88215 L
.68491 .87391 L
.66422 .8575 L
.66026 .85423 L
.6356 .83354 L
.63478 .83284 L
.61095 .81179 L
.60693 .80819 L
.58629 .78909 L
.58038 .78353 L
.56164 .76542 L
.55499 .75888 L
.53698 .74074 L
.53065 .73422 L
.51233 .71501 L
.50726 .70957 L
.48767 .6882 L
.48475 .68491 L
.46304 .66026 L
.46302 .66023 L
.44227 .6356 L
.43836 .63091 L
.42227 .61095 L
.41371 .60024 L
.40298 .58629 L
.38905 .56813 L
.38432 .56164 L
.3663 .53698 L
.3644 .53435 L
.3492 .51233 L
.33974 .49856 L
.33267 .48767 L
.31667 .46302 L
.31509 .46054 L
.30166 .43836 L
.29043 .41964 L
.28711 .41371 L
.27338 .38905 L
.26578 .37507 L
.26036 .3644 L
.24807 .33974 L
.24112 .32528 L
.23659 .31509 L
.22595 .29043 L
.21647 .26687 L
.21607 .26578 L
.20736 .24112 L
.19953 .21647 L
.1928 .19181 L
.19181 .18798 L
.18747 .16716 L
.18356 .1425 L
.18135 .11785 L
.18122 .0932 L
.18375 .06854 L
.18992 .04389 L
.19181 .03938 L
.20162 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.85249 .98077 m
.83284 .97108 L
.80819 .95759 L
.80564 .95611 L
.78353 .94287 L
.76526 .93146 L
.75888 .92725 L
.73422 .91048 L
.72892 .9068 L
.70957 .89265 L
.69548 .88215 L
.68491 .87391 L
.66422 .8575 L
.66026 .85423 L
.6356 .83354 L
.63478 .83284 L
.61095 .81179 L
.60693 .80819 L
.58629 .78909 L
.58038 .78353 L
.56164 .76542 L
.55499 .75888 L
.53698 .74074 L
.53065 .73422 L
.51233 .71501 L
.50726 .70957 L
.48767 .6882 L
.48475 .68491 L
.46304 .66026 L
.46302 .66023 L
.44227 .6356 L
.43836 .63091 L
.42227 .61095 L
.41371 .60024 L
.40298 .58629 L
.38905 .56813 L
.38432 .56164 L
.3663 .53698 L
.3644 .53435 L
.3492 .51233 L
.33974 .49856 L
.33267 .48767 L
.31667 .46302 L
.31509 .46054 L
.30166 .43836 L
.29043 .41964 L
.28711 .41371 L
.27338 .38905 L
.26578 .37507 L
.26036 .3644 L
Mistroke
.24807 .33974 L
.24112 .32528 L
.23659 .31509 L
.22595 .29043 L
.21647 .26687 L
.21607 .26578 L
.20736 .24112 L
.19953 .21647 L
.1928 .19181 L
.19181 .18798 L
.18747 .16716 L
.18356 .1425 L
.18135 .11785 L
.18122 .0932 L
.18375 .06854 L
.18992 .04389 L
.19181 .03938 L
.20162 .01923 L
Mfstroke
.2 g
.98077 .91873 m
.95611 .92606 L
.93146 .92764 L
.9068 .92529 L
.88215 .91998 L
.8575 .91229 L
.84271 .9068 L
.83284 .90258 L
.80819 .89109 L
.79087 .88215 L
.78353 .87807 L
.75888 .86356 L
.74912 .8575 L
.73422 .84771 L
.71261 .83284 L
.70957 .83065 L
.68491 .81228 L
.67958 .80819 L
.66026 .79272 L
.64909 .78353 L
.6356 .77201 L
.62061 .75888 L
.61095 .75012 L
.59381 .73422 L
.58629 .72704 L
.56844 .70957 L
.56164 .70273 L
.54434 .68491 L
.53698 .67714 L
.5214 .66026 L
.51233 .6502 L
.49952 .6356 L
.48767 .62183 L
.4786 .61095 L
.46302 .5919 L
.45859 .58629 L
.43943 .56164 L
.43836 .56023 L
.42126 .53698 L
.41371 .5265 L
.40389 .51233 L
.38905 .49044 L
.38726 .48767 L
.37157 .46302 L
.3644 .45142 L
.3567 .43836 L
.34261 .41371 L
.33974 .40853 L
.32952 .38905 L
.31722 .3644 L
.31509 .35996 L
.306 .33974 L
.29573 .31509 L
.29043 .30133 L
.28661 .29043 L
.27873 .26578 L
.2722 .24112 L
.26727 .21647 L
.26578 .20634 L
.26426 .19181 L
.26363 .16716 L
.26578 .14451 L
.26613 .1425 L
.27321 .11785 L
.28845 .0932 L
.29043 .09106 L
.31509 .07385 L
.33078 .06854 L
.33974 .06675 L
.3644 .06531 L
.38905 .06776 L
.39536 .06854 L
.41371 .07315 L
.43836 .08094 L
.46302 .09069 L
.46879 .0932 L
.48767 .10223 L
.51233 .11531 L
.51687 .11785 L
.53698 .12988 L
.55685 .1425 L
.56164 .14571 L
.58629 .16289 L
.59222 .16716 L
.61095 .18129 L
.62446 .19181 L
.6356 .20085 L
.65434 .21647 L
.66026 .22158 L
.68232 .24112 L
.68491 .24349 L
.7087 .26578 L
.70957 .26661 L
.7337 .29043 L
.73422 .29096 L
.75745 .31509 L
.75888 .3166 L
.78008 .33974 L
.78353 .34359 L
.80167 .3644 L
.80819 .37203 L
.82229 .38905 L
.83284 .40203 L
.84201 .41371 L
.8575 .43377 L
.8609 .43836 L
.87892 .46302 L
.88215 .46754 L
.89602 .48767 L
.9068 .50371 L
.91235 .51233 L
.92788 .53698 L
.93146 .54282 L
.94247 .56164 L
.95611 .58587 L
.95635 .58629 L
.96932 .61095 L
.98077 .63468 L
F
0 g
.98077 .91873 m
.95611 .92606 L
.93146 .92764 L
.9068 .92529 L
.88215 .91998 L
.8575 .91229 L
.84271 .9068 L
.83284 .90258 L
.80819 .89109 L
.79087 .88215 L
.78353 .87807 L
.75888 .86356 L
.74912 .8575 L
.73422 .84771 L
.71261 .83284 L
.70957 .83065 L
.68491 .81228 L
.67958 .80819 L
.66026 .79272 L
.64909 .78353 L
.6356 .77201 L
.62061 .75888 L
.61095 .75012 L
.59381 .73422 L
.58629 .72704 L
.56844 .70957 L
.56164 .70273 L
.54434 .68491 L
.53698 .67714 L
.5214 .66026 L
.51233 .6502 L
.49952 .6356 L
.48767 .62183 L
.4786 .61095 L
.46302 .5919 L
.45859 .58629 L
.43943 .56164 L
.43836 .56023 L
.42126 .53698 L
.41371 .5265 L
.40389 .51233 L
.38905 .49044 L
.38726 .48767 L
.37157 .46302 L
.3644 .45142 L
.3567 .43836 L
.34261 .41371 L
.33974 .40853 L
.32952 .38905 L
.31722 .3644 L
Mistroke
.31509 .35996 L
.306 .33974 L
.29573 .31509 L
.29043 .30133 L
.28661 .29043 L
.27873 .26578 L
.2722 .24112 L
.26727 .21647 L
.26578 .20634 L
.26426 .19181 L
.26363 .16716 L
.26578 .14451 L
.26613 .1425 L
.27321 .11785 L
.28845 .0932 L
.29043 .09106 L
.31509 .07385 L
.33078 .06854 L
.33974 .06675 L
.3644 .06531 L
.38905 .06776 L
.39536 .06854 L
.41371 .07315 L
.43836 .08094 L
.46302 .09069 L
.46879 .0932 L
.48767 .10223 L
.51233 .11531 L
.51687 .11785 L
.53698 .12988 L
.55685 .1425 L
.56164 .14571 L
.58629 .16289 L
.59222 .16716 L
.61095 .18129 L
.62446 .19181 L
.6356 .20085 L
.65434 .21647 L
.66026 .22158 L
.68232 .24112 L
.68491 .24349 L
.7087 .26578 L
.70957 .26661 L
.7337 .29043 L
.73422 .29096 L
.75745 .31509 L
.75888 .3166 L
.78008 .33974 L
.78353 .34359 L
.80167 .3644 L
Mistroke
.80819 .37203 L
.82229 .38905 L
.83284 .40203 L
.84201 .41371 L
.8575 .43377 L
.8609 .43836 L
.87892 .46302 L
.88215 .46754 L
.89602 .48767 L
.9068 .50371 L
.91235 .51233 L
.92788 .53698 L
.93146 .54282 L
.94247 .56164 L
.95611 .58587 L
.95635 .58629 L
.96932 .61095 L
.98077 .63468 L
Mfstroke
.3 g
.3644 .12939 m
.38905 .1241 L
.41371 .12449 L
.43836 .12876 L
.46302 .13596 L
.48086 .1425 L
.48767 .14554 L
.51233 .15718 L
.53107 .16716 L
.53698 .17058 L
.56164 .18564 L
.57115 .19181 L
.58629 .2022 L
.60604 .21647 L
.61095 .22018 L
.6356 .23956 L
.63752 .24112 L
.66026 .26034 L
.66648 .26578 L
.68491 .28247 L
.69344 .29043 L
.70957 .30598 L
.71874 .31509 L
.73422 .33093 L
.74258 .33974 L
.75888 .3574 L
.76514 .3644 L
.78353 .38549 L
.78654 .38905 L
.80684 .41371 L
.80819 .41539 L
.82605 .43836 L
.83284 .44735 L
.84427 .46302 L
.8575 .4817 L
.86156 .48767 L
.87788 .51233 L
.88215 .519 L
.89318 .53698 L
.9068 .56023 L
.90759 .56164 L
.9209 .58629 L
.93146 .60723 L
.93322 .61095 L
.94437 .6356 L
.95437 .66026 L
.95611 .66481 L
.96303 .68491 L
.97016 .70957 L
.97552 .73422 L
.97876 .75888 L
.97928 .78353 L
.97589 .80819 L
.96622 .83284 L
.95611 .84715 L
.94386 .8575 L
.93146 .86323 L
.9068 .86877 L
.88215 .86852 L
.8575 .86436 L
.83328 .8575 L
.83284 .85726 L
.80819 .84773 L
.78353 .83617 L
.77699 .83284 L
.75888 .8228 L
.73477 .80819 L
.73422 .80783 L
.70957 .79128 L
.69863 .78353 L
.68491 .77333 L
.66628 .75888 L
.66026 .754 L
.63665 .73422 L
.6356 .73331 L
.61095 .71122 L
.60915 .70957 L
.58629 .68775 L
.58341 .68491 L
.56164 .66284 L
.55916 .66026 L
.53698 .63643 L
.53623 .6356 L
.51453 .61095 L
.51233 .60838 L
.49396 .58629 L
.48767 .57852 L
.47444 .56164 L
.46302 .54664 L
.45591 .53698 L
.43836 .51239 L
.43832 .51233 L
.42178 .48767 L
.41371 .47518 L
.40617 .46302 L
.3915 .43836 L
.38905 .43411 L
.37789 .41371 L
.36524 .38905 L
.3644 .38734 L
.35378 .3644 L
.34343 .33974 L
.33974 .33028 L
.33441 .31509 L
.32683 .29043 L
.3209 .26578 L
.31698 .24112 L
.31558 .21647 L
.31759 .19181 L
.32478 .16716 L
.33974 .14505 L
.34226 .1425 L
F
0 g
.3644 .12939 m
.38905 .1241 L
.41371 .12449 L
.43836 .12876 L
.46302 .13596 L
.48086 .1425 L
.48767 .14554 L
.51233 .15718 L
.53107 .16716 L
.53698 .17058 L
.56164 .18564 L
.57115 .19181 L
.58629 .2022 L
.60604 .21647 L
.61095 .22018 L
.6356 .23956 L
.63752 .24112 L
.66026 .26034 L
.66648 .26578 L
.68491 .28247 L
.69344 .29043 L
.70957 .30598 L
.71874 .31509 L
.73422 .33093 L
.74258 .33974 L
.75888 .3574 L
.76514 .3644 L
.78353 .38549 L
.78654 .38905 L
.80684 .41371 L
.80819 .41539 L
.82605 .43836 L
.83284 .44735 L
.84427 .46302 L
.8575 .4817 L
.86156 .48767 L
.87788 .51233 L
.88215 .519 L
.89318 .53698 L
.9068 .56023 L
.90759 .56164 L
.9209 .58629 L
.93146 .60723 L
.93322 .61095 L
.94437 .6356 L
.95437 .66026 L
.95611 .66481 L
.96303 .68491 L
.97016 .70957 L
.97552 .73422 L
Mistroke
.97876 .75888 L
.97928 .78353 L
.97589 .80819 L
.96622 .83284 L
.95611 .84715 L
.94386 .8575 L
.93146 .86323 L
.9068 .86877 L
.88215 .86852 L
.8575 .86436 L
.83328 .8575 L
.83284 .85726 L
.80819 .84773 L
.78353 .83617 L
.77699 .83284 L
.75888 .8228 L
.73477 .80819 L
.73422 .80783 L
.70957 .79128 L
.69863 .78353 L
.68491 .77333 L
.66628 .75888 L
.66026 .754 L
.63665 .73422 L
.6356 .73331 L
.61095 .71122 L
.60915 .70957 L
.58629 .68775 L
.58341 .68491 L
.56164 .66284 L
.55916 .66026 L
.53698 .63643 L
.53623 .6356 L
.51453 .61095 L
.51233 .60838 L
.49396 .58629 L
.48767 .57852 L
.47444 .56164 L
.46302 .54664 L
.45591 .53698 L
.43836 .51239 L
.43832 .51233 L
.42178 .48767 L
.41371 .47518 L
.40617 .46302 L
.3915 .43836 L
.38905 .43411 L
.37789 .41371 L
.36524 .38905 L
.3644 .38734 L
Mistroke
.35378 .3644 L
.34343 .33974 L
.33974 .33028 L
.33441 .31509 L
.32683 .29043 L
.3209 .26578 L
.31698 .24112 L
.31558 .21647 L
.31759 .19181 L
.32478 .16716 L
.33974 .14505 L
.34226 .1425 L
.3644 .12939 L
Mfstroke
.4 g
.38905 .17959 m
.41371 .17095 L
.43836 .17004 L
.46302 .17387 L
.48767 .18112 L
.51233 .19103 L
.5141 .19181 L
.53698 .20322 L
.56022 .21647 L
.56164 .21735 L
.58629 .2333 L
.59758 .24112 L
.61095 .2509 L
.63026 .26578 L
.6356 .27009 L
.6598 .29043 L
.66026 .29084 L
.68491 .31316 L
.68696 .31509 L
.70957 .33708 L
.71221 .33974 L
.73422 .36267 L
.73583 .3644 L
.75801 .38905 L
.75888 .39004 L
.77887 .41371 L
.78353 .41941 L
.79851 .43836 L
.80819 .45104 L
.81701 .46302 L
.83284 .48536 L
.83442 .48767 L
.85069 .51233 L
.8575 .52312 L
.86586 .53698 L
.87994 .56164 L
.88215 .56568 L
.89281 .58629 L
.90448 .61095 L
.9068 .61614 L
.91477 .6356 L
.9236 .66026 L
.93073 .68491 L
.93146 .68606 L
.93581 .70957 L
.93836 .73422 L
.93744 .75888 L
.93146 .78257 L
.93108 .78353 L
.91354 .80819 L
.9068 .81281 L
.88215 .82186 L
.8575 .82295 L
.83284 .81924 L
.80819 .8121 L
.79703 .80819 L
.78353 .80225 L
.75888 .79014 L
.74677 .78353 L
.73422 .77605 L
.70957 .76019 L
.70763 .75888 L
.68491 .74262 L
.67381 .73422 L
.66026 .72347 L
.64347 .70957 L
.6356 .70277 L
.61568 .68491 L
.61095 .68051 L
.58991 .66026 L
.58629 .65665 L
.56585 .6356 L
.56164 .63111 L
.54329 .61095 L
.53698 .60379 L
.52206 .58629 L
.51233 .57449 L
.50207 .56164 L
.48767 .54295 L
.48323 .53698 L
.46552 .51233 L
.46302 .50873 L
.44894 .48767 L
.43836 .47109 L
.43343 .46302 L
.41905 .43836 L
.41371 .42873 L
.40583 .41371 L
.3938 .38905 L
.38905 .37862 L
.3831 .3644 L
.37383 .33974 L
.36619 .31509 L
.3644 .30997 L
.36048 .29043 L
.35713 .26578 L
.35693 .24112 L
.36141 .21647 L
.3644 .2077 L
.37432 .19181 L
F
0 g
.38905 .17959 m
.41371 .17095 L
.43836 .17004 L
.46302 .17387 L
.48767 .18112 L
.51233 .19103 L
.5141 .19181 L
.53698 .20322 L
.56022 .21647 L
.56164 .21735 L
.58629 .2333 L
.59758 .24112 L
.61095 .2509 L
.63026 .26578 L
.6356 .27009 L
.6598 .29043 L
.66026 .29084 L
.68491 .31316 L
.68696 .31509 L
.70957 .33708 L
.71221 .33974 L
.73422 .36267 L
.73583 .3644 L
.75801 .38905 L
.75888 .39004 L
.77887 .41371 L
.78353 .41941 L
.79851 .43836 L
.80819 .45104 L
.81701 .46302 L
.83284 .48536 L
.83442 .48767 L
.85069 .51233 L
.8575 .52312 L
.86586 .53698 L
.87994 .56164 L
.88215 .56568 L
.89281 .58629 L
.90448 .61095 L
.9068 .61614 L
.91477 .6356 L
.9236 .66026 L
.93073 .68491 L
.93146 .68606 L
.93581 .70957 L
.93836 .73422 L
.93744 .75888 L
.93146 .78257 L
.93108 .78353 L
.91354 .80819 L
Mistroke
.9068 .81281 L
.88215 .82186 L
.8575 .82295 L
.83284 .81924 L
.80819 .8121 L
.79703 .80819 L
.78353 .80225 L
.75888 .79014 L
.74677 .78353 L
.73422 .77605 L
.70957 .76019 L
.70763 .75888 L
.68491 .74262 L
.67381 .73422 L
.66026 .72347 L
.64347 .70957 L
.6356 .70277 L
.61568 .68491 L
.61095 .68051 L
.58991 .66026 L
.58629 .65665 L
.56585 .6356 L
.56164 .63111 L
.54329 .61095 L
.53698 .60379 L
.52206 .58629 L
.51233 .57449 L
.50207 .56164 L
.48767 .54295 L
.48323 .53698 L
.46552 .51233 L
.46302 .50873 L
.44894 .48767 L
.43836 .47109 L
.43343 .46302 L
.41905 .43836 L
.41371 .42873 L
.40583 .41371 L
.3938 .38905 L
.38905 .37862 L
.3831 .3644 L
.37383 .33974 L
.36619 .31509 L
.3644 .30997 L
.36048 .29043 L
.35713 .26578 L
.35693 .24112 L
.36141 .21647 L
.3644 .2077 L
.37432 .19181 L
Mistroke
.38905 .17959 L
Mfstroke
.5 g
.43836 .2115 m
.46302 .20989 L
.48767 .21382 L
.50059 .21647 L
.51233 .22153 L
.53698 .23218 L
.55453 .24112 L
.56164 .24525 L
.58629 .26047 L
.59429 .26578 L
.61095 .27762 L
.62789 .29043 L
.6356 .29659 L
.65768 .31509 L
.66026 .31735 L
.68476 .33974 L
.68491 .33989 L
.70957 .36427 L
.70969 .3644 L
.73283 .38905 L
.73422 .3906 L
.75438 .41371 L
.75888 .41906 L
.77451 .43836 L
.78353 .44997 L
.7933 .46302 L
.80819 .48382 L
.81083 .48767 L
.82709 .51233 L
.83284 .5215 L
.84208 .53698 L
.85581 .56164 L
.8575 .5648 L
.86815 .58629 L
.87905 .61095 L
.88215 .61841 L
.88831 .6356 L
.89569 .66026 L
.90079 .68491 L
.90293 .70957 L
.90081 .73422 L
.89106 .75888 L
.88215 .76905 L
.8575 .78125 L
.83284 .78308 L
.80819 .77931 L
.78353 .7717 L
.75888 .76114 L
.75412 .75888 L
.73422 .74813 L
.71141 .73422 L
.70957 .73299 L
.68491 .7159 L
.67636 .70957 L
.66026 .69697 L
.64561 .68491 L
.6356 .67627 L
.61783 .66026 L
.61095 .65379 L
.59233 .6356 L
.58629 .62947 L
.5687 .61095 L
.56164 .60321 L
.54672 .58629 L
.53698 .57482 L
.52619 .56164 L
.51233 .544 L
.50702 .53698 L
.48912 .51233 L
.48767 .51025 L
.47252 .48767 L
.46302 .47271 L
.45715 .46302 L
.44306 .43836 L
.43836 .42966 L
.43031 .41371 L
.41898 .38905 L
.41371 .3765 L
.40923 .3644 L
.40128 .33974 L
.39547 .31509 L
.39239 .29043 L
.3931 .26578 L
.39998 .24112 L
.41371 .22315 L
.42425 .21647 L
F
0 g
.43836 .2115 m
.46302 .20989 L
.48767 .21382 L
.50059 .21647 L
.51233 .22153 L
.53698 .23218 L
.55453 .24112 L
.56164 .24525 L
.58629 .26047 L
.59429 .26578 L
.61095 .27762 L
.62789 .29043 L
.6356 .29659 L
.65768 .31509 L
.66026 .31735 L
.68476 .33974 L
.68491 .33989 L
.70957 .36427 L
.70969 .3644 L
.73283 .38905 L
.73422 .3906 L
.75438 .41371 L
.75888 .41906 L
.77451 .43836 L
.78353 .44997 L
.7933 .46302 L
.80819 .48382 L
.81083 .48767 L
.82709 .51233 L
.83284 .5215 L
.84208 .53698 L
.85581 .56164 L
.8575 .5648 L
.86815 .58629 L
.87905 .61095 L
.88215 .61841 L
.88831 .6356 L
.89569 .66026 L
.90079 .68491 L
.90293 .70957 L
.90081 .73422 L
.89106 .75888 L
.88215 .76905 L
.8575 .78125 L
.83284 .78308 L
.80819 .77931 L
.78353 .7717 L
.75888 .76114 L
.75412 .75888 L
.73422 .74813 L
Mistroke
.71141 .73422 L
.70957 .73299 L
.68491 .7159 L
.67636 .70957 L
.66026 .69697 L
.64561 .68491 L
.6356 .67627 L
.61783 .66026 L
.61095 .65379 L
.59233 .6356 L
.58629 .62947 L
.5687 .61095 L
.56164 .60321 L
.54672 .58629 L
.53698 .57482 L
.52619 .56164 L
.51233 .544 L
.50702 .53698 L
.48912 .51233 L
.48767 .51025 L
.47252 .48767 L
.46302 .47271 L
.45715 .46302 L
.44306 .43836 L
.43836 .42966 L
.43031 .41371 L
.41898 .38905 L
.41371 .3765 L
.40923 .3644 L
.40128 .33974 L
.39547 .31509 L
.39239 .29043 L
.3931 .26578 L
.39998 .24112 L
.41371 .22315 L
.42425 .21647 L
.43836 .2115 L
Mfstroke
.6 g
.43836 .26398 m
.46302 .24862 L
.48767 .2468 L
.51233 .25122 L
.53698 .25978 L
.55116 .26578 L
.56164 .27146 L
.58629 .28576 L
.59367 .29043 L
.61095 .30236 L
.62808 .31509 L
.6356 .32107 L
.65789 .33974 L
.66026 .34184 L
.68465 .3644 L
.68491 .36465 L
.70905 .38905 L
.70957 .3896 L
.73149 .41371 L
.73422 .41685 L
.75221 .43836 L
.75888 .44671 L
.77137 .46302 L
.78353 .47975 L
.78904 .48767 L
.80528 .51233 L
.80819 .51695 L
.82007 .53698 L
.83284 .56061 L
.83336 .56164 L
.84505 .58629 L
.85496 .61095 L
.8575 .6171 L
.86282 .6356 L
.86817 .66026 L
.87013 .68491 L
.86682 .70957 L
.8575 .72896 L
.85418 .73422 L
.83284 .74408 L
.80819 .74619 L
.78353 .74192 L
.76072 .73422 L
.75888 .73348 L
.73422 .72189 L
.71248 .70957 L
.70957 .70767 L
.68491 .69114 L
.6763 .68491 L
.66026 .67249 L
.64535 .66026 L
.6356 .65179 L
.6178 .6356 L
.61095 .62905 L
.59278 .61095 L
.58629 .60417 L
.56982 .58629 L
.56164 .577 L
.54863 .56164 L
.53698 .54723 L
.52904 .53698 L
.51233 .51429 L
.51094 .51233 L
.49429 .48767 L
.48767 .47727 L
.47909 .46302 L
.46536 .43836 L
.46302 .43395 L
.4532 .41371 L
.44274 .38905 L
.43836 .37786 L
.43427 .3644 L
.42813 .33974 L
.42508 .31509 L
.42654 .29043 L
.43695 .26578 L
F
0 g
.43836 .26398 m
.46302 .24862 L
.48767 .2468 L
.51233 .25122 L
.53698 .25978 L
.55116 .26578 L
.56164 .27146 L
.58629 .28576 L
.59367 .29043 L
.61095 .30236 L
.62808 .31509 L
.6356 .32107 L
.65789 .33974 L
.66026 .34184 L
.68465 .3644 L
.68491 .36465 L
.70905 .38905 L
.70957 .3896 L
.73149 .41371 L
.73422 .41685 L
.75221 .43836 L
.75888 .44671 L
.77137 .46302 L
.78353 .47975 L
.78904 .48767 L
.80528 .51233 L
.80819 .51695 L
.82007 .53698 L
.83284 .56061 L
.83336 .56164 L
.84505 .58629 L
.85496 .61095 L
.8575 .6171 L
.86282 .6356 L
.86817 .66026 L
.87013 .68491 L
.86682 .70957 L
.8575 .72896 L
.85418 .73422 L
.83284 .74408 L
.80819 .74619 L
.78353 .74192 L
.76072 .73422 L
.75888 .73348 L
.73422 .72189 L
.71248 .70957 L
.70957 .70767 L
.68491 .69114 L
.6763 .68491 L
.66026 .67249 L
Mistroke
.64535 .66026 L
.6356 .65179 L
.6178 .6356 L
.61095 .62905 L
.59278 .61095 L
.58629 .60417 L
.56982 .58629 L
.56164 .577 L
.54863 .56164 L
.53698 .54723 L
.52904 .53698 L
.51233 .51429 L
.51094 .51233 L
.49429 .48767 L
.48767 .47727 L
.47909 .46302 L
.46536 .43836 L
.46302 .43395 L
.4532 .41371 L
.44274 .38905 L
.43836 .37786 L
.43427 .3644 L
.42813 .33974 L
.42508 .31509 L
.42654 .29043 L
.43695 .26578 L
.43836 .26398 L
Mfstroke
.7 g
.48767 .28464 m
.51233 .2827 L
.53698 .28792 L
.54712 .29043 L
.56164 .29756 L
.58629 .31061 L
.59391 .31509 L
.61095 .32646 L
.62921 .33974 L
.6356 .34483 L
.65891 .3644 L
.66026 .36561 L
.68491 .38879 L
.68518 .38905 L
.70886 .41371 L
.70957 .41448 L
.73039 .43836 L
.73422 .443 L
.75003 .46302 L
.75888 .4749 L
.76791 .48767 L
.78353 .51141 L
.7841 .51233 L
.79862 .53698 L
.80819 .55506 L
.81134 .56164 L
.82214 .58629 L
.83065 .61095 L
.83284 .61904 L
.83635 .6356 L
.83818 .66026 L
.83315 .68491 L
.83284 .68575 L
.80819 .70804 L
.80154 .70957 L
.78353 .71025 L
.77773 .70957 L
.75888 .70528 L
.73422 .69574 L
.71271 .68491 L
.70957 .68279 L
.68491 .66702 L
.67528 .66026 L
.66026 .64873 L
.64422 .6356 L
.6356 .62803 L
.61708 .61095 L
.61095 .60494 L
.59273 .58629 L
.58629 .57933 L
.57063 .56164 L
.56164 .55091 L
.55048 .53698 L
.53698 .5191 L
.53212 .51233 L
.51543 .48767 L
.51233 .48284 L
.50043 .46302 L
.48767 .43933 L
.48719 .43836 L
.4758 .41371 L
.46659 .38905 L
.46302 .37691 L
.46002 .3644 L
.45689 .33974 L
.45937 .31509 L
.46302 .30222 L
.47589 .29043 L
F
0 g
.48767 .28464 m
.51233 .2827 L
.53698 .28792 L
.54712 .29043 L
.56164 .29756 L
.58629 .31061 L
.59391 .31509 L
.61095 .32646 L
.62921 .33974 L
.6356 .34483 L
.65891 .3644 L
.66026 .36561 L
.68491 .38879 L
.68518 .38905 L
.70886 .41371 L
.70957 .41448 L
.73039 .43836 L
.73422 .443 L
.75003 .46302 L
.75888 .4749 L
.76791 .48767 L
.78353 .51141 L
.7841 .51233 L
.79862 .53698 L
.80819 .55506 L
.81134 .56164 L
.82214 .58629 L
.83065 .61095 L
.83284 .61904 L
.83635 .6356 L
.83818 .66026 L
.83315 .68491 L
.83284 .68575 L
.80819 .70804 L
.80154 .70957 L
.78353 .71025 L
.77773 .70957 L
.75888 .70528 L
.73422 .69574 L
.71271 .68491 L
.70957 .68279 L
.68491 .66702 L
.67528 .66026 L
.66026 .64873 L
.64422 .6356 L
.6356 .62803 L
.61708 .61095 L
.61095 .60494 L
.59273 .58629 L
.58629 .57933 L
Mistroke
.57063 .56164 L
.56164 .55091 L
.55048 .53698 L
.53698 .5191 L
.53212 .51233 L
.51543 .48767 L
.51233 .48284 L
.50043 .46302 L
.48767 .43933 L
.48719 .43836 L
.4758 .41371 L
.46659 .38905 L
.46302 .37691 L
.46002 .3644 L
.45689 .33974 L
.45937 .31509 L
.46302 .30222 L
.47589 .29043 L
.48767 .28464 L
Mfstroke
.98077 .53367 m
.96736 .51233 L
.95611 .49555 L
.95074 .48767 L
.93373 .46302 L
.93146 .45972 L
.9159 .43836 L
.9068 .42588 L
.89752 .41371 L
.88215 .39366 L
.87848 .38905 L
.85866 .3644 L
.8575 .36296 L
.83795 .33974 L
.83284 .33371 L
.81652 .31509 L
.80819 .30567 L
.7943 .29043 L
.78353 .27879 L
.7712 .26578 L
.75888 .25302 L
.74715 .24112 L
.73422 .2283 L
.72207 .21647 L
.70957 .20461 L
.69585 .19181 L
.68491 .18192 L
.66836 .16716 L
.66026 .16018 L
.63943 .1425 L
.6356 .13938 L
.61095 .11956 L
.60878 .11785 L
.58629 .10083 L
.57599 .0932 L
.56164 .08306 L
.54057 .06854 L
.53698 .0662 L
.51233 .05051 L
.50152 .04389 L
.48767 .03573 L
.46302 .02232 L
.45693 .01923 L
.98077 .01923 L
F
.98077 .53367 m
.96736 .51233 L
.95611 .49555 L
.95074 .48767 L
.93373 .46302 L
.93146 .45972 L
.9159 .43836 L
.9068 .42588 L
.89752 .41371 L
.88215 .39366 L
.87848 .38905 L
.85866 .3644 L
.8575 .36296 L
.83795 .33974 L
.83284 .33371 L
.81652 .31509 L
.80819 .30567 L
.7943 .29043 L
.78353 .27879 L
.7712 .26578 L
.75888 .25302 L
.74715 .24112 L
.73422 .2283 L
.72207 .21647 L
.70957 .20461 L
.69585 .19181 L
.68491 .18192 L
.66836 .16716 L
.66026 .16018 L
.63943 .1425 L
.6356 .13938 L
.61095 .11956 L
.60878 .11785 L
.58629 .10083 L
.57599 .0932 L
.56164 .08306 L
.54057 .06854 L
.53698 .0662 L
.51233 .05051 L
.50152 .04389 L
.48767 .03573 L
.46302 .02232 L
.45693 .01923 L
s
.8 g
.51233 .32112 m
.53698 .31927 L
.56164 .32538 L
.58629 .33649 L
.59277 .33974 L
.61095 .3512 L
.62981 .3644 L
.6356 .36909 L
.65935 .38905 L
.66026 .38989 L
.68491 .41359 L
.68503 .41371 L
.70781 .43836 L
.70957 .4404 L
.72817 .46302 L
.73422 .47089 L
.74636 .48767 L
.75888 .5065 L
.76248 .51233 L
.77662 .53698 L
.78353 .55031 L
.78848 .56164 L
.79792 .58629 L
.8041 .61095 L
.8057 .6356 L
.80068 .66026 L
.78353 .67135 L
.75888 .67379 L
.73422 .66781 L
.71638 .66026 L
.70957 .65688 L
.68491 .64224 L
.67491 .6356 L
.66026 .62447 L
.6436 .61095 L
.6356 .60378 L
.61696 .58629 L
.61095 .58019 L
.59346 .56164 L
.58629 .55349 L
.57248 .53698 L
.56164 .52308 L
.55372 .51233 L
.53703 .48767 L
.53698 .4876 L
.52227 .46302 L
.51233 .44398 L
.50977 .43836 L
.49956 .41371 L
.49235 .38905 L
.48929 .3644 L
.49204 .33974 L
F
0 g
.51233 .32112 m
.53698 .31927 L
.56164 .32538 L
.58629 .33649 L
.59277 .33974 L
.61095 .3512 L
.62981 .3644 L
.6356 .36909 L
.65935 .38905 L
.66026 .38989 L
.68491 .41359 L
.68503 .41371 L
.70781 .43836 L
.70957 .4404 L
.72817 .46302 L
.73422 .47089 L
.74636 .48767 L
.75888 .5065 L
.76248 .51233 L
.77662 .53698 L
.78353 .55031 L
.78848 .56164 L
.79792 .58629 L
.8041 .61095 L
.8057 .6356 L
.80068 .66026 L
.78353 .67135 L
.75888 .67379 L
.73422 .66781 L
.71638 .66026 L
.70957 .65688 L
.68491 .64224 L
.67491 .6356 L
.66026 .62447 L
.6436 .61095 L
.6356 .60378 L
.61696 .58629 L
.61095 .58019 L
.59346 .56164 L
.58629 .55349 L
.57248 .53698 L
.56164 .52308 L
.55372 .51233 L
.53703 .48767 L
.53698 .4876 L
.52227 .46302 L
.51233 .44398 L
.50977 .43836 L
.49956 .41371 L
.49235 .38905 L
Mistroke
.48929 .3644 L
.49204 .33974 L
.51233 .32112 L
Mfstroke
.9 g
.53698 .36407 m
.56164 .35897 L
.5823 .3644 L
.58629 .36587 L
.61095 .37851 L
.62813 .38905 L
.6356 .39553 L
.65759 .41371 L
.66026 .41637 L
.68258 .43836 L
.68491 .44094 L
.70422 .46302 L
.70957 .46973 L
.72292 .48767 L
.73422 .50459 L
.73887 .51233 L
.75241 .53698 L
.75888 .54926 L
.76263 .56164 L
.76943 .58629 L
.77042 .61095 L
.75888 .62821 L
.73422 .6341 L
.70957 .62754 L
.68491 .61482 L
.67802 .61095 L
.66026 .59801 L
.64529 .58629 L
.6356 .57735 L
.61912 .56164 L
.61095 .55292 L
.59669 .53698 L
.58629 .52419 L
.57728 .51233 L
.56164 .48936 L
.56059 .48767 L
.54621 .46302 L
.53698 .44373 L
.53511 .43836 L
.52709 .41371 L
.52401 .38905 L
.53659 .3644 L
F
0 g
.53698 .36407 m
.56164 .35897 L
.5823 .3644 L
.58629 .36587 L
.61095 .37851 L
.62813 .38905 L
.6356 .39553 L
.65759 .41371 L
.66026 .41637 L
.68258 .43836 L
.68491 .44094 L
.70422 .46302 L
.70957 .46973 L
.72292 .48767 L
.73422 .50459 L
.73887 .51233 L
.75241 .53698 L
.75888 .54926 L
.76263 .56164 L
.76943 .58629 L
.77042 .61095 L
.75888 .62821 L
.73422 .6341 L
.70957 .62754 L
.68491 .61482 L
.67802 .61095 L
.66026 .59801 L
.64529 .58629 L
.6356 .57735 L
.61912 .56164 L
.61095 .55292 L
.59669 .53698 L
.58629 .52419 L
.57728 .51233 L
.56164 .48936 L
.56059 .48767 L
.54621 .46302 L
.53698 .44373 L
.53511 .43836 L
.52709 .41371 L
.52401 .38905 L
.53659 .3644 L
.53698 .36407 L
s
1 g
.58629 .40733 m
.60994 .41371 L
.61095 .41391 L
.6356 .42825 L
.65125 .43836 L
.66026 .44886 L
.67478 .46302 L
.68491 .47565 L
.69402 .48767 L
.7094 .51233 L
.70957 .51303 L
.72213 .53698 L
.72583 .56164 L
.70957 .58423 L
.68491 .58063 L
.66026 .56485 L
.65502 .56164 L
.6356 .54446 L
.62761 .53698 L
.61095 .51764 L
.60675 .51233 L
.58881 .48767 L
.58629 .4813 L
.57621 .46302 L
.56983 .43836 L
.57482 .41371 L
F
0 g
.58629 .40733 m
.60994 .41371 L
.61095 .41391 L
.6356 .42825 L
.65125 .43836 L
.66026 .44886 L
.67478 .46302 L
.68491 .47565 L
.69402 .48767 L
.7094 .51233 L
.70957 .51303 L
.72213 .53698 L
.72583 .56164 L
.70957 .58423 L
.68491 .58063 L
.66026 .56485 L
.65502 .56164 L
.6356 .54446 L
.62761 .53698 L
.61095 .51764 L
.60675 .51233 L
.58881 .48767 L
.58629 .4813 L
.57621 .46302 L
.56983 .43836 L
.57482 .41371 L
.58629 .40733 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0193128 0.97619 0.387175 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00377074 0.0192308 0.00377074 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.01923 .16664 m
.01943 .16716 L
.02928 .19181 L
.04051 .21647 L
.04389 .22339 L
.05298 .24112 L
.0665 .26578 L
.06854 .26937 L
.08115 .29043 L
.0932 .30964 L
.09676 .31509 L
.11341 .33974 L
.11785 .34614 L
.13103 .3644 L
.1425 .37988 L
.14954 .38905 L
.16716 .41149 L
.16895 .41371 L
.18933 .43836 L
.19181 .44131 L
.21063 .46302 L
.21647 .46963 L
.23282 .48767 L
.24112 .49667 L
.25592 .51233 L
.26578 .52257 L
.27996 .53698 L
.29043 .54744 L
.30494 .56164 L
.31509 .57138 L
.33089 .58629 L
.33974 .59447 L
.35786 .61095 L
.3644 .61676 L
.38587 .6356 L
.38905 .63833 L
.41371 .65918 L
.415 .66026 L
.43836 .67929 L
.44535 .68491 L
.46302 .69876 L
.47695 .70957 L
.48767 .71764 L
.5099 .73422 L
.51233 .73597 L
.53698 .75363 L
.5444 .75888 L
.56164 .77069 L
.58057 .78353 L
.58629 .78727 L
.61095 .80324 L
.61868 .80819 L
.6356 .8186 L
.65903 .83284 L
.66026 .83355 L
.68491 .84776 L
.70212 .8575 L
.70957 .86152 L
.73422 .87467 L
.7486 .88215 L
.75888 .88725 L
.78353 .89924 L
.79961 .9068 L
.80819 .91064 L
.83284 .92136 L
.85728 .93146 L
.8575 .93155 L
.88215 .94089 L
.9068 .94962 L
.92656 .95611 L
.93146 .95764 L
.95611 .96483 L
.98077 .97112 L
.98077 .98077 L
.01923 .98077 L
F
.01923 .16664 m
.01943 .16716 L
.02928 .19181 L
.04051 .21647 L
.04389 .22339 L
.05298 .24112 L
.0665 .26578 L
.06854 .26937 L
.08115 .29043 L
.0932 .30964 L
.09676 .31509 L
.11341 .33974 L
.11785 .34614 L
.13103 .3644 L
.1425 .37988 L
.14954 .38905 L
.16716 .41149 L
.16895 .41371 L
.18933 .43836 L
.19181 .44131 L
.21063 .46302 L
.21647 .46963 L
.23282 .48767 L
.24112 .49667 L
.25592 .51233 L
.26578 .52257 L
.27996 .53698 L
.29043 .54744 L
.30494 .56164 L
.31509 .57138 L
.33089 .58629 L
.33974 .59447 L
.35786 .61095 L
.3644 .61676 L
.38587 .6356 L
.38905 .63833 L
.41371 .65918 L
.415 .66026 L
.43836 .67929 L
.44535 .68491 L
.46302 .69876 L
.47695 .70957 L
.48767 .71764 L
.5099 .73422 L
.51233 .73597 L
.53698 .75363 L
.5444 .75888 L
.56164 .77069 L
.58057 .78353 L
.58629 .78727 L
Mistroke
.61095 .80324 L
.61868 .80819 L
.6356 .8186 L
.65903 .83284 L
.66026 .83355 L
.68491 .84776 L
.70212 .8575 L
.70957 .86152 L
.73422 .87467 L
.7486 .88215 L
.75888 .88725 L
.78353 .89924 L
.79961 .9068 L
.80819 .91064 L
.83284 .92136 L
.85728 .93146 L
.8575 .93155 L
.88215 .94089 L
.9068 .94962 L
.92656 .95611 L
.93146 .95764 L
.95611 .96483 L
.98077 .97112 L
Mfstroke
.2 g
.98077 .888 m
.95611 .88477 L
.94076 .88215 L
.93146 .88016 L
.9068 .87431 L
.88215 .86738 L
.8575 .8595 L
.85162 .8575 L
.83284 .85066 L
.80819 .84097 L
.78882 .83284 L
.78353 .83051 L
.75888 .81922 L
.73605 .80819 L
.73422 .80726 L
.70957 .7945 L
.68922 .78353 L
.68491 .78112 L
.66026 .76698 L
.64652 .75888 L
.6356 .75221 L
.61095 .73676 L
.60697 .73422 L
.58629 .72058 L
.56998 .70957 L
.56164 .70377 L
.53698 .68626 L
.53512 .68491 L
.51233 .66797 L
.50215 .66026 L
.48767 .64899 L
.47082 .6356 L
.46302 .62925 L
.44099 .61095 L
.43836 .60871 L
.41371 .58731 L
.41256 .58629 L
.38905 .56499 L
.38544 .56164 L
.3644 .54169 L
.35955 .53698 L
.33974 .51732 L
.33484 .51233 L
.31509 .49176 L
.31127 .48767 L
.29043 .46485 L
.28881 .46302 L
.26747 .43836 L
.26578 .43635 L
.24725 .41371 L
.24112 .40598 L
.22814 .38905 L
.21647 .37328 L
.21014 .3644 L
.19329 .33974 L
.19181 .33751 L
.17767 .31509 L
.16716 .29735 L
.16327 .29043 L
.15022 .26578 L
.1425 .24987 L
.13859 .24112 L
.12851 .21647 L
.12014 .19181 L
.11785 .18469 L
.11374 .16716 L
.1096 .1425 L
.10818 .11785 L
.11018 .0932 L
.11679 .06854 L
.11785 .06576 L
.13029 .04389 L
.1425 .03059 L
.15658 .01923 L
.98077 .01923 L
F
0 g
.98077 .888 m
.95611 .88477 L
.94076 .88215 L
.93146 .88016 L
.9068 .87431 L
.88215 .86738 L
.8575 .8595 L
.85162 .8575 L
.83284 .85066 L
.80819 .84097 L
.78882 .83284 L
.78353 .83051 L
.75888 .81922 L
.73605 .80819 L
.73422 .80726 L
.70957 .7945 L
.68922 .78353 L
.68491 .78112 L
.66026 .76698 L
.64652 .75888 L
.6356 .75221 L
.61095 .73676 L
.60697 .73422 L
.58629 .72058 L
.56998 .70957 L
.56164 .70377 L
.53698 .68626 L
.53512 .68491 L
.51233 .66797 L
.50215 .66026 L
.48767 .64899 L
.47082 .6356 L
.46302 .62925 L
.44099 .61095 L
.43836 .60871 L
.41371 .58731 L
.41256 .58629 L
.38905 .56499 L
.38544 .56164 L
.3644 .54169 L
.35955 .53698 L
.33974 .51732 L
.33484 .51233 L
.31509 .49176 L
.31127 .48767 L
.29043 .46485 L
.28881 .46302 L
.26747 .43836 L
.26578 .43635 L
.24725 .41371 L
Mistroke
.24112 .40598 L
.22814 .38905 L
.21647 .37328 L
.21014 .3644 L
.19329 .33974 L
.19181 .33751 L
.17767 .31509 L
.16716 .29735 L
.16327 .29043 L
.15022 .26578 L
.1425 .24987 L
.13859 .24112 L
.12851 .21647 L
.12014 .19181 L
.11785 .18469 L
.11374 .16716 L
.1096 .1425 L
.10818 .11785 L
.11018 .0932 L
.11679 .06854 L
.11785 .06576 L
.13029 .04389 L
.1425 .03059 L
.15658 .01923 L
Mfstroke
.3 g
.98077 .82845 m
.95611 .82901 L
.93146 .82733 L
.9068 .82382 L
.88215 .81876 L
.8575 .81238 L
.84324 .80819 L
.83284 .80481 L
.80819 .79614 L
.78353 .7865 L
.77635 .78353 L
.75888 .7759 L
.73422 .76443 L
.72284 .75888 L
.70957 .75212 L
.68491 .73898 L
.67629 .73422 L
.66026 .72504 L
.6356 .71033 L
.63435 .70957 L
.61095 .69479 L
.59582 .68491 L
.58629 .6785 L
.56164 .66142 L
.56 .66026 L
.53698 .64348 L
.52647 .6356 L
.51233 .62472 L
.4949 .61095 L
.48767 .60509 L
.46508 .58629 L
.46302 .58454 L
.43836 .56298 L
.43686 .56164 L
.41371 .54035 L
.41014 .53698 L
.38905 .51655 L
.38481 .51233 L
.3644 .49143 L
.36083 .48767 L
.33974 .4648 L
.33815 .46302 L
.31675 .43836 L
.31509 .43639 L
.29664 .41371 L
.29043 .40578 L
.27782 .38905 L
.26578 .37234 L
.2603 .3644 L
.24414 .33974 L
.24112 .33491 L
.22943 .31509 L
.21647 .29096 L
.21621 .29043 L
.20466 .26578 L
.19491 .24112 L
.19181 .23269 L
.18723 .21647 L
.18196 .19181 L
.17959 .16716 L
.18097 .1425 L
.18754 .11785 L
.19181 .1083 L
.20244 .0932 L
.21647 .08006 L
.23623 .06854 L
.24112 .06652 L
.26578 .05941 L
.29043 .0563 L
.31509 .05603 L
.33974 .05794 L
.3644 .06164 L
.38905 .06685 L
.39608 .06854 L
.41371 .07338 L
.43836 .0811 L
.46302 .08987 L
.47175 .0932 L
.48767 .09964 L
.51233 .11034 L
.52861 .11785 L
.53698 .12189 L
.56164 .13432 L
.57711 .1425 L
.58629 .14754 L
.61095 .16158 L
.62042 .16716 L
.6356 .1764 L
.66001 .19181 L
.66026 .19198 L
.68491 .2084 L
.69666 .21647 L
.70957 .22559 L
.73092 .24112 L
.73422 .24359 L
.75888 .26245 L
.76312 .26578 L
.78353 .28221 L
.79349 .29043 L
.80819 .30289 L
.82222 .31509 L
.83284 .32456 L
.84944 .33974 L
.8575 .34731 L
.87522 .3644 L
.88215 .37125 L
.89965 .38905 L
.9068 .39653 L
.92276 .41371 L
.93146 .42336 L
.94458 .43836 L
.95611 .452 L
.96516 .46302 L
.98077 .4829 L
F
0 g
.98077 .82845 m
.95611 .82901 L
.93146 .82733 L
.9068 .82382 L
.88215 .81876 L
.8575 .81238 L
.84324 .80819 L
.83284 .80481 L
.80819 .79614 L
.78353 .7865 L
.77635 .78353 L
.75888 .7759 L
.73422 .76443 L
.72284 .75888 L
.70957 .75212 L
.68491 .73898 L
.67629 .73422 L
.66026 .72504 L
.6356 .71033 L
.63435 .70957 L
.61095 .69479 L
.59582 .68491 L
.58629 .6785 L
.56164 .66142 L
.56 .66026 L
.53698 .64348 L
.52647 .6356 L
.51233 .62472 L
.4949 .61095 L
.48767 .60509 L
.46508 .58629 L
.46302 .58454 L
.43836 .56298 L
.43686 .56164 L
.41371 .54035 L
.41014 .53698 L
.38905 .51655 L
.38481 .51233 L
.3644 .49143 L
.36083 .48767 L
.33974 .4648 L
.33815 .46302 L
.31675 .43836 L
.31509 .43639 L
.29664 .41371 L
.29043 .40578 L
.27782 .38905 L
.26578 .37234 L
.2603 .3644 L
.24414 .33974 L
Mistroke
.24112 .33491 L
.22943 .31509 L
.21647 .29096 L
.21621 .29043 L
.20466 .26578 L
.19491 .24112 L
.19181 .23269 L
.18723 .21647 L
.18196 .19181 L
.17959 .16716 L
.18097 .1425 L
.18754 .11785 L
.19181 .1083 L
.20244 .0932 L
.21647 .08006 L
.23623 .06854 L
.24112 .06652 L
.26578 .05941 L
.29043 .0563 L
.31509 .05603 L
.33974 .05794 L
.3644 .06164 L
.38905 .06685 L
.39608 .06854 L
.41371 .07338 L
.43836 .0811 L
.46302 .08987 L
.47175 .0932 L
.48767 .09964 L
.51233 .11034 L
.52861 .11785 L
.53698 .12189 L
.56164 .13432 L
.57711 .1425 L
.58629 .14754 L
.61095 .16158 L
.62042 .16716 L
.6356 .1764 L
.66001 .19181 L
.66026 .19198 L
.68491 .2084 L
.69666 .21647 L
.70957 .22559 L
.73092 .24112 L
.73422 .24359 L
.75888 .26245 L
.76312 .26578 L
.78353 .28221 L
.79349 .29043 L
.80819 .30289 L
Mistroke
.82222 .31509 L
.83284 .32456 L
.84944 .33974 L
.8575 .34731 L
.87522 .3644 L
.88215 .37125 L
.89965 .38905 L
.9068 .39653 L
.92276 .41371 L
.93146 .42336 L
.94458 .43836 L
.95611 .452 L
.96516 .46302 L
.98077 .4829 L
Mfstroke
.4 g
.98077 .77113 m
.95611 .77838 L
.93146 .78113 L
.9068 .78081 L
.88215 .77815 L
.8575 .77361 L
.83284 .76749 L
.80819 .76 L
.80477 .75888 L
.78353 .75126 L
.75888 .7414 L
.74234 .73422 L
.73422 .7305 L
.70957 .71859 L
.69201 .70957 L
.68491 .70576 L
.66026 .69199 L
.64814 .68491 L
.6356 .67732 L
.61095 .66177 L
.60861 .66026 L
.58629 .6453 L
.57235 .6356 L
.56164 .62792 L
.53874 .61095 L
.53698 .60961 L
.51233 .5903 L
.50737 .58629 L
.48767 .56995 L
.47796 .56164 L
.46302 .54849 L
.45034 .53698 L
.43836 .52581 L
.42436 .51233 L
.41371 .50177 L
.39994 .48767 L
.38905 .47617 L
.37702 .46302 L
.3644 .44873 L
.35556 .43836 L
.33974 .41903 L
.33556 .41371 L
.31704 .38905 L
.31509 .38635 L
.30004 .3644 L
.29043 .34941 L
.28461 .33974 L
.27087 .31509 L
.26578 .30518 L
.25897 .29043 L
.24912 .26578 L
.24162 .24112 L
.24112 .2391 L
.23695 .21647 L
.23584 .19181 L
.23961 .16716 L
.24112 .16131 L
.25104 .1425 L
.26578 .12657 L
.27896 .11785 L
.29043 .11268 L
.31509 .10605 L
.33974 .10371 L
.3644 .10434 L
.38905 .10723 L
.41371 .11197 L
.43704 .11785 L
.43836 .11825 L
.46302 .12591 L
.48767 .13478 L
.50703 .1425 L
.51233 .14476 L
.53698 .15579 L
.56041 .16716 L
.56164 .16778 L
.58629 .18075 L
.60612 .19181 L
.61095 .19461 L
.6356 .20939 L
.64695 .21647 L
.66026 .22505 L
.68421 .24112 L
.68491 .24161 L
.70957 .25911 L
.71865 .26578 L
.73422 .27755 L
.75074 .29043 L
.75888 .29696 L
.78078 .31509 L
.78353 .31743 L
.80819 .33903 L
.80898 .33974 L
.83284 .36186 L
.83549 .3644 L
.8575 .38607 L
.86043 .38905 L
.88215 .41187 L
.88384 .41371 L
.90579 .43836 L
.9068 .43954 L
.92627 .46302 L
.93146 .46955 L
.94528 .48767 L
.95611 .50263 L
.96282 .51233 L
.97877 .53698 L
.98077 .54023 L
F
0 g
.98077 .77113 m
.95611 .77838 L
.93146 .78113 L
.9068 .78081 L
.88215 .77815 L
.8575 .77361 L
.83284 .76749 L
.80819 .76 L
.80477 .75888 L
.78353 .75126 L
.75888 .7414 L
.74234 .73422 L
.73422 .7305 L
.70957 .71859 L
.69201 .70957 L
.68491 .70576 L
.66026 .69199 L
.64814 .68491 L
.6356 .67732 L
.61095 .66177 L
.60861 .66026 L
.58629 .6453 L
.57235 .6356 L
.56164 .62792 L
.53874 .61095 L
.53698 .60961 L
.51233 .5903 L
.50737 .58629 L
.48767 .56995 L
.47796 .56164 L
.46302 .54849 L
.45034 .53698 L
.43836 .52581 L
.42436 .51233 L
.41371 .50177 L
.39994 .48767 L
.38905 .47617 L
.37702 .46302 L
.3644 .44873 L
.35556 .43836 L
.33974 .41903 L
.33556 .41371 L
.31704 .38905 L
.31509 .38635 L
.30004 .3644 L
.29043 .34941 L
.28461 .33974 L
.27087 .31509 L
.26578 .30518 L
.25897 .29043 L
Mistroke
.24912 .26578 L
.24162 .24112 L
.24112 .2391 L
.23695 .21647 L
.23584 .19181 L
.23961 .16716 L
.24112 .16131 L
.25104 .1425 L
.26578 .12657 L
.27896 .11785 L
.29043 .11268 L
.31509 .10605 L
.33974 .10371 L
.3644 .10434 L
.38905 .10723 L
.41371 .11197 L
.43704 .11785 L
.43836 .11825 L
.46302 .12591 L
.48767 .13478 L
.50703 .1425 L
.51233 .14476 L
.53698 .15579 L
.56041 .16716 L
.56164 .16778 L
.58629 .18075 L
.60612 .19181 L
.61095 .19461 L
.6356 .20939 L
.64695 .21647 L
.66026 .22505 L
.68421 .24112 L
.68491 .24161 L
.70957 .25911 L
.71865 .26578 L
.73422 .27755 L
.75074 .29043 L
.75888 .29696 L
.78078 .31509 L
.78353 .31743 L
.80819 .33903 L
.80898 .33974 L
.83284 .36186 L
.83549 .3644 L
.8575 .38607 L
.86043 .38905 L
.88215 .41187 L
.88384 .41371 L
.90579 .43836 L
.9068 .43954 L
Mistroke
.92627 .46302 L
.93146 .46955 L
.94528 .48767 L
.95611 .50263 L
.96282 .51233 L
.97877 .53698 L
.98077 .54023 L
Mfstroke
.5 g
.98077 .6827 m
.98014 .68491 L
.96709 .70957 L
.95611 .7208 L
.93146 .73343 L
.92894 .73422 L
.9068 .73874 L
.88215 .73977 L
.8575 .73784 L
.83364 .73422 L
.83284 .73364 L
.80819 .72761 L
.78353 .72 L
.75888 .71101 L
.75519 .70957 L
.73422 .70076 L
.70957 .68935 L
.70055 .68491 L
.68491 .67684 L
.66026 .66327 L
.655 .66026 L
.6356 .64867 L
.61484 .6356 L
.61095 .63307 L
.58629 .61641 L
.5785 .61095 L
.56164 .59872 L
.54516 .58629 L
.53698 .57993 L
.51431 .56164 L
.51233 .55999 L
.48767 .5388 L
.48562 .53698 L
.46302 .51625 L
.45889 .51233 L
.43836 .49215 L
.43397 .48767 L
.41371 .46624 L
.41078 .46302 L
.38925 .43836 L
.38905 .43813 L
.36939 .41371 L
.3644 .40719 L
.35122 .38905 L
.33974 .37217 L
.33479 .3644 L
.32022 .33974 L
.31509 .33036 L
.30766 .31509 L
.29736 .29043 L
.29043 .26922 L
.28969 .26578 L
.28525 .24112 L
.28504 .21647 L
.29043 .19343 L
.29109 .19181 L
.30871 .16716 L
.31509 .16216 L
.33974 .15056 L
.3644 .14589 L
.38905 .14527 L
.41371 .14749 L
.43836 .15192 L
.46302 .15815 L
.48767 .16592 L
.49127 .16716 L
.51233 .17507 L
.53698 .18546 L
.5509 .19181 L
.56164 .197 L
.58629 .20964 L
.59886 .21647 L
.61095 .22332 L
.6356 .23803 L
.64059 .24112 L
.66026 .25377 L
.67808 .26578 L
.68491 .27053 L
.70957 .28836 L
.71235 .29043 L
.73422 .30728 L
.74399 .31509 L
.75888 .32736 L
.77337 .33974 L
.78353 .3487 L
.80073 .3644 L
.80819 .37142 L
.82625 .38905 L
.83284 .39571 L
.85001 .41371 L
.8575 .42185 L
.87209 .43836 L
.88215 .45024 L
.8925 .46302 L
.9068 .4816 L
.91124 .48767 L
.92826 .51233 L
.93146 .51721 L
.94347 .53698 L
.95611 .56039 L
.95673 .56164 L
.96781 .58629 L
.9764 .61095 L
.98077 .62865 L
F
0 g
.98077 .6827 m
.98014 .68491 L
.96709 .70957 L
.95611 .7208 L
.93146 .73343 L
.92894 .73422 L
.9068 .73874 L
.88215 .73977 L
.8575 .73784 L
.83364 .73422 L
.83284 .73364 L
.80819 .72761 L
.78353 .72 L
.75888 .71101 L
.75519 .70957 L
.73422 .70076 L
.70957 .68935 L
.70055 .68491 L
.68491 .67684 L
.66026 .66327 L
.655 .66026 L
.6356 .64867 L
.61484 .6356 L
.61095 .63307 L
.58629 .61641 L
.5785 .61095 L
.56164 .59872 L
.54516 .58629 L
.53698 .57993 L
.51431 .56164 L
.51233 .55999 L
.48767 .5388 L
.48562 .53698 L
.46302 .51625 L
.45889 .51233 L
.43836 .49215 L
.43397 .48767 L
.41371 .46624 L
.41078 .46302 L
.38925 .43836 L
.38905 .43813 L
.36939 .41371 L
.3644 .40719 L
.35122 .38905 L
.33974 .37217 L
.33479 .3644 L
.32022 .33974 L
.31509 .33036 L
.30766 .31509 L
.29736 .29043 L
Mistroke
.29043 .26922 L
.28969 .26578 L
.28525 .24112 L
.28504 .21647 L
.29043 .19343 L
.29109 .19181 L
.30871 .16716 L
.31509 .16216 L
.33974 .15056 L
.3644 .14589 L
.38905 .14527 L
.41371 .14749 L
.43836 .15192 L
.46302 .15815 L
.48767 .16592 L
.49127 .16716 L
.51233 .17507 L
.53698 .18546 L
.5509 .19181 L
.56164 .197 L
.58629 .20964 L
.59886 .21647 L
.61095 .22332 L
.6356 .23803 L
.64059 .24112 L
.66026 .25377 L
.67808 .26578 L
.68491 .27053 L
.70957 .28836 L
.71235 .29043 L
.73422 .30728 L
.74399 .31509 L
.75888 .32736 L
.77337 .33974 L
.78353 .3487 L
.80073 .3644 L
.80819 .37142 L
.82625 .38905 L
.83284 .39571 L
.85001 .41371 L
.8575 .42185 L
.87209 .43836 L
.88215 .45024 L
.8925 .46302 L
.9068 .4816 L
.91124 .48767 L
.92826 .51233 L
.93146 .51721 L
.94347 .53698 L
.95611 .56039 L
Mistroke
.95673 .56164 L
.96781 .58629 L
.9764 .61095 L
.98077 .62865 L
Mfstroke
.6 g
.38905 .18549 m
.41371 .18343 L
.43836 .18501 L
.46302 .18924 L
.47492 .19181 L
.48767 .19554 L
.51233 .2036 L
.53698 .21318 L
.54477 .21647 L
.56164 .22414 L
.58629 .23639 L
.59525 .24112 L
.61095 .24985 L
.6356 .2645 L
.63768 .26578 L
.66026 .28032 L
.67514 .29043 L
.68491 .29732 L
.70896 .31509 L
.70957 .31556 L
.73422 .33508 L
.73987 .33974 L
.75888 .356 L
.7683 .3644 L
.78353 .37846 L
.79453 .38905 L
.80819 .40271 L
.81872 .41371 L
.83284 .42909 L
.84097 .43836 L
.8575 .45821 L
.8613 .46302 L
.8797 .48767 L
.88215 .49111 L
.89611 .51233 L
.9068 .53031 L
.91037 .53698 L
.92226 .56164 L
.93141 .58629 L
.93146 .58646 L
.93722 .61095 L
.9386 .6356 L
.93326 .66026 L
.93146 .66498 L
.91461 .68491 L
.9068 .69001 L
.88215 .69894 L
.8575 .7015 L
.83284 .70027 L
.80819 .69632 L
.78353 .69023 L
.76598 .68491 L
.75888 .68237 L
.73422 .67296 L
.70957 .66215 L
.70551 .66026 L
.68491 .65005 L
.66026 .63673 L
.65827 .6356 L
.6356 .62221 L
.61769 .61095 L
.61095 .60653 L
.58629 .58966 L
.58156 .58629 L
.56164 .57158 L
.54877 .56164 L
.53698 .55221 L
.51872 .53698 L
.51233 .53146 L
.49105 .51233 L
.48767 .50918 L
.46551 .48767 L
.46302 .48516 L
.44198 .46302 L
.43836 .45905 L
.42038 .43836 L
.41371 .43032 L
.40068 .41371 L
.38905 .39793 L
.38293 .38905 L
.36722 .3644 L
.3644 .35974 L
.35372 .33974 L
.34269 .31509 L
.33974 .30971 L
.33457 .29043 L
.33008 .26578 L
.33058 .24112 L
.33919 .21647 L
.33974 .21548 L
.3644 .19342 L
.36686 .19181 L
F
0 g
.38905 .18549 m
.41371 .18343 L
.43836 .18501 L
.46302 .18924 L
.47492 .19181 L
.48767 .19554 L
.51233 .2036 L
.53698 .21318 L
.54477 .21647 L
.56164 .22414 L
.58629 .23639 L
.59525 .24112 L
.61095 .24985 L
.6356 .2645 L
.63768 .26578 L
.66026 .28032 L
.67514 .29043 L
.68491 .29732 L
.70896 .31509 L
.70957 .31556 L
.73422 .33508 L
.73987 .33974 L
.75888 .356 L
.7683 .3644 L
.78353 .37846 L
.79453 .38905 L
.80819 .40271 L
.81872 .41371 L
.83284 .42909 L
.84097 .43836 L
.8575 .45821 L
.8613 .46302 L
.8797 .48767 L
.88215 .49111 L
.89611 .51233 L
.9068 .53031 L
.91037 .53698 L
.92226 .56164 L
.93141 .58629 L
.93146 .58646 L
.93722 .61095 L
.9386 .6356 L
.93326 .66026 L
.93146 .66498 L
.91461 .68491 L
.9068 .69001 L
.88215 .69894 L
.8575 .7015 L
.83284 .70027 L
.80819 .69632 L
Mistroke
.78353 .69023 L
.76598 .68491 L
.75888 .68237 L
.73422 .67296 L
.70957 .66215 L
.70551 .66026 L
.68491 .65005 L
.66026 .63673 L
.65827 .6356 L
.6356 .62221 L
.61769 .61095 L
.61095 .60653 L
.58629 .58966 L
.58156 .58629 L
.56164 .57158 L
.54877 .56164 L
.53698 .55221 L
.51872 .53698 L
.51233 .53146 L
.49105 .51233 L
.48767 .50918 L
.46551 .48767 L
.46302 .48516 L
.44198 .46302 L
.43836 .45905 L
.42038 .43836 L
.41371 .43032 L
.40068 .41371 L
.38905 .39793 L
.38293 .38905 L
.36722 .3644 L
.3644 .35974 L
.35372 .33974 L
.34269 .31509 L
.33974 .30971 L
.33457 .29043 L
.33008 .26578 L
.33058 .24112 L
.33919 .21647 L
.33974 .21548 L
.3644 .19342 L
.36686 .19181 L
.38905 .18549 L
Mfstroke
.7 g
.38905 .23922 m
.41371 .2248 L
.43836 .22078 L
.46302 .22157 L
.48767 .2256 L
.51233 .23208 L
.53698 .24055 L
.53851 .24112 L
.56164 .25072 L
.58629 .26245 L
.59281 .26578 L
.61095 .27562 L
.6356 .29019 L
.636 .29043 L
.66026 .30611 L
.67329 .31509 L
.68491 .32343 L
.70643 .33974 L
.70957 .34221 L
.73422 .36256 L
.73635 .3644 L
.75888 .38465 L
.76354 .38905 L
.78353 .40876 L
.78829 .41371 L
.80819 .4354 L
.81075 .43836 L
.83098 .46302 L
.83284 .46539 L
.84895 .48767 L
.8575 .5005 L
.86453 .51233 L
.8775 .53698 L
.88215 .54571 L
.88744 .56164 L
.89363 .58629 L
.89467 .61095 L
.88708 .6356 L
.88215 .64325 L
.8575 .65905 L
.85356 .66026 L
.83284 .66395 L
.80819 .66363 L
.78522 .66026 L
.78353 .65992 L
.75888 .65373 L
.73422 .64548 L
.70983 .6356 L
.70957 .63548 L
.68491 .62394 L
.6603 .61095 L
.66026 .61092 L
.6356 .59653 L
.61934 .58629 L
.61095 .58076 L
.58629 .56359 L
.5836 .56164 L
.56164 .545 L
.55159 .53698 L
.53698 .52485 L
.52262 .51233 L
.51233 .50298 L
.49627 .48767 L
.48767 .47912 L
.4723 .46302 L
.46302 .45283 L
.45059 .43836 L
.43836 .42329 L
.43111 .41371 L
.41392 .38905 L
.41371 .38874 L
.39917 .3644 L
.38905 .34439 L
.38716 .33974 L
.37836 .31509 L
.37368 .29043 L
.37493 .26578 L
.38731 .24112 L
F
0 g
.38905 .23922 m
.41371 .2248 L
.43836 .22078 L
.46302 .22157 L
.48767 .2256 L
.51233 .23208 L
.53698 .24055 L
.53851 .24112 L
.56164 .25072 L
.58629 .26245 L
.59281 .26578 L
.61095 .27562 L
.6356 .29019 L
.636 .29043 L
.66026 .30611 L
.67329 .31509 L
.68491 .32343 L
.70643 .33974 L
.70957 .34221 L
.73422 .36256 L
.73635 .3644 L
.75888 .38465 L
.76354 .38905 L
.78353 .40876 L
.78829 .41371 L
.80819 .4354 L
.81075 .43836 L
.83098 .46302 L
.83284 .46539 L
.84895 .48767 L
.8575 .5005 L
.86453 .51233 L
.8775 .53698 L
.88215 .54571 L
.88744 .56164 L
.89363 .58629 L
.89467 .61095 L
.88708 .6356 L
.88215 .64325 L
.8575 .65905 L
.85356 .66026 L
.83284 .66395 L
.80819 .66363 L
.78522 .66026 L
.78353 .65992 L
.75888 .65373 L
.73422 .64548 L
.70983 .6356 L
.70957 .63548 L
.68491 .62394 L
Mistroke
.6603 .61095 L
.66026 .61092 L
.6356 .59653 L
.61934 .58629 L
.61095 .58076 L
.58629 .56359 L
.5836 .56164 L
.56164 .545 L
.55159 .53698 L
.53698 .52485 L
.52262 .51233 L
.51233 .50298 L
.49627 .48767 L
.48767 .47912 L
.4723 .46302 L
.46302 .45283 L
.45059 .43836 L
.43836 .42329 L
.43111 .41371 L
.41392 .38905 L
.41371 .38874 L
.39917 .3644 L
.38905 .34439 L
.38716 .33974 L
.37836 .31509 L
.37368 .29043 L
.37493 .26578 L
.38731 .24112 L
.38905 .23922 L
Mfstroke
.1 g
.98077 .42334 m
.97221 .41371 L
.95611 .39625 L
.94933 .38905 L
.93146 .37054 L
.92539 .3644 L
.9068 .34604 L
.90029 .33974 L
.88215 .32263 L
.87398 .31509 L
.8575 .30021 L
.84643 .29043 L
.83284 .27871 L
.81754 .26578 L
.80819 .25806 L
.78725 .24112 L
.78353 .23819 L
.75888 .21911 L
.75539 .21647 L
.73422 .20081 L
.7218 .19181 L
.70957 .1832 L
.68628 .16716 L
.68491 .16624 L
.66026 .15005 L
.64848 .1425 L
.6356 .13452 L
.61095 .11961 L
.60797 .11785 L
.58629 .10547 L
.56402 .0932 L
.56164 .09193 L
.53698 .07917 L
.51548 .06854 L
.51233 .06705 L
.48767 .05574 L
.46302 .04512 L
.46003 .04389 L
.43836 .0353 L
.41371 .02638 L
.39177 .01923 L
.98077 .01923 L
F
0 g
.98077 .42334 m
.97221 .41371 L
.95611 .39625 L
.94933 .38905 L
.93146 .37054 L
.92539 .3644 L
.9068 .34604 L
.90029 .33974 L
.88215 .32263 L
.87398 .31509 L
.8575 .30021 L
.84643 .29043 L
.83284 .27871 L
.81754 .26578 L
.80819 .25806 L
.78725 .24112 L
.78353 .23819 L
.75888 .21911 L
.75539 .21647 L
.73422 .20081 L
.7218 .19181 L
.70957 .1832 L
.68628 .16716 L
.68491 .16624 L
.66026 .15005 L
.64848 .1425 L
.6356 .13452 L
.61095 .11961 L
.60797 .11785 L
.58629 .10547 L
.56402 .0932 L
.56164 .09193 L
.53698 .07917 L
.51548 .06854 L
.51233 .06705 L
.48767 .05574 L
.46302 .04512 L
.46003 .04389 L
.43836 .0353 L
.41371 .02638 L
.39177 .01923 L
s
.8 g
.46302 .25954 m
.48767 .25895 L
.51233 .26266 L
.5281 .26578 L
.53698 .26928 L
.56164 .27824 L
.58629 .28924 L
.58879 .29043 L
.61095 .30196 L
.63347 .31509 L
.6356 .31641 L
.66026 .33249 L
.67061 .33974 L
.68491 .35026 L
.70292 .3644 L
.70957 .36985 L
.73156 .38905 L
.73422 .39147 L
.75713 .41371 L
.75888 .41547 L
.77991 .43836 L
.78353 .44249 L
.79999 .46302 L
.80819 .47393 L
.81731 .48767 L
.83165 .51233 L
.83284 .5135 L
.84261 .53698 L
.84923 .56164 L
.84959 .58629 L
.83739 .61095 L
.83284 .61501 L
.80819 .6251 L
.78353 .62624 L
.75888 .62294 L
.73422 .61657 L
.71694 .61095 L
.70957 .60784 L
.68491 .59711 L
.66344 .58629 L
.66026 .58454 L
.6356 .57031 L
.6218 .56164 L
.61095 .55442 L
.58652 .53698 L
.58629 .53681 L
.56164 .51746 L
.5555 .51233 L
.53698 .49612 L
.52791 .48767 L
.51233 .47244 L
.5033 .46302 L
.48767 .44578 L
.48143 .43836 L
.46302 .41475 L
.46228 .41371 L
.44589 .38905 L
.43836 .3767 L
.43262 .3644 L
.42297 .33974 L
.41815 .31509 L
.42076 .29043 L
.43836 .26745 L
.44273 .26578 L
F
0 g
.46302 .25954 m
.48767 .25895 L
.51233 .26266 L
.5281 .26578 L
.53698 .26928 L
.56164 .27824 L
.58629 .28924 L
.58879 .29043 L
.61095 .30196 L
.63347 .31509 L
.6356 .31641 L
.66026 .33249 L
.67061 .33974 L
.68491 .35026 L
.70292 .3644 L
.70957 .36985 L
.73156 .38905 L
.73422 .39147 L
.75713 .41371 L
.75888 .41547 L
.77991 .43836 L
.78353 .44249 L
.79999 .46302 L
.80819 .47393 L
.81731 .48767 L
.83165 .51233 L
.83284 .5135 L
.84261 .53698 L
.84923 .56164 L
.84959 .58629 L
.83739 .61095 L
.83284 .61501 L
.80819 .6251 L
.78353 .62624 L
.75888 .62294 L
.73422 .61657 L
.71694 .61095 L
.70957 .60784 L
.68491 .59711 L
.66344 .58629 L
.66026 .58454 L
.6356 .57031 L
.6218 .56164 L
.61095 .55442 L
.58652 .53698 L
.58629 .53681 L
.56164 .51746 L
.5555 .51233 L
.53698 .49612 L
.52791 .48767 L
Mistroke
.51233 .47244 L
.5033 .46302 L
.48767 .44578 L
.48143 .43836 L
.46302 .41475 L
.46228 .41371 L
.44589 .38905 L
.43836 .3767 L
.43262 .3644 L
.42297 .33974 L
.41815 .31509 L
.42076 .29043 L
.43836 .26745 L
.44273 .26578 L
.46302 .25954 L
Mfstroke
.9 g
.48767 .30359 m
.51233 .29969 L
.53698 .30247 L
.56164 .30921 L
.57882 .31509 L
.58629 .31877 L
.61095 .33078 L
.62703 .33974 L
.6356 .34499 L
.66026 .36141 L
.66443 .3644 L
.68491 .37994 L
.69592 .38905 L
.70957 .40096 L
.72295 .41371 L
.73422 .425 L
.74625 .43836 L
.75888 .45328 L
.76604 .46302 L
.78221 .48767 L
.78353 .49002 L
.79436 .51233 L
.80114 .53698 L
.79933 .56164 L
.78353 .58171 L
.75888 .58494 L
.73422 .58297 L
.70957 .57675 L
.68491 .5674 L
.67177 .56164 L
.66026 .55569 L
.6356 .54167 L
.62802 .53698 L
.61095 .52562 L
.59279 .51233 L
.58629 .5073 L
.563 .48767 L
.56164 .48647 L
.53728 .46302 L
.53698 .46272 L
.51512 .43836 L
.51233 .43524 L
.49646 .41371 L
.48767 .40123 L
.48157 .38905 L
.47102 .3644 L
.46663 .33974 L
.47301 .31509 L
F
0 g
.48767 .30359 m
.51233 .29969 L
.53698 .30247 L
.56164 .30921 L
.57882 .31509 L
.58629 .31877 L
.61095 .33078 L
.62703 .33974 L
.6356 .34499 L
.66026 .36141 L
.66443 .3644 L
.68491 .37994 L
.69592 .38905 L
.70957 .40096 L
.72295 .41371 L
.73422 .425 L
.74625 .43836 L
.75888 .45328 L
.76604 .46302 L
.78221 .48767 L
.78353 .49002 L
.79436 .51233 L
.80114 .53698 L
.79933 .56164 L
.78353 .58171 L
.75888 .58494 L
.73422 .58297 L
.70957 .57675 L
.68491 .5674 L
.67177 .56164 L
.66026 .55569 L
.6356 .54167 L
.62802 .53698 L
.61095 .52562 L
.59279 .51233 L
.58629 .5073 L
.563 .48767 L
.56164 .48647 L
.53728 .46302 L
.53698 .46272 L
.51512 .43836 L
.51233 .43524 L
.49646 .41371 L
.48767 .40123 L
.48157 .38905 L
.47102 .3644 L
.46663 .33974 L
.47301 .31509 L
.48767 .30359 L
s
1 g
.53698 .35726 m
.56164 .35031 L
.58629 .35674 L
.60491 .3644 L
.61095 .36674 L
.6356 .3805 L
.64875 .38905 L
.66026 .39722 L
.67977 .41371 L
.68491 .41771 L
.70439 .43836 L
.70957 .44148 L
.72358 .46302 L
.73422 .48276 L
.73635 .48767 L
.74101 .51233 L
.73422 .52525 L
.70957 .53294 L
.68491 .52971 L
.66026 .51944 L
.64496 .51233 L
.6356 .50647 L
.61095 .48924 L
.60887 .48767 L
.58629 .46921 L
.57989 .46302 L
.56164 .44421 L
.55715 .43836 L
.53975 .41371 L
.53698 .40813 L
.52899 .38905 L
.52895 .3644 L
F
0 g
.53698 .35726 m
.56164 .35031 L
.58629 .35674 L
.60491 .3644 L
.61095 .36674 L
.6356 .3805 L
.64875 .38905 L
.66026 .39722 L
.67977 .41371 L
.68491 .41771 L
.70439 .43836 L
.70957 .44148 L
.72358 .46302 L
.73422 .48276 L
.73635 .48767 L
.74101 .51233 L
.73422 .52525 L
.70957 .53294 L
.68491 .52971 L
.66026 .51944 L
.64496 .51233 L
.6356 .50647 L
.61095 .48924 L
.60887 .48767 L
.58629 .46921 L
.57989 .46302 L
.56164 .44421 L
.55715 .43836 L
.53975 .41371 L
.53698 .40813 L
.52899 .38905 L
.52895 .3644 L
.53698 .35726 L
s
.98077 .34029 m
.98023 .33974 L
.95611 .31625 L
.9549 .31509 L
.93146 .29307 L
.9286 .29043 L
.9068 .27072 L
.90126 .26578 L
.88215 .24912 L
.87285 .24112 L
.8575 .22823 L
.84332 .21647 L
.83284 .208 L
.8126 .19181 L
.80819 .18839 L
.78353 .16941 L
.78057 .16716 L
.75888 .15112 L
.74709 .1425 L
.73422 .13339 L
.71208 .11785 L
.70957 .11615 L
.68491 .09958 L
.67528 .0932 L
.66026 .08358 L
.63648 .06854 L
.6356 .06801 L
.61095 .05317 L
.59526 .04389 L
.58629 .03866 L
.56164 .02484 L
.55114 .01923 L
.98077 .01923 L
F
.98077 .34029 m
.98023 .33974 L
.95611 .31625 L
.9549 .31509 L
.93146 .29307 L
.9286 .29043 L
.9068 .27072 L
.90126 .26578 L
.88215 .24912 L
.87285 .24112 L
.8575 .22823 L
.84332 .21647 L
.83284 .208 L
.8126 .19181 L
.80819 .18839 L
.78353 .16941 L
.78057 .16716 L
.75888 .15112 L
.74709 .1425 L
.73422 .13339 L
.71208 .11785 L
.70957 .11615 L
.68491 .09958 L
.67528 .0932 L
.66026 .08358 L
.63648 .06854 L
.6356 .06801 L
.61095 .05317 L
.59526 .04389 L
.58629 .03866 L
.56164 .02484 L
.55114 .01923 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.423961 0.477324 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55574 Mtetra
.53207 .55574 .53948 .56341 .55329 .55926 .54592 .55156 Mtetra
.54592 .55156 .55329 .55926 .56716 .5551 .55985 .54736 Mtetra
.55985 .54736 .56716 .5551 .58111 .55092 .57384 .54314 Mtetra
.57384 .54314 .58111 .55092 .59512 .54671 .5879 .5389 Mtetra
.663 .741 .908 r
.5879 .5389 .59512 .54671 .60921 .54249 .60203 .53463 Mtetra
.60203 .53463 .60921 .54249 .62337 .53824 .61624 .53035 Mtetra
.61624 .53035 .62337 .53824 .6376 .53398 .63052 .52605 Mtetra
.63052 .52605 .6376 .53398 .6519 .5297 .64487 .52173 Mtetra
.663 .741 .909 r
.64487 .52173 .6519 .5297 .66627 .5254 .6593 .51741 Mtetra
.662 .742 .909 r
.6593 .51741 .66627 .5254 .68072 .52109 .6738 .51309 Mtetra
.661 .742 .91 r
.6738 .51309 .68072 .52109 .69525 .51679 .68838 .50878 Mtetra
.66 .742 .911 r
.68838 .50878 .69525 .51679 .70985 .51249 .70304 .50451 Mtetra
.657 .743 .913 r
.70304 .50451 .70985 .51249 .72454 .50823 .71778 .50031 Mtetra
.653 .745 .917 r
.71778 .50031 .72454 .50823 .7393 .50403 .73261 .49622 Mtetra
.648 .747 .921 r
.73261 .49622 .7393 .50403 .75415 .49993 .74753 .49229 Mtetra
.64 .75 .928 r
.74753 .49229 .75415 .49993 .7691 .49597 .76255 .48858 Mtetra
.629 .754 .937 r
.76255 .48858 .7691 .49597 .78414 .49219 .77768 .48514 Mtetra
.615 .76 .948 r
.77768 .48514 .78414 .49219 .79929 .48864 .79293 .48204 Mtetra
.596 .767 .961 r
.79293 .48204 .79929 .48864 .81455 .48536 .80831 .4793 Mtetra
.573 .776 .975 r
.80831 .4793 .81455 .48536 .82994 .48237 .82382 .47693 Mtetra
.543 .786 .988 r
.82382 .47693 .82994 .48237 .84544 .47966 .83946 .47487 Mtetra
.51 .795 .997 r
.83946 .47487 .84544 .47966 .86108 .47718 .85524 .47304 Mtetra
.478 .803 1 r
.85524 .47304 .86108 .47718 .87683 .47483 .87113 .47128 Mtetra
.453 .812 .996 r
.87113 .47128 .87683 .47483 .89269 .47249 .88713 .4694 Mtetra
.444 .823 .99 r
.88713 .4694 .89269 .47249 .90864 .46998 .90321 .46717 Mtetra
.459 .84 .986 r
.90321 .46717 .90864 .46998 .92466 .46714 .91933 .46438 Mtetra
.496 .862 .987 r
.91933 .46438 .92466 .46714 .94072 .46379 .93546 .46084 Mtetra
.55 .882 .989 r
.93546 .46084 .94072 .46379 .9568 .4598 .95159 .45643 Mtetra
.609 .895 .988 r
.95159 .45643 .9568 .4598 .97288 .4551 .96768 .45111 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55638 Mtetra
.49701 .55638 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.51077 .55221 .51829 .5599 .53207 .55574 .5246 .54801 Mtetra
.5246 .54801 .53207 .55574 .54592 .55156 .5385 .54379 Mtetra
.5385 .54379 .54592 .55156 .55985 .54736 .55246 .53955 Mtetra
.55246 .53955 .55985 .54736 .57384 .54314 .5665 .53529 Mtetra
.663 .741 .908 r
.5665 .53529 .57384 .54314 .5879 .5389 .58061 .53101 Mtetra
.58061 .53101 .5879 .5389 .60203 .53463 .59479 .5267 Mtetra
.59479 .5267 .60203 .53463 .61624 .53035 .60905 .52238 Mtetra
.60905 .52238 .61624 .53035 .63052 .52605 .62338 .51805 Mtetra
.663 .741 .909 r
.62338 .51805 .63052 .52605 .64487 .52173 .63778 .51371 Mtetra
.662 .742 .909 r
.63778 .51371 .64487 .52173 .6593 .51741 .65226 .50937 Mtetra
.661 .742 .91 r
.65226 .50937 .6593 .51741 .6738 .51309 .66681 .50504 Mtetra
.659 .742 .911 r
.66681 .50504 .6738 .51309 .68838 .50878 .68145 .50076 Mtetra
.657 .743 .914 r
.68145 .50076 .68838 .50878 .70304 .50451 .69616 .49656 Mtetra
.652 .745 .917 r
.69616 .49656 .70304 .50451 .71778 .50031 .71097 .49247 Mtetra
.646 .747 .922 r
.71097 .49247 .71778 .50031 .73261 .49622 .72586 .48858 Mtetra
.637 .75 .93 r
.72586 .48858 .73261 .49622 .74753 .49229 .74086 .48493 Mtetra
.625 .754 .94 r
.74086 .48493 .74753 .49229 .76255 .48858 .75597 .48161 Mtetra
.607 .76 .952 r
.75597 .48161 .76255 .48858 .77768 .48514 .77121 .47868 Mtetra
.583 .768 .967 r
.77121 .47868 .77768 .48514 .79293 .48204 .78657 .47621 Mtetra
.551 .776 .982 r
.78657 .47621 .79293 .48204 .80831 .4793 .80208 .47419 Mtetra
.509 .783 .994 r
.80208 .47419 .80831 .4793 .82382 .47693 .81773 .47261 Mtetra
.457 .787 .999 r
.81773 .47261 .82382 .47693 .83946 .47487 .83353 .47135 Mtetra
.402 .786 .991 r
.83353 .47135 .83946 .47487 .85524 .47304 .84947 .47026 Mtetra
.353 .782 .971 r
.84947 .47026 .85524 .47304 .87113 .47128 .86551 .46911 Mtetra
.325 .783 .948 r
.86551 .46911 .87113 .47128 .88713 .4694 .88165 .46764 Mtetra
.332 .796 .934 r
.88165 .46764 .88713 .4694 .90321 .46717 .89784 .46556 Mtetra
.376 .826 .937 r
.89784 .46556 .90321 .46717 .91933 .46438 .91404 .46262 Mtetra
.452 .865 .953 r
.91404 .46262 .91933 .46438 .93546 .46084 .93023 .45865 Mtetra
.542 .9 .971 r
.93023 .45865 .93546 .46084 .95159 .45643 .94637 .45356 Mtetra
.625 .918 .978 r
.94637 .45356 .95159 .45643 .96768 .45111 .96245 .44736 Mtetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55702 Mtetra
.46198 .55702 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55638 .48938 .54866 Mtetra
.48938 .54866 .49701 .55638 .51077 .55221 .50318 .54444 Mtetra
.50318 .54444 .51077 .55221 .5246 .54801 .51705 .5402 Mtetra
.51705 .5402 .5246 .54801 .5385 .54379 .531 .53594 Mtetra
.531 .53594 .5385 .54379 .55246 .53955 .54501 .53167 Mtetra
.663 .741 .908 r
.54501 .53167 .55246 .53955 .5665 .53529 .5591 .52736 Mtetra
.5591 .52736 .5665 .53529 .58061 .53101 .57325 .52304 Mtetra
.57325 .52304 .58061 .53101 .59479 .5267 .58748 .51871 Mtetra
.58748 .51871 .59479 .5267 .60905 .52238 .60179 .51435 Mtetra
.60179 .51435 .60905 .52238 .62338 .51805 .61617 .50999 Mtetra
.662 .742 .909 r
.61617 .50999 .62338 .51805 .63778 .51371 .63062 .50563 Mtetra
.661 .742 .91 r
.63062 .50563 .63778 .51371 .65226 .50937 .64515 .50129 Mtetra
.659 .742 .911 r
.64515 .50129 .65226 .50937 .66681 .50504 .65976 .49699 Mtetra
.656 .743 .914 r
.65976 .49699 .66681 .50504 .68145 .50076 .67445 .49278 Mtetra
.652 .744 .918 r
.67445 .49278 .68145 .50076 .69616 .49656 .68923 .4887 Mtetra
.645 .747 .923 r
.68923 .4887 .69616 .49656 .71097 .49247 .7041 .48483 Mtetra
.635 .75 .931 r
.7041 .48483 .71097 .49247 .72586 .48858 .71908 .48124 Mtetra
.62 .754 .942 r
.71908 .48124 .72586 .48858 .74086 .48493 .73416 .47802 Mtetra
.599 .76 .956 r
.73416 .47802 .74086 .48493 .75597 .48161 .74938 .47527 Mtetra
.569 .767 .972 r
.74938 .47527 .75597 .48161 .77121 .47868 .76473 .47306 Mtetra
.527 .774 .988 r
.76473 .47306 .77121 .47868 .78657 .47621 .78023 .47142 Mtetra
.468 .776 .997 r
.78023 .47142 .78657 .47621 .80208 .47419 .79588 .47033 Mtetra
.391 .769 .991 r
.79588 .47033 .80208 .47419 .81773 .47261 .8117 .46971 Mtetra
.303 .749 .962 r
.8117 .46971 .81773 .47261 .83353 .47135 .82767 .46937 Mtetra
.221 .72 .91 r
.82767 .46937 .83353 .47135 .84947 .47026 .84377 .46907 Mtetra
.166 .696 .856 r
.84377 .46907 .84947 .47026 .86551 .46911 .85997 .46848 Mtetra
.157 .696 .82 r
.85997 .46848 .86551 .46911 .88165 .46764 .87624 .46728 Mtetra
.202 .729 .82 r
.87624 .46728 .88165 .46764 .89784 .46556 .89253 .46512 Mtetra
.296 .792 .854 r
.89253 .46512 .89784 .46556 .91404 .46262 .90879 .46176 Mtetra
.425 .865 .906 r
.90879 .46176 .91404 .46262 .93023 .45865 .92499 .45704 Mtetra
.557 .92 .949 r
.92499 .45704 .93023 .45865 .94637 .45356 .94112 .45095 Mtetra
.66 .938 .966 r
.94112 .45095 .94637 .45356 .96245 .44736 .95715 .4436 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56181 Mtetra
.41347 .56181 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .55349 Mtetra
.44054 .55349 .44838 .56118 .46198 .55702 .45418 .5493 Mtetra
.45418 .5493 .46198 .55702 .47564 .55285 .46789 .54509 Mtetra
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54444 .49552 .5366 Mtetra
.49552 .5366 .50318 .54444 .51705 .5402 .50944 .53232 Mtetra
.50944 .53232 .51705 .5402 .531 .53594 .52343 .52803 Mtetra
.52343 .52803 .531 .53594 .54501 .53167 .53749 .52371 Mtetra
.663 .741 .908 r
.53749 .52371 .54501 .53167 .5591 .52736 .55162 .51937 Mtetra
.55162 .51937 .5591 .52736 .57325 .52304 .56582 .51501 Mtetra
.56582 .51501 .57325 .52304 .58748 .51871 .5801 .51064 Mtetra
.5801 .51064 .58748 .51871 .60179 .51435 .59446 .50625 Mtetra
.662 .742 .909 r
.59446 .50625 .60179 .51435 .61617 .50999 .60889 .50187 Mtetra
.661 .742 .91 r
.60889 .50187 .61617 .50999 .63062 .50563 .62339 .49751 Mtetra
.659 .742 .911 r
.62339 .49751 .63062 .50563 .64515 .50129 .63798 .4932 Mtetra
.656 .743 .914 r
.63798 .4932 .64515 .50129 .65976 .49699 .65264 .48898 Mtetra
.651 .744 .918 r
.65264 .48898 .65976 .49699 .67445 .49278 .66739 .4849 Mtetra
.644 .746 .924 r
.66739 .4849 .67445 .49278 .68923 .4887 .68224 .48104 Mtetra
.633 .75 .932 r
.68224 .48104 .68923 .4887 .7041 .48483 .69719 .4775 Mtetra
.616 .754 .944 r
.69719 .4775 .7041 .48483 .71908 .48124 .71225 .47438 Mtetra
.592 .76 .959 r
.71225 .47438 .71908 .48124 .73416 .47802 .72744 .47179 Mtetra
.555 .766 .976 r
.72744 .47179 .73416 .47802 .74938 .47527 .74277 .46983 Mtetra
.501 .769 .992 r
.74277 .46983 .74938 .47527 .76473 .47306 .75825 .46856 Mtetra
.422 .764 .996 r
.75825 .46856 .76473 .47306 .78023 .47142 .77391 .46799 Mtetra
.313 .74 .972 r
.77391 .46799 .78023 .47142 .79588 .47033 .78974 .46804 Mtetra
.185 .689 .908 r
.78974 .46804 .79588 .47033 .8117 .46971 .80574 .46852 Mtetra
.065 .622 .81 r
.80574 .46852 .8117 .46971 .82767 .46937 .82189 .46917 Mtetra
0 .565 .712 r
.82189 .46917 .82767 .46937 .84377 .46907 .83816 .46961 Mtetra
.04 0 0 r
.83816 .46961 .84377 .46907 .85997 .46848 .85451 .46945 Mtetra
.004 0 0 r
.85451 .46945 .85997 .46848 .87624 .46728 .87089 .46826 Mtetra
0 0 0 r
.87089 .46826 .87624 .46728 .89253 .46512 .88725 .46571 Mtetra
.25 .762 .769 r
.88725 .46571 .89253 .46512 .90879 .46176 .90354 .46155 Mtetra
.437 .876 .868 r
.90354 .46155 .90879 .46176 .92499 .45704 .91972 .45572 Mtetra
.604 .944 .933 r
.91972 .45572 .92499 .45704 .94112 .45095 .93579 .4483 Mtetra
.712 .953 .951 r
.93579 .4483 .94112 .45095 .95715 .4436 .95175 .43954 Mtetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56181 .40547 .55414 Mtetra
.40547 .55414 .41347 .56181 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .55349 .43263 .54574 Mtetra
.43263 .54574 .44054 .55349 .45418 .5493 .44632 .54151 Mtetra
.44632 .54151 .45418 .5493 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .53298 Mtetra
.47389 .53298 .48167 .54086 .49552 .5366 .48778 .52869 Mtetra
.48778 .52869 .49552 .5366 .50944 .53232 .50175 .52437 Mtetra
.50175 .52437 .50944 .53232 .52343 .52803 .51578 .52003 Mtetra
.663 .741 .908 r
.51578 .52003 .52343 .52803 .53749 .52371 .52989 .51567 Mtetra
.52989 .51567 .53749 .52371 .55162 .51937 .54407 .5113 Mtetra
.54407 .5113 .55162 .51937 .56582 .51501 .55833 .5069 Mtetra
.55833 .5069 .56582 .51501 .5801 .51064 .57265 .5025 Mtetra
.662 .742 .909 r
.57265 .5025 .5801 .51064 .59446 .50625 .58706 .4981 Mtetra
.661 .742 .91 r
.58706 .4981 .59446 .50625 .60889 .50187 .60154 .49372 Mtetra
.659 .742 .911 r
.60154 .49372 .60889 .50187 .62339 .49751 .6161 .48939 Mtetra
.656 .743 .914 r
.6161 .48939 .62339 .49751 .63798 .4932 .63073 .48515 Mtetra
.651 .744 .918 r
.63073 .48515 .63798 .4932 .65264 .48898 .64546 .48106 Mtetra
.643 .746 .924 r
.64546 .48106 .65264 .48898 .66739 .4849 .66028 .47721 Mtetra
.631 .749 .933 r
.66028 .47721 .66739 .4849 .68224 .48104 .6752 .4737 Mtetra
.613 .754 .945 r
.6752 .4737 .68224 .48104 .69719 .4775 .69023 .47066 Mtetra
.585 .759 .961 r
.69023 .47066 .69719 .4775 .71225 .47438 .70539 .46821 Mtetra
.542 .764 .979 r
.70539 .46821 .71225 .47438 .72744 .47179 .72069 .46649 Mtetra
.474 .763 .994 r
.72069 .46649 .72744 .47179 .74277 .46983 .73616 .46559 Mtetra
.371 .747 .99 r
.73616 .46559 .74277 .46983 .75825 .46856 .75181 .46553 Mtetra
.226 .698 .941 r
.75181 .46553 .75825 .46856 .77391 .46799 .76764 .46627 Mtetra
.057 .608 .829 r
.76764 .46627 .77391 .46799 .78974 .46804 .78366 .46762 Mtetra
.093 0 0 r
.78366 .46762 .78974 .46804 .80574 .46852 .79985 .4693 Mtetra
.187 0 0 r
.79985 .4693 .80574 .46852 .82189 .46917 .81619 .4709 Mtetra
.22 0 0 r
.81619 .4709 .82189 .46917 .83816 .46961 .83263 .47195 Mtetra
.194 0 0 r
.83263 .47195 .83816 .46961 .85451 .46945 .84911 .47193 Mtetra
.11 0 0 r
.84911 .47193 .85451 .46945 .87089 .46826 .86557 .4704 Mtetra
0 0 0 r
.86557 .4704 .87089 .46826 .88725 .46571 .88196 .46703 Mtetra
.263 .763 .718 r
.88196 .46703 .88725 .46571 .90354 .46155 .89823 .46165 Mtetra
.501 .909 .856 r
.89823 .46165 .90354 .46155 .91972 .45572 .91436 .45431 Mtetra
.678 .968 .925 r
.91436 .45431 .91972 .45572 .93579 .4483 .93034 .44524 Mtetra
.768 .956 .933 r
.93034 .44524 .93579 .4483 .95175 .43954 .94621 .43484 Mtetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53791 Mtetra
.42465 .53791 .43263 .54574 .44632 .54151 .43837 .53364 Mtetra
.43837 .53364 .44632 .54151 .46007 .53726 .45217 .52935 Mtetra
.45217 .52935 .46007 .53726 .47389 .53298 .46604 .52504 Mtetra
.46604 .52504 .47389 .53298 .48778 .52869 .47998 .5207 Mtetra
.47998 .5207 .48778 .52869 .50175 .52437 .49399 .51634 Mtetra
.663 .741 .908 r
.49399 .51634 .50175 .52437 .51578 .52003 .50807 .51196 Mtetra
.50807 .51196 .51578 .52003 .52989 .51567 .52222 .50757 Mtetra
.52222 .50757 .52989 .51567 .54407 .5113 .53645 .50315 Mtetra
.53645 .50315 .54407 .5113 .55833 .5069 .55076 .49873 Mtetra
.662 .742 .909 r
.55076 .49873 .55833 .5069 .57265 .5025 .56513 .49431 Mtetra
.661 .742 .91 r
.56513 .49431 .57265 .5025 .58706 .4981 .57959 .48991 Mtetra
.659 .742 .911 r
.57959 .48991 .58706 .4981 .60154 .49372 .59412 .48555 Mtetra
.656 .743 .914 r
.59412 .48555 .60154 .49372 .6161 .48939 .60873 .48129 Mtetra
.651 .744 .918 r
.60873 .48129 .6161 .48939 .63073 .48515 .62343 .47719 Mtetra
.643 .746 .924 r
.62343 .47719 .63073 .48515 .64546 .48106 .63822 .47333 Mtetra
.63 .749 .933 r
.63822 .47333 .64546 .48106 .66028 .47721 .6531 .46984 Mtetra
.61 .753 .946 r
.6531 .46984 .66028 .47721 .6752 .4737 .6681 .46686 Mtetra
.579 .758 .963 r
.6681 .46686 .6752 .4737 .69023 .47066 .68323 .46453 Mtetra
.529 .761 .982 r
.68323 .46453 .69023 .47066 .70539 .46821 .69851 .46302 Mtetra
.449 .756 .994 r
.69851 .46302 .70539 .46821 .72069 .46649 .71395 .46245 Mtetra
.321 .727 .979 r
.71395 .46245 .72069 .46649 .73616 .46559 .72957 .46289 Mtetra
.137 .648 .898 r
.72957 .46289 .73616 .46559 .75181 .46553 .7454 .46431 Mtetra
0 .514 .735 r
.7454 .46431 .75181 .46553 .76764 .46627 .76143 .46656 Mtetra
.233 0 0 r
.76143 .46656 .76764 .46627 .78366 .46762 .77765 .46933 Mtetra
.327 0 0 r
.77765 .46933 .78366 .46762 .79985 .4693 .79405 .4722 Mtetra
.36 0 0 r
.79405 .4722 .79985 .4693 .81619 .4709 .81056 .47461 Mtetra
.342 0 0 r
.81056 .47461 .81619 .4709 .83263 .47195 .82715 .47597 Mtetra
.276 0 0 r
.82715 .47597 .83263 .47195 .84911 .47193 .84373 .4757 Mtetra
.147 0 0 r
.84373 .4757 .84911 .47193 .86557 .4704 .86024 .47335 Mtetra
0 0 0 r
.86024 .47335 .86557 .4704 .88196 .46703 .87662 .46865 Mtetra
.349 .813 .721 r
.87662 .46865 .88196 .46703 .89823 .46165 .89283 .46158 Mtetra
.612 .956 .869 r
.89283 .46158 .89823 .46165 .91436 .45431 .90886 .45235 Mtetra
.761 .978 .916 r
.90886 .45235 .91436 .45431 .93034 .44524 .92472 .44137 Mtetra
.817 .941 .908 r
.92472 .44137 .93034 .44524 .94621 .43484 .94047 .42919 Mtetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .5343 Mtetra
.40288 .5343 .41099 .54216 .42465 .53791 .41658 .53001 Mtetra
.41658 .53001 .42465 .53791 .43837 .53364 .43036 .5257 Mtetra
.43036 .5257 .43837 .53364 .45217 .52935 .4442 .52137 Mtetra
.4442 .52137 .45217 .52935 .46604 .52504 .45811 .51701 Mtetra
.45811 .51701 .46604 .52504 .47998 .5207 .4721 .51264 Mtetra
.663 .741 .908 r
.4721 .51264 .47998 .5207 .49399 .51634 .48615 .50824 Mtetra
.48615 .50824 .49399 .51634 .50807 .51196 .50028 .50382 Mtetra
.50028 .50382 .50807 .51196 .52222 .50757 .51448 .49939 Mtetra
.51448 .49939 .52222 .50757 .53645 .50315 .52876 .49494 Mtetra
.662 .741 .909 r
.52876 .49494 .53645 .50315 .55076 .49873 .54311 .4905 Mtetra
.661 .742 .91 r
.54311 .4905 .55076 .49873 .56513 .49431 .55754 .48607 Mtetra
.659 .742 .911 r
.55754 .48607 .56513 .49431 .57959 .48991 .57204 .48169 Mtetra
.656 .743 .914 r
.57204 .48169 .57959 .48991 .59412 .48555 .58663 .47741 Mtetra
.651 .744 .918 r
.58663 .47741 .59412 .48555 .60873 .48129 .6013 .47328 Mtetra
.643 .746 .924 r
.6013 .47328 .60873 .48129 .62343 .47719 .61606 .46941 Mtetra
.629 .748 .933 r
.61606 .46941 .62343 .47719 .63822 .47333 .63091 .46592 Mtetra
.608 .752 .947 r
.63091 .46592 .63822 .47333 .6531 .46984 .64588 .46297 Mtetra
.575 .756 .964 r
.64588 .46297 .6531 .46984 .6681 .46686 .66097 .46073 Mtetra
.519 .758 .983 r
.66097 .46073 .6681 .46686 .68323 .46453 .6762 .45939 Mtetra
.426 .748 .994 r
.6762 .45939 .68323 .46453 .69851 .46302 .69161 .45912 Mtetra
.273 .704 .966 r
.69161 .45912 .69851 .46302 .71395 .46245 .7072 .46002 Mtetra
.054 .593 .851 r
.7072 .46002 .71395 .46245 .72957 .46289 .72301 .46209 Mtetra
.178 0 0 r
.72301 .46209 .72957 .46289 .7454 .46431 .73903 .46523 Mtetra
.344 0 0 r
.73903 .46523 .7454 .46431 .76143 .46656 .75527 .46912 Mtetra
.431 0 0 r
.75527 .46912 .76143 .46656 .77765 .46933 .77171 .47333 Mtetra
.46 0 0 r
.77171 .47333 .77765 .46933 .79405 .4722 .7883 .47723 Mtetra
.448 0 0 r
.7883 .47723 .79405 .4722 .81056 .47461 .80499 .48014 Mtetra
.397 0 0 r
.80499 .48014 .81056 .47461 .82715 .47597 .82169 .48137 Mtetra
.296 0 0 r
.82169 .48137 .82715 .47597 .84373 .4757 .83833 .48031 Mtetra
.118 0 0 r
.83833 .48031 .84373 .4757 .86024 .47335 .85484 .47657 Mtetra
0 0 0 r
.85484 .47657 .86024 .47335 .87662 .46865 .87115 .47002 Mtetra
.505 .902 .773 r
.87115 .47002 .87662 .46865 .89283 .46158 .88726 .46081 Mtetra
.736 .989 .885 r
.88726 .46081 .89283 .46158 .90886 .45235 .90316 .44937 Mtetra
.827 .963 .896 r
.90316 .44937 .90886 .45235 .92472 .44137 .91889 .4363 Mtetra
.847 .91 .878 r
.91889 .4363 .92472 .44137 .94047 .42919 .93452 .42231 Mtetra
.664 .741 .908 r
.34042 .54346 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53067 Mtetra
.38103 .53067 .38925 .53857 .40288 .5343 .3947 .52637 Mtetra
.3947 .52637 .40288 .5343 .41658 .53001 .40845 .52204 Mtetra
.40845 .52204 .41658 .53001 .43036 .5257 .42226 .51768 Mtetra
.42226 .51768 .43036 .5257 .4442 .52137 .43615 .51331 Mtetra
.43615 .51331 .4442 .52137 .45811 .51701 .45011 .50892 Mtetra
.663 .741 .908 r
.45011 .50892 .45811 .51701 .4721 .51264 .46414 .5045 Mtetra
.46414 .5045 .4721 .51264 .48615 .50824 .47824 .50006 Mtetra
.47824 .50006 .48615 .50824 .50028 .50382 .49242 .49561 Mtetra
.49242 .49561 .50028 .50382 .51448 .49939 .50667 .49114 Mtetra
.662 .741 .909 r
.50667 .49114 .51448 .49939 .52876 .49494 .52099 .48667 Mtetra
.661 .742 .91 r
.52099 .48667 .52876 .49494 .54311 .4905 .53539 .48222 Mtetra
.659 .742 .911 r
.53539 .48222 .54311 .4905 .55754 .48607 .54987 .47781 Mtetra
.656 .743 .913 r
.54987 .47781 .55754 .48607 .57204 .48169 .56443 .4735 Mtetra
.651 .744 .917 r
.56443 .4735 .57204 .48169 .58663 .47741 .57907 .46934 Mtetra
.643 .745 .923 r
.57907 .46934 .58663 .47741 .6013 .47328 .59379 .46544 Mtetra
.629 .748 .933 r
.59379 .46544 .6013 .47328 .61606 .46941 .60862 .46193 Mtetra
.608 .751 .946 r
.60862 .46193 .61606 .46941 .63091 .46592 .62355 .45899 Mtetra
.572 .755 .964 r
.62355 .45899 .63091 .46592 .64588 .46297 .6386 .4568 Mtetra
.512 .755 .984 r
.6386 .4568 .64588 .46297 .66097 .46073 .65379 .45559 Mtetra
.408 .74 .993 r
.65379 .45559 .66097 .46073 .6762 .45939 .66915 .45556 Mtetra
.233 .682 .953 r
.66915 .45556 .6762 .45939 .69161 .45912 .68471 .45685 Mtetra
0 .542 .805 r
.68471 .45685 .69161 .45912 .7072 .46002 .70048 .45953 Mtetra
.266 0 0 r
.70048 .45953 .7072 .46002 .72301 .46209 .71648 .46351 Mtetra
.428 0 0 r
.71648 .46351 .72301 .46209 .73903 .46523 .73272 .46852 Mtetra
.506 0 0 r
.73272 .46852 .73903 .46523 .75527 .46912 .74918 .4741 Mtetra
.532 .008 0 r
.74918 .4741 .75527 .46912 .77171 .47333 .76582 .47959 Mtetra
.522 .017 0 r
.76582 .47959 .77171 .47333 .7883 .47723 .7826 .48421 Mtetra
.482 0 0 r
.7826 .48421 .7883 .47723 .80499 .48014 .79942 .48715 Mtetra
.403 0 0 r
.79942 .48715 .80499 .48014 .82169 .48137 .81619 .48765 Mtetra
.261 0 0 r
.81619 .48765 .82169 .48137 .83833 .48031 .83284 .48516 Mtetra
.011 0 0 r
.83284 .48516 .83833 .48031 .85484 .47657 .84929 .47941 Mtetra
.361 .801 .641 r
.84929 .47941 .85484 .47657 .87115 .47002 .8655 .47047 Mtetra
.688 .98 .836 r
.8655 .47047 .87115 .47002 .88726 .46081 .88146 .45875 Mtetra
.831 .981 .879 r
.88146 .45875 .88726 .46081 .90316 .44937 .89721 .4449 Mtetra
.865 .924 .865 r
.89721 .4449 .90316 .44937 .91889 .4363 .9128 .4297 Mtetra
.86 .871 .846 r
.9128 .4297 .91889 .4363 .93452 .42231 .92832 .41398 Mtetra
.664 .741 .908 r
.33199 .53562 .34042 .54346 .35388 .53922 .3455 .53133 Mtetra
.3455 .53133 .35388 .53922 .36742 .53496 .35908 .52703 Mtetra
.35908 .52703 .36742 .53496 .38103 .53067 .37272 .5227 Mtetra
.37272 .5227 .38103 .53067 .3947 .52637 .38644 .51836 Mtetra
.38644 .51836 .3947 .52637 .40845 .52204 .40023 .51398 Mtetra
.40023 .51398 .40845 .52204 .42226 .51768 .41409 .50959 Mtetra
.41409 .50959 .42226 .51768 .43615 .51331 .42802 .50518 Mtetra
.663 .741 .908 r
.42802 .50518 .43615 .51331 .45011 .50892 .44203 .50074 Mtetra
.44203 .50074 .45011 .50892 .46414 .5045 .45611 .49628 Mtetra
.45611 .49628 .46414 .5045 .47824 .50006 .47026 .49181 Mtetra
.47026 .49181 .47824 .50006 .49242 .49561 .48448 .48732 Mtetra
.662 .741 .909 r
.48448 .48732 .49242 .49561 .50667 .49114 .49878 .48283 Mtetra
.661 .742 .909 r
.49878 .48283 .50667 .49114 .52099 .48667 .51315 .47835 Mtetra
.66 .742 .911 r
.51315 .47835 .52099 .48667 .53539 .48222 .5276 .47391 Mtetra
.657 .742 .913 r
.5276 .47391 .53539 .48222 .54987 .47781 .54213 .46956 Mtetra
.652 .743 .917 r
.54213 .46956 .54987 .47781 .56443 .4735 .55674 .46537 Mtetra
.643 .745 .923 r
.55674 .46537 .56443 .4735 .57907 .46934 .57143 .46143 Mtetra
.63 .747 .932 r
.57143 .46143 .57907 .46934 .59379 .46544 .58622 .45789 Mtetra
.608 .75 .946 r
.58622 .45789 .59379 .46544 .60862 .46193 .60111 .45492 Mtetra
.571 .753 .964 r
.60111 .45492 .60862 .46193 .62355 .45899 .61612 .45275 Mtetra
.508 .752 .984 r
.61612 .45275 .62355 .45899 .6386 .4568 .63127 .45161 Mtetra
.396 .734 .991 r
.63127 .45161 .6386 .4568 .65379 .45559 .64658 .45175 Mtetra
.203 .664 .943 r
.64658 .45175 .65379 .45559 .66915 .45556 .66208 .45336 Mtetra
0 .499 .768 r
.66208 .45336 .66915 .45556 .68471 .45685 .6778 .45656 Mtetra
.332 0 0 r
.6778 .45656 .68471 .45685 .70048 .45953 .69376 .46131 Mtetra
.489 0 0 r
.69376 .46131 .70048 .45953 .71648 .46351 .70998 .46737 Mtetra
.56 .024 0 r
.70998 .46737 .71648 .46351 .73272 .46852 .72644 .47431 Mtetra
.583 .079 .022 r
.72644 .47431 .73272 .46852 .74918 .4741 .74312 .48143 Mtetra
.576 .093 .071 r
.74312 .48143 .74918 .4741 .76582 .47959 .75996 .48788 Mtetra
.544 .07 .081 r
.75996 .48788 .76582 .47959 .7826 .48421 .77688 .49272 Mtetra
.481 .007 .052 r
.77688 .49272 .7826 .48421 .79942 .48715 .79379 .49503 Mtetra
.369 0 0 r
.79379 .49503 .79942 .48715 .81619 .48765 .81059 .49408 Mtetra
.162 0 0 r
.81059 .49408 .81619 .48765 .83284 .48516 .82719 .48945 Mtetra
0 0 0 r
.82719 .48945 .83284 .48516 .84929 .47941 .84353 .48109 Mtetra
.614 .947 .769 r
.84353 .48109 .84929 .47941 .8655 .47047 .85959 .46934 Mtetra
.827 .993 .86 r
.85959 .46934 .8655 .47047 .88146 .45875 .87539 .45486 Mtetra
.879 .936 .852 r
.87539 .45486 .88146 .45875 .89721 .4449 .89098 .43854 Mtetra
.877 .876 .831 r
.89098 .43854 .89721 .4449 .9128 .4297 .90644 .42133 Mtetra
.86 .83 .816 r
.90644 .42133 .9128 .4297 .92832 .41398 .92188 .40411 Mtetra
.664 .741 .908 r
.32348 .52769 .33199 .53562 .3455 .53133 .33703 .52337 Mtetra
.33703 .52337 .3455 .53133 .35908 .52703 .35065 .51903 Mtetra
.35065 .51903 .35908 .52703 .37272 .5227 .36434 .51466 Mtetra
.36434 .51466 .37272 .5227 .38644 .51836 .37811 .51027 Mtetra
.37811 .51027 .38644 .51836 .40023 .51398 .39194 .50586 Mtetra
.39194 .50586 .40023 .51398 .41409 .50959 .40584 .50142 Mtetra
.663 .741 .908 r
.40584 .50142 .41409 .50959 .42802 .50518 .41982 .49697 Mtetra
.41982 .49697 .42802 .50518 .44203 .50074 .43387 .49249 Mtetra
.43387 .49249 .44203 .50074 .45611 .49628 .44799 .48799 Mtetra
.44799 .48799 .45611 .49628 .47026 .49181 .46219 .48348 Mtetra
.663 .741 .909 r
.46219 .48348 .47026 .49181 .48448 .48732 .47646 .47897 Mtetra
.662 .742 .909 r
.47646 .47897 .48448 .48732 .49878 .48283 .49081 .47446 Mtetra
.66 .742 .91 r
.49081 .47446 .49878 .48283 .51315 .47835 .50523 .46999 Mtetra
.657 .742 .913 r
.50523 .46999 .51315 .47835 .5276 .47391 .51973 .46561 Mtetra
.652 .743 .916 r
.51973 .46561 .5276 .47391 .54213 .46956 .53431 .46137 Mtetra
.644 .744 .922 r
.53431 .46137 .54213 .46956 .55674 .46537 .54897 .45738 Mtetra
.631 .747 .931 r
.54897 .45738 .55674 .46537 .57143 .46143 .56373 .45378 Mtetra
.609 .749 .944 r
.56373 .45378 .57143 .46143 .58622 .45789 .57858 .45077 Mtetra
.572 .752 .962 r
.57858 .45077 .58622 .45789 .60111 .45492 .59354 .44856 Mtetra
.508 .75 .983 r
.59354 .44856 .60111 .45492 .61612 .45275 .60864 .44744 Mtetra
.392 .729 .99 r
.60864 .44744 .61612 .45275 .63127 .45161 .62389 .44767 Mtetra
.186 .652 .937 r
.62389 .44767 .63127 .45161 .64658 .45175 .63933 .44951 Mtetra
0 .468 .744 r
.63933 .44951 .64658 .45175 .66208 .45336 .65498 .45312 Mtetra
.379 0 0 r
.65498 .45312 .66208 .45336 .6778 .45656 .67089 .45853 Mtetra
.532 0 0 r
.67089 .45853 .6778 .45656 .69376 .46131 .68705 .46556 Mtetra
.599 .077 0 r
.68705 .46556 .69376 .46131 .70998 .46737 .70349 .47378 Mtetra
.621 .133 .073 r
.70349 .47378 .70998 .46737 .72644 .47431 .72017 .48252 Mtetra
.616 .149 .123 r
.72017 .48252 .72644 .47431 .74312 .48143 .73705 .49085 Mtetra
.59 .134 .139 r
.73705 .49085 .74312 .48143 .75996 .48788 .75406 .49773 Mtetra
.54 .085 .121 r
.75406 .49773 .75996 .48788 .77688 .49272 .77109 .50207 Mtetra
.45 0 .058 r
.77109 .50207 .77688 .49272 .79379 .49503 .78804 .50296 Mtetra
.282 0 0 r
.78804 .50296 .79379 .49503 .81059 .49408 .8048 .49979 Mtetra
0 0 0 r
.8048 .49979 .81059 .49408 .82719 .48945 .8213 .49233 Mtetra
.515 .887 .686 r
.8213 .49233 .82719 .48945 .84353 .48109 .83748 .48085 Mtetra
.814 .999 .839 r
.83748 .48085 .84353 .48109 .85959 .46934 .85337 .46599 Mtetra
.89 .945 .84 r
.85337 .46599 .85959 .46934 .87539 .45486 .86899 .44869 Mtetra
.891 .878 .816 r
.86899 .44869 .87539 .45486 .89098 .43854 .88444 .43004 Mtetra
.874 .828 .8 r
.88444 .43004 .89098 .43854 .90644 .42133 .89981 .41109 Mtetra
.853 .793 .793 r
.89981 .41109 .90644 .42133 .92188 .40411 .9152 .39272 Mtetra
.664 .741 .908 r
.31489 .5197 .32348 .52769 .33703 .52337 .32848 .51533 Mtetra
.32848 .51533 .33703 .52337 .35065 .51903 .34215 .51095 Mtetra
.34215 .51095 .35065 .51903 .36434 .51466 .35588 .50654 Mtetra
.35588 .50654 .36434 .51466 .37811 .51027 .36969 .5021 Mtetra
.36969 .5021 .37811 .51027 .39194 .50586 .38357 .49765 Mtetra
.38357 .49765 .39194 .50586 .40584 .50142 .39752 .49317 Mtetra
.663 .741 .908 r
.39752 .49317 .40584 .50142 .41982 .49697 .41154 .48868 Mtetra
.41154 .48868 .41982 .49697 .43387 .49249 .42563 .48416 Mtetra
.42563 .48416 .43387 .49249 .44799 .48799 .4398 .47963 Mtetra
.663 .741 .909 r
.4398 .47963 .44799 .48799 .46219 .48348 .45405 .47509 Mtetra
.662 .741 .909 r
.45405 .47509 .46219 .48348 .47646 .47897 .46837 .47055 Mtetra
.66 .742 .91 r
.46837 .47055 .47646 .47897 .49081 .47446 .48276 .46605 Mtetra
.658 .742 .912 r
.48276 .46605 .49081 .47446 .50523 .46999 .49723 .46163 Mtetra
.653 .743 .916 r
.49723 .46163 .50523 .46999 .51973 .46561 .51178 .45734 Mtetra
.645 .744 .921 r
.51178 .45734 .51973 .46561 .53431 .46137 .52641 .45329 Mtetra
.633 .746 .93 r
.52641 .45329 .53431 .46137 .54897 .45738 .54113 .44963 Mtetra
.612 .748 .942 r
.54113 .44963 .54897 .45738 .56373 .45378 .55594 .44654 Mtetra
.575 .751 .96 r
.55594 .44654 .56373 .45378 .57858 .45077 .57086 .44426 Mtetra
.512 .748 .981 r
.57086 .44426 .57858 .45077 .59354 .44856 .5859 .44309 Mtetra
.395 .727 .99 r
.5859 .44309 .59354 .44856 .60864 .44744 .60109 .44334 Mtetra
.183 .646 .937 r
.60109 .44334 .60864 .44744 .62389 .44767 .61646 .4453 Mtetra
0 .451 .736 r
.61646 .4453 .62389 .44767 .63933 .44951 .63204 .44919 Mtetra
.408 0 0 r
.63204 .44919 .63933 .44951 .65498 .45312 .64786 .45512 Mtetra
.562 .002 0 r
.64786 .45512 .65498 .45312 .67089 .45853 .66396 .46297 Mtetra
.628 .116 .01 r
.66396 .46297 .67089 .45853 .68705 .46556 .68034 .47236 Mtetra
.649 .172 .107 r
.68034 .47236 .68705 .46556 .70349 .47378 .69699 .48262 Mtetra
.646 .192 .159 r
.69699 .48262 .70349 .47378 .72017 .48252 .71388 .49282 Mtetra
.625 .183 .179 r
.71388 .49282 .72017 .48252 .73705 .49085 .73094 .5018 Mtetra
.585 .144 .169 r
.73094 .5018 .73705 .49085 .75406 .49773 .74807 .50835 Mtetra
.512 .063 .122 r
.74807 .50835 .75406 .49773 .77109 .50207 .76515 .51134 Mtetra
.375 0 .011 r
.76515 .51134 .77109 .50207 .78804 .50296 .78208 .50994 Mtetra
.098 0 0 r
.78208 .50994 .78804 .50296 .8048 .49979 .79874 .50376 Mtetra
.395 .804 .593 r
.79874 .50376 .8048 .49979 .8213 .49233 .81509 .4929 Mtetra
.79 .999 .818 r
.81509 .4929 .8213 .49233 .83748 .48085 .8311 .47796 Mtetra
.897 .951 .831 r
.8311 .47796 .83748 .48085 .85337 .46599 .8468 .45992 Mtetra
.901 .878 .803 r
.8468 .45992 .85337 .46599 .86899 .44869 .86226 .43997 Mtetra
.883 .823 .784 r
.86226 .43997 .86899 .44869 .88444 .43004 .87759 .41931 Mtetra
.862 .787 .775 r
.87759 .41931 .88444 .43004 .89981 .41109 .8929 .39901 Mtetra
.841 .762 .775 r
.8929 .39901 .89981 .41109 .9152 .39272 .90829 .37992 Mtetra
.664 .741 .908 r
.30622 .51162 .31489 .5197 .32848 .51533 .31985 .50722 Mtetra
.31985 .50722 .32848 .51533 .34215 .51095 .33356 .50279 Mtetra
.33356 .50279 .34215 .51095 .35588 .50654 .34734 .49834 Mtetra
.34734 .49834 .35588 .50654 .36969 .5021 .36119 .49386 Mtetra
.36119 .49386 .36969 .5021 .38357 .49765 .37511 .48937 Mtetra
.663 .741 .908 r
.37511 .48937 .38357 .49765 .39752 .49317 .38911 .48485 Mtetra
.38911 .48485 .39752 .49317 .41154 .48868 .40318 .48031 Mtetra
.40318 .48031 .41154 .48868 .42563 .48416 .41732 .47576 Mtetra
.41732 .47576 .42563 .48416 .4398 .47963 .43154 .47119 Mtetra
.662 .741 .909 r
.43154 .47119 .4398 .47963 .45405 .47509 .44583 .46663 Mtetra
.661 .742 .91 r
.44583 .46663 .45405 .47509 .46837 .47055 .46019 .4621 Mtetra
.658 .742 .912 r
.46019 .4621 .46837 .47055 .48276 .46605 .47464 .45763 Mtetra
.654 .743 .915 r
.47464 .45763 .48276 .46605 .49723 .46163 .48916 .45329 Mtetra
.647 .744 .92 r
.48916 .45329 .49723 .46163 .51178 .45734 .50375 .44918 Mtetra
.635 .745 .928 r
.50375 .44918 .51178 .45734 .52641 .45329 .51844 .44543 Mtetra
.615 .747 .94 r
.51844 .44543 .52641 .45329 .54113 .44963 .53321 .44223 Mtetra
.58 .749 .958 r
.53321 .44223 .54113 .44963 .55594 .44654 .54808 .43985 Mtetra
.519 .747 .978 r
.54808 .43985 .55594 .44654 .57086 .44426 .56306 .43858 Mtetra
.405 .727 .99 r
.56306 .43858 .57086 .44426 .5859 .44309 .57819 .43876 Mtetra
.194 .648 .943 r
.57819 .43876 .5859 .44309 .60109 .44334 .59348 .44072 Mtetra
0 .45 .744 r
.59348 .44072 .60109 .44334 .61646 .4453 .60897 .44477 Mtetra
.42 0 0 r
.60897 .44477 .61646 .4453 .63204 .44919 .6247 .45105 Mtetra
.581 .025 0 r
.6247 .45105 .63204 .44919 .64786 .45512 .64071 .45953 Mtetra
.649 .142 .029 r
.64071 .45953 .64786 .45512 .66396 .46297 .657 .4699 Mtetra
.672 .202 .129 r
.657 .4699 .66396 .46297 .68034 .47236 .67359 .48155 Mtetra
.671 .225 .183 r
.67359 .48155 .68034 .47236 .69699 .48262 .69045 .49351 Mtetra
.654 .221 .207 r
.69045 .49351 .69699 .48262 .71388 .49282 .70752 .50459 Mtetra
.621 .19 .203 r
.70752 .50459 .71388 .49282 .73094 .5018 .72471 .51343 Mtetra
.561 .124 .167 r
.72471 .51343 .73094 .5018 .74807 .50835 .74191 .51873 Mtetra
.45 0 .078 r
.74191 .51873 .74807 .50835 .76515 .51134 .75899 .51941 Mtetra
.217 0 0 r
.75899 .51941 .76515 .51134 .78208 .50994 .77583 .51487 Mtetra
0 0 0 r
.77583 .51487 .78208 .50994 .79874 .50376 .79235 .50502 Mtetra
.756 .993 .8 r
.79235 .50502 .79874 .50376 .81509 .4929 .80851 .49037 Mtetra
.899 .956 .826 r
.80851 .49037 .81509 .4929 .8311 .47796 .82433 .47189 Mtetra
.907 .874 .793 r
.82433 .47189 .8311 .47796 .8468 .45992 .83986 .45084 Mtetra
.889 .816 .769 r
.83986 .45084 .8468 .45992 .86226 .43997 .8552 .4286 Mtetra
.869 .777 .758 r
.8552 .4286 .86226 .43997 .87759 .41931 .87046 .40641 Mtetra
.848 .753 .757 r
.87046 .40641 .87759 .41931 .8929 .39901 .88576 .38529 Mtetra
.829 .737 .764 r
.88576 .38529 .8929 .39901 .90829 .37992 .90121 .36595 Mtetra
.664 .741 .908 r
.29746 .50347 .30622 .51162 .31985 .50722 .31114 .49902 Mtetra
.31114 .49902 .31985 .50722 .33356 .50279 .32489 .49455 Mtetra
.32489 .49455 .33356 .50279 .34734 .49834 .33872 .49006 Mtetra
.33872 .49006 .34734 .49834 .36119 .49386 .35261 .48554 Mtetra
.663 .741 .908 r
.35261 .48554 .36119 .49386 .37511 .48937 .36658 .481 Mtetra
.36658 .481 .37511 .48937 .38911 .48485 .38062 .47644 Mtetra
.38062 .47644 .38911 .48485 .40318 .48031 .39473 .47187 Mtetra
.39473 .47187 .40318 .48031 .41732 .47576 .40892 .46728 Mtetra
.662 .741 .909 r
.40892 .46728 .41732 .47576 .43154 .47119 .42318 .46269 Mtetra
.661 .742 .91 r
.42318 .46269 .43154 .47119 .44583 .46663 .43752 .45812 Mtetra
.659 .742 .911 r
.43752 .45812 .44583 .46663 .46019 .4621 .45194 .45361 Mtetra
.655 .742 .914 r
.45194 .45361 .46019 .4621 .47464 .45763 .46643 .44922 Mtetra
.648 .743 .919 r
.46643 .44922 .47464 .45763 .48916 .45329 .48099 .44503 Mtetra
.637 .745 .926 r
.48099 .44503 .48916 .45329 .50375 .44918 .49564 .44119 Mtetra
.618 .747 .938 r
.49564 .44119 .50375 .44918 .51844 .44543 .51037 .43787 Mtetra
.586 .748 .954 r
.51037 .43787 .51844 .44543 .53321 .44223 .5252 .43535 Mtetra
.529 .746 .975 r
.5252 .43535 .53321 .44223 .54808 .43985 .54013 .43392 Mtetra
.421 .728 .989 r
.54013 .43392 .54808 .43985 .56306 .43858 .55519 .43395 Mtetra
.218 .656 .953 r
.55519 .43395 .56306 .43858 .57819 .43876 .5704 .43581 Mtetra
0 .463 .766 r
.5704 .43581 .57819 .43876 .59348 .44072 .5858 .43985 Mtetra
.417 0 0 r
.5858 .43985 .59348 .44072 .60897 .44477 .60142 .44629 Mtetra
.591 .033 0 r
.60142 .44629 .60897 .44477 .6247 .45105 .61731 .4552 Mtetra
.663 .158 .034 r
.61731 .4552 .6247 .45105 .64071 .45953 .63349 .46633 Mtetra
.689 .222 .139 r
.63349 .46633 .64071 .45953 .657 .4699 .64998 .47914 Mtetra
.691 .249 .198 r
.64998 .47914 .657 .4699 .67359 .48155 .66677 .4927 Mtetra
.678 .25 .225 r
.66677 .4927 .67359 .48155 .69045 .49351 .68381 .50578 Mtetra
.65 .227 .226 r
.68381 .50578 .69045 .49351 .70752 .50459 .70103 .51692 Mtetra
.601 .172 .199 r
.70103 .51692 .70752 .50459 .72471 .51343 .7183 .52464 Mtetra
.51 .064 .126 r
.7183 .52464 .72471 .51343 .74191 .51873 .73551 .52765 Mtetra
.317 0 0 r
.73551 .52765 .74191 .51873 .75899 .51941 .75252 .52508 Mtetra
0 0 0 r
.75252 .52508 .75899 .51941 .77583 .51487 .76922 .51665 Mtetra
.711 .981 .787 r
.76922 .51665 .77583 .51487 .79235 .50502 .78556 .50271 Mtetra
.898 .958 .826 r
.78556 .50271 .79235 .50502 .80851 .49037 .80153 .48416 Mtetra
.909 .869 .787 r
.80153 .48416 .80851 .49037 .82433 .47189 .81717 .46232 Mtetra
.892 .807 .758 r
.81717 .46232 .82433 .47189 .83986 .45084 .83256 .43869 Mtetra
.872 .767 .744 r
.83256 .43869 .83986 .45084 .8552 .4286 .84782 .41471 Mtetra
.852 .742 .74 r
.84782 .41471 .8552 .4286 .87046 .40641 .86307 .39159 Mtetra
.834 .726 .746 r
.86307 .39159 .87046 .40641 .88576 .38529 .87843 .37022 Mtetra
.816 .718 .757 r
.87843 .37022 .88576 .38529 .90121 .36595 .89397 .35111 Mtetra
.664 .741 .908 r
.28862 .49524 .29746 .50347 .31114 .49902 .30235 .49075 Mtetra
.30235 .49075 .31114 .49902 .32489 .49455 .31614 .48624 Mtetra
.31614 .48624 .32489 .49455 .33872 .49006 .33001 .4817 Mtetra
.663 .741 .908 r
.33001 .4817 .33872 .49006 .35261 .48554 .34395 .47714 Mtetra
.34395 .47714 .35261 .48554 .36658 .481 .35796 .47256 Mtetra
.35796 .47256 .36658 .481 .38062 .47644 .37204 .46796 Mtetra
.37204 .46796 .38062 .47644 .39473 .47187 .38621 .46335 Mtetra
.662 .741 .909 r
.38621 .46335 .39473 .47187 .40892 .46728 .40044 .45873 Mtetra
.661 .742 .909 r
.40044 .45873 .40892 .46728 .42318 .46269 .41475 .45413 Mtetra
.659 .742 .911 r
.41475 .45413 .42318 .46269 .43752 .45812 .42913 .44958 Mtetra
.656 .742 .913 r
.42913 .44958 .43752 .45812 .45194 .45361 .44359 .44513 Mtetra
.65 .743 .917 r
.44359 .44513 .45194 .45361 .46643 .44922 .45813 .44086 Mtetra
.64 .744 .924 r
.45813 .44086 .46643 .44922 .48099 .44503 .47274 .43692 Mtetra
.623 .746 .935 r
.47274 .43692 .48099 .44503 .49564 .44119 .48744 .43347 Mtetra
.593 .747 .951 r
.48744 .43347 .49564 .44119 .51037 .43787 .50222 .43077 Mtetra
.54 .746 .971 r
.50222 .43077 .51037 .43787 .5252 .43535 .51709 .42914 Mtetra
.441 .731 .988 r
.51709 .42914 .5252 .43535 .54013 .43392 .53209 .42894 Mtetra
.252 .669 .964 r
.53209 .42894 .54013 .43392 .55519 .43395 .54722 .43059 Mtetra
0 .49 .801 r
.54722 .43059 .55519 .43395 .5704 .43581 .56252 .43448 Mtetra
.396 0 0 r
.56252 .43448 .5704 .43581 .5858 .43985 .57803 .4409 Mtetra
.59 .028 0 r
.57803 .4409 .5858 .43985 .60142 .44629 .59378 .44999 Mtetra
.672 .165 .028 r
.59378 .44999 .60142 .44629 .61731 .4552 .60983 .46162 Mtetra
.702 .235 .14 r
.60983 .46162 .61731 .4552 .63349 .46633 .62619 .47531 Mtetra
.707 .267 .204 r
.62619 .47531 .63349 .46633 .64998 .47914 .64287 .49021 Mtetra
.698 .273 .235 r
.64287 .49021 .64998 .47914 .66677 .4927 .65983 .50509 Mtetra
.675 .256 .241 r
.65983 .50509 .66677 .4927 .68381 .50578 .67702 .51843 Mtetra
.635 .211 .22 r
.67702 .51843 .68381 .50578 .70103 .51692 .69433 .5286 Mtetra
.56 .119 .159 r
.69433 .5286 .70103 .51692 .7183 .52464 .71163 .5341 Mtetra
.401 0 .013 r
.71163 .5341 .7183 .52464 .73551 .52765 .72878 .53381 Mtetra
.002 0 0 r
.72878 .53381 .73551 .52765 .75252 .52508 .74567 .52719 Mtetra
.654 .962 .779 r
.74567 .52719 .75252 .52508 .76922 .51665 .76221 .51438 Mtetra
.893 .959 .833 r
.76221 .51438 .76922 .51665 .78556 .50271 .77836 .49619 Mtetra
.908 .862 .783 r
.77836 .49619 .78556 .50271 .80153 .48416 .79414 .47395 Mtetra
.891 .796 .749 r
.79414 .47395 .80153 .48416 .81717 .46232 .80963 .44924 Mtetra
.871 .755 .731 r
.80963 .44924 .81717 .46232 .83256 .43869 .82494 .42366 Mtetra
.853 .729 .726 r
.82494 .42366 .83256 .43869 .84782 .41471 .84018 .39864 Mtetra
.836 .714 .729 r
.84018 .39864 .84782 .41471 .86307 .39159 .85548 .37524 Mtetra
.82 .706 .74 r
.85548 .37524 .86307 .39159 .87843 .37022 .87094 .35416 Mtetra
.803 .704 .755 r
.87094 .35416 .87843 .37022 .89397 .35111 .88663 .33571 Mtetra
.664 .741 .908 r
.2797 .48693 .28862 .49524 .30235 .49075 .29347 .4824 Mtetra
.29347 .4824 .30235 .49075 .31614 .48624 .3073 .47784 Mtetra
.3073 .47784 .31614 .48624 .33001 .4817 .32121 .47326 Mtetra
.663 .741 .908 r
.32121 .47326 .33001 .4817 .34395 .47714 .3352 .46866 Mtetra
.3352 .46866 .34395 .47714 .35796 .47256 .34926 .46404 Mtetra
.34926 .46404 .35796 .47256 .37204 .46796 .36339 .4594 Mtetra
.663 .741 .909 r
.36339 .4594 .37204 .46796 .38621 .46335 .37759 .45476 Mtetra
.662 .741 .909 r
.37759 .45476 .38621 .46335 .40044 .45873 .39187 .45012 Mtetra
.66 .742 .91 r
.39187 .45012 .40044 .45873 .41475 .45413 .40623 .44553 Mtetra
.657 .742 .913 r
.40623 .44553 .41475 .45413 .42913 .44958 .42066 .44102 Mtetra
.652 .743 .916 r
.42066 .44102 .42913 .44958 .44359 .44513 .43517 .43668 Mtetra
.642 .744 .922 r
.43517 .43668 .44359 .44513 .45813 .44086 .44975 .43262 Mtetra
.627 .745 .932 r
.44975 .43262 .45813 .44086 .47274 .43692 .4644 .42903 Mtetra
.6 .746 .947 r
.4644 .42903 .47274 .43692 .48744 .43347 .47914 .42614 Mtetra
.553 .746 .966 r
.47914 .42614 .48744 .43347 .50222 .43077 .49396 .42426 Mtetra
.465 .734 .986 r
.49396 .42426 .50222 .43077 .51709 .42914 .50889 .42378 Mtetra
.294 .683 .975 r
.50889 .42378 .51709 .42914 .53209 .42894 .52394 .42512 Mtetra
0 .526 .844 r
.52394 .42512 .53209 .42894 .54722 .43059 .53914 .4287 Mtetra
.356 0 0 r
.53914 .4287 .54722 .43059 .56252 .43448 .55453 .43491 Mtetra
.579 .009 0 r
.55453 .43491 .56252 .43448 .57803 .4409 .57015 .44394 Mtetra
.675 .161 .009 r
.57015 .44394 .57803 .4409 .59378 .44999 .58605 .45578 Mtetra
.711 .241 .132 r
.58605 .45578 .59378 .44999 .60983 .46162 .60225 .47004 Mtetra
.72 .279 .202 r
.60225 .47004 .60983 .46162 .62619 .47531 .61878 .48596 Mtetra
.714 .29 .238 r
.61878 .48596 .62619 .47531 .64287 .49021 .63562 .50236 Mtetra
.697 .278 .248 r
.63562 .50236 .64287 .49021 .65983 .50509 .65272 .51769 Mtetra
.664 .242 .233 r
.65272 .51769 .65983 .50509 .67702 .51843 .67001 .53023 Mtetra
.602 .164 .181 r
.67001 .53023 .67702 .51843 .69433 .5286 .68736 .53828 Mtetra
.471 0 .053 r
.68736 .53828 .69433 .5286 .71163 .5341 .70463 .54047 Mtetra
.125 0 0 r
.70463 .54047 .71163 .5341 .72878 .53381 .72168 .536 Mtetra
.582 .936 .778 r
.72168 .536 .72878 .53381 .74567 .52719 .73841 .52476 Mtetra
.882 .958 .847 r
.73841 .52476 .74567 .52719 .76221 .51438 .75476 .5074 Mtetra
.902 .852 .784 r
.75476 .5074 .76221 .51438 .77836 .49619 .77073 .48519 Mtetra
.886 .784 .742 r
.77073 .48519 .77836 .49619 .79414 .47395 .78636 .45978 Mtetra
.868 .742 .721 r
.78636 .45978 .79414 .47395 .80963 .44924 .80176 .4329 Mtetra
.851 .717 .713 r
.80176 .4329 .80963 .44924 .82494 .42366 .81704 .40616 Mtetra
.836 .702 .715 r
.81704 .40616 .82494 .42366 .84018 .39864 .83233 .38084 Mtetra
.821 .694 .724 r
.83233 .38084 .84018 .39864 .85548 .37524 .84774 .3578 Mtetra
.806 .692 .739 r
.84774 .3578 .85548 .37524 .87094 .35416 .86335 .33752 Mtetra
.79 .694 .758 r
.86335 .33752 .87094 .35416 .88663 .33571 .87922 .32008 Mtetra
.664 .741 .908 r
.27069 .47854 .2797 .48693 .29347 .4824 .2845 .47397 Mtetra
.2845 .47397 .29347 .4824 .3073 .47784 .29838 .46937 Mtetra
.663 .741 .908 r
.29838 .46937 .3073 .47784 .32121 .47326 .31234 .46474 Mtetra
.31234 .46474 .32121 .47326 .3352 .46866 .32636 .4601 Mtetra
.32636 .4601 .3352 .46866 .34926 .46404 .34047 .45544 Mtetra
.34047 .45544 .34926 .46404 .36339 .4594 .35464 .45076 Mtetra
.662 .741 .909 r
.35464 .45076 .36339 .4594 .37759 .45476 .3689 .4461 Mtetra
.661 .742 .91 r
.3689 .4461 .37759 .45476 .39187 .45012 .38322 .44146 Mtetra
.658 .742 .912 r
.38322 .44146 .39187 .45012 .40623 .44553 .39762 .4369 Mtetra
.653 .742 .915 r
.39762 .4369 .40623 .44553 .42066 .44102 .4121 .43248 Mtetra
.645 .743 .921 r
.4121 .43248 .42066 .44102 .43517 .43668 .42665 .42831 Mtetra
.631 .744 .929 r
.42665 .42831 .43517 .43668 .44975 .43262 .44127 .42457 Mtetra
.608 .746 .943 r
.44127 .42457 .44975 .43262 .4644 .42903 .45596 .42146 Mtetra
.566 .745 .961 r
.45596 .42146 .4644 .42903 .47914 .42614 .47074 .41931 Mtetra
.489 .737 .982 r
.47074 .41931 .47914 .42614 .49396 .42426 .48561 .41849 Mtetra
.34 .697 .982 r
.48561 .41849 .49396 .42426 .50889 .42378 .50058 .41943 Mtetra
.066 .568 .888 r
.50058 .41943 .50889 .42378 .52394 .42512 .51568 .4226 Mtetra
.295 0 0 r
.51568 .4226 .52394 .42512 .53914 .4287 .53095 .42841 Mtetra
.553 0 0 r
.53095 .42841 .53914 .4287 .55453 .43491 .54643 .43714 Mtetra
.671 .147 0 r
.54643 .43714 .55453 .43491 .57015 .44394 .56216 .44889 Mtetra
.716 .239 .115 r
.56216 .44889 .57015 .44394 .58605 .45578 .57818 .46338 Mtetra
.73 .284 .193 r
.57818 .46338 .58605 .45578 .60225 .47004 .59453 .47995 Mtetra
.728 .301 .234 r
.59453 .47995 .60225 .47004 .61878 .48596 .61121 .4975 Mtetra
.715 .295 .249 r
.61121 .4975 .61878 .48596 .63562 .50236 .62818 .51452 Mtetra
.688 .266 .239 r
.62818 .51452 .63562 .50236 .65272 .51769 .64539 .52922 Mtetra
.638 .201 .194 r
.64539 .52922 .65272 .51769 .67001 .53023 .66273 .53976 Mtetra
.531 .059 .08 r
.66273 .53976 .67001 .53023 .68736 .53828 .68007 .54454 Mtetra
.237 0 0 r
.68007 .54454 .68736 .53828 .70463 .54047 .69725 .54248 Mtetra
.494 .898 .781 r
.69725 .54248 .70463 .54047 .72168 .536 .71416 .5332 Mtetra
.864 .953 .867 r
.71416 .5332 .72168 .536 .73841 .52476 .73072 .51715 Mtetra
.892 .841 .788 r
.73072 .51715 .73841 .52476 .75476 .5074 .7469 .49547 Mtetra
.878 .77 .739 r
.7469 .49547 .75476 .5074 .77073 .48519 .76271 .46981 Mtetra
.862 .728 .714 r
.76271 .46981 .77073 .48519 .78636 .45978 .77825 .442 Mtetra
.847 .703 .703 r
.77825 .442 .78636 .45978 .80176 .4329 .79362 .41383 Mtetra
.834 .689 .703 r
.79362 .41383 .80176 .4329 .81704 .40616 .80894 .38676 Mtetra
.82 .681 .71 r
.80894 .38676 .81704 .40616 .83233 .38084 .82434 .36187 Mtetra
.807 .679 .723 r
.82434 .36187 .83233 .38084 .84774 .3578 .8399 .33977 Mtetra
.793 .682 .742 r
.8399 .33977 .84774 .3578 .86335 .33752 .8557 .32068 Mtetra
.778 .688 .764 r
.8557 .32068 .86335 .33752 .87922 .32008 .87177 .30449 Mtetra
.664 .741 .908 r
.26159 .47007 .27069 .47854 .2845 .47397 .27545 .46545 Mtetra
.663 .741 .908 r
.27545 .46545 .2845 .47397 .29838 .46937 .28937 .46081 Mtetra
.28937 .46081 .29838 .46937 .31234 .46474 .30337 .45614 Mtetra
.30337 .45614 .31234 .46474 .32636 .4601 .31744 .45145 Mtetra
.31744 .45145 .32636 .4601 .34047 .45544 .33159 .44676 Mtetra
.662 .741 .909 r
.33159 .44676 .34047 .45544 .35464 .45076 .34581 .44206 Mtetra
.661 .742 .91 r
.34581 .44206 .35464 .45076 .3689 .4461 .36011 .43738 Mtetra
.659 .742 .911 r
.36011 .43738 .3689 .4461 .38322 .44146 .37448 .43276 Mtetra
.655 .742 .914 r
.37448 .43276 .38322 .44146 .39762 .4369 .38893 .42827 Mtetra
.648 .743 .919 r
.38893 .42827 .39762 .4369 .4121 .43248 .40344 .42399 Mtetra
.636 .744 .926 r
.40344 .42399 .4121 .43248 .42665 .42831 .41803 .42009 Mtetra
.615 .745 .938 r
.41803 .42009 .42665 .42831 .44127 .42457 .43269 .41677 Mtetra
.579 .745 .956 r
.43269 .41677 .44127 .42457 .45596 .42146 .44742 .41433 Mtetra
.513 .739 .976 r
.44742 .41433 .45596 .42146 .47074 .41931 .46223 .41313 Mtetra
.386 .71 .986 r
.46223 .41313 .47074 .41931 .48561 .41849 .47713 .41361 Mtetra
.146 .61 .927 r
.47713 .41361 .48561 .41849 .50058 .41943 .49214 .41624 Mtetra
0 .371 .692 r
.49214 .41624 .50058 .41943 .51568 .4226 .5073 .42149 Mtetra
.51 0 0 r
.5073 .42149 .51568 .4226 .53095 .42841 .52263 .42971 Mtetra
.658 .12 0 r
.52263 .42971 .53095 .42841 .54643 .43714 .53819 .44107 Mtetra
.716 .229 .086 r
.53819 .44107 .54643 .43714 .56216 .44889 .55402 .45543 Mtetra
.737 .284 .176 r
.55402 .45543 .56216 .44889 .57818 .46338 .57017 .47225 Mtetra
.739 .307 .224 r
.57017 .47225 .57818 .46338 .59453 .47995 .58664 .49054 Mtetra
.73 .307 .244 r
.58664 .49054 .59453 .47995 .61121 .4975 .60345 .50885 Mtetra
.709 .285 .238 r
.60345 .50885 .61121 .4975 .62818 .51452 .62053 .5254 Mtetra
.669 .23 .199 r
.62053 .5254 .62818 .51452 .64539 .52922 .6378 .53824 Mtetra
.581 .108 .095 r
.6378 .53824 .64539 .52922 .66273 .53976 .65514 .5456 Mtetra
.336 0 0 r
.65514 .5456 .66273 .53976 .68007 .54454 .67241 .54611 Mtetra
.389 .846 .786 r
.67241 .54611 .68007 .54454 .69725 .54248 .68948 .53912 Mtetra
.838 .944 .892 r
.68948 .53912 .69725 .54248 .71416 .5332 .70624 .52481 Mtetra
.877 .827 .794 r
.70624 .52481 .71416 .5332 .73072 .51715 .72263 .50417 Mtetra
.867 .756 .737 r
.72263 .50417 .73072 .51715 .7469 .49547 .73865 .47876 Mtetra
.854 .715 .708 r
.73865 .47876 .7469 .49547 .76271 .46981 .75437 .45048 Mtetra
.841 .69 .696 r
.75437 .45048 .76271 .46981 .77825 .442 .76987 .42125 Mtetra
.829 .676 .693 r
.76987 .42125 .77825 .442 .79362 .41383 .78528 .39271 Mtetra
.818 .669 .698 r
.78528 .39271 .79362 .41383 .80894 .38676 .8007 .36614 Mtetra
.806 .667 .71 r
.8007 .36614 .80894 .38676 .82434 .36187 .81626 .34231 Mtetra
.794 .67 .727 r
.81626 .34231 .82434 .36187 .8399 .33977 .83201 .32159 Mtetra
.781 .677 .749 r
.83201 .32159 .8399 .33977 .8557 .32068 .84802 .30397 Mtetra
.766 .685 .774 r
.84802 .30397 .8557 .32068 .87177 .30449 .86431 .28918 Mtetra
.663 .741 .908 r
.25241 .46152 .26159 .47007 .27545 .46545 .2663 .45685 Mtetra
.2663 .45685 .27545 .46545 .28937 .46081 .28027 .45217 Mtetra
.28027 .45217 .28937 .46081 .30337 .45614 .29432 .44746 Mtetra
.29432 .44746 .30337 .45614 .31744 .45145 .30843 .44273 Mtetra
.662 .741 .909 r
.30843 .44273 .31744 .45145 .33159 .44676 .32263 .438 Mtetra
.661 .741 .909 r
.32263 .438 .33159 .44676 .34581 .44206 .33689 .43329 Mtetra
.66 .742 .911 r
.33689 .43329 .34581 .44206 .36011 .43738 .35123 .42862 Mtetra
.656 .742 .913 r
.35123 .42862 .36011 .43738 .37448 .43276 .36565 .42405 Mtetra
.65 .743 .917 r
.36565 .42405 .37448 .43276 .38893 .42827 .38013 .41967 Mtetra
.64 .743 .924 r
.38013 .41967 .38893 .42827 .40344 .42399 .39469 .41561 Mtetra
.622 .744 .934 r
.39469 .41561 .40344 .42399 .41803 .42009 .40931 .41208 Mtetra
.591 .745 .95 r
.40931 .41208 .41803 .42009 .43269 .41677 .424 .40933 Mtetra
.536 .741 .97 r
.424 .40933 .43269 .41677 .44742 .41433 .43876 .40773 Mtetra
.431 .721 .986 r
.43876 .40773 .44742 .41433 .46223 .41313 .4536 .4077 Mtetra
.228 .647 .957 r
.4536 .4077 .46223 .41313 .47713 .41361 .46853 .40971 Mtetra
0 .449 .781 r
.46853 .40971 .47713 .41361 .49214 .41624 .48358 .41427 Mtetra
.443 0 0 r
.48358 .41427 .49214 .41624 .5073 .42149 .49877 .42177 Mtetra
.632 .077 0 r
.49877 .42177 .5073 .42149 .52263 .42971 .51417 .43248 Mtetra
.71 .209 .043 r
.51417 .43248 .52263 .42971 .53819 .44107 .5298 .44636 Mtetra
.74 .276 .149 r
.5298 .44636 .53819 .44107 .55402 .45543 .54573 .46303 Mtetra
.748 .308 .207 r
.54573 .46303 .55402 .45543 .57017 .47225 .56198 .4816 Mtetra
.743 .314 .232 r
.56198 .4816 .57017 .47225 .58664 .49054 .57857 .50075 Mtetra
.727 .299 .231 r
.57857 .50075 .58664 .49054 .60345 .50885 .59547 .51873 Mtetra
.695 .252 .196 r
.59547 .51873 .60345 .50885 .62053 .5254 .61261 .53358 Mtetra
.624 .147 .101 r
.61261 .53358 .62053 .5254 .6378 .53824 .6299 .54336 Mtetra
.42 0 0 r
.6299 .54336 .6378 .53824 .65514 .5456 .64721 .54648 Mtetra
.27 .776 .788 r
.64721 .54648 .65514 .5456 .67241 .54611 .66439 .542 Mtetra
.8 .927 .919 r
.66439 .542 .67241 .54611 .68948 .53912 .68132 .52982 Mtetra
.857 .811 .803 r
.68132 .52982 .68948 .53912 .70624 .52481 .69792 .51069 Mtetra
.853 .741 .738 r
.69792 .51069 .70624 .52481 .72263 .50417 .71417 .48607 Mtetra
.843 .701 .705 r
.71417 .48607 .72263 .50417 .73865 .47876 .7301 .45783 Mtetra
.833 .677 .69 r
.7301 .45783 .73865 .47876 .75437 .45048 .74577 .42798 Mtetra
.823 .664 .685 r
.74577 .42798 .75437 .45048 .76987 .42125 .7613 .39833 Mtetra
.814 .657 .689 r
.7613 .39833 .76987 .42125 .78528 .39271 .77681 .37033 Mtetra
.804 .656 .698 r
.77681 .37033 .78528 .39271 .8007 .36614 .79239 .34495 Mtetra
.794 .659 .714 r
.79239 .34495 .8007 .36614 .81626 .34231 .80814 .32269 Mtetra
.782 .665 .735 r
.80814 .32269 .81626 .34231 .83201 .32159 .82411 .30366 Mtetra
.769 .675 .759 r
.82411 .30366 .83201 .32159 .84802 .30397 .84035 .28765 Mtetra
.754 .686 .786 r
.84035 .28765 .84802 .30397 .86431 .28918 .85685 .27428 Mtetra
.663 .741 .908 r
.24313 .45288 .25241 .46152 .2663 .45685 .25707 .44817 Mtetra
.25707 .44817 .2663 .45685 .28027 .45217 .27108 .44344 Mtetra
.27108 .44344 .28027 .45217 .29432 .44746 .28517 .43869 Mtetra
.28517 .43869 .29432 .44746 .30843 .44273 .29933 .43393 Mtetra
.662 .741 .909 r
.29933 .43393 .30843 .44273 .32263 .438 .31357 .42918 Mtetra
.66 .742 .91 r
.31357 .42918 .32263 .438 .33689 .43329 .32788 .42446 Mtetra
.657 .742 .912 r
.32788 .42446 .33689 .43329 .35123 .42862 .34227 .41982 Mtetra
.652 .742 .916 r
.34227 .41982 .35123 .42862 .36565 .42405 .35672 .41534 Mtetra
.644 .743 .921 r
.35672 .41534 .36565 .42405 .38013 .41967 .37124 .41114 Mtetra
.629 .744 .93 r
.37124 .41114 .38013 .41967 .39469 .41561 .38583 .40739 Mtetra
.603 .744 .944 r
.38583 .40739 .39469 .41561 .40931 .41208 .40049 .40434 Mtetra
.556 .742 .963 r
.40049 .40434 .40931 .41208 .424 .40933 .4152 .40233 Mtetra
.471 .729 .982 r
.4152 .40233 .424 .40933 .43876 .40773 .42998 .40175 Mtetra
.306 .678 .976 r
.42998 .40175 .43876 .40773 .4536 .4077 .44484 .4031 Mtetra
.012 .527 .862 r
.44484 .4031 .4536 .4077 .46853 .40971 .45979 .40685 Mtetra
.347 0 0 r
.45979 .40685 .46853 .40971 .48358 .41427 .47486 .41348 Mtetra
.588 .015 0 r
.47486 .41348 .48358 .41427 .49877 .42177 .49009 .4233 Mtetra
.695 .175 0 r
.49009 .4233 .49877 .42177 .51417 .43248 .50554 .4364 Mtetra
.738 .26 .111 r
.50554 .4364 .51417 .43248 .5298 .44636 .52125 .4525 Mtetra
.753 .302 .181 r
.52125 .4525 .5298 .44636 .54573 .46303 .53726 .4709 Mtetra
.753 .316 .213 r
.53726 .4709 .54573 .46303 .56198 .4816 .5536 .4904 Mtetra
.742 .307 .217 r
.5536 .4904 .56198 .4816 .57857 .50075 .57028 .50934 Mtetra
.716 .269 .187 r
.57028 .50934 .57857 .50075 .59547 .51873 .58725 .52578 Mtetra
.659 .177 .097 r
.58725 .52578 .59547 .51873 .61261 .53358 .60443 .5377 Mtetra
.489 0 0 r
.60443 .5377 .61261 .53358 .6299 .54336 .6217 .54333 Mtetra
.145 .69 .784 r
.6217 .54333 .6299 .54336 .64721 .54648 .63894 .54146 Mtetra
.75 .9 .945 r
.63894 .54146 .64721 .54648 .66439 .542 .656 .53169 Mtetra
.832 .792 .813 r
.656 .53169 .66439 .542 .68132 .52982 .6728 .51451 Mtetra
.836 .724 .741 r
.6728 .51451 .68132 .52982 .69792 .51069 .68927 .49119 Mtetra
.831 .687 .704 r
.68927 .49119 .69792 .51069 .71417 .48607 .70542 .46353 Mtetra
.823 .665 .686 r
.70542 .46353 .71417 .48607 .7301 .45783 .7213 .43357 Mtetra
.816 .652 .679 r
.7213 .43357 .7301 .45783 .74577 .42798 .737 .40323 Mtetra
.808 .646 .681 r
.737 .40323 .74577 .42798 .7613 .39833 .75262 .37414 Mtetra
.8 .644 .689 r
.75262 .37414 .7613 .39833 .77681 .37033 .76828 .34745 Mtetra
.791 .647 .703 r
.76828 .34745 .77681 .37033 .79239 .34495 .78405 .3238 Mtetra
.782 .654 .722 r
.78405 .3238 .79239 .34495 .80814 .32269 .80002 .30345 Mtetra
.77 .664 .746 r
.80002 .30345 .80814 .32269 .82411 .30366 .81622 .28626 Mtetra
.757 .676 .773 r
.81622 .28626 .82411 .30366 .84035 .28765 .83268 .27189 Mtetra
.742 .689 .801 r
.83268 .27189 .84035 .28765 .85685 .27428 .84939 .25988 Mtetra
.663 .741 .908 r
.23376 .44416 .24313 .45288 .25707 .44817 .24774 .43941 Mtetra
.24774 .43941 .25707 .44817 .27108 .44344 .2618 .43463 Mtetra
.2618 .43463 .27108 .44344 .28517 .43869 .27593 .42984 Mtetra
.662 .741 .909 r
.27593 .42984 .28517 .43869 .29933 .43393 .29014 .42506 Mtetra
.661 .741 .91 r
.29014 .42506 .29933 .43393 .31357 .42918 .30442 .42029 Mtetra
.659 .742 .911 r
.30442 .42029 .31357 .42918 .32788 .42446 .31878 .41559 Mtetra
.654 .742 .914 r
.31878 .41559 .32788 .42446 .34227 .41982 .3332 .41102 Mtetra
.647 .743 .919 r
.3332 .41102 .34227 .41982 .35672 .41534 .34769 .40668 Mtetra
.634 .743 .927 r
.34769 .40668 .35672 .41534 .37124 .41114 .36225 .40272 Mtetra
.613 .744 .939 r
.36225 .40272 .37124 .41114 .38583 .40739 .37687 .39938 Mtetra
.575 .743 .956 r
.37687 .39938 .38583 .40739 .40049 .40434 .39154 .39695 Mtetra
.506 .734 .976 r
.39154 .39695 .40049 .40434 .4152 .40233 .40627 .39583 Mtetra
.376 .701 .984 r
.40627 .39583 .4152 .40233 .42998 .40175 .42107 .39646 Mtetra
.132 .594 .923 r
.42107 .39646 .42998 .40175 .44484 .4031 .43593 .39935 Mtetra
0 .356 .694 r
.43593 .39935 .44484 .4031 .45979 .40685 .45089 .40498 Mtetra
.517 0 0 r
.45089 .40498 .45979 .40685 .47486 .41348 .46599 .41372 Mtetra
.667 .125 0 r
.46599 .41372 .47486 .41348 .49009 .4233 .48125 .42576 Mtetra
.729 .233 .057 r
.48125 .42576 .49009 .4233 .50554 .4364 .49674 .44095 Mtetra
.753 .288 .144 r
.49674 .44095 .50554 .4364 .52125 .4525 .51251 .45874 Mtetra
.759 .311 .186 r
.51251 .45874 .52125 .4525 .53726 .4709 .5286 .47808 Mtetra
.753 .309 .196 r
.5286 .47808 .53726 .4709 .5536 .4904 .54503 .49747 Mtetra
.734 .278 .169 r
.54503 .49747 .5536 .4904 .57028 .50934 .56178 .51501 Mtetra
.686 .198 .083 r
.56178 .51501 .57028 .50934 .58725 .52578 .57879 .52869 Mtetra
.544 0 0 r
.57879 .52869 .58725 .52578 .60443 .5377 .59597 .53659 Mtetra
.026 .595 .772 r
.59597 .53659 .60443 .5377 .6217 .54333 .6132 .53729 Mtetra
.687 .861 .965 r
.6132 .53729 .6217 .54333 .63894 .54146 .63035 .5301 Mtetra
.801 .769 .824 r
.63035 .5301 .63894 .54146 .656 .53169 .64731 .51521 Mtetra
.816 .708 .745 r
.64731 .51521 .656 .53169 .6728 .51451 .66399 .49365 Mtetra
.816 .673 .705 r
.66399 .49365 .6728 .51451 .68927 .49119 .68037 .4671 Mtetra
.812 .652 .684 r
.68037 .4671 .68927 .49119 .70542 .46353 .69647 .43756 Mtetra
.807 .64 .675 r
.69647 .43756 .70542 .46353 .7213 .43357 .71236 .40703 Mtetra
.801 .635 .675 r
.71236 .40703 .7213 .43357 .737 .40323 .72814 .37725 Mtetra
.795 .634 .681 r
.72814 .37725 .737 .40323 .75262 .37414 .7439 .34955 Mtetra
.788 .637 .693 r
.7439 .34955 .75262 .37414 .76828 .34745 .75974 .32474 Mtetra
.78 .644 .711 r
.75974 .32474 .76828 .34745 .78405 .3238 .77573 .3032 Mtetra
.77 .654 .734 r
.77573 .3032 .78405 .3238 .80002 .30345 .79192 .2849 Mtetra
.759 .666 .76 r
.79192 .2849 .80002 .30345 .81622 .28626 .80835 .26957 Mtetra
.745 .681 .788 r
.80835 .26957 .81622 .28626 .83268 .27189 .82503 .25677 Mtetra
.73 .695 .816 r
.82503 .25677 .83268 .27189 .84939 .25988 .84194 .246 Mtetra
.663 .741 .908 r
.2243 .43536 .23376 .44416 .24774 .43941 .23833 .43056 Mtetra
.23833 .43056 .24774 .43941 .2618 .43463 .25243 .42574 Mtetra
.662 .741 .909 r
.25243 .42574 .2618 .43463 .27593 .42984 .2666 .42092 Mtetra
.661 .741 .909 r
.2666 .42092 .27593 .42984 .29014 .42506 .28085 .41611 Mtetra
.66 .742 .911 r
.28085 .41611 .29014 .42506 .30442 .42029 .29518 .41135 Mtetra
.656 .742 .913 r
.29518 .41135 .30442 .42029 .31878 .41559 .30957 .40669 Mtetra
.65 .742 .917 r
.30957 .40669 .31878 .41559 .3332 .41102 .32404 .40222 Mtetra
.64 .743 .923 r
.32404 .40222 .3332 .41102 .34769 .40668 .33856 .39808 Mtetra
.622 .743 .934 r
.33856 .39808 .34769 .40668 .36225 .40272 .35315 .39446 Mtetra
.591 .743 .949 r
.35315 .39446 .36225 .40272 .37687 .39938 .36779 .39164 Mtetra
.536 .738 .968 r
.36779 .39164 .37687 .39938 .39154 .39695 .38248 .38997 Mtetra
.435 .717 .984 r
.38248 .38997 .39154 .39695 .40627 .39583 .39722 .38989 Mtetra
.243 .647 .961 r
.39722 .38989 .40627 .39583 .42107 .39646 .41201 .39187 Mtetra
0 .465 .811 r
.41201 .39187 .42107 .39646 .43593 .39935 .42688 .39642 Mtetra
.411 0 0 r
.42688 .39642 .43593 .39935 .45089 .40498 .44184 .40394 Mtetra
.617 .051 0 r
.44184 .40394 .45089 .40498 .46599 .41372 .45695 .4147 Mtetra
.709 .191 0 r
.45695 .4147 .46599 .41372 .48125 .42576 .47224 .42868 Mtetra
.747 .264 .093 r
.47224 .42868 .48125 .42576 .49674 .44095 .48778 .44545 Mtetra
.761 .298 .149 r
.48778 .44545 .49674 .44095 .51251 .45874 .50361 .46416 Mtetra
.76 .304 .165 r
.50361 .46416 .51251 .45874 .5286 .47808 .51977 .48346 Mtetra
.746 .28 .143 r
.51977 .48346 .5286 .47808 .54503 .49747 .53626 .50159 Mtetra
.707 .21 .06 r
.53626 .50159 .54503 .49747 .56178 .51501 .55306 .51654 Mtetra
.583 .02 0 r
.55306 .51654 .56178 .51501 .57879 .52869 .5701 .52637 Mtetra
0 .502 .756 r
.5701 .52637 .57879 .52869 .59597 .53659 .58726 .52947 Mtetra
.612 .81 .976 r
.58726 .52947 .59597 .53659 .6132 .53729 .60444 .52488 Mtetra
.765 .744 .834 r
.60444 .52488 .6132 .53729 .63035 .5301 .6215 .51251 Mtetra
.794 .69 .75 r
.6215 .51251 .63035 .5301 .64731 .51521 .63836 .49311 Mtetra
.8 .659 .706 r
.63836 .49311 .64731 .51521 .66399 .49365 .65495 .46816 Mtetra
.8 .64 .684 r
.65495 .46816 .66399 .49365 .68037 .4671 .67128 .43956 Mtetra
.798 .629 .673 r
.67128 .43956 .68037 .4671 .69647 .43756 .68739 .40934 Mtetra
.794 .624 .671 r
.68739 .40934 .69647 .43756 .71236 .40703 .70335 .37933 Mtetra
.789 .624 .676 r
.70335 .37933 .71236 .40703 .72814 .37725 .71925 .35099 Mtetra
.784 .627 .686 r
.71925 .35099 .72814 .37725 .7439 .34955 .73518 .32529 Mtetra
.777 .634 .702 r
.73518 .32529 .7439 .34955 .75974 .32474 .75123 .30276 Mtetra
.769 .644 .723 r
.75123 .30276 .75974 .32474 .77573 .3032 .76744 .28348 Mtetra
.759 .657 .749 r
.76744 .28348 .77573 .3032 .79192 .2849 .78386 .26726 Mtetra
.747 .672 .777 r
.78386 .26726 .79192 .2849 .80835 .26957 .80051 .2537 Mtetra
.733 .687 .806 r
.80051 .2537 .80835 .26957 .82503 .25677 .81739 .24231 Mtetra
.719 .701 .832 r
.81739 .24231 .82503 .25677 .84194 .246 .83448 .23261 Mtetra
.663 .741 .908 r
.21474 .42646 .2243 .43536 .23833 .43056 .22881 .42162 Mtetra
.22881 .42162 .23833 .43056 .25243 .42574 .24296 .41677 Mtetra
.662 .741 .909 r
.24296 .41677 .25243 .42574 .2666 .42092 .25718 .41192 Mtetra
.66 .741 .91 r
.25718 .41192 .2666 .42092 .28085 .41611 .27147 .40711 Mtetra
.658 .742 .912 r
.27147 .40711 .28085 .41611 .29518 .41135 .28584 .40237 Mtetra
.653 .742 .915 r
.28584 .40237 .29518 .41135 .30957 .40669 .30027 .39778 Mtetra
.644 .742 .921 r
.30027 .39778 .30957 .40669 .32404 .40222 .31477 .39346 Mtetra
.63 .743 .929 r
.31477 .39346 .32404 .40222 .33856 .39808 .32933 .38959 Mtetra
.605 .743 .942 r
.32933 .38959 .33856 .39808 .35315 .39446 .34393 .38639 Mtetra
.562 .74 .96 r
.34393 .38639 .35315 .39446 .36779 .39164 .35859 .3842 Mtetra
.483 .727 .979 r
.35859 .3842 .36779 .39164 .38248 .38997 .37328 .38341 Mtetra
.337 .684 .979 r
.37328 .38341 .38248 .38997 .39722 .38989 .38802 .38449 Mtetra
.078 .559 .899 r
.38802 .38449 .39722 .38989 .41201 .39187 .40281 .38792 Mtetra
0 .314 .66 r
.40281 .38792 .41201 .39187 .42688 .39642 .41767 .39414 Mtetra
.535 0 0 r
.41767 .39414 .42688 .39642 .44184 .40394 .43264 .40346 Mtetra
.672 .127 0 r
.43264 .40346 .44184 .40394 .45695 .4147 .44775 .41597 Mtetra
.732 .226 .024 r
.44775 .41597 .45695 .4147 .47224 .42868 .46307 .4314 Mtetra
.756 .275 .097 r
.46307 .4314 .47224 .42868 .48778 .44545 .47865 .44906 Mtetra
.762 .29 .124 r
.47865 .44906 .48778 .44545 .50361 .46416 .49454 .46777 Mtetra
.753 .274 .107 r
.49454 .46777 .50361 .46416 .51977 .48346 .51077 .48593 Mtetra
.719 .212 .026 r
.51077 .48593 .51977 .48346 .53626 .50159 .52732 .50165 Mtetra
.606 .041 0 r
.52732 .50165 .53626 .50159 .55306 .51654 .54416 .51296 Mtetra
0 .422 .74 r
.54416 .51296 .55306 .51654 .5701 .52637 .5612 .51816 Mtetra
.532 .751 .976 r
.5612 .51816 .5701 .52637 .58726 .52947 .57834 .51607 Mtetra
.724 .717 .843 r
.57834 .51607 .58726 .52947 .60444 .52488 .59546 .5063 Mtetra
.769 .672 .756 r
.59546 .5063 .60444 .52488 .6215 .51251 .61245 .48934 Mtetra
.783 .645 .71 r
.61245 .48934 .6215 .51251 .63836 .49311 .62923 .46639 Mtetra
.787 .629 .685 r
.62923 .46639 .63836 .49311 .65495 .46816 .64578 .43924 Mtetra
.787 .619 .672 r
.64578 .43924 .65495 .46816 .67128 .43956 .6621 .40983 Mtetra
.786 .615 .669 r
.6621 .40983 .67128 .43956 .68739 .40934 .67826 .38006 Mtetra
.783 .614 .672 r
.67826 .38006 .68739 .40934 .70335 .37933 .69433 .35149 Mtetra
.779 .618 .68 r
.69433 .35149 .70335 .37933 .71925 .35099 .71038 .32525 Mtetra
.774 .624 .695 r
.71038 .32525 .71925 .35099 .73518 .32529 .72651 .30196 Mtetra
.767 .635 .714 r
.72651 .30196 .73518 .32529 .75123 .30276 .74277 .28188 Mtetra
.759 .648 .739 r
.74277 .28188 .75123 .30276 .76744 .28348 .7592 .26487 Mtetra
.748 .663 .766 r
.7592 .26487 .76744 .28348 .78386 .26726 .77584 .2506 Mtetra
.736 .679 .795 r
.77584 .2506 .78386 .26726 .80051 .2537 .79269 .23863 Mtetra
.722 .694 .823 r
.79269 .23863 .80051 .2537 .81739 .24231 .80975 .22846 Mtetra
.708 .708 .848 r
.80975 .22846 .81739 .24231 .83448 .23261 .827 .21965 Mtetra
.663 .741 .908 r
.20509 .41748 .21474 .42646 .22881 .42162 .2192 .4126 Mtetra
.662 .741 .909 r
.2192 .4126 .22881 .42162 .24296 .41677 .23339 .40772 Mtetra
.661 .741 .91 r
.23339 .40772 .24296 .41677 .25718 .41192 .24766 .40285 Mtetra
.659 .742 .911 r
.24766 .40285 .25718 .41192 .27147 .40711 .26199 .39804 Mtetra
.655 .742 .914 r
.26199 .39804 .27147 .40711 .28584 .40237 .2764 .39335 Mtetra
.648 .742 .918 r
.2764 .39335 .28584 .40237 .30027 .39778 .29087 .38888 Mtetra
.636 .743 .925 r
.29087 .38888 .30027 .39778 .31477 .39346 .30539 .38477 Mtetra
.617 .743 .936 r
.30539 .38477 .31477 .39346 .32933 .38959 .31997 .38123 Mtetra
.583 .741 .951 r
.31997 .38123 .32933 .38959 .34393 .38639 .3346 .37855 Mtetra
.523 .734 .97 r
.3346 .37855 .34393 .38639 .35859 .3842 .34926 .37709 Mtetra
.413 .707 .983 r
.34926 .37709 .35859 .3842 .37328 .38341 .36395 .37728 Mtetra
.215 .629 .953 r
.36395 .37728 .37328 .38341 .38802 .38449 .37868 .37959 Mtetra
0 .445 .801 r
.37868 .37959 .38802 .38449 .40281 .38792 .39345 .38446 Mtetra
.41 0 0 r
.39345 .38446 .40281 .38792 .41767 .39414 .4083 .39226 Mtetra
.607 .036 0 r
.4083 .39226 .41767 .39414 .43264 .40346 .42327 .40314 Mtetra
.7 .168 0 r
.42327 .40314 .43264 .40346 .44775 .41597 .4384 .41696 Mtetra
.741 .238 .027 r
.4384 .41696 .44775 .41597 .46307 .4314 .45375 .43319 Mtetra
.756 .265 .067 r
.45375 .43319 .46307 .4314 .47865 .44906 .46938 .45086 Mtetra
.752 .258 .057 r
.46938 .45086 .47865 .44906 .49454 .46777 .48534 .46855 Mtetra
.721 .203 0 r
.48534 .46855 .49454 .46777 .51077 .48593 .50163 .48449 Mtetra
.614 .045 0 r
.50163 .48449 .51077 .48593 .52732 .50165 .51824 .4968 Mtetra
0 .361 .73 r
.51824 .4968 .52732 .50165 .54416 .51296 .53511 .5037 Mtetra
.452 .688 .967 r
.53511 .5037 .54416 .51296 .5612 .51816 .55215 .50387 Mtetra
.68 .687 .85 r
.55215 .50387 .5612 .51816 .57834 .51607 .56926 .49667 Mtetra
.742 .654 .763 r
.56926 .49667 .57834 .51607 .59546 .5063 .58633 .48229 Mtetra
.764 .632 .714 r
.58633 .48229 .59546 .5063 .61245 .48934 .60326 .46167 Mtetra
.773 .618 .687 r
.60326 .46167 .61245 .48934 .62923 .46639 .62 .43637 Mtetra
.776 .61 .673 r
.62 .43637 .62923 .46639 .64578 .43924 .63653 .40826 Mtetra
.777 .606 .668 r
.63653 .40826 .64578 .43924 .6621 .40983 .6529 .3792 Mtetra
.775 .606 .669 r
.6529 .3792 .6621 .40983 .67826 .38006 .66914 .35084 Mtetra
.773 .609 .677 r
.66914 .35084 .67826 .38006 .69433 .35149 .68534 .32439 Mtetra
.769 .616 .689 r
.68534 .32439 .69433 .35149 .71038 .32525 .70157 .30065 Mtetra
.764 .626 .707 r
.70157 .30065 .71038 .32525 .72651 .30196 .7179 .27995 Mtetra
.757 .639 .73 r
.7179 .27995 .72651 .30196 .74277 .28188 .73436 .2623 Mtetra
.748 .655 .757 r
.73436 .2623 .74277 .28188 .7592 .26487 .75101 .24742 Mtetra
.737 .671 .786 r
.75101 .24742 .7592 .26487 .77584 .2506 .76785 .23491 Mtetra
.724 .688 .815 r
.76785 .23491 .77584 .2506 .79269 .23863 .78488 .22431 Mtetra
.711 .703 .841 r
.78488 .22431 .79269 .23863 .80975 .22846 .8021 .21515 Mtetra
.698 .715 .862 r
.8021 .21515 .80975 .22846 .827 .21965 .81949 .20703 Mtetra
.663 .741 .909 r
.19534 .40842 .20509 .41748 .2192 .4126 .2095 .4035 Mtetra
.662 .741 .909 r
.2095 .4035 .2192 .4126 .23339 .40772 .22373 .39859 Mtetra
.66 .741 .91 r
.22373 .39859 .23339 .40772 .24766 .40285 .23803 .39372 Mtetra
.657 .742 .912 r
.23803 .39372 .24766 .40285 .26199 .39804 .25241 .38894 Mtetra
.651 .742 .916 r
.25241 .38894 .26199 .39804 .2764 .39335 .26685 .38432 Mtetra
.642 .742 .922 r
.26685 .38432 .2764 .39335 .29087 .38888 .28135 .38 Mtetra
.626 .742 .931 r
.28135 .38 .29087 .38888 .30539 .38477 .29591 .37615 Mtetra
.6 .742 .944 r
.29591 .37615 .30539 .38477 .31997 .38123 .3105 .37303 Mtetra
.554 .737 .961 r
.3105 .37303 .31997 .38123 .3346 .37855 .32513 .37094 Mtetra
.473 .722 .979 r
.32513 .37094 .3346 .37855 .34926 .37709 .33979 .37029 Mtetra
.327 .675 .977 r
.33979 .37029 .34926 .37709 .36395 .37728 .35447 .37152 Mtetra
.079 .553 .901 r
.35447 .37152 .36395 .37728 .37868 .37959 .36919 .37505 Mtetra
0 .33 .69 r
.36919 .37505 .37868 .37959 .39345 .38446 .38395 .38128 Mtetra
.5 0 0 r
.38395 .38128 .39345 .38446 .4083 .39226 .39879 .39042 Mtetra
.643 .084 0 r
.39879 .39042 .4083 .39226 .42327 .40314 .41376 .40245 Mtetra
.71 .18 0 r
.41376 .40245 .42327 .40314 .4384 .41696 .42891 .41699 Mtetra
.738 .225 0 r
.42891 .41699 .4384 .41696 .45375 .43319 .44431 .43325 Mtetra
.74 .228 0 r
.44431 .43325 .45375 .43319 .46938 .45086 .46 .44999 Mtetra
.712 .18 0 r
.46 .44999 .46938 .45086 .48534 .46855 .47602 .46565 Mtetra
.603 .033 0 r
.47602 .46565 .48534 .46855 .50163 .48449 .49238 .47843 Mtetra
0 .321 .729 r
.49238 .47843 .50163 .48449 .51824 .4968 .50905 .48658 Mtetra
.381 .629 .951 r
.50905 .48658 .51824 .4968 .53511 .5037 .52595 .48867 Mtetra
.634 .657 .856 r
.52595 .48867 .53511 .5037 .55215 .50387 .543 .48387 Mtetra
.713 .636 .77 r
.543 .48387 .55215 .50387 .56926 .49667 .56008 .47207 Mtetra
.744 .619 .72 r
.56008 .47207 .56926 .49667 .58633 .48229 .5771 .45397 Mtetra
.758 .607 .691 r
.5771 .45397 .58633 .48229 .60326 .46167 .59399 .43086 Mtetra
.764 .601 .675 r
.59399 .43086 .60326 .46167 .62 .43637 .61072 .40445 Mtetra
.767 .598 .668 r
.61072 .40445 .62 .43637 .63653 .40826 .62728 .37655 Mtetra
.768 .598 .668 r
.62728 .37655 .63653 .40826 .6529 .3792 .64371 .34881 Mtetra
.767 .602 .674 r
.64371 .34881 .6529 .3792 .66914 .35084 .66006 .32255 Mtetra
.764 .609 .686 r
.66006 .32255 .66914 .35084 .68534 .32439 .67641 .29865 Mtetra
.76 .618 .702 r
.67641 .29865 .68534 .32439 .70157 .30065 .69282 .27759 Mtetra
.755 .631 .724 r
.69282 .27759 .70157 .30065 .7179 .27995 .70934 .25946 Mtetra
.747 .647 .75 r
.70934 .25946 .7179 .27995 .73436 .2623 .72601 .24408 Mtetra
.737 .664 .778 r
.72601 .24408 .73436 .2623 .75101 .24742 .74285 .23111 Mtetra
.726 .681 .807 r
.74285 .23111 .75101 .24742 .76785 .23491 .75987 .22011 Mtetra
.713 .697 .834 r
.75987 .22011 .76785 .23491 .78488 .22431 .77706 .21062 Mtetra
.7 .711 .856 r
.77706 .21062 .78488 .22431 .8021 .21515 .79443 .20226 Mtetra
.689 .721 .874 r
.79443 .20226 .8021 .21515 .81949 .20703 .81195 .19467 Mtetra
.662 .741 .909 r
.18549 .39927 .19534 .40842 .2095 .4035 .19969 .39432 Mtetra
.661 .741 .91 r
.19969 .39432 .2095 .4035 .22373 .39859 .21396 .38939 Mtetra
.658 .742 .911 r
.21396 .38939 .22373 .39859 .23803 .39372 .22831 .38453 Mtetra
.654 .742 .914 r
.22831 .38453 .23803 .39372 .25241 .38894 .24272 .37979 Mtetra
.647 .742 .919 r
.24272 .37979 .25241 .38894 .26685 .38432 .2572 .37529 Mtetra
.634 .742 .926 r
.2572 .37529 .26685 .38432 .28135 .38 .27173 .37117 Mtetra
.614 .742 .937 r
.27173 .37117 .28135 .38 .29591 .37615 .2863 .36764 Mtetra
.579 .739 .952 r
.2863 .36764 .29591 .37615 .3105 .37303 .30091 .36499 Mtetra
.519 .731 .97 r
.30091 .36499 .3105 .37303 .32513 .37094 .31554 .36356 Mtetra
.413 .704 .982 r
.31554 .36356 .32513 .37094 .33979 .37029 .33019 .36376 Mtetra
.229 .63 .957 r
.33019 .36376 .33979 .37029 .35447 .37152 .34486 .366 Mtetra
0 .47 .834 r
.34486 .366 .35447 .37152 .36919 .37505 .35955 .37068 Mtetra
.342 0 0 r
.35955 .37068 .36919 .37505 .38395 .38128 .3743 .37806 Mtetra
.546 0 0 r
.3743 .37806 .38395 .38128 .39879 .39042 .38914 .38819 Mtetra
.653 .096 0 r
.38914 .38819 .39879 .39042 .41376 .40245 .40413 .40084 Mtetra
.701 .163 0 r
.40413 .40084 .41376 .40245 .42891 .41699 .41932 .41539 Mtetra
.713 .179 0 r
.41932 .41539 .42891 .41699 .44431 .43325 .43477 .43081 Mtetra
.686 .139 0 r
.43477 .43081 .44431 .43325 .46 .44999 .45054 .44571 Mtetra
.572 .003 0 r
.45054 .44571 .46 .44999 .47602 .46565 .46664 .45846 Mtetra
0 .302 .739 r
.46664 .45846 .47602 .46565 .49238 .47843 .48307 .46737 Mtetra
.322 .578 .934 r
.48307 .46737 .49238 .47843 .50905 .48658 .49979 .47098 Mtetra
.588 .629 .859 r
.49979 .47098 .50905 .48658 .52595 .48867 .51673 .46829 Mtetra
.684 .619 .778 r
.51673 .46829 .52595 .48867 .543 .48387 .53377 .45898 Mtetra
.723 .607 .726 r
.53377 .45898 .543 .48387 .56008 .47207 .55084 .44345 Mtetra
.742 .598 .696 r
.55084 .44345 .56008 .47207 .5771 .45397 .56784 .42274 Mtetra
.752 .593 .678 r
.56784 .42274 .5771 .45397 .59399 .43086 .58471 .39836 Mtetra
.757 .591 .67 r
.58471 .39836 .59399 .43086 .61072 .40445 .60144 .372 Mtetra
.76 .592 .669 r
.60144 .372 .61072 .40445 .62728 .37655 .61805 .34528 Mtetra
.76 .595 .673 r
.61805 .34528 .62728 .37655 .64371 .34881 .63457 .31957 Mtetra
.759 .602 .683 r
.63457 .31957 .64371 .34881 .66006 .32255 .65105 .29584 Mtetra
.756 .612 .699 r
.65105 .29584 .66006 .32255 .67641 .29865 .66756 .27467 Mtetra
.752 .625 .719 r
.66756 .27467 .67641 .29865 .69282 .27759 .68414 .25626 Mtetra
.745 .64 .743 r
.68414 .25626 .69282 .27759 .70934 .25946 .70084 .24052 Mtetra
.737 .657 .771 r
.70084 .24052 .70934 .25946 .72601 .24408 .71769 .22718 Mtetra
.726 .675 .8 r
.71769 .22718 .72601 .24408 .74285 .23111 .73471 .21583 Mtetra
.714 .692 .827 r
.73471 .21583 .74285 .23111 .75987 .22011 .75188 .20605 Mtetra
.702 .706 .851 r
.75188 .20605 .75987 .22011 .77706 .21062 .76922 .19745 Mtetra
.691 .718 .87 r
.76922 .19745 .77706 .21062 .79443 .20226 .78671 .18968 Mtetra
.682 .726 .884 r
.78671 .18968 .79443 .20226 .81195 .19467 .80435 .18247 Mtetra
.661 .741 .909 r
.17554 .39003 .18549 .39927 .19969 .39432 .18978 .38505 Mtetra
.66 .741 .911 r
.18978 .38505 .19969 .39432 .21396 .38939 .20409 .38012 Mtetra
.656 .742 .913 r
.20409 .38012 .21396 .38939 .22831 .38453 .21848 .37528 Mtetra
.651 .742 .916 r
.21848 .37528 .22831 .38453 .24272 .37979 .23293 .37062 Mtetra
.641 .742 .922 r
.23293 .37062 .24272 .37979 .2572 .37529 .24743 .36626 Mtetra
.625 .742 .931 r
.24743 .36626 .2572 .37529 .27173 .37117 .26198 .36238 Mtetra
.599 .74 .944 r
.26198 .36238 .27173 .37117 .2863 .36764 .27657 .35922 Mtetra
.554 .735 .96 r
.27657 .35922 .2863 .36764 .30091 .36499 .29118 .35709 Mtetra
.478 .72 .977 r
.29118 .35709 .30091 .36499 .31554 .36356 .30581 .35634 Mtetra
.346 .678 .978 r
.30581 .35634 .31554 .36356 .33019 .36376 .32045 .35738 Mtetra
.134 .578 .925 r
.32045 .35738 .33019 .36376 .34486 .366 .3351 .36057 Mtetra
0 .398 .772 r
.3351 .36057 .34486 .366 .35955 .37068 .34979 .3662 Mtetra
.396 0 0 r
.34979 .3662 .35955 .37068 .3743 .37806 .36453 .37441 Mtetra
.555 0 0 r
.36453 .37441 .3743 .37806 .38914 .38819 .37939 .38507 Mtetra
.635 .073 0 r
.37939 .38507 .38914 .38819 .40413 .40084 .3944 .39771 Mtetra
.661 .107 0 r
.3944 .39771 .40413 .40084 .41932 .41539 .40965 .4115 Mtetra
.636 .078 0 r
.40965 .4115 .41932 .41539 .43477 .43081 .42518 .42526 Mtetra
.517 0 0 r
.42518 .42526 .43477 .43081 .45054 .44571 .44103 .43752 Mtetra
0 .304 .758 r
.44103 .43752 .45054 .44571 .46664 .45846 .45723 .44671 Mtetra
.28 .539 .918 r
.45723 .44671 .46664 .45846 .48307 .46737 .47374 .45138 Mtetra
.546 .603 .862 r
.47374 .45138 .48307 .46737 .49979 .47098 .49052 .45046 Mtetra
.654 .604 .786 r
.49052 .45046 .49979 .47098 .51673 .46829 .50748 .44341 Mtetra
.702 .596 .734 r
.50748 .44341 .51673 .46829 .53377 .45898 .52453 .43038 Mtetra
.727 .589 .702 r
.52453 .43038 .53377 .45898 .55084 .44345 .54158 .41217 Mtetra
.74 .586 .683 r
.54158 .41217 .55084 .44345 .56784 .42274 .55857 .39004 Mtetra
.747 .584 .674 r
.55857 .39004 .56784 .42274 .58471 .39836 .57544 .36553 Mtetra
.751 .586 .671 r
.57544 .36553 .58471 .39836 .60144 .372 .5922 .34018 Mtetra
.753 .59 .674 r
.5922 .34018 .60144 .372 .61805 .34528 .60887 .31536 Mtetra
.753 .597 .683 r
.60887 .31536 .61805 .34528 .63457 .31957 .62549 .29211 Mtetra
.751 .606 .697 r
.62549 .29211 .63457 .31957 .65105 .29584 .6421 .2711 Mtetra
.748 .619 .715 r
.6421 .2711 .65105 .29584 .66756 .27467 .65876 .25262 Mtetra
.743 .634 .739 r
.65876 .25262 .66756 .27467 .68414 .25626 .67551 .23668 Mtetra
.736 .651 .766 r
.67551 .23668 .68414 .25626 .70084 .24052 .69238 .22307 Mtetra
.726 .67 .794 r
.69238 .22307 .70084 .24052 .71769 .22718 .7094 .21145 Mtetra
.715 .687 .822 r
.7094 .21145 .71769 .22718 .73471 .21583 .72656 .20142 Mtetra
.704 .702 .846 r
.72656 .20142 .73471 .21583 .75188 .20605 .74387 .19261 Mtetra
.693 .715 .866 r
.74387 .19261 .75188 .20605 .76922 .19745 .76134 .18467 Mtetra
.683 .724 .881 r
.76134 .18467 .76922 .19745 .78671 .18968 .77894 .17733 Mtetra
.676 .731 .891 r
.77894 .17733 .78671 .18968 .80435 .18247 .79668 .17037 Mtetra
.661 .741 .91 r
.16548 .38071 .17554 .39003 .18978 .38505 .17977 .37572 Mtetra
.658 .741 .911 r
.17977 .37572 .18978 .38505 .20409 .38012 .19412 .37079 Mtetra
.654 .742 .914 r
.19412 .37079 .20409 .38012 .21848 .37528 .20854 .36599 Mtetra
.646 .742 .919 r
.20854 .36599 .21848 .37528 .23293 .37062 .22302 .36143 Mtetra
.634 .742 .926 r
.22302 .36143 .23293 .37062 .24743 .36626 .23755 .35724 Mtetra
.614 .741 .936 r
.23755 .35724 .24743 .36626 .26198 .36238 .25212 .35364 Mtetra
.581 .738 .95 r
.25212 .35364 .26198 .36238 .27657 .35922 .26672 .35088 Mtetra
.526 .729 .967 r
.26672 .35088 .27657 .35922 .29118 .35709 .28133 .34929 Mtetra
.433 .706 .98 r
.28133 .34929 .29118 .35709 .30581 .35634 .29595 .34921 Mtetra
.281 .648 .967 r
.29595 .34921 .30581 .35634 .32045 .35738 .31058 .35101 Mtetra
.057 .529 .893 r
.31058 .35101 .32045 .35738 .3351 .36057 .32522 .35499 Mtetra
0 .352 .736 r
.32522 .35499 .3351 .36057 .34979 .3662 .3399 .36131 Mtetra
.403 0 0 r
.3399 .36131 .34979 .3662 .36453 .37441 .35466 .36994 Mtetra
.525 0 0 r
.35466 .36994 .36453 .37441 .37939 .38507 .36954 .38056 Mtetra
.574 .005 0 r
.36954 .38056 .37939 .38507 .3944 .39771 .38462 .39253 Mtetra
.556 0 0 r
.38462 .39253 .3944 .39771 .40965 .4115 .39994 .40484 Mtetra
.436 0 0 r
.39994 .40484 .40965 .4115 .42518 .42526 .41557 .41622 Mtetra
0 .323 .785 r
.41557 .41622 .42518 .42526 .44103 .43752 .43153 .42524 Mtetra
.256 .514 .906 r
.43153 .42524 .44103 .43752 .45723 .44671 .44782 .43053 Mtetra
.508 .581 .864 r
.44782 .43053 .45723 .44671 .47374 .45138 .46442 .43095 Mtetra
.625 .59 .794 r
.46442 .43095 .47374 .45138 .49052 .45046 .48125 .42586 Mtetra
.681 .587 .743 r
.48125 .42586 .49052 .45046 .50748 .44341 .49824 .41518 Mtetra
.711 .582 .71 r
.49824 .41518 .50748 .44341 .52453 .43038 .51529 .39944 Mtetra
.727 .58 .689 r
.51529 .39944 .52453 .43038 .54158 .41217 .53234 .37967 Mtetra
.737 .579 .678 r
.53234 .37967 .54158 .41217 .55857 .39004 .54932 .35721 Mtetra
.743 .581 .674 r
.54932 .35721 .55857 .39004 .57544 .36553 .56621 .33351 Mtetra
.746 .585 .676 r
.56621 .33351 .57544 .36553 .5922 .34018 .58301 .30989 Mtetra
.747 .592 .684 r
.58301 .30989 .5922 .34018 .60887 .31536 .59975 .28741 Mtetra
.746 .602 .696 r
.59975 .28741 .60887 .31536 .62549 .29211 .61647 .26681 Mtetra
.744 .614 .714 r
.61647 .26681 .62549 .29211 .6421 .2711 .63321 .24847 Mtetra
.74 .629 .736 r
.63321 .24847 .6421 .2711 .65876 .25262 .65001 .23249 Mtetra
.734 .646 .762 r
.65001 .23249 .65876 .25262 .67551 .23668 .66691 .21874 Mtetra
.726 .665 .789 r
.66691 .21874 .67551 .23668 .69238 .22307 .68393 .20692 Mtetra
.716 .683 .817 r
.68393 .20692 .69238 .22307 .7094 .21145 .70109 .1967 Mtetra
.705 .699 .842 r
.70109 .1967 .7094 .21145 .72656 .20142 .71839 .18771 Mtetra
.694 .712 .862 r
.71839 .18771 .72656 .20142 .74387 .19261 .73583 .17962 Mtetra
.685 .722 .878 r
.73583 .17962 .74387 .19261 .76134 .18467 .75341 .17215 Mtetra
.677 .729 .889 r
.75341 .17215 .76134 .18467 .77894 .17733 .77111 .1651 Mtetra
.672 .734 .897 r
.77111 .1651 .77894 .17733 .79668 .17037 .78895 .1583 Mtetra
.659 .741 .911 r
.15532 .37131 .16548 .38071 .17977 .37572 .16965 .3663 Mtetra
.656 .742 .913 r
.16965 .3663 .17977 .37572 .19412 .37079 .18404 .36139 Mtetra
.651 .742 .916 r
.18404 .36139 .19412 .37079 .20854 .36599 .19849 .35666 Mtetra
.641 .742 .922 r
.19849 .35666 .20854 .36599 .22302 .36143 .213 .35221 Mtetra
.626 .741 .93 r
.213 .35221 .22302 .36143 .23755 .35724 .22756 .34823 Mtetra
.601 .74 .942 r
.22756 .34823 .23755 .35724 .25212 .35364 .24214 .34494 Mtetra
.561 .734 .957 r
.24214 .34494 .25212 .35364 .26672 .35088 .25675 .34259 Mtetra
.496 .721 .972 r
.25675 .34259 .26672 .35088 .28133 .34929 .27136 .34152 Mtetra
.39 .688 .979 r
.27136 .34152 .28133 .34929 .29595 .34921 .28597 .34205 Mtetra
.227 .618 .954 r
.28597 .34205 .29595 .34921 .31058 .35101 .30059 .34448 Mtetra
.012 .496 .871 r
.30059 .34448 .31058 .35101 .32522 .35499 .31523 .349 Mtetra
0 .34 .735 r
.31523 .349 .32522 .35499 .3399 .36131 .32992 .35565 Mtetra
.362 0 0 r
.32992 .35565 .3399 .36131 .35466 .36994 .34471 .36424 Mtetra
.441 0 0 r
.34471 .36424 .35466 .36994 .36954 .38056 .35965 .37425 Mtetra
.438 0 0 r
.35965 .37425 .36954 .38056 .38462 .39253 .3748 .3849 Mtetra
0 .199 .652 r
.3748 .3849 .38462 .39253 .39994 .40484 .39023 .39509 Mtetra
0 .356 .817 r
.39023 .39509 .39994 .40484 .41557 .41622 .40597 .40356 Mtetra
.249 .503 .9 r
.40597 .40356 .41557 .41622 .43153 .42524 .42205 .40903 Mtetra
.478 .566 .866 r
.42205 .40903 .43153 .42524 .44782 .43053 .43845 .4104 Mtetra
.599 .579 .803 r
.43845 .4104 .44782 .43053 .46442 .43095 .45512 .4069 Mtetra
.661 .579 .753 r
.45512 .4069 .46442 .43095 .48125 .42586 .47201 .3983 Mtetra
.694 .577 .719 r
.47201 .3983 .48125 .42586 .49824 .41518 .48902 .3849 Mtetra
.714 .575 .697 r
.48902 .3849 .49824 .41518 .51529 .39944 .50607 .36749 Mtetra
.726 .575 .685 r
.50607 .36749 .51529 .39944 .53234 .37967 .52311 .34721 Mtetra
.734 .577 .679 r
.52311 .34721 .53234 .37967 .54932 .35721 .5401 .32536 Mtetra
.738 .582 .68 r
.5401 .32536 .54932 .35721 .56621 .33351 .55701 .30317 Mtetra
.741 .589 .686 r
.55701 .30317 .56621 .33351 .58301 .30989 .57386 .28171 Mtetra
.741 .598 .697 r
.57386 .28171 .58301 .30989 .59975 .28741 .59067 .26176 Mtetra
.74 .61 .714 r
.59067 .26176 .59975 .28741 .61647 .26681 .60749 .24377 Mtetra
.737 .625 .735 r
.60749 .24377 .61647 .26681 .63321 .24847 .62435 .22792 Mtetra
.732 .642 .759 r
.62435 .22792 .63321 .24847 .65001 .23249 .64129 .21414 Mtetra
.725 .661 .786 r
.64129 .21414 .65001 .23249 .66691 .21874 .65832 .20223 Mtetra
.715 .679 .813 r
.65832 .20223 .66691 .21874 .68393 .20692 .67548 .19187 Mtetra
.705 .695 .838 r
.67548 .19187 .68393 .20692 .70109 .1967 .69276 .18273 Mtetra
.695 .709 .859 r
.69276 .18273 .70109 .1967 .71839 .18771 .71018 .17452 Mtetra
.686 .72 .875 r
.71018 .17452 .71839 .18771 .73583 .17962 .72773 .16694 Mtetra
.678 .728 .887 r
.72773 .16694 .73583 .17962 .75341 .17215 .74541 .1598 Mtetra
.673 .733 .895 r
.74541 .1598 .75341 .17215 .77111 .1651 .76321 .15292 Mtetra
.669 .736 .901 r
.76321 .15292 .77111 .1651 .78895 .1583 .78114 .1462 Mtetra
.658 .741 .911 r
.14505 .36182 .15532 .37131 .16965 .3663 .15942 .35682 Mtetra
.654 .741 .914 r
.15942 .35682 .16965 .3663 .18404 .36139 .17385 .35194 Mtetra
.647 .741 .918 r
.17385 .35194 .18404 .36139 .19849 .35666 .18833 .34728 Mtetra
.635 .741 .925 r
.18833 .34728 .19849 .35666 .213 .35221 .20287 .34298 Mtetra
.617 .74 .934 r
.20287 .34298 .213 .35221 .22756 .34823 .21744 .33922 Mtetra
.588 .737 .947 r
.21744 .33922 .22756 .34823 .24214 .34494 .23204 .33623 Mtetra
.541 .73 .962 r
.23204 .33623 .24214 .34494 .25675 .34259 .24665 .33429 Mtetra
.467 .711 .975 r
.24665 .33429 .25675 .34259 .27136 .34152 .26126 .33369 Mtetra
.354 .671 .975 r
.26126 .33369 .27136 .34152 .28597 .34205 .27587 .33471 Mtetra
.195 .596 .945 r
.27587 .33471 .28597 .34205 .30059 .34448 .29049 .33756 Mtetra
.007 .485 .87 r
.29049 .33756 .30059 .34448 .31523 .349 .30515 .34233 Mtetra
0 .364 .771 r
.30515 .34233 .31523 .349 .32992 .35565 .31987 .34892 Mtetra
0 .275 .696 r
.31987 .34892 .32992 .35565 .34471 .36424 .33471 .35696 Mtetra
0 .248 .686 r
.33471 .35696 .34471 .36424 .35965 .37425 .34974 .36582 Mtetra
0 .294 .749 r
.34974 .36582 .35965 .37425 .3748 .3849 .36499 .37459 Mtetra
.002 .399 .851 r
.36499 .37459 .3748 .3849 .39023 .39509 .38054 .3822 Mtetra
.258 .504 .899 r
.38054 .3822 .39023 .39509 .40597 .40356 .39642 .38748 Mtetra
.457 .557 .869 r
.39642 .38748 .40597 .40356 .42205 .40903 .41261 .38938 Mtetra
.575 .572 .813 r
.41261 .38938 .42205 .40903 .43845 .4104 .42911 .3871 Mtetra
.641 .574 .764 r
.42911 .3871 .43845 .4104 .45512 .4069 .44586 .38027 Mtetra
.679 .573 .729 r
.44586 .38027 .45512 .4069 .47201 .3983 .46279 .369 Mtetra
.702 .572 .706 r
.46279 .369 .47201 .3983 .48902 .3849 .47981 .35386 Mtetra
.716 .573 .692 r
.47981 .35386 .48902 .3849 .50607 .36749 .49687 .33577 Mtetra
.725 .575 .686 r
.49687 .33577 .50607 .36749 .52311 .34721 .51391 .31586 Mtetra
.731 .58 .685 r
.51391 .31586 .52311 .34721 .5401 .32536 .5309 .29529 Mtetra
.734 .586 .69 r
.5309 .29529 .5401 .32536 .55701 .30317 .54783 .27505 Mtetra
.736 .596 .7 r
.54783 .27505 .55701 .30317 .57386 .28171 .56473 .25595 Mtetra
.735 .608 .715 r
.56473 .25595 .57386 .28171 .59067 .26176 .58162 .2385 Mtetra
.733 .622 .735 r
.58162 .2385 .59067 .26176 .60749 .24377 .59854 .22293 Mtetra
.729 .639 .758 r
.59854 .22293 .60749 .24377 .62435 .22792 .61551 .20926 Mtetra
.723 .657 .784 r
.61551 .20926 .62435 .22792 .64129 .21414 .63256 .19734 Mtetra
.715 .676 .811 r
.63256 .19734 .64129 .21414 .65832 .20223 .64972 .18691 Mtetra
.705 .692 .835 r
.64972 .18691 .65832 .20223 .67548 .19187 .66699 .17768 Mtetra
.695 .707 .857 r
.66699 .17768 .67548 .19187 .69276 .18273 .68439 .16935 Mtetra
.686 .718 .873 r
.68439 .16935 .69276 .18273 .71018 .17452 .70191 .16169 Mtetra
.679 .726 .886 r
.70191 .16169 .71018 .17452 .72773 .16694 .71956 .15446 Mtetra
.673 .732 .894 r
.71956 .15446 .72773 .16694 .74541 .1598 .73734 .14752 Mtetra
.669 .736 .9 r
.73734 .14752 .74541 .1598 .76321 .15292 .75523 .14074 Mtetra
.667 .738 .903 r
.75523 .14074 .76321 .15292 .78114 .1462 .77324 .13404 Mtetra
.656 .741 .912 r
.13468 .35226 .14505 .36182 .15942 .35682 .14908 .34726 Mtetra
.651 .741 .916 r
.14908 .34726 .15942 .35682 .17385 .35194 .16354 .34242 Mtetra
.643 .741 .921 r
.16354 .34242 .17385 .35194 .18833 .34728 .17806 .33786 Mtetra
.629 .741 .928 r
.17806 .33786 .18833 .34728 .20287 .34298 .19262 .33371 Mtetra
.607 .739 .938 r
.19262 .33371 .20287 .34298 .21744 .33922 .20721 .33018 Mtetra
.574 .734 .951 r
.20721 .33018 .21744 .33922 .23204 .33623 .22182 .32749 Mtetra
.522 .724 .965 r
.22182 .32749 .23204 .33623 .24665 .33429 .23643 .32589 Mtetra
.444 .701 .975 r
.23643 .32589 .24665 .33429 .26126 .33369 .25105 .32566 Mtetra
.332 .658 .972 r
.25105 .32566 .26126 .33369 .27587 .33471 .26567 .32701 Mtetra
.191 .587 .942 r
.26567 .32701 .27587 .33471 .29049 .33756 .28031 .33004 Mtetra
.044 .498 .887 r
.28031 .33004 .29049 .33756 .30515 .34233 .295 .33473 Mtetra
0 .416 .83 r
.295 .33473 .30515 .34233 .31987 .34892 .30977 .34084 Mtetra
0 .375 .807 r
.30977 .34084 .31987 .34892 .33471 .35696 .3247 .34786 Mtetra
0 .388 .832 r
.3247 .34786 .33471 .35696 .34974 .36582 .33983 .35509 Mtetra
.087 .448 .881 r
.33983 .35509 .34974 .36582 .36499 .37459 .35521 .36161 Mtetra
.279 .515 .902 r
.35521 .36161 .36499 .37459 .38054 .3822 .3709 .36638 Mtetra
.446 .555 .873 r
.3709 .36638 .38054 .3822 .39642 .38748 .38691 .36844 Mtetra
.556 .569 .823 r
.38691 .36844 .39642 .38748 .41261 .38938 .40323 .367 Mtetra
.623 .572 .776 r
.40323 .367 .41261 .38938 .42911 .3871 .41982 .3616 Mtetra
.664 .571 .741 r
.41982 .3616 .42911 .3871 .44586 .38027 .43663 .35219 Mtetra
.689 .571 .717 r
.43663 .35219 .44586 .38027 .46279 .369 .45359 .33913 Mtetra
.706 .572 .702 r
.45359 .33913 .46279 .369 .47981 .35386 .47062 .32317 Mtetra
.716 .574 .694 r
.47062 .32317 .47981 .35386 .49687 .33577 .48767 .30524 Mtetra
.723 .579 .692 r
.48767 .30524 .49687 .33577 .51391 .31586 .50471 .28637 Mtetra
.728 .585 .696 r
.50471 .28637 .51391 .31586 .5309 .29529 .5217 .2675 Mtetra
.73 .595 .705 r
.5217 .2675 .5309 .29529 .54783 .27505 .53867 .24942 Mtetra
.731 .606 .718 r
.53867 .24942 .54783 .27505 .56473 .25595 .55562 .23266 Mtetra
.729 .621 .737 r
.55562 .23266 .56473 .25595 .58162 .2385 .57258 .21752 Mtetra
.726 .637 .759 r
.57258 .21752 .58162 .2385 .59854 .22293 .58958 .20408 Mtetra
.721 .655 .784 r
.58958 .20408 .59854 .22293 .61551 .20926 .60666 .19224 Mtetra
.713 .673 .809 r
.60666 .19224 .61551 .20926 .63256 .19734 .62382 .1818 Mtetra
.704 .69 .834 r
.62382 .1818 .63256 .19734 .64972 .18691 .64108 .17252 Mtetra
.695 .705 .855 r
.64108 .17252 .64972 .18691 .66699 .17768 .65846 .16413 Mtetra
.687 .716 .872 r
.65846 .16413 .66699 .17768 .68439 .16935 .67596 .15638 Mtetra
.679 .725 .884 r
.67596 .15638 .68439 .16935 .70191 .16169 .69358 .14909 Mtetra
.674 .731 .893 r
.69358 .14909 .70191 .16169 .71956 .15446 .71132 .14208 Mtetra
.67 .735 .899 r
.71132 .14208 .71956 .15446 .73734 .14752 .72918 .13525 Mtetra
.667 .738 .903 r
.72918 .13525 .73734 .14752 .75523 .14074 .74716 .1285 Mtetra
.666 .739 .905 r
.74716 .1285 .75523 .14074 .77324 .13404 .76526 .1218 Mtetra
.654 .741 .914 r
.12419 .34261 .13468 .35226 .14908 .34726 .13863 .33763 Mtetra
.648 .741 .917 r
.13863 .33763 .14908 .34726 .16354 .34242 .15312 .33285 Mtetra
.638 .741 .923 r
.15312 .33285 .16354 .34242 .17806 .33786 .16767 .32838 Mtetra
.622 .74 .931 r
.16767 .32838 .17806 .33786 .19262 .33371 .18225 .32439 Mtetra
.598 .737 .942 r
.18225 .32439 .19262 .33371 .20721 .33018 .19686 .32107 Mtetra
.561 .731 .954 r
.19686 .32107 .20721 .33018 .22182 .32749 .21148 .31863 Mtetra
.507 .718 .967 r
.21148 .31863 .22182 .32749 .23643 .32589 .2261 .31731 Mtetra
.43 .693 .974 r
.2261 .31731 .23643 .32589 .25105 .32566 .24073 .31732 Mtetra
.329 .65 .969 r
.24073 .31732 .25105 .32566 .26567 .32701 .25538 .31879 Mtetra
.216 .591 .947 r
.25538 .31879 .26567 .32701 .28031 .33004 .27005 .32173 Mtetra
.117 .528 .914 r
.27005 .32173 .28031 .33004 .295 .33473 .28479 .32599 Mtetra
.064 .483 .891 r
.28479 .32599 .295 .33473 .30977 .34084 .29966 .33122 Mtetra
.082 .473 .892 r
.29966 .33122 .30977 .34084 .3247 .34786 .31469 .33684 Mtetra
.174 .498 .907 r
.31469 .33684 .3247 .34786 .33983 .35509 .32994 .34211 Mtetra
.311 .535 .908 r
.32994 .34211 .33983 .35509 .35521 .36161 .34547 .34613 Mtetra
.443 .561 .879 r
.34547 .34613 .35521 .36161 .3709 .36638 .36131 .34805 Mtetra
.542 .571 .833 r
.36131 .34805 .3709 .36638 .38691 .36844 .37745 .34709 Mtetra
.608 .573 .789 r
.37745 .34709 .38691 .36844 .40323 .367 .39388 .34277 Mtetra
.65 .572 .754 r
.39388 .34277 .40323 .367 .41982 .3616 .41055 .33491 Mtetra
.677 .572 .729 r
.41055 .33491 .41982 .3616 .43663 .35219 .4274 .32372 Mtetra
.695 .572 .713 r
.4274 .32372 .43663 .35219 .45359 .33913 .44438 .30973 Mtetra
.708 .575 .703 r
.44438 .30973 .45359 .33913 .47062 .32317 .46141 .29373 Mtetra
.716 .579 .7 r
.46141 .29373 .47062 .32317 .48767 .30524 .47845 .27658 Mtetra
.721 .586 .703 r
.47845 .27658 .48767 .30524 .50471 .28637 .49549 .25917 Mtetra
.725 .595 .711 r
.49549 .25917 .50471 .28637 .5217 .2675 .51249 .24222 Mtetra
.726 .606 .723 r
.51249 .24222 .5217 .2675 .53867 .24942 .52949 .22628 Mtetra
.725 .62 .74 r
.52949 .22628 .53867 .24942 .55562 .23266 .54649 .21169 Mtetra
.723 .636 .761 r
.54649 .21169 .55562 .23266 .57258 .21752 .56352 .19858 Mtetra
.718 .654 .785 r
.56352 .19858 .57258 .21752 .58958 .20408 .58061 .18691 Mtetra
.712 .672 .809 r
.58061 .18691 .58958 .20408 .60666 .19224 .59777 .17654 Mtetra
.704 .688 .833 r
.59777 .17654 .60666 .19224 .62382 .1818 .61503 .16725 Mtetra
.695 .703 .853 r
.61503 .16725 .62382 .1818 .64108 .17252 .63239 .15882 Mtetra
.687 .715 .87 r
.63239 .15882 .64108 .17252 .65846 .16413 .64986 .15102 Mtetra
.679 .724 .883 r
.64986 .15102 .65846 .16413 .67596 .15638 .66746 .14367 Mtetra
.674 .73 .892 r
.66746 .14367 .67596 .15638 .69358 .14909 .68517 .13661 Mtetra
.67 .735 .898 r
.68517 .13661 .69358 .14909 .71132 .14208 .703 .12972 Mtetra
.667 .737 .902 r
.703 .12972 .71132 .14208 .72918 .13525 .72094 .12293 Mtetra
.666 .739 .905 r
.72094 .12293 .72918 .13525 .74716 .1285 .73901 .11618 Mtetra
.665 .74 .906 r
.73901 .11618 .74716 .1285 .76526 .1218 .75719 .10944 Mtetra
.652 .741 .915 r
.11359 .33288 .12419 .34261 .13863 .33763 .12806 .32792 Mtetra
.645 .741 .919 r
.12806 .32792 .13863 .33763 .15312 .33285 .14259 .3232 Mtetra
.633 .74 .925 r
.14259 .3232 .15312 .33285 .16767 .32838 .15716 .31883 Mtetra
.616 .739 .934 r
.15716 .31883 .16767 .32838 .18225 .32439 .17177 .31499 Mtetra
.589 .735 .944 r
.17177 .31499 .18225 .32439 .19686 .32107 .18639 .31184 Mtetra
.551 .727 .956 r
.18639 .31184 .19686 .32107 .21148 .31863 .20103 .3096 Mtetra
.498 .712 .967 r
.20103 .3096 .21148 .31863 .2261 .31731 .21567 .30845 Mtetra
.428 .687 .972 r
.21567 .30845 .2261 .31731 .24073 .31732 .23033 .30853 Mtetra
.345 .649 .968 r
.23033 .30853 .24073 .31732 .25538 .31879 .24501 .30989 Mtetra
.265 .604 .953 r
.24501 .30989 .25538 .31879 .27005 .32173 .25974 .31246 Mtetra
.212 .565 .937 r
.25974 .31246 .27005 .32173 .28479 .32599 .27456 .31597 Mtetra
.207 .544 .928 r
.27456 .31597 .28479 .32599 .29966 .33122 .28953 .32 Mtetra
.258 .545 .925 r
.28953 .32 .29966 .33122 .31469 .33684 .30469 .32394 Mtetra
.349 .559 .914 r
.30469 .32394 .31469 .33684 .32994 .34211 .32009 .32705 Mtetra
.45 .572 .885 r
.32009 .32705 .32994 .34211 .34547 .34613 .33577 .32856 Mtetra
.534 .577 .845 r
.33577 .32856 .34547 .34613 .36131 .34805 .35175 .32779 Mtetra
.596 .578 .803 r
.35175 .32779 .36131 .34805 .37745 .34709 .36801 .32422 Mtetra
.638 .576 .769 r
.36801 .32422 .37745 .34709 .39388 .34277 .38454 .3176 Mtetra
.666 .575 .743 r
.38454 .3176 .39388 .34277 .41055 .33491 .40127 .308 Mtetra
.686 .575 .725 r
.40127 .308 .41055 .33491 .4274 .32372 .41816 .29579 Mtetra
.699 .577 .715 r
.41816 .29579 .4274 .32372 .44438 .30973 .43514 .28159 Mtetra
.709 .582 .711 r
.43514 .28159 .44438 .30973 .46141 .29373 .45216 .26614 Mtetra
.715 .588 .712 r
.45216 .26614 .46141 .29373 .47845 .27658 .4692 .25019 Mtetra
.719 .597 .718 r
.4692 .25019 .47845 .27658 .49549 .25917 .48622 .23444 Mtetra
.721 .608 .73 r
.48622 .23444 .49549 .25917 .51249 .24222 .50325 .21942 Mtetra
.721 .621 .745 r
.50325 .21942 .51249 .24222 .52949 .22628 .52027 .20548 Mtetra
.719 .637 .765 r
.52027 .20548 .52949 .22628 .54649 .21169 .53732 .19279 Mtetra
.715 .654 .787 r
.53732 .19279 .54649 .21169 .56352 .19858 .55442 .18137 Mtetra
.709 .671 .81 r
.55442 .18137 .56352 .19858 .58061 .18691 .57158 .17112 Mtetra
.702 .687 .833 r
.57158 .17112 .58061 .18691 .59777 .17654 .58883 .16188 Mtetra
.694 .702 .853 r
.58883 .16188 .59777 .17654 .61503 .16725 .60618 .15344 Mtetra
.686 .714 .87 r
.60618 .15344 .61503 .16725 .63239 .15882 .62363 .14561 Mtetra
.68 .723 .882 r
.62363 .14561 .63239 .15882 .64986 .15102 .64119 .13821 Mtetra
.674 .73 .892 r
.64119 .13821 .64986 .15102 .66746 .14367 .65887 .13109 Mtetra
.67 .734 .898 r
.65887 .13109 .66746 .14367 .68517 .13661 .67667 .12416 Mtetra
.667 .737 .902 r
.67667 .12416 .68517 .13661 .703 .12972 .69458 .11732 Mtetra
.666 .739 .905 r
.69458 .11732 .703 .12972 .72094 .12293 .71261 .11053 Mtetra
.665 .74 .906 r
.71261 .11053 .72094 .12293 .73901 .11618 .73076 .10375 Mtetra
.664 .741 .907 r
.73076 .10375 .73901 .11618 .75719 .10944 .74902 .09695 Mtetra
.65 .741 .916 r
.10287 .32307 .11359 .33288 .12806 .32792 .11738 .31814 Mtetra
.642 .741 .921 r
.11738 .31814 .12806 .32792 .14259 .3232 .13194 .31347 Mtetra
.629 .739 .927 r
.13194 .31347 .14259 .3232 .15716 .31883 .14654 .30919 Mtetra
.61 .737 .936 r
.14654 .30919 .15716 .31883 .17177 .31499 .16117 .30546 Mtetra
.583 .732 .946 r
.16117 .30546 .17177 .31499 .18639 .31184 .17581 .30244 Mtetra
.545 .723 .956 r
.17581 .30244 .18639 .31184 .20103 .3096 .19048 .30031 Mtetra
.496 .708 .965 r
.19048 .30031 .20103 .3096 .21567 .30845 .20515 .29919 Mtetra
.437 .684 .968 r
.20515 .29919 .21567 .30845 .23033 .30853 .21985 .29917 Mtetra
.377 .653 .965 r
.21985 .29917 .23033 .30853 .24501 .30989 .23458 .3002 Mtetra
.329 .622 .957 r
.23458 .3002 .24501 .30989 .25974 .31246 .24939 .30213 Mtetra
.312 .598 .947 r
.24939 .30213 .25974 .31246 .27456 .31597 .26432 .30464 Mtetra
.334 .586 .936 r
.26432 .30464 .27456 .31597 .28953 .32 .27941 .30723 Mtetra
.391 .585 .92 r
.27941 .30723 .28953 .32 .30469 .32394 .29471 .30933 Mtetra
.463 .588 .892 r
.29471 .30933 .30469 .32394 .32009 .32705 .31027 .31026 Mtetra
.532 .588 .856 r
.31027 .31026 .32009 .32705 .33577 .32856 .3261 .30942 Mtetra
.587 .586 .818 r
.3261 .30942 .33577 .32856 .35175 .32779 .34221 .3063 Mtetra
.628 .583 .784 r
.34221 .3063 .35175 .32779 .36801 .32422 .35858 .30061 Mtetra
.657 .581 .758 r
.35858 .30061 .36801 .32422 .38454 .3176 .37518 .29232 Mtetra
.677 .58 .74 r
.37518 .29232 .38454 .3176 .40127 .308 .39196 .28166 Mtetra
.691 .582 .728 r
.39196 .28166 .40127 .308 .41816 .29579 .40886 .26911 Mtetra
.702 .586 .722 r
.40886 .26911 .41816 .29579 .43514 .28159 .42583 .25524 Mtetra
.709 .591 .722 r
.42583 .25524 .43514 .28159 .45216 .26614 .44285 .24074 Mtetra
.713 .6 .728 r
.44285 .24074 .45216 .26614 .4692 .25019 .45987 .2262 Mtetra
.716 .61 .738 r
.45987 .2262 .4692 .25019 .48622 .23444 .4769 .21214 Mtetra
.717 .623 .752 r
.4769 .21214 .48622 .23444 .50325 .21942 .49394 .19891 Mtetra
.715 .638 .77 r
.49394 .19891 .50325 .21942 .52027 .20548 .511 .18672 Mtetra
.712 .655 .791 r
.511 .18672 .52027 .20548 .53732 .19279 .5281 .17562 Mtetra
.707 .671 .813 r
.5281 .17562 .53732 .19279 .55442 .18137 .54526 .16555 Mtetra
.7 .687 .834 r
.54526 .16555 .55442 .18137 .57158 .17112 .56249 .15639 Mtetra
.693 .702 .853 r
.56249 .15639 .57158 .17112 .58883 .16188 .57982 .14797 Mtetra
.686 .713 .87 r
.57982 .14797 .58883 .16188 .60618 .15344 .59725 .14013 Mtetra
.679 .722 .882 r
.59725 .14013 .60618 .15344 .62363 .14561 .61479 .13269 Mtetra
.674 .729 .891 r
.61479 .13269 .62363 .14561 .64119 .13821 .63243 .12554 Mtetra
.67 .734 .898 r
.63243 .12554 .64119 .13821 .65887 .13109 .6502 .11856 Mtetra
.668 .737 .902 r
.6502 .11856 .65887 .13109 .67667 .12416 .66808 .11169 Mtetra
.666 .739 .904 r
.66808 .11169 .67667 .12416 .69458 .11732 .68607 .10485 Mtetra
.665 .74 .906 r
.68607 .10485 .69458 .11732 .71261 .11053 .70418 .09803 Mtetra
.664 .741 .907 r
.70418 .09803 .71261 .11053 .73076 .10375 .72241 .09119 Mtetra
.72241 .09119 .73076 .10375 .74902 .09695 .74076 .08432 Mtetra
.648 .741 .917 r
.09203 .31316 .10287 .32307 .11738 .31814 .10658 .30825 Mtetra
.638 .74 .922 r
.10658 .30825 .11738 .31814 .13194 .31347 .12117 .30363 Mtetra
.625 .738 .929 r
.12117 .30363 .13194 .31347 .14654 .30919 .1358 .29943 Mtetra
.605 .735 .937 r
.1358 .29943 .14654 .30919 .16117 .30546 .15045 .29577 Mtetra
.579 .73 .946 r
.15045 .29577 .16117 .30546 .17581 .30244 .16513 .29282 Mtetra
.544 .72 .955 r
.16513 .29282 .17581 .30244 .19048 .30031 .17983 .29069 Mtetra
.502 .705 .961 r
.17983 .29069 .19048 .30031 .20515 .29919 .19454 .28947 Mtetra
.457 .684 .963 r
.19454 .28947 .20515 .29919 .21985 .29917 .2093 .28916 Mtetra
.418 .66 .96 r
.2093 .28916 .21985 .29917 .23458 .3002 .22411 .28966 Mtetra
.396 .638 .953 r
.22411 .28966 .23458 .3002 .24939 .30213 .23902 .29074 Mtetra
.401 .621 .941 r
.23902 .29074 .24939 .30213 .26432 .30464 .25406 .29204 Mtetra
.433 .612 .924 r
.25406 .29204 .26432 .30464 .27941 .30723 .26929 .29308 Mtetra
.482 .606 .899 r
.26929 .29308 .27941 .30723 .29471 .30933 .28475 .29331 Mtetra
.535 .602 .867 r
.28475 .29331 .29471 .30933 .31027 .31026 .30045 .2922 Mtetra
.582 .597 .832 r
.30045 .2922 .31027 .31026 .3261 .30942 .31642 .28928 Mtetra
.62 .592 .8 r
.31642 .28928 .3261 .30942 .34221 .3063 .33265 .28424 Mtetra
.648 .589 .775 r
.33265 .28424 .34221 .3063 .35858 .30061 .34911 .27698 Mtetra
.669 .588 .755 r
.34911 .27698 .35858 .30061 .37518 .29232 .36577 .26763 Mtetra
.684 .588 .742 r
.36577 .26763 .37518 .29232 .39196 .28166 .38257 .25652 Mtetra
.695 .591 .736 r
.38257 .25652 .39196 .28166 .40886 .26911 .39948 .24412 Mtetra
.703 .597 .735 r
.39948 .24412 .40886 .26911 .42583 .25524 .41644 .23097 Mtetra
.708 .604 .739 r
.41644 .23097 .42583 .25524 .44285 .24074 .43344 .21762 Mtetra
.711 .614 .747 r
.43344 .21762 .44285 .24074 .45987 .2262 .45046 .20453 Mtetra
.712 .627 .76 r
.45046 .20453 .45987 .2262 .4769 .21214 .46749 .19206 Mtetra
.711 .641 .777 r
.46749 .19206 .4769 .21214 .49394 .19891 .48455 .1804 Mtetra
.709 .657 .796 r
.48455 .1804 .49394 .19891 .511 .18672 .50164 .16967 Mtetra
.704 .673 .816 r
.50164 .16967 .511 .18672 .5281 .17562 .5188 .15982 Mtetra
.698 .688 .836 r
.5188 .15982 .5281 .17562 .54526 .16555 .53602 .15078 Mtetra
.692 .702 .855 r
.53602 .15078 .54526 .16555 .56249 .15639 .55333 .14242 Mtetra
.685 .713 .87 r
.55333 .14242 .56249 .15639 .57982 .14797 .57073 .13458 Mtetra
.679 .722 .882 r
.57073 .13458 .57982 .14797 .59725 .14013 .58824 .12713 Mtetra
.674 .729 .891 r
.58824 .12713 .59725 .14013 .61479 .13269 .60586 .11995 Mtetra
.67 .733 .897 r
.60586 .11995 .61479 .13269 .63243 .12554 .62358 .11293 Mtetra
.668 .737 .902 r
.62358 .11293 .63243 .12554 .6502 .11856 .64143 .10602 Mtetra
.666 .739 .904 r
.64143 .10602 .6502 .11856 .66808 .11169 .65939 .09914 Mtetra
.665 .74 .906 r
.65939 .09914 .66808 .11169 .68607 .10485 .67746 .09228 Mtetra
.664 .74 .907 r
.67746 .09228 .68607 .10485 .70418 .09803 .69566 .0854 Mtetra
.664 .741 .907 r
.69566 .0854 .70418 .09803 .72241 .09119 .71397 .0785 Mtetra
.664 .741 .908 r
.71397 .0785 .72241 .09119 .74076 .08432 .7324 .07156 Mtetra
.646 .74 .918 r
.08108 .30316 .09203 .31316 .10658 .30825 .09566 .29827 Mtetra
.636 .739 .923 r
.09566 .29827 .10658 .30825 .12117 .30363 .11028 .29368 Mtetra
.622 .737 .929 r
.11028 .29368 .12117 .30363 .1358 .29943 .12494 .28951 Mtetra
.603 .733 .937 r
.12494 .28951 .1358 .29943 .15045 .29577 .13963 .28588 Mtetra
.578 .727 .944 r
.13963 .28588 .15045 .29577 .16513 .29282 .15435 .28291 Mtetra
.548 .717 .951 r
.15435 .28291 .16513 .29282 .17983 .29069 .16909 .28068 Mtetra
.514 .703 .956 r
.16909 .28068 .17983 .29069 .19454 .28947 .18386 .27921 Mtetra
.483 .685 .956 r
.18386 .27921 .19454 .28947 .2093 .28916 .19869 .27845 Mtetra
.462 .666 .951 r
.19869 .27845 .2093 .28916 .22411 .28966 .21359 .27825 Mtetra
.457 .649 .942 r
.21359 .27825 .22411 .28966 .23902 .29074 .22862 .27833 Mtetra
.473 .636 .926 r
.22862 .27833 .23902 .29074 .25406 .29204 .2438 .27833 Mtetra
.504 .626 .905 r
.2438 .27833 .25406 .29204 .26929 .29308 .25917 .2778 Mtetra
.543 .618 .877 r
.25917 .2778 .26929 .29308 .28475 .29331 .27478 .27628 Mtetra
.582 .61 .846 r
.27478 .27628 .28475 .29331 .30045 .2922 .29062 .27335 Mtetra
.615 .604 .817 r
.29062 .27335 .30045 .2922 .31642 .28928 .30672 .26872 Mtetra
.641 .6 .792 r
.30672 .26872 .31642 .28928 .33265 .28424 .32305 .26224 Mtetra
.662 .597 .772 r
.32305 .26224 .33265 .28424 .34911 .27698 .33958 .25394 Mtetra
.677 .597 .758 r
.33958 .25394 .34911 .27698 .36577 .26763 .35627 .24406 Mtetra
.689 .599 .751 r
.35627 .24406 .36577 .26763 .38257 .25652 .37309 .23295 Mtetra
.697 .604 .748 r
.37309 .23295 .38257 .25652 .39948 .24412 .38998 .22105 Mtetra
.703 .611 .751 r
.38998 .22105 .39948 .24412 .41644 .23097 .40694 .20883 Mtetra
.706 .62 .758 r
.40694 .20883 .41644 .23097 .43344 .21762 .42392 .19669 Mtetra
.708 .632 .77 r
.42392 .19669 .43344 .21762 .45046 .20453 .44094 .18497 Mtetra
.707 .645 .785 r
.44094 .18497 .45046 .20453 .46749 .19206 .45798 .17389 Mtetra
.705 .66 .802 r
.45798 .17389 .46749 .19206 .48455 .1804 .47506 .16354 Mtetra
.701 .675 .821 r
.47506 .16354 .48455 .1804 .50164 .16967 .4922 .15396 Mtetra
.696 .689 .839 r
.4922 .15396 .50164 .16967 .5188 .15982 .50941 .14507 Mtetra
.69 .702 .856 r
.50941 .14507 .5188 .15982 .53602 .15078 .52669 .13678 Mtetra
.684 .713 .871 r
.52669 .13678 .53602 .15078 .55333 .14242 .54407 .12897 Mtetra
.678 .722 .882 r
.54407 .12897 .55333 .14242 .57073 .13458 .56155 .12152 Mtetra
.674 .729 .891 r
.56155 .12152 .57073 .13458 .58824 .12713 .57913 .11431 Mtetra
.67 .733 .897 r
.57913 .11431 .58824 .12713 .60586 .11995 .59683 .10726 Mtetra
.668 .736 .901 r
.59683 .10726 .60586 .11995 .62358 .11293 .61464 .10031 Mtetra
.666 .738 .904 r
.61464 .10031 .62358 .11293 .64143 .10602 .63256 .0934 Mtetra
.665 .74 .906 r
.63256 .0934 .64143 .10602 .65939 .09914 .6506 .0865 Mtetra
.664 .74 .907 r
.6506 .0865 .65939 .09914 .67746 .09228 .66876 .07958 Mtetra
.664 .741 .907 r
.66876 .07958 .67746 .09228 .69566 .0854 .68703 .07264 Mtetra
.664 .741 .908 r
.68703 .07264 .69566 .0854 .71397 .0785 .70542 .06566 Mtetra
.70542 .06566 .71397 .0785 .7324 .07156 .72394 .05864 Mtetra
.644 .74 .919 r
.07001 .29304 .08108 .30316 .09566 .29827 .08462 .28816 Mtetra
.634 .738 .924 r
.08462 .28816 .09566 .29827 .11028 .29368 .09928 .28358 Mtetra
.62 .736 .929 r
.09928 .28358 .11028 .29368 .12494 .28951 .11398 .27941 Mtetra
.602 .732 .936 r
.11398 .27941 .12494 .28951 .13963 .28588 .12871 .27575 Mtetra
.58 .725 .942 r
.12871 .27575 .13963 .28588 .15435 .28291 .14347 .27268 Mtetra
.556 .715 .947 r
.14347 .27268 .15435 .28291 .16909 .28068 .15826 .27023 Mtetra
.531 .702 .948 r
.15826 .27023 .16909 .28068 .18386 .27921 .17311 .26839 Mtetra
.512 .687 .946 r
.17311 .26839 .18386 .27921 .19869 .27845 .18802 .26706 Mtetra
.504 .672 .939 r
.18802 .26706 .19869 .27845 .21359 .27825 .20304 .26603 Mtetra
.509 .658 .927 r
.20304 .26603 .21359 .27825 .22862 .27833 .21819 .26504 Mtetra
.527 .646 .909 r
.21819 .26504 .22862 .27833 .2438 .27833 .23351 .26372 Mtetra
.554 .635 .886 r
.23351 .26372 .2438 .27833 .25917 .2778 .24903 .2617 Mtetra
.584 .626 .859 r
.24903 .2617 .25917 .2778 .27478 .27628 .26477 .25863 Mtetra
.612 .618 .833 r
.26477 .25863 .27478 .27628 .29062 .27335 .28075 .2542 Mtetra
.637 .612 .809 r
.28075 .2542 .29062 .27335 .30672 .26872 .29695 .24826 Mtetra
.656 .609 .789 r
.29695 .24826 .30672 .26872 .32305 .26224 .31335 .24079 Mtetra
.671 .607 .775 r
.31335 .24079 .32305 .26224 .33958 .25394 .32993 .23192 Mtetra
.683 .609 .767 r
.32993 .23192 .33958 .25394 .35627 .24406 .34665 .22192 Mtetra
.691 .612 .763 r
.34665 .22192 .35627 .24406 .37309 .23295 .36347 .21113 Mtetra
.697 .618 .765 r
.36347 .21113 .37309 .23295 .38998 .22105 .38036 .19994 Mtetra
.701 .627 .771 r
.38036 .19994 .38998 .22105 .40694 .20883 .3973 .18871 Mtetra
.703 .638 .78 r
.3973 .18871 .40694 .20883 .42392 .19669 .41428 .17772 Mtetra
.703 .65 .794 r
.41428 .17772 .42392 .19669 .44094 .18497 .4313 .16721 Mtetra
.702 .664 .809 r
.4313 .16721 .44094 .18497 .45798 .17389 .44836 .15728 Mtetra
.698 .678 .826 r
.44836 .15728 .45798 .17389 .47506 .16354 .46547 .14798 Mtetra
.694 .691 .843 r
.46547 .14798 .47506 .16354 .4922 .15396 .48266 .13927 Mtetra
.688 .704 .859 r
.48266 .13927 .4922 .15396 .50941 .14507 .49992 .13107 Mtetra
.683 .714 .872 r
.49992 .13107 .50941 .14507 .52669 .13678 .51727 .1233 Mtetra
.678 .722 .883 r
.51727 .1233 .52669 .13678 .54407 .12897 .53471 .11585 Mtetra
.673 .729 .891 r
.53471 .11585 .54407 .12897 .56155 .12152 .55227 .10863 Mtetra
.67 .733 .897 r
.55227 .10863 .56155 .12152 .57913 .11431 .56993 .10156 Mtetra
.668 .736 .901 r
.56993 .10156 .57913 .11431 .59683 .10726 .5877 .09457 Mtetra
.666 .738 .904 r
.5877 .09457 .59683 .10726 .61464 .10031 .60558 .08762 Mtetra
.665 .74 .906 r
.60558 .08762 .61464 .10031 .63256 .0934 .62359 .08068 Mtetra
.664 .74 .907 r
.62359 .08068 .63256 .0934 .6506 .0865 .64171 .07373 Mtetra
.664 .741 .907 r
.64171 .07373 .6506 .0865 .66876 .07958 .65994 .06674 Mtetra
.664 .741 .908 r
.65994 .06674 .66876 .07958 .68703 .07264 .6783 .05973 Mtetra
.6783 .05973 .68703 .07264 .70542 .06566 .69678 .05267 Mtetra
.69678 .05267 .70542 .06566 .72394 .05864 .71537 .04557 Mtetra
.642 .739 .919 r
.05882 .28281 .07001 .29304 .08462 .28816 .07347 .27791 Mtetra
.633 .738 .924 r
.07347 .27791 .08462 .28816 .09928 .28358 .08817 .27331 Mtetra
.62 .735 .929 r
.08817 .27331 .09928 .28358 .11398 .27941 .10291 .2691 Mtetra
.604 .73 .934 r
.10291 .2691 .11398 .27941 .12871 .27575 .11768 .26534 Mtetra
.586 .723 .938 r
.11768 .26534 .12871 .27575 .14347 .27268 .1325 .26208 Mtetra
.567 .714 .941 r
.1325 .26208 .14347 .27268 .15826 .27023 .14736 .25933 Mtetra
.551 .702 .94 r
.14736 .25933 .15826 .27023 .17311 .26839 .16229 .25702 Mtetra
.541 .689 .936 r
.16229 .25702 .17311 .26839 .18802 .26706 .17731 .25501 Mtetra
.54 .676 .926 r
.17731 .25501 .18802 .26706 .20304 .26603 .19244 .25311 Mtetra
.55 .664 .912 r
.19244 .25311 .20304 .26603 .21819 .26504 .20772 .25103 Mtetra
.567 .652 .893 r
.20772 .25103 .21819 .26504 .23351 .26372 .22318 .24847 Mtetra
.59 .642 .871 r
.22318 .24847 .23351 .26372 .24903 .2617 .23884 .24513 Mtetra
.613 .633 .847 r
.23884 .24513 .24903 .2617 .26477 .25863 .25471 .24075 Mtetra
.634 .626 .826 r
.25471 .24075 .26477 .25863 .28075 .2542 .27079 .23516 Mtetra
.651 .622 .807 r
.27079 .23516 .28075 .2542 .29695 .24826 .28708 .2283 Mtetra
.666 .619 .793 r
.28708 .2283 .29695 .24826 .31335 .24079 .30354 .22024 Mtetra
.677 .62 .784 r
.30354 .22024 .31335 .24079 .32993 .23192 .32015 .21117 Mtetra
.686 .622 .779 r
.32015 .21117 .32993 .23192 .34665 .22192 .33688 .20134 Mtetra
.692 .628 .779 r
.33688 .20134 .34665 .22192 .36347 .21113 .3537 .19108 Mtetra
.696 .635 .784 r
.3537 .19108 .36347 .21113 .38036 .19994 .37058 .18067 Mtetra
.699 .645 .792 r
.37058 .18067 .38036 .19994 .3973 .18871 .38751 .17038 Mtetra
.699 .656 .804 r
.38751 .17038 .3973 .18871 .41428 .17772 .4045 .16042 Mtetra
.698 .668 .818 r
.4045 .16042 .41428 .17772 .4313 .16721 .42153 .15091 Mtetra
.695 .681 .833 r
.42153 .15091 .4313 .16721 .44836 .15728 .43861 .14189 Mtetra
.691 .694 .848 r
.43861 .14189 .44836 .15728 .46547 .14798 .45577 .13337 Mtetra
.686 .705 .862 r
.45577 .13337 .46547 .14798 .48266 .13927 .473 .12529 Mtetra
.681 .715 .874 r
.473 .12529 .48266 .13927 .49992 .13107 .49032 .11757 Mtetra
.677 .723 .884 r
.49032 .11757 .49992 .13107 .51727 .1233 .50774 .11014 Mtetra
.673 .729 .892 r
.50774 .11014 .51727 .1233 .53471 .11585 .52525 .10291 Mtetra
.67 .733 .898 r
.52525 .10291 .53471 .11585 .55227 .10863 .54288 .09581 Mtetra
.667 .736 .902 r
.54288 .09581 .55227 .10863 .56993 .10156 .56061 .08879 Mtetra
.666 .738 .904 r
.56061 .08879 .56993 .10156 .5877 .09457 .57846 .08181 Mtetra
.665 .74 .906 r
.57846 .08181 .5877 .09457 .60558 .08762 .59643 .07483 Mtetra
.664 .74 .907 r
.59643 .07483 .60558 .08762 .62359 .08068 .61451 .06784 Mtetra
.664 .741 .907 r
.61451 .06784 .62359 .08068 .64171 .07373 .63271 .06082 Mtetra
.664 .741 .908 r
.63271 .06082 .64171 .07373 .65994 .06674 .65103 .05376 Mtetra
.65103 .05376 .65994 .06674 .6783 .05973 .66946 .04666 Mtetra
.66946 .04666 .6783 .05973 .69678 .05267 .68802 .03952 Mtetra
.68802 .03952 .69678 .05267 .71537 .04557 .70671 .03234 Mtetra
.642 .739 .919 r
.04751 .27244 .05882 .28281 .07347 .27791 .0622 .26751 Mtetra
.632 .737 .923 r
.0622 .26751 .07347 .27791 .08817 .27331 .07694 .26286 Mtetra
.621 .733 .927 r
.07694 .26286 .08817 .27331 .10291 .2691 .09173 .25855 Mtetra
.608 .729 .931 r
.09173 .25855 .10291 .2691 .11768 .26534 .10656 .25464 Mtetra
.593 .722 .933 r
.10656 .25464 .11768 .26534 .1325 .26208 .12144 .25113 Mtetra
.58 .713 .934 r
.12144 .25113 .1325 .26208 .14736 .25933 .13638 .24799 Mtetra
.57 .703 .931 r
.13638 .24799 .14736 .25933 .16229 .25702 .1514 .24513 Mtetra
.567 .691 .924 r
.1514 .24513 .16229 .25702 .17731 .25501 .16653 .24241 Mtetra
.571 .68 .914 r
.16653 .24241 .17731 .25501 .19244 .25311 .18178 .23962 Mtetra
.581 .668 .899 r
.18178 .23962 .19244 .25311 .20772 .25103 .19719 .23652 Mtetra
.597 .658 .88 r
.19719 .23652 .20772 .25103 .22318 .24847 .21278 .23285 Mtetra
.615 .649 .861 r
.21278 .23285 .22318 .24847 .23884 .24513 .22857 .2284 Mtetra
.632 .641 .841 r
.22857 .2284 .23884 .24513 .25471 .24075 .24455 .223 Mtetra
.648 .636 .824 r
.24455 .223 .25471 .24075 .27079 .23516 .26073 .21657 Mtetra
.662 .633 .81 r
.26073 .21657 .27079 .23516 .28708 .2283 .27708 .20913 Mtetra
.673 .632 .801 r
.27708 .20913 .28708 .2283 .30354 .22024 .29358 .20081 Mtetra
.681 .634 .795 r
.29358 .20081 .30354 .22024 .32015 .21117 .31022 .19179 Mtetra
.687 .638 .795 r
.31022 .19179 .32015 .21117 .33688 .20134 .32695 .18233 Mtetra
.692 .644 .798 r
.32695 .18233 .33688 .20134 .3537 .19108 .34376 .17266 Mtetra
.694 .653 .804 r
.34376 .17266 .3537 .19108 .37058 .18067 .36064 .16301 Mtetra
.695 .663 .814 r
.36064 .16301 .37058 .18067 .38751 .17038 .37758 .15357 Mtetra
.694 .674 .826 r
.37758 .15357 .38751 .17038 .4045 .16042 .39457 .14446 Mtetra
.692 .686 .84 r
.39457 .14446 .4045 .16042 .42153 .15091 .41162 .13573 Mtetra
.688 .697 .853 r
.41162 .13573 .42153 .15091 .43861 .14189 .42875 .12741 Mtetra
.684 .707 .866 r
.42875 .12741 .43861 .14189 .45577 .13337 .44595 .11944 Mtetra
.68 .716 .877 r
.44595 .11944 .45577 .13337 .473 .12529 .46323 .11179 Mtetra
.676 .724 .886 r
.46323 .11179 .473 .12529 .49032 .11757 .48061 .10438 Mtetra
.672 .729 .893 r
.48061 .10438 .49032 .11757 .50774 .11014 .49809 .09715 Mtetra
.669 .733 .898 r
.49809 .09715 .50774 .11014 .52525 .10291 .51568 .09003 Mtetra
.667 .736 .902 r
.51568 .09003 .52525 .10291 .54288 .09581 .53338 .08298 Mtetra
.666 .738 .904 r
.53338 .08298 .54288 .09581 .56061 .08879 .55119 .07596 Mtetra
.665 .74 .906 r
.55119 .07596 .56061 .08879 .57846 .08181 .56912 .06895 Mtetra
.664 .74 .907 r
.56912 .06895 .57846 .08181 .59643 .07483 .58716 .06192 Mtetra
.664 .741 .907 r
.58716 .06192 .59643 .07483 .61451 .06784 .60532 .05486 Mtetra
.664 .741 .908 r
.60532 .05486 .61451 .06784 .63271 .06082 .6236 .04776 Mtetra
.6236 .04776 .63271 .06082 .65103 .05376 .642 .04063 Mtetra
.642 .04063 .65103 .05376 .66946 .04666 .66052 .03345 Mtetra
.66052 .03345 .66946 .04666 .68802 .03952 .67916 .02622 Mtetra
.67916 .02622 .68802 .03952 .70671 .03234 .69793 .01894 Mtetra
.642 .738 .919 r
.03608 .26193 .04751 .27244 .0622 .26751 .05082 .25694 Mtetra
.633 .736 .922 r
.05082 .25694 .0622 .26751 .07694 .26286 .0656 .2522 Mtetra
.623 .732 .925 r
.0656 .2522 .07694 .26286 .09173 .25855 .08044 .24776 Mtetra
.613 .727 .927 r
.08044 .24776 .09173 .25855 .10656 .25464 .09534 .24363 Mtetra
.602 .721 .928 r
.09534 .24363 .10656 .25464 .12144 .25113 .11029 .23981 Mtetra
.594 .713 .927 r
.11029 .23981 .12144 .25113 .13638 .24799 .12532 .23623 Mtetra
.589 .703 .922 r
.12532 .23623 .13638 .24799 .1514 .24513 .14044 .2328 Mtetra
.589 .693 .914 r
.14044 .2328 .1514 .24513 .16653 .24241 .15568 .22937 Mtetra
.595 .683 .903 r
.15568 .22937 .16653 .24241 .18178 .23962 .17105 .22574 Mtetra
.606 .673 .888 r
.17105 .22574 .18178 .23962 .19719 .23652 .18659 .22171 Mtetra
.619 .664 .872 r
.18659 .22171 .19719 .23652 .21278 .23285 .2023 .21711 Mtetra
.633 .657 .855 r
.2023 .21711 .21278 .23285 .22857 .2284 .21819 .21178 Mtetra
.646 .651 .84 r
.21819 .21178 .22857 .2284 .24455 .223 .23427 .20562 Mtetra
.658 .647 .827 r
.23427 .20562 .24455 .223 .26073 .21657 .25052 .19865 Mtetra
.669 .645 .818 r
.25052 .19865 .26073 .21657 .27708 .20913 .26692 .19091 Mtetra
.677 .646 .812 r
.26692 .19091 .27708 .20913 .29358 .20081 .28346 .18256 Mtetra
.683 .649 .81 r
.28346 .18256 .29358 .20081 .31022 .19179 .30011 .17377 Mtetra
.687 .654 .812 r
.30011 .17377 .31022 .19179 .32695 .18233 .31685 .16474 Mtetra
.69 .662 .817 r
.31685 .16474 .32695 .18233 .34376 .17266 .33366 .15567 Mtetra
.691 .67 .825 r
.33366 .15567 .34376 .17266 .36064 .16301 .35054 .1467 Mtetra
.69 .68 .835 r
.35054 .1467 .36064 .16301 .37758 .15357 .36749 .13797 Mtetra
.688 .691 .847 r
.36749 .13797 .37758 .15357 .39457 .14446 .3845 .12952 Mtetra
.685 .701 .858 r
.3845 .12952 .39457 .14446 .41162 .13573 .40159 .12138 Mtetra
.682 .71 .869 r
.40159 .12138 .41162 .13573 .42875 .12741 .41875 .11354 Mtetra
.678 .718 .879 r
.41875 .11354 .42875 .12741 .44595 .11944 .436 .10595 Mtetra
.674 .725 .887 r
.436 .10595 .44595 .11944 .46323 .11179 .45334 .09857 Mtetra
.671 .73 .894 r
.45334 .09857 .46323 .11179 .48061 .10438 .47079 .09134 Mtetra
.669 .734 .899 r
.47079 .09134 .48061 .10438 .49809 .09715 .48834 .08421 Mtetra
.667 .736 .902 r
.48834 .08421 .49809 .09715 .51568 .09003 .506 .07713 Mtetra
.666 .738 .904 r
.506 .07713 .51568 .09003 .53338 .08298 .52377 .07008 Mtetra
.665 .74 .906 r
.52377 .07008 .53338 .08298 .55119 .07596 .54166 .06303 Mtetra
.664 .74 .907 r
.54166 .06303 .55119 .07596 .56912 .06895 .55966 .05597 Mtetra
.664 .741 .907 r
.55966 .05597 .56912 .06895 .58716 .06192 .57778 .04887 Mtetra
.664 .741 .908 r
.57778 .04887 .58716 .06192 .60532 .05486 .59602 .04173 Mtetra
.59602 .04173 .60532 .05486 .6236 .04776 .61438 .03456 Mtetra
.61438 .03456 .6236 .04776 .642 .04063 .63286 .02733 Mtetra
.63286 .02733 .642 .04063 .66052 .03345 .65147 .02007 Mtetra
.65147 .02007 .66052 .03345 .67916 .02622 .6702 .01275 Mtetra
.6702 .01275 .67916 .02622 .69793 .01894 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.423961 0.97619 0.791823 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39729 .59642 .40512 .60371 .41826 .59977 .41047 .59244 Mtetra
.41047 .59244 .41826 .59977 .43147 .59581 .42372 .58844 Mtetra
.42372 .58844 .43147 .59581 .44474 .59183 .43703 .58443 Mtetra
.43703 .58443 .44474 .59183 .45807 .58783 .4504 .58039 Mtetra
.4504 .58039 .45807 .58783 .47147 .58381 .46385 .57633 Mtetra
.46385 .57633 .47147 .58381 .48494 .57977 .47736 .57226 Mtetra
.47736 .57226 .48494 .57977 .49847 .57571 .49093 .56816 Mtetra
.49093 .56816 .49847 .57571 .51207 .57163 .50458 .56404 Mtetra
.50458 .56404 .51207 .57163 .52574 .56753 .51829 .5599 Mtetra
.51829 .5599 .52574 .56753 .53948 .56341 .53207 .55575 Mtetra
.663 .741 .908 r
.53207 .55575 .53948 .56341 .55329 .55927 .54592 .55157 Mtetra
.54592 .55157 .55329 .55927 .56716 .55511 .55985 .54737 Mtetra
.55985 .54737 .56716 .55511 .58111 .55092 .57384 .54315 Mtetra
.57384 .54315 .58111 .55092 .59512 .54672 .5879 .53892 Mtetra
.5879 .53892 .59512 .54672 .60921 .5425 .60203 .53466 Mtetra
.663 .742 .908 r
.60203 .53466 .60921 .5425 .62337 .53827 .61624 .53039 Mtetra
.663 .742 .909 r
.61624 .53039 .62337 .53827 .6376 .53401 .63052 .52611 Mtetra
.662 .742 .909 r
.63052 .52611 .6376 .53401 .6519 .52975 .64487 .52182 Mtetra
.662 .742 .91 r
.64487 .52182 .6519 .52975 .66628 .52547 .6593 .51753 Mtetra
.661 .743 .91 r
.6593 .51753 .66628 .52547 .68073 .52118 .67381 .51323 Mtetra
.66 .743 .911 r
.67381 .51323 .68073 .52118 .69526 .5169 .68839 .50895 Mtetra
.659 .744 .913 r
.68839 .50895 .69526 .5169 .70986 .51261 .70305 .50469 Mtetra
.658 .745 .914 r
.70305 .50469 .70986 .51261 .72454 .50834 .71779 .50046 Mtetra
.656 .747 .917 r
.71779 .50046 .72454 .50834 .7393 .50409 .73261 .49628 Mtetra
.653 .748 .92 r
.73261 .49628 .7393 .50409 .75415 .49988 .74752 .49215 Mtetra
.65 .751 .923 r
.74752 .49215 .75415 .49988 .76908 .49571 .76252 .4881 Mtetra
.646 .754 .928 r
.76252 .4881 .76908 .49571 .78409 .49159 .77761 .48413 Mtetra
.642 .758 .933 r
.77761 .48413 .78409 .49159 .7992 .48754 .79279 .48027 Mtetra
.637 .762 .939 r
.79279 .48027 .7992 .48754 .8144 .48357 .80807 .47652 Mtetra
.631 .768 .945 r
.80807 .47652 .8144 .48357 .82969 .47968 .82345 .47288 Mtetra
.624 .774 .953 r
.82345 .47288 .82969 .47968 .84508 .47588 .83894 .46936 Mtetra
.616 .781 .96 r
.83894 .46936 .84508 .47588 .86057 .47216 .85453 .46594 Mtetra
.608 .789 .968 r
.85453 .46594 .86057 .47216 .87616 .46852 .87022 .46261 Mtetra
.6 .797 .975 r
.87022 .46261 .87616 .46852 .89185 .46493 .88603 .45933 Mtetra
.592 .806 .981 r
.88603 .45933 .89185 .46493 .90764 .46138 .90193 .45608 Mtetra
.585 .814 .986 r
.90193 .45608 .90764 .46138 .92353 .45784 .91794 .45279 Mtetra
.581 .822 .99 r
.91794 .45279 .92353 .45784 .93952 .45426 .93403 .44943 Mtetra
.579 .83 .993 r
.93403 .44943 .93952 .45426 .95559 .45062 .95022 .44593 Mtetra
.581 .838 .994 r
.95022 .44593 .95559 .45062 .97175 .44685 .96648 .44225 Mtetra
.664 .741 .908 r
.38939 .58906 .39729 .59642 .41047 .59244 .40261 .58505 Mtetra
.40261 .58505 .41047 .59244 .42372 .58844 .41589 .58101 Mtetra
.41589 .58101 .42372 .58844 .43703 .58443 .42925 .57696 Mtetra
.42925 .57696 .43703 .58443 .4504 .58039 .44267 .57288 Mtetra
.44267 .57288 .4504 .58039 .46385 .57633 .45615 .56879 Mtetra
.45615 .56879 .46385 .57633 .47736 .57226 .4697 .56468 Mtetra
.4697 .56468 .47736 .57226 .49093 .56816 .48332 .56054 Mtetra
.48332 .56054 .49093 .56816 .50458 .56404 .49701 .55639 Mtetra
.49701 .55639 .50458 .56404 .51829 .5599 .51077 .55221 Mtetra
.663 .741 .908 r
.51077 .55221 .51829 .5599 .53207 .55575 .5246 .54801 Mtetra
.5246 .54801 .53207 .55575 .54592 .55157 .5385 .5438 Mtetra
.5385 .5438 .54592 .55157 .55985 .54737 .55246 .53956 Mtetra
.55246 .53956 .55985 .54737 .57384 .54315 .5665 .53531 Mtetra
.5665 .53531 .57384 .54315 .5879 .53892 .58061 .53104 Mtetra
.663 .742 .908 r
.58061 .53104 .5879 .53892 .60203 .53466 .59479 .52676 Mtetra
.663 .742 .909 r
.59479 .52676 .60203 .53466 .61624 .53039 .60905 .52246 Mtetra
.662 .742 .909 r
.60905 .52246 .61624 .53039 .63052 .52611 .62338 .51816 Mtetra
.662 .742 .91 r
.62338 .51816 .63052 .52611 .64487 .52182 .63778 .51386 Mtetra
.661 .743 .911 r
.63778 .51386 .64487 .52182 .6593 .51753 .65226 .50956 Mtetra
.66 .743 .912 r
.65226 .50956 .6593 .51753 .67381 .51323 .66682 .50528 Mtetra
.658 .744 .914 r
.66682 .50528 .67381 .51323 .68839 .50895 .68146 .50103 Mtetra
.656 .746 .916 r
.68146 .50103 .68839 .50895 .70305 .50469 .69618 .49682 Mtetra
.654 .747 .918 r
.69618 .49682 .70305 .50469 .71779 .50046 .71098 .49268 Mtetra
.651 .75 .922 r
.71098 .49268 .71779 .50046 .73261 .49628 .72587 .48861 Mtetra
.647 .752 .926 r
.72587 .48861 .73261 .49628 .74752 .49215 .74084 .48463 Mtetra
.642 .756 .931 r
.74084 .48463 .74752 .49215 .76252 .4881 .75592 .48077 Mtetra
.637 .761 .938 r
.75592 .48077 .76252 .4881 .77761 .48413 .77108 .47704 Mtetra
.63 .766 .945 r
.77108 .47704 .77761 .48413 .79279 .48027 .78635 .47345 Mtetra
.621 .772 .953 r
.78635 .47345 .79279 .48027 .80807 .47652 .80173 .47001 Mtetra
.612 .78 .961 r
.80173 .47001 .80807 .47652 .82345 .47288 .81721 .46672 Mtetra
.601 .788 .97 r
.81721 .46672 .82345 .47288 .83894 .46936 .8328 .46357 Mtetra
.589 .796 .979 r
.8328 .46357 .83894 .46936 .85453 .46594 .84851 .46053 Mtetra
.576 .805 .986 r
.84851 .46053 .85453 .46594 .87022 .46261 .86432 .45758 Mtetra
.563 .814 .992 r
.86432 .45758 .87022 .46261 .88603 .45933 .88024 .45467 Mtetra
.551 .823 .996 r
.88024 .45467 .88603 .45933 .90193 .45608 .89627 .45175 Mtetra
.542 .831 .999 r
.89627 .45175 .90193 .45608 .91794 .45279 .9124 .44874 Mtetra
.536 .839 .999 r
.9124 .44874 .91794 .45279 .93403 .44943 .92861 .44557 Mtetra
.537 .848 .998 r
.92861 .44557 .93403 .44943 .95022 .44593 .94491 .44219 Mtetra
.544 .856 .997 r
.94491 .44219 .95022 .44593 .96648 .44225 .96127 .43852 Mtetra
.664 .741 .908 r
.38141 .58163 .38939 .58906 .40261 .58505 .39467 .57758 Mtetra
.39467 .57758 .40261 .58505 .41589 .58101 .408 .57351 Mtetra
.408 .57351 .41589 .58101 .42925 .57696 .42139 .56942 Mtetra
.42139 .56942 .42925 .57696 .44267 .57288 .43486 .56531 Mtetra
.43486 .56531 .44267 .57288 .45615 .56879 .44838 .56118 Mtetra
.44838 .56118 .45615 .56879 .4697 .56468 .46198 .55703 Mtetra
.46198 .55703 .4697 .56468 .48332 .56054 .47564 .55285 Mtetra
.47564 .55285 .48332 .56054 .49701 .55639 .48938 .54866 Mtetra
.663 .741 .908 r
.48938 .54866 .49701 .55639 .51077 .55221 .50318 .54445 Mtetra
.50318 .54445 .51077 .55221 .5246 .54801 .51705 .54021 Mtetra
.51705 .54021 .5246 .54801 .5385 .5438 .531 .53596 Mtetra
.531 .53596 .5385 .5438 .55246 .53956 .54501 .53169 Mtetra
.54501 .53169 .55246 .53956 .5665 .53531 .5591 .5274 Mtetra
.663 .742 .909 r
.5591 .5274 .5665 .53531 .58061 .53104 .57325 .52311 Mtetra
.57325 .52311 .58061 .53104 .59479 .52676 .58748 .5188 Mtetra
.662 .742 .909 r
.58748 .5188 .59479 .52676 .60905 .52246 .60179 .51448 Mtetra
.661 .742 .91 r
.60179 .51448 .60905 .52246 .62338 .51816 .61617 .51017 Mtetra
.66 .743 .911 r
.61617 .51017 .62338 .51816 .63778 .51386 .63063 .50588 Mtetra
.659 .744 .913 r
.63063 .50588 .63778 .51386 .65226 .50956 .64516 .5016 Mtetra
.657 .745 .914 r
.64516 .5016 .65226 .50956 .66682 .50528 .65977 .49737 Mtetra
.655 .746 .917 r
.65977 .49737 .66682 .50528 .68146 .50103 .67447 .49319 Mtetra
.652 .748 .92 r
.67447 .49319 .68146 .50103 .69618 .49682 .68925 .48908 Mtetra
.648 .751 .924 r
.68925 .48908 .69618 .49682 .71098 .49268 .70411 .48508 Mtetra
.644 .754 .929 r
.70411 .48508 .71098 .49268 .72587 .48861 .71907 .48119 Mtetra
.638 .758 .936 r
.71907 .48119 .72587 .48861 .74084 .48463 .73413 .47744 Mtetra
.63 .763 .943 r
.73413 .47744 .74084 .48463 .75592 .48077 .74928 .47386 Mtetra
.621 .77 .951 r
.74928 .47386 .75592 .48077 .77108 .47704 .76454 .47046 Mtetra
.61 .777 .961 r
.76454 .47046 .77108 .47704 .78635 .47345 .7799 .46726 Mtetra
.596 .785 .97 r
.7799 .46726 .78635 .47345 .80173 .47001 .79538 .46424 Mtetra
.58 .793 .98 r
.79538 .46424 .80173 .47001 .81721 .46672 .81098 .4614 Mtetra
.562 .802 .989 r
.81098 .4614 .81721 .46672 .8328 .46357 .82669 .45872 Mtetra
.542 .811 .996 r
.82669 .45872 .8328 .46357 .84851 .46053 .84252 .45616 Mtetra
.521 .819 .999 r
.84252 .45616 .84851 .46053 .86432 .45758 .85846 .45366 Mtetra
.5 .825 1 r
.85846 .45366 .86432 .45758 .88024 .45467 .87452 .45115 Mtetra
.483 .831 .997 r
.87452 .45115 .88024 .45467 .89627 .45175 .89068 .44857 Mtetra
.471 .838 .992 r
.89068 .44857 .89627 .45175 .9124 .44874 .90693 .44581 Mtetra
.468 .845 .987 r
.90693 .44581 .9124 .44874 .92861 .44557 .92326 .44281 Mtetra
.476 .854 .984 r
.92326 .44281 .92861 .44557 .94491 .44219 .93966 .43946 Mtetra
.494 .865 .983 r
.93966 .43946 .94491 .44219 .96127 .43852 .95611 .4357 Mtetra
.664 .741 .908 r
.37336 .57414 .38141 .58163 .39467 .57758 .38666 .57005 Mtetra
.38666 .57005 .39467 .57758 .408 .57351 .40003 .56594 Mtetra
.40003 .56594 .408 .57351 .42139 .56942 .41347 .56182 Mtetra
.41347 .56182 .42139 .56942 .43486 .56531 .42697 .55767 Mtetra
.42697 .55767 .43486 .56531 .44838 .56118 .44054 .5535 Mtetra
.44054 .5535 .44838 .56118 .46198 .55703 .45418 .54931 Mtetra
.45418 .54931 .46198 .55703 .47564 .55285 .46789 .54509 Mtetra
.663 .741 .908 r
.46789 .54509 .47564 .55285 .48938 .54866 .48167 .54086 Mtetra
.48167 .54086 .48938 .54866 .50318 .54445 .49552 .53661 Mtetra
.49552 .53661 .50318 .54445 .51705 .54021 .50944 .53234 Mtetra
.50944 .53234 .51705 .54021 .531 .53596 .52343 .52806 Mtetra
.663 .742 .908 r
.52343 .52806 .531 .53596 .54501 .53169 .53749 .52375 Mtetra
.663 .742 .909 r
.53749 .52375 .54501 .53169 .5591 .5274 .55162 .51944 Mtetra
.662 .742 .909 r
.55162 .51944 .5591 .5274 .57325 .52311 .56583 .51512 Mtetra
.662 .742 .91 r
.56583 .51512 .57325 .52311 .58748 .5188 .58011 .51079 Mtetra
.661 .743 .91 r
.58011 .51079 .58748 .5188 .60179 .51448 .59446 .50648 Mtetra
.66 .743 .912 r
.59446 .50648 .60179 .51448 .61617 .51017 .60889 .50218 Mtetra
.658 .744 .913 r
.60889 .50218 .61617 .51017 .63063 .50588 .6234 .49791 Mtetra
.656 .745 .915 r
.6234 .49791 .63063 .50588 .64516 .5016 .63799 .4937 Mtetra
.654 .747 .918 r
.63799 .4937 .64516 .5016 .65977 .49737 .65266 .48955 Mtetra
.65 .749 .922 r
.65266 .48955 .65977 .49737 .67447 .49319 .66742 .48549 Mtetra
.645 .752 .927 r
.66742 .48549 .67447 .49319 .68925 .48908 .68226 .48156 Mtetra
.639 .756 .933 r
.68226 .48156 .68925 .48908 .70411 .48508 .6972 .47777 Mtetra
.632 .761 .94 r
.6972 .47777 .70411 .48508 .71907 .48119 .71224 .47416 Mtetra
.622 .766 .949 r
.71224 .47416 .71907 .48119 .73413 .47744 .72737 .47075 Mtetra
.61 .773 .958 r
.72737 .47075 .73413 .47744 .74928 .47386 .74262 .46757 Mtetra
.595 .781 .969 r
.74262 .46757 .74928 .47386 .76454 .47046 .75797 .46462 Mtetra
.576 .789 .98 r
.75797 .46462 .76454 .47046 .7799 .46726 .77345 .46192 Mtetra
.554 .798 .99 r
.77345 .46192 .7799 .46726 .79538 .46424 .78905 .45944 Mtetra
.526 .806 .997 r
.78905 .45944 .79538 .46424 .81098 .4614 .80477 .45717 Mtetra
.495 .811 1 r
.80477 .45717 .81098 .4614 .82669 .45872 .82061 .45505 Mtetra
.46 .814 .997 r
.82061 .45505 .82669 .45872 .84252 .45616 .83658 .45303 Mtetra
.426 .815 .988 r
.83658 .45303 .84252 .45616 .85846 .45366 .85267 .45103 Mtetra
.396 .813 .973 r
.85267 .45103 .85846 .45366 .87452 .45115 .86886 .44895 Mtetra
.375 .813 .957 r
.86886 .44895 .87452 .45115 .89068 .44857 .88515 .44668 Mtetra
.366 .815 .944 r
.88515 .44668 .89068 .44857 .90693 .44581 .90153 .44413 Mtetra
.374 .824 .937 r
.90153 .44413 .90693 .44581 .92326 .44281 .91797 .44118 Mtetra
.398 .84 .937 r
.91797 .44118 .92326 .44281 .93966 .43946 .93447 .43774 Mtetra
.436 .86 .945 r
.93447 .43774 .93966 .43946 .95611 .4357 .951 .43375 Mtetra
.664 .741 .908 r
.36524 .56658 .37336 .57414 .38666 .57005 .37858 .56245 Mtetra
.37858 .56245 .38666 .57005 .40003 .56594 .39199 .55831 Mtetra
.39199 .55831 .40003 .56594 .41347 .56182 .40547 .55414 Mtetra
.40547 .55414 .41347 .56182 .42697 .55767 .41902 .54995 Mtetra
.41902 .54995 .42697 .55767 .44054 .5535 .43263 .54574 Mtetra
.663 .741 .908 r
.43263 .54574 .44054 .5535 .45418 .54931 .44632 .54151 Mtetra
.44632 .54151 .45418 .54931 .46789 .54509 .46007 .53726 Mtetra
.46007 .53726 .46789 .54509 .48167 .54086 .47389 .533 Mtetra
.47389 .533 .48167 .54086 .49552 .53661 .48778 .52871 Mtetra
.48778 .52871 .49552 .53661 .50944 .53234 .50175 .5244 Mtetra
.663 .742 .908 r
.50175 .5244 .50944 .53234 .52343 .52806 .51578 .52009 Mtetra
.663 .742 .909 r
.51578 .52009 .52343 .52806 .53749 .52375 .52989 .51576 Mtetra
.662 .742 .909 r
.52989 .51576 .53749 .52375 .55162 .51944 .54407 .51142 Mtetra
.662 .742 .91 r
.54407 .51142 .55162 .51944 .56583 .51512 .55833 .50709 Mtetra
.661 .743 .911 r
.55833 .50709 .56583 .51512 .58011 .51079 .57266 .50277 Mtetra
.659 .743 .912 r
.57266 .50277 .58011 .51079 .59446 .50648 .58706 .49847 Mtetra
.658 .744 .914 r
.58706 .49847 .59446 .50648 .60889 .50218 .60155 .49421 Mtetra
.655 .746 .916 r
.60155 .49421 .60889 .50218 .6234 .49791 .61611 .49002 Mtetra
.652 .748 .92 r
.61611 .49002 .6234 .49791 .63799 .4937 .63076 .4859 Mtetra
.648 .75 .924 r
.63076 .4859 .63799 .4937 .65266 .48955 .64549 .48191 Mtetra
.642 .753 .93 r
.64549 .48191 .65266 .48955 .66742 .48549 .66031 .47805 Mtetra
.635 .758 .937 r
.66031 .47805 .66742 .48549 .68226 .48156 .67523 .47438 Mtetra
.625 .763 .945 r
.67523 .47438 .68226 .48156 .6972 .47777 .69024 .47092 Mtetra
.613 .769 .955 r
.69024 .47092 .6972 .47777 .71224 .47416 .70536 .4677 Mtetra
.598 .777 .966 r
.70536 .4677 .71224 .47416 .72737 .47075 .72059 .46476 Mtetra
.577 .785 .977 r
.72059 .46476 .72737 .47075 .74262 .46757 .73594 .4621 Mtetra
.551 .793 .988 r
.73594 .4621 .74262 .46757 .75797 .46462 .75141 .45975 Mtetra
.518 .799 .997 r
.75141 .45975 .75797 .46462 .77345 .46192 .76701 .45768 Mtetra
.477 .803 1 r
.76701 .45768 .77345 .46192 .78905 .45944 .78274 .45588 Mtetra
.429 .802 .994 r
.78274 .45588 .78905 .45944 .80477 .45717 .7986 .45427 Mtetra
.376 .794 .976 r
.7986 .45427 .80477 .45717 .82061 .45505 .81459 .45281 Mtetra
.322 .78 .948 r
.81459 .45281 .82061 .45505 .83658 .45303 .83071 .45138 Mtetra
.275 .763 .913 r
.83071 .45138 .83658 .45303 .85267 .45103 .84694 .44989 Mtetra
.241 .749 .879 r
.84694 .44989 .85267 .45103 .86886 .44895 .86327 .44819 Mtetra
.227 .744 .852 r
.86327 .44819 .86886 .44895 .88515 .44668 .8797 .44617 Mtetra
.234 .751 .839 r
.8797 .44617 .88515 .44668 .90153 .44413 .89619 .4437 Mtetra
.264 .771 .842 r
.89619 .4437 .90153 .44413 .91797 .44118 .91274 .44066 Mtetra
.315 .804 .86 r
.91274 .44066 .91797 .44118 .93447 .43774 .92932 .43696 Mtetra
.384 .844 .889 r
.92932 .43696 .93447 .43774 .951 .43375 .94591 .43253 Mtetra
.664 .741 .908 r
.35704 .55894 .36524 .56658 .37858 .56245 .37043 .55478 Mtetra
.37043 .55478 .37858 .56245 .39199 .55831 .38388 .5506 Mtetra
.38388 .5506 .39199 .55831 .40547 .55414 .3974 .54639 Mtetra
.3974 .54639 .40547 .55414 .41902 .54995 .41099 .54216 Mtetra
.663 .741 .908 r
.41099 .54216 .41902 .54995 .43263 .54574 .42465 .53792 Mtetra
.42465 .53792 .43263 .54574 .44632 .54151 .43837 .53365 Mtetra
.43837 .53365 .44632 .54151 .46007 .53726 .45217 .52936 Mtetra
.45217 .52936 .46007 .53726 .47389 .533 .46604 .52506 Mtetra
.46604 .52506 .47389 .533 .48778 .52871 .47998 .52074 Mtetra
.663 .742 .909 r
.47998 .52074 .48778 .52871 .50175 .5244 .49399 .5164 Mtetra
.49399 .5164 .50175 .5244 .51578 .52009 .50807 .51206 Mtetra
.662 .742 .909 r
.50807 .51206 .51578 .52009 .52989 .51576 .52222 .50771 Mtetra
.661 .742 .91 r
.52222 .50771 .52989 .51576 .54407 .51142 .53645 .50337 Mtetra
.66 .743 .911 r
.53645 .50337 .54407 .51142 .55833 .50709 .55076 .49904 Mtetra
.659 .744 .913 r
.55076 .49904 .55833 .50709 .57266 .50277 .56514 .49475 Mtetra
.657 .745 .915 r
.56514 .49475 .57266 .50277 .58706 .49847 .5796 .4905 Mtetra
.654 .746 .918 r
.5796 .4905 .58706 .49847 .60155 .49421 .59413 .48633 Mtetra
.65 .748 .921 r
.59413 .48633 .60155 .49421 .61611 .49002 .60876 .48225 Mtetra
.645 .751 .926 r
.60876 .48225 .61611 .49002 .63076 .4859 .62346 .47832 Mtetra
.638 .755 .933 r
.62346 .47832 .63076 .4859 .64549 .48191 .63826 .47455 Mtetra
.63 .759 .94 r
.63826 .47455 .64549 .48191 .66031 .47805 .65315 .471 Mtetra
.618 .765 .95 r
.65315 .471 .66031 .47805 .67523 .47438 .66814 .4677 Mtetra
.603 .772 .961 r
.66814 .4677 .67523 .47438 .69024 .47092 .68324 .46469 Mtetra
.582 .779 .973 r
.68324 .46469 .69024 .47092 .70536 .4677 .69845 .46201 Mtetra
.555 .787 .985 r
.69845 .46201 .70536 .4677 .72059 .46476 .71379 .45969 Mtetra
.519 .793 .995 r
.71379 .45969 .72059 .46476 .73594 .4621 .72925 .45772 Mtetra
.472 .796 .999 r
.72925 .45772 .73594 .4621 .75141 .45975 .74485 .45611 Mtetra
.413 .791 .992 r
.74485 .45611 .75141 .45975 .76701 .45768 .76058 .45482 Mtetra
.342 .775 .969 r
.76058 .45482 .76701 .45768 .78274 .45588 .77646 .4538 Mtetra
.264 .748 .926 r
.77646 .4538 .78274 .45588 .7986 .45427 .79247 .45296 Mtetra
.188 .711 .869 r
.79247 .45296 .7986 .45427 .81459 .45281 .80862 .45219 Mtetra
.124 .672 .805 r
.80862 .45219 .81459 .45281 .83071 .45138 .8249 .45137 Mtetra
.081 .641 .748 r
.8249 .45137 .83071 .45138 .84694 .44989 .84128 .45034 Mtetra
.062 .626 .707 r
.84128 .45034 .84694 .44989 .86327 .44819 .85776 .44895 Mtetra
0 0 0 r
.85776 .44895 .86327 .44819 .8797 .44617 .87431 .44704 Mtetra
.87431 .44704 .8797 .44617 .89619 .4437 .89091 .44448 Mtetra
.167 .702 .725 r
.89091 .44448 .89619 .4437 .91274 .44066 .90754 .44113 Mtetra
.253 .764 .775 r
.90754 .44113 .91274 .44066 .92932 .43696 .92418 .43693 Mtetra
.357 .831 .835 r
.92418 .43693 .92932 .43696 .94591 .43253 .94081 .43183 Mtetra
.664 .741 .908 r
.34877 .55124 .35704 .55894 .37043 .55478 .36219 .54704 Mtetra
.36219 .54704 .37043 .55478 .38388 .5506 .37569 .54281 Mtetra
.37569 .54281 .38388 .5506 .3974 .54639 .38925 .53857 Mtetra
.663 .741 .908 r
.38925 .53857 .3974 .54639 .41099 .54216 .40288 .53431 Mtetra
.40288 .53431 .41099 .54216 .42465 .53792 .41658 .53002 Mtetra
.41658 .53002 .42465 .53792 .43837 .53365 .43036 .52572 Mtetra
.43036 .52572 .43837 .53365 .45217 .52936 .4442 .52139 Mtetra
.4442 .52139 .45217 .52936 .46604 .52506 .45811 .51706 Mtetra
.663 .742 .909 r
.45811 .51706 .46604 .52506 .47998 .52074 .47209 .5127 Mtetra
.662 .742 .909 r
.47209 .5127 .47998 .52074 .49399 .5164 .48615 .50834 Mtetra
.662 .742 .91 r
.48615 .50834 .49399 .5164 .50807 .51206 .50028 .50398 Mtetra
.661 .742 .91 r
.50028 .50398 .50807 .51206 .52222 .50771 .51448 .49963 Mtetra
.66 .743 .912 r
.51448 .49963 .52222 .50771 .53645 .50337 .52876 .4953 Mtetra
.658 .744 .913 r
.52876 .4953 .53645 .50337 .55076 .49904 .54312 .49101 Mtetra
.656 .745 .916 r
.54312 .49101 .55076 .49904 .56514 .49475 .55755 .48677 Mtetra
.653 .747 .919 r
.55755 .48677 .56514 .49475 .5796 .4905 .57206 .48262 Mtetra
.648 .749 .923 r
.57206 .48262 .5796 .4905 .59413 .48633 .58665 .47859 Mtetra
.642 .752 .928 r
.58665 .47859 .59413 .48633 .60876 .48225 .60133 .47472 Mtetra
.634 .756 .935 r
.60133 .47472 .60876 .48225 .62346 .47832 .6161 .47105 Mtetra
.624 .761 .944 r
.6161 .47105 .62346 .47832 .63826 .47455 .63097 .46762 Mtetra
.61 .767 .955 r
.63097 .46762 .63826 .47455 .65315 .471 .64593 .4645 Mtetra
.59 .774 .967 r
.64593 .4645 .65315 .471 .66814 .4677 .66101 .46172 Mtetra
.564 .781 .98 r
.66101 .46172 .66814 .4677 .68324 .46469 .6762 .45933 Mtetra
.528 .788 .992 r
.6762 .45933 .68324 .46469 .69845 .46201 .69152 .45735 Mtetra
.48 .79 .999 r
.69152 .45735 .69845 .46201 .71379 .45969 .70697 .45581 Mtetra
.414 .784 .994 r
.70697 .45581 .71379 .45969 .72925 .45772 .72256 .4547 Mtetra
.331 .764 .969 r
.72256 .4547 .72925 .45772 .74485 .45611 .7383 .45398 Mtetra
.232 .726 .917 r
.7383 .45398 .74485 .45611 .76058 .45482 .75419 .4536 Mtetra
.128 .669 .839 r
.75419 .4536 .76058 .45482 .77646 .4538 .77022 .45346 Mtetra
.035 .605 .746 r
.77022 .45346 .77646 .4538 .79247 .45296 .7864 .45343 Mtetra
.038 0 0 r
.7864 .45343 .79247 .45296 .80862 .45219 .80272 .45337 Mtetra
.084 0 0 r
.80272 .45337 .80862 .45219 .8249 .45137 .81915 .45309 Mtetra
.101 0 0 r
.81915 .45309 .8249 .45137 .84128 .45034 .83568 .45242 Mtetra
.091 0 0 r
.83568 .45242 .84128 .45034 .85776 .44895 .8523 .45117 Mtetra
.054 0 0 r
.8523 .45117 .85776 .44895 .87431 .44704 .86896 .44917 Mtetra
0 0 0 r
.86896 .44917 .87431 .44704 .89091 .44448 .88565 .44627 Mtetra
.88565 .44627 .89091 .44448 .90754 .44113 .90235 .44236 Mtetra
.233 .743 .712 r
.90235 .44236 .90754 .44113 .92418 .43693 .91902 .43739 Mtetra
.372 .838 .805 r
.91902 .43739 .92418 .43693 .94081 .43183 .93566 .43134 Mtetra
.664 .741 .908 r
.34042 .54347 .34877 .55124 .36219 .54704 .35388 .53922 Mtetra
.35388 .53922 .36219 .54704 .37569 .54281 .36742 .53496 Mtetra
.663 .741 .908 r
.36742 .53496 .37569 .54281 .38925 .53857 .38103 .53068 Mtetra
.38103 .53068 .38925 .53857 .40288 .53431 .3947 .52638 Mtetra
.3947 .52638 .40288 .53431 .41658 .53002 .40845 .52205 Mtetra
.40845 .52205 .41658 .53002 .43036 .52572 .42226 .51771 Mtetra
.42226 .51771 .43036 .52572 .4442 .52139 .43615 .51336 Mtetra
.663 .742 .909 r
.43615 .51336 .4442 .52139 .45811 .51706 .45011 .50899 Mtetra
.662 .742 .909 r
.45011 .50899 .45811 .51706 .47209 .5127 .46414 .50461 Mtetra
.662 .742 .91 r
.46414 .50461 .47209 .5127 .48615 .50834 .47824 .50024 Mtetra
.661 .742 .911 r
.47824 .50024 .48615 .50834 .50028 .50398 .49242 .49588 Mtetra
.659 .743 .912 r
.49242 .49588 .50028 .50398 .51448 .49963 .50667 .49154 Mtetra
.658 .744 .914 r
.50667 .49154 .51448 .49963 .52876 .4953 .52099 .48725 Mtetra
.655 .745 .916 r
.52099 .48725 .52876 .4953 .54312 .49101 .5354 .48302 Mtetra
.651 .747 .92 r
.5354 .48302 .54312 .49101 .55755 .48677 .54988 .4789 Mtetra
.646 .749 .924 r
.54988 .4789 .55755 .48677 .57206 .48262 .56445 .47491 Mtetra
.639 .753 .931 r
.56445 .47491 .57206 .48262 .58665 .47859 .5791 .47111 Mtetra
.63 .757 .938 r
.5791 .47111 .58665 .47859 .60133 .47472 .59384 .46753 Mtetra
.618 .762 .948 r
.59384 .46753 .60133 .47472 .6161 .47105 .60868 .46425 Mtetra
.601 .768 .96 r
.60868 .46425 .6161 .47105 .63097 .46762 .62362 .4613 Mtetra
.577 .775 .973 r
.62362 .4613 .63097 .46762 .64593 .4645 .63866 .45876 Mtetra
.544 .782 .987 r
.63866 .45876 .64593 .4645 .66101 .46172 .65383 .45667 Mtetra
.497 .786 .997 r
.65383 .45667 .66101 .46172 .6762 .45933 .66913 .45507 Mtetra
.431 .781 .997 r
.66913 .45507 .6762 .45933 .69152 .45735 .68457 .45398 Mtetra
.343 .762 .977 r
.68457 .45398 .69152 .45735 .70697 .45581 .70015 .45341 Mtetra
.231 .719 .925 r
.70015 .45341 .70697 .45581 .72256 .4547 .71588 .45331 Mtetra
.104 .65 .835 r
.71588 .45331 .72256 .4547 .7383 .45398 .73178 .45362 Mtetra
0 .563 .719 r
.73178 .45362 .7383 .45398 .75419 .4536 .74783 .45424 Mtetra
.117 0 0 r
.74783 .45424 .75419 .4536 .77022 .45346 .76403 .45503 Mtetra
.187 0 0 r
.76403 .45503 .77022 .45346 .7864 .45343 .78038 .45581 Mtetra
.226 0 0 r
.78038 .45581 .7864 .45343 .80272 .45337 .79686 .45638 Mtetra
.238 0 0 r
.79686 .45638 .80272 .45337 .81915 .45309 .81345 .45653 Mtetra
.226 0 0 r
.81345 .45653 .81915 .45309 .83568 .45242 .83013 .45604 Mtetra
.188 0 0 r
.83013 .45604 .83568 .45242 .8523 .45117 .84686 .45469 Mtetra
.123 0 0 r
.84686 .45469 .8523 .45117 .86896 .44917 .86362 .45231 Mtetra
.026 0 0 r
.86362 .45231 .86896 .44917 .88565 .44627 .88038 .44876 Mtetra
0 0 0 r
.88038 .44876 .88565 .44627 .90235 .44236 .89711 .44398 Mtetra
.267 .761 .694 r
.89711 .44398 .90235 .44236 .91902 .43739 .91379 .43792 Mtetra
.438 .874 .811 r
.91379 .43792 .91902 .43739 .93566 .43134 .9304 .43066 Mtetra
.664 .741 .908 r
.33199 .53562 .34042 .54347 .35388 .53922 .3455 .53134 Mtetra
.663 .741 .908 r
.3455 .53134 .35388 .53922 .36742 .53496 .35908 .52704 Mtetra
.35908 .52704 .36742 .53496 .38103 .53068 .37272 .52271 Mtetra
.37272 .52271 .38103 .53068 .3947 .52638 .38644 .51837 Mtetra
.38644 .51837 .3947 .52638 .40845 .52205 .40023 .51401 Mtetra
.40023 .51401 .40845 .52205 .42226 .51771 .41409 .50964 Mtetra
.663 .742 .909 r
.41409 .50964 .42226 .51771 .43615 .51336 .42802 .50526 Mtetra
.662 .742 .909 r
.42802 .50526 .43615 .51336 .45011 .50899 .44203 .50087 Mtetra
.662 .742 .91 r
.44203 .50087 .45011 .50899 .46414 .50461 .4561 .49648 Mtetra
.66 .743 .911 r
.4561 .49648 .46414 .50461 .47824 .50024 .47025 .49211 Mtetra
.659 .743 .912 r
.47025 .49211 .47824 .50024 .49242 .49588 .48447 .48776 Mtetra
.657 .744 .914 r
.48447 .48776 .49242 .49588 .50667 .49154 .49877 .48347 Mtetra
.654 .745 .917 r
.49877 .48347 .50667 .49154 .52099 .48725 .51315 .47926 Mtetra
.65 .747 .921 r
.51315 .47926 .52099 .48725 .5354 .48302 .5276 .47516 Mtetra
.644 .75 .926 r
.5276 .47516 .5354 .48302 .54988 .4789 .54214 .47122 Mtetra
.637 .753 .933 r
.54214 .47122 .54988 .4789 .56445 .47491 .55676 .46748 Mtetra
.626 .758 .941 r
.55676 .46748 .56445 .47491 .5791 .47111 .57147 .464 Mtetra
.611 .763 .952 r
.57147 .464 .5791 .47111 .59384 .46753 .58628 .46085 Mtetra
.591 .77 .965 r
.58628 .46085 .59384 .46753 .60868 .46425 .60119 .4581 Mtetra
.562 .776 .979 r
.60119 .4581 .60868 .46425 .62362 .4613 .61621 .4558 Mtetra
.52 .781 .992 r
.61621 .4558 .62362 .4613 .63866 .45876 .63135 .45402 Mtetra
.46 .78 .998 r
.63135 .45402 .63866 .45876 .65383 .45667 .64662 .45281 Mtetra
.375 .766 .988 r
.64662 .45281 .65383 .45667 .66913 .45507 .66203 .4522 Mtetra
.259 .727 .946 r
.66203 .4522 .66913 .45507 .68457 .45398 .6776 .45219 Mtetra
.118 .654 .858 r
.6776 .45219 .68457 .45398 .70015 .45341 .69332 .45275 Mtetra
0 .552 .728 r
.69332 .45275 .70015 .45341 .71588 .45331 .70921 .4538 Mtetra
.155 0 0 r
.70921 .4538 .71588 .45331 .73178 .45362 .72527 .45524 Mtetra
.249 0 0 r
.72527 .45524 .73178 .45362 .74783 .45424 .7415 .45692 Mtetra
.307 0 0 r
.7415 .45692 .74783 .45424 .76403 .45503 .75788 .45862 Mtetra
.337 0 0 r
.75788 .45862 .76403 .45503 .78038 .45581 .7744 .46013 Mtetra
.343 0 0 r
.7744 .46013 .78038 .45581 .79686 .45638 .79105 .46118 Mtetra
.329 0 0 r
.79105 .46118 .79686 .45638 .81345 .45653 .80779 .46154 Mtetra
.292 0 0 r
.80779 .46154 .81345 .45653 .83013 .45604 .82459 .46093 Mtetra
.231 0 0 r
.82459 .46093 .83013 .45604 .84686 .45469 .84142 .45917 Mtetra
.14 0 0 r
.84142 .45917 .84686 .45469 .86362 .45231 .85824 .45606 Mtetra
.009 0 0 r
.85824 .45606 .86362 .45231 .88038 .44876 .87503 .45152 Mtetra
0 0 0 r
.87503 .45152 .88038 .44876 .89711 .44398 .89176 .44552 Mtetra
.364 .823 .728 r
.89176 .44552 .89711 .44398 .91379 .43792 .90841 .43808 Mtetra
.549 .93 .847 r
.90841 .43808 .91379 .43792 .9304 .43066 .92498 .42932 Mtetra
.663 .741 .908 r
.32348 .5277 .33199 .53562 .3455 .53134 .33703 .52338 Mtetra
.33703 .52338 .3455 .53134 .35908 .52704 .35065 .51904 Mtetra
.35065 .51904 .35908 .52704 .37272 .52271 .36434 .51468 Mtetra
.36434 .51468 .37272 .52271 .38644 .51837 .3781 .5103 Mtetra
.3781 .5103 .38644 .51837 .40023 .51401 .39194 .50591 Mtetra
.663 .742 .909 r
.39194 .50591 .40023 .51401 .41409 .50964 .40584 .50151 Mtetra
.662 .742 .909 r
.40584 .50151 .41409 .50964 .42802 .50526 .41982 .4971 Mtetra
.661 .742 .91 r
.41982 .4971 .42802 .50526 .44203 .50087 .43387 .4927 Mtetra
.66 .743 .911 r
.43387 .4927 .44203 .50087 .4561 .49648 .44799 .48832 Mtetra
.659 .743 .912 r
.44799 .48832 .4561 .49648 .47025 .49211 .46218 .48397 Mtetra
.656 .744 .915 r
.46218 .48397 .47025 .49211 .48447 .48776 .47645 .47968 Mtetra
.653 .746 .918 r
.47645 .47968 .48447 .48776 .49877 .48347 .4908 .47547 Mtetra
.649 .748 .922 r
.4908 .47547 .49877 .48347 .51315 .47926 .50522 .4714 Mtetra
.642 .75 .927 r
.50522 .4714 .51315 .47926 .5276 .47516 .51973 .4675 Mtetra
.634 .754 .935 r
.51973 .4675 .5276 .47516 .54214 .47122 .53432 .46382 Mtetra
.621 .759 .944 r
.53432 .46382 .54214 .47122 .55676 .46748 .549 .46044 Mtetra
.604 .764 .956 r
.549 .46044 .55676 .46748 .57147 .464 .56377 .45743 Mtetra
.58 .77 .969 r
.56377 .45743 .57147 .464 .58628 .46085 .57865 .45486 Mtetra
.545 .776 .984 r
.57865 .45486 .58628 .46085 .60119 .4581 .59363 .45281 Mtetra
.494 .778 .995 r
.59363 .45281 .60119 .4581 .61621 .4558 .60874 .45135 Mtetra
.419 .771 .996 r
.60874 .45135 .61621 .4558 .63135 .45402 .62398 .45054 Mtetra
.311 .742 .97 r
.62398 .45054 .63135 .45402 .64662 .45281 .63936 .45042 Mtetra
.168 .678 .899 r
.63936 .45042 .64662 .45281 .66203 .4522 .6549 .45099 Mtetra
.003 .574 .772 r
.6549 .45099 .66203 .4522 .6776 .45219 .67061 .45223 Mtetra
.152 0 0 r
.67061 .45223 .6776 .45219 .69332 .45275 .68649 .45406 Mtetra
.272 0 0 r
.68649 .45406 .69332 .45275 .70921 .4538 .70254 .45637 Mtetra
.352 0 0 r
.70254 .45637 .70921 .4538 .72527 .45524 .71878 .45898 Mtetra
.399 0 0 r
.71878 .45898 .72527 .45524 .7415 .45692 .73519 .46168 Mtetra
.42 0 0 r
.73519 .46168 .7415 .45692 .75788 .45862 .75174 .46419 Mtetra
.421 0 0 r
.75174 .46419 .75788 .45862 .7744 .46013 .76844 .46625 Mtetra
.404 0 0 r
.76844 .46625 .7744 .46013 .79105 .46118 .78523 .46753 Mtetra
.37 0 0 r
.78523 .46753 .79105 .46118 .80779 .46154 .8021 .46777 Mtetra
.313 0 0 r
.8021 .46777 .80779 .46154 .82459 .46093 .819 .4667 Mtetra
.228 0 0 r
.819 .4667 .82459 .46093 .84142 .45917 .8359 .46413 Mtetra
.103 0 0 r
.8359 .46413 .84142 .45917 .85824 .45606 .85276 .45991 Mtetra
0 0 0 r
.85276 .45991 .85824 .45606 .87503 .45152 .86955 .45399 Mtetra
.293 .765 .646 r
.86955 .45399 .87503 .45152 .89176 .44552 .88625 .44642 Mtetra
.514 .911 .8 r
.88625 .44642 .89176 .44552 .90841 .43808 .90285 .43731 Mtetra
.679 .977 .889 r
.90285 .43731 .90841 .43808 .92498 .42932 .91934 .42686 Mtetra
.663 .741 .908 r
.31489 .5197 .32348 .5277 .33703 .52338 .32848 .51534 Mtetra
.32848 .51534 .33703 .52338 .35065 .51904 .34215 .51097 Mtetra
.34215 .51097 .35065 .51904 .36434 .51468 .35588 .50657 Mtetra
.35588 .50657 .36434 .51468 .3781 .5103 .36969 .50216 Mtetra
.663 .742 .909 r
.36969 .50216 .3781 .5103 .39194 .50591 .38356 .49774 Mtetra
.662 .742 .909 r
.38356 .49774 .39194 .50591 .40584 .50151 .39751 .49332 Mtetra
.661 .742 .91 r
.39751 .49332 .40584 .50151 .41982 .4971 .41153 .4889 Mtetra
.66 .743 .911 r
.41153 .4889 .41982 .4971 .43387 .4927 .42562 .48451 Mtetra
.658 .743 .913 r
.42562 .48451 .43387 .4927 .44799 .48832 .43979 .48015 Mtetra
.656 .744 .915 r
.43979 .48015 .44799 .48832 .46218 .48397 .45403 .47586 Mtetra
.652 .746 .918 r
.45403 .47586 .46218 .48397 .47645 .47968 .46835 .47166 Mtetra
.647 .748 .923 r
.46835 .47166 .47645 .47968 .4908 .47547 .48274 .46761 Mtetra
.64 .751 .929 r
.48274 .46761 .4908 .47547 .50522 .4714 .49722 .46374 Mtetra
.631 .754 .937 r
.49722 .46374 .50522 .4714 .51973 .4675 .51177 .46013 Mtetra
.617 .759 .947 r
.51177 .46013 .51973 .4675 .53432 .46382 .52642 .45685 Mtetra
.598 .765 .959 r
.52642 .45685 .53432 .46382 .549 .46044 .54115 .45397 Mtetra
.57 .77 .973 r
.54115 .45397 .549 .46044 .56377 .45743 .55599 .45158 Mtetra
.529 .775 .988 r
.55599 .45158 .56377 .45743 .57865 .45486 .57094 .44977 Mtetra
.467 .773 .997 r
.57094 .44977 .57865 .45486 .59363 .45281 .58601 .44862 Mtetra
.375 .757 .989 r
.58601 .44862 .59363 .45281 .60874 .45135 .60121 .44821 Mtetra
.243 .711 .945 r
.60121 .44821 .60874 .45135 .62398 .45054 .61655 .44858 Mtetra
.074 .619 .84 r
.61655 .44858 .62398 .45054 .63936 .45042 .63206 .44974 Mtetra
.106 0 0 r
.63206 .44974 .63936 .45042 .6549 .45099 .64774 .45167 Mtetra
.258 0 0 r
.64774 .45167 .6549 .45099 .67061 .45223 .66359 .45431 Mtetra
.364 0 0 r
.66359 .45431 .67061 .45223 .68649 .45406 .67964 .45752 Mtetra
.43 0 0 r
.67964 .45752 .68649 .45406 .70254 .45637 .69587 .46111 Mtetra
.466 0 0 r
.69587 .46111 .70254 .45637 .71878 .45898 .71229 .46484 Mtetra
.48 0 0 r
.71229 .46484 .71878 .45898 .73519 .46168 .72887 .46843 Mtetra
.477 0 0 r
.72887 .46843 .73519 .46168 .75174 .46419 .7456 .47155 Mtetra
.46 0 0 r
.7456 .47155 .75174 .46419 .76844 .46625 .76245 .47385 Mtetra
.427 0 0 r
.76245 .47385 .76844 .46625 .78523 .46753 .77938 .47502 Mtetra
.375 0 0 r
.77938 .47502 .78523 .46753 .8021 .46777 .79636 .47474 Mtetra
.296 0 0 r
.79636 .47474 .8021 .46777 .819 .4667 .81333 .47277 Mtetra
.176 0 0 r
.81333 .47277 .819 .4667 .8359 .46413 .83026 .46894 Mtetra
.001 0 0 r
.83026 .46894 .8359 .46413 .85276 .45991 .84712 .46319 Mtetra
0 0 0 r
.84712 .46319 .85276 .45991 .86955 .45399 .86387 .45553 Mtetra
.487 .891 .759 r
.86387 .45553 .86955 .45399 .88625 .44642 .88051 .4461 Mtetra
.68 .978 .87 r
.88051 .4461 .88625 .44642 .90285 .43731 .89703 .4351 Mtetra
.784 .981 .905 r
.89703 .4351 .90285 .43731 .91934 .42686 .91343 .42281 Mtetra
.663 .741 .908 r
.30622 .51163 .31489 .5197 .32848 .51534 .31985 .50724 Mtetra
.31985 .50724 .32848 .51534 .34215 .51097 .33356 .50282 Mtetra
.33356 .50282 .34215 .51097 .35588 .50657 .34734 .49839 Mtetra
.663 .742 .909 r
.34734 .49839 .35588 .50657 .36969 .50216 .36119 .49396 Mtetra
.662 .742 .909 r
.36119 .49396 .36969 .50216 .38356 .49774 .37511 .48952 Mtetra
.661 .742 .91 r
.37511 .48952 .38356 .49774 .39751 .49332 .3891 .48509 Mtetra
.66 .743 .911 r
.3891 .48509 .39751 .49332 .41153 .4889 .40316 .48068 Mtetra
.658 .743 .913 r
.40316 .48068 .41153 .4889 .42562 .48451 .4173 .47631 Mtetra
.655 .744 .915 r
.4173 .47631 .42562 .48451 .43979 .48015 .43151 .47202 Mtetra
.652 .746 .919 r
.43151 .47202 .43979 .48015 .45403 .47586 .4458 .46783 Mtetra
.646 .748 .923 r
.4458 .46783 .45403 .47586 .46835 .47166 .46016 .46379 Mtetra
.639 .751 .93 r
.46016 .46379 .46835 .47166 .48274 .46761 .4746 .45996 Mtetra
.628 .755 .938 r
.4746 .45996 .48274 .46761 .49722 .46374 .48912 .4564 Mtetra
.613 .759 .949 r
.48912 .4564 .49722 .46374 .51177 .46013 .50373 .4532 Mtetra
.591 .765 .962 r
.50373 .4532 .51177 .46013 .52642 .45685 .51843 .45044 Mtetra
.559 .77 .977 r
.51843 .45044 .52642 .45685 .54115 .45397 .53322 .44823 Mtetra
.512 .773 .991 r
.53322 .44823 .54115 .45397 .55599 .45158 .54813 .44665 Mtetra
.439 .767 .997 r
.54813 .44665 .55599 .45158 .57094 .44977 .56315 .44581 Mtetra
.329 .74 .979 r
.56315 .44581 .57094 .44977 .58601 .44862 .5783 .44578 Mtetra
.174 .674 .912 r
.5783 .44578 .58601 .44862 .60121 .44821 .59361 .44662 Mtetra
0 .556 .775 r
.59361 .44662 .60121 .44821 .61655 .44858 .60907 .44837 Mtetra
.2 0 0 r
.60907 .44837 .61655 .44858 .63206 .44974 .6247 .451 Mtetra
.342 0 0 r
.6247 .451 .63206 .44974 .64774 .45167 .64053 .45443 Mtetra
.434 0 0 r
.64053 .45443 .64774 .45167 .66359 .45431 .65655 .45855 Mtetra
.488 0 0 r
.65655 .45855 .66359 .45431 .67964 .45752 .67276 .46314 Mtetra
.515 0 0 r
.67276 .46314 .67964 .45752 .69587 .46111 .68917 .46795 Mtetra
.524 .026 .013 r
.68917 .46795 .69587 .46111 .71229 .46484 .70577 .47265 Mtetra
.52 .034 .042 r
.70577 .47265 .71229 .46484 .72887 .46843 .72252 .47689 Mtetra
.502 .024 .051 r
.72252 .47689 .72887 .46843 .7456 .47155 .73941 .48028 Mtetra
.471 0 .041 r
.73941 .48028 .7456 .47155 .76245 .47385 .7564 .48244 Mtetra
.422 0 .008 r
.7564 .48244 .76245 .47385 .77938 .47502 .77344 .48303 Mtetra
.348 0 0 r
.77344 .48303 .77938 .47502 .79636 .47474 .79048 .48174 Mtetra
.233 0 0 r
.79048 .48174 .79636 .47474 .81333 .47277 .80749 .47839 Mtetra
.059 0 0 r
.80749 .47839 .81333 .47277 .83026 .46894 .82442 .47287 Mtetra
0 0 0 r
.82442 .47287 .83026 .46894 .84712 .46319 .84124 .46519 Mtetra
.471 .878 .732 r
.84124 .46519 .84712 .46319 .86387 .45553 .85793 .45547 Mtetra
.688 .981 .86 r
.85793 .45547 .86387 .45553 .88051 .4461 .87448 .44395 Mtetra
.8 .983 .896 r
.87448 .44395 .88051 .4461 .89703 .4351 .8909 .43093 Mtetra
.842 .943 .888 r
.8909 .43093 .89703 .4351 .91343 .42281 .9072 .41677 Mtetra
.663 .741 .908 r
.29746 .50349 .30622 .51163 .31985 .50724 .31114 .49906 Mtetra
.31114 .49906 .31985 .50724 .33356 .50282 .32489 .49461 Mtetra
.663 .742 .909 r
.32489 .49461 .33356 .50282 .34734 .49839 .33871 .49016 Mtetra
.662 .742 .909 r
.33871 .49016 .34734 .49839 .36119 .49396 .3526 .4857 Mtetra
.661 .742 .91 r
.3526 .4857 .36119 .49396 .37511 .48952 .36657 .48125 Mtetra
.66 .743 .911 r
.36657 .48125 .37511 .48952 .3891 .48509 .3806 .47683 Mtetra
.658 .743 .913 r
.3806 .47683 .3891 .48509 .40316 .48068 .39471 .47245 Mtetra
.655 .744 .916 r
.39471 .47245 .40316 .48068 .4173 .47631 .40889 .46815 Mtetra
.651 .746 .919 r
.40889 .46815 .4173 .47631 .43151 .47202 .42314 .46396 Mtetra
.645 .748 .924 r
.42314 .46396 .43151 .47202 .4458 .46783 .43747 .45993 Mtetra
.637 .751 .931 r
.43747 .45993 .4458 .46783 .46016 .46379 .45188 .45613 Mtetra
.626 .755 .939 r
.45188 .45613 .46016 .46379 .4746 .45996 .46637 .45262 Mtetra
.609 .759 .951 r
.46637 .45262 .4746 .45996 .48912 .4564 .48093 .4495 Mtetra
.585 .765 .964 r
.48093 .4495 .48912 .4564 .50373 .4532 .49559 .44685 Mtetra
.549 .769 .979 r
.49559 .44685 .50373 .4532 .51843 .45044 .51034 .44479 Mtetra
.495 .77 .993 r
.51034 .44479 .51843 .45044 .53322 .44823 .5252 .44343 Mtetra
.412 .759 .995 r
.5252 .44343 .53322 .44823 .54813 .44665 .54017 .44286 Mtetra
.285 .721 .966 r
.54017 .44286 .54813 .44665 .56315 .44581 .55527 .4432 Mtetra
.109 .635 .877 r
.55527 .4432 .56315 .44581 .5783 .44578 .57052 .4445 Mtetra
0 .493 .711 r
.57052 .4445 .5783 .44578 .59361 .44662 .58593 .4468 Mtetra
.278 0 0 r
.58593 .4468 .59361 .44662 .60907 .44837 .60151 .4501 Mtetra
.407 0 0 r
.60151 .4501 .60907 .44837 .6247 .451 .61728 .45433 Mtetra
.487 0 0 r
.61728 .45433 .6247 .451 .64053 .45443 .63326 .45934 Mtetra
.531 .005 0 r
.63326 .45934 .64053 .45443 .65655 .45855 .64944 .46493 Mtetra
.553 .051 .017 r
.64944 .46493 .65655 .45855 .67276 .46314 .66583 .47081 Mtetra
.558 .075 .064 r
.66583 .47081 .67276 .46314 .68917 .46795 .68242 .47665 Mtetra
.552 .081 .089 r
.68242 .47665 .68917 .46795 .70577 .47265 .69919 .48205 Mtetra
.535 .07 .096 r
.69919 .48205 .70577 .47265 .72252 .47689 .7161 .48657 Mtetra
.505 .041 .085 r
.7161 .48657 .72252 .47689 .73941 .48028 .73313 .48979 Mtetra
.459 0 .053 r
.73313 .48979 .73941 .48028 .7564 .48244 .75022 .4913 Mtetra
.388 0 0 r
.75022 .4913 .7564 .48244 .77344 .48303 .76733 .49078 Mtetra
.277 0 0 r
.76733 .49078 .77344 .48303 .79048 .48174 .78441 .48798 Mtetra
.102 0 0 r
.78441 .48798 .79048 .48174 .80749 .47839 .80141 .48276 Mtetra
0 0 0 r
.80141 .48276 .80749 .47839 .82442 .47287 .81831 .47512 Mtetra
.47 .876 .723 r
.81831 .47512 .82442 .47287 .84124 .46519 .83506 .46519 Mtetra
.705 .985 .859 r
.83506 .46519 .84124 .46519 .85793 .45547 .85166 .45319 Mtetra
.818 .98 .89 r
.85166 .45319 .85793 .45547 .87448 .44395 .86811 .43947 Mtetra
.855 .934 .876 r
.86811 .43947 .87448 .44395 .8909 .43093 .88443 .42442 Mtetra
.859 .885 .854 r
.88443 .42442 .8909 .43093 .9072 .41677 .90064 .40847 Mtetra
.663 .741 .908 r
.28862 .49528 .29746 .50349 .31114 .49906 .30234 .49081 Mtetra
.662 .742 .909 r
.30234 .49081 .31114 .49906 .32489 .49461 .31613 .48634 Mtetra
.31613 .48634 .32489 .49461 .33871 .49016 .33 .48186 Mtetra
.661 .742 .91 r
.33 .48186 .33871 .49016 .3526 .4857 .34393 .4774 Mtetra
.66 .743 .911 r
.34393 .4774 .3526 .4857 .36657 .48125 .35794 .47296 Mtetra
.658 .743 .913 r
.35794 .47296 .36657 .48125 .3806 .47683 .37202 .46857 Mtetra
.655 .744 .916 r
.37202 .46857 .3806 .47683 .39471 .47245 .38617 .46426 Mtetra
.65 .746 .92 r
.38617 .46426 .39471 .47245 .40889 .46815 .40039 .46007 Mtetra
.644 .748 .925 r
.40039 .46007 .40889 .46815 .42314 .46396 .41469 .45604 Mtetra
.636 .751 .931 r
.41469 .45604 .42314 .46396 .43747 .45993 .42906 .45226 Mtetra
.624 .755 .941 r
.42906 .45226 .43747 .45993 .45188 .45613 .4435 .44879 Mtetra
.606 .759 .952 r
.4435 .44879 .45188 .45613 .46637 .45262 .45803 .44572 Mtetra
.58 .764 .966 r
.45803 .44572 .46637 .45262 .48093 .4495 .47264 .44317 Mtetra
.541 .768 .981 r
.47264 .44317 .48093 .4495 .49559 .44685 .48735 .44124 Mtetra
.481 .766 .994 r
.48735 .44124 .49559 .44685 .51034 .44479 .50215 .44007 Mtetra
.387 .75 .992 r
.50215 .44007 .51034 .44479 .5252 .44343 .51707 .43976 Mtetra
.245 .701 .952 r
.51707 .43976 .5252 .44343 .54017 .44286 .53211 .44042 Mtetra
.051 .596 .842 r
.53211 .44042 .54017 .44286 .55527 .4432 .54729 .44214 Mtetra
.161 0 0 r
.54729 .44214 .55527 .4432 .57052 .4445 .56264 .44497 Mtetra
.338 0 0 r
.56264 .44497 .57052 .4445 .58593 .4468 .57816 .4489 Mtetra
.456 0 0 r
.57816 .4489 .58593 .4468 .60151 .4501 .59387 .45387 Mtetra
.526 0 0 r
.59387 .45387 .60151 .4501 .61728 .45433 .60978 .45974 Mtetra
.564 .051 0 r
.60978 .45974 .61728 .45433 .63326 .45934 .62591 .46629 Mtetra
.581 .092 .058 r
.62591 .46629 .63326 .45934 .64944 .46493 .64226 .47324 Mtetra
.585 .113 .1 r
.64226 .47324 .64944 .46493 .66583 .47081 .65882 .48021 Mtetra
.578 .117 .122 r
.65882 .48021 .66583 .47081 .68242 .47665 .67558 .48676 Mtetra
.561 .106 .128 r
.67558 .48676 .68242 .47665 .69919 .48205 .6925 .49243 Mtetra
.533 .077 .116 r
.6925 .49243 .69919 .48205 .7161 .48657 .70955 .49675 Mtetra
.488 .027 .084 r
.70955 .49675 .7161 .48657 .73313 .48979 .72668 .49925 Mtetra
.42 0 .024 r
.72668 .49925 .73313 .48979 .75022 .4913 .74385 .49955 Mtetra
.31 0 0 r
.74385 .49955 .75022 .4913 .76733 .49078 .761 .49737 Mtetra
.131 0 0 r
.761 .49737 .76733 .49078 .78441 .48798 .77808 .49253 Mtetra
0 0 0 r
.77808 .49253 .78441 .48798 .80141 .48276 .79504 .48501 Mtetra
.486 .886 .734 r
.79504 .48501 .80141 .48276 .81831 .47512 .81187 .47493 Mtetra
.73 .99 .867 r
.81187 .47493 .81831 .47512 .83506 .46519 .82853 .46252 Mtetra
.835 .971 .886 r
.82853 .46252 .83506 .46519 .85166 .45319 .84503 .44816 Mtetra
.864 .918 .864 r
.84503 .44816 .85166 .45319 .86811 .43947 .86138 .43227 Mtetra
.865 .867 .839 r
.86138 .43227 .86811 .43947 .88443 .42442 .8776 .41531 Mtetra
.855 .827 .819 r
.8776 .41531 .88443 .42442 .90064 .40847 .89374 .39778 Mtetra
.662 .742 .909 r
.2797 .48699 .28862 .49528 .30234 .49081 .29346 .4825 Mtetra
.29346 .4825 .30234 .49081 .31613 .48634 .30729 .478 Mtetra
.661 .742 .91 r
.30729 .478 .31613 .48634 .33 .48186 .3212 .47352 Mtetra
.659 .743 .911 r
.3212 .47352 .33 .48186 .34393 .4774 .33517 .46906 Mtetra
.657 .743 .913 r
.33517 .46906 .34393 .4774 .35794 .47296 .34922 .46466 Mtetra
.654 .744 .916 r
.34922 .46466 .35794 .47296 .37202 .46857 .36334 .46034 Mtetra
.65 .746 .92 r
.36334 .46034 .37202 .46857 .38617 .46426 .37753 .45614 Mtetra
.644 .748 .925 r
.37753 .45614 .38617 .46426 .40039 .46007 .39179 .45211 Mtetra
.635 .751 .932 r
.39179 .45211 .40039 .46007 .41469 .45604 .40613 .44834 Mtetra
.622 .754 .941 r
.40613 .44834 .41469 .45604 .42906 .45226 .42054 .44489 Mtetra
.603 .759 .953 r
.42054 .44489 .42906 .45226 .4435 .44879 .43502 .44187 Mtetra
.576 .763 .967 r
.43502 .44187 .4435 .44879 .45803 .44572 .44959 .43939 Mtetra
.534 .766 .983 r
.44959 .43939 .45803 .44572 .47264 .44317 .46424 .43758 Mtetra
.468 .763 .994 r
.46424 .43758 .47264 .44317 .48735 .44124 .47899 .43656 Mtetra
.366 .742 .989 r
.47899 .43656 .48735 .44124 .50215 .44007 .49385 .43646 Mtetra
.211 .683 .939 r
.49385 .43646 .50215 .44007 .51707 .43976 .50882 .43741 Mtetra
.004 .563 .811 r
.50882 .43741 .51707 .43976 .53211 .44042 .52394 .4395 Mtetra
.212 0 0 r
.52394 .4395 .53211 .44042 .54729 .44214 .5392 .44279 Mtetra
.383 0 0 r
.5392 .44279 .54729 .44214 .56264 .44497 .55464 .44729 Mtetra
.493 0 0 r
.55464 .44729 .56264 .44497 .57816 .4489 .57028 .45294 Mtetra
.556 .022 0 r
.57028 .45294 .57816 .4489 .59387 .45387 .58612 .45961 Mtetra
.589 .085 .025 r
.58612 .45961 .59387 .45387 .60978 .45974 .60218 .46708 Mtetra
.604 .123 .086 r
.60218 .46708 .60978 .45974 .62591 .46629 .61847 .47504 Mtetra
.607 .142 .125 r
.61847 .47504 .62591 .46629 .64226 .47324 .63498 .48309 Mtetra
.599 .145 .145 r
.63498 .48309 .64226 .47324 .65882 .48021 .65169 .49078 Mtetra
.583 .133 .149 r
.65169 .49078 .65882 .48021 .67558 .48676 .6686 .49759 Mtetra
.555 .105 .137 r
.6686 .49759 .67558 .48676 .6925 .49243 .68565 .50301 Mtetra
.513 .056 .104 r
.68565 .50301 .6925 .49243 .70955 .49675 .70281 .50652 Mtetra
.445 0 .043 r
.70281 .50652 .70955 .49675 .72668 .49925 .72002 .5077 Mtetra
.336 0 0 r
.72002 .5077 .72668 .49925 .74385 .49955 .73723 .5062 Mtetra
.149 0 0 r
.73723 .5062 .74385 .49955 .761 .49737 .75438 .50181 Mtetra
0 0 0 r
.75438 .50181 .761 .49737 .77808 .49253 .77142 .49449 Mtetra
.517 .906 .765 r
.77142 .49449 .77808 .49253 .79504 .48501 .78832 .48434 Mtetra
.758 .992 .881 r
.78832 .48434 .79504 .48501 .81187 .47493 .80505 .47162 Mtetra
.848 .956 .881 r
.80505 .47162 .81187 .47493 .82853 .46252 .82162 .45668 Mtetra
.868 .897 .852 r
.82162 .45668 .82853 .46252 .84503 .44816 .83801 .44002 Mtetra
.865 .846 .823 r
.83801 .44002 .84503 .44816 .86138 .43227 .85427 .42212 Mtetra
.855 .807 .802 r
.85427 .42212 .86138 .43227 .8776 .41531 .87042 .40353 Mtetra
.843 .777 .789 r
.87042 .40353 .8776 .41531 .89374 .39778 .88651 .38474 Mtetra
.662 .742 .909 r
.27068 .47864 .2797 .48699 .29346 .4825 .28449 .47413 Mtetra
.661 .742 .91 r
.28449 .47413 .29346 .4825 .30729 .478 .29836 .46963 Mtetra
.659 .743 .911 r
.29836 .46963 .30729 .478 .3212 .47352 .31231 .46515 Mtetra
.657 .743 .913 r
.31231 .46515 .3212 .47352 .33517 .46906 .32633 .46073 Mtetra
.654 .744 .916 r
.32633 .46073 .33517 .46906 .34922 .46466 .34041 .45639 Mtetra
.65 .746 .92 r
.34041 .45639 .34922 .46466 .36334 .46034 .35457 .45217 Mtetra
.643 .748 .925 r
.35457 .45217 .36334 .46034 .37753 .45614 .3688 .44814 Mtetra
.634 .751 .932 r
.3688 .44814 .37753 .45614 .39179 .45211 .3831 .44437 Mtetra
.621 .754 .941 r
.3831 .44437 .39179 .45211 .40613 .44834 .39747 .44093 Mtetra
.601 .758 .954 r
.39747 .44093 .40613 .44834 .42054 .44489 .41191 .43794 Mtetra
.573 .762 .968 r
.41191 .43794 .42054 .44489 .43502 .44187 .42643 .43551 Mtetra
.528 .764 .983 r
.42643 .43551 .43502 .44187 .44959 .43939 .44103 .43377 Mtetra
.459 .759 .994 r
.44103 .43377 .44959 .43939 .46424 .43758 .45572 .43287 Mtetra
.351 .734 .986 r
.45572 .43287 .46424 .43758 .47899 .43656 .47051 .43294 Mtetra
.186 .667 .929 r
.47051 .43294 .47899 .43656 .49385 .43646 .48542 .43413 Mtetra
0 .536 .789 r
.48542 .43413 .49385 .43646 .50882 .43741 .50045 .43652 Mtetra
.249 0 0 r
.50045 .43652 .50882 .43741 .52394 .4395 .51563 .44021 Mtetra
.416 0 0 r
.51563 .44021 .52394 .4395 .5392 .44279 .53098 .4452 Mtetra
.519 0 0 r
.53098 .4452 .5392 .44279 .55464 .44729 .54652 .45145 Mtetra
.578 .051 0 r
.54652 .45145 .55464 .44729 .57028 .45294 .56227 .45883 Mtetra
.608 .111 .046 r
.56227 .45883 .57028 .45294 .58612 .45961 .57824 .46713 Mtetra
.622 .147 .104 r
.57824 .46713 .58612 .45961 .60218 .46708 .59445 .47601 Mtetra
.624 .164 .141 r
.59445 .47601 .60218 .46708 .61847 .47504 .61088 .48508 Mtetra
.617 .167 .159 r
.61088 .48508 .61847 .47504 .63498 .48309 .62754 .49384 Mtetra
.601 .155 .162 r
.62754 .49384 .63498 .48309 .65169 .49078 .64441 .50176 Mtetra
.575 .126 .148 r
.64441 .50176 .65169 .49078 .6686 .49759 .66144 .50826 Mtetra
.533 .076 .114 r
.66144 .50826 .6686 .49759 .68565 .50301 .6786 .51278 Mtetra
.466 0 .05 r
.6786 .51278 .68565 .50301 .70281 .50652 .69584 .51486 Mtetra
.354 0 0 r
.69584 .51486 .70281 .50652 .72002 .5077 .71309 .51408 Mtetra
.156 0 0 r
.71309 .51408 .72002 .5077 .73723 .5062 .7303 .51022 Mtetra
0 0 0 r
.7303 .51022 .73723 .5062 .75438 .50181 .74741 .50318 Mtetra
.563 .933 .813 r
.74741 .50318 .75438 .50181 .77142 .49449 .76439 .49306 Mtetra
.785 .986 .896 r
.76439 .49306 .77142 .49449 .78832 .48434 .78121 .48011 Mtetra
.855 .933 .876 r
.78121 .48011 .78832 .48434 .80505 .47162 .79784 .46471 Mtetra
.867 .871 .838 r
.79784 .46471 .80505 .47162 .82162 .45668 .81431 .44736 Mtetra
.861 .821 .808 r
.81431 .44736 .82162 .45668 .83801 .44002 .83062 .42861 Mtetra
.851 .784 .786 r
.83062 .42861 .83801 .44002 .85427 .42212 .8468 .40904 Mtetra
.839 .758 .773 r
.8468 .40904 .85427 .42212 .87042 .40353 .86291 .38918 Mtetra
.827 .738 .766 r
.86291 .38918 .87042 .40353 .88651 .38474 .87899 .36953 Mtetra
.661 .742 .91 r
.26158 .47023 .27068 .47864 .28449 .47413 .27543 .46571 Mtetra
.659 .743 .911 r
.27543 .46571 .28449 .47413 .29836 .46963 .28934 .46121 Mtetra
.657 .743 .913 r
.28934 .46121 .29836 .46963 .31231 .46515 .30333 .45677 Mtetra
.654 .744 .916 r
.30333 .45677 .31231 .46515 .32633 .46073 .31738 .45241 Mtetra
.65 .746 .92 r
.31738 .45241 .32633 .46073 .34041 .45639 .33151 .44818 Mtetra
.643 .748 .925 r
.33151 .44818 .34041 .45639 .35457 .45217 .3457 .44413 Mtetra
.634 .75 .932 r
.3457 .44413 .35457 .45217 .3688 .44814 .35996 .44034 Mtetra
.62 .754 .941 r
.35996 .44034 .3688 .44814 .3831 .44437 .37429 .4369 Mtetra
.6 .757 .954 r
.37429 .4369 .3831 .44437 .39747 .44093 .38869 .43392 Mtetra
.571 .761 .968 r
.38869 .43392 .39747 .44093 .41191 .43794 .40316 .43151 Mtetra
.525 .762 .984 r
.40316 .43151 .41191 .43794 .42643 .43551 .41771 .42982 Mtetra
.454 .756 .994 r
.41771 .42982 .42643 .43551 .44103 .43377 .43234 .42899 Mtetra
.341 .729 .985 r
.43234 .42899 .44103 .43377 .45572 .43287 .44706 .42919 Mtetra
.171 .657 .924 r
.44706 .42919 .45572 .43287 .47051 .43294 .46189 .43054 Mtetra
0 .519 .777 r
.46189 .43054 .47051 .43294 .48542 .43413 .47684 .43317 Mtetra
.272 0 0 r
.47684 .43317 .48542 .43413 .50045 .43652 .49193 .43716 Mtetra
.436 0 0 r
.49193 .43716 .50045 .43652 .51563 .44021 .50718 .44255 Mtetra
.537 0 0 r
.50718 .44255 .51563 .44021 .53098 .4452 .52262 .4493 Mtetra
.594 .07 0 r
.52262 .4493 .53098 .4452 .54652 .45145 .53826 .45728 Mtetra
.623 .129 .057 r
.53826 .45728 .54652 .45145 .56227 .45883 .55412 .46629 Mtetra
.636 .164 .114 r
.55412 .46629 .56227 .45883 .57824 .46713 .57022 .47599 Mtetra
.639 .18 .148 r
.57022 .47599 .57824 .46713 .59445 .47601 .58656 .48596 Mtetra
.632 .183 .166 r
.58656 .48596 .59445 .47601 .61088 .48508 .60314 .49571 Mtetra
.617 .17 .167 r
.60314 .49571 .61088 .48508 .62754 .49384 .61993 .50465 Mtetra
.592 .142 .152 r
.61993 .50465 .62754 .49384 .64441 .50176 .63692 .51217 Mtetra
.551 .091 .115 r
.63692 .51217 .64441 .50176 .66144 .50826 .65406 .51769 Mtetra
.484 .006 .046 r
.65406 .51769 .66144 .50826 .6786 .51278 .6713 .52065 Mtetra
.367 0 0 r
.6713 .52065 .6786 .51278 .69584 .51486 .68857 .52064 Mtetra
.151 0 0 r
.68857 .52064 .69584 .51486 .71309 .51408 .70583 .51735 Mtetra
0 0 0 r
.70583 .51735 .71309 .51408 .7303 .51022 .72301 .51068 Mtetra
.615 .958 .868 r
.72301 .51068 .7303 .51022 .74741 .50318 .74007 .50068 Mtetra
.805 .969 .907 r
.74007 .50068 .74741 .50318 .76439 .49306 .75697 .48761 Mtetra
.856 .903 .867 r
.75697 .48761 .76439 .49306 .78121 .48011 .77369 .47186 Mtetra
.861 .841 .824 r
.77369 .47186 .78121 .48011 .79784 .46471 .79024 .45396 Mtetra
.854 .795 .792 r
.79024 .45396 .79784 .46471 .81431 .44736 .80662 .43448 Mtetra
.843 .761 .771 r
.80662 .43448 .81431 .44736 .83062 .42861 .82286 .41404 Mtetra
.833 .737 .758 r
.82286 .41404 .83062 .42861 .8468 .40904 .83901 .39322 Mtetra
.822 .72 .752 r
.83901 .39322 .8468 .40904 .86291 .38918 .85511 .37255 Mtetra
.812 .708 .75 r
.85511 .37255 .86291 .38918 .87899 .36953 .87122 .35248 Mtetra
.66 .742 .911 r
.25239 .46177 .26158 .47023 .27543 .46571 .26627 .45725 Mtetra
.657 .743 .913 r
.26627 .45725 .27543 .46571 .28934 .46121 .28023 .45278 Mtetra
.654 .744 .916 r
.28023 .45278 .28934 .46121 .30333 .45677 .29425 .4484 Mtetra
.65 .745 .919 r
.29425 .4484 .30333 .45677 .31738 .45241 .30834 .44414 Mtetra
.643 .747 .925 r
.30834 .44414 .31738 .45241 .33151 .44818 .3225 .44007 Mtetra
.634 .75 .932 r
.3225 .44007 .33151 .44818 .3457 .44413 .33672 .43626 Mtetra
.62 .753 .941 r
.33672 .43626 .3457 .44413 .35996 .44034 .35101 .4328 Mtetra
.6 .757 .953 r
.35101 .4328 .35996 .44034 .37429 .4369 .36537 .4298 Mtetra
.571 .76 .968 r
.36537 .4298 .37429 .4369 .38869 .43392 .37979 .42739 Mtetra
.525 .761 .983 r
.37979 .42739 .38869 .43392 .40316 .43151 .39428 .42571 Mtetra
.453 .754 .994 r
.39428 .42571 .40316 .43151 .41771 .42982 .40885 .42492 Mtetra
.339 .725 .984 r
.40885 .42492 .41771 .42982 .43234 .42899 .42351 .42517 Mtetra
.167 .652 .924 r
.42351 .42517 .43234 .42899 .44706 .42919 .43826 .42662 Mtetra
0 .512 .776 r
.43826 .42662 .44706 .42919 .46189 .43054 .45312 .4294 Mtetra
.281 0 0 r
.45312 .4294 .46189 .43054 .47684 .43317 .46811 .43361 Mtetra
.447 0 0 r
.46811 .43361 .47684 .43317 .49193 .43716 .48326 .43929 Mtetra
.548 0 0 r
.48326 .43929 .49193 .43716 .50718 .44255 .49857 .44641 Mtetra
.605 .081 0 r
.49857 .44641 .50718 .44255 .52262 .4493 .51409 .45487 Mtetra
.634 .14 .059 r
.51409 .45487 .52262 .4493 .53826 .45728 .52983 .46444 Mtetra
.648 .174 .115 r
.52983 .46444 .53826 .45728 .55412 .46629 .5458 .47482 Mtetra
.651 .191 .149 r
.5458 .47482 .55412 .46629 .57022 .47599 .56203 .48556 Mtetra
.645 .194 .165 r
.56203 .48556 .57022 .47599 .58656 .48596 .57849 .49616 Mtetra
.631 .181 .165 r
.57849 .49616 .58656 .48596 .60314 .49571 .5952 .50601 Mtetra
.606 .152 .148 r
.5952 .50601 .60314 .49571 .61993 .50465 .61211 .51447 Mtetra
.566 .1 .107 r
.61211 .51447 .61993 .50465 .63692 .51217 .6292 .52091 Mtetra
.498 .011 .03 r
.6292 .52091 .63692 .51217 .65406 .51769 .64642 .52475 Mtetra
.374 0 0 r
.64642 .52475 .65406 .51769 .6713 .52065 .6637 .5255 Mtetra
.132 0 0 r
.6637 .5255 .6713 .52065 .68857 .52064 .68099 .52283 Mtetra
.284 .775 .714 r
.68099 .52283 .68857 .52064 .70583 .51735 .69823 .51659 Mtetra
.665 .968 .918 r
.69823 .51659 .70583 .51735 .72301 .51068 .71536 .50682 Mtetra
.814 .939 .91 r
.71536 .50682 .72301 .51068 .74007 .50068 .73234 .49375 Mtetra
.849 .868 .855 r
.73234 .49375 .74007 .50068 .75697 .48761 .74916 .47779 Mtetra
.85 .809 .81 r
.74916 .47779 .75697 .48761 .77369 .47186 .76579 .45947 Mtetra
.843 .767 .778 r
.76579 .45947 .77369 .47186 .79024 .45396 .78226 .4394 Mtetra
.834 .737 .758 r
.78226 .4394 .79024 .45396 .80662 .43448 .79858 .41823 Mtetra
.825 .716 .745 r
.79858 .41823 .80662 .43448 .82286 .41404 .81479 .39659 Mtetra
.816 .702 .739 r
.81479 .39659 .82286 .41404 .83901 .39322 .83094 .37503 Mtetra
.807 .692 .738 r
.83094 .37503 .83901 .39322 .85511 .37255 .84708 .35405 Mtetra
.798 .686 .741 r
.84708 .35405 .85511 .37255 .87122 .35248 .86326 .33403 Mtetra
.658 .743 .913 r
.2431 .45327 .25239 .46177 .26627 .45725 .25702 .44878 Mtetra
.655 .744 .915 r
.25702 .44878 .26627 .45725 .28023 .45278 .27101 .44436 Mtetra
.65 .745 .919 r
.27101 .44436 .28023 .45278 .29425 .4484 .28507 .44008 Mtetra
.644 .747 .924 r
.28507 .44008 .29425 .4484 .30834 .44414 .29919 .43597 Mtetra
.634 .749 .931 r
.29919 .43597 .30834 .44414 .3225 .44007 .31338 .43213 Mtetra
.621 .752 .94 r
.31338 .43213 .3225 .44007 .33672 .43626 .32763 .42863 Mtetra
.601 .756 .952 r
.32763 .42863 .33672 .43626 .35101 .4328 .34194 .4256 Mtetra
.572 .759 .966 r
.34194 .4256 .35101 .4328 .36537 .4298 .35632 .42316 Mtetra
.527 .759 .982 r
.35632 .42316 .36537 .4298 .37979 .42739 .37075 .42145 Mtetra
.456 .752 .993 r
.37075 .42145 .37979 .42739 .39428 .42571 .38526 .42064 Mtetra
.344 .724 .985 r
.38526 .42064 .39428 .42571 .40885 .42492 .39985 .4209 Mtetra
.173 .652 .928 r
.39985 .4209 .40885 .42492 .42351 .42517 .41452 .42238 Mtetra
0 .515 .787 r
.41452 .42238 .42351 .42517 .43826 .42662 .42929 .42522 Mtetra
.277 0 0 r
.42929 .42522 .43826 .42662 .45312 .4294 .44418 .42954 Mtetra
.447 0 0 r
.44418 .42954 .45312 .4294 .46811 .43361 .45921 .43538 Mtetra
.552 0 0 r
.45921 .43538 .46811 .43361 .48326 .43929 .47441 .44274 Mtetra
.611 .084 0 r
.47441 .44274 .48326 .43929 .49857 .44641 .48979 .45152 Mtetra
.642 .144 .052 r
.48979 .45152 .49857 .44641 .51409 .45487 .50539 .46151 Mtetra
.657 .18 .108 r
.50539 .46151 .51409 .45487 .52983 .46444 .52122 .47239 Mtetra
.661 .197 .142 r
.52122 .47239 .52983 .46444 .5458 .47482 .53731 .48374 Mtetra
.656 .2 .157 r
.53731 .48374 .5458 .47482 .56203 .48556 .55364 .49503 Mtetra
.643 .187 .156 r
.55364 .49503 .56203 .48556 .57849 .49616 .57023 .50564 Mtetra
.619 .158 .136 r
.57023 .50564 .57849 .49616 .5952 .50601 .58705 .51492 Mtetra
.579 .103 .089 r
.58705 .51492 .5952 .50601 .61211 .51447 .60406 .52219 Mtetra
.508 .007 .001 r
.60406 .52219 .61211 .51447 .6292 .52091 .62123 .52683 Mtetra
.372 0 0 r
.62123 .52683 .6292 .52091 .64642 .52475 .63849 .52833 Mtetra
.095 0 0 r
.63849 .52833 .64642 .52475 .6637 .5255 .65579 .52629 Mtetra
.361 .833 .821 r
.65579 .52629 .6637 .5255 .68099 .52283 .67307 .52055 Mtetra
.701 .955 .95 r
.67307 .52055 .68099 .52283 .69823 .51659 .69026 .5111 Mtetra
.812 .9 .903 r
.69026 .5111 .69823 .51659 .71536 .50682 .70733 .49816 Mtetra
.836 .83 .841 r
.70733 .49816 .71536 .50682 .73234 .49375 .72424 .48214 Mtetra
.836 .777 .795 r
.72424 .48214 .73234 .49375 .74916 .47779 .74097 .46357 Mtetra
.83 .74 .765 r
.74097 .46357 .74916 .47779 .76579 .45947 .75754 .44308 Mtetra
.823 .714 .745 r
.75754 .44308 .76579 .45947 .78226 .4394 .77395 .42136 Mtetra
.815 .696 .733 r
.77395 .42136 .78226 .4394 .79858 .41823 .79025 .39904 Mtetra
.808 .684 .728 r
.79025 .39904 .79858 .41823 .81479 .39659 .80647 .37675 Mtetra
.8 .676 .727 r
.80647 .37675 .81479 .39659 .83094 .37503 .82266 .355 Mtetra
.793 .671 .73 r
.82266 .355 .83094 .37503 .84708 .35405 .83888 .33419 Mtetra
.786 .67 .736 r
.83888 .33419 .84708 .35405 .86326 .33403 .85516 .31464 Mtetra
.655 .744 .915 r
.23371 .44474 .2431 .45327 .25702 .44878 .24767 .4403 Mtetra
.651 .745 .919 r
.24767 .4403 .25702 .44878 .27101 .44436 .26169 .43598 Mtetra
.644 .747 .923 r
.26169 .43598 .27101 .44436 .28507 .44008 .27578 .43184 Mtetra
.635 .749 .93 r
.27578 .43184 .28507 .44008 .29919 .43597 .28993 .42795 Mtetra
.622 .751 .939 r
.28993 .42795 .29919 .43597 .31338 .43213 .30414 .4244 Mtetra
.603 .755 .951 r
.30414 .4244 .31338 .43213 .32763 .42863 .31841 .42131 Mtetra
.574 .757 .965 r
.31841 .42131 .32763 .42863 .34194 .4256 .33274 .41881 Mtetra
.531 .758 .98 r
.33274 .41881 .34194 .4256 .35632 .42316 .34713 .41704 Mtetra
.463 .751 .992 r
.34713 .41704 .35632 .42316 .37075 .42145 .36157 .41617 Mtetra
.355 .725 .987 r
.36157 .41617 .37075 .42145 .38526 .42064 .37609 .41637 Mtetra
.19 .658 .937 r
.37609 .41637 .38526 .42064 .39985 .4209 .39068 .4178 Mtetra
0 .527 .807 r
.39068 .4178 .39985 .4209 .41452 .42238 .40536 .42061 Mtetra
.259 0 0 r
.40536 .42061 .41452 .42238 .42929 .42522 .42015 .42493 Mtetra
.437 0 0 r
.42015 .42493 .42929 .42522 .44418 .42954 .43506 .43081 Mtetra
.548 0 0 r
.43506 .43081 .44418 .42954 .45921 .43538 .45013 .43827 Mtetra
.612 .079 0 r
.45013 .43827 .45921 .43538 .47441 .44274 .46538 .4472 Mtetra
.646 .141 .035 r
.46538 .4472 .47441 .44274 .48979 .45152 .48083 .45742 Mtetra
.663 .179 .093 r
.48083 .45742 .48979 .45152 .50539 .46151 .49651 .46863 Mtetra
.668 .198 .127 r
.49651 .46863 .50539 .46151 .52122 .47239 .51243 .4804 Mtetra
.665 .201 .142 r
.51243 .4804 .52122 .47239 .53731 .48374 .52862 .49219 Mtetra
.652 .189 .139 r
.52862 .49219 .53731 .48374 .55364 .49503 .54506 .5034 Mtetra
.629 .158 .115 r
.54506 .5034 .55364 .49503 .57023 .50564 .56176 .51333 Mtetra
.588 .099 .061 r
.56176 .51333 .57023 .50564 .58705 .51492 .57867 .52131 Mtetra
.513 0 0 r
.57867 .52131 .58705 .51492 .60406 .52219 .59576 .52667 Mtetra
.36 0 0 r
.59576 .52667 .60406 .52219 .62123 .52683 .61298 .52886 Mtetra
.037 0 0 r
.61298 .52886 .62123 .52683 .63849 .52833 .63027 .52746 Mtetra
.439 .871 .917 r
.63027 .52746 .63849 .52833 .65579 .52629 .64756 .52225 Mtetra
.719 .922 .961 r
.64756 .52225 .65579 .52629 .67307 .52055 .66481 .5132 Mtetra
.801 .854 .89 r
.66481 .5132 .67307 .52055 .69026 .5111 .68195 .50053 Mtetra
.819 .791 .826 r
.68195 .50053 .69026 .5111 .70733 .49816 .69895 .48459 Mtetra
.82 .746 .782 r
.69895 .48459 .70733 .49816 .72424 .48214 .71578 .46595 Mtetra
.816 .714 .753 r
.71578 .46595 .72424 .48214 .74097 .46357 .73246 .44523 Mtetra
.811 .692 .734 r
.73246 .44523 .74097 .46357 .75754 .44308 .74898 .42314 Mtetra
.805 .677 .723 r
.74898 .42314 .75754 .44308 .77395 .42136 .76538 .40035 Mtetra
.799 .667 .718 r
.76538 .40035 .77395 .42136 .79025 .39904 .78169 .3775 Mtetra
.793 .661 .717 r
.78169 .3775 .79025 .39904 .80647 .37675 .79796 .35514 Mtetra
.787 .657 .72 r
.79796 .35514 .80647 .37675 .82266 .355 .81423 .3337 Mtetra
.781 .657 .726 r
.81423 .3337 .82266 .355 .83888 .33419 .83056 .31351 Mtetra
.774 .659 .735 r
.83056 .31351 .83888 .33419 .85516 .31464 .84698 .29478 Mtetra
.651 .745 .918 r
.22422 .43621 .23371 .44474 .24767 .4403 .23821 .43185 Mtetra
.645 .746 .923 r
.23821 .43185 .24767 .4403 .26169 .43598 .25227 .42766 Mtetra
.636 .748 .929 r
.25227 .42766 .26169 .43598 .27578 .43184 .26638 .42371 Mtetra
.624 .751 .938 r
.26638 .42371 .27578 .43184 .28993 .42795 .28055 .4201 Mtetra
.606 .753 .949 r
.28055 .4201 .28993 .42795 .30414 .4244 .29478 .41694 Mtetra
.578 .756 .962 r
.29478 .41694 .30414 .4244 .31841 .42131 .30906 .41435 Mtetra
.537 .756 .977 r
.30906 .41435 .31841 .42131 .33274 .41881 .3234 .41248 Mtetra
.473 .75 .99 r
.3234 .41248 .33274 .41881 .34713 .41704 .33779 .4115 Mtetra
.372 .727 .989 r
.33779 .4115 .34713 .41704 .36157 .41617 .35224 .41158 Mtetra
.216 .668 .949 r
.35224 .41158 .36157 .41617 .37609 .41637 .36675 .41289 Mtetra
.004 .548 .835 r
.36675 .41289 .37609 .41637 .39068 .4178 .38134 .41559 Mtetra
.226 0 0 r
.38134 .41559 .39068 .4178 .40536 .42061 .39603 .41979 Mtetra
.414 0 0 r
.39603 .41979 .40536 .42061 .42015 .42493 .41083 .42559 Mtetra
.536 0 0 r
.41083 .42559 .42015 .42493 .43506 .43081 .42576 .43299 Mtetra
.606 .064 0 r
.42576 .43299 .43506 .43081 .45013 .43827 .44087 .44191 Mtetra
.645 .131 .008 r
.44087 .44191 .45013 .43827 .46538 .4472 .45616 .45219 Mtetra
.665 .172 .069 r
.45616 .45219 .46538 .4472 .48083 .45742 .47168 .46352 Mtetra
.673 .193 .104 r
.47168 .46352 .48083 .45742 .49651 .46863 .48744 .47549 Mtetra
.671 .197 .119 r
.48744 .47549 .49651 .46863 .51243 .4804 .50346 .48759 Mtetra
.66 .185 .113 r
.50346 .48759 .51243 .4804 .52862 .49219 .51974 .49919 Mtetra
.637 .152 .084 r
.51974 .49919 .52862 .49219 .54506 .5034 .53629 .5096 Mtetra
.594 .088 .019 r
.53629 .5096 .54506 .5034 .56176 .51333 .55307 .51813 Mtetra
.511 0 0 r
.55307 .51813 .56176 .51333 .57867 .52131 .57007 .52409 Mtetra
.333 0 0 r
.57007 .52409 .57867 .52131 .59576 .52667 .58722 .5269 Mtetra
.044 .613 .721 r
.58722 .5269 .59576 .52667 .61298 .52886 .60447 .52611 Mtetra
.504 .876 .978 r
.60447 .52611 .61298 .52886 .63027 .52746 .62176 .52145 Mtetra
.721 .873 .953 r
.62176 .52145 .63027 .52746 .64756 .52225 .63903 .51289 Mtetra
.784 .808 .872 r
.63903 .51289 .64756 .52225 .66481 .5132 .65623 .50058 Mtetra
.8 .754 .81 r
.65623 .50058 .66481 .5132 .68195 .50053 .67332 .48489 Mtetra
.803 .716 .769 r
.67332 .48489 .68195 .50053 .69895 .48459 .69026 .46635 Mtetra
.801 .69 .742 r
.69026 .46635 .69895 .48459 .71578 .46595 .70705 .44561 Mtetra
.798 .672 .725 r
.70705 .44561 .71578 .46595 .73246 .44523 .72368 .42336 Mtetra
.794 .659 .714 r
.72368 .42336 .73246 .44523 .74898 .42314 .74019 .4003 Mtetra
.79 .651 .709 r
.74019 .4003 .74898 .42314 .76538 .40035 .75661 .37709 Mtetra
.785 .646 .709 r
.75661 .37709 .76538 .40035 .78169 .3775 .77297 .35431 Mtetra
.78 .644 .712 r
.77297 .35431 .78169 .3775 .79796 .35514 .78932 .33241 Mtetra
.775 .645 .718 r
.78932 .33241 .79796 .35514 .81423 .3337 .80571 .31174 Mtetra
.77 .648 .727 r
.80571 .31174 .81423 .3337 .83056 .31351 .82218 .29253 Mtetra
.764 .652 .739 r
.82218 .29253 .83056 .31351 .84698 .29478 .83876 .2749 Mtetra
.646 .746 .922 r
.21463 .42769 .22422 .43621 .23821 .43185 .22865 .42344 Mtetra
.638 .748 .928 r
.22865 .42344 .23821 .43185 .25227 .42766 .24273 .41943 Mtetra
.626 .75 .936 r
.24273 .41943 .25227 .42766 .26638 .42371 .25686 .41575 Mtetra
.609 .752 .946 r
.25686 .41575 .26638 .42371 .28055 .4201 .27105 .41249 Mtetra
.583 .755 .96 r
.27105 .41249 .28055 .4201 .29478 .41694 .28529 .40979 Mtetra
.545 .755 .974 r
.28529 .40979 .29478 .41694 .30906 .41435 .29957 .40779 Mtetra
.485 .75 .988 r
.29957 .40779 .30906 .41435 .3234 .41248 .31391 .40666 Mtetra
.392 .731 .991 r
.31391 .40666 .3234 .41248 .33779 .4115 .32829 .40657 Mtetra
.25 .68 .962 r
.32829 .40657 .33779 .4115 .35224 .41158 .34273 .40769 Mtetra
.05 .575 .868 r
.34273 .40769 .35224 .41158 .36675 .41289 .35724 .41017 Mtetra
0 .41 .692 r
.35724 .41017 .36675 .41289 .38134 .41559 .37183 .41416 Mtetra
.377 0 0 r
.37183 .41416 .38134 .41559 .39603 .41979 .38651 .41975 Mtetra
.512 0 0 r
.38651 .41975 .39603 .41979 .41083 .42559 .40132 .42694 Mtetra
.593 .039 0 r
.40132 .42694 .41083 .42559 .42576 .43299 .41628 .43569 Mtetra
.639 .113 0 r
.41628 .43569 .42576 .43299 .44087 .44191 .43142 .44583 Mtetra
.663 .158 .034 r
.43142 .44583 .44087 .44191 .45616 .45219 .44677 .45708 Mtetra
.674 .181 .071 r
.44677 .45708 .45616 .45219 .47168 .46352 .46236 .46905 Mtetra
.674 .187 .086 r
.46236 .46905 .47168 .46352 .48744 .47549 .4782 .48123 Mtetra
.664 .174 .077 r
.4782 .48123 .48744 .47549 .50346 .48759 .49431 .493 Mtetra
.64 .138 .041 r
.49431 .493 .50346 .48759 .51974 .49919 .51069 .5037 Mtetra
.594 .068 0 r
.51069 .5037 .51974 .49919 .53629 .5096 .52733 .51259 Mtetra
.498 0 0 r
.52733 .51259 .53629 .5096 .55307 .51813 .5442 .51901 Mtetra
.284 0 0 r
.5442 .51901 .55307 .51813 .57007 .52409 .56125 .52234 Mtetra
.141 .676 .852 r
.56125 .52234 .57007 .52409 .58722 .5269 .57844 .52211 Mtetra
.546 .848 .998 r
.57844 .52211 .58722 .5269 .60447 .52611 .59571 .51802 Mtetra
.711 .82 .932 r
.59571 .51802 .60447 .52611 .62176 .52145 .61299 .50999 Mtetra
.764 .764 .852 r
.61299 .50999 .62176 .52145 .63903 .51289 .63024 .49815 Mtetra
.781 .72 .796 r
.63024 .49815 .63903 .51289 .65623 .50058 .64739 .48285 Mtetra
.786 .689 .758 r
.64739 .48285 .65623 .50058 .67332 .48489 .66443 .4646 Mtetra
.787 .668 .733 r
.66443 .4646 .67332 .48489 .69026 .46635 .68133 .44402 Mtetra
.785 .653 .717 r
.68133 .44402 .69026 .46635 .70705 .44561 .69808 .42182 Mtetra
.783 .643 .707 r
.69808 .42182 .70705 .44561 .72368 .42336 .71471 .39872 Mtetra
.78 .637 .703 r
.71471 .39872 .72368 .42336 .74019 .4003 .73125 .37537 Mtetra
.777 .633 .702 r
.73125 .37537 .74019 .4003 .75661 .37709 .74771 .35236 Mtetra
.773 .632 .705 r
.74771 .35236 .75661 .37709 .77297 .35431 .76416 .33019 Mtetra
.769 .634 .711 r
.76416 .33019 .77297 .35431 .78932 .33241 .78063 .30921 Mtetra
.765 .637 .72 r
.78063 .30921 .78932 .33241 .80571 .31174 .79716 .28967 Mtetra
.76 .643 .732 r
.79716 .28967 .80571 .31174 .82218 .29253 .81379 .2717 Mtetra
.754 .65 .746 r
.81379 .2717 .82218 .29253 .83876 .2749 .83055 .25535 Mtetra
.639 .747 .926 r
.20492 .4192 .21463 .42769 .22865 .42344 .21897 .41512 Mtetra
.628 .749 .934 r
.21897 .41512 .22865 .42344 .24273 .41943 .23307 .41134 Mtetra
.612 .751 .944 r
.23307 .41134 .24273 .41943 .25686 .41575 .24722 .40797 Mtetra
.589 .753 .956 r
.24722 .40797 .25686 .41575 .27105 .41249 .26141 .40514 Mtetra
.553 .754 .971 r
.26141 .40514 .27105 .41249 .28529 .40979 .27565 .40298 Mtetra
.5 .75 .985 r
.27565 .40298 .28529 .40979 .29957 .40779 .28993 .40166 Mtetra
.416 .735 .991 r
.28993 .40166 .29957 .40779 .31391 .40666 .30426 .40135 Mtetra
.289 .693 .973 r
.30426 .40135 .31391 .40666 .32829 .40657 .31863 .40221 Mtetra
.106 .605 .901 r
.31863 .40221 .32829 .40657 .34273 .40769 .33306 .40441 Mtetra
0 .458 .752 r
.33306 .40441 .34273 .40769 .35724 .41017 .34755 .40808 Mtetra
.323 0 0 r
.34755 .40808 .35724 .41017 .37183 .41416 .36213 .41333 Mtetra
.475 0 0 r
.36213 .41333 .37183 .41416 .38651 .41975 .37682 .42018 Mtetra
.57 .002 0 r
.37682 .42018 .38651 .41975 .40132 .42694 .39164 .42859 Mtetra
.625 .084 0 r
.39164 .42859 .40132 .42694 .41628 .43569 .40663 .4384 Mtetra
.656 .135 0 r
.40663 .4384 .41628 .43569 .43142 .44583 .42181 .44938 Mtetra
.67 .162 .026 r
.42181 .44938 .43142 .44583 .44677 .45708 .43722 .46113 Mtetra
.672 .169 .04 r
.43722 .46113 .44677 .45708 .46236 .46905 .45288 .47317 Mtetra
.662 .155 .028 r
.45288 .47317 .46236 .46905 .4782 .48123 .46881 .4849 Mtetra
.638 .116 0 r
.46881 .4849 .4782 .48123 .49431 .493 .48501 .49566 Mtetra
.584 .035 0 r
.48501 .49566 .49431 .493 .51069 .5037 .50148 .50475 Mtetra
.468 0 0 r
.50148 .50475 .51069 .5037 .52733 .51259 .51821 .51146 Mtetra
.205 0 0 r
.51821 .51146 .52733 .51259 .5442 .51901 .53514 .51519 Mtetra
.237 .708 .942 r
.53514 .51519 .5442 .51901 .56125 .52234 .55225 .51544 Mtetra
.566 .802 .988 r
.55225 .51544 .56125 .52234 .57844 .52211 .56947 .51189 Mtetra
.696 .768 .907 r
.56947 .51189 .57844 .52211 .59571 .51802 .58674 .50443 Mtetra
.743 .724 .834 r
.58674 .50443 .59571 .51802 .61299 .50999 .60401 .49315 Mtetra
.762 .689 .782 r
.60401 .49315 .61299 .50999 .63024 .49815 .62122 .47836 Mtetra
.769 .665 .748 r
.62122 .47836 .63024 .49815 .64739 .48285 .63834 .46056 Mtetra
.772 .648 .725 r
.63834 .46056 .64739 .48285 .66443 .4646 .65534 .44035 Mtetra
.773 .636 .71 r
.65534 .44035 .66443 .4646 .68133 .44402 .67221 .41842 Mtetra
.772 .628 .701 r
.67221 .41842 .68133 .44402 .69808 .42182 .68897 .39549 Mtetra
.77 .623 .697 r
.68897 .39549 .69808 .42182 .71471 .39872 .70562 .37221 Mtetra
.768 .621 .697 r
.70562 .37221 .71471 .39872 .73125 .37537 .7222 .3492 Mtetra
.766 .621 .7 r
.7222 .3492 .73125 .37537 .74771 .35236 .73875 .32695 Mtetra
.763 .624 .706 r
.73875 .32695 .74771 .35236 .76416 .33019 .75531 .30583 Mtetra
.76 .628 .715 r
.75531 .30583 .76416 .33019 .78063 .30921 .77192 .28612 Mtetra
.755 .634 .726 r
.77192 .28612 .78063 .30921 .79716 .28967 .78861 .26795 Mtetra
.751 .642 .74 r
.78861 .26795 .79716 .28967 .81379 .2717 .80541 .25139 Mtetra
.745 .651 .756 r
.80541 .25139 .81379 .2717 .83055 .25535 .82235 .2364 Mtetra
.631 .748 .932 r
.1951 .41076 .20492 .4192 .21897 .41512 .20916 .40689 Mtetra
.616 .75 .941 r
.20916 .40689 .21897 .41512 .23307 .41134 .22328 .4034 Mtetra
.595 .752 .953 r
.22328 .4034 .23307 .41134 .24722 .40797 .23744 .40042 Mtetra
.563 .753 .967 r
.23744 .40042 .24722 .40797 .26141 .40514 .25163 .39808 Mtetra
.515 .75 .981 r
.25163 .39808 .26141 .40514 .27565 .40298 .26587 .39653 Mtetra
.442 .738 .99 r
.26587 .39653 .27565 .40298 .28993 .40166 .28014 .39595 Mtetra
.33 .706 .982 r
.28014 .39595 .28993 .40166 .30426 .40135 .29445 .39649 Mtetra
.167 .635 .932 r
.29445 .39649 .30426 .40135 .31863 .40221 .3088 .39833 Mtetra
0 .51 .814 r
.3088 .39833 .31863 .40221 .33306 .40441 .32321 .4016 Mtetra
.252 0 0 r
.32321 .4016 .33306 .40441 .34755 .40808 .3377 .40641 Mtetra
.421 0 0 r
.3377 .40641 .34755 .40808 .36213 .41333 .35227 .41278 Mtetra
.533 0 0 r
.35227 .41278 .36213 .41333 .37682 .42018 .36696 .4207 Mtetra
.601 .042 0 r
.36696 .4207 .37682 .42018 .39164 .42859 .3818 .43003 Mtetra
.639 .1 0 r
.3818 .43003 .39164 .42859 .40663 .4384 .39682 .44053 Mtetra
.658 .131 0 r
.39682 .44053 .40663 .4384 .42181 .44938 .41206 .45186 Mtetra
.663 .14 0 r
.41206 .45186 .42181 .44938 .43722 .46113 .42753 .46354 Mtetra
.654 .126 0 r
.42753 .46354 .43722 .46113 .45288 .47317 .44327 .47501 Mtetra
.625 .081 0 r
.44327 .47501 .45288 .47317 .46881 .4849 .45929 .48563 Mtetra
.56 0 0 r
.45929 .48563 .46881 .4849 .48501 .49566 .47559 .4947 Mtetra
.413 0 0 r
.47559 .4947 .48501 .49566 .50148 .50475 .49215 .50154 Mtetra
0 .472 .76 r
.49215 .50154 .50148 .50475 .51821 .51146 .50895 .50554 Mtetra
.316 .707 .98 r
.50895 .50554 .51821 .51146 .53514 .51519 .52595 .50618 Mtetra
.573 .752 .962 r
.52595 .50618 .53514 .51519 .55225 .51544 .5431 .50313 Mtetra
.679 .723 .882 r
.5431 .50313 .55225 .51544 .56947 .51189 .56034 .49623 Mtetra
.723 .689 .817 r
.56034 .49623 .56947 .51189 .58674 .50443 .57761 .48557 Mtetra
.743 .662 .771 r
.57761 .48557 .58674 .50443 .60401 .49315 .59486 .47141 Mtetra
.753 .643 .739 r
.59486 .47141 .60401 .49315 .62122 .47836 .61204 .45421 Mtetra
.758 .63 .718 r
.61204 .45421 .62122 .47836 .63834 .46056 .62913 .43455 Mtetra
.76 .621 .705 r
.62913 .43455 .63834 .46056 .65534 .44035 .64611 .4131 Mtetra
.761 .615 .697 r
.64611 .4131 .65534 .44035 .67221 .41842 .66299 .39054 Mtetra
.761 .611 .693 r
.66299 .39054 .67221 .41842 .68897 .39549 .67976 .36756 Mtetra
.76 .611 .693 r
.67976 .36756 .68897 .39549 .70562 .37221 .69646 .34475 Mtetra
.759 .612 .696 r
.69646 .34475 .70562 .37221 .7222 .3492 .71312 .32262 Mtetra
.757 .615 .702 r
.71312 .32262 .7222 .3492 .73875 .32695 .72978 .30155 Mtetra
.754 .62 .71 r
.72978 .30155 .73875 .32695 .75531 .30583 .74647 .28183 Mtetra
.751 .626 .722 r
.74647 .28183 .75531 .30583 .77192 .28612 .76323 .26361 Mtetra
.747 .635 .736 r
.76323 .26361 .77192 .28612 .78861 .26795 .78008 .24696 Mtetra
.742 .644 .752 r
.78008 .24696 .78861 .26795 .80541 .25139 .79706 .23186 Mtetra
.737 .655 .769 r
.79706 .23186 .80541 .25139 .82235 .2364 .81419 .21822 Mtetra
.62 .749 .938 r
.18516 .4024 .1951 .41076 .20916 .40689 .19924 .39878 Mtetra
.601 .751 .949 r
.19924 .39878 .20916 .40689 .22328 .4034 .21336 .39563 Mtetra
.573 .752 .962 r
.21336 .39563 .22328 .4034 .23744 .40042 .22752 .39308 Mtetra
.531 .75 .976 r
.22752 .39308 .23744 .40042 .25163 .39808 .24171 .39129 Mtetra
.467 .741 .988 r
.24171 .39129 .25163 .39808 .26587 .39653 .25593 .3904 Mtetra
.372 .717 .988 r
.25593 .3904 .26587 .39653 .28014 .39595 .27019 .39059 Mtetra
.231 .663 .957 r
.27019 .39059 .28014 .39595 .29445 .39649 .28448 .392 Mtetra
.045 .562 .872 r
.28448 .392 .29445 .39649 .3088 .39833 .29881 .39479 Mtetra
0 .416 .723 r
.29881 .39479 .3088 .39833 .32321 .4016 .31321 .39906 Mtetra
.345 0 0 r
.31321 .39906 .32321 .4016 .3377 .40641 .32768 .40485 Mtetra
.477 0 0 r
.32768 .40485 .3377 .40641 .35227 .41278 .34225 .41214 Mtetra
.561 0 0 r
.34225 .41214 .35227 .41278 .36696 .4207 .35696 .42082 Mtetra
.61 .051 0 r
.35696 .42082 .36696 .4207 .3818 .43003 .37183 .43068 Mtetra
.636 .088 0 r
.37183 .43068 .3818 .43003 .39682 .44053 .38689 .44139 Mtetra
.643 .099 0 r
.38689 .44139 .39682 .44053 .41206 .45186 .40219 .45252 Mtetra
.632 .082 0 r
.40219 .45252 .41206 .45186 .42753 .46354 .41775 .46353 Mtetra
.596 .03 0 r
.41775 .46353 .42753 .46354 .44327 .47501 .43358 .47379 Mtetra
.512 0 0 r
.43358 .47379 .44327 .47501 .45929 .48563 .4497 .48265 Mtetra
.325 0 0 r
.4497 .48265 .45929 .48563 .47559 .4947 .46609 .48945 Mtetra
.017 .528 .865 r
.46609 .48945 .47559 .4947 .49215 .50154 .48274 .49356 Mtetra
.373 .685 .979 r
.48274 .49356 .49215 .50154 .50895 .50554 .49961 .49449 Mtetra
.573 .706 .932 r
.49961 .49449 .50895 .50554 .52595 .50618 .51667 .49187 Mtetra
.663 .684 .859 r
.51667 .49187 .52595 .50618 .5431 .50313 .53385 .48554 Mtetra
.705 .659 .802 r
.53385 .48554 .5431 .50313 .56034 .49623 .55109 .47553 Mtetra
.726 .639 .761 r
.55109 .47553 .56034 .49623 .57761 .48557 .56836 .46208 Mtetra
.738 .624 .733 r
.56836 .46208 .57761 .48557 .59486 .47141 .58559 .44561 Mtetra
.745 .614 .713 r
.58559 .44561 .59486 .47141 .61204 .45421 .60275 .42665 Mtetra
.749 .607 .701 r
.60275 .42665 .61204 .45421 .62913 .43455 .61983 .40586 Mtetra
.751 .603 .693 r
.61983 .40586 .62913 .43455 .64611 .4131 .63681 .38389 Mtetra
.752 .601 .69 r
.63681 .38389 .64611 .4131 .66299 .39054 .6537 .36141 Mtetra
.6537 .36141 .66299 .39054 .67976 .36756 .67052 .339 Mtetra
.751 .603 .693 r
.67052 .339 .67976 .36756 .69646 .34475 .68729 .31718 Mtetra
.75 .607 .699 r
.68729 .31718 .69646 .34475 .71312 .32262 .70405 .29635 Mtetra
.748 .612 .707 r
.70405 .29635 .71312 .32262 .72978 .30155 .72083 .27677 Mtetra
.746 .62 .719 r
.72083 .27677 .72978 .30155 .74647 .28183 .73766 .25864 Mtetra
.743 .628 .733 r
.73766 .25864 .74647 .28183 .76323 .26361 .75458 .24203 Mtetra
.739 .639 .748 r
.75458 .24203 .76323 .26361 .78008 .24696 .7716 .22692 Mtetra
.734 .65 .766 r
.7716 .22692 .78008 .24696 .79706 .23186 .78876 .21325 Mtetra
.728 .662 .784 r
.78876 .21325 .79706 .23186 .81419 .21822 .80606 .20089 Mtetra
.607 .75 .945 r
.17509 .39412 .18516 .4024 .19924 .39878 .18918 .3908 Mtetra
.582 .751 .957 r
.18918 .3908 .19924 .39878 .21336 .39563 .2033 .38803 Mtetra
.546 .75 .971 r
.2033 .38803 .21336 .39563 .22752 .39308 .21746 .38596 Mtetra
.492 .743 .984 r
.21746 .38596 .22752 .39308 .24171 .39129 .23164 .38474 Mtetra
.412 .726 .989 r
.23164 .38474 .24171 .39129 .25593 .3904 .24584 .38453 Mtetra
.294 .686 .975 r
.24584 .38453 .25593 .3904 .27019 .39059 .26008 .38548 Mtetra
.133 .609 .919 r
.26008 .38548 .27019 .39059 .28448 .392 .27435 .38773 Mtetra
0 .489 .808 r
.27435 .38773 .28448 .392 .29881 .39479 .28866 .39137 Mtetra
.248 0 0 r
.28866 .39137 .29881 .39479 .31321 .39906 .30305 .39648 Mtetra
.398 0 0 r
.30305 .39648 .31321 .39906 .32768 .40485 .31751 .40303 Mtetra
.5 0 0 r
.31751 .40303 .32768 .40485 .34225 .41214 .3321 .41094 Mtetra
.562 0 0 r
.3321 .41094 .34225 .41214 .35696 .42082 .34683 .42001 Mtetra
.596 .027 0 r
.34683 .42001 .35696 .42082 .37183 .43068 .36175 .42994 Mtetra
.606 .04 0 r
.36175 .42994 .37183 .43068 .38689 .44139 .37688 .44033 Mtetra
.593 .021 0 r
.37688 .44033 .38689 .44139 .40219 .45252 .39226 .45068 Mtetra
.545 0 0 r
.39226 .45068 .40219 .45252 .41775 .46353 .40791 .46041 Mtetra
.434 0 0 r
.40791 .46041 .41775 .46353 .43358 .47379 .42384 .46887 Mtetra
0 .355 .719 r
.42384 .46887 .43358 .47379 .4497 .48265 .44006 .47545 Mtetra
.126 .559 .922 r
.44006 .47545 .4497 .48265 .46609 .48945 .45655 .47953 Mtetra
.412 .657 .96 r
.45655 .47953 .46609 .48945 .48274 .49356 .47328 .48063 Mtetra
.57 .668 .904 r
.47328 .48063 .48274 .49356 .49961 .49449 .49023 .47837 Mtetra
.648 .652 .84 r
.49023 .47837 .49961 .49449 .51667 .49187 .50732 .47257 Mtetra
.688 .634 .79 r
.50732 .47257 .51667 .49187 .53385 .48554 .52453 .46322 Mtetra
.711 .619 .753 r
.52453 .46322 .53385 .48554 .55109 .47553 .54178 .45054 Mtetra
.724 .608 .728 r
.54178 .45054 .55109 .47553 .56836 .46208 .55904 .43489 Mtetra
.732 .601 .71 r
.55904 .43489 .56836 .46208 .58559 .44561 .57625 .41677 Mtetra
.738 .596 .698 r
.57625 .41677 .58559 .44561 .60275 .42665 .59341 .39679 Mtetra
.741 .593 .691 r
.59341 .39679 .60275 .42665 .61983 .40586 .61048 .37558 Mtetra
.743 .592 .688 r
.61048 .37558 .61983 .40586 .63681 .38389 .62748 .35379 Mtetra
.744 .593 .688 r
.62748 .35379 .63681 .38389 .6537 .36141 .64441 .33198 Mtetra
.744 .596 .691 r
.64441 .33198 .6537 .36141 .67052 .339 .66129 .31065 Mtetra
.744 .6 .697 r
.66129 .31065 .67052 .339 .68729 .31718 .67815 .29021 Mtetra
.743 .606 .706 r
.67815 .29021 .68729 .31718 .70405 .29635 .69502 .27095 Mtetra
.741 .614 .717 r
.69502 .27095 .70405 .29635 .72083 .27677 .71192 .25304 Mtetra
.739 .623 .731 r
.71192 .25304 .72083 .27677 .73766 .25864 .7289 .23658 Mtetra
.735 .634 .746 r
.7289 .23658 .73766 .25864 .75458 .24203 .74598 .22158 Mtetra
.731 .645 .764 r
.74598 .22158 .75458 .24203 .7716 .22692 .76317 .20796 Mtetra
.726 .658 .782 r
.76317 .20796 .7716 .22692 .78876 .21325 .78049 .19562 Mtetra
.72 .67 .801 r
.78049 .19562 .78876 .21325 .80606 .20089 .79796 .18443 Mtetra
.592 .75 .953 r
.1649 .38593 .17509 .39412 .18918 .3908 .17899 .38294 Mtetra
.561 .749 .965 r
.17899 .38294 .18918 .3908 .2033 .38803 .19311 .38058 Mtetra
.515 .745 .978 r
.19311 .38058 .2033 .38803 .21746 .38596 .20725 .37901 Mtetra
.449 .733 .988 r
.20725 .37901 .21746 .38596 .23164 .38474 .22142 .37838 Mtetra
.352 .704 .984 r
.22142 .37838 .23164 .38474 .24584 .38453 .2356 .37882 Mtetra
.218 .649 .954 r
.2356 .37882 .24584 .38453 .26008 .38548 .24982 .38048 Mtetra
.05 .557 .879 r
.24982 .38048 .26008 .38548 .27435 .38773 .26407 .38345 Mtetra
0 .433 .76 r
.26407 .38345 .27435 .38773 .28866 .39137 .27838 .3878 Mtetra
.292 0 0 r
.27838 .3878 .28866 .39137 .30305 .39648 .29276 .39352 Mtetra
.411 0 0 r
.29276 .39352 .30305 .39648 .31751 .40303 .30724 .40054 Mtetra
.489 0 0 r
.30724 .40054 .31751 .40303 .3321 .41094 .32185 .4087 Mtetra
.532 0 0 r
.32185 .4087 .3321 .41094 .34683 .42001 .33663 .41771 Mtetra
.545 0 0 r
.33663 .41771 .34683 .42001 .36175 .42994 .35161 .42721 Mtetra
.526 0 0 r
.35161 .42721 .36175 .42994 .37688 .44033 .36682 .43674 Mtetra
.461 0 0 r
.36682 .43674 .37688 .44033 .39226 .45068 .3823 .44576 Mtetra
.321 0 0 r
.3823 .44576 .39226 .45068 .40791 .46041 .39805 .45366 Mtetra
0 .427 .823 r
.39805 .45366 .40791 .46041 .42384 .46887 .41409 .45986 Mtetra
.216 .571 .94 r
.41409 .45986 .42384 .46887 .44006 .47545 .43042 .46377 Mtetra
.439 .631 .936 r
.43042 .46377 .44006 .47545 .45655 .47953 .44701 .46492 Mtetra
.567 .637 .88 r
.44701 .46492 .45655 .47953 .47328 .48063 .46382 .46293 Mtetra
.635 .626 .824 r
.46382 .46293 .47328 .48063 .49023 .47837 .48082 .4576 Mtetra
.674 .614 .78 r
.48082 .4576 .49023 .47837 .50732 .47257 .49796 .44891 Mtetra
.697 .603 .747 r
.49796 .44891 .50732 .47257 .52453 .46322 .51518 .43702 Mtetra
.711 .595 .724 r
.51518 .43702 .52453 .46322 .54178 .45054 .53244 .42226 Mtetra
.721 .589 .708 r
.53244 .42226 .54178 .45054 .55904 .43489 .54969 .40508 Mtetra
.727 .586 .697 r
.54969 .40508 .55904 .43489 .57625 .41677 .56689 .38604 Mtetra
.732 .584 .69 r
.56689 .38604 .57625 .41677 .59341 .39679 .58405 .36575 Mtetra
.735 .584 .687 r
.58405 .36575 .59341 .39679 .61048 .37558 .60113 .34479 Mtetra
.736 .586 .688 r
.60113 .34479 .61048 .37558 .62748 .35379 .61815 .32374 Mtetra
.737 .589 .691 r
.61815 .32374 .62748 .35379 .64441 .33198 .63513 .30307 Mtetra
.738 .594 .697 r
.63513 .30307 .64441 .33198 .66129 .31065 .65209 .28319 Mtetra
.737 .601 .705 r
.65209 .28319 .66129 .31065 .67815 .29021 .66904 .26438 Mtetra
.736 .609 .716 r
.66904 .26438 .67815 .29021 .69502 .27095 .68603 .24683 Mtetra
.734 .619 .73 r
.68603 .24683 .69502 .27095 .71192 .25304 .70307 .23064 Mtetra
.731 .63 .745 r
.70307 .23064 .71192 .25304 .7289 .23658 .7202 .21583 Mtetra
.728 .642 .763 r
.7202 .21583 .7289 .23658 .74598 .22158 .73743 .20235 Mtetra
.723 .655 .781 r
.73743 .20235 .74598 .22158 .76317 .20796 .75477 .1901 Mtetra
.718 .668 .8 r
.75477 .1901 .76317 .20796 .78049 .19562 .77226 .17896 Mtetra
.711 .68 .818 r
.77226 .17896 .78049 .19562 .79796 .18443 .78988 .16877 Mtetra
.574 .748 .959 r
.15457 .37782 .1649 .38593 .17899 .38294 .16866 .37517 Mtetra
.536 .746 .972 r
.16866 .37517 .17899 .38294 .19311 .38058 .18277 .37324 Mtetra
.482 .737 .983 r
.18277 .37324 .19311 .38058 .20725 .37901 .1969 .37216 Mtetra
.404 .718 .987 r
.1969 .37216 .20725 .37901 .22142 .37838 .21105 .37208 Mtetra
.296 .679 .975 r
.21105 .37208 .22142 .37838 .2356 .37882 .22522 .37312 Mtetra
.156 .613 .932 r
.22522 .37312 .2356 .37882 .24982 .38048 .23943 .37537 Mtetra
0 .517 .851 r
.23943 .37537 .24982 .38048 .26407 .38345 .25367 .37891 Mtetra
0 .403 .741 r
.25367 .37891 .26407 .38345 .27838 .3878 .26797 .38375 Mtetra
.293 0 0 r
.26797 .38375 .27838 .3878 .29276 .39352 .28237 .38981 Mtetra
.384 0 0 r
.28237 .38981 .29276 .39352 .30724 .40054 .29687 .39695 Mtetra
.437 0 0 r
.29687 .39695 .30724 .40054 .32185 .4087 .31153 .40493 Mtetra
.451 0 0 r
.31153 .40493 .32185 .4087 .33663 .41771 .32638 .41342 Mtetra
.425 0 0 r
.32638 .41342 .33663 .41771 .35161 .42721 .34144 .422 Mtetra
.343 0 0 r
.34144 .422 .35161 .42721 .36682 .43674 .35676 .43016 Mtetra
0 .347 .753 r
.35676 .43016 .36682 .43674 .3823 .44576 .37235 .43737 Mtetra
.048 .48 .886 r
.37235 .43737 .3823 .44576 .39805 .45366 .38822 .44304 Mtetra
.287 .574 .938 r
.38822 .44304 .39805 .45366 .41409 .45986 .40438 .44665 Mtetra
.459 .61 .913 r
.40438 .44665 .41409 .45986 .43042 .46377 .42082 .44773 Mtetra
.564 .614 .861 r
.42082 .44773 .43042 .46377 .44701 .46492 .4375 .44592 Mtetra
.625 .607 .812 r
.4375 .44592 .44701 .46492 .46382 .46293 .45439 .441 Mtetra
.662 .598 .773 r
.45439 .441 .46382 .46293 .48082 .4576 .47144 .43293 Mtetra
.685 .59 .743 r
.47144 .43293 .48082 .4576 .49796 .44891 .4886 .42184 Mtetra
.7 .584 .722 r
.4886 .42184 .49796 .44891 .51518 .43702 .50584 .40799 Mtetra
.71 .58 .707 r
.50584 .40799 .51518 .43702 .53244 .42226 .52309 .39182 Mtetra
.718 .578 .697 r
.52309 .39182 .53244 .42226 .54969 .40508 .54033 .37382 Mtetra
.723 .577 .691 r
.54033 .37382 .54969 .40508 .56689 .38604 .55754 .35454 Mtetra
.727 .578 .688 r
.55754 .35454 .56689 .38604 .58405 .36575 .57469 .33456 Mtetra
.729 .581 .688 r
.57469 .33456 .58405 .36575 .60113 .34479 .5918 .3144 Mtetra
.731 .585 .692 r
.5918 .3144 .60113 .34479 .61815 .32374 .60886 .29454 Mtetra
.732 .59 .698 r
.60886 .29454 .61815 .32374 .63513 .30307 .6259 .27534 Mtetra
.732 .597 .706 r
.6259 .27534 .63513 .30307 .65209 .28319 .64293 .25711 Mtetra
.731 .606 .717 r
.64293 .25711 .65209 .28319 .66904 .26438 .65999 .24003 Mtetra
.73 .616 .73 r
.65999 .24003 .66904 .26438 .68603 .24683 .67709 .22422 Mtetra
.728 .627 .746 r
.67709 .22422 .68603 .24683 .70307 .23064 .69427 .2097 Mtetra
.724 .639 .763 r
.69427 .2097 .70307 .23064 .7202 .21583 .71153 .19643 Mtetra
.72 .652 .781 r
.71153 .19643 .7202 .21583 .73743 .20235 .72891 .18433 Mtetra
.715 .666 .8 r
.72891 .18433 .73743 .20235 .75477 .1901 .7464 .17329 Mtetra
.709 .678 .818 r
.7464 .17329 .75477 .1901 .77226 .17896 .76403 .16316 Mtetra
.703 .69 .835 r
.76403 .16316 .77226 .17896 .78988 .16877 .7818 .15381 Mtetra
.556 .746 .965 r
.14411 .36975 .15457 .37782 .16866 .37517 .15819 .36746 Mtetra
.511 .74 .977 r
.15819 .36746 .16866 .37517 .18277 .37324 .1723 .36594 Mtetra
.449 .727 .986 r
.1723 .36594 .18277 .37324 .1969 .37216 .18642 .36532 Mtetra
.364 .701 .984 r
.18642 .36532 .1969 .37216 .21105 .37208 .20056 .36572 Mtetra
.252 .656 .964 r
.20056 .36572 .21105 .37208 .22522 .37312 .21472 .36724 Mtetra
.118 .586 .917 r
.21472 .36724 .22522 .37312 .23943 .37537 .22891 .36994 Mtetra
0 .498 .844 r
.22891 .36994 .23943 .37537 .25367 .37891 .24316 .37384 Mtetra
0 .405 .758 r
.24316 .37384 .25367 .37891 .26797 .38375 .25748 .37889 Mtetra
0 .325 .682 r
.25748 .37889 .26797 .38375 .28237 .38981 .27191 .38496 Mtetra
.307 0 0 r
.27191 .38496 .28237 .38981 .29687 .39695 .28647 .39183 Mtetra
.323 0 0 r
.28647 .39183 .29687 .39695 .31153 .40493 .3012 .39923 Mtetra
0 .273 .662 r
.3012 .39923 .31153 .40493 .32638 .41342 .31613 .40675 Mtetra
0 .334 .743 r
.31613 .40675 .32638 .41342 .34144 .422 .33131 .41395 Mtetra
0 .425 .843 r
.33131 .41395 .34144 .422 .35676 .43016 .34674 .42033 Mtetra
.156 .516 .915 r
.34674 .42033 .35676 .43016 .37235 .43737 .36246 .42536 Mtetra
.341 .574 .926 r
.36246 .42536 .37235 .43737 .38822 .44304 .37846 .42855 Mtetra
.476 .595 .893 r
.37846 .42855 .38822 .44304 .40438 .44665 .39474 .42946 Mtetra
.562 .597 .846 r
.39474 .42946 .40438 .44665 .42082 .44773 .41127 .42773 Mtetra
.616 .592 .803 r
.41127 .42773 .42082 .44773 .4375 .44592 .42804 .42314 Mtetra
.651 .586 .768 r
.42804 .42314 .4375 .44592 .45439 .441 .44499 .41565 Mtetra
.674 .58 .741 r
.44499 .41565 .45439 .441 .47144 .43293 .46208 .40532 Mtetra
.69 .575 .722 r
.46208 .40532 .47144 .43293 .4886 .42184 .47927 .39241 Mtetra
.701 .573 .708 r
.47927 .39241 .4886 .42184 .50584 .40799 .4965 .37727 Mtetra
.709 .572 .698 r
.4965 .37727 .50584 .40799 .52309 .39182 .51375 .36036 Mtetra
.715 .572 .692 r
.51375 .36036 .52309 .39182 .54033 .37382 .53099 .34219 Mtetra
.719 .573 .69 r
.53099 .34219 .54033 .37382 .55754 .35454 .54819 .32327 Mtetra
.722 .576 .69 r
.54819 .32327 .55754 .35454 .57469 .33456 .56536 .30411 Mtetra
.725 .581 .694 r
.56536 .30411 .57469 .33456 .5918 .3144 .58249 .28515 Mtetra
.726 .587 .7 r
.58249 .28515 .5918 .3144 .60886 .29454 .5996 .26676 Mtetra
.727 .594 .708 r
.5996 .26676 .60886 .29454 .6259 .27534 .6167 .24921 Mtetra
.727 .603 .719 r
.6167 .24921 .6259 .27534 .64293 .25711 .63382 .23271 Mtetra
.726 .613 .732 r
.63382 .23271 .64293 .25711 .65999 .24003 .65098 .21736 Mtetra
.724 .625 .747 r
.65098 .21736 .65999 .24003 .67709 .22422 .6682 .20321 Mtetra
.721 .638 .764 r
.6682 .20321 .67709 .22422 .69427 .2097 .6855 .19022 Mtetra
.717 .651 .782 r
.6855 .19022 .69427 .2097 .71153 .19643 .7029 .17834 Mtetra
.713 .664 .8 r
.7029 .17834 .71153 .19643 .72891 .18433 .72041 .16744 Mtetra
.707 .677 .818 r
.72041 .16744 .72891 .18433 .7464 .17329 .73804 .15741 Mtetra
.702 .689 .835 r
.73804 .15741 .7464 .17329 .76403 .16316 .7558 .14812 Mtetra
.695 .7 .851 r
.7558 .14812 .76403 .16316 .7818 .15381 .7737 .13945 Mtetra
.537 .742 .97 r
.13352 .3617 .14411 .36975 .15819 .36746 .1476 .35974 Mtetra
.488 .733 .98 r
.1476 .35974 .15819 .36746 .1723 .36594 .1617 .35858 Mtetra
.421 .716 .985 r
.1617 .35858 .1723 .36594 .18642 .36532 .17581 .35835 Mtetra
.334 .685 .98 r
.17581 .35835 .18642 .36532 .20056 .36572 .18994 .35913 Mtetra
.228 .638 .957 r
.18994 .35913 .20056 .36572 .21472 .36724 .20411 .36099 Mtetra
.111 .575 .915 r
.20411 .36099 .21472 .36724 .22891 .36994 .21831 .36394 Mtetra
0 .503 .86 r
.21831 .36394 .22891 .36994 .24316 .37384 .23258 .36795 Mtetra
0 .436 .805 r
.23258 .36795 .24316 .37384 .25748 .37889 .24694 .3729 Mtetra
0 .388 .768 r
.24694 .3729 .25748 .37889 .27191 .38496 .26142 .37863 Mtetra
0 .368 .76 r
.26142 .37863 .27191 .38496 .28647 .39183 .27605 .38487 Mtetra
0 .381 .787 r
.27605 .38487 .28647 .39183 .3012 .39923 .29088 .39127 Mtetra
0 .424 .84 r
.29088 .39127 .3012 .39923 .31613 .40675 .30593 .39743 Mtetra
.086 .485 .896 r
.30593 .39743 .31613 .40675 .33131 .41395 .32122 .40289 Mtetra
.243 .54 .924 r
.32122 .40289 .33131 .41395 .34674 .42033 .33679 .40719 Mtetra
.384 .573 .914 r
.33679 .40719 .34674 .42033 .36246 .42536 .35264 .40987 Mtetra
.489 .586 .878 r
.35264 .40987 .36246 .42536 .37846 .42855 .36877 .4105 Mtetra
.562 .586 .836 r
.36877 .4105 .37846 .42855 .39474 .42946 .38517 .40876 Mtetra
.61 .582 .797 r
.38517 .40876 .39474 .42946 .41127 .42773 .4018 .40443 Mtetra
.643 .577 .766 r
.4018 .40443 .41127 .42773 .42804 .42314 .41864 .39744 Mtetra
.665 .572 .741 r
.41864 .39744 .42804 .42314 .44499 .41565 .43564 .38784 Mtetra
.681 .569 .723 r
.43564 .38784 .44499 .41565 .46208 .40532 .45276 .37583 Mtetra
.692 .568 .71 r
.45276 .37583 .46208 .40532 .47927 .39241 .46995 .36173 Mtetra
.701 .567 .701 r
.46995 .36173 .47927 .39241 .4965 .37727 .48719 .34594 Mtetra
.708 .568 .695 r
.48719 .34594 .4965 .37727 .51375 .36036 .50443 .32891 Mtetra
.712 .57 .693 r
.50443 .32891 .51375 .36036 .53099 .34219 .52166 .31112 Mtetra
.716 .574 .694 r
.52166 .31112 .53099 .34219 .54819 .32327 .53886 .29303 Mtetra
.719 .579 .697 r
.53886 .29303 .54819 .32327 .56536 .30411 .55605 .27506 Mtetra
.721 .585 .703 r
.55605 .27506 .56536 .30411 .58249 .28515 .57321 .25755 Mtetra
.722 .593 .711 r
.57321 .25755 .58249 .28515 .5996 .26676 .59037 .24077 Mtetra
.722 .602 .722 r
.59037 .24077 .5996 .26676 .6167 .24921 .60754 .22492 Mtetra
.721 .612 .735 r
.60754 .22492 .6167 .24921 .63382 .23271 .62475 .21012 Mtetra
.72 .624 .75 r
.62475 .21012 .63382 .23271 .65098 .21736 .64201 .1964 Mtetra
.718 .637 .767 r
.64201 .1964 .65098 .21736 .6682 .20321 .65934 .18375 Mtetra
.714 .65 .784 r
.65934 .18375 .6682 .20321 .6855 .19022 .67676 .17212 Mtetra
.71 .664 .802 r
.67676 .17212 .6855 .19022 .7029 .17834 .69428 .16142 Mtetra
.705 .677 .82 r
.69428 .16142 .7029 .17834 .72041 .16744 .71192 .15153 Mtetra
.7 .689 .837 r
.71192 .15153 .72041 .16744 .73804 .15741 .72967 .14233 Mtetra
.694 .7 .851 r
.72967 .14233 .73804 .15741 .7558 .14812 .74756 .1337 Mtetra
.688 .709 .864 r
.74756 .1337 .7558 .14812 .7737 .13945 .76557 .12554 Mtetra
.52 .737 .973 r
.1228 .35359 .13352 .3617 .1476 .35974 .13688 .35191 Mtetra
.468 .725 .981 r
.13688 .35191 .1476 .35974 .1617 .35858 .15098 .35106 Mtetra
.402 .705 .984 r
.15098 .35106 .1617 .35858 .17581 .35835 .16509 .35111 Mtetra
.321 .673 .976 r
.16509 .35111 .17581 .35835 .18994 .35913 .17923 .35213 Mtetra
.229 .63 .957 r
.17923 .35213 .18994 .35913 .20411 .36099 .19341 .35414 Mtetra
.136 .578 .926 r
.19341 .35414 .20411 .36099 .21831 .36394 .20764 .35711 Mtetra
.057 .527 .893 r
.20764 .35711 .21831 .36394 .23258 .36795 .22195 .36096 Mtetra
.004 .487 .868 r
.22195 .36096 .23258 .36795 .24694 .3729 .23637 .36552 Mtetra
0 .467 .86 r
.23637 .36552 .24694 .3729 .26142 .37863 .25093 .37057 Mtetra
.016 .47 .873 r
.25093 .37057 .26142 .37863 .27605 .38487 .26567 .37581 Mtetra
.088 .494 .899 r
.26567 .37581 .27605 .38487 .29088 .39127 .28061 .38089 Mtetra
.194 .528 .921 r
.28061 .38089 .29088 .39127 .30593 .39743 .29579 .38538 Mtetra
.312 .558 .923 r
.29579 .38538 .30593 .39743 .32122 .40289 .31122 .38888 Mtetra
.419 .575 .902 r
.31122 .38888 .32122 .40289 .33679 .40719 .32693 .39095 Mtetra
.502 .581 .867 r
.32693 .39095 .33679 .40719 .35264 .40987 .34292 .39123 Mtetra
.563 .58 .829 r
.34292 .39123 .35264 .40987 .36877 .4105 .35917 .3894 Mtetra
.605 .576 .794 r
.35917 .3894 .36877 .4105 .38517 .40876 .37567 .38525 Mtetra
.636 .571 .765 r
.37567 .38525 .38517 .40876 .4018 .40443 .39239 .37869 Mtetra
.657 .568 .743 r
.39239 .37869 .4018 .40443 .41864 .39744 .40929 .36976 Mtetra
.673 .566 .726 r
.40929 .36976 .41864 .39744 .43564 .38784 .42632 .35862 Mtetra
.685 .564 .713 r
.42632 .35862 .43564 .38784 .45276 .37583 .44346 .34552 Mtetra
.694 .564 .704 r
.44346 .34552 .45276 .37583 .46995 .36173 .46065 .33084 Mtetra
.701 .566 .699 r
.46065 .33084 .46995 .36173 .48719 .34594 .47788 .31496 Mtetra
.706 .569 .697 r
.47788 .31496 .48719 .34594 .50443 .32891 .49511 .29833 Mtetra
.71 .572 .698 r
.49511 .29833 .50443 .32891 .52166 .31112 .51234 .28135 Mtetra
.713 .578 .701 r
.51234 .28135 .52166 .31112 .53886 .29303 .52955 .26441 Mtetra
.715 .584 .707 r
.52955 .26441 .53886 .29303 .55605 .27506 .54675 .24784 Mtetra
.717 .592 .716 r
.54675 .24784 .55605 .27506 .57321 .25755 .56395 .23189 Mtetra
.718 .602 .726 r
.56395 .23189 .57321 .25755 .59037 .24077 .58116 .21675 Mtetra
.717 .613 .739 r
.58116 .21675 .59037 .24077 .60754 .22492 .5984 .20254 Mtetra
.716 .625 .754 r
.5984 .20254 .60754 .22492 .62475 .21012 .61569 .18931 Mtetra
.714 .637 .77 r
.61569 .18931 .62475 .21012 .64201 .1964 .63305 .17705 Mtetra
.711 .651 .788 r
.63305 .17705 .64201 .1964 .65934 .18375 .65048 .16572 Mtetra
.707 .664 .805 r
.65048 .16572 .65934 .18375 .67676 .17212 .66801 .15524 Mtetra
.703 .677 .822 r
.66801 .15524 .67676 .17212 .69428 .16142 .68565 .14551 Mtetra
.698 .689 .838 r
.68565 .14551 .69428 .16142 .71192 .15153 .7034 .13643 Mtetra
.692 .7 .853 r
.7034 .13643 .71192 .15153 .72967 .14233 .72127 .12788 Mtetra
.687 .71 .865 r
.72127 .12788 .72967 .14233 .74756 .1337 .73927 .11975 Mtetra
.682 .717 .876 r
.73927 .11975 .74756 .1337 .76557 .12554 .75739 .11197 Mtetra
.506 .731 .974 r
.11196 .34535 .1228 .35359 .13688 .35191 .12605 .3439 Mtetra
.456 .717 .98 r
.12605 .3439 .13688 .35191 .15098 .35106 .14015 .34325 Mtetra
.394 .696 .981 r
.14015 .34325 .15098 .35106 .16509 .35111 .15428 .34346 Mtetra
.325 .667 .975 r
.15428 .34346 .16509 .35111 .17923 .35213 .16844 .34455 Mtetra
.254 .631 .961 r
.16844 .34455 .17923 .35213 .19341 .35414 .18265 .34651 Mtetra
.19 .594 .943 r
.18265 .34651 .19341 .35414 .20764 .35711 .19693 .34925 Mtetra
.146 .562 .928 r
.19693 .34925 .20764 .35711 .22195 .36096 .21131 .35266 Mtetra
.131 .542 .92 r
.21131 .35266 .22195 .36096 .23637 .36552 .22581 .35654 Mtetra
.15 .537 .923 r
.22581 .35654 .23637 .36552 .25093 .37057 .24048 .36062 Mtetra
.203 .545 .929 r
.24048 .36062 .25093 .37057 .26567 .37581 .25533 .36458 Mtetra
.281 .56 .93 r
.25533 .36458 .26567 .37581 .28061 .38089 .27041 .36808 Mtetra
.368 .573 .918 r
.27041 .36808 .28061 .38089 .29579 .38538 .28573 .37073 Mtetra
.448 .579 .893 r
.28573 .37073 .29579 .38538 .31122 .38888 .30132 .37215 Mtetra
.514 .58 .859 r
.30132 .37215 .31122 .38888 .32693 .39095 .31717 .37201 Mtetra
.565 .577 .825 r
.31717 .37201 .32693 .39095 .34292 .39123 .33328 .37001 Mtetra
.603 .573 .793 r
.33328 .37001 .34292 .39123 .35917 .3894 .34965 .36596 Mtetra
.63 .569 .767 r
.34965 .36596 .35917 .3894 .37567 .38525 .36624 .35977 Mtetra
.651 .566 .746 r
.36624 .35977 .37567 .38525 .39239 .37869 .38303 .35143 Mtetra
.666 .564 .73 r
.38303 .35143 .39239 .37869 .40929 .36976 .39997 .34109 Mtetra
.678 .563 .718 r
.39997 .34109 .40929 .36976 .42632 .35862 .41702 .32896 Mtetra
.688 .564 .71 r
.41702 .32896 .42632 .35862 .44346 .34552 .43416 .31534 Mtetra
.695 .565 .705 r
.43416 .31534 .44346 .34552 .46065 .33084 .45135 .3006 Mtetra
.7 .568 .703 r
.45135 .3006 .46065 .33084 .47788 .31496 .46856 .28511 Mtetra
.705 .573 .704 r
.46856 .28511 .47788 .31496 .49511 .29833 .48578 .26925 Mtetra
.708 .578 .707 r
.48578 .26925 .49511 .29833 .51234 .28135 .503 .25337 Mtetra
.711 .585 .713 r
.503 .25337 .51234 .28135 .52955 .26441 .52022 .23776 Mtetra
.712 .593 .721 r
.52022 .23776 .52955 .26441 .54675 .24784 .53745 .22267 Mtetra
.713 .603 .732 r
.53745 .22267 .54675 .24784 .56395 .23189 .55468 .20828 Mtetra
.713 .614 .745 r
.55468 .20828 .56395 .23189 .58116 .21675 .57195 .19471 Mtetra
.713 .626 .759 r
.57195 .19471 .58116 .21675 .5984 .20254 .58926 .182 Mtetra
.711 .639 .775 r
.58926 .182 .5984 .20254 .61569 .18931 .60663 .17017 Mtetra
.708 .652 .792 r
.60663 .17017 .61569 .18931 .63305 .17705 .62408 .15917 Mtetra
.705 .666 .809 r
.62408 .15917 .63305 .17705 .65048 .16572 .64161 .14894 Mtetra
.7 .678 .825 r
.64161 .14894 .65048 .16572 .66801 .15524 .65925 .13939 Mtetra
.696 .69 .841 r
.65925 .13939 .66801 .15524 .68565 .14551 .67699 .13044 Mtetra
.691 .701 .855 r
.67699 .13044 .68565 .14551 .7034 .13643 .69485 .12197 Mtetra
.686 .71 .867 r
.69485 .12197 .7034 .13643 .72127 .12788 .71283 .11391 Mtetra
.681 .718 .877 r
.71283 .11391 .72127 .12788 .73927 .11975 .73093 .10615 Mtetra
.677 .724 .885 r
.73093 .10615 .73927 .11975 .75739 .11197 .74915 .09862 Mtetra
.499 .725 .973 r
.10101 .3369 .11196 .34535 .12605 .3439 .11511 .33558 Mtetra
.453 .711 .978 r
.11511 .33558 .12605 .3439 .14015 .34325 .12924 .33502 Mtetra
.401 .691 .978 r
.12924 .33502 .14015 .34325 .15428 .34346 .14339 .33524 Mtetra
.347 .666 .974 r
.14339 .33524 .15428 .34346 .16844 .34455 .15759 .33622 Mtetra
.298 .639 .966 r
.15759 .33622 .16844 .34455 .18265 .34651 .17185 .33791 Mtetra
.262 .613 .957 r
.17185 .33791 .18265 .34651 .19693 .34925 .1862 .34021 Mtetra
.248 .594 .95 r
.1862 .34021 .19693 .34925 .21131 .35266 .20067 .34293 Mtetra
.259 .584 .945 r
.20067 .34293 .21131 .35266 .22581 .35654 .21528 .34586 Mtetra
.295 .582 .941 r
.21528 .34586 .22581 .35654 .24048 .36062 .23007 .34873 Mtetra
.35 .584 .931 r
.23007 .34873 .24048 .36062 .25533 .36458 .24506 .35123 Mtetra
.413 .586 .912 r
.24506 .35123 .25533 .36458 .27041 .36808 .26029 .35301 Mtetra
.474 .586 .886 r
.26029 .35301 .27041 .36808 .28573 .37073 .27576 .35375 Mtetra
.526 .583 .855 r
.27576 .35375 .28573 .37073 .30132 .37215 .29149 .35314 Mtetra
.568 .578 .823 r
.29149 .35314 .30132 .37215 .31717 .37201 .30748 .35092 Mtetra
.601 .574 .795 r
.30748 .35092 .31717 .37201 .33328 .37001 .32372 .3469 Mtetra
.627 .57 .771 r
.32372 .3469 .33328 .37001 .34965 .36596 .34018 .34099 Mtetra
.646 .567 .751 r
.34018 .34099 .34965 .36596 .36624 .35977 .35685 .33317 Mtetra
.661 .565 .736 r
.35685 .33317 .36624 .35977 .38303 .35143 .37368 .32355 Mtetra
.673 .564 .724 r
.37368 .32355 .38303 .35143 .39997 .34109 .39065 .31232 Mtetra
.682 .565 .716 r
.39065 .31232 .39997 .34109 .41702 .32896 .40771 .29972 Mtetra
.689 .567 .712 r
.40771 .29972 .41702 .32896 .43416 .31534 .42484 .28606 Mtetra
.695 .57 .71 r
.42484 .28606 .43416 .31534 .45135 .3006 .44202 .27169 Mtetra
.7 .574 .711 r
.44202 .27169 .45135 .3006 .46856 .28511 .45922 .25693 Mtetra
.703 .58 .714 r
.45922 .25693 .46856 .28511 .48578 .26925 .47643 .24209 Mtetra
.706 .587 .72 r
.47643 .24209 .48578 .26925 .503 .25337 .49364 .22745 Mtetra
.708 .596 .728 r
.49364 .22745 .503 .25337 .52022 .23776 .51087 .21323 Mtetra
.709 .606 .739 r
.51087 .21323 .52022 .23776 .53745 .22267 .52812 .19961 Mtetra
.71 .617 .751 r
.52812 .19961 .53745 .22267 .55468 .20828 .5454 .18669 Mtetra
.709 .629 .765 r
.5454 .18669 .55468 .20828 .57195 .19471 .56272 .17452 Mtetra
.707 .641 .781 r
.56272 .17452 .57195 .19471 .58926 .182 .5801 .16313 Mtetra
.705 .654 .797 r
.5801 .16313 .58926 .182 .60663 .17017 .59755 .15248 Mtetra
.702 .668 .813 r
.59755 .15248 .60663 .17017 .62408 .15917 .61509 .14253 Mtetra
.698 .68 .829 r
.61509 .14253 .62408 .15917 .64161 .14894 .63271 .13318 Mtetra
.693 .692 .844 r
.63271 .13318 .64161 .14894 .65925 .13939 .65044 .12437 Mtetra
.689 .702 .857 r
.65044 .12437 .65925 .13939 .67699 .13044 .66829 .11601 Mtetra
.684 .711 .869 r
.66829 .11601 .67699 .13044 .69485 .12197 .68624 .108 Mtetra
.68 .718 .878 r
.68624 .108 .69485 .12197 .71283 .11391 .70432 .10028 Mtetra
.676 .724 .886 r
.70432 .10028 .71283 .11391 .73093 .10615 .72252 .09276 Mtetra
.673 .729 .892 r
.72252 .09276 .73093 .10615 .74915 .09862 .74084 .08541 Mtetra
.498 .72 .971 r
.08997 .32815 .10101 .3369 .11511 .33558 .10409 .32686 Mtetra
.459 .706 .974 r
.10409 .32686 .11511 .33558 .12924 .33502 .11825 .32626 Mtetra
.418 .688 .974 r
.11825 .32626 .12924 .33502 .14339 .33524 .13244 .32633 Mtetra
.381 .668 .971 r
.13244 .32633 .14339 .33524 .15759 .33622 .1467 .32702 Mtetra
.353 .647 .966 r
.1467 .32702 .15759 .33622 .17185 .33791 .16104 .32825 Mtetra
.34 .63 .959 r
.16104 .32825 .17185 .33791 .1862 .34021 .17548 .32987 Mtetra
.345 .617 .952 r
.17548 .32987 .1862 .34021 .20067 .34293 .19006 .33171 Mtetra
.368 .609 .942 r
.19006 .33171 .20067 .34293 .21528 .34586 .2048 .33351 Mtetra
.406 .603 .928 r
.2048 .33351 .21528 .34586 .23007 .34873 .21972 .33502 Mtetra
.451 .599 .907 r
.21972 .33502 .23007 .34873 .24506 .35123 .23487 .33594 Mtetra
.496 .594 .881 r
.23487 .33594 .24506 .35123 .26029 .35301 .25024 .33598 Mtetra
.538 .588 .853 r
.25024 .33598 .26029 .35301 .27576 .35375 .26587 .33488 Mtetra
.573 .583 .825 r
.26587 .33488 .27576 .35375 .29149 .35314 .28174 .33239 Mtetra
.602 .577 .799 r
.28174 .33239 .29149 .35314 .30748 .35092 .29785 .32834 Mtetra
.624 .573 .776 r
.29785 .32834 .30748 .35092 .32372 .3469 .31419 .32263 Mtetra
.642 .57 .758 r
.31419 .32263 .32372 .3469 .34018 .34099 .33073 .31526 Mtetra
.657 .568 .743 r
.33073 .31526 .34018 .34099 .35685 .33317 .34745 .30628 Mtetra
.668 .567 .732 r
.34745 .30628 .35685 .33317 .37368 .32355 .36432 .29586 Mtetra
.677 .568 .724 r
.36432 .29586 .37368 .32355 .39065 .31232 .38129 .2842 Mtetra
.685 .57 .72 r
.38129 .2842 .39065 .31232 .40771 .29972 .39835 .27157 Mtetra
.691 .573 .718 r
.39835 .27157 .40771 .29972 .42484 .28606 .41547 .25826 Mtetra
.695 .578 .719 r
.41547 .25826 .42484 .28606 .44202 .27169 .43263 .24455 Mtetra
.699 .584 .722 r
.43263 .24455 .44202 .27169 .45922 .25693 .44981 .23073 Mtetra
.702 .591 .728 r
.44981 .23073 .45922 .25693 .47643 .24209 .46701 .21703 Mtetra
.704 .599 .736 r
.46701 .21703 .47643 .24209 .49364 .22745 .48424 .20368 Mtetra
.705 .609 .747 r
.48424 .20368 .49364 .22745 .51087 .21323 .50148 .19081 Mtetra
.706 .62 .759 r
.50148 .19081 .51087 .21323 .52812 .19961 .51876 .17855 Mtetra
.705 .632 .773 r
.51876 .17855 .52812 .19961 .5454 .18669 .53608 .16693 Mtetra
.704 .645 .787 r
.53608 .16693 .5454 .18669 .56272 .17452 .55346 .15599 Mtetra
.702 .658 .803 r
.55346 .15599 .56272 .17452 .5801 .16313 .5709 .14571 Mtetra
.699 .67 .819 r
.5709 .14571 .5801 .16313 .59755 .15248 .58843 .13603 Mtetra
.695 .683 .834 r
.58843 .13603 .59755 .15248 .61509 .14253 .60605 .1269 Mtetra
.691 .694 .848 r
.60605 .1269 .61509 .14253 .63271 .13318 .62376 .11824 Mtetra
.687 .704 .86 r
.62376 .11824 .63271 .13318 .65044 .12437 .64159 .10998 Mtetra
.682 .712 .871 r
.64159 .10998 .65044 .12437 .66829 .11601 .65952 .10204 Mtetra
.678 .719 .88 r
.65952 .10204 .66829 .11601 .68624 .108 .67757 .09436 Mtetra
.675 .725 .887 r
.67757 .09436 .68624 .108 .70432 .10028 .69574 .08686 Mtetra
.672 .729 .893 r
.69574 .08686 .70432 .10028 .72252 .09276 .71403 .0795 Mtetra
.67 .733 .897 r
.71403 .0795 .72252 .09276 .74084 .08541 .73245 .07224 Mtetra
.504 .715 .966 r
.07883 .31902 .08997 .32815 .10409 .32686 .09299 .31765 Mtetra
.473 .702 .968 r
.09299 .31765 .10409 .32686 .11825 .32626 .1072 .31687 Mtetra
.445 .687 .968 r
.1072 .31687 .11825 .32626 .13244 .32633 .12146 .31663 Mtetra
.423 .67 .965 r
.12146 .31663 .13244 .32633 .1467 .32702 .13579 .31687 Mtetra
.411 .655 .959 r
.13579 .31687 .1467 .32702 .16104 .32825 .15022 .31746 Mtetra
.411 .641 .951 r
.15022 .31746 .16104 .32825 .17548 .32987 .16478 .31825 Mtetra
.426 .63 .939 r
.16478 .31825 .17548 .32987 .19006 .33171 .17948 .31905 Mtetra
.451 .62 .923 r
.17948 .31905 .19006 .33171 .2048 .33351 .19436 .31961 Mtetra
.483 .612 .903 r
.19436 .31961 .2048 .33351 .21972 .33502 .20943 .31969 Mtetra
.517 .604 .879 r
.20943 .31969 .21972 .33502 .23487 .33594 .22473 .31904 Mtetra
.55 .596 .853 r
.22473 .31904 .23487 .33594 .25024 .33598 .24025 .31742 Mtetra
.578 .589 .828 r
.24025 .31742 .25024 .33598 .26587 .33488 .25602 .31462 Mtetra
.603 .583 .804 r
.25602 .31462 .26587 .33488 .28174 .33239 .27201 .31049 Mtetra
.623 .578 .783 r
.27201 .31049 .28174 .33239 .29785 .32834 .28823 .30493 Mtetra
.64 .575 .766 r
.28823 .30493 .29785 .32834 .31419 .32263 .30466 .29792 Mtetra
.653 .573 .752 r
.30466 .29792 .31419 .32263 .33073 .31526 .32126 .28951 Mtetra
.664 .572 .741 r
.32126 .28951 .33073 .31526 .34745 .30628 .33802 .27981 Mtetra
.673 .573 .734 r
.33802 .27981 .34745 .30628 .36432 .29586 .3549 .26901 Mtetra
.68 .575 .729 r
.3549 .26901 .36432 .29586 .38129 .2842 .37187 .25732 Mtetra
.686 .578 .728 r
.37187 .25732 .38129 .2842 .39835 .27157 .38892 .24499 Mtetra
.691 .583 .729 r
.38892 .24499 .39835 .27157 .41547 .25826 .40602 .23227 Mtetra
.695 .589 .732 r
.40602 .23227 .41547 .25826 .43263 .24455 .42316 .21941 Mtetra
.698 .596 .738 r
.42316 .21941 .43263 .24455 .44981 .23073 .44033 .20663 Mtetra
.7 .604 .746 r
.44033 .20663 .44981 .23073 .46701 .21703 .45753 .1941 Mtetra
.702 .614 .756 r
.45753 .1941 .46701 .21703 .48424 .20368 .47476 .18198 Mtetra
.702 .625 .767 r
.47476 .18198 .48424 .20368 .50148 .19081 .49202 .17035 Mtetra
.702 .637 .781 r
.49202 .17035 .50148 .19081 .51876 .17855 .50933 .15928 Mtetra
.701 .649 .795 r
.50933 .15928 .51876 .17855 .53608 .16693 .5267 .14879 Mtetra
.699 .662 .81 r
.5267 .14879 .53608 .16693 .55346 .15599 .54413 .13887 Mtetra
.696 .674 .824 r
.54413 .13887 .55346 .15599 .5709 .14571 .56165 .12947 Mtetra
.693 .685 .839 r
.56165 .12947 .5709 .14571 .58843 .13603 .57925 .12055 Mtetra
.689 .696 .852 r
.57925 .12055 .58843 .13603 .60605 .1269 .59695 .11205 Mtetra
.685 .706 .863 r
.59695 .11205 .60605 .1269 .62376 .11824 .61475 .1039 Mtetra
.681 .714 .873 r
.61475 .1039 .62376 .11824 .64159 .10998 .63266 .09604 Mtetra
.677 .72 .882 r
.63266 .09604 .64159 .10998 .65952 .10204 .65068 .08839 Mtetra
.674 .726 .889 r
.65068 .08839 .65952 .10204 .67757 .09436 .66882 .08092 Mtetra
.671 .73 .894 r
.66882 .08092 .67757 .09436 .69574 .08686 .68708 .07356 Mtetra
.669 .733 .898 r
.68708 .07356 .69574 .08686 .71403 .0795 .70546 .06629 Mtetra
.668 .736 .901 r
.70546 .06629 .71403 .0795 .73245 .07224 .72397 .05906 Mtetra
.515 .711 .96 r
.06762 .30944 .07883 .31902 .09299 .31765 .08183 .30788 Mtetra
.494 .699 .961 r
.08183 .30788 .09299 .31765 .1072 .31687 .0961 .30679 Mtetra
.476 .686 .958 r
.0961 .30679 .1072 .31687 .12146 .31663 .11044 .30611 Mtetra
.465 .672 .954 r
.11044 .30611 .12146 .31663 .13579 .31687 .12487 .30575 Mtetra
.463 .659 .946 r
.12487 .30575 .13579 .31687 .15022 .31746 .13941 .30558 Mtetra
.471 .646 .934 r
.13941 .30558 .15022 .31746 .16478 .31825 .15409 .30542 Mtetra
.488 .635 .919 r
.15409 .30542 .16478 .31825 .17948 .31905 .16893 .30509 Mtetra
.51 .625 .9 r
.16893 .30509 .17948 .31905 .19436 .31961 .18396 .30437 Mtetra
.536 .615 .879 r
.18396 .30437 .19436 .31961 .20943 .31969 .19918 .30305 Mtetra
.561 .606 .855 r
.19918 .30305 .20943 .31969 .22473 .31904 .21463 .30091 Mtetra
.585 .598 .832 r
.21463 .30091 .22473 .31904 .24025 .31742 .23029 .29779 Mtetra
.606 .591 .811 r
.23029 .29779 .24025 .31742 .25602 .31462 .24618 .29354 Mtetra
.623 .586 .791 r
.24618 .29354 .25602 .31462 .27201 .31049 .26229 .28807 Mtetra
.638 .582 .775 r
.26229 .28807 .27201 .31049 .28823 .30493 .27859 .28134 Mtetra
.651 .58 .762 r
.27859 .28134 .28823 .30493 .30466 .29792 .29508 .2734 Mtetra
.661 .579 .752 r
.29508 .2734 .30466 .29792 .32126 .28951 .31173 .26434 Mtetra
.67 .579 .745 r
.31173 .26434 .32126 .28951 .33802 .27981 .3285 .2543 Mtetra
.677 .581 .74 r
.3285 .2543 .33802 .27981 .3549 .26901 .34539 .24346 Mtetra
.683 .584 .739 r
.34539 .24346 .3549 .26901 .37187 .25732 .36235 .23203 Mtetra
.688 .589 .74 r
.36235 .23203 .37187 .25732 .38892 .24499 .37939 .22023 Mtetra
.692 .595 .743 r
.37939 .22023 .38892 .24499 .40602 .23227 .39647 .20827 Mtetra
.695 .602 .748 r
.39647 .20827 .40602 .23227 .42316 .21941 .41359 .19634 Mtetra
.697 .611 .756 r
.41359 .19634 .42316 .21941 .44033 .20663 .43075 .1846 Mtetra
.698 .62 .766 r
.43075 .1846 .44033 .20663 .45753 .1941 .44795 .17318 Mtetra
.699 .631 .777 r
.44795 .17318 .45753 .1941 .47476 .18198 .46519 .16217 Mtetra
.699 .642 .79 r
.46519 .16217 .47476 .18198 .49202 .17035 .48248 .15162 Mtetra
.698 .654 .803 r
.48248 .15162 .49202 .17035 .50933 .15928 .49983 .14157 Mtetra
.696 .666 .817 r
.49983 .14157 .50933 .15928 .5267 .14879 .51724 .13199 Mtetra
.693 .678 .831 r
.51724 .13199 .5267 .14879 .54413 .13887 .53474 .12288 Mtetra
.69 .689 .844 r
.53474 .12288 .54413 .13887 .56165 .12947 .55232 .11417 Mtetra
.686 .699 .856 r
.55232 .11417 .56165 .12947 .57925 .12055 .56999 .10583 Mtetra
.683 .708 .867 r
.56999 .10583 .57925 .12055 .59695 .11205 .58777 .09779 Mtetra
.679 .715 .876 r
.58777 .09779 .59695 .11205 .61475 .1039 .60565 .09 Mtetra
.676 .722 .884 r
.60565 .09 .61475 .1039 .63266 .09604 .62365 .0824 Mtetra
.673 .727 .89 r
.62365 .0824 .63266 .09604 .65068 .08839 .64176 .07494 Mtetra
.671 .731 .895 r
.64176 .07494 .65068 .08839 .66882 .08092 .65998 .06759 Mtetra
.669 .734 .899 r
.65998 .06759 .66882 .08092 .68708 .07356 .67833 .0603 Mtetra
.667 .736 .901 r
.67833 .0603 .68708 .07356 .70546 .06629 .6968 .05305 Mtetra
.666 .738 .903 r
.6968 .05305 .70546 .06629 .72397 .05906 .71539 .04582 Mtetra
.531 .708 .952 r
.05634 .29936 .06762 .30944 .08183 .30788 .07062 .2975 Mtetra
.517 .697 .951 r
.07062 .2975 .08183 .30788 .0961 .30679 .08497 .296 Mtetra
.507 .685 .947 r
.08497 .296 .0961 .30679 .11044 .30611 .0994 .29477 Mtetra
.504 .672 .939 r
.0994 .29477 .11044 .30611 .12487 .30575 .11394 .2937 Mtetra
.508 .66 .929 r
.11394 .2937 .12487 .30575 .13941 .30558 .12861 .29267 Mtetra
.519 .649 .915 r
.12861 .29267 .13941 .30558 .15409 .30542 .14342 .29151 Mtetra
.534 .637 .899 r
.14342 .29151 .15409 .30542 .16893 .30509 .1584 .29004 Mtetra
.553 .627 .879 r
.1584 .29004 .16893 .30509 .18396 .30437 .17357 .28808 Mtetra
.573 .617 .859 r
.17357 .28808 .18396 .30437 .19918 .30305 .18894 .28545 Mtetra
.592 .609 .838 r
.18894 .28545 .19918 .30305 .21463 .30091 .20452 .28199 Mtetra
.609 .602 .818 r
.20452 .28199 .21463 .30091 .23029 .29779 .22032 .27759 Mtetra
.625 .596 .801 r
.22032 .27759 .23029 .29779 .24618 .29354 .23632 .27215 Mtetra
.638 .591 .785 r
.23632 .27215 .24618 .29354 .26229 .28807 .25251 .26565 Mtetra
.649 .589 .773 r
.25251 .26565 .26229 .28807 .27859 .28134 .26889 .2581 Mtetra
.659 .587 .763 r
.26889 .2581 .27859 .28134 .29508 .2734 .28542 .24959 Mtetra
.667 .588 .757 r
.28542 .24959 .29508 .2734 .31173 .26434 .30209 .24021 Mtetra
.674 .589 .752 r
.30209 .24021 .31173 .26434 .3285 .2543 .31887 .23013 Mtetra
.68 .592 .751 r
.31887 .23013 .3285 .2543 .34539 .24346 .33575 .21951 Mtetra
.685 .597 .752 r
.33575 .21951 .34539 .24346 .36235 .23203 .35271 .20854 Mtetra
.689 .603 .755 r
.35271 .20854 .36235 .23203 .37939 .22023 .36972 .1974 Mtetra
.692 .61 .76 r
.36972 .1974 .37939 .22023 .39647 .20827 .38679 .18625 Mtetra
.694 .618 .767 r
.38679 .18625 .39647 .20827 .41359 .19634 .4039 .17524 Mtetra
.695 .628 .777 r
.4039 .17524 .41359 .19634 .43075 .1846 .42106 .16448 Mtetra
.696 .638 .787 r
.42106 .16448 .43075 .1846 .44795 .17318 .43826 .15404 Mtetra
.695 .649 .799 r
.43826 .15404 .44795 .17318 .46519 .16217 .45552 .14399 Mtetra
.694 .66 .812 r
.45552 .14399 .46519 .16217 .48248 .15162 .47284 .13435 Mtetra
.693 .671 .825 r
.47284 .13435 .48248 .15162 .49983 .14157 .49023 .12512 Mtetra
.69 .682 .838 r
.49023 .12512 .49983 .14157 .51724 .13199 .5077 .11627 Mtetra
.687 .693 .85 r
.5077 .11627 .51724 .13199 .53474 .12288 .52525 .10777 Mtetra
.684 .702 .861 r
.52525 .10777 .53474 .12288 .55232 .11417 .5429 .09958 Mtetra
.681 .71 .871 r
.5429 .09958 .55232 .11417 .56999 .10583 .56065 .09164 Mtetra
.678 .717 .879 r
.56065 .09164 .56999 .10583 .58777 .09779 .5785 .08392 Mtetra
.675 .723 .886 r
.5785 .08392 .58777 .09779 .60565 .09 .59646 .07636 Mtetra
.672 .728 .892 r
.59646 .07636 .60565 .09 .62365 .0824 .61454 .06893 Mtetra
.67 .731 .896 r
.61454 .06893 .62365 .0824 .64176 .07494 .63274 .06158 Mtetra
.668 .734 .899 r
.63274 .06158 .64176 .07494 .65998 .06759 .65105 .05428 Mtetra
.667 .736 .902 r
.65105 .05428 .65998 .06759 .67833 .0603 .66948 .04701 Mtetra
.666 .738 .904 r
.66948 .04701 .67833 .0603 .6968 .05305 .68804 .03975 Mtetra
.665 .739 .905 r
.68804 .03975 .6968 .05305 .71539 .04582 .70672 .03248 Mtetra
.548 .705 .943 r
.045 .28875 .05634 .29936 .07062 .2975 .05936 .28651 Mtetra
.54 .695 .94 r
.05936 .28651 .07062 .2975 .08497 .296 .0738 .2845 Mtetra
.536 .684 .933 r
.0738 .2845 .08497 .296 .0994 .29477 .08834 .28264 Mtetra
.538 .672 .924 r
.08834 .28264 .0994 .29477 .11394 .2937 .103 .28082 Mtetra
.544 .661 .912 r
.103 .28082 .11394 .2937 .12861 .29267 .11779 .2789 Mtetra
.555 .65 .898 r
.11779 .2789 .12861 .29267 .14342 .29151 .13274 .27674 Mtetra
.569 .639 .881 r
.13274 .27674 .14342 .29151 .1584 .29004 .14787 .27418 Mtetra
.584 .629 .863 r
.14787 .27418 .1584 .29004 .17357 .28808 .16318 .27107 Mtetra
.599 .621 .845 r
.16318 .27107 .17357 .28808 .18894 .28545 .17868 .26728 Mtetra
.613 .613 .827 r
.17868 .26728 .18894 .28545 .20452 .28199 .19439 .26271 Mtetra
.627 .607 .811 r
.19439 .26271 .20452 .28199 .22032 .27759 .21029 .25726 Mtetra
.638 .602 .797 r
.21029 .25726 .22032 .27759 .23632 .27215 .22638 .25092 Mtetra
.649 .599 .785 r
.22638 .25092 .23632 .27215 .25251 .26565 .24265 .2437 Mtetra
.658 .598 .776 r
.24265 .2437 .25251 .26565 .26889 .2581 .25907 .23564 Mtetra
.665 .598 .77 r
.25907 .23564 .26889 .2581 .28542 .24959 .27563 .22683 Mtetra
.672 .599 .765 r
.27563 .22683 .28542 .24959 .30209 .24021 .29231 .21741 Mtetra
.677 .602 .764 r
.29231 .21741 .30209 .24021 .31887 .23013 .3091 .20751 Mtetra
.682 .606 .765 r
.3091 .20751 .31887 .23013 .33575 .21951 .32597 .19728 Mtetra
.686 .612 .768 r
.32597 .19728 .33575 .21951 .35271 .20854 .3429 .18687 Mtetra
.689 .619 .773 r
.3429 .18687 .35271 .20854 .36972 .1974 .3599 .17643 Mtetra
.691 .627 .78 r
.3599 .17643 .36972 .1974 .38679 .18625 .37696 .16608 Mtetra
.692 .636 .788 r
.37696 .16608 .38679 .18625 .4039 .17524 .39407 .15592 Mtetra
.693 .645 .798 r
.39407 .15592 .4039 .17524 .42106 .16448 .41123 .14602 Mtetra
.692 .656 .809 r
.41123 .14602 .42106 .16448 .43826 .15404 .42845 .13644 Mtetra
.691 .667 .821 r
.42845 .13644 .43826 .15404 .45552 .14399 .44574 .12718 Mtetra
.69 .677 .833 r
.44574 .12718 .45552 .14399 .47284 .13435 .4631 .11826 Mtetra
.687 .687 .844 r
.4631 .11826 .47284 .13435 .49023 .12512 .48053 .10966 Mtetra
.685 .697 .855 r
.48053 .10966 .49023 .12512 .5077 .11627 .49806 .10135 Mtetra
.682 .705 .865 r
.49806 .10135 .5077 .11627 .52525 .10777 .51567 .09331 Mtetra
.679 .713 .874 r
.51567 .09331 .52525 .10777 .5429 .09958 .53339 .08547 Mtetra
.676 .719 .882 r
.53339 .08547 .5429 .09958 .56065 .09164 .55121 .07782 Mtetra
.673 .725 .888 r
.55121 .07782 .56065 .09164 .5785 .08392 .56914 .0703 Mtetra
.671 .729 .893 r
.56914 .0703 .5785 .08392 .59646 .07636 .58718 .06288 Mtetra
.669 .732 .897 r
.58718 .06288 .59646 .07636 .61454 .06893 .60534 .05553 Mtetra
.668 .735 .9 r
.60534 .05553 .61454 .06893 .63274 .06158 .62362 .04823 Mtetra
.666 .737 .902 r
.62362 .04823 .63274 .06158 .65105 .05428 .64201 .04094 Mtetra
.666 .738 .904 r
.64201 .04094 .65105 .05428 .66948 .04701 .66053 .03365 Mtetra
.665 .739 .905 r
.66053 .03365 .66948 .04701 .68804 .03975 .67917 .02635 Mtetra
.664 .74 .906 r
.67917 .02635 .68804 .03975 .70672 .03248 .69794 .01903 Mtetra
.566 .703 .933 r
.03359 .27763 .045 .28875 .05936 .28651 .04805 .27494 Mtetra
.562 .693 .928 r
.04805 .27494 .05936 .28651 .0738 .2845 .06259 .27237 Mtetra
.562 .683 .92 r
.06259 .27237 .0738 .2845 .08834 .28264 .07725 .26984 Mtetra
.566 .672 .91 r
.07725 .26984 .08834 .28264 .103 .28082 .09203 .26724 Mtetra
.573 .662 .898 r
.09203 .26724 .103 .28082 .11779 .2789 .10695 .26445 Mtetra
.583 .651 .883 r
.10695 .26445 .11779 .2789 .13274 .27674 .12204 .26134 Mtetra
.594 .642 .868 r
.12204 .26134 .13274 .27674 .14787 .27418 .1373 .25778 Mtetra
.606 .633 .852 r
.1373 .25778 .14787 .27418 .16318 .27107 .15274 .25367 Mtetra
.618 .625 .836 r
.15274 .25367 .16318 .27107 .17868 .26728 .16836 .24891 Mtetra
.629 .619 .821 r
.16836 .24891 .17868 .26728 .19439 .26271 .18418 .24343 Mtetra
.639 .614 .809 r
.18418 .24343 .19439 .26271 .21029 .25726 .20017 .2372 Mtetra
.649 .611 .798 r
.20017 .2372 .21029 .25726 .22638 .25092 .21633 .23022 Mtetra
.657 .609 .789 r
.21633 .23022 .22638 .25092 .24265 .2437 .23265 .22254 Mtetra
.664 .609 .783 r
.23265 .22254 .24265 .2437 .25907 .23564 .24911 .21422 Mtetra
.67 .61 .779 r
.24911 .21422 .25907 .23564 .27563 .22683 .26569 .20536 Mtetra
.675 .613 .778 r
.26569 .20536 .27563 .22683 .29231 .21741 .28237 .19608 Mtetra
.679 .617 .778 r
.28237 .19608 .29231 .21741 .3091 .20751 .29915 .1865 Mtetra
.683 .622 .781 r
.29915 .1865 .3091 .20751 .32597 .19728 .31601 .17674 Mtetra
.686 .628 .786 r
.31601 .17674 .32597 .19728 .3429 .18687 .33294 .16694 Mtetra
.688 .636 .792 r
.33294 .16694 .3429 .18687 .3599 .17643 .34993 .15718 Mtetra
.689 .644 .8 r
.34993 .15718 .3599 .17643 .37696 .16608 .36698 .14756 Mtetra
.689 .654 .809 r
.36698 .14756 .37696 .16608 .39407 .15592 .38409 .13815 Mtetra
.689 .663 .82 r
.38409 .13815 .39407 .15592 .41123 .14602 .40127 .12897 Mtetra
.688 .673 .83 r
.40127 .12897 .41123 .14602 .42845 .13644 .41851 .12007 Mtetra
.687 .683 .841 r
.41851 .12007 .42845 .13644 .44574 .12718 .43583 .11144 Mtetra
.685 .692 .851 r
.43583 .11144 .44574 .12718 .4631 .11826 .45323 .10307 Mtetra
.682 .701 .861 r
.45323 .10307 .4631 .11826 .48053 .10966 .47072 .09494 Mtetra
.68 .709 .87 r
.47072 .09494 .48053 .10966 .49806 .10135 .4883 .08703 Mtetra
.677 .716 .878 r
.4883 .08703 .49806 .10135 .51567 .09331 .50599 .07929 Mtetra
.674 .721 .885 r
.50599 .07929 .51567 .09331 .53339 .08547 .52377 .0717 Mtetra
.672 .726 .89 r
.52377 .0717 .53339 .08547 .55121 .07782 .54167 .06421 Mtetra
.67 .73 .895 r
.54167 .06421 .55121 .07782 .56914 .0703 .55967 .05681 Mtetra
.668 .733 .898 r
.55967 .05681 .56914 .0703 .58718 .06288 .57779 .04946 Mtetra
.667 .735 .901 r
.57779 .04946 .58718 .06288 .60534 .05553 .59603 .04214 Mtetra
.666 .737 .903 r
.59603 .04214 .60534 .05553 .62362 .04823 .61439 .03483 Mtetra
.665 .738 .905 r
.61439 .03483 .62362 .04823 .64201 .04094 .63287 .02752 Mtetra
.665 .739 .906 r
.63287 .02752 .64201 .04094 .66053 .03365 .65147 .02019 Mtetra
.664 .74 .906 r
.65147 .02019 .66053 .03365 .67917 .02635 .6702 .01283 Mtetra
.664 .74 .907 r
.6702 .01283 .67917 .02635 .69794 .01903 .68905 .00543 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 324.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001A2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`006_oooonD000003?oooooU?l0000Kooooo`006_oo
ool00`00003oooooooooo`2@ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0T?oo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2@ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`0Kooooo`0300000?oooooooooo02;ooooo0ol0001=ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool04oooool2000002;ooooo0ol0000Dooooo`?o0000?oooool00ol0
003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0L000002L06ATI0_l00018000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0BoaTI6@030000000c<c<0<c<c02D0
<c<c0ol0000D01TI6@;o0000>P000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`030000
0?oooooooooo01/00000:P0I6AT2o`0004H000000oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo017o6ATI00<0000003<c<`0c<c<0:@0c<c<3o`0001<06ATI00?o0000000000000000
=`000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01X00000;@0I
6AT00ol00000000000000013000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0@oaTI6@030000000c<c<0<c<c02d0<c<c0ol0000A01TI6@;o0000=`000003ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0300000?oooooooooo01X00000;P0I6AT2o`0004<000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo013o6ATI00<0000003<c<`0c<c<0<00c<c<2
o`0001406ATI00?o0000000000000000=0000003ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0300000?oooooooooo01X00000<00I6AT00ol00000000000000010000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`0?oaTI6@030000000c<c<0<c<c01@0<c<c3000000C03<c
<`;o0000400I6AT2o`0003@000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`0I000001P06ATI1@00000E01TI6@03o`0000000000000003l000000oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo00ko6ATI00<0000003<c<`0c<c<04@0c<c<4000000`0
C4a<1000000A03<c<`03o`00000I6AT06ATI00l06ATI00?o0000000000000000<@000003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01T00000500I6AT01000003o0000
00000000000503<c<`04o`00000000000000000001806ATI0_l0000o000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`0>oaTI6@03o`00000c<c<0<c<c00h0<c<c0`00000D04a<
C004o`00000000000000000000h0<c<c1?l0000>01TI6@;o0000<@000003ooooo`03o`000?oooooo
oooo01Wooooo000Jooooo`0300000?oooooooooo01T000004@0I6AT3000000d0<c<c0`00000A01TI
6@;o0000?@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool03_lI6AT00`00
0000<c<c03<c<`0=03<c<`030000001<C4`0C4a<01T0C4a<0`00000?03<c<`;o00003P0I6AT2o`00
02l000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0I00000100
6ATI00<0000003<c<`0c<c<04@0c<c<3000001006ATI0_l0000k000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0=oaTI6@030000000c<c<0<c<c00`0<c<c0P00000O04a<C0<0
00003P0c<c<00ol000006ATI01TI6@0=01TI6@;o0000;@000003ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0300000?oooooooooo01T000003`0I6AT00`000000<c<c03<c<`0E03<c<`040000
0?l000000000000000h06ATI00?o0000000000000000>0000003ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool03OlI6AT00`000000<c<c03<c<`0;03<c<`030000001<C4`0C4a<0280
C4a<00<00000o`00000000000P00000:03<c<`?o00003P0I6AT2o`0002/000000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0I000000l06ATI00<0000003<c<`0c<c<0
6@0c<c<00`0000006ATI01TI6@0;01TI6@03o`0000000000000003P000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo00go6ATI00<0000003<c<`0c<c<02`0c<c<00`000000C4a<
04a<C00W04a<C08000002`0c<c<00ol000006ATI01TI6@0=01TI6@03o`0000000000000002P00000
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0I000000h06ATI00<0
000003<c<`0c<c<06`0c<c<2000000`06ATI0_l0000h000000?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`0=oaTI6@030000000c<c<0<c<c00X0<c<c00<0000004a<C01<C4`03@1<
C4`<00000140C4a<00<0000003<c<`0c<c<02@0c<c<2o`0000h06ATI00?o00000000000000009`00
0003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01T000003@0I6AT0
0`000000<c<c03<c<`0N03<c<`030000000I6AT06ATI00/06ATI00?o0000000000000000=@000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool03OlI6AT00`000000<c<c03<c<`09
03<c<`030000001<C4`0C4a<00/0C4a<0`00000<06IVIPL000002`1<C4`3000000X0<c<c00?o0000
01TI6@0I6AT0300I6AT00ol0000000000000000V000000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool06@00000<01TI6@030000000c<c<0<c<c0200<c<c00?o00000000
000000002`0I6AT2o`0003D000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
00go6ATI00<0000003<c<`0c<c<02@0c<c<00ol00000C4a<04a<C00904a<C08000005P1VIVH30000
00/0C4a<00?o000003<c<`0c<c<0200c<c<2o`0000d06ATI0ol0000U000000?ooooo00?o0000oooo
ooooool06Oooool001[ooooo00<00000ooooooooool06@00000<01TI6@030000000c<c<0<c<c00d0
<c<c2000000>03<c<`030000000I6AT06ATI00X06ATI00?o0000000000000000<P000003ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool03OlI6AT00`000000<c<c03<c<`0903<c<`03
0000001<C4`0C4a<00P0C4a<00<0000006IVIP1VIVH06@1VIVH3000000T0C4a<0P00000:03<c<`03
o`00000I6AT06ATI00d06ATI00?o00000000000000008P000003ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0300000?oooooooooo01T00000300I6AT00`000000<c<c03<c<`0:03<c<`<00000
201<C4`3000000`0<c<c0P00000;01TI6@03o`00000000000000034000000oooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo00go6ATI00<0000003<c<`0c<c<02@0c<c<00`000000C4a<
04a<C00804a<C0030000001VIVH0IVIV01`0IVIV0P00000904a<C0030000000c<c<0<c<c00P0<c<c
00?o000001TI6@0I6AT03@0I6AT00ol0000000000000000Q000000?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool06@00000;01TI6@030000000c<c<0<c<c00T0<c<c0P00
000>04a<C0@000002P0c<c<00`0000006ATI01TI6@0901TI6@03o`00000000000000030000000ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00go6ATI00<0000003<c<`0c<c<0200c
<c<00`000000C4a<04a<C00804a<C0030000001VIVH0IVIV01l0IVIV0P00000804a<C0<00000200c
<c<2o`0000h06ATI00?o000000000000000080000003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`0300000?oooooooooo01T000002`0I6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0
C4a<0180C4a<00?o0000000000000000200c<c<00ol00000000001TI6@0901TI6@;o0000<0000003
ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool03OlI6AT00`000000<c<c03<c<`08
03<c<`030000001<C4`0C4a<00L0C4a<00<0000006IVIP1VIVH0301VIVH<000000X0IVIV00?o0000
000000000000201<C4`00ol0000000000000000703<c<`;o00003@0I6AT00ol0000000000000000O
000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool06@00000;01TI
6@030000000c<c<0<c<c00P0<c<c00<0000004a<C01<C4`05@1<C4`00`000000<c<c03<c<`0703<c
<`030000000I6AT06ATI00T06ATI00?o0000000000000000;@000003ooooo`0300000?oooooooooo
037ooooo00?o0000ooooooooool03OlI6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<
00H0C4a<00<0000006IVIP1VIVH02P1VIVH3000000`0Ogmo0`00000:06IVIP8000002@1<C4`00`00
0000<c<c03<c<`0603<c<`;o0000300I6AT2o`0001l000000oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00`00003oooooooooo`0J000000X06ATI00<0000003<c<`0c<c<01`0c<c<00`000000
C4a<04a<C00G04a<C0<000001`0c<c<00`0000006ATI01TI6@0901TI6@03o`0000000000000002`0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00ko6ATI00<0000003<c<`0c
<c<01P0c<c<00`000000C4a<04a<C00604a<C0030000001VIVH0IVIV00T0IVIV0P00000B07moO`@0
0000201VIVH3000000L0C4a<00<0000003<c<`0c<c<01`0c<c<2o`0000`06ATI0_l0000M000000?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool06P00000:01TI6@030000
000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`06`1<C4`00ol00000<c<c03<c<`0503<c<`03o`00
00000000000000T06ATI0_l0000/000000?ooooo00<00000ooooooooool0<Oooool01?l0003ooooo
ooooo`00000=oaTI6@030000000c<c<0<c<c00H0<c<c00<0000004a<C01<C4`01P1<C4`00ol00000
IVIV06IVIP0706IVIP03o`0000000000Ogmo01L0Ogmo1000000706IVIP8000001P1<C4`00ol00000
000003<c<`0803<c<`03o`00000I6AT06ATI00/06ATI00?o00000000000000006P000003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01X000002P0I6AT00`000000<c<c
03<c<`0603<c<`030000001<C4`0C4a<00P0C4a<3000000804a<C0800000200c<c<00`0000006ATI
01TI6@0801TI6@03o`0000000000000002T000000oooool00`00003oooooooooo`0aooooo`04o`00
0?oooooooooo000000go6ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00604a<C003
0000001VIVH0IVIV00L0IVIV00<0000007moO`1oOgl06`1oOgl2000000L0IVIV0P00000604a<C003
0000000c<c<0<c<c00L0<c<c00?o000001TI6@0I6AT02P0I6AT2o`0001/000000oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0J000000X06ATI00<0000003<c<`0c<c<0
1P0c<c<00`000000C4a<04a<C00604a<C0800000301VIVH3000000L0C4a<0P00000703<c<`030000
000I6AT06ATI00P06ATI00?o0000000000000000:0000003ooooo`0300000?oooooooooo037ooooo
00Co0000ooooooooool000003OlI6AT00`000000<c<c03<c<`0603<c<`030000001<C4`0C4a<00H0
C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo07moO`0N07moO`8000001`1VIVH2000000D0
C4a<0P00000803<c<`03o`00000I6AT06ATI00/06ATI0_l0000I000000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool06P00000:01TI6@030000000c<c<0<c<c00D0<c<c
00<0000004a<C01<C4`01P1<C4`00`000000IVIV06IVIP0?06IVIP030000001<C4`0C4a<00H0C4a<
00?o000003<c<`0c<c<01@0c<c<00`0000006ATI01TI6@0701TI6@03o`0000000000000002P00000
0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo008000003?lI6AT00`000000<c<c
03<c<`0703<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo
07moO`0907moO`/00000301oOgl2000000L0IVIV00<0000004a<C01<C4`0101<C4`2000000L0<c<c
0_l0000=01TI6@03o`0000000000000001H000000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`0I00000003o`00000I6AT06ATI00P06ATI00<0000003<c<`0c<c<01@0c
<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV0140IVIV00?o00000000000000001P1<
C4`2000000H0<c<c00?o000001TI6@0I6AT01`0I6AT00ol0000000000000000W000000?ooooo00<0
0000ooooooooool0<Oooool00ol0003oooooooooo`02000000go6ATI00?o000003<c<`0c<c<01P0c
<c<00`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01`1o
Ogl3000000/0VIVI1`00000707moO`03o`00001VIVH0IVIV00D0IVIV00?o00000000001<C4`01@1<
C4`2000000L0<c<c0_l0000;01TI6@;o00005`000003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`0300000?oooooooooo01X000002P0I6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0
C4a<00D0C4a<00<0000006IVIP1VIVH0501VIVH00`000000C4a<04a<C00504a<C0030000000c<c<0
<c<c00@0<c<c00<0000001TI6@0I6AT01`0I6AT00ol0000000000000000V000000?ooooo00<00000
ooooooooool0<Oooool00ol0003oooooooooo`02000000go6ATI00<0000003<c<`0c<c<01P0c<c<0
0`000000C4a<04a<C00504a<C0030000001VIVH0IVIV00D0IVIV00<0000007moO`1oOgl01P1oOgl0
0`000000VIVI09VIV@0C09VIV@030000001oOgl0Ogmo00D0Ogmo0P00000706IVIP030000001<C4`0
C4a<00D0C4a<0P00000703<c<`03o`00000I6AT06ATI00X06ATI00?o000000000000000050000003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01X000002P0I6AT00`00
0000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH05P1VIVH20000
00H0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@03o`00000000000000
02D000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00<000003?lI6AT00`00
0000<c<c03<c<`0603<c<`030000001<C4`0C4a<00D0C4a<00<0000006IVIP1VIVH01@1VIVH00`00
0000Ogmo07moO`0507moO`030000002IVIT0VIVI01D0VIVI0`00000607moO`8000001P1VIVH00`00
0000C4a<04a<C00604a<C0030000000c<c<0<c<c00D0<c<c00?o000001TI6@0I6AT02P0I6AT00ol0
000000000000000C000000?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooooooo
ool06`00000901TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`01@1<C4`00`000000
IVIV06IVIP0606IVIP/000001`1VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00@0
<c<c00<0000001TI6@0I6AT01`0I6AT00ol0000000000000000T000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`03000000go6ATI00<0000003<c<`0c<c<01P0c<c<00`000000
C4a<04a<C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000
VIVI09VIV@0I09VIV@0300000?l00000Ogmo00D0Ogmo0P00000506IVIP8000001P1<C4`00`000000
<c<c03<c<`0603<c<`03o`00000I6AT06ATI00X06ATI00?o00000000000000004P000003ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01/000002@0I6AT00`000000<c<c
03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01P1VIVH00`000000Ogmo
07moO`0907moO`03o`0000000000000000D0IVIV00?o0000000000000000101<C4`00ol000000000
03<c<`0403<c<`03o`00000000006ATI00L06ATI0_l0000T000000?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`0300000003o`000?lI6AWo6ATI00[o6ATI00<0000003<c<`0c<c<0
1P0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl0
1@1oOgl00ol00000VIVI09VIV@0:09VIV@P000002@2IVIT2000000H0Ogmo0P00000506IVIP800000
1@1<C4`2000000L0<c<c0_l0000;01TI6@;o00004P000003ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo01/000002@0I6AT00`000000<c<c03<c<`0403<c<`030000001<
C4`0C4a<00@0C4a<00<0000006IVIP1VIVH01@1VIVH00ol00000Ogmo07moO`0=07moO`8000001P1V
IVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00<0000001TI6@0I6AT01`0I
6AT00ol0000000000000000Q000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`05000000_o6ATI00<0000003<c<`0c<c<01P0c<c<00`000000C4a<04a<C00404a<C0030000001V
IVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VIV@0709VIV@<00000202c
/k<4000000L0VIVI0`00000507moO`8000001@1VIVH2000000D0C4a<0P00000703<c<`03o`00000I
6AT06ATI00X06ATI00?o00000000000000003`000003ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`0300000?oooooooooo01`000002@0I6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0
C4a<00<0C4a<00<0000006IVIP1VIVH0101VIVH00`000000Ogmo07moO`0@07moO`<00000101VIVH2
000000@0C4a<00<0000003<c<`0c<c<0100c<c<00`0000006ATI01TI6@0701TI6@03o`0000000000
0000020000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00D000003?lI6AT0
0`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH0101VIVH0
0`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00H0VIVI0P00000?0;>c/`<000001`2IVIT0
0`00003o000007moO`0407moO`030000001VIVH0IVIV00@0IVIV00<0000004a<C01<C4`0101<C4`0
0`000000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00X06ATI00?o00000000000000003P000003
ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01d00000200I6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00`1VIVH00`00
0000Ogmo07moO`0D07moO`03o`00001VIVH0IVIV00<0IVIV00<0000004a<C01<C4`00P1<C4`00ol0
0000000003<c<`0403<c<`03o`00000I6AT06ATI00L06ATI00?o00000000000000007`000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool01P00000;oaTI6@030000000c<c<0<c<c
00H0<c<c00?o000004a<C01<C4`00`1<C4`00`00003o000006IVIP0406IVIP030000001oOgl0Ogmo
00@0Ogmo00<0000009VIV@2IVIT01@2IVIT00ol00000/k>c0;>c/`0B0;>c/`<000001P2IVIT30000
00<0Ogmo00?o0000000000000000101VIVH00ol00000000004a<C00404a<C003o`00000c<c<0<c<c
00D0<c<c0_l0000;01TI6@03o`0000000000000000d000000oooool00ol0003oooooooooo`0Ioooo
o`006_ooool00`00003oooooooooo`0M000000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl01@1oOgl8000000P0
Ogmo0P00000406IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<00`0c<c<00`000000
6ATI01TI6@0701TI6@03o`0000000000000001h000000oooool00`00003oooooooooo`0aooooo`03
o`000?oooooooooo00H000003?lI6AT00ol00000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0
C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0407moO`030000002IVIT0VIVI00D0
VIVI00<000000;>c/`2c/k<05@2c/k<00`000000VIVI09VIV@0609VIV@030000001oOgl0Ogmo00<0
Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C08000001`0c<c<00ol00000
6ATI01TI6@0901TI6@03o`0000000000000000`000000oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`0M000000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<
04a<C00304a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1oOgl0101oOgl00`000000VIVI
09VIV@0609VIV@<000001`1oOgl00`000000IVIV06IVIP0206IVIP800000101<C4`00`000000<c<c
03<c<`0303<c<`030000000I6AT06ATI00L06ATI00?o00000000000000007@000003ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool01`00000;oaTI6@030000000c<c<0<c<c00D0<c<c
00<0000004a<C01<C4`0101<C4`00`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo00@0Ogmo
00<0000009VIV@2IVIT0102IVIT00`000000/k>c0;>c/`0G0;>c/`<000001P2IVIT00`000000Ogmo
07moO`0307moO`800000101VIVH00`000000C4a<04a<C00404a<C0030000000c<c<0<c<c00D0<c<c
00?o000001TI6@0I6AT02@0I6AT00ol0000000000000000;000000?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool07P00000801TI6@030000000c<c<0<c<c00<0<c<c00<0
000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00@0Ogmo00<0
000009VIV@2IVIT02P2IVIT3000000D0Ogmo00?o000006IVIP1VIVH00`1VIVH00`000000C4a<04a<
C00204a<C003o`00000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01P0I6AT00ol0000000000000
000M000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`07000000co6ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0
000007moO`1oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@030000002c/k<0/k>c00P0/k>c2`00
00070;>c/`0300000?l00000VIVI00@0VIVI00<0000007moO`1oOgl0101oOgl00`000000IVIV06IV
IP0206IVIP8000001@1<C4`00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00T06ATI00?o
00000000000000002P000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo01h00000200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<00<0C4a<00<00000
06IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`03o`00002IVIT0VIVI00h0VIVI0P000004
07moO`800000101VIVH2000000<0C4a<0P00000403<c<`8000001`0I6AT00ol0000000000000000L
000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`08000000_o6ATI00<00000
03<c<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<00000
07moO`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00H0/k>c00?o0000
0000000000002`3<c<`00ol000000000000000060;>c/`<000000`2IVIT00ol00000000000000004
07moO`03o`0000000000IVIV00<0IVIV00<0000004a<C01<C4`00`1<C4`2000000H0<c<c00?o0000
01TI6@0I6AT02@0I6AT00ol00000000000000009000000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool07P00000801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<
C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo00<0Ogmo00<0000009VI
V@2IVIT0402IVIT2000000@0Ogmo00<0000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<
C0030000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000000K0000
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`08000000_o6ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007mo
O`1oOgl00`1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00H0/k>c00<000000<c<
c03<c<`03P3<c<`00`000000/k>c0;>c/`060;>c/`800000102IVIT00`000000Ogmo07moO`0307mo
O`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`0101<C4`00`000000<c<c03<c<`0403<c
<`03o`00000I6AT06ATI00T06ATI0_l00009000000?ooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool07`00000801TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<
C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT0202IVIT4000000L0VIVI00<0000007moO`1oOgl00P1oOgl2000000@0IVIV00<0000004a<C01<
C4`00P1<C4`00ol00000<c<c03<c<`0303<c<`030000000I6AT06ATI00D06ATI0_l0000K000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`09000000_o6ATI00<0000003<c<`0c
<c<01@0c<c<00`000000C4a<04a<C00404a<C0030000001VIVH0IVIV00<0IVIV00<0000007moO`1o
Ogl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00D0/k>c00<000000<c<c03<
c<`0403<c<`3000000L0/k>c00<0000009VIV@2IVIT00P2IVIT2000000@0Ogmo00<0000006IVIP1V
IVH00P1VIVH2000000D0C4a<00?o000003<c<`0c<c<0100c<c<2o`0000/06ATI00?o000000000000
00001P000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo01l00000
200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00@0VIVI100000040;>c/`030000
0?l000000000008000000`2IVIT00ol0000000000000000307moO`03o`00001VIVH0IVIV0080IVIV
00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00H06ATI
00?o000000000000000060000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
2P00000;oaTI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV
06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00`2IVIT00`000000/k>c
0;>c/`040;>c/`030000003<c<`0c<c<01@0c<c<0`0000050;>c/`800000102IVIT2000000<0Ogmo
00?o00000000001VIVH00`1VIVH00ol00000C4a<04a<C00304a<C08000001P0c<c<00ol000006ATI
01TI6@0901TI6@03o`0000000000000000D000000oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`0O000000P06ATI00<0000003<c<`0c<c<00`0c<c<00`000000C4a<04a<
C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VI
V@0309VIV@030000002c/k<0/k>c00/0/k>c0P00000409VIV@040000001oOgl0Ogmo07moO`800000
0`1VIVH01@000000C4a<04a<C01<C4`0000000D0<c<c00<0000001TI6@0I6AT01P0I6AT00ol00000
00000000000H000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0:000000co
6ATI00?o000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00<0
IVIV00<0000007moO`1oOgl00P1oOgl00`000000VIVI09VIV@0309VIV@030000002c/k<0/k>c00@0
/k>c00<000000<c<c03<c<`05`3<c<`2000000D0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000
Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV0P00000504a<C0030000000c<c<0<c<c00@0
<c<c00?o000001TI6@0I6AT02@0I6AT00ol00000000000000004000000?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool08000000801TI6@030000000c<c<0<c<c0080<c<c
00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVH0000000@0Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`0>0;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1o
Ogl00P1oOgl01@000000IVIV06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<00`0c<c<00`00
00006ATI01TI6@0601TI6@03o`0000000000000001L000000oooool00`00003oooooooooo`0aoooo
o`03o`000?oooooooooo00/000002olI6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<
00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0307moO`030000002IVIT0VIVI
0080VIVI00<000000;>c/`2c/k<0102c/k<00`000000c<c<0<c<c0060<c<c0_o0000203<c<`20000
00@0/k>c00<0000009VIV@2IVIT00`2IVIT00`000000Ogmo07moO`0207moO`030000001VIVH0IVIV
00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI
00T06ATI00?o00000000000000000`000003ooooo`03o`000?oooooooooo01Wooooo000Jooooo`03
00000?oooooooooo02000000200I6AT00`000000<c<c03<c<`0303<c<`030000001<C4`0C4a<0080
C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<03`2c/k<00ol00000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00D0000006IV
IP1VIVH0IVIV0000000304a<C0800000100c<c<00`0000006ATI01TI6@0601TI6@03o`0000000000
000001H000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00/0000000?o0000
oaTI6OlI6AT02OlI6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<00000
06IVIP1VIVH00`1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<00000
0;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0060<c<c003o`00003Vi^H0i^KV00T0i^KV0ol00007
0<c<c0030000002c/k<0/k>c0080/k>c0P00000409VIV@030000001oOgl0Ogmo0080Ogmo00?o0000
06IVIP1VIVH00`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c00?o0000
01TI6@0I6AT02@0I6AT00ol00000000000000002000000?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool08@00000801TI6@030000000c<c<0<c<c0080<c<c00<0000004a<
C01<C4`00P1<C4`01Ol00000IVIV06IVIP1VIVH0000000@0Ogmo00<0000009VIV@2IVIT00P2IVIT0
0`000000/k>c0;>c/`0@0;>c/`8000000`2IVIT00ol00000Ogmo07moO`0207moO`050000001VIVH0
IVIV06IVIP000000101<C4`00`000000<c<c03<c<`0203<c<`03o`00000000006ATI00H06ATI00?o
00000000000000005@000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool03000
000;oaTI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`00ol00000IVIV06IV
IP0206IVIP030000001oOgl0Ogmo0080Ogmo00?o000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c
/`020;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H03@3Vi^H00ol00000c<c<0<c<
c0050<c<c0800000102c/k<2000000<0VIVI0P00000307moO`030000001VIVH0IVIV00<0IVIV00<0
000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00T06ATI00Co
000000000000000000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0Q000000P06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C0050000001V
IVH0IVIV06IVIP000000101oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00@0/k>c
1`0000070;>c/`040000002IVIT0VIVI09VIV@8000000`1oOgl01@000000IVIV06IVIP1VIVH00000
00@0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@03o`00000000000000
01D000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo00`000002olI6AT00`00
0000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI00<000000;>c/`2c/k<00P2c/k<00`00
0000c<c<0<c<c0050<c<c003o`00003Vi^H0i^KV00h0i^KV0ol000060<c<c0030000002c/k<0/k>c
00<0/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1oOgl0000000D0IVIV00<00000
04a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00T06ATI00?o0000
0000000000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`0R0000
00L06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00<00000
07moO`1oOgl00P1oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c00<0/k>c00<00000
0<c<c03<c<`01@3<c<`4000000@0/k>c00<0000009VIV@2IVIT00P2IVIT01@000000Ogmo07moO`1o
Ogl0000000<0IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`0203<c<`030000000I
6AT06ATI00D06ATI00?o000000000000000050000003ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool03@00000;oaTI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<
C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2I
VIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00D0c<c<00?o00000>KViP3Vi^H04@3V
i^H2o`0000D0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@040000001o
Ogl0Ogmo07moO`800000101VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c
00?o000001TI6@0I6AT02@0I6AT00ol000000000ooooo`02ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo02800000200I6AT00`000000<c<c03<c<`0203<c<`030000001<
C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`050000002IVIT0VIVI09VIV@00
00001@2c/k<00`000000c<c<0<c<c00:0<c<c003o`00002c/k<0/k>c0080/k>c00<0000009VIV@2I
VIT00P2IVIT01P000000Ogmo07moO`1oOgl00000o`000080IVIV00Go000004a<C01<C4`0C4a<0000
000503<c<`030000000I6AT06ATI00D06ATI00?o00000000000000004`000003ooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool03P00000;oaTI6@030000000c<c<0<c<c00@0<c<c00<0
000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0
000009VIV@2IVIT00`2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00@0c<c<00?o
00000>KViP3Vi^H04`3Vi^H00ol00000c<c<0<c<c0030<c<c003o`00002c/k<0/k>c00<0/k>c00<0
000009VIV@2IVIT00P2IVIT00ol00000Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0
000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`03o`00000I6AT06ATI00T06ATI00Go
0000ooooooooooooooooo`00000Kooooo`006_ooool00`00003oooooooooo`0S000000L06ATI00<0
000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00D0000007moO`1oOgl0
Ogmo0000000309VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0303<c<`300000080
/k>c00?o00000000000000000P2IVIT200000080Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<
C0800000100c<c<00`0000006ATI01TI6@0501TI6@03o`00000000000000018000000oooool00`00
003oooooooooo`0aooooo`03o`000?oooooooooo00h0000000?o0000oaTI6OlI6AT02?lI6AT00ol0
0000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`00
0000c<c<0<c<c0040<c<c003o`00003Vi^H0i^KV01@0i^KV0ol000030<c<c0<000000`2c/k<20000
00<0VIVI00<0000007moO`1oOgl00P1oOgl00ol00000IVIV06IVIP0206IVIP030000001<C4`0C4a<
00<0C4a<00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0901TI6@04o`000?oooooooooo
o`0001_ooooo000Jooooo`0300000?oooooooooo02<000001`0I6AT00`000000<c<c03<c<`0303<c
<`050000001<C4`0C4a<04a<C00000000`1VIVH01@000000Ogmo07moO`1oOgl0000000<0VIVI00<0
00000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c00?0<c<c08000000`2c/k<01@000000VIVI09VI
V@2IVIT000000080Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<C0030000000c<c<0<c<c0080
<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000000A000000?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0?000000_o6ATI00<0000003<c<`0c<c<0100c<c<00`000000
C4a<04a<C00404a<C005o`00001VIVH0IVIV06IVIP000000101oOgl00`000000VIVI09VIV@0209VI
V@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`0103<c<`00ol00000i^KV0>KViP090>KV
iPCo00002P3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00D0000009VI
V@2IVIT0VIVI0000000407moO`8000000`1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0
<c<c00@0<c<c0_l0000901TI6@?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooo
ooooool09000000701TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<00000003
06IVIP050000001oOgl0Ogmo07moO`0000000`2IVIT01@000000/k>c0;>c/`2c/k<0000000P0c<c<
1Ol000060<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT010000000Ogmo07moO`00000306IV
IP030000001<C4`0C4a<0080C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI
6@03o`00000000000000010000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
010000002olI6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IV
IP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c
/`2c/k<00P2c/k<00`000000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00L0i^KV0_l000040?oo
o`Co00001`3Vi^H00ol00000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00@0000009VI
V@2IVIT0VIVI0P00000407moO`050000001VIVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c
<`0503<c<`03o`00000I6AT06ATI00H06ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`0T000000L06ATI00<00000o`00000c<c<00`0c<c<01@000000C4a<04a<C01<
C4`0000000<0IVIV00D0000007moO`1oOgl0Ogmo0000000309VIV@050000002c/k<0/k>c0;>c/`00
00001P3<c<`2o`0000D0i^KV0_l000050<c<c005o`00002c/k<0/k>c0;>c/`0000000`2IVIT01000
0000Ogmo07moO`00000306IVIP050000001<C4`0C4a<04a<C00000001@0c<c<00ol000006ATI01TI
6@0501TI6@03o`0000000000000000l000000oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo014000002olI6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0
000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<0
00000;>c/`2c/k<00P2c/k<00`000000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00H0i^KV00?o
00000?ooo`3oool0203oool00ol00000i^KV0>KViP050>KViP;o0000103<c<`00ol00000/k>c0;>c
/`020;>c/`030000002IVIT0VIVI0080VIVI00<0000007moO`1oOgl00P1oOgl01_l00000IVIV06IV
IP1VIVKo0000000000@0C4a<00?o000003<c<`0c<c<01@0c<c<00ol000006ATI01TI6@0501TI6@?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool09000000801TI6@030000
000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000306IVIP050000001oOgl0Ogmo07mo
O`0000000`2IVIT01@000000/k>c0;>c/`2c/k<0000000H0c<c<00?o00000>KViP3Vi^H01P3Vi^H2
o`0000<0c<c<0P0000030;>c/`040000002IVIT0VIVI000000<0Ogmo00@0000006IVIP1VIVH00000
101<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00@06ATI00?o0000000000000000
3`000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool04@00000;oaTI6@030000
000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0306IVIP05o`00
001oOgl0Ogmo07moO`000000102IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<0080
c<c<00?o00000>KViP3Vi^H01P3Vi^H00ol00000oooo0?ooo`090?ooo`;o00001`3Vi^H00ol00000
c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000
Ogmo07moO`0207moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`00`000000
<c<c03<c<`0503<c<`03o`00000I6AT06ATI00@06ATI0oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`0U000000P06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<
04a<C01<C4`0000000<0IVIV00@0000007moO`1oOgl000000`2IVIT01@000000/k>c0;>c/`2c/k<0
000000D0c<c<00?o00000>KViP3Vi^H02@3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0
/k>c0;>c/`0000000P2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00<0000004a<C01<C4`0
0P1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00D06ATI00?o0000000000000000
3P000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool04P00000;oaTI6@030000
000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000
001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT01@000000/k>c0;>c/`2c/k<0000000D0
c<c<00?o00000>KViP3Vi^H01@3Vi^H00ol00000oooo0?ooo`0;0?ooo`03o`00003Vi^H0i^KV00D0
i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080
VIVI00D0000007moO`1oOgl0Ogmo0000000506IVIP030000001<C4`0C4a<0080C4a<00<0000003<c
<`0c<c<0100c<c<00ol000006ATI01TI6@0401TI6@?ooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool09@00000801TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<
C4`0C4a<0000000306IVIP040000001oOgl0Ogmo000000<0VIVI00D000000;>c/`2c/k<0/k>c0000
00050<c<c003o`00003Vi^H0i^KV00X0i^KV00?o00000<c<c03<c<`00P3<c<`01@000000/k>c0;>c
/`2c/k<000000080VIVI00D0000007moO`1oOgl0Ogmo0000000206IVIP030000001<C4`0C4a<0080
C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@03o`0000000000000000d0
00000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo0180000000?o0000oaTI6OlI
6AT02OlI6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1V
IVH00P1VIVH01@000000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00P2c/k<00`00
0000c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00D0i^KV00?o00000?ooo`3oool0303oool2o`00
00H0i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`03o`00002IVIT0VIVI
0080VIVI00D0000007moO`1oOgl0Ogmo0000000506IVIP03o`00001<C4`0C4a<0080C4a<00<00000
03<c<`0c<c<0100c<c<00ol000006ATI01TI6@0301TI6@?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool09P00000801TI6@030000000c<c<0<c<c0080<c<c00D0000004a<
C01<C4`0C4a<0000000306IVIP040000001oOgl0Ogmo000000<0VIVI00@000000;>c/`2c/k<00000
103<c<`00ol00000i^KV0>KViP0<0>KViP03o`00003<c<`0c<c<0080c<c<0P0000020;>c/`040000
002IVIT0VIVI000000<0Ogmo00D0000006IVIP1VIVKo00000000000304a<C0030000000c<c<0<c<c
0080<c<c00<0000001TI6@0I6AT01@0I6AT00ol0000000000000000<000000?ooooo00<00000oooo
ooooool0<Oooool00ol0003oooooooooo`0D000000_o6ATI00<0000003<c<`0c<c<0100c<c<00`00
0000C4a<04a<C00304a<C003o`00001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo00000004
09VIV@030000002c/k<0/k>c0080/k>c00<000000<c<c03<c<`00P3<c<`00ol00000i^KV0>KViP04
0>KViP03o`00003oool0oooo00h0oooo0_l000050>KViP03o`00003<c<`0c<c<0080c<c<00?o0000
0000002c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moOol00000101V
IVH00`000000C4a<04a<C00304a<C003o`00000c<c<0<c<c00@0<c<c00?o000001TI6@0I6AT00P0I
6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo02H00000200I6AT0
0`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH010000000Ogmo07mo
O`00000309VIV@040000002c/k<0/k>c000000@0c<c<00?o00000>KViP3Vi^H03@3Vi^H2o`0000@0
c<c<00@000000;>c/`2c/k<000000P2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00<00000
04a<C01<C4`00P1<C4`01@000000<c<c03<c<`0c<c<0000000P06ATI00?o00000000000000002`00
0003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool05@00000:oaTI6@030000000c
<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001o
Ogl0Ogmo0080Ogmo00Go000009VIV@2IVIT0VIVI000000040;>c/`030000003<c<`0c<c<0080c<c<
00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0@0?ooo`;o0000103Vi^H00ol00000c<c<
0<c<c0030<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT010000000Ogmo07moO`1oOgl20000
00<0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`;o00000P0I6AT3oooo
o`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo02L00000200I6AT00`000000
<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C00000000`1VIVH010000000Ogmo07moO`000003
09VIV@040000002c/k<0/k>c000000@0c<c<00?o00000>KViP3Vi^H03P3Vi^H2o`0000<0c<c<00@0
00000;>c/`2c/k<000000P2IVIT01@000000Ogmo07moO`1oOgl000000080IVIV00<0000004a<C01<
C4`00P1<C4`010000000<c<c03<c<`0c<c<2000000L06ATI00?o00000000000000002P000003oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool05P00000:oaTI6@030000000c<c<0<c<c
00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo
0080Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`030000003<c<`0c<c<0080c<c<00?o0000
0>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`0A0?ooo`03o`00003Vi^H0i^KV0080i^KV0_l00004
0<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT00ol00000Ogmo07moO`0207moO`050000001V
IVH0IVIV06IVIP0000001@1<C4`00`000000<c<c03<c<`0503<c<`03o`00000I6AWooooo00;ooooo
00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0:000000701TI6@030000000c
<c<0<c<c00<0<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP050000001oOgl0Ogmo07moO`00
00000P2IVIT010000000/k>c0;>c/`0000040<c<c003o`00003Vi^H0i^KV00@0i^KV1_l000060>KV
iP05o`00003<c<`0c<c<0<c<c00000000P2c/k<01?l00000VIVI09VIVOl0000307moO`04o`00001V
IVH0IVIVo`0000@0C4a<00?o000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@03o`00
00000000000000T000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01L00000
2_lI6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH0
0P1VIVH00`000000Ogmo07moO`0207moO`050000002IVIT0VIVI09VIV@000000102c/k<00`000000
c<c<0<c<c0020<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool04P3oool00ol00000
i^KV0>KViP030>KViP03o`00003<c<`0c<c<0080c<c<00Ko00000;>c/`2c/k<0/k>co`0000000003
09VIV@030000001oOgl0Ogmo0080Ogmo00H0000006IVIP1VIVH0IVIVo`000000000404a<C0030000
000c<c<0<c<c00D0<c<c00Go0000ooooooooooooooooo`00000Kooooo`006_ooool00`00003ooooo
ooooo`0X00000003o`00000I6AT06ATI00@06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<
04a<C01<C4`000000080IVIV00D0000007moO`1oOgl0Ogmo0000000209VIV@040000002c/k<0/k>c
000000@0c<c<00?o00000>KViP3Vi^H0103Vi^H00ol00000oooo0?ooo`020?ooo`;o00001@3Vi^H0
1Ol00000c<c<0<c<c03<c<`000000080/k>c00D0000009VIV@2IVIT0VIVI0000000307moO`040000
001VIVH0IVIV000000<0C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI6@03
o`0000000000000000T000000oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo01L0
00002_lI6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<00Go000006IVIP1V
IVH0IVIV0000000407moO`050000002IVIT0VIVI09VIV@000000102c/k<00ol00000c<c<0<c<c002
0<c<c003o`00003Vi^H0i^KV00<0i^KV00?o00000?ooo`3oool04`3oool00ol00000i^KV0>KViP03
0>KViP05o`00003<c<`0c<c<0<c<c0000000102c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo
00<0000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00304a<C0030000000c<c<0<c<c00@0<c<c
00Go0000ooooooooooooooooo`00000Kooooo`006_ooool00`00003oooooooooo`0Y000000L06ATI
00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`000000080IVIV00D0000007moO`1o
Ogl0Ogmo0000000209VIV@040000002c/k<0/k>c000000<0c<c<00?o00000>KViP3Vi^H0103Vi^H0
0ol00000oooo0?ooo`040?ooo`03o`00003Vi^H0i^KV00<0i^KV00Go00000<c<c03<c<`0c<c<0000
00020;>c/`050000002IVIT0VIVI09VIV@0000000P1oOgl010000000IVIV06IVIP00000304a<C003
0000000c<c<0<c<c00<0<c<c00<0000001TI6@0I6AT01@0I6AT00ol00000000000000008000000?o
oooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0H000000[o6ATI00<0000003<c<`0c
<c<01@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0000007moO`1o
Ogl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00P3<c<`00ol0
0000i^KV0>KViP030>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H0103Vi^H01Ol0
0000c<c<0<c<c03<c<`0000000@0/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`030000001V
IVH0IVIV0080IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c<`0403<c<`04o`000?oo
ooooooooo`0001_ooooo000Jooooo`0300000?oooooooooo02X000001`0I6AT00`000000<c<c03<c
<`0203<c<`050000001<C4`0C4a<04a<C00000000P1VIVH01@000000Ogmo07moO`1oOgl000000080
VIVI00@000000;>c/`2c/k<00000103<c<`00ol00000i^KV0>KViP020>KViP03o`00003oool0oooo
00H0oooo0ol000030>KViP05o`00003<c<`0c<c<0<c<c00000000P2c/k<01@000000VIVI09VIV@2I
VIT000000080Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`0303<c<`03o`00
000I6AT06ATI00D06ATI00?o00000000000000001`000003ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool06@00000:oaTI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0
0`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00D0000009VIV@2IVIT0
VIVI000000040;>c/`050000003<c<`0c<c<0<c<c?l000001P3Vi^H00ol00000oooo0?ooo`0B0?oo
o`03o`00003Vi^H0i^KV00@0i^KV00Go00000<c<c03<c<`0c<c<000000040;>c/`050000002IVIT0
VIVI09VIVOl00000101oOgl00`000000IVIV06IVIP0206IVIP030000001<C4`0C4a<00<0C4a<00<0
000003<c<`0c<c<00`0c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo02X00000200I6AT00`000000<c<c03<c<`0203<c<`05o`00001<C4`0C4a<04a<C?l000000P1V
IVH01?l00000Ogmo07moOol0000309VIV@040000002c/k<0/k>c000000<0c<c<00?o00000>KViP3V
i^H00P3Vi^H00ol00000oooo0?ooo`090?ooo`04o`00003Vi^H0i^KV0>KViP;o00000P3<c<`01000
0000/k>c0;>c/ol0000309VIV@04o`00001oOgl0Ogmo00000080IVIV00D0000004a<C01<C4`0C4a<
o`00000403<c<`030000000I6AT06ATI00H06ATI00?o00000000000000001P000003ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool06@0000000ol0003o6ATIoaTI6@08oaTI6@030000
000c<c<0<c<c00@0<c<c00<00000o`00001<C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000
001oOgl0Ogmo0080Ogmo00Go000009VIV@2IVIT0VIVI000000040;>c/`040000003<c<`0c<c<0<c<
c0;o00001@3Vi^H00ol00000oooo0?ooo`0B0?ooo`03o`00003Vi^H0i^KV00@0i^KV00Go00000<c<
c03<c<`0c<c<o`0000040;>c/`050000002IVIT0VIVI09VIV@000000101oOgl00`000000IVIV06IV
IP0206IVIP030000001<C4`0C4a<00<0C4a<00<0000003<c<`0c<c<00P0c<c<3ooooo`03o`000?oo
oooooooo01Wooooo000Jooooo`0300000?oooooooooo02X00000200I6AT00`000000<c<c03<c<`02
03<c<`050000001<C4`0C4a<04a<C00000000P1VIVH010000000Ogmo07moO`00000309VIV@040000
002c/k<0/k>co`0000<0c<c<00?o00000>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`090?ooo`03
o`00003Vi^H0i^KV0080i^KV00Co00000<c<c03<c<`000000`2c/k<01`000000VIVI09VIV@2IVIT0
000007moO`0000000`1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c00<0000001TI6@0I6AT0
1P0I6AT00ol00000000000000006000000?ooooo00<00000ooooooooool0<Oooool00ol0003ooooo
ooooo`0J000000[o6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0050000
001VIVH0IVIV06IVIP000000101oOgl00`000000VIVI09VIV@0209VIV@030000002c/k<0/k>c0080
/k>c00Go00000<c<c03<c<`0c<c<o`0000050>KViP03o`00003oool0oooo01<0oooo00?o00000>KV
iP3Vi^H00`3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`000000102IVIT0
1@000000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000<c<c03<c
<`0203<c<`?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0:`000008
01TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP040000001o
Ogl0Ogmo000000<0VIVI00<000000;>c/`0000000`3<c<`00ol00000i^KV0>KViP020>KViP03o`00
003oool0oooo00X0oooo00?o00000>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c00000020;>c/`05
0000002IVIT0VIVI09VIV@0000000P1oOgl01@000000IVIV06IVIP1VIVH000000080C4a<00<00000
03<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0601TI6@03o`0000000000000000D000000oooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo01/000002_lI6AT00`000000<c<c03<c<`05
03<c<`030000001<C4`0C4a<00<0C4a<00D0000006IVIP1VIVH0IVIV0000000407moO`030000002I
VIT0VIVI0080VIVI00D000000;>c/`2c/k<0/k>c000000040<c<c003o`00003Vi^H0i^KV00<0i^KV
00?o00000?ooo`3oool04P3oool00ol00000i^KV0>KViP040>KViP05o`00003<c<`0c<c<0<c<c000
0000102c/k<00`000000VIVI09VIV@0209VIV@050000001oOgl0Ogmo07moO`000000101VIVH00`00
0000C4a<04a<C00304a<C0040000000c<c<0<c<c03<c<`?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool0;000000701TI6@030000000c<c<0<c<c0080<c<c00D0000004a<
C01<C4`0C4a<0000000206IVIP040000001oOgl0Ogmo000000<0VIVI00@000000;>c/`2c/k<00000
0`3<c<`00ol00000i^KV0>KViP020>KViP03o`00003oool0oooo00X0oooo00Go00000>KViP3Vi^H0
i^KVo`0000030<c<c0040000002c/k<0/k>c000000<0VIVI00@0000007moO`1oOgl000000P1VIVH0
1@000000C4a<04a<C01<C4`0000000@0<c<c00<0000001TI6@0I6AT01P0I6AT00ol0000000000000
0004000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0L000000[o6ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00204a<C0030000001VIVH0IVIV0080IVIV00<0
000007moO`1oOgl00P1oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`0
0P3<c<`00ol00000i^KV0>KViP030>KViP03o`00003oool0oooo0180oooo00?o00000>KViP3Vi^H0
0`3Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT0
0P2IVIT01Ol00000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C01<C4`00`1<C4`00`000000
<c<c03<c<`03ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo02`00000
00?o000001TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C000
00000P1VIVH010000000Ogmo07moO`00000309VIV@040000002c/k<0/k>c00000080c<c<00?o0000
0>KViP3Vi^H00P3Vi^H00ol00000oooo0?ooo`0;0?ooo`05o`00003Vi^H0i^KV0>KVi_l000000`3<
c<`00ol00000/k>c0;>c/`020000000309VIV@000000Ogmo0080Ogmo00@0000006IVIP1VIVH00000
0`1<C4`00`000000<c<c03<c<`0203<c<`03o`00000000006ATI00D06ATI00?o0000000000000000
10000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0700000000ol0003o6ATI
oaTI6@08oaTI6@0300000?l00000<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV
06IVIP0206IVIP0300000?l00000Ogmo0080Ogmo00Co000009VIV@2IVIT0VIVI0P0000030;>c/`03
0000003<c<`0c<c<0080c<c<00?o00000>KViP3Vi^H00`3Vi^H00ol00000oooo0?ooo`0B0?ooo`03
o`00003Vi^H0i^KV00<0i^KV00?o00000<c<c03<c<`00P3<c<`2000000<0/k>c00D0000009VIV@2I
VIT0VIVI0000000407moO`030000001VIVH0IVIV0080IVIV00?o000004a<C01<C4`00`1<C4`00`00
0000<c<cooooo`02ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo02d0
00001`0I6AT00`000000<c<c03<c<`0203<c<`050000001<C4`0C4a<04a<C?l000000`1VIVH01?l0
0000Ogmo07moO`00000209VIV@040000002c/k<0/k>c00000080c<c<00?o00000>KViP3Vi^H00P3V
i^H00ol00000oooo0?ooo`0<0?ooo`05o`00003Vi^H0i^KV0>KVi_l000000`3<c<`01`000000/k>c
0;>c/`2c/k<0000009VIV@0000000P1oOgl010000000IVIV06IVIP00000404a<C0030000000c<c<0
<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AT00ol00000000000000003000000?ooooo00<00000
ooooooooool0<Oooool00ol0003oooooooooo`0N000000_o6ATI00<0000003<c<`0c<c<0100c<c<0
0`000000C4a<04a<C00204a<C0030000001VIVH0IVIV00<0IVIV00D0000007moO`1oOgl0Ogmo0000
000409VIV@060000002c/k<0/k>c0;>c/ol0000000000`3<c<`00ol00000i^KV0>KViP030>KViP;o
00004P3oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<00<0c<c<00D000000;>c/`2c
/k<0/k>c0000000309VIV@030000001oOgl0Ogmo0080Ogmo00<0000006IVIP1VIVH00P1VIVH00`00
0000C4a<04a<C00204a<C0030000000c<c?ooooo00;ooooo00?o0000ooooooooool06Oooool001[o
oooo00<00000ooooooooool0;P00000701TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<
C4`0C4a<0000000306IVIP040000001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k<000000P3<
c<`00ol00000i^KV0>KViP020>KViP03o`00003oool0oooo00`0oooo00Go00000>KViP3Vi^H0i^KV
o`0000030<c<c0040000002c/k<0/k>c00000080VIVI00Co000007moO`1oOgl000000P1VIVH00`00
0000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AT00ol0
0000000000000002000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0O0000
00_o6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00204a<C0800000101VIVH01@00
0000Ogmo07moO`1oOgl0000000@0VIVI00<000000;>c/`2c/k<00P2c/k<01@000000c<c<0<c<c03<
c<co000000H0i^KV00?o00000?ooo`3oool0403oool00ol00000i^KV0>KViP040>KViP03o`00003<
c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo
00?o000006IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C00500000?ooooooooooooooool0
00006oooool001[ooooo00<00000ooooooooool0;`00000701TI6@030000000c<c<0<c<c0080<c<c
00Go000004a<C01<C4`0C4a<0000000306IVIP070000001oOgl0Ogmoo`00002IVIT00000o`000002
0;>c/`040000003<c<`0c<c<o`0000@0i^KV00?o00000?ooo`3oool0303oool01Ol00000i^KV0>KV
iP3Vi^Ko000000<0c<c<00@000000;>c/`2c/k<000000P2IVIT010000000Ogmo07moO`00000206IV
IP03o`0000000000C4a<0080C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0501TI
6@04o`00000000000000000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0P
000000_o6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0
IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000409VIV@03o`00002c/k<0/k>c0080/k>c00@0
00000<c<c03<c<`0c<c<0_l000050>KViP03o`00003oool0oooo0100oooo00?o00000>KViP3Vi^H0
103Vi^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0
VIVIo`00000407moO`030000001VIVH0IVIV0080IVIV00<0000004a<C01<C4`00P1<C4`01000003o
ooooooooool0000Kooooo`006_ooool00`00003oooooooooo`0_000000L06ATI00?o000003<c<`0c
<c<00P0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00@0000007moO`1oOgl000000P2IVIT0
10000000/k>c0;>c/`0000030<c<c005o`00003Vi^H0i^KV0>KVi_l000003P3oool01Ol00000i^KV
0>KViP3Vi^Ko000000<0c<c<00@000000;>c/`2c/k<000000P2IVIT010000000Ogmo07moO`000003
06IVIP050000001<C4`0C4a<04a<C0000000100c<c<00`0000006ATI01TI6@0501TI6@04o`000000
00000000000000?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0P000000_o6ATI
00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C00304a<C0050000001VIVH0IVIV06IVI_l0
0000101oOgl01@000000VIVI09VIV@2IVIT0000000@0/k>c00<000000<c<c03<c<`00`3<c<`00ol0
0000i^KV0>KViP030>KViP;o0000403oool00ol00000i^KV0>KViP040>KViP03o`00003<c<`0c<c<
0080c<c<00<000000;>c/`2c/k<00P2c/k<01@000000VIVI09VIV@2IVIT0000000@0Ogmo00<00000
06IVIP1VIVH00P1VIVH00`000000C4a<04a<C00204a<C0?ooooo00?o0000ooooooooool06Oooool0
01[ooooo00<00000ooooooooool0<000000601TI6@030000000c<c<0<c<c00<0<c<c00D0000004a<
C01<C4`0C4a<0000000306IVIP040000001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k<00000
0P3<c<`00ol00000i^KV0>KViP020>KViP03o`00003oool0oooo00`0oooo00Go00000>KViP3Vi^H0
i^KVo`0000030<c<c0040000002c/k<0/k>c00000080VIVI00@0000007moO`1oOgl000000`1VIVH0
1@000000C4a<04a<C01<C4`0000000@0<c<c00<0000001TI6@0I6AT0100I6AT01?l0000000000000
00000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool08P00000:oaTI6@030000
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00`1<C4`01@000000IVIV06IVIP1VIVH0000000@0
Ogmo00D0000009VIV@2IVIT0VIVI000000040;>c/`800000103<c<`00ol00000i^KV0>KViP040>KV
iP03o`00003oool0oooo00d0oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000c<c<0<c<c0030<c<
c0030000002c/k<0/k>c0080/k>c00D0000009VIV@2IVIT0VIVI0000000407moO`030000001VIVH0
IVIV0080IVIV00@0000004a<C01<C4`0C4a<0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`0`000000L06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C002
04a<C0040000001VIVH0IVIV00000080Ogmo00@0000009VIV@2IVIT000000P2c/k<01@000000c<c<
0<c<c03<c<co000000<0i^KV00?o00000?ooo`3oool0303oool00ol00000i^KV0>KViP020>KViP07
o`00003<c<`0c<c<0<c<c?l00000/k>c0000000209VIV@050000001oOgl0Ogmo07moO`0000000P1V
IVH01@000000C4a<04a<C01<C4`0000000@0<c<c00?o000001TI6@0I6AT01@0I6AT00ol000000000
00000003ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool08`00000:oaTI6@030000
000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000
001oOgl0Ogmo0080Ogmo00@0000009VIV@2IVIT0VIVI0P0000040;>c/`030000003<c<`0c<c<0080
c<c<00?o00000>KViP3Vi^H0103Vi^H2o`0000h0oooo00?o00000>KViP3Vi^H0103Vi^H00ol00000
c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01@000000
Ogmo07moO`1oOgl0000000@0IVIV00Co000004a<C01<C4`0C4a<0oooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0a000000L06ATI00<0000003<c<`0c<c<00P0c<c<01@00
003o000004a<C01<C4co000000<0IVIV00@0000007moO`1oOgl000000P2IVIT010000000/k>c0;>c
/`0000030<c<c005o`00003Vi^H0i^KV0>KVi_l000003P3oool00ol00000i^KV0>KViP020>KViP04
o`00003<c<`0c<c<00000080/k>c00@0000009VIV@2IVIWo00000`1oOgl01?l00000IVIV06IVIP00
000304a<C003o`00000c<c<0<c<c0080<c<c00<0000001TI6@0I6AT01@0I6AT00ol000000000oooo
o`02ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool08`0000000ol0003o6ATIoaTI
6@08oaTI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IV
IP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c
/`020;>c/`030000003<c<`0c<c<0080c<c<0_l000060>KViP;o0000303oool00ol00000i^KV0>KV
iP050>KViP03o`00003<c<`0c<c<0080c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VI
V@0209VIV@050000001oOgl0Ogmo07moOol00000101VIVH00`000000C4a<04a<C003ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo038000001`0I6AT01@000000<c<c03<c
<`0c<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`050000002IVIT0VIVI09VI
VOl000000P2c/k<010000000c<c<0<c<c?l000040>KViP03o`00003oool0oooo00/0oooo00?o0000
0>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c00000020;>c/`050000002IVIT0VIVI09VIV@000000
0P1oOgl010000000IVIV06IVIP00000404a<C0050000000c<c<0<c<c03<c<`0000001`0I6AT00ol0
00000000ooooo`02ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool09@00000:oaTI
6@03o`00000c<c<0<c<c00@0<c<c00?o000004a<C01<C4`00`1<C4`00`000000IVIV06IVIP0206IV
IP03o`00001oOgl0Ogmo0080Ogmo00<0000009VIV@2IVIT00P2IVIT01P000000/k>c0;>c/`2c/k?o
0000000000D0c<c<00?o00000>KViP3Vi^H01@3Vi^H2o`0000X0oooo00?o00000>KViP3Vi^H01@3V
i^H00ol00000c<c<0<c<c0020<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2I
VIT00`000000Ogmo07moO`0207moO`050000001VIVH0IVIV06IVIP0000000P1<C4`3ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo03<000001`0I6AT01@000000<c<c03<c
<`0c<c<0000000<0C4a<00D0000006IVIP1VIVH0IVIV0000000207moO`040000002IVIT0VIVI0000
00<0/k>c00@000000<c<c03<c<co00000`3Vi^H00ol00000oooo0?ooo`0<0?ooo`03o`00003Vi^H0
i^KV0080i^KV00Co00000<c<c03<c<`000000P2c/k<010000000VIVI09VIV@00000207moO`050000
001VIVH0IVIV06IVIP0000000`1<C4`00`000000<c<c03<c<`0203<c<`030000000I6AT06ATI00D0
6ATI00Go0000oooooooooooooooo0000000cooooo`03o`000?oooooooooo02D000002olI6AT00`00
0000<c<c03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`00
0000Ogmo07moO`0207moO`030000002IVIT0VIVI0080VIVI00<000000;>c/`2c/k<00P2c/k<00`00
0000c<c<0<c<c0030<c<c003o`00003Vi^H0i^KV00H0i^KV0_l000050?ooo`?o0000203Vi^H00ol0
0000c<c<0<c<c0030<c<c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT01@00
0000Ogmo07moO`1oOgl0000000@0IVIV00<0000004a<C?ooool00_ooool00ol0003oooooooooo`0I
ooooo`006_ooool00`00003oooooooooo`0d000000H06ATI00<0000003<c<`0c<c<00P0c<c<01@00
0000C4a<04a<C01<C4`0000000<0IVIV00@0000007moO`1oOgl000000P2IVIT010000000/k>c0;>c
/`0000030<c<c005o`00003Vi^H0i^KV0>KVi_l000003@3oool00ol00000i^KV0>KViP020>KViP04
o`00003<c<`0c<c<00000080/k>c00D0000009VIV@2IVIT0VIVI0000000207moO`040000001VIVH0
IVIV000000@0C4a<00D0000003<c<`0c<c<0<c<c0000000801TI6@04o`000?oooooooooo000003?o
oooo00?o0000ooooooooool09P00000;oaTI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<
C4`00`1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00P2IVIT00`000000/k>c0;>c/`020;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3V
i^H01`3Vi^H5o`0000`0i^KV00?o00000<c<c03<c<`00P3<c<`00`000000/k>c0;>c/`020;>c/`03
0000002IVIT0VIVI0080VIVI00?o000007moO`1oOgl00P1oOgl00`000000IVIV06IVIP0206IVIP05
00000?ooooooooooooooool000006oooool001[ooooo00<00000ooooooooool0<`0000000ol00000
6ATI01TI6@0501TI6@030000000c<c<0<c<c0080<c<c00H0000004a<C01<C4`0C4a<00000?l00002
06IVIP040000001oOgl0Ogmo00000080VIVI00@000000;>c/`2c/k<000000`3<c<`01Ol00000i^KV
0>KViP3Vi^Ko000000d0oooo00?o00000>KViP3Vi^H00P3Vi^H01?l00000c<c<0<c<c00000020;>c
/`040000002IVIT0VIVI000000<0Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000<c<c03<c
<`0203<c<`03o`00000000006ATI00D06ATI0oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo02P000002_lI6AT00`00003o000003<c<`0403<c<`0300000?l00000C4a<00<0C4a<0P00
000306IVIP0300000?l00000Ogmo0080Ogmo00?o00000000002IVIT00P2IVIT00`000000/k>c0;>c
/`020;>c/`800000103<c<`3o`0001L0i^KV00?o00000<c<c03<c<`00`3<c<`00`000000/k>c0;>c
/`020;>c/`03o`00002IVIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo0000000506IVIP04o`00
0?ooooooooooo`0001_ooooo000Jooooo`0300000?oooooooooo03D000001P0I6AT00`000000<c<c
03<c<`0303<c<`05o`00001<C4`0C4a<04a<C00000000P1VIVH01Ol00000Ogmo07moO`1oOgoo0000
0080VIVI00@000000;>c/`2c/k<000000`3<c<`01?l00000i^KV0>KViP3Vi^H2o`0000/0oooo00?o
00000>KViP3Vi^H00`3Vi^H00ol00000c<c<000000030;>c/`030000002IVIT0000000<0Ogmo00@0
000006IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00@06ATI
0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo02T000002olI6AT00`000000<c<c
03<c<`0403<c<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo
07moO`0207moO`060000002IVIT0VIVI09VIVOl000000000102c/k<2000000D0c<c<0_l0000E0>KV
iP03o`00003<c<`0c<c<00<0c<c<00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VI
V@050000001oOgl0Ogmo07moO`0000001@1VIVH3ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0300000?oooooooooo03H000001P0I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<
04a<C00000000P1VIVH01@000000Ogmo07moO`1oOgl000000080VIVI00@000000;>c/`2c/k<00000
0`3<c<`00ol00000i^KV0>KViP020>KViP03o`00003oool0oooo00T0oooo00?o00000>KViP3Vi^H0
0P3Vi^H01?l00000c<c<0<c<c?l000030;>c/`03o`00002IVIT0000000<0Ogmo00@0000006IVIP1V
IVH000000`1<C4`00`000000<c<c03<c<`0303<c<`030000000I6AT06ATI00<06ATI0oooool00`00
003oooooooooo`0aooooo`03o`000?oooooooooo02X000002olI6AT00`000000<c<c03<c<`0403<c
<`030000001<C4`0C4a<00<0C4a<00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207mo
O`8000000`2IVIT2000000@0/k>c00<000000<c<c03<c<`0103<c<`2o`000180i^KV00?o00000<c<
c03<c<`01@3<c<`01@000000/k>c0;>c/`2c/k<0000000D0VIVI00D0000007moO`1oOgl0Ogmo0000
000406IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0=`000006
01TI6@0300000?l00000<c<c00<0<c<c00D0000004a<C01<C4`0C4a<0000000206IVIP050000001o
Ogl0Ogmo07moO`0000000P2IVIT01?l00000/k>c0;>c/ol000030<c<c003o`00003Vi^H0i^KV0080
i^KV00?o00000?ooo`3oool0203oool00ol00000i^KV0>KViP020>KViP05o`00003<c<`0c<c<0<c<
c00000000P2c/k<010000000VIVI09VIV@00000307moO`04o`00001VIVH0IVIVo`0000<0C4a<00<0
000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0301TI6@?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`0[000000_o6ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00304a<C08000000`1VIVH00`00003o000007moO`0307moO`030000002IVIT0VIVI0080VIVI0P00
00030;>c/`03o`0000000000c<c<00D0c<c<0_l0000@0>KViP03o`00003<c<`0c<c<00D0c<c<00<0
00000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo00@0
000006IVIP1VIVH0IVIV0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0f00000003o`00000I6AT06ATI00D06ATI00<0000003<c<`0c<c<00P0c<c<01@000000C4a<04a<
C01<C4`0000000<0IVIV00L0000007moO`1oOgl0Ogmo0000002IVIT0000000<0/k>c00@000000<c<
c03<c<co00001@3Vi^H2o`0000P0oooo00?o00000>KViP3Vi^H00P3Vi^H01Ol00000c<c<0<c<c03<
c<`000000080/k>c00@0000009VIV@2IVIT000000`1oOgl01@000000IVIV06IVIP1VIVH000000080
C4a<00<0000003<c<`0c<c<00P0c<c<00`0000006ATI01TI6@0301TI6@?ooooo00<00000oooooooo
ool0<Oooool00ol0003oooooooooo`0[000000_o6ATI00?o00000000000c<c<01@0c<c<00`000000
C4a<04a<C00404a<C0030000001VIVH0IVIV0080IVIV00D0000007moO`1oOgl0Ogmo0000000609VI
V@030000002c/k<0/k>c0080/k>c0P0000060<c<c0?o00003@3Vi^H00ol00000c<c<0<c<c0050<c<
c0030000002c/k<0/k>c0080/k>c00<0000009VIV@2IVIT00P2IVIT00`000000Ogmo07moO`0207mo
O`040000001VIVH0IVIV06IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000oooo
ooooool0=`00000801TI6@030000000c<c<0<c<c0080<c<c00D0000004a<C01<C4`0C4a<00000003
06IVIP070000001oOgl0Ogmo07moO`000000VIVI000000030;>c/`040000003<c<`0c<c<o`0000H0
i^KV0_l000050?ooo`03o`00003Vi^H0i^KV00<0i^KV00Go00000<c<c03<c<`0c<c<000000030;>c
/`040000002IVIT0VIVI00000080Ogmo00D0000006IVIP1VIVH0IVIV0000000304a<C0030000000c
<c<0<c<c0080<c<c00<0000001TI6@0I6AT00P0I6AT3ooooo`0300000?oooooooooo037ooooo00?o
0000ooooooooool0;@00000;oaTI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`0101<
C4`00`000000IVIV06IVIP0206IVIP040000001oOgl0Ogmo07moO`8000001@2IVIT00`000000/k>c
0;>c/`030;>c/`030000003<c<`0c<c<00H0c<c<0ol000090>KViP03o`00003<c<`0c<c<00H0c<c<
00<000000;>c/`2c/k<00P2c/k<00`000000VIVI09VIV@0309VIV@030000001oOgl0Ogmo0080Ogmo
00<0000006IVIP1VIVH00oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0h000000L06ATI00<0000003<c<`0c<c<00`0c<c<01@000000C4a<04a<C01<C4`000000080IVIV
00D0000007moO`1oOgl0Ogmo0000000209VIV@050000002c/k<0/k>c0;>c/`0000000P3<c<`2o`00
00H0i^KV0ol000000`3ooooo00000>KViP060>KViP05o`00003<c<`0c<c<0<c<c00000000P2c/k<0
10000000VIVI09VIV@00000307moO`050000001VIVH0IVIV06IVIP0000000P1<C4`00`000000<c<c
03<c<`0203<c<`030000000I6AT06ATI00806ATI0oooool00`00003oooooooooo`0aooooo`03o`00
0?oooooooooo02h000002olI6AT00`000000<c<c03<c<`0403<c<`030000001<C4`0C4a<00@0C4a<
00<0000006IVIP1VIVH00P1VIVH00`000000Ogmo07moO`0207moO`030000002IVIT0VIVI00<0VIVI
00<000000;>c/`2c/k<00`2c/k<00`000000c<c<0<c<c0080<c<c0Co00000P3Vi^H3o`0000T0c<c<
00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0209VIV@030000001oOgl0Ogmo0080Ogmo
00<0000006IVIP1VIVH00oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooooooo
o`0i000000L06ATI00<0000003<c<`0c<c<00`0c<c<01Ol00000C4a<04a<C01<C4`000000080IVIV
0P00000207moO`040000002IVIT0VIVIo`0000<0/k>c00Go00000<c<c03<c<`0c<c<o`0000080>KV
iP03o`00003Vi^H0i^KV00H0i^KV00Go00000<c<c03<c<`0c<c<000000030;>c/`040000002IVIT0
VIVI000000<0Ogmo00@0000006IVIP1VIVH000000`1<C4`00`000000<c<c03<c<`0203<c<`040000
0?l000006ATI01TI6@?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0^00000003
o`000?lI6AWo6ATI00Wo6ATI00<0000003<c<`0c<c<0100c<c<2000000D0C4a<0P00000306IVIP03
o`00001oOgl0Ogmo0080Ogmo00<00000o`00000000000`2IVIT00ol0000000000;>c/`030;>c/`<0
00002`3<c<`2o`0000`0c<c<00<000000;>c/`2c/k<00`2c/k<00`000000VIVI09VIV@0309VIV@03
0000001oOgl0Ogmo0080Ogmo00<0000006IVI_ooool00_ooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`0j000000L06ATI00?o000003<c<`0c<c<00P0c<c<00`000000C4a<
04a<C00204a<C0050000001VIVH0IVIV06IVIP0000000P1oOgl010000000VIVI09VIV@0000030;>c
/`050000003<c<`0c<c<0<c<c?l00000403Vi^H01Ol00000c<c<0<c<c03<c<`0000000<0/k>c00@0
000009VIV@2IVIT000000`1oOgl010000000IVIV06IVIP00000304a<C0030000000c<c<0<c<c0080
<c<c00@0000001TI6@0I6AT06ATI0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
034000002_lI6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00D0000006IV
IP1VIVH0IVIV0000000607moO`030000002IVIT0VIVI0080VIVI0P0000050;>c/`<000005P3<c<`0
0`000000/k>c0;>c/`030;>c/`030000002IVIT0VIVI00<0VIVI00<0000007moO`1oOgl00P1oOgl0
0`000000IVIVooooo`02ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo
03/000001`0I6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IV
IP1VIVH0IVIV0000000207moO`040000002IVIT0VIVI000000<0/k>c0P0000020<c<c0?o00003@3V
i^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`0000000P2IVIT01@000000Ogmo
07moO`1oOgl000000080IVIV00D0000004a<C01<C4`0C4a<0000000403<c<`030000000I6AT06ATI
00?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`0b000000[o6ATI00<0000003<c
<`0c<c<01@0c<c<00`000000C4a<04a<C00404a<C0040000001VIVH0IVIV06IVIP<00000101oOgl0
0`000000VIVI09VIV@0309VIV@8000001P2c/k<00`000000c<c<0<c<c00B0<c<c0030000002c/k<0
/k>c00@0/k>c00<0000009VIV@2IVIT0102IVIT00`000000Ogmo07moO`0207moO`0500000?oooooo
ooooooooool000006oooool001[ooooo00<00000ooooooooool0>`0000000ol000006ATI01TI6@05
01TI6@030000000c<c<0<c<c0080<c<c00<00000o`00001<C4`00P1<C4`01Ol00000IVIV06IVIP1V
IVKo00000080Ogmo00Go000009VIV@2IVIT00000o`0000030;>c/`030000003<c<`0c<c<0080c<c<
00?o00000>KViP3Vi^H02P3Vi^H00ol00000c<c<0<c<c0020<c<c0050000002c/k<0/k>c0;>c/`00
00000`2IVIT01?l00000Ogmo07moO`00000306IVIP05o`00001<C4`0C4a<04a<C0000000100c<c<0
0`0000006ATIooooo`02ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0<P000000
0ol0003o6ATIoaTI6@08oaTI6@0300000?l00000<c<c00D0<c<c00<00000o`00001<C4`0101<C4`0
0`000000IVIV06IVIP0306IVIP030000001oOgl0Ogmo0080Ogmo00<00000o`00002IVIT0102IVIT2
000000D0/k>c00@00000o`000000000000003`3<c<`00ol00000/k>c0;>c/`050;>c/`030000002I
VIT0VIVI00@0VIVI00<0000007moO`1oOgl00P1oOgl01@00003ooooooooooooooooo000001_ooooo
000Jooooo`0300000?oooooooooo03`00000200I6AT00`000000<c<c03<c<`0203<c<`030000001<
C4`0C4a<0080C4a<00@0000006IVIP1VIVH000000`1oOgl010000000VIVI09VIV@0000040;>c/`03
0000003<c<`0c<c<0080c<c<0_l0000:0>KViP03o`00003<c<`0c<c<0080c<c<00D000000;>c/`2c
/k<0/k>c0000000309VIV@040000001oOgl0Ogmo000000<0IVIV00D0000004a<C01<C4`0C4a<0000
000403<c<`030000000I6AWooooo00;ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0d000000_o6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001V
IVH0IVIV00<0IVIV00?o00000000001oOgl00`1oOgl00`000000VIVI09VIV@0409VIV@8000001`2c
/k<3000000X0c<c<0P0000080;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00P1o
Ogl01@00003ooooooooooooooooo000001_ooooo000Jooooo`0300000?oooooooooo03d00000200I
6AT00`000000<c<c03<c<`0203<c<`030000001<C4`0C4a<0080C4a<00@0000006IVIP1VIVH00000
0`1oOgl010000000VIVI09VIV@0000040;>c/`030000003<c<`0c<c<00<0c<c<00?o00000>KViP3V
i^H01P3Vi^H00ol00000c<c<0<c<c0030<c<c0050000002c/k<0/k>c0;>c/`0000000`2IVIT01@00
0000Ogmo07moO`1oOgl000000080IVIV00<0000004a<C01<C4`00P1<C4`00`000000<c<c03<c<`02
03<c<`0500000?ooooooooooooooo`000000<oooool00ol0003oooooooooo`0e000000_o6ATI00<0
000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00@0IVIV00<0
000007moO`1oOgl00P1oOgl2000000H0VIVI0P0000080;>c/`<000001P3<c<`00`000000/k>c0;>c
/`080;>c/`030000002IVIT0VIVI00@0VIVI00<0000007moO`1oOgl00`1oOgl01000003ooooooooo
ool0000Kooooo`006_ooool00`00003oooooooooo`0n000000L06ATI00<0000003<c<`0c<c<00`0c
<c<00`000000C4a<04a<C00204a<C0040000001VIVH0IVIV000000<0Ogmo00<0000009VIV@2IVIT0
0P0000030;>c/`030000003<c<`0c<c<00<0c<c<0ol000030>KViP?o00001@3<c<`01@000000/k>c
0;>c/`2c/k<0000000@0VIVI00@0000007moO`1oOgl000000`1VIVH01@000000C4a<04a<C01<C4`0
000000@0<c<c00D00000oooooooooooooooo0000000cooooo`03o`000?oooooooooo03H000002olI
6AT00`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00<0C4a<0P00000506IVIP030000001o
Ogl0Ogmo00<0Ogmo0P00000609VIV@030000002c/k<0/k>c00P0/k>c1P00000:0;>c/`030000002I
VIT0VIVI00D0VIVI00<0000007moO`1oOgl00`1oOgl01000003oooooooooool0000Kooooo`006_oo
ool00`00003oooooooooo`0n00000003o`00000I6AT06ATI00D06ATI00<0000003<c<`0c<c<00`0c
<c<01@000000C4a<04a<C01<C4co000000<0IVIV00Go000007moO`1oOgl0Ogmoo`00000309VIV@04
0000002c/k<0/k>c0;>c/`8000001P3<c<`3o`0000P0c<c<00<000000;>c/`2c/k<00P2c/k<01@00
0000VIVI09VIV@2IVIT000000080Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<C0030000000c
<c<0<c<c0080<c<c00@00000ooooooooool00000<oooool00ol0003oooooooooo`0g000000_o6ATI
00?o00000000000c<c<01@0c<c<2000000D0C4a<0P00000406IVIP8000001@1oOgl2000000D0VIVI
0`00000G0;>c/`03o`00002IVIT0VIVI00D0VIVI00<0000007moO`1oOgl00`1oOgl3ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo03l00000200I6AT00`000000<c<c03<c
<`0203<c<`030000001<C4`0C4a<0080C4a<00D0000006IVIP1VIVH0IVIV0000000307moO`050000
002IVIT0VIVI09VIV@000000102c/k<2000000l0c<c<00<000000;>c/`2c/k<00P2c/k<01@000000
VIVI09VIV@2IVIT000000080Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<C0030000000c<c<0
<c<c0080<c<c0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03P000003?lI6AT0
0`000000<c<c03<c<`0503<c<`030000001<C4`0C4a<00@0C4a<00<0000006IVIP1VIVH00`1VIVH0
0`000000Ogmo07moO`0407moO`8000001P2IVIT300000180/k>c0P00000809VIV@030000001oOgl0
Ogmo00<0Ogmo0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`100000
00P06ATI00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV
06IVIP0000000`1oOgl01@000000VIVI09VIV@2IVIT0000000D0/k>c00<000000<c<c03<c<`0303<
c<`00`000000/k>c0;>c/`020;>c/`050000002IVIT0VIVI09VIV@0000000`1oOgl01@000000IVIV
06IVIP1VIVH0000000<0C4a<00<0000003<c<`0c<c<00P0c<c<3ooooo`0300000?oooooooooo037o
oooo00?o0000ooooooooool0>@00000<oaTI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<
C4`0101<C4`00`000000IVIV06IVIP0306IVIP8000001P1oOgl2000000L0VIVI00<000000;>c/`2c
/k<03P2c/k<00`000000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00<0Ogmo0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1100000003o`00000I6AT06ATI00D06ATI
00<0000003<c<`0c<c<00P0c<c<00`000000C4a<04a<C00204a<C0050000001VIVH0IVIV06IVIP00
00000`1oOgl01@000000VIVI09VIV@2IVIT0000000D0/k>c00<000000<c<c03<c<`02`3<c<`00`00
0000/k>c0;>c/`020;>c/`030000002IVIT0VIVI0080VIVI00@0000007moO`1oOgl000000`1VIVH0
0`000000C4a<04a<C00204a<C0040000000c<c<0<c<c03<c<`?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`0j000000co6ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<
C00404a<C0030000001VIVH0IVIV00@0IVIV00<0000007moO`1oOgl01@1oOgl00`000000VIVI09VI
V@0509VIV@<00000302c/k<00ol00000VIVI09VIV@0809VIV@030000001oOgl0Ogmo00@0Ogmo0ooo
ool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`12000000P06ATI00<00000
03<c<`0c<c<00P0c<c<00`00003o000004a<C00204a<C005o`00001VIVH0IVIV06IVI_l000000`1o
Ogl200000080VIVI0P0000040;>c/`03o`0000000000000000T0c<c<0P0000040;>c/`030000002I
VIT0VIVI0080VIVI00D0000007moO`1oOgl0Ogmo0000000306IVIP050000001<C4`0C4a<04a<C000
00000`0c<c<3ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0?000000;oaTI6@03
0000000c<c<0<c<c00D0<c<c0P00000504a<C00300000?l00000000000@0IVIV00<00000o`000000
00001@1oOgl2000000P0VIVI3000000;09VIV@030000001oOgl0Ogmo00@0Ogmo0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`13000000P06ATI00<0000003<c<`0c<c<0
0`0c<c<01@000000C4a<04a<C01<C4`0000000<0IVIV00<0000007moO`1oOgl00P1oOgl010000000
VIVI09VIV@2IVIT2000000D0/k>c0`0000030<c<c0<000001P2c/k<00`000000VIVI09VIV@0209VI
V@050000001oOgl0Ogmo07moO`0000000`1VIVH01@000000C4a<04a<C01<C4`0000000<0<c<c0ooo
ool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03d000002olI6AT00ol00000000003<c
<`0603<c<`8000001P1<C4`00`000000IVIV06IVIP0406IVIP8000001@1oOgl2000001`0VIVI00<0
000007moO`1oOgl01@1oOgl3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooo
oooo04@00000200I6AT00`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C00000000`1V
IVH2000000<0Ogmo00<0000009VIV@2IVIT00P2IVIT00`000000/k>c0;>c/`050;>c/`<00000202c
/k<00`000000VIVI09VIV@0309VIV@050000001oOgl0Ogmo07moO`000000101VIVH01@000000C4a<
04a<C01<C4`000000080<c<c0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo03d0
000000?o0000oaTI6OlI6AT02_lI6AT2000000L0<c<c00<0000004a<C01<C4`0101<C4`2000000H0
IVIV0P00000507moO`<00000602IVIT00`000000Ogmo07moO`0607moO`?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool0A@00000801TI6@03o`00000c<c<0<c<c00<0<c<c
00H0000004a<C01<C4`0C4a<00000?l0000306IVIP040000001oOgl0Ogmo07moO`8000000`2IVIT0
0`00003o00000000000?0;>c/`030000002IVIT0VIVI00<0VIVI00D0000007moO`1oOgl0Ogmo0000
000406IVIP050000001<C4`0C4a<04a<C00000000P0c<c<3ooooo`0300000?oooooooooo037ooooo
00?o0000ooooooooool0@000000<oaTI6@030000000c<c<0<c<c00D0<c<c00?o00000000001<C4`0
1@1<C4`2000000H0IVIV00<0000007moO`1oOgl01@1oOgl01000003o000000000000000C09VIV@03
o`00001oOgl0Ogmo00L0Ogmo00@00000oooooooooooo00006oooool001[ooooo00<00000oooooooo
ool0A@0000000ol000006ATI01TI6@0601TI6@030000000c<c<0<c<c0080<c<c00?o00000000001<
C4`00P1<C4`00`000000IVIV06IVIP0206IVIP030000001oOgl0Ogmo0080Ogmo00<0000009VIV@2I
VIT00`2IVIT00`000000/k>c0;>c/`0<0;>c/`030000002IVIT0VIVI00<0VIVI00D0000007moO`1o
Ogl0Ogmo0000000406IVIP050000001<C4`0C4a<04a<C00000000P0c<c<3ooooo`0300000?oooooo
oooo037ooooo00?o0000ooooooooool0@@00000<oaTI6@030000000c<c<0<c<c00H0<c<c00<00000
04a<C01<C4`01@1<C4`2000000D0IVIV00?o00000000001oOgl0201oOgl3000000d0VIVI0`00000:
07moO`0400000?ooooooooooo`0001_ooooo000Jooooo`0300000?oooooooooo04L00000200I6AT0
0`000000<c<c03<c<`0303<c<`050000001<C4`0C4a<04a<C0000000101VIVH00`000000Ogmo07mo
O`0207moO`030000002IVIT0VIVI00<0VIVI0`00000:0;>c/`030000002IVIT0VIVI00@0VIVI00D0
000007moO`1oOgl0Ogmo0000000406IVIP050000001<C4`0C4a<04a<C00000000P0c<c<3ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool0@P00000<oaTI6@030000000c<c<0<c<c00H0
<c<c0P00000704a<C08000001@1VIVH2000000X0Ogmo1000000609VIV@<00000301oOgl01@00003o
oooooooooooooooo000001_ooooo000Jooooo`0300000?oooooooooo04P00000200I6AT00`000000
<c<c03<c<`0303<c<`040000001<C4`0C4a<04a<C08000000`1VIVH00`000000Ogmo07moO`0207mo
O`030000002IVIT0VIVI00D0VIVI0`0000060;>c/`030000002IVIT0VIVI00@0VIVI00<0000007mo
O`1oOgl00`1oOgl01@000000IVIV06IVIP1VIVH0000000@0C4a<00<0000003<c<oooool00_ooool0
0`00003oooooooooo`0aooooo`03o`000?oooooooooo04<000003?lI6AT2000000P0<c<c00<00000
04a<C01<C4`01P1<C4`00`000000IVIV06IVIP0406IVIP<000002`1oOgl6000000l0Ogmo00D00000
ooooooooooooooooo`00000Kooooo`006_ooool00`00003oooooooooo`19000000P06ATI00?o0000
03<c<`0c<c<00`0c<c<00`000000C4a<04a<C00204a<C0040000001VIVH0IVIV06IVIP8000000`1o
Ogl00`00003o00000000000709VIV@0300000?l0000000000080000000?o000009VIV@2IVIT01@2I
VIT00`000000Ogmo07moO`0307moO`050000001VIVH0IVIV06IVIP000000101<C4`00`000000<c<c
ooooo`02ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0A@00000<oaTI6@030000
000c<c<0<c<c00H0<c<c0P00000704a<C003o`0000000000IVIV00H0IVIV0`00000L07moO`030000
001VIVKooooo00;ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0B000
00000ol000006ATI01TI6@0701TI6@030000000c<c<0<c<c00<0<c<c00<0000004a<C01<C4`00P1<
C4`00`000000IVIV06IVIP0206IVIP800000101oOgl00`000000VIVI09VIV@0A09VIV@030000001o
Ogl0Ogmo00<0Ogmo00D0000006IVIP1VIVH0IVIV0000000404a<C0030000000c<c?ooooo00;ooooo
00<00000ooooooooool0<Oooool00ol0003oooooooooo`16000000co6ATI00<0000003<c<`0c<c<0
1`0c<c<2000000L0C4a<0P00000806IVIP<00000601oOgl00`000000IVIV06IVIP03ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo04X000002@0I6AT00`000000<c<c03<c
<`0303<c<`030000001<C4`0C4a<0080C4a<00<0000006IVIP1VIVH00`1VIVH00`000000Ogmo07mo
O`0207moO`<000003`2IVIT00`000000Ogmo07moO`0407moO`050000001VIVH0IVIV06IVIP000000
101<C4`00`000000<c<cooooo`02ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0
A`00000<oaTI6@8000002@0c<c<00`000000C4a<04a<C00604a<C08000002@1VIVH2000001@0Ogmo
0P00000306IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0B`00
000801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00P1<C4`00`000000IVIV06IV
IP0306IVIP030000001oOgl0Ogmo00@0Ogmo0P00000=09VIV@03o`00001oOgl0Ogmo00<0Ogmo00<0
000006IVIP1VIVH00`1VIVH00`000000C4a<04a<C00204a<C00500000?ooooooooooooooo`000000
<oooool00ol0003oooooooooo`18000000go6ATI00<0000003<c<`0c<c<01`0c<c<00`000000C4a<
04a<C00704a<C0030000001VIVH0IVIV00P0IVIV1000000>07moO`03o`0000000000IVIV00@0IVIV
0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1<00000003o`00000I
6AT06ATI00D06ATI0P00000503<c<`03o`0000000000C4a<0080C4a<0P00000406IVIP03o`000000
0000Ogmo00@0Ogmo00?o00000000000000002@2IVIT2000000H0Ogmo00<0000006IVIP1VIVH00`1V
IVH00`000000C4a<04a<C00204a<C00500000?ooooooooooooooo`000000<oooool00ol0003ooooo
ooooo`1:000000co6ATI00<00000o`00000000001`0c<c<4000000H0C4a<00?o00000000001VIVH0
2P1VIVH00ol0000000000000000<000000L0IVIV0oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`1>000000P06ATI00<0000003<c<`0c<c<0100c<c<00`000000C4a<04a<
C00204a<C0800000101VIVH00`000000Ogmo07moO`0507moO`T00000201oOgl00`000000IVIV06IV
IP0306IVIP030000001<C4`0C4a<0080C4a<00D00000oooooooooooooooo0000000cooooo`03o`00
0?oooooooooo04`000003OlI6AT00`000000<c<c03<c<`0803<c<`030000001<C4`0C4a<00D0C4a<
0`00000N06IVIP?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0C`00
000801TI6@030000000c<c<0<c<c00@0<c<c00<0000004a<C01<C4`00`1<C4`00`000000IVIV06IV
IP0206IVIP<00000501oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<00@0
0000ooooooooool00000<oooool00ol0003oooooooooo`1<00000003o`000?lI6AWo6ATI00_o6ATI
0P00000903<c<`800000201<C4`4000001X0IVIV0oooool00ol0003oooooooooo`0Iooooo`006_oo
ool00`00003oooooooooo`1@000000P06ATI00?o000003<c<`0c<c<0100c<c<00ol00000000004a<
C00304a<C08000001@1VIVH00`00003o00000000000A07moO`030000001VIVH0IVIV00@0IVIV00<0
000004a<C01<C4`00`1<C4`01000003oooooooooo`00000cooooo`03o`000?oooooooooo04h00000
3_lI6AT2000000T0<c<c0P00000:04a<C00400000?l000000000000001H0IVIV0oooool00ol0003o
ooooooooo`0Iooooo`006_ooool00`00003oooooooooo`1@00000003o`00000I6AT06ATI00H06ATI
00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000001VIVH0IVIV00D0IVIV
00<0000007moO`1oOgl03P1oOgl00`000000IVIV06IVIP0406IVIP030000001<C4`0C4a<00<0C4a<
00@00000ooooooooool00000<oooool00ol0003oooooooooo`1?000000oo6ATI0P00000903<c<`80
0000301<C4`3000001<0IVIV0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`1A000000T06ATI00<0000003<c<`0c<c<01@0c<c<00`000000C4a<04a<C00304a<C0030000
001VIVH0IVIV00D0IVIV0`00000:07moO`<000001`1VIVH00`000000C4a<04a<C00304a<C0040000
0?oooooooooo000003?ooooo00?o0000ooooooooool0D@00000?oaTI6@8000002@0c<c<00`000000
C4a<04a<C00<04a<C0@000003@1VIVH3000000;ooooo00?o0000ooooooooool06Oooool001[ooooo
00<00000ooooooooool0DP00000901TI6@030000000c<c<0<c<c00D0<c<c00<0000004a<C01<C4`0
0`1<C4`2000000P0IVIV1000000207moO`@000002@1VIVH00`000000C4a<04a<C00404a<C0040000
0?oooooooooo000003?ooooo00?o0000ooooooooool0DP00000@oaTI6@030000000c<c<0<c<c00L0
<c<c0`00000?04a<C0d000000P1<C4`3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`030000
0?oooooooooo05<000002@0I6AT2000000H0<c<c00<0000004a<C01<C4`0101<C4`2000000X0IVIV
0P00000=06IVIP030000001<C4`0C4a<00@0C4a<00@00000ooooooooool00000<oooool00ol0003o
ooooooooo`1B00000003o`0000000000000000go6ATI00?o00000000000000002P0c<c<00`00003o
00000000000K04a<C0?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0
D`0000000ol00000000001TI6@0801TI6@8000001@0c<c<00ol00000000004a<C00504a<C0<00000
5@1VIVH00`000000C4a<04a<C00504a<C00400000?oooooooooo000003?ooooo00?o0000oooooooo
ool0EP00000?oaTI6@8000002`0c<c<2000001T0C4a<0oooool00ol0003oooooooooo`0Iooooo`00
6_ooool00`00003oooooooooo`1F000000X06ATI00<0000003<c<`0c<c<0100c<c<2000000L0C4a<
0P00000B06IVIP030000001<C4`0C4a<00D0C4a<00D00000oooooooooooooooo0000000cooooo`03
o`000?oooooooooo05L000004?lI6AT2000000/0<c<c0`00000F04a<C0?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool0E`00000:01TI6@030000000c<c<0<c<c00D0<c<c
0P00000704a<C08000003`1VIVH00ol00000C4a<04a<C00604a<C00500000?ooooooooooooooo`00
0000<oooool00ol0003oooooooooo`1G00000003o`000000003o6ATI00oo6ATI0P00000<03<c<`@0
00004P1<C4`3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo05L00000
00?o000001TI6@0I6AT0200I6AT00ol00000<c<c03<c<`0603<c<`030000001<C4`0C4a<00H0C4a<
0`00000:06IVIP8000002@1<C4`01@00003oooooooooooooool0000003?ooooo00?o0000oooooooo
ool0FP00000AoaTI6@030000000c<c<0<c<c00d0<c<c0`00000?04a<C0?ooooo00?o0000oooooooo
ool06Oooool001[ooooo00<00000ooooooooool0F@00000:01TI6@030000000c<c<0<c<c00H0<c<c
00<0000004a<C01<C4`0201<C4`3000000<0IVIV1000000;04a<C00500000?ooooooooooooooo`00
0000<oooool00ol0003oooooooooo`1L0000013o6ATI0P00000@03<c<`<00000301<C4`3ooooo`03
o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo05X000002P0I6AT00`000000<c<c
03<c<`0603<c<`8000002`1<C4`3000000h0C4a<00<0000003<c<oooool00_ooool00`00003ooooo
ooooo`0aooooo`03o`000?oooooooooo05h000004?lI6AT200000140<c<c3@000002ooooo`03o`00
0?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo05`000002@0I6AT00`00003o00000000
000703<c<`0300000?l00000000001T0C4a<00<0000003<c<oooool00_ooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo060000004?lI6AT01000003o000000000000000I03<c<`?ooooo
00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0G@00000;01TI6@030000000c
<c<0<c<c00L0<c<c0P00000F04a<C0030000000c<c<0<c<c00?ooooo00<00000ooooooooool0<Ooo
ool00ol0003oooooooooo`1R000001;o6ATI0P00000G03<c<`?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool0GP00000;01TI6@030000000c<c<0<c<c00P0<c<c0P00000C
04a<C0040000000c<c<0<c<c03<c<`?ooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`1S000001?o6ATI00<0000003<c<`0c<c<0500c<c<3ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`0300000?oooooooooo05l000002`0I6AT00`000000<c<c03<c<`0903<c<`030000001<C4`0
C4a<0100C4a<00@0000003<c<`0c<c<0<c<c0oooool00`00003oooooooooo`0aooooo`03o`000?oo
oooooooo06@000004olI6AT3000001<0<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`1O00000003o`00000000006ATI00T06ATI0`00000903<c<`<000002P1<C4`5
000000@0<c<c0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo06@0000000?o0000
0000000000004olI6AT01000003o000000000000000?03<c<`?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool0HP00000<01TI6@030000000c<c<0<c<c00T0<c<c2P000009
03<c<`?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`1Y000001Go6ATI0`00000<
03<c<`?ooooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0H`00000<01TI
6@030000000c<c<0<c<c01/0<c<c0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
06/000005_lI6AT4000000P0<c<c0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003o
ooooooooo`1S00000003o`00000I6AT06ATI00X06ATI00<00000o`00000000006P0c<c<3ooooo`03
00000?oooooooooo037ooooo00?o0000ooooooooool0J`0000000ol0003o6ATIoaTI6@0GoaTI6@80
000000?o00000000000c<c<00`0c<c<3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`030000
0?oooooooooo06D000003P0I6AT00`000000<c<c03<c<`0G03<c<`?ooooo00<00000ooooooooool0
<Oooool00ol0003oooooooooo`1^000001_o6ATI1@000002ooooo`03o`000?oooooooooo01Wooooo
000Jooooo`0300000?oooooooooo06L000003@0I6AT3000001H0<c<c0oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo070000007OlI6AT3ooooo`03o`000?oooooooooo01Wooooo000J
ooooo`0300000?oooooooooo06P000003`0I6AT2000001@0<c<c0oooool00`00003oooooooooo`0a
ooooo`03o`000?oooooooooo078000006olI6AT3ooooo`03o`000?oooooooooo01Wooooo000Joooo
o`0300000?oooooooooo06T0000000?o00000000000I6AT03@0I6AT200000180<c<c0oooool00`00
003oooooooooo`0aooooo`03o`000?oooooooooo07H000005olI6AT3ooooo`03o`000?oooooooooo
01Wooooo000Jooooo`0300000?oooooooooo06`000003`0I6AT3000000l0<c<c0oooool00`00003o
ooooooooo`0aooooo`03o`000?oooooooooo07L000005_lI6AT3ooooo`03o`000?oooooooooo01Wo
oooo000Jooooo`0300000?oooooooooo06d000004@0I6AT4000000T0<c<c0`000002ooooo`030000
0?oooooooooo037ooooo00?o0000ooooooooool0NP00000CoaTI6@?ooooo00?o0000ooooooooool0
6Oooool001[ooooo00<00000ooooooooool0K`00000C01TI6@T000000P0I6AT3ooooo`0300000?oo
oooooooo037ooooo00?o0000ooooooooool0O@00000@oaTI6@?ooooo00?o0000ooooooooool06Ooo
ool001[ooooo00<00000ooooooooool0L000000M01TI6@?ooooo00<00000ooooooooool0<Oooool0
0ol0003oooooooooo`1n000000oo6ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00
003oooooooooo`1b000001/06ATI0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo
084000003?lI6AT3ooooo`03o`000?oooooooooo01Wooooo000Jooooo`0300000?oooooooooo07<0
00006P0I6AT3ooooo`0300000?oooooooooo037ooooo00?o0000ooooooooool0Q@000008oaTI6@?o
oooo00?o0000ooooooooool06Oooool001[ooooo00<00000ooooooooool0M00000000ol000000000
01TI6@0F01TI6@?ooooo00<00000ooooooooool0<Oooool00ol0003oooooooooo`2500000004o`00
000000000000000000Co6ATI0oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003ooooo
ooooo`1g000001H06ATI0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08`00000
00Go6ATIooooooooooooooooo`00000Kooooo`006_ooool00`00003oooooooooo`1i000001@06ATI
0oooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo08h000000_ooool00ol0003ooooo
ooooo`0Iooooo`006_ooool00`00003oooooooooo`1j000001<06ATI0oooool00`00003ooooooooo
o`0aooooo`03o`000?oooooooooo08d000000oooool00ol0003oooooooooo`0Iooooo`006_ooool0
0`00003oooooooooo`1k000001806ATI0oooool00`00003oooooooooo`0aooooo`03o`000?oooooo
oooo08d000000oooool00ol0003oooooooooo`0Iooooo`006_ooool00`00003oooooooooo`2@oooo
o`0300000?oooooooooo037ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0Ioooo
o`006_oooonD000003?oooooU?l0000Kooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00QOooool2o`000<Gooooo0_l00012ooooo`00P_ooool3o`000003oooo
ool0003ooooo0<7ooooo0ol000000ooooooo0000ooooo`11ooooo`00P?ooool2o`0000;ooooo0_nY
_NP2o`000;oooooo0_l00002ooooo`;oZKgX0_l00011ooooo`00OOooool3o`000003oooooonY_NSo
ZKgX00?oZKgX00?o0000ooooool00000^oooool3o`000003oooooonY_NOoZKgX00?oZKgX00?o0000
ooooool00000@?ooool007[ooooo0ol00003ooooo`KoZKgX00?o0000ooooool00000^?ooool3o`00
00?ooooo0onY_NL3ojVmj003o`000?oooooo0000043ooooo001hooooo`;o00001?ooool8ojVmj004
o`000?nY_NSoooooo`000;Gooooo0_l00003ooooo`;oZ[gW1OnY_NL2ojVmj004o`000?nY_NOooooo
o`0003oooooo001eooooo`?o00000_ooool<ojVmj005o`000?nY_NSoZKgXooooool00000/Oooool3
o`0000;ooooo00?oZ[cWojZmionZ_NL00onZ_NL2ojVmi`;oZ[gW0_nY_NL01Ol0003oZKgWojVmiooo
oooo000003kooooo001cooooo`;o00000_ooool?ojVmj005o`000?nY_NSoZKgXooooool00000[ooo
ool2o`0000;ooooo1OnZ_>L3ojZmi`03ojZlionZ_NOoZ[gW00?oZ[gW00KoZKgWo`000?nZ_NOoZ[gW
ooooool0000nooooo`00L?ooool3o`0000?ooooo4?nY_NP01_l0003oZKgXojVmj?nY_NSoooooo`00
0:_ooooo0ol00003ooooo`OoZ[cW00CoZ[gWojZlionZ_>OoZ[cW0onZ_NL00onZ_>OoZ[gWo`000003
ojZmi`03ooooool0003ooooo03cooooo001^ooooo`;o00001?oooolBojVmj006o`000?nY_NSoZKgX
ojVmj?oooooo0000ZOooool2o`0000Cooooo00?oZ[cVojZlionZ_>L01OnZ_>L2ojZliPCoZ[cW00Go
Z[gWojZlionZ_>OoZ[cWo`000002ojZmi`03ojZliooooooo000003gooooo001[ooooo`?o00000_oo
oolFojVmj003o`000?nY_NSoZKgX00;oZKgX00?oooooo`000?ooool0Y?ooool3o`0000;ooooo0_n[
^nD4ojZliP;oZ[cW0_n[_>H5ojZliP;oZ[cW0_nZ_>H3ojZli`03o`000?nZ_NOoZ[cW00;oZ[cW00?o
ooooo`000?ooool0>oooool006Sooooo0ol00002oooooaWoZKgX00?o0000ojVmj?nY_NP00onY_NP0
0ooooooo0000ooooo`2Pooooo`?o00000_ooool00on[^^GoZk_Uoj^ki@03oj^ki@;oZ[cV00?oZk_U
oj^li_n[_>H00on[_>H2ojZliP;oZk_V1OnZ_>H2ojZli`03o`000?nZ_>KoZ[cW00?oZ[cW00?ooooo
o`000?ooool0>_ooool006Kooooo0_l00004oooooa_oZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0
003oooooooooo`2Mooooo`;o00001?ooool3oj^ji@?oZk_U00?oZk[Toj^kiOn[^nD00_n[^nD3oj^l
iP03oj^kiOn[^nKoZk_V00?oZk_V0_nZ_>H2oj^kiP?oZ[cV00Oo0000ojZli_nZ_>OoZ[cWoj^li_oo
oooo000003_ooooo001Sooooo`?o00001?ooool2ojZmia_oZKgX00?o0000ojVmj?nY_NP01?nY_NP0
0ol0003oooooooooo`2Iooooo`?o00001?ooool2ojbih`CoZk[U00CoZk_Uoj^ji?n[^^CoZk[T1?n[
^nD01?n[_>KoZk_Uoj^kiOn[^nD3oj^kiP03oj^kiOn[^nKoZk_V00?oZk_V0_nZ_>H00ol0003oZk_U
oj^liP03oj^liP03ooooool0003ooooo03Wooooo001Qooooo`;o00001?ooool2ojZli`CoZ[gW0_nY
_NP2ojZmiaKoZKgX00?o0000ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`2Gooooo`;o00001?oo
ool00on/^>;o[;WSojbih`03ojbih`;oZk[U0_n/^N<4oj^ji0;oZk_U0_n/^^@4oj^ki@04oj^ki_n[
^nGoZk_Uoj^ki@?oZk_V00CoZk[Toj^kiOn[^nGo00000_n[^nD2oj^liP04oj^kiOooooooooooo`00
03Wooooo001Nooooo`?o00000_ooool2ojZliPGoZ[cW0_nZ_NL00onZ_>OoZ[gWojZmi`03ojZmi`;o
ZKgX0_nZ_NLAojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ooooooooool0Toooool3o`0000?o
oooo00?o[KOPojbhh_n/^>800_n/^>83ojbih`03ojfhhOn/^N?o[;WS00?o[;WS0_n[^^@2ojbihPCo
[;[T0_n[^nD2ojbjh`CoZk_U00KoZk_Voj^ji?n[^^CoZk[Toj^kiOl00002oj^ki@06oj^li_n[^nGo
Zk_Uoj^kiOoooooo0000>Oooool005cooooo0_l00002ooooo`03oj^ki_nZ_>KoZ[cV00?oZ[cV0_nZ
_>L2ojZliPCoZ[cW0_nZ_NL2ojZli`GoZ[gW0_nY_NP2ojZmi`coZKgX00?o0000ojVmj?nY_NP01OnY
_NP00ooooooo0000ooooo`2Aooooo`;o00001?ooool4ojfgh0?o[;SR00?o[;WSojfhhOn]^>400_n]
^>43ojbih`03ojfghOn/^N;o[;WR00?o[;WR0_n/^^@00on]^>;o[;[Sojbjh`03ojbjh`;oZk_U0_n/
^N<4oj^ji004o`000?n[^nGo[;[Tojbji0CoZk_U00?oooooo`000?ooool0=oooool005Wooooo0ol0
0003ooooo`?oZk_V0onZ_>H00on[^nGoZ[cVojZliP03ojZliP;oZ[cW0_nZ_>H4ojZli`;oZ[gW0_nZ
_>L5ojZmi`;oZKgX00?oZ[gWojVmj?nY_NP01_nY_NP00ol0003oZKgXojVmj006ojVmj003ooooool0
003ooooo08gooooo0ol00004ooooo`;o[[GN1?n]]n02ojbhhP;o[KKO1?n]^>400on/^N?o[KOQojfg
h@02ojfgh@?o[;WR00?o[KOPojfhh_n]^>800_n]^>82ojbjh`;o[KSQ1On/^N<2oj^ji003ojbihol0
003o[;[T00?o[;[T0_n[^nD01?n/^^Coooooooooool0000gooooo`00Eoooool2o`0000Cooooo0_n[
^^@4oj^kiP04ojZli_n[^nGoZk_Uoj^ki@?oZ[cV00?oZk_UojZli_nZ_>H00onZ_>H2ojZli`03oj^l
i_nZ_>OoZ[cW00?oZ[cW0_nZ_NL2ojZli`CoZ[gW0_nY_NP2ojZmi`?oZKgX00?o0000ojVmj?nY_NP0
1onY_NP00ol0003oooooooooo`2:ooooo`;o00001?ooool00on^/mco[[GNojjegP03ojjegP;o[KOP
00?o[[CMojffgon]]]l00on]]]l2ojfhh@;o[[GN1?n]]n400on/^N;o[KOPojfgh002ojfgh0;o[KSR
00?o[[KOojfhhOn]^>400on]^>43ojbih`05ojfhhOn/^N?o[;WSojbihol000000_n/^^@2ojfihPCo
[;[T00?oooooo`000?ooool0=_ooool005Cooooo0ol00003ooooo`;o[;WS1?n[^^@2oj^kiP;o[;[T
1?n[^nD01?nZ_>KoZk_Uoj^kiOn[^nD3ojZliP03oj^kiOn[_>KoZkcV00;oZkcV0onZ_>L00on[_>Ko
Z[cWojZli`03ojZli`SoZ[gW0_nY_NP00ol0003oZ[gWojVmj007ojVmj003ooooool0003ooooo08Oo
oooo0ol00005ooooo`?o[[?L0on^]Mh00on_/][o[[CMojjdg@02ojjdg@?o[KKO00?o[k?Lojjeg_n^
]Mh00on^]Mh2ojfgh@;o[[GM1?n]]n001?n]^>;o[[KOojjfgon^]]l4ojfhh@03ojbihon]^>7o[KSQ
00;o[KSQ0_n/^N<00ol0003o[KWRojfihP03ojfihP;o[;[T0_n]^N800ooooooo0000ooooo`0eoooo
o`00DOooool3o`0000?ooooo00?o[KOQojbihon/^N<00on/^N<2oj^ji0;o[KWR1?n/^^@2oj^ki@;o
[;[T1?n[^nD01?nZ_>KoZk_Uoj^kiOn[^nD4oj^liP04ojZlion[_>KoZkcVoj^liP?oZ[cW00?oZkcV
ojZmionZ_NL02?nZ_NL00ol0003oZ[gWojZmi`02ojVmj0;oZ[gW1?nY_NP00ooooooo0000ooooo`23
ooooo`?o00001_ooool00on_/MWo[[?Lojjcg003ojjcg004ojjeg_n_/][o[k;JojnbfPCo[[CM00Co
[KKOojncg?n_/mco[k?L0on^]Mh00on_/]_o[[GMojjeg@03ojjeg@;o[KOP00?o[kCLojjfgon^]]l0
0on^]]l2ojfhh@;o[[KN1?n]^>401?n/^N?o[[OPo`000?n^]n03ojfihP03ojjgh?n]^N;o[KWR00?o
[KWR00?oooooo`000?ooool0=?ooool004oooooo0_l00005ooooo`?o[KOQ0on/^N<00on^]n3o[KWR
ojfihP03ojfihP;o[;[T0_n]^N84ojbji0;oZk_U0_n/^^@4oj^ki@;oZkcV0_n[^nD4oj^liP04ojZl
ion[_>KoZkcVoj^liP?oZ[gW00?oZkcVojZmionZ_NL00onZ_NL00ol0003oZ[gWojZmi`05ojZmi`;o
ZKgX00?oZ[gWooooool00000P_ooool2o`0000Kooooo00?o[jkGojnafOn_/MT00_n_/MT3ojjcg003
ojn_f?n_/][o[k;J00?o[k;J0_n^]=d2ojnaf@Co[k?L00Co[[GNojnbfon_/]_o[k;K0on^]Md00on`
/][o[kCLojndg002ojndg0?o[[KO00?o[kCLojjfg_n^]]h00on^]]h2ojfhh@;o[kKN00Go[[OPo`00
0?n^]n3o[[OPojfihP03ojjgh0?o[KWR00?o[[OPooooool00000=Oooool004cooooo0ol00005oooo
o`;o[[GN1?n]]n401?n/^N?o[[OPojjgh?n^]n03ojfihP03ojjggon]^N;o[KWR00?o[KWR0_n/^^@2
ojfhhPCo[;[T0_n[^nD00on/^^CoZk_Uoj^ki@03oj^ki@;oZkcV00?oZk_Uoj^li_n[_>H00on[_>H0
1?nZ_NOoZkcVoj^li_n[_>H3ojZmi`03ojZli_l0003oZ[gW00[oZ[gW00?oooooo`000?ooool0OOoo
ool3o`0000Oooooo0on_[]L4ojnaf@04ojjcg?n_[mSo[joHojn_f0?o[k;J00?o/:kFojnafOn_/MT0
0on_/MT2ojncg003ok2`f?n_/]_o[k;K00?o[k;K00Co[[GMok2bf_n`/][o/;;J1?n_]=`01?n^]]oo
[kCLojndg?n_]=`3ojjfgP03ok2cfon_]]ko[kKN00?o[kKN00?o0000ojjgh?n_]Md01On^]n001_n]
^N;o[[OPojjgh?n^]n3oooooo`0003Cooooo001:ooooo`;o00001Oooool00on_/m_o[[GNojjegP03
ojjegP;o[KOQ0_n_]=d4ojjgh004ojfih_n^]moo[[OOojjgg`?o[KWR00?o[[KOojfhh_n]^>800on]
^>82ojbji003ojfhhOn/^^Co[;[T00;o[;[T0_n[^nD2ojbji0CoZk_U0_n[_>H2oj^ki@CoZkcV00Go
Z[gWojZli_nZ_>KoZ[cVo`000002ojZmi`03ojZli_nZ_NOoZ[gW00OoZ[gW00?o0000ooooooooool0
N_ooool2o`0000Sooooo00?o/:cDojn^eon_[]L00on_[]L2ojnaf@;o/:gE1?n_[mP01?n_/][o/:kF
ok2^e_n`[]H3ojnaf@03ok6]e?n`/=So/;3H00;o/;3H0on_/]/00ona[mKo/;;Jok2bfP03ok2bfP;o
[kCL00?o/;7Iojndg?n_]=`00on_]=`01?n^]]ko/;?Kok2cfon`/m/3ojnfgP03ok2cf_l0003o[kGM
00;o[kGM0_n^]n02ojneg@Co[[OP00?oooooo`000?ooool0<oooool004Oooooo0ol00006ooooo`?o
[k?K0on^]Mh00on`/][o[kCMojndg@03ojndg@;o[[OP00?o[kCLojjggon^]ml00on^]ml01?n]^N;o
[[KOojjfgon^]]l3ojfhhP03ojnfg_n]^>7o[KSQ00;o[KSQ0_n/^^@2ojfhh@Co[;[T0_n[^nD2ojbj
i0CoZk_U0_n[_>H2oj^ki@?oZ[cV00?o0000ojZmionZ_>H00_nZ_>H3ojZmi`03ojZlionZ_NOoZ[gW
00?oZ[gW00?o0000ooooooooool0M_ooool3o`0000Oooooo00?o/:WAok2/e?n`[=@00_n`[=@3ojn^
e`03ok2Zd_n`[MGo/:gE00?o/:gE0_n_[mP00onaZm?o/:kFok2^eP03ok2^eP04ojnafOna[MCo/JgD
ok6]e0Co/;3H00Co[k;Kok6_e_na[mKo/JoF0on`/]X00ona[]Go/;7Iok2af@02ok2af@;o[kCL0_na
/MP4ok2cf`05ojnfg_n`/m[o/;?Jok2cf_l000000_n_]Md00ona/m[o[kGMojneg@03ojneg@;o[[OP
0_n`]Md00ooooooo0000ooooo`0booooo`00AOooool2o`0000Oooooo00?o/;3Hojncfon_/m/00on_
/m/01?n^]Mko/;;Jok2bf_n`/]X3ojndg@03ok2afOn_]=co[kCL00;o[kCL0_n^]ml2ok2df`Co[[KO
00?o[KSRojnfg_n_]]h00_n_]]h2ojfhh@03ojnfg_n]^>7o[KSQ00?o[KSQ0_n/^^@2ojfhh@Co[;[T
0_n[^nD2ojbji0CoZk_U0_nZ_>H00ol0003oZkcUojZliP03ojZliP04ojZmionZ_>OoZ[cWojZli`?o
Z[gW00?oZ[cWooooool00000MOooool2o`0000Sooooo0on`ZM45ok2/e004ojn^eon`Z];o/:[Bok2Z
dP?o/:gE00?o/JS?ok6[donaZm<00_naZm<3ok2^eP03ok:ZdOna[MCo/JgD00;o/JgD0_n`/=P2ok:/
dPCo/JoF00?o/;;Jok6^eOna[]D00_na[]D2ok2af@03ok:^e?na/MSo/K7H00?o/K7H0_n`/m/2ok:`
e`?o/;?J00?o0000ojnegOna/mX00_na/mX3ojneg@03ok6cfOn`]Mgo/;GM00?o/;GM00?oooooo`00
0?ooool0<Oooool004;ooooo0ol00006ooooo`03ok2^eOn`/=So/;3H00;o/;3H0_n_/m/2ok6_e`Co
/;;J00?o[kCMok2afOn`/MT00_n`/MT2ojndg003ok6`eon`]=_o/;CK00?o/;CK0_n^]]l2ok2cf`Co
[kKN00Co[KSQojnfg_n_]]ko[kKN0on]^>400on_]]ko[KSQojfhh@03ojfhh@;o[;[T0_n^^N44ojbj
i0;oZk_U0_n/^^@01?n[_>Go0000oj^liOn[_>D2ojZliP03oj^li_nZ_>OoZ[cW00?oZ[cW00GoZ[gW
ojZlionZ_>OoZ[cWo`00001booooo`?o00002?ooool00on`Yloo/:WAok2Yd@03ok2Yd@?o/:cD00?o
/JO?ok2Zd_n`Z]800_n`Z]801?n`[MGo/JS?ok6XconaZ<l4ok6[d`03ok2^e_nbZ]7o/Z[A00;o/Z[A
0_na[M@00onbZLoo/ZcBok:/dP03ok:/dP;o/JoF00?o/Z_Aok6^eOna[]D00ona[]D01?n`/MWo/ZkD
ok:^e?nb[]@3ok6af003ok>]donb/=Oo/[3G00?o/[3G0_n`/mX00ol0003o/K?Jok6cfP03ok6cfP04
ojnegOna/mWo/K?Iok6cf@?o/;GM00?o/K?Iooooool00000<_ooool003oooooo0ol00008ooooo`?o
/:kE0_n`/=P00ona[=?o/JoGok6_e`03ok6_e`;o/;;J00?o/JkEok2afOn`/MT00on`/MT01?n_]=co
/K3Gok6`eona/=L3ok2df`03ok:`e_n`/m_o/;?K00?o/;?K0_n_]]h2ok6cfPCo[kKN00Co[KSQojnf
g_n_]]ko[kKN0on]^>400on_]]ko[[WQojjih@03ojjih@;o[;[T00?o[KWRojbji?n/^^@00on/^^@0
0ol0003oZkcUojbki004oj^liP;oZ[cW0_n[_>H4ojZli`03ooooool0003ooooo06gooooo0ol0000:
ooooo`?o/:O?1?n`ZM400on`[=Co/JO?ok6Wc`02ok6Wc`;o/:[B00?o/JK<ok6XconaZ<l00onaZ<l2
ok6[d`03ok:WcOnbZ]7o/Z[A00?o/Z[A00Co/JgDok:YconbZLoo/ZW?0onb[=800oncZ<go/Z_Aok:[
d@02ok:[d@?o/JkE00?o/j_@ok:^e?nb[]@00onb[]@01?na/MSo/jgCok>]donc[M<3ok:`e`05ok>]
d_nb/=Ko/[3Fo`000?nb/=H00ona/mX00onc/=Ko/K?Iok6cf@03ok6cf@06ok2egOna/mWo/K?Iok6c
fOoooooo0000<Oooool003gooooo0_l00008ooooo`;o/:_C1?n`[]D01?n`/=So/JcCok6/dona[=<3
ok6_e`03ok:[dOna[]Go/JkE00;o/JkE0on`/MT00onb[M?o/K3Gok6`e`03ok6`e`04ok2dfonb/=Ko
/[3Fok:`eP?o/;?K00?o/[3Fok6cf_na/mX00ona/mX2ojnfgP;o/K?J1?n_]]h01?n]^>7o[kKNojnf
g_n_]]h3ojjih@03ojngg_n]^N;o[KWR00;o[KWR0_n/^^@2ojfihP04o`000?n/^nCo[;_Tojbki0;o
ZkcV0_n/^n@4oj^liP;oZ[cW0_n[_>H00ooooooo0000ooooo`1Zooooo`;o00002oooool00on`Y<co
/:O?ok2Wc`03ok2Wc`;o/:WA00?o/JG<ok6WconaYll00onaYll01?n`Z];o/JK<ok6Vc?naY/`4ok6X
c`04ok6[donbYlgo/ZO=ok:Wc@?o/Z[A00?o/jK;ok:YconbZLl00onbZLl01?nb[=;o/jS=ok>XcOnc
Z<d4ok:[d@04ok6^eOncZm3o/j_@ok>[d0?o/ZkD00?o]:[?ok>]donc[M<00onc[M<01_nb/=Oo/jgB
ok>]d_nc[M;o/[3Fo`0000;o/[3F00Co/K?Jok>`e_nc/=Ko/k3F0ona/mT00onc/=Go/K?Iok6cf@02
ok6cf@;ooooo00?o0000ooooooooool0;_ooool003[ooooo0ol00007ooooo`03ok2YdOn`Zm?o/:_C
00?o/:_C0_n`[]D00onaZM3o/JcCok6/d`03ok6/d`04ok6_eonbZm7o/Z_Aok:[d@Co/JkE00Co/;7I
ok:]donb[M?o/ZgC0ona/=L00onc[=;o/[3Fok:`eP03ok:`eP04ok2cfonb/=Ko/[3Fok:`eP?o/K?J
00?o/joEok6cf_na/mX00ona/mX2ojnfgP03ok6cf_n_]]ko[kKN00;o[kKN00?o[[WQojngg_n_]mh0
0_n_]mh2ojfihP03ojnggon]^N;o[KWR00;o[KWR00?o0000ojbki?n/^n@00_n]^N84ojbki0;oZkcV
0_n/^nD4oj^liP03o`000?oooooooooo06Kooooo0ol0000<ooooo`?o/:C<0on`Yll00onaX/Wo/JG<
ok6Uc002ok6Uc0?o/JO?00?o/Z?9ok6Vc?naY/`00onaY/`2ok6Xc`03ok:Tb_nbYlgo/ZO=00?o/ZO=
00Co/Z[Aok>VboncY/_o/jK;0onbZLl00ondYLWo/jS=ok>Xc@02ok>Xc@?o/Z_A00?o]:O<ok>[d?nc
Zm000oncZm001?nb[]Co]:[?okBZcondZ/l3ok>]d`03okBYc_nc[M;o/jgB00?o/jgB00?o0000ok:`
e_nd[M401?nc/=H00ona/mWo/k3Eok>`e@02ok>`e@;o/K?I00Co/k3Eoooooooooooo0000<?ooool0
03Sooooo0_l00009ooooo`?o/:WA1?n`Zm<01?n`[]Go/JW@ok6Yd?naZM03ok6/d`03ok:WcOnbZm7o
/Z_A00?o/Z_A0_na[]D00oncZLoo/ZgCok:]d`03ok:]d`04ok6`eonc[=;o/jcBok>/dP?o/[3F00?o
]:c@ok:`e_nb/=H00onb/=H01?na/m[o/joEok>_eOnc[mD3ok6cfP03ok>_eOna/m[o/K?J00;o/K?J
0_n_]]h2ok6cfPCo[kON00Co[KWRojnggon_]moo[kOO0on]^N800ol0003o[KWRojfihP03ojfihP;o
[;_T00?o[K[SojbkiOn/^nD00on/^nD2oj^liP03ojbkiOoooooo000006Gooooo0_l0000=ooooo`03
ok2Rb_n`Y<co/:C<00?o/:C<00Co/:O?ok6RbOnaX/Wo/J;91?naYL`01?naYloo/Z?9ok:SbOnbXlT3
ok6Vc003ok:Qa_nbY<[o/ZC:00;o/ZC:0onbYld00oncXlOo/jK;ok>Vb`03ok>Vb`04ok:YcondYLWo
]:G9okBUb@Co/jS=00Co/Z_AokBWc?ndYlco]:O<0oncZm000oneY/[o]:[?okBZc`03okBZc`04ok>]
dondZLko]:W>okBYcP?o/jgB00?o]JW=o`000?nd[M400_nd[M42ok>`eP;o]:gA1?nc/=D01?na/mWo
/k3Eok>`eOnc/=D2ooooo`03o`000?oooooooooo02gooooo000eooooo`?o00002Oooool00on_Yloo
/:WAok2Yd@03ok2Yd@;o/:_C00?o/JO=ok6Yd?naZM000onaZM001?na[=?o/ZO=ok:WcOnbYld3ok:[
d@03ok>VboncZLoo/jW?00;o/jW?0onb[M<00ondZ<go/jcBok>/dP03ok>/dP04ok:`e_nd[=3o]:c@
okB/d0?o/[3F00?o]:_@ok>_eOnc[mD00_nc[mD00ona/m[o/joEok>_e@02ok>_e@;o/K?J00?o];3E
ok6cf_na/mX00ona/mX2ojnggP;o/KCJ1?n_]ml01?n]^N;o[kOOo`000?n_]ml3ojfihP03ojnhgon]
^^?o[K[S00;o[K[S0_n/^nD2ojfjh`Co[;_U00?oooooo`000?ooool0H?ooool3o`0000cooooo00?o
[j39ok2Rb_n`X/X00_n`X/X3ok2Tc003ok2PaonaX/Wo/J;900;o/J;90onaYL`00onaX<Ko/Z?9ok:S
b@03ok:Sb@04ok6Vc?nbXLKo/Z76ok:QaPCo/ZC:00Co/ZO=ok>SaoncXlOo/j?70oncY//00ondXLGo
]:G9okBUb@02okBUb@?o/jS=00?o]:C7okBWc?ndYl`00ondYl`01?ncZm3o]JK:okFVb_neY/X3okBZ
c`03okJVbOndZLko]:W>00;o]:W>00Go/jgBokFYcOneZLgo]JW=o`000002okB]d@03okJYc?nd[M7o
]:gA00?o]:gA0_nc/=D2okF]d@Co/k3E0_ooool00ol0003oooooooooo`0/ooooo`00<oooool2o`00
00_ooooo0on_Yll3ok2Yd@03ok6Tc?naYlgo/JO=00;o/JO=0onaZM000onbYL[o/ZO=ok:Wc@03ok:W
c@04ok:[dOncY/_o/jK;ok>Vb`Co/jW?00Co/ZgCokBXcOndZ<go]:S=0onc[=800oneZ<_o]:c@okB/
d003okB/d004ok:`e_ndZm3o]:_@okB[d0;o/joE00?o]J_?ok>_eOnc[mD00onc[mD01?na/m[o];3E
okB`eOnd/=D3ok6cfP03okB`eOna]=[o/KCJ00?o/KCJ0_n_]ml01?na]=_o[kOOojnggol00002ojng
g`04ojfih_n_^=oo[kSOojnhg`;o[K[S00?o[kSPojfjhon]^^<00on]^^<2ojbki@;o[K_T00?o0000
ooooooooool0GOooool2o`0000kooooo0on_X<T4ok2RbP04ok2Tc?n`X<Oo/:37ok2Pa`Co/J;900Co
/JG<ok6Pa_naX<Ko/J361?nbXlT4ok:QaP?o/ZC:00?o/io4ok>SaoncXlL00oncXlL01?ncY/_o]:75
okBQaOndXLD4okBUb@04ok>XcOndY<Oo]:C7okBTa`?o]:O<00?o]Z?6okFVb_neY/X00oneY/X01?nd
Z/oo]ZK9okJVbOnfY/T2okBYcP03okJVb?neZLgo]JW=00;o]JW=00?o0000okB]dOnfZL`00_nfZL`3
okB]d@03okNZc?ne[M7o]JgA00?o]JgA0_nc/=D01?nf[]7oooooooooool0000^ooooo`00<?ooool3
o`0000_ooooo00?o[ZK?ojnWcon_Yll00on_Yll01?n`ZM7o/JC<ok6Tc?naY<`4ok6Wc@04ok6Yd?nb
YL[o/ZG:ok:UbP?o/ZO=00?o/j?7ok>VboncY//00_ncY//3ok>Yc`03okBUb?ndZ<go]:S=00?o]:S=
00Co/jcBokFXboneZ<_o]JS;0ond[=000onfYl[o]:_@okB[d002okB[d004ok>_eOneZloo]J_?okF[
c`?o/joE00?o]Zc?okB`eOnd/=D00ond/=D01?na/m[o];3EokB`eOnd/=D3ok6dfP03okBaeOna]=_o
/KCK00;o/KCK00Co[kOOo`000?na]M_o/KGK1?n_^=l01?n]^^?o[kSPojnhh?n_^>03ojfjh`03ojji
hOn]^nCo[K_T00?o[K_T00?o0000ooooooooool0FOooool3o`0000kooooo00?o[Yo7ojnPbOn_X<T0
0_n_X<T3ok2RbP03ok2NaOn`X<Oo/:3700;o/:370onaX/T00onaW/Co/J36ok6PaP02ok6PaP?o/Z?9
0_nbW/@4ok:QaP04ok:Tb_ncWlCo/io4ok>Oa0Co/j?71?ndXLD3okBUb@03okFQ`ondY<Oo]:C700?o
]:C700Co]:O<okJSa_nfXlKo]Z?60oneY/X00onfXlGo]ZK9okJVb@02okJVb@04okBYc_nfY/So]ZK8
okJVb0?o]JW=00?o0000okJYc?nfZL`00onfZL`01?nd[M7o]j[<okNZc?ngZ/`4okF]d@Co]ZkA0_oo
ool00ol0003oooooooooo`0[ooooo`00;Oooool3o`0000_ooooo00?o[JG?ojjVcon^Y/l00_n^Y/l3
ojnWc`03ojnSbonaY<co/JC<00;o/JC<0onaYld00onbX/So/ZG:ok:UbP03ok:UbP04ok:WcOncXlOo
/j?7ok>Sa`Co/jK;00Co/jW?okBUb?ndYLSo]:G80ondZ<d00onfY<Ko]JS;okFXb`03okFXb`04okB/
d?nfYl[o]ZO:okJWbP;o]:_@00?o]jO9okF[coneZll00oneZll01?nc[mGo]Zc?okJ/conf[<l3okB`
e@03okJ/cond/=Go];3E00?o];3E00Co/KCJokBaeOnd/MGo];7E0_na]=/00ond/MKo/KGKo`000003
ok6ef`;o[kSO0_na]]`4ojnhh004ojfjhon^^N7o[[WQojjih@;o[K_T0_n^^N800ol0003ooooooooo
o`1Fooooo`?o00004?ooool3ojjOa`Co[j3900Co/:;:ok2NaOn`W/Go/9k51?n`X<L01?naX/Wo/Ik4
ok6Na?naW/@4ok6PaP04ok:SbOnbW/Co/Yk4ok:Na0?o/Z7600?o/ig1ok>Oa?ncWl@00_ncWl@3ok>S
a`;o]9k21?ndXLD01?ndYLWo]J73okFQ`oneXL<3okBTa`03okJP`_nfXlKo]Z?600;o]Z?600Co]JK:
okJSaOnfXlGo]Z?51?nfY/T4okJVb0?o]JW=00?o0000okNVb?nfZL`00onfZL`4okNZc0?o]JgA0_ng
Zl`2okJ^d@04okR[cOooooooooooo`0002gooooo000[ooooo`;o00003Oooool3ojfUc`Co[ZK?00Co
[jO?ojnSbon_Xl_o[j?;1?naY<`01?naYlgo/Z;8ok:Rb?nbX/P3ok:UbP03ok>PaOncXlOo/j?700;o
/j?70oncY//00oneXLGo]:G8okBUb003okBUb004okBXcOnfY<Ko]ZC6okJTaP?o]JS;00?o]j?5okJW
b_nfYlX00_nfYlX01?ndZm3o]jO9okNWbOngYlT3okF[c`03okNWb?nf[<oo]Zc?00?o]Zc?00Co];3E
okJ/conf[<oo]Zc?0ond/=D00ong[Loo];7EokBae@02okBae@08ok6dfond/MKo];7FokBae_na]M_o
0000ok6efond/]L5ok6fg0;o[kSP00Go/KOMojjihOn^^N7o[[WQok2ggP05ojjihP03o`000?oooooo
oooo05?ooooo0_l0000Aooooo`03ojfMaon^WlOo[Yo700;o[Yo70on_X<T00on_W<Co/9k5ok2Na@02
ok2Na@?o/:3700?o/Ic2ok6Na?naW/@00_naW/@3ok6PaP03ok:L`OnbW/Co/Yk400?o/Yk400Co/Z76
ok>M`OncWL7o/ig11?ncWl@01?ncXlOo]9k2okBN`_ndW/83okBQa@03okFM`?neXL?o]J7300;o]J73
00Co]:C7okJP`_nfX<;o]Z321?nfXlH5okJSa@;o]ZK90_ngXl@4okJVb004okFYcOngY/So]jK8o`00
00?o]ZW<00?o^:K7okNZc?ngZ/`00ongZ/`01One[M7o]j_<okN[c?ngZlco]ZkA00?o^:_=0_ooool0
0ol0003oooooooooo`0Zooooo`00:?ooool3o`0000gooooo00?oZjGAojfUcon]YLl00on]YLl2ojjV
c`03ojjRbon_Xl_o[j?;00;o[j?;0onaY<`00onaX<Oo/Z;8ok:Rb003ok:Rb004ok:Ub_ncX<Go/j35
ok>Pa@Co/j?700Co/jK;okFQaOneXLGo]J750ondYLP00onfX<;o]ZC6okJTaP02okJTaP03okFXbong
XlGo]j?500;o]j?50_nfYlX00onhXl?o]jO9okNWb@03okNWb@04okF[congYlSo]jO8okNWb0?o]Zc?
00?o^:O8okJ/conf[<l00onf[<l01?nd/=Go]jg?okN]cong[Ll2okBae@03okN]d?nd/MKo];7F00?o
];7F00Co0000okBbeond/]Oo];;G0ona]]`00ond/mSo/KOMok6gg@02ok6gg@04ojjihOn`]mko/;ON
ok2ggP?o[[WR00?o/;SOooooool00000DOooool3o`0001;ooooo0on]WLL4ojjOa`04ojnPbOn_W<Co
[ic4ojnLa0Co/9k500Co/:37ok6L`_naW<;o/Ic21?naW/@01?naX<Ko/Yc1ok:L`OnbW<43ok:Na003
ok>J__ncWL7o/ig100;o/ig10oncWl@00ondVkoo]9k2okBN`P03okBN`P03okBQaOneWL3o]Ig000Co
]J731OnfX<82okJSaP;o]io11?nfXlD01?nfY/Wo]j?4okNSa?ngXl@3okJVb007okRS`ongY/So]jK8
okNVb?l0003o]jK8okJYc003okRVa`?o]j[<00?o^JO7okN[c?ngZl`00_ngZl`5okR[c@;ooooo00?o
0000ooooooooool0:Oooool002Kooooo0_l0000=ooooo`03ojRUdon[YM7oZjGA00;oZjGA0on]YLl0
0on/XLgo[Z;;ojjRb`02ojjRb`Co[j?;00Co/JC<ok6PaonaX<Oo/J370onbX/P00onbW/?o/j35ok>P
a@02ok>Pa@?o/j?700?o]9k2okFQaOneXLD00oneXLD01?ndYLSo]Z32okJP`_nfX<82okJTaP03okNO
`?ngXlGo]j?500?o]j?500Co]ZO:okRS`onhXl?o^:?30ongYlT00oniX/;o]jO8okNWb003okNWb004
okJ/conhYlSo^:O8okRWb0?o]Zc?00?o^JS8okN]cong[Ll00_ng[Ll01?nd/MGo]jg@okN]d?ng[M03
okBaeP03okN^dOl0003o];;G00;o];;G00?o/KKLokBcf?nd/mP00_nd/mP2ok6gg@;o/kCI1?n`]mh0
1On^^N;o/;SOok2hgon`^=oo000004oooooo0_l0000Cooooo`03ojbLaon]WLOo[Ig700;o[Ig70on^
WlL00on^Vl?o[ic4ojnLa002ojnLa0?o/9k500?o/9[1ok6L`_naW<800_naW<83ok6Na003ok6J_onb
W<7o/Yc100?o/Yc100?o/Yk4ok>J__ncV[h01OncWL400oncWlCo]9^ookBK_`04okBN`P03okFK_One
WL3o]Ig000;o]Ig00_neXL<2okJM_PCo]Z3200Co]Z?6okNO`OngWl7o]io10onfXlD00onhWkoo]j?4
okNSa003okNSa004okJVb?nhXl?o^:?3okRS``;o]jK800?o0000okVS`onhY/L00onhY/L00ongZ/co
^JO7okVWa`02okVWa`;o]j_<0_niZ<P4okR[c@;ooooo00?o0000ooooooooool0:Oooool002?ooooo
0ol0000<ooooo`03ojFVeonXYM?oZ:GC00;oZ:GC1?n[YM401?n]YLoo[:7=ojbQcOn/XLd4ojjRb`;o
[j?;00?o[io7ok6PaonaX<L00onaX<L01?nbX/So/Yk3ok:N`onbW/<4ok>Pa@04ok>SaondW/;o]9k2
okBN`P?o]J7500?o]YfookJP`_nfX<800_nfX<801?nfY<Ko]io0okNO`?ngWl04okNSa@Go^:?300Co
]jO9okVR`_niX/;o^J;20ongYlP00oniXl;o^:O8okRWb002okRWb003okJ/coniZ<So^JS800;o^JS8
0_ng[Ll00oniZLWo]jg@okN]d003okN]d004okBae_ng[]7o]jkAo`0000;o];;G0_ng[m83okBcf003
okJadonc]=Wo/kCI00?o/kCI0_n`]mh00onc]]_o/;SOok2hg`02ok2hg`03ooooool0003ooooo04[o
oooo0ol0000Booooo`03oj^Laon/W<Oo[9c700;o[9c71?n]WLL01?n^WlOo[Y_3ojjK`on^Vl<4ojnL
a004ok2NaOn`V/7o/9[1ok2J`@Co/Ic200Co/Ik4ok6J_onaV[oo/IZo1?nbW<44ok>J_P?o/ig100?o
]9VlokBK_ondVkl00_ndVkl2okBN`P;o]I^m1?neWL001?neXL?o]YfnokJM__nfWKh3okJP`P03okNL
_OngWl7o]io100?o]io100Co]Z?5okRO_onhWkoo^9no0ongXl@00oniWkoo^:?3okRS``03okRS``04
okNVb?l0003o^J?3okVS``;o^:K700?o^ZC3okVWaoniYlL00oniYlL01?ngZlco^JS8okVXb?niZ<P3
okR[c@05okZYb?ooooooooooooooool00000:_ooool0027ooooo0_l0000=ooooo`04oj:Xf_nUY]Oo
YJKGojFVe`CoZ:GC0_n[YM400onYX/oo[:7=ojbQc@02ojbQc@?o[Z;;00?o[Ik8ojnOaon_WlL00_n_
WlL3ok6Pa`03ok2L`onbW/?o/Yk300;o/Yk30oncX<D00oncW<3o]9k2okBN`P02okBN`P04okFQaOnf
WKoo]YfookJM_`Co]Z321?ngWl03okNSa@;o^9jn1?nhXl<5okVR`P04okNWb?niXl;o^J?2okVS`P;o
^:O800?o^Z?2okVXb?niZ<P00oniZ<P01?ng[Loo^JW9okVYbOniZLT3okN]d005okVZbOng[]7o]jkA
okN^dOl000001Ong[m801?nd/mSo][7CokJadonf/M<3ok>df@03okJbeOnc]]_o/kKK00;o/kKK0_n`
^=l2ok:gg003ooooool0003ooooo04Oooooo0_l0000Dooooo`?oZic71?n/W<L2ojfMa`03ojfJ`on^
Vl?o[Y_300;o[Y_30on_W<@00on_V<3o/9[1ok2J`@02ok2J`@?o/Ic200?o/IRnok6J_onaV[l00_na
V[l3ok:L`@03ok:H_?ncV[ko/iZn00;o/iZn00Co/ig1okBI_?ndVKco]9Vl1?ndVkl00ondW/;o]I^m
okFK_@02okFK_@;o]Ig000?o]YZkokJM__nfWKh00onfWKh01?nfX<;o]ibmokNL_OngW;d4okNO`@Go
^9no00?o]j?4okVO_oniWkl01?nhXl<00onjX;ko^J?3o`000002okVS``04okRVaonjY<?o^ZC3okZT
``?o^JO700?o^jG3okVXb?niZ<P00oniZ<P01?nhZlgo^ZW8okZYb?njZLP3ooooo`03o`000?oooooo
oooo02Oooooo000Nooooo`?o00003?ooool00onNZMooXZSJoj:XfP02oj:XfP?oYJKG0_nXYM<00onU
X];oZJ;?ojVRc`02ojVRc`Co[:7=00Co[Z;;ojfNb?n]W/So[Ik81?n_WlL01?naX<Oo/9c3ok2L`on`
W<<4ok:N``03ok>PaOncW<3o/ic000Co]9k21OnfWKl2okJP`P;o]ibl1?ngWl001?ngXlGo^9jnokRN
__nhW[h3okRS``;o^Ijm1?niX/84okVS`P04okRWb?njXl;o^Z?2okZS`P?o^JS800?o^jC2okVYbOni
ZLT00oniZLT02?ng[M3o^J[9okVZbOniZ/Wo]jkAokV[bol0003o^J_;0ong[m800oni[<co][7CokJa
d`03okJad`04ok>dfOnf/]Go][;EokJbe@;o/kKK0_nf/mL4ok:gg003o`000?oooooooooo04?ooooo
0ol0000Dooooo`03ojVKb?n[W<OoZic700;oZic70on/W<L00on/VL?o[I[3ojfJ``02ojfJ``Co[Y_3
00Co[ic4ojnH`?n_V<3o[iS01?n`V/400onaW<;o/IRnok6H_P05ok6J_`04ok:L`OnbV;co/YRlok:H
_0?o/iZn1OndVK`2okBK_`03okFH^_neVkgo]I^m00?o]I^m00Co]Ig0okJJ^onfV[_o]YZk1?nfWKh4
okNL_@?o]io10_nhW;`4okRO_`Co^Ino0_nhXl<2okZP_P04okVS`ol0003o^J?3okVS``Go^ZC300Co
^JO7ok^U`onkYL?o^jG30oniZ<P00onkY/Co^ZW8okZYb002okZYb0?ooooo00?o0000ooooooooool0
9oooool001cooooo0_l0000<ooooo`03oi^/honNZMooWZWO00;oWZWO0onRZ=X2ojFVe`03oj6TeonU
X];oYJ;B00;oYJ;B1?nYX/l2ojbQc@03ojZNbon]W/So[Ik800;o[Ik80on_WlL00on^VlCo/9c3ok2L
``02ok2L``?o/Yk300?o/YZook>L`?ncW<000_ncW<02okBN`P;o]IZm1?nfWKl01?nfX<;o]iblokNL
_?ngW;`4okNO`0Go^9jn00Co^:?3okVN_OniW[go^Ijm0oniX/800onjW[co^J?2okVS`P02okVS`PGo
^Z?200Co^JS8ok^T`_nkY<;o^jC20oniZLT00onkYL?o^J[9okVZb@02okVZb@;o^J_;00Co0000okV[
boniZl_o]joB0oni[<`3okJad`03okV^c_nf/]Go][;E00;o][;E00?o/kKKokJceonf/mL00_nf/mL2
ok:gg003okFefOoooooo000004;ooooo0_l0000Dooooo`03ojRKbOnYVlSoZI_800;oZI_81?n[W<L0
1?n/W<Oo[9W3ojbI`on/VL<3ojfJ``?o[Y_300?o[YO0ojnH`?n_V<000_n_V<03ok2J`@03ok2F_Ona
V;ko/IRn00;o/IRn0onaV[l00onaU[_o/YRlok:H_002ok:H_0;o/iZn0_ncUkX4okBI_004okBK_one
V;[o]IRjokFH^PCo]I^m1?nfV[/3okJM_P;o]iZi1?ngW;d01?ngWl7o^9blokRL_?nhW;`3okRO_`03
okVL^oniWkoo^Ino00;o^Ino00?o^:?3okZP__njX;h00_njX;h01?l0003o^J?3ok^Q__nkXKh4okZT
``Go^jG300Co^JS8ok^Va?nkY/Co^jK40_njZLP00onlYlCoooooooooo`02ooooo`03o`000?oooooo
oooo02Kooooo000Iooooo`?o00002oooool2oiR^i`?oVjcS1?nNZMl00onRZ=[oWJKLoj6Te`03oj6T
e`?oYJ;B0onYX/l00onVWlkoZYk;ojZNb`02ojZNb`Co[Ik800Co[io7ojjKa?n^VlCo[Y_41?n`W<<0
0onbW/?o/YZook:J_`04ok>L`004okBN`_neV[go]IZmokFJ_@Co]Yfo1?ngW;`3okNO`0;o^9^j1?nh
W[h5okVN_@04okVR`_njW[co^YjlokZN_0;o^J?20_nkWk`4okZS`PGo^jC200Co^JW9ok^U`onkYL?o
^jG30_niZ/T2okbVa004okV[bol0003o^J_;okV[b`Co^Jc<00?o][7CokV^c_ni[/h00_ni[/h2okJb
e@03okV`d?nf/mOo][?G00;o][?G00?o^;7BokFefOne]MT00_ne]MT00ooooooo0000ooooo`0moooo
o`?o00005Oooool3ojRKb@?oZI_80on[W<L00onZVLGo[9W3ojbI``02ojbI``Co[I[300?o[Y_3ojjG
`?n^Ul001On_V<000on`V/7o/9Jmok2F_@04ok6H_P04ok6J_onaU[_o/IJkok6F^`Co/YRl00Co/iZn
ok>G^_ncUk[o/iNj1?ndVK`4okFH^P?o]I^m0_nfUkP4okJJ^`04okJM__ngV[Wo]iZiokNJ^@Co]ibm
1OnhW;`01?nhWkoo^IbkokVL^oniW;/3okVO_`Go^Z2n00Co0000ok^Q__nkXKko^j6n0onjY<<00onl
X[ko^jG3ok^U``02ok^U``03okfS_onkY/Co^jK400;o^jK400Co^ZW8okbWa?nlYlCo_:O41?ooool0
0ol0003oooooooooo`0Uooooo`005_ooool3o`0000Wooooo0_nF/n`2oiJaj@CoV:kW0onK[><2oijY
g`04oiRXhOnMY]coWJKLoifVg0?oXJCG1?nUX]801?nYX/ooYYo>ojJOc_nVWlh3ojZNb`?o[Ik800?o
Zi_6ojjKa?n^Vl@00_n^Vl@3ok2L``03ok2I`?nbV[oo/YZo00;o/YZo0_ncW<000oncV;co]IZmokFJ
_@02okFJ_@?o]Yfo0_nfVKX4okNL_004okNO`?nhVk[o^9^jokRK^P?o^9jn0_niVkT4okVN_@Co^Yjl
00Co^J?2ok^O_?nkWkco^inl0onjXl82okbO_0Co^jC21?nkYL<01oniZ/Wo_:K4okbVa?nlY/Co^J_;
o`000?niZl/00_nlZ<D2okV/c003okbYaoni[/ko^Jk>00?o^Jk>00Go][;EokV`d?ni/=3o^K3@okJc
e`04okRadP;o]KGI00?o^;?Dooooool00000>oooool3o`0001Kooooo00?oYYc<ojRKbOnXVlT00_nX
VlT4ojVKb004oj^LaonZVLGoZYW5ojZIa@?o[9W30on]V/<00on/U/3o[YO0ojjG`002ojjG`0?o[iS0
00?o[YFmok2F_On`U[d00_n`U[d2ok6H_P03ok2E^_naU[_o/IJk00?o/IJk0_nbV;`00onbUKSo/iNj
ok>G^P02ok>G^P?o]9Vl0_ndU[P4okFH^P04okFK_OnfUkSo]YNhokJG^0Co]YZk1?ngV[T3okNL_@;o
^9Zh1?nhW;`4okVL^`;o^Ino0_njWKX4okZP_P03o`000?nkXKko^j6n00;o^j6n00Co^ZC3okbR__nl
X[ko_::n0_nkYL<2okfS_`Co^jK41OnlYl@3ooooo`03o`000?oooooooooo02Gooooo000Dooooo`;o
00001_ooool00onJ^>goV;K]oiRfk@02oiRfk@CoU[?/0_nF/NT2oiR^i`04oi:^jOnDZnKoU:_VoiB[
iPCoV:SQ0onMY]`3oj6Te`;oYJ;B00?oXZ3CojJOc_nVWlh00_nVWlh4ojZNb`04ojfNb?n[VlKoZi_6
oj^KaPCo[Y_400?o/9c3ok2I`?n`VL001?nbV[l01?ncW<3o/iRlok>H_?ncV;`4okFJ_@04okJM_onf
VK[o]YVjokJI^P?o]ibl00?o^9RgokRK^_nhVkX00onhVkX01?nhW[ko^I^iokVK^OniVkT3okVN_@03
ok^K]onjW[co^Yjl00;o^Yjl1OnkWk`01?njXl;o_9nlokbO_?nlWk`3ok^T`P03okfQ_?nkYL?o^jG3
00;o^jG31OnlY/@01Ol0003o_:S5okbXaOnlZ<Go^Jc<00?o_:W70oni[/h01OnlZlWo^K3@okV`d?ni
/=3o_:g;00Go^;7B00Ko]KGIokRce?nh/mCo^;?Dooooool0000hooooo`;o00005_ooool00onSWLoo
YYc<ojJLc002ojJLc0CoZ9_90_nYVlP00onXVLKoZYW5ojZIa@02ojZIa@Co[9W300?o[I[3ojbF`?n/
U/001?n^Ul001?n_V<3o[YFmojjE_On^UKd4ok2F_@04ok6H__n`UK[o/9Fjok2E^PCo/IJk00Co/YRl
ok:E^?nbUKSo/YFh1?ncUkX01?ndVKco]9JhokBF^?ndU[P4okFH^PCo]YNh0onfV[/2okNG]`Co]iZi
00Co]ibmokRJ^?nhV[So^9Zh0onhW;`00onjV[So^IbkokVL^`02okVL^`04okVO_onjWK[o^YfjokZM
^P?o^Z2n00?o^ijjo`000?nkXKh00onkXKh4okbR_P03ok^U`onmXkoo_J>o00;o_J>o0_nkY/@2okfT
`0Co_:O41?ooool00ol0003oooooooooo`0Tooooo`004Oooool3o`0000Gooooo0_nL^^d3oiZhk@Co
V;K]0_nF/n`01?nA/nkoTK3/oi6`k?nA/>`3oi:^j@?oU:_V0onHZ>42oifVg004oiNTg_nLX]SoW:;H
oibRf0CoXZ3C1?nVWlh2ojZNb`03ojNKbOn[VlKoZi_600;oZi_60on^Vl@00on]V<;o/9W0ok2I`002
ok2I`0?o/YZo1?ncV;`3okFJ_@03okFG^?nfVK[o]YVj00?o]YVj00Co]iblokRH]onhV;Oo^9Rg1?nh
VkX5okVK^@04okVN_OnkVkOo^i^gok^K]`;o^Yjl0_nlVkL4ok^O_0Go_9nl00Co^jC2okfQ_?nmXKco
_J6l0_nkYL<2okjR_@?o_:K40_l00003okbXa@Go_:W700Go^Jk>okb[bOnlZlWo_:_9okV`d003okb]
b`?o^;7B00?o^jo>okRce?nh/m@00_nh/m@2ooooo`03o`000?oooooooooo03;ooooo0ol0000Eoooo
o`03oj6Nd_nSWLooXig?00;oXig?1?nVW<`2ojRKb@03ojJIb?nXVLKoZ9W600;oZ9W61?nZVLD2ojbI
``03ojZF`On/U/3o[9K000;o[9K00_n^Ul000on]U;go[YFmojjE_@03ojjE_@?o/9Jm1?n`UKX4ok6F
^`Co/YFh1?ncUkX4okBF^0?o]IRj0_nfUKH4okJG^004okJJ^ongUkOo]iNgokNG]`Co]iZi1OnhV[P0
1?nhW;co^YZhokZJ^?njV[P3okVL^`Go^Yfj00Co^Z2nok^N^_l0003o00000onkXKh00onmWk_o_::n
okbR_P02okbR_PGo_J>o00Co^jK4okfT`?nmY<3o_JC00onlYl@2okjV`@Cooooo00?o0000oooooooo
ool08oooool0013ooooo0_l00005ooooo`;oWk_/0onL^^d3oiZhk@;oV;K]0_nD]^l3oi6ckP?oTK3/
0onB[^T3oiB[iP03oiRXhOnAY^CoUjCN00?oUjCN0onLX]P4oj:Pd`;oYYo>00?oXic?ojNKbOnWVlT0
0_nWVlT4oj^KaP03ojjKa?n]V<;o[IS200Co/9W00_nbV[l2ok6G_0Co/iRl00Co]IZmokFG^?neUkSo
]INh1?nfVKX4okRH]`?o^9^j00?o^IRfokVK^OniVkT00oniVkT4ok^K]`04okZN_?nlVkOo_9^gokbK
]`?o^inl0_nmW;H4okbO_0Co_J6l00Co^jG3okjR_OnnX[go_Z:m0ol000001?nnXkko0000okbXaOnl
Z<D2oknU_`Co_:W71?nlZlT5okb]b`04okRad_nk[lko^jo>ok^_cP;o^;?D0_nj/M000ooooooo0000
ooooo`0booooo`;o00005?ooool00onNWmKoXIkBoj6NdP02oj6NdP?oXig?0onVW<`00onSV/coYYW8
ojJIb002ojJIb0?oZ9W60onZVLD01?nXU/?oZYK1ojZF`OnZU/44ojbF`004ojjG`?n]U;go[IBmojfD
_@Co[YFm0_n`U[d2ojnC^P?o/9Fj0onaU[/2ok6C^0?o/YFh0oncUkX2ok>D]PCo]9Jh00Co]IRjokJE
]_nfUKKo]YFf1?nfUkP4okNG]`?o]iZi00?o^9NfokRJ^?nhV[P00_nhV[P00onjV;Go^YZhokZJ^002
okZJ^0;o^Ibk0_nkVkL3okZM^P?o000000Co^ijjo`000?nkW[[o^j6n0onmWk/2okbR_P;o_Z2k1?nm
Xkl5okfT`004okbWa?nnY/7o_ZK1okjV`@Cooooo00?o0000ooooooooool08oooool0013ooooo00Co
0000ooooool0003ooooo0_nR_>`4oinkk003oibjkOnK^^koVk[^00?oUkS^1?nD]^l2oi6ckP;oTK3/
0_n:/>l3ohZ]k@?oS:WY0_nAY^@4oiNTgP?oW:;H0_nRX=<00onLW]GoXic?oj>Lc`02oj>Lc`?oYi_9
0on[VlH00onYV<Go[IS2ojfH`P02ojfH`P?o/9W000Co/YZook6G_?naUkco/INl1?ncV;`4okFG^0?o
]YVj0_ngU[H4okRH]`04okRK^_niV;Ko^IRfokVH]P?o^I^i00?o^YRdok^K]onkVkL00_nkVkL5okbK
]`04ok^O_?nmW;Ko_IbfokfL]P?o_9nl00?o_YffokfQ_?nmXK`00_nmXK`01OnnX[go0000o`000?l0
003o_Z:m00Co_Z>n00Co0000oknU_onoYKoo_jFo0onlZLL2oknW`@;o_:_90_noZL@3okb]b`03okn/
a_nk[lko^jo>00;o^jo>00?o^;?DokZad?nj/M000_nj/M000ooooooo0000ooooo`0aooooo`03o`00
0?oooooo0000017ooooo00CoVj;JoijOe_nNWmKoWYoF0onQW]84oj>Mc`04ojJLc?nSV/coXi[<oj>J
c0?oYYW81?nXVLH00onZVLGoZ9K3ojRF``04ojZF`@;o[9K000?oZiBnojfD_On]U;d00_n]U;d4ojjE
_@04ok2F_On_Tk[o[i>jojnC^PCo/9Fj00Co/IJkok6C^?naTkSo/I>h1?nbUKP01?ncUk[o/iBfok>D
]_ncU;H4okBF^0Co]YFf0onfUkP2okNE]0Co]iNg00Co]iZiokRG]_nhUkKo^9Nf0_nhV[P2okZH]@Co
^YZh00Co^Ibkok^K]onkVkOo^i^g0ol00002okbK]`?o^ijj00?o0000okfO^onmWk/00_nmWk/01?nl
X[ko_Z2kokjP^onnX;/3okfS_`;o_j:l1?nmY<04okjV`@Gooooo00?o0000ooooooooool08_ooool0
013ooooo00?o0000ojBljonT_>/01?nR_>`2oinkk0;oW[_]0onK^^h3oiNhkP;oU;K_0_nA]_02ohfc
l0CoR[3_0on:[Nd3ohbYj@;oTJKT0_nGY=h01?n=X^;oUJ3KoiFPfonEX=/4oibNe@?oXic?1?nWVlT0
0on[VlKoZIS5ojVHa@04ojfH`P;o/9W000?o[iJmok6G_?naUk`00_naUk`3ok>H_0;o/iJh1?neUkP0
1?nfVK[o]iJfokNF]_ngU[H4okRH]`Co^IRf0_niVkT3okZH]0?o^i^g00?o_9RcokbK]onlVkL00_nl
VkL5okfL]P05okbO_?nnWKKo_YffokjM]_nmXK`00ol00004okjR_@Co_Z>n00?o_jFoo`000?noYKl0
0_noYKl01OnlZLOo_jO1oknW`OnoYl7o_:_900Co_jW400Co_:g;okn/a_no[<Ko_jc60_nk[lh2okj^
b@?o^[7@00?o_K3=ooooool00000<_ooool01?l0003oooooooooool0000:ooooo`04oiFVh_nHY=ko
V:CNoiRTgPCoVj;J0onNWmH3oj6NdP;oXig?00?oX9_?oj>Jc?nSV/`00_nSV/`4ojJIb0;oZ9W600?o
YYK5ojRF`onXU/<00_nXU/<3ojZF`@04ojbF`?n[U;koZiBnoj^D_P?o[IBm0on^UKd00on^Tk[o[i>j
ojnC^P02ojnC^P?o/9Fj00?o/9:gok6C^?naTkP00_naTkP3ok:E^003ok>B]_ncU;Ko/iBf00;o/iBf
0ondU[P2okFC]0Co]YFf00Co]YNhokNE]?ngUKCo]iFd1?ngUkL4okRG]P03okRJ^?njV;Go^YRe00;o
^YRe0onjV[P01_nkVkOo0000o`000?l0003o^i^gokZM^P?o_9^g0onkW[X00onmWKOo0000okfO^`02
okfO^`Go_Z2k00Co_J>ooknR_?noX[co_j:l0onmY<02ol2T_@;o_ZK10_o1Y[h4ooooo`03o`000?oo
oooooooo02;ooooo000@ooooo`04o`000?ooooooY;c[ojBlj`;oX[c/0_nQ_>`4oijkk@03oi^jk_nJ
^^ooV[[_00CoU[W`0onA]_02ohfcl0;oR[3_0_n3[o83oh6/l0;oPZS]0on6YNP3ohfRhP?oUJ3K0onL
W]D4oj>Lc`;oYi_900?oY9W:ojVHaOnYV<D00_nYV<D3ojfH`P04ok2I`?n_U[go[iJmojnF_@Co/INl
00Co/iRlok>F^?ncU[So/iJh1?neUkP4okNF]P?o^9Rg00?o^9JcokVH]_niV;H00_niV;H00oniVkWo
^YRdokZH]002okZH]0;o^i^g0_nlV;<4okbK]`03okfI/_nmW;Ko_Ibf00;o_Ibf0_nnWKH3o`0000?o
_ijg0onnX[d2ol2O^0;o_Z>n0_o1XKT01?noYKoo0000oknU_onoYKl4oknW`@Go_jW41?no[<H00onk
[lko_Zk9okj^b@02okj^b@06okZad?nm/<go_K3=okf`cOoooooo0000<Oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?oT:cXoi:YiOnBZND01?nEY^83oiRTgPCoVj;J00?oWYoFoiVNf?nLW=<0
0_nLW=<4oj2Kc`CoXi[<0_nVVLP01?nSUlSoYYK5ojJFaOnVU/D4ojRF``;oZYK100?oZIC0oj^D__n[
U;h00_n[U;h4ojfD_@04ojjE_On^Tk[o[Y>jojjC^PCo[i>j00Co/9Fjok2B]on`T[Oo/9:g1?naTkP0
1?nbUKSo/i:fok>B]_ncT[H4ok>D]P04okBF^?neTkCo]I>dokFC]0Co]YFf1?ngUK@3okNG]`03okRE
/onhUkKo^9Nf00;o^9Nf1OnjV;D01?njV[So0000o`000?l00004ok^K]`Go_9^g00Ko^ijjokfM]onm
WKOo_Ifgo`000?nmWk/2okjN^0Co_Z2k1OnoX[`01OnmY<3o`:Bmol2T_Oo0Y;go_ZK100?o`JJn1Ooo
ool00ol0003oooooooooo`0Qooooo`003oooool01?l0003oooooooooooooool3ojBmj`?oXKc/0_nN
^nd2oijlk@?oV[[_0_nF^O02oiBil@?oS[Ob0_n7/o84oh>_lP?oPJc`0_n2Z>d3ohJUj0?oSJ;R0onE
X=/3oibNe@;oXic?00CoWI[AojBIb_nTVL[oY9W:1?nYV<D2ojfH`P03oj^F`On_U[go[iJm00;o[iJm
0onaUk`00on`U;[o/iJhok>F^002ok>F^0?o]INh0_neU;H4okNF]P04okRH]onhU[?o^9JcokRF/`?o
^IRf1OnjV;@01?nkVkOo_9RcokbH/onlV;<3okbK]`;o_IVb0onmW;H3o`0000;o_Yff1OnoW[L01Onn
X[go`9nhol2O^?o0WkSo_Z>n00?o`J6i00?o_jFoo`000?noYKl00_o1XkX2oknW`@;o`ZFm0onoZL@0
0oo2Z;oo_jc6okn/aP02okn/aPGo_Zk91?nm/<d2ooooo`03o`000?oooooooooo02gooooo00Go0000
ooooooooooooooooohnak@04ohn^j`?oT:cX0_nBZND4oiFVhP?oV:CN0_nKX]X01?nEXMcoVIkHoiVN
f?nIW]P3oibLd`CoX9_?0_nSV/`01?nOV<goXiO8oj>Gb?nSUlP4ojJFa@?oZ9K300CoZYK1ojVD`?nY
U<3oZIC00on[U;h3ojfD_@03ojbB^on^Tk[o[Y>j00;o[Y>j1?n_TkX4ok2B]`Co/I>h1?ncT[H4ok>D
]PCo]I>d0onfUKH00onfTk?o]iFdokNE]003okNE]004okNG]onhUK?o^9FcokRE/`?o^9Nf00?o^IJc
okZH]OnjV;D00ol00003ok^H]0?o^i^g0_nlVK@4okbK]`Co_Ifg00Co0000okjN^?nnW[So_Yjh0onn
X;/2ol2P^0Co_j:l1?o0Y;d5ol6V_PGooooo00?o0000ooooooooool08?ooool000oooooo00?o0000
ooooooooool00_ooool3ojBmj`CoX[c/0onN_>d00onJ^^ooV[__oiZkk`04oiBil@?oS[Ob0_n7/o82
oh>_lP;oNjod0_mfZ_<2ogBVl@?oNJ;]0on1X>L3oh^Nh0?oU9cH1?nMV]43ojBIbP;oZIS500?oYIK6
oj^F`On[U/400_n[U/44ojnF_@04ok6G_?n`U;[o/9Bjok2D^PCo/iJh00Co]INhokFD]_neU;Ko]IBf
1?ngU[H4okRF/`;o^IRf0_njUK84okZH]0Go_9Rc00Co_9^gokfI/_nmVK;o_IVb0ol00002okjJ/P?o
_Yff00?o`9^boknN]onoW[L00_noW[L4ol2O^0Go`J6i00Go_jFoo`000?o1Xk[o`J>joknW`@04ol:U
_@04oknYa?o2Z;oo`ZRool:X_`;o_jc60_o2Z/83okj^b@;o`Jg50_nm/<d01?o1[lWoooooooooool0
000_ooooo`04o`000?n@/nkoT;?^oi2ckP;oSk7]1?n?[^/3oi2/j0;oTZWU0_nEY^801?n>Y^GoTJ?Q
oi6ShOnAXn44oiFQg0;oVIkH1?nLW=<2oj2Kc`03oi^JdOnOV<goWiS=00;oWiS=0onSUlP3ojJFa@;o
Z9K300?oYYC3ojVD`?nYU<000_nYU<04oj^D_P04ojfD_On/T[_o[9:kojbB^`?o[Y>j0on_TkX2ojnA
^0?o/9:g0onaTkP2ok6A]@?o/i:f0oncU;H2okBB]0Co]I>d00Co]YFfokJC/onfTk?o]Y>c0ongUK@0
0onhU;;o^9FcokRE/`02okRE/`;o^9Nf00Co^IJco`000?l0003o00000_njV;D5ok^H]004ok^K]onl
VKCo_9VdokbI]0Co_9^g1?nmWKL00onnW[So0000okjN^002okjN^004okjP^oo0X;So`:2hol2P^0?o
_j:l00?o`J:iol2T_Oo0Y;d00_o0Y;d00oo2Y;_o`JJnol6V_P02ol6V_PGooooo00?o0000oooooooo
ool08?ooool000oooooo00?o0000ooooooooool00oooool3ojBmj`CoX[c/1?nN_>d2oiZkk`;oU;Wa
0_nC^_43ohbgl`?oPk?d0omk[o@2ogJZl`;oM:Ka0omiX^d3oh6Pi`?oRikP0onDW=P3oifJd@?oY9W:
00CoZIS5ojFFa_nUU/KoYIK60on[U/43ojnF_@03ojfD_On`U;[o/9Bj00;o/9Bj1?ncU[P4okFD]P?o
]iJf00?o]iBcokRF/onhU[<00_nhU[<01?niV;Ko^YFbokZE/_njUK84okZH]003ok^F/?nlV;?o_9Rc
00;o_9Rc00Ko_IVbo`000?l0003o0000okfI/_nmW;H3okjJ/P;o_Yff0_o0Vk84oknN]`Co`9nh00?o
`Yjcol6Q^Oo1XKT00_o1XKT2ol6S^P03o`000?o1Xk[o`ZFm00Co`ZFm1?o2Z;l00ono[<Ko`Z[2ol:Z
`P02ol:Z`P05okj^bOo1[LGo`Jg5ol6]aOnm/<d00oo1[lT2ooooo`03o`000?oooooooooo02cooooo
00?o0000oooooon@/nh00_n@/nh2ohnak@;oSjk[0_n9[nh3ohV/k0;oRjWY0on>Y^D3oi6Sh@?oUJ7L
0onIW]P2oibLd`03oiNKe_nKV]7oVi[A00;oVi[A0onOV<d3oj>Gb0;oYYK500?oXiC6ojJD`onVU<<0
0_nVU<<4ojVD`0;oZiBn00?oZI:mojbB^on/T[/00_n/T[/4ojjC^P04ojnC^_n_TKSo[i6hojnA^0Co
/9:g00Co/I>hok6A]OnaTKGo/I6e1?ncT[H01?ncU;Ko]9:dokBB]?ndT[@4okFC]0Co]Y>c0_ngUK@2
okRD/PCo^9Fc0ol000001?niU[?o^YReokZH]OnjV;D2ok^G/PCo^iRd1?nlVK@3okbK]`;o_Y^d0onm
WKL00onoW;Co_Yjho`000002okjN^0Go`:2h00Co_j:lol6R^Oo1X[Wo`J:i0_o0Y;d2ol:T^`?o`JJn
0_o3Y[d5ooooo`03o`000?oooooooooo01oooooo000?ooooo`03o`000?oooooooooo00Cooooo0onT
_N/4oj:lk0;oW[c]0_nO_>d2oiZkk`CoTk[a0on<]o<00on3/oCoP;Cfoh2dmP03ogB_mP;oJjSe0_md
Y_43ogVRk@?oPJ3W0on;W^02oiBLf0;oWI[A00CoU9SDoijGc?nNUlcoWYO<1?nUU/H4oj^F`@04ojnF
_On]U;go[IBmojfD_@?o/9Bj0oncU[P00onbTkOo]IBfokFD]P03okFD]P04okNF]_ngU;?o]iBcokND
/`?o^9Jc1?njUK83okZH]0;o^iJ`0_nlV;<3o`0000Co_IVb1?nnV[801?nnWKKo`9^bol2K/_o0Vk83
oknN]`;o`Ibb0_o0WkP2ol:N/`?o`J6i00Ko`j2dol6S^_o1Xk[o`J>jo`000?o4X[H4ol:U_@Co`ZRo
1Oo2Z/84ol6]a@Co`Jo90oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00?oS;Ca
0_n:/O04ohV_kP?oRJc/0_n;ZNT3ohjVi@?oTJ?Q00?oUJ7LohfPhOnBWM/00_nBWM/4oiNKeP?oVi[A
1?nOV<d00onSUlSoWiK:oj>DaP03oj>DaP?oYYC30onYU<000onWT/3oZI:mojVB_@02ojVB_@?o[9:k
0on^TkX00on]TKWo[i6hojnA^002ojnA^0?o/9:g00?o/96fok6A]OnaTKD00_naTKD3ok>B]P03ok>A
/ondT[Co]9:d00;o]9:d0oneTk@00oneT[;o]Y>cokJC/`02okJC/`03okNE]?nhU;;o^9Bb00;o^9Bb
0ol00005okVF/`04okZH]OnkUk;o^iNbok^G/PCo^iRd00?o_9RbokbI]?nlVK@00_nlVK@01?nlVkOo
_Y^dokjK]?nnVk@2okfM]`;o_ibd0_nnW[P00ol0003o_Yjhol6N]@04ol2P^0Co`J:i00?o`:Bmol:T
^oo2Y;/00_o2Y;/01?o1Y[ko`jJmol>V_Oo3Y[d6ooooo`03o`000?oooooooooo01kooooo000?oooo
o`03o`000?oooooooooo00Gooooo0onT_N/2oj:lk0;oX[g/1?nO_>d2oiZkk`;oTk[a0_nD^_84oh^h
m0;oP;Cf0omd[oH3of^Xm@04ofFSlomVW_3oIYk`ofJNl0;oKYc/0omkVnH2ohRJg@CoU9SD0onNUl`4
ojFFaP;oZiK100?oZ9C2ojfD_On]U;d00_n]U;d4ok2D^P04ok>F^?nbTkOo/Y>gok:C]`?o]IBf00?o
]I>cokND/ongU;<00_ngU;<2okRF/`;o^IBa1?njUK801?njV;Co^iJ`ok^F/?nkU[02o`000003okbH
/onmUZoo_IJ_00Co_IVb1?nnV[85ol2K/P05oknN]oo1W;;o`Ibbol6L/_o0WkP01?o2W[<01?o1XKWo
`j2dol>P]?o3X;@2ol6S^P03o`000?o4X[Ko`ZFm00;o`ZFm0_o4Y;T2ol:X_`;oaJNk0oo2Z/82olFY
_P;o`Jg50_o4[<82ol6_b@;oa:o60_ooool00ol0003oooooooooo`0[ooooo`04o`000?oooooooooo
ooooo`?oS;Ca0_n:/O02ohV_kP;oPJob0on1[?02oh:Xk@?oQ:KZ0on8XnH2ohfPh@?oTYgK0onGVmH4
oi^Jd@;oWiS=00CoViO?oinFb_nOU/[oWiK:0onSU<H4ojJD``04ojVD`?nWT/3oYi;0ojNB`0?oZI:m
1?n/T[/01?n^Tk[o[I6iojfA^On]TKT4ojnA^004ok2B]on`TKKo/96fok2A]PCo/I6e00?o/i:fok>A
/oncTK<01OndT[@01?neTkCo]I:bokFB/_neT[83okJC/`?o^9Bb0_l00002okRE/`;o^IBa1?niU[<4
ok^G/P?o^iRd0_nlV;84okbI]0Co_Y^d00Co_IfgoknL]?noW;Co_ibd0_nnW[P00ol0003o`Ijeol6N
]@03ol2P^003ol:P]oo1X[Wo`J:i00;o`J:i1Oo2Y;/4ol>V_@Kooooo00?o0000ooooooooool07_oo
ool000oooooo00?o0000ooooooooool01_ooool00onT_N_oYKg[ojFmj`04oj:mk0CoWkc]0onJ_>l3
oiBjlP;oRkSd00CoRkWdogjemomn]OOoO[Gg0om_[oL2of2Wm`;oE9od0omVW_02ofjLk0?oNi_V0_n8
V]d3oiBHe0?oWYO<0onUU/H00onPULSoZ9C2ojRD`P02ojRD`P?o[IBm0on`U;X00on_TkWo/Y>gok:C
]`02ok:C]`;o]IBf0_neTk<4okND/`04okRF/oniU;7o^IBaokVD/@Co^YFb00Ko^iJ`o`000?l0003o
0000ok^F/?nlV;<3okfF[`?o_IVb0_noUjl3okjJ/P03ol2H[_o0Vk;o`9^b00;o`9^b1?o1W;85ol:N
/`Co`j2d00Ko`J>jolBR]_o4X[Ko0000olBR]_o2YKd3olBT^@03ol:X_oo5Yk_oaJNk00;oaJNk00Go
`Z[2olFY__o5ZKkoaJVnol6]a@03olB/`P03ol6_bOo4[lKoa:o600;oa:o60_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00;ooooo0on7]O<2ohBbl`CoPJob0on1[?02oh:Xk@?oQ:KZ
0on8XnH2ohfPh@?oTYgK0onGVmH2oi^Jd@04oiFIe?nKUlooViO?oi^Gc`?oWiK:1?nSU<H2ojJD``03
oj>Ca?nWT/3oYi;000;oYi;00onYT[d3ojbB^`03oj^A^on]TKWo[I6i00;o[I6i1?n_TKP4ok2A]PCo
/I6e1?ncTK<3okBB]003okBA/_neT[;o]I:b00;o]I:b0_nfTk<01?ngT[7o0000o`000?l00002okRD
/P04okRE/oniU;7o^IBaokVD/@Co^IJc00?o^iFaok^G/_nkUk800_nkUk801?nkV;Co_9RbokbH/_nl
V;83okbI]003okjI/_nnVkCo_Y^d00;o_Y^d1OnoW;@00onnW[So`Ijeo`000002ol6N]@04ol2P^?o2
X;Oo`Z2gol:P]`;o`J:i0_o3XkP3ol:T^`03olFU^_o3Y[go`jJm00;o`jJm00?oaZRlooooooooool0
1?ooool00ol0003oooooooooo`0Mooooo`003_ooool00ol0003oooooooooo`08ooooo`?oYKg[0_nR
_N`2oj>mk0CoWkc]00?oV[c_oiblkonL_>l00onE^o83oh^im0?oO[Gg0om_[oL2of2Wm`;oE9od0om?
VO82oeFFk`;oNi_V0on8V]d3oiBHe0?oWYO<00CoYIK6oj2Eb?nPULSoX9G80onXU<84ojfD_@03ok2D
^_n_TkWo[i>i00Co/Y>g00Co]IBfokFC/oneTk?o]I>c1?ngU;<4okVD/@;o^YFb0ol00004ok^F/0Go
_IJ_00Co_IVboknG[onoUjoo_iN_0_nnV[82ol2H[PCo`9^b1?o1W;800oo3Vjoo`Yjcol:N/`02ol:N
/`04olBM/?o3X;Co`j2dol>P]0Coa::f00?o0000olBT^Oo4Y;T00_o4Y;T5olFW^`CoaJVn1?o4[<85
olB_aP?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`?oQkGc0_n4/_<2
oh6_lP;oNJoe0omg[?@01?mfZ?;oN:G_ogRUkomhYNl3ogbRj`;oPYoV0on9WN43ohnKfP?oUIWD1?nK
Ull3oinFbP;oXiC600?oWi?8oj>Ca?nSTl@00_nSTl@3ojNB`0CoZI:m00Co[9:koj^A^on[TK_oZi6k
0on]TKT3ojnA^003ojj@]on`TKKo/96f00;o/96f0onaTKD00onaT;Co/i6cok>A/`02ok>A/`;o]9:d
0_ndTK84okFB/P?o000000?o]i:aokRD/_nhU;800_nhU;84okVD/@?o^IJc0_nkUK44ok^G/PGo_9Rb
00Co_9VdokjI/_nnVK;o_YVb0_nnVk@2oknK/PCo_ibd0oo1W[D00ol0003o`Ijeol:P]`03ol:P]`03
ol6R^Oo3XkSo`j>h00;o`j>h00Co`ZBkolFU^_o5YK[oaJFj0_o3Y[d2olJX_0Oooooo00?o0000oooo
ooooool07?ooool000kooooo00?o0000ooooooooool02Oooool00onU_N_oYKgZojFmjP04oj>mk0;o
Wkc]0_nQ_Nd3oiblk`?oUK_b00?oRkWdohfjm?n=^_@00omo]_L3off_n0;oF:Kg0_m3V_<3odnIlP03
oeFFkomTUN_oI9G[00?oMYKT0on8U]/3oiJFd@CoX9G80onXU<83ojfD_@03ojZC__n_TkWo[i>i00;o
[i>i0onbTkL5okFC/`?o]iBc00?o]i:aokVD/OniU;400ol00003ok^D[`Co^iJ`00?o_9B^okfF[onm
UZl00_nmUZl4oknG[`04okjJ/_o0V:ko`9R^ol2H[P?o`9^b0_o2VZh2ol6L/P;o`i^_0oo2W[<2olBM
/0?o`j2d00?oaYnaolBR]_o4X[H00_o4X[H01Ol0003oa:BiolBT^Oo4Y;WoajBf00CoaJNk00?ob:Nh
olFY__o5ZKh00_o8Z[`3olB/`P04olN]_oo4[lKoa:o6olB_aP;oak330_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Gooooo0on3]_D3ogjbmP?oNJoe0omg[?@01?mfZ?;oN:G_ogRU
komhYNl3ogbRj`;oPYoV0on9WN43ohnKfP?oUIWD0onKUll2oinFbP03oiZEcOnOTlSoWi?800;oWi?8
0onSTl@4ojNB`0;oZI:m00?oZ96noj^A^on[TK/00_n[TK/4ojfA^@03ojnA^?n^T;Oo[Y2g00Go/96f
00?o/I6eok6@]?naT;@01?ncTK<01OndT[Co]96bokBA/_ndTK;o]I:b00?o00001?ngT[44okRD/P03
okRC/?niU;7o^IBa00;o^IBa00Co^IJcok^E/OnkUK7o^iFa1?nkUk800onlU[3o_9RbokbH/P02okbH
/PCo_YVb00Co_Y^doknK/_noVk;o_i^b0onoW;@2ol6M/`?o`Ije00?o0000ol:P]oo2X;L00_o2X;L5
ol>S^0CoaJFj00?o`jJmolJX_?o6Z;`00_o6Z;`6ooooo`03o`000?oooooooooo01cooooo000>oooo
o`03o`000?oooooooooo00[ooooo0onU_NX2oj>mk0;oY;g[1?nQ_Nd00onL_>ooWKg_oifmk`04oiJl
l@;oSK[d0omo]_L3off_n0;oF:Kg0om3V_<2ocJ@k`03ocB;kOmTUN_oI9G[00?oMYKT0on8U]/3oiJF
d@?oX9G81?nXU<800on]U;goZY>nojZC_P04ojnC^@;o/Y>g0_naT[H4okFC/`;o]iBc00Co]i:ao`00
0?l0003o00000_niU;44ok^D[`?o^iJ`0_nlU:h4okfF[`Co_iN_1Oo0V:h01Oo0Vk;o`YZ^ol:J[_o2
VZko`Ibb00?o`i^_0_o2W[<3olBM/0;o`j2d0_o6Wk43olBR]P04olJR/ol0003oa:BiolBT^@;oajBf
0oo5Yk/2olRW^003olFY__o8Z[cob:Zl00;ob:Zl00Goa:c2olN]_oo7[KooajfoolB_aP03olN```?o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`?oPkKe00?oO[;fogVcmomi
/oL00oma[oL3ofb[m`04ofVWmOmhYNooN:G_ogRUk`;oO:;[0on2WnH3ohVMh@?oSi_J0_nEVM@2oi^G
c`03oi>FdonJULgoVYG=00;oVYG=0onOTlP4oj>Ca0;oYi;000?oY972ojRA__nXTKh00_nXTKh3oj^A
^`?o[I6i00?o[92iojj@]on^T;L00_n^T;L3ok2A]P03ok2@]OnaT;Co/I2d00;o/I2d0oncTK<2okBA
/P?o00000oneT[800onfTK7o]i:aokNB/@02okNB/@;o^9Bb0_nhTk04okVD/@Go^iFa0_nkUk82okbF
/0Co_9Rb1?nnVK85oknK/P04oknL]?o1WK?o`Ifcol6M/`?o`Ije00?o0000ol>O]?o2X;L00_o2X;L0
0oo4X[Ko`j>hol>S^002ol>S^0CoaJFj1Oo6Z;`7ooooo`03o`000?oooooooooo01_ooooo000>oooo
o`03o`000?oooooooooo00_ooooo00CoYKgZojJmj_nV_N[oY[gZ0onT_N/2oj6mk@03oj:mk?nM_Noo
WKg_00;oWKg_0_nF_?42oiVll@?oSk_d0on1]oL3ofjan@;oE:Kh0_lgUo82oaf7j@03ocB;kOm2Rnco
@X_/00?oMYKT0_n8U]/4oiJFd@?oX9G80_nXU<800onSTlCoZY>nojZC_P02ojZC_P?o[i>i00Co/Y>g
ok6B]_naT[Ko/I:f1?neTk<3o`000003okNB/OniU;7o^IBa00;o^IBa00?o^I>_ok^D[onkU:l00_nk
U:l01?nkU[3o_9B^okbD[_nlU:h3okfF[`03okjE[OnoUjoo_iN_00;o_iN_00?o`9N/ol2H[_o0V:h0
0_o0V:h4ol:J[PGo`i^_00?o`YjcolBM/?o4WK000_o4WK001Oo3X;CoaYnaolJO/Oo6Wk7oa::f00?o
aZ:c00?o0000olNT]_o7Y;H00_o7Y;H01?o5Yk_ob:NholRW^?o8YkP5olRZ_0Coajfo1?o7/<<4oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool3oh6gm`;oNK?g0oma[oL3ofb[
m`;oJJOe0_mYY?<2offQl0?oLik/0_mkW>L3ohBJh@;oS9SJ1?nCU]<3oiZEc@?oWi?80onSTl@00onO
T/KoY972ojBA`P02ojBA`P?oZ96n1?n[TK/00on]TKWo[92iojb@^@04ojj@]`;o/96f0_n`T;D4ok6@
]0;o/i6c0ol00003okBA/P;o]I:b0_nfTK44okNB/@04okRD/_nhTk3o^9>`okRC/0Co^IBa00?o^YB`
ok^E/OnkUK400_nkUK401?nkUk;o_9J`okbF/?nlU[03okbH/P;o_YR`0onnVK800oo0V[7o_i^boknK
/P02oknK/PGo`Ifc00Co`Ijeol>O]?o3WkCo00000_o2X;L2olBR]P?o`j>h0_o6YKL2olFU^P;oajRi
1?o6Z;`8ooooo`03o`000?oooooooooo01[ooooo000>ooooo`03o`000?oooooooooo00gooooo0onV
_NX4ojFmj`;oX[g/0_nM_Nl3oinmkP?oVKca00?oSk_doi:klonB^o<00on5^OL3og6cn@;oE:Sh0_l`
U_400olMQnWo47_Toa1ki002od:;k0;oFHoY0omcT^82oiJFd@04ohRCf?nHTlgoV9?=oiRCc@?oXi?4
1?nZTkh2ojnC^@03ojfB^_naT[Ko/I:f00;o/I:f00Co]I>co`000?l0003o00001OngT[42okVD/@;o
^I>_1?nkU:l5okbD[P04okfF[onnUJgo_YF]okjE[@;o_iN_0_o0Uj`4ol2H[P05ol:H[?o2VZko`YZ^
ol:J[_o4VZ`01?o3Vjl5olBM/0CoaYna1?o6X[<00oo7Y;Ko0000olNT]P02olNT]PCob:Nh00?objRf
olRZ_?o8Z[`00_o8Z[`4olN]_`03ol^^_Oo7/<?oak3300;ob[720oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Wooooo0omo^?P2ogFdn@?oJk3i0omQZoP2oeZUm`;oEj7e0_m]XO03
og>Nk0;oNicW0on4V^42ohbHfP?oTiKC1?nJULd3oinCb004oj>Ca?nOT/KoWi;6oinBaP?oY9721?nX
TKh2oj^A^`03ojV@_?n/T;Wo[92i00;o[92i0on^T;L01?n`TKKo/92eok2@]On`T;D3ok6@]0?o0000
0_ncT;84okBA/P04okFB/_nfTK7o]Y6aokJA/@Co]i:a1OnhTk02okVD/@;o^YB`1?nkUK45okbF/004
okbH/_nnV;3o_YR`okjH/0;o_YVb0_o0V[44oknK/P03ol:L/_o1WK?o`Ifc00;o`Ifc1?o3Wk@00ol0
003oa::folBR]P02olBR]P05ol>S^?o6YKOoaZFgolJU]oo5YKX00oo7Z;T3olJX_0;obJ^l1oooool0
0ol0003oooooooooo`0Jooooo`003_ooool00ol0003oooooooooo`0>ooooo`?oY[gZ0_nU_N/2ojFm
jP?oXkg/0_nO_Nh2oj6mk@?oVkg`0onB^o<3ohFim`03og6cnOmg]_WoMkKi00;oFZ_i0ol`U_42oa1k
i0;o57WT0_mISnT2og>BhP?oR9?H0onHTld4oj>Ca0?oZY>n00Go[i>iojfB^_n]T[[o[I:jok6B]P03
o`000004okFC/ondT[?o]9:cokBB/`Co]i:a00Co^IBaokVC[oniTjoo^I>_1?nkU:l5okbD[PCo_YF]
00Co_iN_ol2G[?o0Ujco`9N/0oo0V:h2ol:H[0;o`YZ^0_o4VZ`4ol>K[`03olFK[Oo4WK3oa9f`00;o
a9f`1?o6Wk401_o8X:ooaZ:colJR/oo6X[?obJ>ao`0000?oajBf0oo8YkP2ol^X]P?ob:Zl0_o;ZkX2
olN]_`;objjm00Coak33olZa`_o:/L;ob[721?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00[ooooo0omo^?P2ogFdn@?oJk3i0omQZoP2oeZUm`;oEj7e0_mHWO<2oejKl@?oIi[]0_n4
V^43ohbHfP?oTiKC0_nJULd01?nBUM?oVY?<oiZCc?nJTl`4oinBaP?oY9720onXTKh01?nUTL3oZI2l
ojV@_?nYT;`4ojb@^@;o[Y2g00?o[I2gok2@]On`T;D00_n`T;D3o`000003ok6@]?ncT;;o/i2b00;o
/i2b1?ndTK85okJA/@;o]i:a0_nhT[04okRC/004okVD/OnjU;3o^YB`okZD/0?o^iFa1_nlU[04okjH
/004okjI/_o0V[7o`9Zaol2J/@?o_i^b0_o2W;84ol6M/`Co`ind00?o0000olBR]_o4X[H00_o4X[H4
olJU]`GoajRi00CoaZRlolV[_?o9ZkcobJ^l2?ooool00ol0003oooooooooo`0Iooooo`003Oooool0
0ol0003oooooooooo`0@ooooo`03ojJmj_nW_NWoYkgY00CoYKgZ00?oXkg/ojBmjonT_N/01?nQ_Nd0
0onK_O3oWKg_oifmk`03oiJllPCoR[[f0_mg]_T3oeZ[n@;o<ISa00Co0GcNo`1Ze?lDNNCo57WT0_l/
OnP2og>BhP?oR9?H0onHTld3oj>Ca0;oZY>n00?oYY;1ojfB^_n]T[X00ol00003ok6B]PCo]9:c1?ng
T[45okVC[`;o^iB_00?o^i>]okbD[_nlU:h00onlU:h4okjE[@03oknG[oo0Ujco`9N/00;o`9N/00Co
`9R^ol:H[?o2V:co`YR/0_o2VZh2olBJ[0?o`i^_0_o5Vjd3olBM/0;oaij^0_o6Wk42olRP[`;oaZ:c
0_o9Xk400oo7Y;Ko0000olNT]P02olZU/`03olRW^?o;Z;KobjRf00;objRf00Gob:Zlol^[^_o;Zk[o
bj^jolN]_`03ol^^_@Cob[721?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00co
oooo1?mo^OT2og>fnP?oI[3j0_mHZ_T2odbSm`;o@icd0_mHWO<2oejKl@?oIi[]00CoLiWXogjHhOmn
V>7oOYSQ0on9U]X4oi:Ed`?oVY?<0onOT/H4ojBA`P03ojRA__nUTL3oYI7000CoZI2l0on/T;T01?n^
T;Oo[I2gojf@]on]T;L3o`000003ok2@]OnaT;Co/I2d00;o/I2d1?ncT;82okBA/P;o]I6a1?nfTK40
1?ngT[7o^9:`okRB/?nhT[04okRC/0Go^YB`00?o^iFaokbF/?nlU[001?nlU[000onnUk3o_YR`okjH
/002okjH/0Go`9Za00Co_i^bol:L/_o2W;;o`Ybb0oo1WK<2olBN/`?o`ind00?oaJ6do`000?o4X[H0
0_o4X[H4olJU]`03olVX^?o7Z;WoajRi00;oajRi1?o9Zk`8ooooo`03o`000?oooooooooo01Wooooo
000=ooooo`03o`000?oooooooooo013ooooo1?nW_NT2ojFmjP;oY[gZ0onT_N/2oj6mk@;oX[g/0onM
_Nl3oiJllP;oR[[f00?oSk_dogjhn?mn^?P00_mn^?P3of>`nP05ocZNm?l3O]ko0gkNo`1MaOl0Glh0
0_l/OnP2odn8j0;oR9?H0onHTld2oj>Ca004oi^BbOnVT/7oYY;1ojJB`@;o00000_n]T[X3ok6B]P;o
/9:g0ondT[<5okNB/@Co^I>_00Co^iB_ok^C[OnkTjgo^i>]0onlU:h00onnU:co_YF]okjE[@02okjE
[@Go`9N/00?o`9R^ol:H[?o2V:`00_o2V:`01Oo2VZkoa9Z/olBJ[?o4VZco`i^_00?oaI^]0_o4WK03
olNN[P03olJO/Oo8X:oob:2_00;ob:2_00KoaZ:colVS/Oo9Xk7obJ>aolNT]_l00002olZU/`03olRW
^?o;Z;KobjRf00;objRf1?o;ZkX4ol^^_@05olja_Oo:/L;ob[72olZa`_o=]<401?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00gooooo0_mo^OT2oh6kn@;oM;Oj0omT/_/2oe>Zn@;o
@J7f0om3W?@00oloV??o@YGaod:El@03ofNJk@04og>Ij?mnV>7oOYSQogjHh@?oRIKJ0onBUM<3oiZC
c0CoWi;60_nTTL800onPTLGoYI70ojFA`002ojFA`0?oZI2l0_n/T;T00onZT;[o[I2gojf@]`02o`00
00Co/92e1?naT;@4ok>@/P04okBA/_neTK7o]I6aokFA/@Co]Y6a1?nhT[03okRC/0;o^Y>`1?njU;06
okbF/0?o_YN`0onnV;000oo0VK3o`9Zaol2J/@02ol2J/@Go`Ybb00Co`IfcolBN/oo4W[?oa9jc0_o3
Wk@2olFQ]003olBR]_l0003oa::f00;oajBf0_o6YKL2olVX^0?oajRi0_o;ZkX2olV[_0;oc:nm2?oo
ool00ol0003oooooooooo`0Hooooo`003Oooool00ol0003oooooooooo`0Aooooo`CoYkgY1?nV_NX0
0onT_N_oYKg[ojFmj`04oj:mk003oifmkonP_NkoX;g^00CoVKga0_n?^o@2ogjhn0;oQ[[g0_m^]?X2
odNUm`?o0gkN00Co05Nlo`1Se?l0HmCoChSX0_maSn43ohZBe@?oVi;90ol000000onVT/7o[I:jojfB
^P02ojfB^P04ok6B]_n`T[Oo/9:gok2B]`Co]9:c1?ngT[44okVC[`Co^i>]0_nlU:h3okjD[0?o_YF]
00?o`9J[ol2G[?o0Uj`00_o0Uj`5ol:H[0Coa9Z/00?o`i^_olFK[Oo5Vjd00_o5Vjd01Oo4WK3oaij^
olNN[_o7WZkoaYna00Cob:2_1?o9Xk42olZU/`03o`000?o:YK?objRf00CobjRf1?o;ZkX00oo>[KWo
bjjmol^^_@03olja_@04olZa`_o=]<7ocKC1olfd`@Cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0?ooooo`?oPK_i0_md]oX3ofBbn`;oDj[i0om1XOH2oc2Hl@03obF?kOm2UO7o@YGa
00?oBiC`00CoFIG^ogjHhOmnV>7oOYSQ0on9U]X3oi:Ed`?oVY?<0_nOT/H01?nIT/_oX975oj2AaOnP
TLD4ojFA`0?oZI2l00?o[92iojZ@^_l000000_l00002ojf@]`?o/92e00?o[i2fok6@]?naT;@00_na
T;@4ok>@/PCo]I6a0onfTK42okNB/@Co^9:`00Co^9>`okZC/?njTk3o^Y>`1?njU;05okbF/0Co_YN`
0_nnV;02ol2I/0Co`9Za00?o`Ybaol:L/_o2W;800_o2W;84olBN/`03ol>O]?o5XKCoaJ6d00;oaJ6d
00Goa::fo`000?o7Y;KoajBfolJU]`04olVX^005olNX^Oo;Zk[obj^jol^[^_o9Zk`01?o<[kd8oooo
o`03o`000?oooooooooo01Oooooo000=ooooo`03o`000?oooooooooo01;ooooo1?nW_NT2ojJmjP;o
YkgY0onU_N/2oj:mk0;oY;g/0onP_Nh2oiVml@03oifmkonD_??oU;cc00;oU;cc0on6^_L2ofjdnP?o
AjGg0ol>Qn@00ol0HmCo5W;Qodn8j002og6?h@;oRY;E0ol000001?nKT/WoYY;1ojJB`OnVT/43ojfB
^P03ojVB_On`T[Oo/9:g00;o/9:g1?ndT[<4okNB/@Co^I>_1?nkTjd00onlU:ko_YB/okjD[002okjD
[0;o_YF]0_o0UZ/4ol2G[003ol:GZoo2V:co`YR/00;o`YR/1?o4VZ`5olFK[@Coaij^1Oo8X:l4olVS
/@05olbT/?o:YK?o0000olZU/oo=Yk800oo;Z;H2oljZ]@;obj^j0_o>[KT00oo;[[goc[6molja_@02
olja_@CocKC11?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo013ooooo1?n5_?T2
ogNin`?oI[Ck0_mB[?T3ocZQm004ob:CkOlUSngo9Ho]ob6:j`?oBiC`00?oFIG^ofVFjOmYU^T00omi
U^83ohJEfP?oTI?B0onIT//4oj2Aa@?oYI700_nYT;`3o`0000;oZY2j1?n]T;L01?n`T;Go[i2fojn@
]_n_T;H4ok6@]0;o/i2b0_ncTK<4okFA/@04okJA/OngT[7o]i:aokNB/@Co^9:`1?njTk03okZD/003
okbE[onlU[3o_9J`00;o_9J`1OnnUk001?nnV;3o`9V`ol2I/?o0VK03ol2J/@;o`Yba1?o2W;84olBN
/`GoaJ6d00CoajBfo`000?o7Y;KoajBf1Oo9Z;P4ol^[^PGoc:nm2?ooool00ol0003oooooooooo`0G
ooooo`003Oooool00ol0003oooooooooo`0Cooooo`;oYkgY0onX_NT3ojNmj@CoY[gZ00?oY;g/ojFm
jonU_N/01?nR_Nd2oifmk`;oU;cc0_nI_O44ohflm@;oN[Sj0omH[OX2ob:Ck003o`0o[olFL^7oLHoQ
00?o000000?oRY;Eoi^BbOnKT/T00_nKT/T3ojJB`@04ojfB^_nYT[goZI:mojVB_@Co/9:g0_ndT[<2
ok>B]0Co]i:a0oniTjl4ok^C[@Go_YB/00Co_YF]ol2FZoo0UZ_o`9J[0oo0Uj`2ol:GZ`?o`YR/00?o
a9V[olBJ[?o4VZ`00_o4VZ`00oo6Vj_oaI^]olFK[@02olFK[@Coaij^00CobIn]olRP[oo8X:oob:2_
0_o;XZh2olVS/@;oc:B`0_o:YK<01?l0003ocJNbolfW/_o;Z;H3oljZ]@04ol^[^_o>[KWocZfiolj]
^@Goc[6m00?odKBmolfd`Oo=]<400_o@]l44ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool04Oooool2ohFln@;oRKgh0oml^oX3of^go0;oEJoj0_ljXo@00olLTn[o3XKTo`j6i002o`5l
gP03obJ9k?lcRngo<h_]00;oJIKY0omiU^83ohJEfP?oTI?B0onIT//3oj2Aa@;oYI700ol00002ojJ@
_P?oZY2j0on]T;L00on/T;Wo[i2fojn@]P02ojn@]PCo/I2d00Co/i2bok>A/oncTK?o/i6c1?neTK44
okNB/@Co^9:`00?o^I>`okZC/?njTk000_njTk001?njU;3o_9F_okbE[onlUJl3okbF/0Go_YN`1Oo0
VK001?o0V[7o`Ybaol:L/Oo2W;43ol:L/P;oa9jb0oo4W[<00oo6X[?oaJ6dolFQ]002olFQ]0;oajBf
00?o0000olNT]_o;ZKL01?o9Z;P4ol^[^P04olja_?o<[kgoc:nmolb__@;ockFo2?ooool00ol0003o
ooooooooo`0Fooooo`003Oooool00ol0003oooooooooo`0Eooooo`CoZ;gY0onW_NT2ojJmjP;oYkgY
0onU_N/2oj:mk@;oY;g/0onO_Nh3oiVml@;oSKce00?oU;gcohBkn?n4^oP00_n4^oP3ofVdn`?o0000
0_m7PnH3og:>g`;oVi;900CoSY7BoinBa_nOT/KoWi;61?nYT[d4ok2B]`04okBB/oncT[Co/i:dok>B
]0Co]i:a1?niTjl3ok^C[@03okbD[OnnU:co_YB/00;o_YB/1Oo0UZ/01?o0Ujco`YN[ol:GZoo2Uj/2
ol:H[0?oa9V[0_o4VZ`2olJKZ`?oaI^]0_o8WJ`2olNN[P;obIn]0_o8X:l3ol^R[P03olVS/Oo<Y;3o
c:B`00;oc:B`00CobZFcolfW/_l0003ocJNb1?o>Z[D4olj]^@04om:a^Oo>/Kgoc[6molja_@;odKBm
00CocKC1om2g`Oo@]l7od;O11Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01?o
oooo0on9_OP00oml^o[oP[gjoh:mnP04og:jo0;oGK?k00Co@:OfoabCj_lLTn[o083L0_l1O=h00ol0
Mmco<h_]oc>;k@02odN?kP?oNIKR0on6UMX2oi6CdP?oVI;;0_nPTLD3o`0000;oXI740onVT;h4ojZ@
^P04ojf@]on/T;Wo[92iojb@^@?o[i2f0onaT;@00onaTKGo/i6cok>A/`02ok>A/`?o]I6a0_neT[84
okNB/@;o^9:`0_niTk04okZC/0Co_9F_0_nlU[06okjG/0Go`9V`00?o`9Zaol:L/Oo2W;400_o2W;40
1?o2W;;oa9jbolBN/_o4W[82olBN/`;oaZ:c0oo5XK@2olRU]@;oajBf00?o0000ol^Y]oo9Z;P00_o9
Z;P2olb]^P;obj^j0oo>/K`01?o<[kgockFoolne_oo?]Kl9ooooo`03o`000?oooooooooo01Gooooo
000<ooooo`03o`000?oooooooooo01Oooooo1?nX_NT00onW_NWoZ;gYojRmj@04ojNmj@03ojFmjonV
_N[oY[gZ00CoY;g/00?oWkg^oj:mkOnR_Nd01?nM_Nl2oiBml`;oQ;_h00GoSKcfo`000?l0003o0000
ogVhnP02oe>/nP03o`1;_om7PnKoAh?V00;oLXkO1?n>TM83oinBaP?oZI:m0on`T[L00on]T[[o/i:d
ok>B]002ok>B]0Co]i:a1?niTjl2ok^C[@;o_9B]1?nnU:`00onoUJco`9J[ol2FZ`02ol2FZ`Go`YN[
00Go`YR/olBIZoo4VJ_oa9V[olBJ[003olJKZ`;oaI^]0oo8WJ`00oo7WZkobIn]olVO[@02olVO[@05
olRP[oo;XZkobj:^ol^R[_o9Xk401?o<Y;03olfW/P03o`000?o>Z[GocZZe00;ocZZe00?odJjeolj]
^Oo>[KT00ooB/KT01?o>/KgodKBmom6d_OoA];d4om2g`@03omBl`ooooooooooo00;ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Fooooo`?oS[kg0_n2_OX2og:jo004og^lnomW]oco
IkOlofNgo0;oBjgi0_lNU^X00ol0OmSo06o>o`1gg002o`Ahg`;oAho^0_mNT^/3og:Di0;oPiCK0_n@
Tm<3o`0000;oVY;;0onQTL@3ojJ@_P?oZY2j00?oZ96nojb@^On/T;T00_n/T;T4ojn@]P04ok6@]?na
TKGo/I6eok6A]@Co/i6c00Co]I6aokFB/_neT[;o]I:b1?ngT[401?nhT[3o^I>`okVC/?niTk04okZC
/0Co_9F_00?o_9J`okjG/?nnUk001?nnUk06ol2I/0Go`Yba1?o4W[800oo4W[?oaZ:colJR/`02olJR
/`05olFQ]?o8YKGob:FeolRU]Oo7Y;H00_o;ZKL00ol0003objVgolVX^003olb]^P03ol^[^_o>/Kco
c[6l00;oc[6l1?o?]Kl9ooooo`03o`000?oooooooooo01Gooooo000<ooooo`03o`000?oooooooooo
01Sooooo0_nX_NT00onY_NSoZ;gYojRmj@02ojRmj@?oYkgY1?nV_NX2ojBmk003ojFmjonR_NgoX[g]
00;oX[g]0_nM_Nl00onP_NkoVKgaoiVml@03o`0000;oSKcf00?oNKSjohFkn?n5^oP00omY]?/2o`1V
f@;oLXkO0on>TM83oinBaPCoZI:m00?o/9:gojfB^_n]T[X01OncT[@2okNB/@03okJC/_niTjoo^I>_
00;o^I>_00Co^i>]okbD[OnlU:go_9B]0onnU:`2oknE[0Co`9J[00?o`IN[ol:GZoo2Uj/00_o2Uj/4
olBIZ`03olBJ[?o6Vj_oaY^[00;oaY^[00GoaI^]olRM[?o8WJcob9f/olNN[P04olVO[@Cobj:^1Oo<
Y;03olfW/P04o`000?oAZk;ocZZeoljZ]@?odJje00CocZfiom:a^OoB/KWod[6i1?oA];d00ooE^Kko
d;O1om2g`@02omBl``Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`?o
T[oe0on9__P2og^ln`?oIkOl0om;[OT2obNLkP04o`24fOl0Il;o17SOo`Ahg`;o5WkV0_mNT^/3og:D
i0?o00000_n@Tm<3oiZBb`?oXI741?nVT;h01?nZT;[oZ96nojRA__nXTKh3ojb@^@?o[i2f00?o[Y6i
ok6A]OnaTKD00_naTKD4ok>A/`Co]I:b1?ngT[45okVC/0;o^Y>`00?o^iF`okbE[onlUJl00_nlUJl6
okjG/0Oo`9V`1Oo2W;44olBN/PGoaZ:c1?o8YKD3ol^Y]`03o`000?o;ZKOoc:fj00?oc:fj1Oo>/K`4
olne_`03om>la?oooooooooo00Oooooo00?o0000ooooooooool05?ooool000cooooo00?o0000oooo
ooooool06Oooool3ojVmj0CoZ;gY0onW_NT2ojJmjP?oYkgY0_nU_N/2oj:mk@?oY;g/0ol000000onI
_O7oWKk_oifnk`03oiFml`?oQK_h0_mY]?/00omk^_[o06KIod:1iP02od:1iP;oSY7B1?nOT/H2ojVB
_@03ojBB`on]T[[o[I:j00;o[I:j1?ncT[@01?ngT[7o]Y>bokJC/_nfTk83okVC[`Go_9B]00Co_YB/
oknE[?noUJco_iF/0oo0UZ/2ol6GZ`Co`YN[1?o4VJ/5olJKZ`Cob9f/1Oo9Wjd4ol^R[P04oljU[_o<
Y;3oc:B`olbT/0;od:R`00GocJNbom6[/_oAZk;o0000oljZ]@04om6^]@Cod[6i00?oe[Jjom6d_OoA
];d00_oE^Kh01Oo@]l7oe;c3omBl`ooD_<?oel?600Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Hooooo`03oi:omOnG_o?oUkoc00CoSkog0_n3__X3og:ko0;oF[Ck0olgY_@00ol<
S^7o05>^o`1N`P02oaIniP04oc67jol0003o0000o`0000;oPiCK0on@Tm<3oiZBb`CoXI740_nVT;h0
0onRT/?oZ96nojRA_P02ojRA_PCo[92i00Co[i2fojjA^On^TKWo[Y6i0onaTKD3ok>A/`03ok>B]One
T[;o]I:b00?o]I:b0_ngT[400ongTk;o^I>`okVC/003okVC/004okZC/?nkUK3o^iF`ok^E/0?o_9F_
00?o_IN`okjG/?nnUk000onnUk06ol2I/0Go`Yba0_o5Wk83olBN/P03olNS/oo6X[?oaZ:c00;oaZ:c
1?o8YKD01Oo<Z[OobjVgol^Y]oo;ZKOo000000Coc:fj00Cod;>molja_?o>/Kcoc[6l0_oB^<02olne
_`;odkc42_ooool00ol0003oooooooooo`0Cooooo`003?ooool00ol0003oooooooooo`0Jooooo`Co
ZKgX0onX_NT01?nW_NWoZ;gYojRmjOnX_NT2ojNmj@03ojRmjOnV_N[oY[gZ00;oY[gZ00?oY;g/o`00
0?l000001?nR_^`3oifnk`04oiFmlonJ__7oV[kaoiZnl@?oSkge0_mk^_X00omF[o[o@X7Vod:1iP03
ogB>gP;oWi;600CoTi;@ojBB`onTT/?oY9;31?n]T[X3ok>B]003ok6C^?nfTk;o]Y>b00;o]Y>b0_ni
Tjl2okZD/0Co_9B]00?o_YB/oknE[?noUJ`00_noUJ`01?o0UZ_o`IN[ol6GZoo1Uj/3ol:GZ`Goa9V[
1Oo6Vj/4olRM[004ol^OZoo9WjgobIn]olVO[@;ocJ:/0_o;XZh2oljU[P;oc:B`0oo@Z;001Oo=Yk;o
dJ^bom6[/_oAZk;o000000CodJje00?oe[>gom:a^OoB/KT00_oF][X01OoA];goeKVnomFi__oE^Kko
fL3100?oe;c30_oG`lH4ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06_ooool2
oiNol`;oSkog0_nD`?@3oh^on0?oOKkk0_mY^Od3od^_n@;o8Y_[0_l000000olaQn_oChk/odn>k003
of^CiP?oT9?C0onJT//2oj6Aa003oiZCbonRT/?oXY;300;oXY;30onXTKh3ojb@^@03ojZB_On^TKWo
[Y6i00;o[Y6i1?naTKD00oncTK?o/i:eok>B]@05okFB/P04okNB/OngTk;o]i>bokNC/P?o^I>`00?o
^YJbok^E/?nkUK000_nkUK02okbE[`;o_IN`1?nnUk06ol2I/0Go`Yba0oo5Wk82olBN/P;oaj>c0oo6
X[<2olZV]@;ob:Fe0_o<Z[L3ol^Y]`04olj_^_l0003oc:fjolb]^P?od;>m00Goc[6lom:h`?oB^<3o
d[S0olne_`03om>la003omO6bOoooooooooo00Oooooo00?o0000ooooooooool04oooool000cooooo
00?o0000ooooooooool07?ooool7ojVmj003ojRmjOnX_NSoZ;gX00?oZ;gY00CoY[gZo`000?l0003o
00000onU_N/2oj:nk0;oY;g[0onQ_^d2oiZnl@;oWkk_0onG__83ohVlm`;o@X7V0_mdS]h3oi>Bd0Co
Y9;30on]T[X01?ncT[Co/I>hok6C^?naTkP4okJC/P04okVC[onjU;3o^YB`okZD/0Co_9B]1OnoUJ`0
0oo0UZ_o`IN[ol6GZ`02ol6GZ`03ol:GZoo4VJ_oa9V[00?oa9V[1Oo6Vj/2olVMZ`;ob9f/0_o;Wj/3
olVO[@;ocJ:/00?obj:^oljU[_o>YJh00_o>YJh01?o<Y;3od:R`om2X/?o@Z;04om6[/P04omF`/ol0
003odJjeom6^]@;oe[>g00Cod[6iomJf^_oF][[oe[Jj1?oE^Kh2omW0`@04omBl`ooG`lKoel?6omO3
aPGooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`?oVkoa0onD`?@00on;
_oSoT/3foi;0mP04ohNon@;oMkgl0ol00002oc^Ym004o`^?gol0K=OoChk/odn>k0;oJi?V0on0U=d3
oi2De0CoVY?;0onRT/<4ojRA_P03ojb@^OnZT[goZY:m00Co[Y6i0onaTKD00on`TkSo/i:eok>B]@02
ok>B]@?o]I:b00?o]IBdokNC/_ngTk800_ngTk82okVC/0;o^YJb1?nkUK001?nlUJoo_IN`okfG/?nm
Uk04okjG/003ol2J/Oo0VK3o`9V`00;o`9V`1_o2W;43olFO/P04olBN/_o7Xk?oaj>colNS/`;oaZ:c
0oo:Y[D00oo8YKGoc:ZgolbZ]`02olbZ]`05ol^Y]oo>[k[ocZnjolj_^_l000001?o@/kd4om:h`0?o
dkc40ooGa/T9ooooo`03o`000?oooooooooo01;ooooo000<ooooo`03o`000?oooooooooo01cooooo
1onY_NP4ojRmj0?o00001?nW_NT00onU_N_oYkgZojNmjP04ojBmj`03oj6nkOnS_^coXkk/00CoWkk_
00?oUkkboibnl?nL__000onC__@2o`1Kd@;oM8kN0onCT]03ojBB``;o[I:j00?oZIC0ok6C^?naTkP0
0onaTkP3okJC/PCo^YB`1?nlU:d00onmUZko_iF/oknE[002oknE[0Go`IN[00?o`YN[olBIZoo4VJ/0
0_o4VJ/5olJKZ`?obIf[00Cob9f/ol^OZoo;Wj_obin[0_o9Wjd3olfR[003ol^R[_o>YJkocZF^00;o
cZF^1?o@Z;000ooD[K7odJ^bom6[/P02omF`/`03o`000?oA[[Goe[>g00;oe[>g1?oF][X00ooJ_Kgo
eKVnomFi_P03omW0`@?oel?60_oJbl/4ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07?ooool00onK_o7oW[o`oijol003oiW0lP?oT/3f0_n7_oT3o`0000;oPkok0_ma_?d3oeBdn`03
obZRk_lFO>Go5WcU00;oJi?V0on0U=d3oi2De0?oVY?;1?nRT/<2ojRA_P03ojBCa?nZT[goZY:m00;o
ZY:m1?n^TKT00onaTKGo/9>hok2C^004ok>B]@;o]I:b0_neU;@4okNC/P03okVC/?njU[;o^YJb00;o
^YJb0onkUK05okfG/0;o_YN`0_o0V[44ol2I/003ol:M/_o2W;7o`Yba00;o`Yba1?o5Wk85olNS/`05
olJR/oo:Y[GobZJeolZV]Oo8YKD01?o<Z[L4olj_^P03o`000?o@/kgod;>m00;od;>m00?oeKc2om:h
`?oB^<000_oF`/D00ooC_<CoelK9omO6b@02omO6b@Wooooo00?o0000ooooooooool04_ooool000co
oooo00?o0000ooooooooool07Oooool7ojVmj0?o000000CoZKgXojRmjOnX_NWoZ;gY0_nW_NT00onX
_NWoYkgZojNmjP02ojNmjP;oY;g[0_nV_NX3oj>nk0;oWkk_0_nR_^d3oibnl0;oTkkd00CoV[kaofl0
0?loP>Ko?h3V0onCT]03ojBB``04ojfB^_nYU<3oZIC0ojVD`0Co/I>h0_nfTk82okJD]@Co^YB`0_nl
U:d2okfF[PCo_iF/00?o`9N]ol6GZoo1Uj/00_o1Uj/5olBIZ`GoaY^[0oo9WJ/00oo8WJcobin[ol^O
Z`02ol^OZ`04olVO[Oo=XZcocJ:/olfR[0GocZF^0oo@Z;02omB]/@;odJ^b0ooE/;<01Ol0003oe[>g
omJc]ooF/kOof[Zi00;oe[Jj0ooJ_Kd01_oE^KkofL31omW0`OoI`<7og<W6omO3aP?of/_;1Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo0onN_o001?nI`?;oWKo`oifol?nH
`?<3o`000003oi30monF`?CoU/3d00CoSL7h0_mo_o`3ofZlo@;o5WcU0_lnR^`3oh2Dg@?oT9CD0onJ
Tl/2oj:B``04oibDc?nTTlCoY9?4ojBCa0CoZY:m0on^TKT00on/U;go/9>hok2C^002ok2C^0?o/i:e
00?o]I:bokFD]?neU;@00_neU;@3okNC/PGo^YJb0_nkUK02okbH/PCo_IN`00Co_YN`ol2J/Oo0V[7o
`9Za0oo0VK02ol:M/PCo`Yba1?o5Wk800oo8Y;Coaj>colNS/`02olNS/`CobZJe1Oo<Z[L4olj_^P04
om>g__l0003od;>mom2c_@;oeKc200God[S0omK2aOoF`/Goe/;5om[>c@03omO6b@;of]?A2Oooool0
0ol0003oooooooooo`0Aooooo`002oooool00ol0003oooooooooo`0Oooooo`?oZKgX0ol00005ojVm
j004ojRmjOnX_NSoZ;gXojRmj0;oZ;gY0_nW_NX3ojNmj@03ojJmj_nW_NWoYkgY00CoYKk[00?oX[k]
ojBnjonT_^/00onQ_^h3oiZnl@03ofl00?loP>KoNY3M00;oNY3M0onIU<d4ojVD`0Co/I>h00Co]Y>b
okJD]OnfU;Go]YBe1?njU;001?nlU:go_IJ^okfF[_nmUZh3oknE[0;o`9N]1?o1Uj/4olBIZ`GoaY^[
1?o9WJ/5ol^OZ`CocJ:/00Cod:J]oljU[_o>YJkocZF^0_oBZJl00oo@Z;3oe:faomB]/@02omB]/@07
om6[/_oE/;?oeK2comF`/ooF/kOo0000omJc]`02omZj^@03omJf^_oJ_Kgof[fm00;of[fm0ooI`<42
omc9aP?of/_;0_oLe=05ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07oooool3
oj6okP?o00000_nH`?<2oic0l@?oU/3d0_n=`OP00onE`OGoRl7ioh_1n@02oh_1n@?oO;ol00?o05Fn
ocj:k?lnR^`00_mRT^T3ogfFh0?oSiKF0onLU<`4ojBCa0?oZY:m00Co[Y6iojbD_On/U;go[9Bm1?n`
TkP2ok>B]@03ok>E^?neU;Co]IBd00?o]IBd0_ngTk82okRF]@Co^YJb00Co^iF`okbH/_nlV;;o_9Rb
1?nmUk05ol2J/@04ol2I/?o2WK;o`Yfbol:M/P?o`Yba0_o5X;<2olFO/P;ob:Bd1?o7Xk<4olZV]@04
olj]^Oo<Z[Ooc:ZgolbZ]`;od;:k0_o>[kX3om>g_P05o`000?oE_<;oeKc2omFl`_oIb<T00ooF`/D2
om[>c@05omO6bOoJdm7of]?Aom[CdOoKh]X02Oooool00ol0003oooooooooo`0@ooooo`002oooool0
0ol0003oooooooooo`0Oooooo`?o00002OnY_NP2ojRmj0;oZKgX0onX_NT2ojNmj@03ojRmjOnW_NWo
YkgY00;oYkgY0_nU_^/00onV_N[oY;k[ojBnj`02ojBnj`03oj6nk_nS_^coXkk/00CoWkk_00Co05;8
ogZ@gOmjT=goNY3M0onIU<d3ojVD`0?o/I>h00?o[YJnokJD]OnfU;D00_nfU;D4okZD/0Go_IJ^00Co
_iF/ol2G[Oo0Ujgo`9N]0oo1Uj/00oo3VJcoa9V[olBIZ`02olBIZ`03olJL[?o6Vj_oaY^[00;oaY^[
00GobIj/olVMZoo9WJ_obIf[olbQ[004ol^OZ`03oljS[?o=XZcocJ:/00;od:J]0oo>YJh2om:Y[`03
om2X/?oD[K7oe:fa00;oe:fa1?oE/;<00ooI]kKoe[>go`000002omZj^@Gof[fm00?og/K2omW0`OoL
bLH00_oLbLH00ooOdlcof/_;omcDd002omcDd003omcNf?oooooooooo00;ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Oooooo`?o000000?oXko]oj2okonP_nl00_nP_nl00onL`?7o
X;o_oj2ok`04oi_0lP;oUL7e0_n;`OT3oi?1mP;oRL7j00?oNKomof`00?l0K=L00_mRT^T2ogfFh0?o
SiKF1?nLU<`3ojBCa0;oZY:m00?oYYK4ojbD_On/U;d00on/U;d3ok2C^004ok>B]OncUKSo/iFhok>E
^0Co]IBd00Co]i>bokRF]OnhU[Go^9Je1?njU[84okbH/P?o_IN`0_noVk<4ol2J/@Go`Yfb00Go`Yba
olFP/oo5X;?oaJ2colFO/P03olRT]0?oaj>c0_o;Z;H2olZV]@?ocZfi00Goc:Zgom2b^oo@/[_od;:k
olj_^P04om>g_P04omFl`_l0003oeKc2omFl`P;ofLS900Coe/;5om[>cOoJc/gof/k=0ooJdm42om_R
fPWooooo00?o0000ooooooooool04?ooool000_ooooo00?o0000ooooooooool07?ooool3o`0000?o
oooo3_nY_NP00onX_NWoZKgXojVmj003ojRmj@;oYkgY0_nX_NT3ojJmjP;oY;k[00?oY[kZoj>nk?nS
_^`00_nS_^`2oinnk`03oj:nkOnM__3o05;800;oNY3M0onIU<d4ojVD`004ok6C^?n^U[ko[YJnojjF
_PCo]YBe0_njU;02okZF/`Co_IJ^00?o_iF/ol2G[Oo0Ujd00_o0Ujd01?o1Uj_o`iV/ol>I[?o3VJ`2
olBIZ`;oaYb/0oo6Vj/2olVN[0;obIf[0_o<XJ`3ol^OZ`;ocZ>/0_o=XZ`2om2V[@;ocZF^0ooBZJl5
omB]/@03omRc/ooE/;?oeK2c00;ofKNf00Goe[>go`000?oJ^[Wof[Ziomo4_P03omZm_@;og/K20ooL
bLH2omoCc0?og=C@0_oLg]P5ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07?oo
ool3o`0000?ooooo0_nS_nd2oj2ok`?oXko]0_nP_nl2oi_0lP03oio0l?nK`?;oVl3b00;oVl3b0_nC
`OH00onJ`O?oT/7goi;1m`02oi;1m`;oQl;j0_lWQ>X2ogfFh0?oSiKF0onLU<`3ojBCa004ojZB_OnV
U/CoYYK4ojJFa0Co[9Bm0_n`TkP00on_Ukko/iFhok>E^002ok>E^0Co]IBd1?nhU[D4okZF/P03ok^I
]OnlV;;o_9Rb00;o_9Rb00Co_IN`oknK/onoVk?o_i^c1?o0V[400oo2W[Co`Yfbol:M/P02ol:M/PCo
aJ2c1Oo8Y;@01Oo7Xk?objRfol^X]_o;Z;KobZJe00CocZfi1?o@/[/5om>g_P03omO2aOl0003oeKc2
00?ofLS90ooJc/d2omgMeP03om[CdOoKh][ofn;J00;oeo7S2Oooool00ol0003oooooooooo`0?oooo
o`002oooool00ol0003oooooooooo`0Iooooo`?o00001ooooolAojVmj004ojRmjOnX_NSoZ;gXojRm
j0?oZ;gY00CoY[gZojNmjOnW_NWoYkgY0_nV_^X2oj>nk0?oYKk[0_nR_^d2oifnl0;o@H?W0onIU<d2
ojVD`003oinGbon^U[ko[YJn00;o[YJn1?nfU;D01?njU;3o^YJcokZF/onjU[<4okfF[PGo`9N]00Go
`IN[ol>I[?o3VJco`iV/olBIZ`03olJL[0?oaY^[0_o9WZ`2olVMZ`;oc:6/0_o;Wj/3oljS[0;ocJ:/
0oo@YZd01Oo>YJkodZV_om:Y[ooBZJooek2b00?oe:fa0_oH/k<01ooE/;?ofKNfomVg]_oI]kKog/6k
omZj^Ol000000ooOa;h01_oJ_Kgog/K2omk6`_oNa/;oh];8omc9aP;ogm?<0_oPh=@00ooLe=3og=kH
omcNf002omSXh0?ooooo0ol0000Iooooo`03o`000?oooooooooo01Wooooo0ol00007ooooo`?oYKk/
0_nS_nd00onU_^coX[o]oj:ok@02oj:ok@;oWl3`0_nK`?83oio0l0;oV/7c0_nB`OL2oiW1l`;oT/;g
00?o9hCZoeNBkOmGT^d00on?U]H2oibDc004ohnHf?nMUlgoWIO=oifGc@CoYYK41?n/U;d01?n`TkSo
[iNnojnG__n_Ukh3ok>E^0?o]IBd0_nfV;T4okRF]@;o^YJb0_nkVKD4okbH/PCo_i^c0oo0V[42ol:N
]0Co`Yfb1?o5X;<00oo8YkOob:BdolRT]002olRT]0CobjRf1Oo>[KT4om2b^`04omFl`_oC]kkodkNn
om>g_P;oel;500?oeKc2o`000?oIb<T00_oIb<T00ooMf=;of/k=omgMeP02omgMeP05om[_h?oKh][o
eo7SomOahoo8nnL00_n]n^<6ooooo`?o00004?ooool000_ooooo00?o0000ooooooooool05_ooool3
o`0000_ooooo4OnY_NP2ojRmj0;oZKgX0onX_NT2ojNmj@03ojRmjOnW_NWoYkgY00;oYkgY0_nU_^/0
0onW_N[oYKk[ojFnj`02ojFnj`03oj6nkOm1PnOoPYCM00;oPYCM1?nOUl/3ojjF_P?o]YBe00?o/iRk
okZF/onjU[<00_njU[<3okfF[P03okfI/_o0Ujgo`9N]00?o`9N]1?o3VJ`00oo4VJ_oaYb/olJL[002
olJL[003olJKZoo9WZcobIj/00;obIj/00GobIf[olbQ[?o<XJcoc:6/ol^OZ`04oljS[0Cod:J]0ooB
ZJl2omN`/P;oe:fa0ooH/k<4omVg]P;og/6k00Cof[Zio`000?oOa;koglBn0ooNa/82on;Bb003onCP
d?oOdlcoh>3D00;oh>3D00CogNcMomcNf?oHj>3of>SP0_oAl>P2o`0000;ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Fooooo`?o00002oooool00onU_^coY[k[ojJnj`03ojFnk0;o
X[o]0_nT_n`3oj:okP;oWl3`00?oX[o^oik0l?nN`?000_nN`?000onI`O?oW/3`oik0l002oiW1l`03
o`1H`?mGT^goEi;]00;oNIST1?n?V=P3oifGc@?oYYK40on/U;d00onYVLGo[iNnojnG_P02ojnG_PCo
/iFh00Co]IBdokJH^OnfV;Wo]YRi1?nhU[D01?njU[;o^iVeok^I]OnkVKD4okbH/P03okjM]_noVk?o
_i^c00;o_i^c00Co`9Zaol:N]?o2W[Co`Yjd0oo2WK82olFR]@;oaJ2c0_o8YkL4olRT]0CobjRf00Co
ck6kolj]^Oo>[KWocZfi0_oB][h2om2b^`?oeKc200SodkNnomO2aOoG`/Goel;5omcBc_oIb<Wo0000
omW8b@;ogMSB0ooMgMH01OoJkn3oc?_UolckiOoGlN?ob?_W00;o[O[S00CoS>kHog3OcomOe/koFmCE
0_mRf><01?l0003oooooooooool0000@ooooo`002oooool00ol0003oooooooooo`0Dooooo`;o0000
3ooooolEojVmj003ojRmjOnY_NSoZKgX00?oZ;gY0_nW_NT2ojRmj@?oYkgZ0_nU_^/01?nV_^[oY;k/
ojBnk?l0CL83oh:Dg@?oWiO;1?n^U[h01?nfU;Go/iRkok>H^oncV;/4okZF/`04okfF[_nmVK;o_IVb
okfI/P?o`9N]00?o`Y^`ol>I[?o3VJ`00_o3VJ`5olJL[003olJKZoo9WZcobIj/00;obIj/1?o<XJ`5
oljS[0Cod:J]00?oeJf`om:Y[ooBZJl00ooG/;801OoD[K7of;>comRc/ooH/k?og[fh00;ofKNf0ooN
`K/2omo4_P04o`000?oOa;kohm34omk6`P;oh];80_oTh=03on3Pe004omg/gOoCm^GodoKUomSXh0;o
dO3X0_o4m>h3ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool2o`0000ko
oooo1?nV_^/01?nU_^coY[k[ojJnjonV_^/3ojBok004oj:ok_nT_ncoY;o/ojBok0;oX[o^0_nN`?03
oj:okP;oW/3`0_nI`O<00onN`O3o37[Ro`ajhP02ogVHi0?oSiSH0onMUld4ojJFa004ojbD_OnYVLGo
ZIW5ojVIa@?o[iNn0oncUKP00onbV[oo]YRiokJH^@02okJH^@Co^9Je1OnkVKD2okbH/P;o_Yff1?no
Vk<5ol:N]005ol:M/_o5X[GoaJ:eolFR]Oo5X;<00oo8YkL3olRT]0;oc:bi0_o;Z;H3olna^`05olj]
^OoB][kod[Jnom:f__o@/[/01?oE_<83omO2a@?og=;>00?ofLS9o`000?oMf=800_oMjmd02ooMgMKo
f^oPolckiOo<nnGo[_[Noh?Yc?mMd[[oA<:aoc^n]_m0`lKoD<gL00;oIMO_0_m_g?401?mngO_oRm_o
oh_Kool0000@ooooo`002_ooool00ol0003oooooooooo`0Booooo`?o00004_oooolHojVmj003ojRm
jOnY_NSoZKgX00CoZ;gY00CoYkgZojRmjOnX_NWoZ;gY0_nV_^X2ojBnk003o`1=`_n2U=goPYCM00?o
WiO;0on^U[h00onWV/Wo/iRkok>H^`02ok>H^`Co^YJc1?nmVK82ol2G[@;o`Y^`1?o3VJ`00oo5WZoo
aYb/olJL[002olJL[0GobIj/1?o<XJ`00oo?YZoocZ>/oljS[002oljS[0?od:J]0_oE[K02om:Y[`?o
ek2b0ooH/k<3omjm^007omVg]_oN`K_og/6komk1^ooTc/;oglBno`000002on?@a004onKPcOoRd/So
i>3@onCPd0;ohNoJ00Coh>3Domg/gOoCm^GodoKU0_o2n^X01?oAl>Soa?C^olCdk_nflo<2ojS`m`03
ooooool0003ooooo01Oooooo00?o0000ooooooooool04_ooool3o`00017ooooo0_nV_^/2ojNnjP;o
Y[k[0_nW_^X3ojJnj`;oY;o/00?oY[k[ojBok?nT_n`00_nT_n`2oj:okP03ojBok?nR_nkoX[o^00;o
X[o^00CoW/7`oj;0k_l<N^;o37[R0_m9T_03ohnHf0?oWIO=0_nVU/@00onOVlooZIW5ojVIa@02ojVI
a@Co[iNn00Co/iFhok:J_onbV[oo/YZo1?nfV;T2okRF]@;o^I^j1?nkVKD01?nlV;;o_YffokjM]_nn
WKH3oknK/`03ol:Q]oo2W[Co`Yjd00;o`Yjd00?oaJFiolFR]Oo5X[D00_o5X[D5olRW]`05olRT]?o<
[;Woc:biolb/^Oo;Z;H01?o?/K/4om:f_P04omO4aooE_<;oeKc2omFl`P;of/_:00?oel;5omcBc_oL
d/h00_oLd/h01OoNiM[o0000omg[gOoMjmgodO[S00;o/?_L00Goc?_Uojkjg_n3jLco0000oeg@l@02
oeoBk`;oMmSl0_mif_/2ohWIo`;oRm_o00?oU=Kno`000?ooool03oooool000[ooooo00?o0000oooo
ooooool03oooool3o`0001Kooooo6onY_NP2ojRmj@;oZ;gX0onX_NT4ojNmj@04ojJnj_nW_NWoAhW[
odN9j`?oWiO;00Co[YJnojNJbOnWV/WoYi[90oncV;/3okZF/`03okVK^OnmVK;o_IVb00;o_IVb00?o
`9N]ol:K/?o2Vk000_o2Vk02ol>I[0;oaIj_1?o6W:`00oo9XJoobIj/olVN[002olVN[0?oc:6/0_o?
YZl3oljS[0;odZZ_00?od:J]omF]/?oE[K000_oE[K04omN`/P03ombj]_oH/k?og[fh00?og[fh0ooN
`K/2onC>`P03omo4__oSd<Co000000;oi^3=00?oho7GonCPd?oQkmX00_oQkmX00ooDnn7o_?gRom?f
i@02ol;jjP04ojggk?nJlNkoV_7^okKcl`;oZ?3g0_nOjoX00ooooooo0000ooooo`0Fooooo`03o`00
0?oooooooooo00oooooo0ol0000Fooooo`03ojNnj_nX_^WoZ;kY00CoYkkZ00?oY[k[ojNnj_nW_^X0
0onV_^/2ojBok0;oY[k[0onT_n`2oj:okP03ojBok?nR`>koX/3^00;oX/3^00?oDP00odVBl?m9T_00
0_meW>T3oi2Mg0CoWi_?0onYVLD3ojnG_P03ojbMaonbV[oo/YZo00;o/YZo1?nfV;T01?nhU[Go^I^j
okVK^_niVkX4ok^I]@Go_Yff00Co_i^col:Q]oo2XKOo`Z6g0_o2W[@2olFU^@CoaJ:e00?obJ^kolRW
]oo8YkL00_o8YkL4olb/^@Gock6k00Coe;g3om:f__oB][kod[Jn0_oGa<L01OoE_<;of/_:om[;b_oJ
bl[ogMkF00?og=;>0_oNiMX00ooEn>;o0000om7jh`02ok3kg004ogcT`_m;`jGoNmCoog_Do`;oN=Km
0_n:e?l2ohWFo`;oU=;m0onDe?h2oiCFoP03ooooool0003ooooo00kooooo000:ooooo`03o`000?oo
oooooooo00cooooo0ol0000JoooooacoZKgX00?oZ;gXojVmj?nY_NP00onX_NT2ojNmj@05ojRmjOnW
_NWoYkgYojNmjOm7RN/00on;V]`4ojNJb@Co/iRk00Co^YJcokVK^OniVkWo^I^i0onmVK85ol:K/004
ol>I[?o5WZooaIj_olFN[`?oaYb/0_o9XJl3olVN[0;oc:>_0_o<XJ`2olnV[`;ocZ>/0ooBZZl00oo@
YZgoeJf`omF]/002omF]/0?oek2b0_oL^[H00ooH/k?og[fhomjm^002omjm^003onC;_ooN`K_oi<k2
00;oi<k200Coj=o;on?@a?oVh<go00000_oSlML2om?ng007on7_f_oDnn7o_?gRokcmh_nLm=koP>SK
ojggk002oi[akP03ohk[l_n:i_SoR^Kh00;oWn_j00?oVnGlooooool000005oooool00ol0003ooooo
ooooo`0<ooooo`?o00006_ooool3ojRnj@;oYkkZ00?oZ;kYojNnj_nW_^X00_nW_^X01?nV_^_oYkkZ
ojNnj_nW_^X3ojJnj`04ojBok?nV_^_oY[k[ojJnj`;oY;o/0_nR`>h2ojBok0;oX/3^00?o06gBogFL
jOmeW>T00on@WM`3oinKc`CoZIW500Co[iNnojbMaon/WLOo[9g70onbV[l3okJH^@03okJN`?niVk[o
^I^j00;o^I^j0onkVKD2okbO^`Co_Yff1?o2XKL00oo2W[CoaJFiolFU^@02olFU^@;oaJ:e0_o9Zk/3
olRW]`;ocK2m0_o<[;T2om2f`0?ock6k0ooD_L<01?oB][koelC7omO4aooGa<L3om[;bP?ogMkF00Wo
g=;>omkUf_oNiM[oeOSRokClfomhh;_o0000ok3kg?modol00_n@d?d3ohgBoP;oR]Co0_nEd?`2oiCB
o@Oooooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool02Oooool3o`0001ko
oooo7onY_NP00onX_NWoZKgXojVmj003ojRmj@;oYkgY00?oZ;gYodN9jon;V]`00_n;V]`3ojNJb@?o
/iRk00?o[ik7okVK^OniVkT00_niVkT2okfI/P;o_Yjh1?o2Vk000oo3VJcoaIj_olFN[`02olFN[`04
olJL[?o9XJoobJ6_olVQ[`;obIj/0oo<Xjl00oo<XJcocjJ_olnV[`02olnV[`04oljS[?oBZZoodZZ_
om:Z[`GoeJf`00?of[NeomN`/_oL^[H00_oL^[H4omjm^0;oi<^o00?og/6konC>`_oTc/800_oXgl/0
0ooUlmCoi^3=o`000002on?ae`0:om?ng?n`n]KoPNK5oh7VaOnloN;oW?CNoh3Xfom_h=koK=gWog?M
l`;oO]cl0_n<hOd4ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool3o`00
01kooooo00CoZ;kYojRmjOnX_NWoZ;gY0_nX_^T2ojNnjP;oZ;kY0_nW_^X2ojRnj@?oYkkZ0_nV_^/0
0onW_^[oY[k[ojJnj`02ojJnj`03ojBok?nV_^_oY[k[00?oY;o/0_lgT_03oi2Mg0?oWi_?0_nYVLD0
0onRX=;o[9g7ojbMa`02ojbMa`Co/YZo00Co]YRiokJN`?nfW/3o]Yk01?niVkX01?nkVKGo_9nkokbO
^onlWk/3okjM]P03ol2T_Oo2XKOo`Z6g00;o`Z6g1Oo5YKT00oo5X[GobJ^kolV[^`02olV[^`05olRW
]oo=/;gocK2molf`_Oo<[;T01?o@]/000oo?/K_oe;g3omBm``02omBm``?oelC70_oLem801?oJbl[o
gMkFomgNe_oMg]H2omWdh@03omkUf_oEn>;o]?cK00;oN>2k00Co0000oi?>o?n@d?goT=3m0_nIc?T3
oiO>n`;oUM3l2_ooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003oooooooooo`06oooo
o`?o00008_oooolRojVmj006ojRmjOnY_NSoZKgXojVmj?nX_NWoZ;gX0on;V]`4ojNJb@03ok>H^on_
W/Oo[ik700Co^I^i00Co_IVbokjN^?nnW[So_Yjh1?o2Vk05olFN[`GobJ6_00GobIj/olbS[oo<Xjoo
c:>_olbQ[004olnV[`CodZZ_00Coek>domF]/?oE[K3oeJf`0_oJ]kD01OoG/;;og;Zfombj]_oL^[Ko
h/Rm00;og[fh0ooTbkl00ooXg/Woi<k2onSOb`02onSOb`06onGce?o@omKod?oFo`000?oCo]co/?[F
0_n1i/D01?mId;SoE<__of3CkomPdnl2ogGGo0;oO]cl1oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Kooooo0ol0000Rooooo`;oZ;gY00?oZKgXojRnjOnX_^T02OnX_^T00onW_^[o
Z;kYojRnj@03ojNnjP;oY[k[00?oYkkZojJnjonV_^/00_nV_^/2ojBok003ojJnjolgT_3o=i;`00;o
L:7_0onAXn44oj:PdP?o[9g70onbV[l00on`X/[o]Yk0okJN`002okJN`0?o^I^j00?o^J?2okbO^onl
Wk/00onlWk/01?nnWKKo`:Bmol2T_Oo0Y;d3ol:Q]`03olBZ_oo5YKWoaJFi00;oaJFi1Oo9Zk/4olf`
_@God;K01?oD_L<2omW?c`04omO4aooLem;og=OBomcGdP;of^kP00KogMkFomWdhOoIm>7o^_gMogSP
^Ol00002oiK;nP04oig7mOnKbOOo0000oi_9m`;oVLci4?ooool00ol0003oooooooooo`0=ooooo`00
2_ooool00ol0003oooooooooo`03ooooo`?o00009_oooolUojVmj0?oZ;gX0_mBTnl4oiJQf`Co[ik7
0oniVkT4okjN^0?o`Y^`0_o3XKH4olFN[`03olRU]Oo9XJoobJ6_00;obJ6_1?o<Xjl5olnV[`?odZZ_
0_oG/k@2omF]/0?of[Ne0ooL^[H3on;8_@05omjm^?oTbkooi<^oonC;_ooXg/T00ooXgl/2onGce005
om3oe_nMl/CoG<fTo`000?mjcOl00omccoh00omad_goooooooooo`0;ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00oooool3o`0002Kooooo0onY_NP2ojRnj@;oZKgX2_nX_^T01?nW
_^[oZ;kYojRnjOnX_^T2ojNnjP;oY[k[0_nW_^X2ojJnj`03ojNnj_l0F[So05Zh00;oL:7_0onAXn43
oj:PdPCo[9g700Co/YZook2Rb_n`X/[o/:;:1?nfW/000oniVk[o^J?2okVS`P04okbO^`03okjYaOo0
Y;go`:Bm00;o`:Bm0_o2XKL2olBZ_`?oaJFi0_o9/<84olV[^`CocK2m00CodKk8om2f`?o@]/3od;K0
0_oFa//2omBm``?ofLo?0ooLem83om[^h005ol;mhOoIm>7o^_gMogSP^OnIbOP00_nOa_<3oig7m@03
oi_9mol0003ooooo017ooooo00?o0000ooooooooool03Oooool000Wooooo00Co0000oooooooooooo
oooo0ol0000ZooooobGoZKgX0_nX_NP00onY_NSoDY?_oe:Ck`04oiJQf`?o[ik70_niVkT2okJRa@Co
_Yjh00Co`Y^`ol>Q]_o3XKKo`j6f0oo5WZl2olRU]@CobJ6_1?o<Xjl01?o@[;CocjJ_olnV[oo?YZl2
omB_]003om:Z[ooG/kCoek>d00;oek>d00KoeJf`omZg]OoJ]kGof[Neon35_OoL^[H4on;8_@?oi<^o
0_oXg/T01_oVm=?oj=o;onGce?oUlmCod?oFoigba0?ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Dooooo`04o`000?ooooooooooooooo`?o0000:_ooool7ojVmj005ojRnjOnY_NSo
ZKgXojVmj?nX_^T00_nY_NP:ojRnj@03ojNnj_nX_^WoZ;kY00CoYkkZ00?oY[k[ob2?k?lPSn`00onA
Xn43oj:PdP;o[9g700?oYJKGok2Rb_n`X/X00_n`X/X3okJN`003okBXcOniXl;o^J?200;o^J?20_nl
Wk/2okjYa@Co`:Bm00?o`Z6golBZ_oo4Z[l00_o4Z[l01?o5YKWobK32olV``_o9/<83olV[^`;ocKO4
0_o=/;d3om6nb005om2f`?oFa/_oe/K;omK6booD_L<00ooIcll2om_Wg@07omcGd_oJk^3of^kPom[^
h?o2oN7oO>:ko`000002oj74l@;oWlKc1_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00gooooo0009ooooo`Co0000;ooooolXojVmj004o`1B^_nFXM_oUZ7KoiJQf`?o[ik700Co^I^i
okJRaOnfX/Go]Z;51?nnW[P4ol>Q]P;oaIj_0oo8YKD3olVQ[`;oc:Rd0_o<Xjl2om2/]0;ocjJ_0ooD
[k@00ooBZZooek>domNc]002omNc]0?of[Ne0_oPaKd00ooL^[Koh/Rmon;8_@02on;8_@04onSLb?oT
bkooj=k9onSNb@;oi_CC00?ob_oAoh?S[ol000001Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Cooooo1?l0000_ooooo`goZKgX00?oZ;kYojVmj?nY_NP02_nX_^T2ojNnjP;oZ;kY
0_nW_^X3ofVXm@?oTJ_W1?nUY]L4ok2RbP03okJN`?ndZ<go]:S=00Co^J?200?o_9nkokjYaOnnZLD0
0_nnZLD2ol2T_@03ol>`b?o4Z[ooa:Zo00?oa:Zo1Oo9/<801Oo9Zk_ocKO4olfga?o=]lCocK2m00Co
dKk80ooFa//3omWNfP03omW?cooKimgofnOM00?ob?cU00Cof^kPol;mhOnS`o3oXl?`0_nQa?49oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool000Wooooo0_l0000aooooob[o
ZKgX0_mQXO<3oj:Xf`Co]Z;50onnW[P2okfW``Co`j6f00?oaIj_olRU]Oo8YKD00_o8YKD01Oo9XJoo
c:RdolbX]?o<Z;Coc:>_00Cod:bd00CocjJ_omB_]?oD[kCoe:nd1OoG/k@00ooM`Kcof[Neon35_@02
on35_@04onKJb?oRb;goh/Rmon;8_@;oj=c800KoiOGConSNbOoVm=?oi_CCol[odOn3hjl8ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool2o`00037ooooo4OnY_NP01?nX_^Wo
ZKgXojVmj?nY_NP<ojRnj@?oJJSe0onAZnL3ojFVe`;o/:;:0_nY[m/4okBXc@;o^J?200?o^K3AokjY
aOnnZLD00onnZLD01?o0Y;go`k38ol>`b?o3/<P3olBZ_`;oakS;1?o9/<84olfga004om7:dooA_/So
dKk8om6nb0;oe]CG00?oe/K;omWNf_oIg]X00_oIg]X00oo>n>SofnOMolSli@02olSli@03ohCW`onT
`^kooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`002oooool0
0ol0003oooooooooo`0_ooooob[oZKgX0_mQXO<3oj:Xf`Co]Z;500Co_YjhokfW`onmYl?o_JO31?o3
XKH5olRU]@Coc:Rd1Oo@[;@4omB_]004omZm_?oG/kCoek>domNc]0;ogL6l00Cof[Neon35_OoPaKgo
h<Fm0_oVf/P01?oRb;goj=c8onSLb?oUmM<2ol7nc003ofG=Uooooooooooo00[ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02oooooo6?nY_NP00onX
_^WoZKgXojVmj007ojRnj@;o18OM0_mO[oX2ojFVe`03oi:dk_nY[m_oZJoK00?oZJoK0ondZ<d01?ni
Xl;o^K3AokV`dOni/=43okjYa@03okjieOo3/<So`k3800?o`k3800Coa:ZoolNhboo7^<_oakS;0oo9
/<82olc1c`;ocKO40ooAb]<01OoA_/Soe]CGomKDeooFe=Ood?3X00?ofMkJ00Goc_SXoi3^d?n@k]3o
T>k@olSli@0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool000cooooo
00?o0000ooooooooool0<?oooolYojVmj0;o05bj0onRZ=/2okJRa@03ojj_fOnmYl?o_JO300;o_JO3
0oo3XKH2olB/`@Cob:Fe1?o<Z;@00oo@]Kkod:bdom2/]002om2/]003omJi_OoD[kCoe:nd00?of[fl
00Goek>domg1_?oM`KcogL6lonCGb@02on35_@?oi][800?oi?GEonSLb?oUmM<00_o1o/`00omUcIOo
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0`oooooa[oZKgX0_nX_^T2ojVmj0CoZ;kY00?oZKgYoen_n_mO[oX00onB]>h4ojV_f`;o
]:S=00?o[KWQokV`dOni/=400oni/=401?nnZLGo_[WEokjieOnn^MD3ol>`b003ol?3f_o7^<_oakS;
00?oakS;00GobK32olc1coo<`Looc<7?olfga004om7:d`?oe]CG0oo@l>P01?oIg][oc_SXoi3^d?n@
k]0Gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000gooooo00?o0000
ooooooooool0;oooool[ojVmj003o`1L^_mc/?OoLk3g00Co[ZoI1?nmYl<01?o3XKKoa:c1olB/`Oo4
[<43olRU]@;obk2o0_o<Z;@2om2e_P?od:bd0_oF^Kd00ooD[kCof[flomZm_002omZm_0CogL6l0_oT
elT00ooPaKgoi][8onKJb002onCee@;o00004Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0;ooooolRojVmj004ojVmjOnY_NSoZKgXojVmj0?oT[C^
0_nY[m/2oi;0mP?o[KWQ0oni/=400onba>So_[WEokjie@03okjie@04ol>`b?o3`m[o`l?Jol?3fP?o
akS;00Cob<kOolc1coo<`Looc<7?0_o=f^<3om7:d`;ocnKW00Koe]CGom3`j?o@l>Sod?3Xoigeg_l0
000Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool000kooooo0_l0000`
ooooobcoZKgX0_mc/?L4ojj_f@;o_JO300?o^KOGolB/`Oo4[<400oo4[<401Oo8YKGobk2ool^`_oo;
/;ooc:Rd00Cod;Fn00Cod:bdomJi_OoF^Kgoe[Vm1OoJ_K`00ooPdl_ogL6lomg1_003onCGb@04on7e
f?oVf/Soi?GEonCeeAGooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`;o
0000<?oooolWojVmj0?oD;Cj0onB`?H3ojfih@04okV`dOnba>So//CXok;4j0?o_[WE00?o]]7^ol?3
f_o3`mX00oo3`mX01Oo7^<_ob<kOolS>goo8c]ooc<7?00CocM[S00?odL[ColoVioo?i^L00_nZmn/0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
013ooooo00?o0000ooooooooool0;oooool[ojVmj0;o06bm0_n^[mT00on8`?Wo^KOGokVge`02okVg
e`?oa:c100?o`kkEol^`_oo;/;l00_o;/;l5om2e_PCoe[Vm00Coflo=omZm_?oJ_Kcof[fl0_oPdl/0
1OoM`Kcoi=O9onCGbOoTelWohOGH00;oYoK700?oi?GEooooooooool05Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;ooooolYojVmj0?o?;Ga0on@
cO`4ok;4j004okjieOnfdNko]]7^okKAkP;o`l?J0_nhgo<3olS>g`?o^>cf0_o=f^<2ok?dl`03oloV
ionZmn_oZ_O[02;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`004Ooo
ool00ol0003oooooooooo`0_ooooobgoZKgX0on8`?T3okVge`03olB/`Oo3_]Go`kkE00;o`kkE0_o;
/;l2olg4dP?od;Fn0_oDb]02omJi_@?oflo=00Cof[flon3CbooPdl_oh=?;0_oMlmd01?oTelWohOGH
ojOfaonWm/LJooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0_ooooob_oZKgX00Co?;Gaoi3=o?n@cOcoT<gl0_nba>P2oh_Io`;o]]7^0_n1h?X4okSO
l`04olS>gonhk?Ko^>cfokS/mP;oG=GB0_ncm?<Wooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool001;ooooo00?o0000ooooooooool0;oooool^ojVmj003o`20`Oni]mOo^KOG
00;oW<oi1?o3_]D00oo;/;oocLCBolg4dP02olg4dP05om2e__oDb]3oe<[@omC:d?oF^Kd01?oKcld3
on3Cb`;ogO?M00?oU>o7o`000?ooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0;oooooldojVmj0?oPN3j0_nhgo<01?m`g^[oZKgXojVmj?nY
_NP/ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool001?ooooo0_l0000`
oooooc3oZKgX0onLcoT2ol>ne@;o[mcg0oo=a=801?noi_7oe<[@omC:d?oDb]02olc]j`?oflo=0_oF
lN@01?oPdl_ogO?MomgcgOnDklLPooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
7?ooool2o`00033ooooo>OnY_NP`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool001Gooooo00?o0000ooooooooool0;ooooolbojVmj005o`JHaOn_g?Oo[mcgojoLmoo=a=80
0onoi_400ooDb]3oc>g[olc]j`02olc]j`03om_?cOoFlNCoe_7T00;oO^G79?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;ooooolbojVmj3Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`005_ooool00ol0003ooooooooo
o`0^ooooobooZKgX2?ooool2okoVl@?oALK90_o<kN/00omSf<Woooooooooo`0Xooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0^ooooobooZKgX>_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000Gooooo`03o`000?oooooo
oooo02kooooo;?nY_NPlooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0^ooooobcoZKgX??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00_ooooo000Hooooo`;o0000<?oooolWojVmj43ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Qooooo`;o0000<?oooolWojVmj43ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0;ooooo`006_ooool00ol0003oooooooooo`0]ooooob;oZKgXA_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;OoooolRojVmj4Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`006oooool00ol0003ooooo
ooooo`0]oooooaooZKgXBOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0;OoooolOojVmj4Wooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0:ooooo`007?ooool00ol0003oooooooooo`0^oooooaSoZKgXC_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0;_oooolHojVmj4kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`007Oooool00ol0003oooooooooo`0^
oooooaCoZKgXD_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0;_oooolDojVmj5;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`007_ooool2o`0002oooooo4OnY_NQEooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09_ooool2o`0002kooooo4_nY_NQEooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02_ooool0023ooooo00?o0000ooooooooool0;Oooool;ojVmj5[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02cooooo3?nY_NQJooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool0027ooooo00?o0000ooooooooool0
;Oooool8ojVmj5gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02gooooo1onY_NQNooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool002;ooooo00?o0000ooooooooool0;Oooool4ojVmj67ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02gooooo1?nY_NQQooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02Oooool002?ooooo0_l0000]ooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`;o0000;Oooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool0
02Gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`009_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00Go0000ooooooooooooooooo`00000_oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo
000000_ooooo000Wooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0IOooool01?l0
003oooooooooool0000`ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0IOooool0
1?l0003oooooooooool0000;ooooo`00:?ooool2o`0002Sooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooo`00000aooooo`;o0000:?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo
000000_ooooo000Zooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00ol0
003oooooo`00000cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0I_ooool00ol0
003oooooo`00000;ooooo`00:oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooool00000<oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooool000002_ooool002cooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`1Xooooo`;o0000=?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Sooooo
0_l0000:ooooo`00;Oooool2o`0002?ooooo00?o0000ooooooooool0Ioooool3o`0003Gooooo0_l0
000Sooooo`03o`000?oooooooooo06Oooooo0ol0000:ooooo`00;oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06?ooooo1?l0000jooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0Hoooool4o`0000gooooo000`ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0H?ooool3o`0003oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Poooo
o`?o00004Oooool0037ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`Co
0000@oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05cooooo1?l0000Dooooo`00
<_ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4o`0004Sooooo0_l0000Nooooo`03o`00
0?oooooooooo05Sooooo1?l0000Hooooo`00=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Cooooo1?l0001>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0E?oo
ool4o`0001cooooo000eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool3
o`0005?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o00008?ooool0
03Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co0000Eoooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0000Sooooo`00=oooool2o`0001Wo
oooo00?o0000ooooooooool0BOooool4o`0005cooooo0_l0000Iooooo`03o`000?oooooooooo04Wo
oooo1?l0000Wooooo`00>Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo
1?l0001Rooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOooool4o`0002_ooooo
000jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0006Oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`13ooooo`?o0000;oooool003_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0oooooo`Co0000Joooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo03oooooo1?l0000booooo`00??ooool2o`0001?ooooo00?o0000oooo
ooooool0>oooool4o`00073ooooo0_l0000Cooooo`03o`000?oooooooooo03_ooooo1?l0000foooo
o`00?_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0001fooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0=oooool4o`0003[ooooo000oooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<oooool4o`0007_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool0043ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0`ooooo`?o0000P?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo033ooooo0ol00012ooooo`00@Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo02cooooo1?l00024ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool4
o`0004Gooooo0012ooooo`;o00003Oooool00ol0003oooooooooo`0Xooooo`Co0000ROooool2o`00
00gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo0014ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09?ooool4o`0008oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Tooooo`Co0000COooool004Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Qooooo`?o0000U?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo
0ol0001Aooooo`00A_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0
002Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`0005Cooooo0017
ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000WOooool2o`0000Sooooo00?o0000
ooooooooool06Oooool4o`0005Sooooo0019ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05Oooool4o`000:?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Eoooo
o`Co0000G?ooool004[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o
0000Z?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo0ol0001Pooooo`00
Boooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002/ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`0006?ooooo001<ooooo`;o00000ooo
ool00ol0003oooooooooo`0:ooooo`Co0000/Oooool2o`0000?ooooo00?o0000ooooooooool02_oo
ool4o`0006Oooooo001>ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002gooooo`04o`000?oo
ooooooooo`0000Sooooo1?l0001[ooooo`00Coooool00ol0003oooooo`000005ooooo`?o0000_?oo
ool00ol0003oooooo`000005ooooo`?o0000Koooool0053ooooo0_l000000ooooooo0000o`000002
o`000<3ooooo0_l000000ooooooo0000o`000002o`0007;ooooo001Aooooo`;o0000aOooool2o`00
07Kooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {323.438, 0}} -> {-0.0506837, -0.0405654, \
0.00526659, 0.00526659}, {{9.625, 190.438}, {315.688, 169}} -> {-53.3508, \
-19.1129, 1.80794, 1.80794}, {{208.5, 389.375}, {315.688, 169}} -> {-412.962, \
-19.1129, 1.80794, 1.80794}, {{9.625, 190.438}, {154.375, 7.6875}} -> \
{-0.0507135, -0.826023, 0.00526844, 0.00526844}, {{208.5, 389.375}, {154.375, \
7.6875}} -> {-1.09839, -0.825821, 0.0052676, 0.0052676}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Classification in 2d", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowTwoClassificationRegions[pdf1, pdf2, pr, x, y, classColors, 
        gbase, Axes \[Rule] False, Frame \[Rule] True, \ 
        FrameTicks \[Rule] False, yS];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.57475 .21322 m
.592 .23162 L
.61081 .25242 L
.62848 .27256 L
.64547 .29242 L
.66356 .31403 L
.68097 .33525 L
.69947 .35819 L
.7173 .38065 L
.73445 .40255 L
.7527 .42614 L
.77026 .44911 L
.78716 .47143 L
.80514 .49541 L
.82245 .5187 L
.84086 .54366 L
.85859 .56789 L
.87564 .59135 L
.89379 .61648 L
.91126 .64082 L
.92982 .66683 L
.94771 .69204 L
.96492 .71641 L
.98323 .74245 L
.99996 .76636 L
s
.57475 .99996 m
.592 .99996 L
.61081 .99996 L
.62848 .99996 L
.64547 .99996 L
.66356 .99996 L
.68097 .99996 L
.69947 .99996 L
.7173 .99996 L
.73445 .99996 L
.7527 .99996 L
.77026 .99996 L
.78716 .99996 L
.80514 .99996 L
.82245 .99996 L
.84086 .99996 L
.85859 .99996 L
.87564 .99996 L
.89379 .99996 L
.91126 .99996 L
.92982 .99996 L
.94771 .99996 L
.96492 .99996 L
.98323 .99996 L
.99996 .99996 L
s
.5 1 1 r
.57475 .21322 m
.592 .23162 L
.61081 .25242 L
.62848 .27256 L
.64547 .29242 L
.66356 .31403 L
.68097 .33525 L
.69947 .35819 L
.7173 .38065 L
.73445 .40255 L
.7527 .42614 L
.77026 .44911 L
.78716 .47143 L
.80514 .49541 L
.82245 .5187 L
.84086 .54366 L
.85859 .56789 L
.87564 .59135 L
.89379 .61648 L
.91126 .64082 L
.92982 .66683 L
.94771 .69204 L
.96492 .71641 L
.98323 .74245 L
.99996 .76636 L
.99996 .99996 L
.98323 .99996 L
.96492 .99996 L
.94771 .99996 L
.92982 .99996 L
.91126 .99996 L
.89379 .99996 L
.87564 .99996 L
.85859 .99996 L
.84086 .99996 L
.82245 .99996 L
.80514 .99996 L
.78716 .99996 L
.77026 .99996 L
.7527 .99996 L
.73445 .99996 L
.7173 .99996 L
.69947 .99996 L
.68097 .99996 L
.66356 .99996 L
.64547 .99996 L
.62848 .99996 L
.61081 .99996 L
.592 .99996 L
.57475 .99996 L
F
0 g
.57475 .21322 m
.592 .23162 L
.61081 .25242 L
.62848 .27256 L
.64547 .29242 L
.66356 .31403 L
.68097 .33525 L
.69947 .35819 L
.7173 .38065 L
.73445 .40255 L
.7527 .42614 L
.77026 .44911 L
.78716 .47143 L
.80514 .49541 L
.82245 .5187 L
.84086 .54366 L
.85859 .56789 L
.87564 .59135 L
.89379 .61648 L
.91126 .64082 L
.92982 .66683 L
.94771 .69204 L
.96492 .71641 L
.98323 .74245 L
.99996 .76636 L
s
.57475 .99996 m
.592 .99996 L
.61081 .99996 L
.62848 .99996 L
.64547 .99996 L
.66356 .99996 L
.68097 .99996 L
.69947 .99996 L
.7173 .99996 L
.73445 .99996 L
.7527 .99996 L
.77026 .99996 L
.78716 .99996 L
.80514 .99996 L
.82245 .99996 L
.84086 .99996 L
.85859 .99996 L
.87564 .99996 L
.89379 .99996 L
.91126 .99996 L
.92982 .99996 L
.94771 .99996 L
.96492 .99996 L
.98323 .99996 L
.99996 .99996 L
s
.3893 .20289 m
.38953 .19011 L
.38973 .18546 L
.38997 .18146 L
.3902 .17838 L
.39104 .16985 L
.39196 .16316 L
.39296 .15747 L
.39497 .14875 L
.39682 .14265 L
.4008 .1331 L
.40281 .12947 L
.40503 .12614 L
.4088 .12165 L
.41287 .11811 L
.41484 .11677 L
.41699 .11554 L
.41904 .11457 L
.4209 .11385 L
.42274 .11327 L
.42473 .11277 L
.42582 .11255 L
.42683 .11239 L
.42779 .11225 L
.42881 .11214 L
.42932 .1121 L
.4298 .11206 L
.43027 .11204 L
.43071 .11201 L
.43112 .112 L
.43156 .11199 L
.43178 .11198 L
.43199 .11198 L
.43223 .11198 L
.43248 .11198 L
.43273 .11198 L
.43297 .11198 L
.4331 .11198 L
.43322 .11198 L
.4335 .11199 L
.43377 .112 L
.43405 .112 L
.43458 .11203 L
.43558 .11209 L
.4365 .11216 L
.43839 .11237 L
.44016 .11263 L
.44417 .11342 L
.44813 .11447 L
.45174 .11564 L
Mistroke
.45948 .11871 L
.46692 .12232 L
.47485 .12675 L
.48248 .13152 L
.49059 .13706 L
.4984 .14281 L
.50592 .14866 L
.51391 .15521 L
.52161 .16181 L
.52901 .16839 L
.5369 .17563 L
.54448 .18281 L
.55255 .19065 L
.56032 .19839 L
.56779 .206 L
.57475 .21322 L
Mfstroke
.3893 .20305 m
.38953 .21683 L
.38973 .22239 L
.3902 .23151 L
.39104 .2437 L
.39296 .26441 L
.39682 .29604 L
.40503 .34827 L
.4128 .39009 L
.42028 .42673 L
.42824 .46324 L
.4359 .49669 L
.44327 .52765 L
.45111 .55959 L
.45866 .58953 L
.46669 .62062 L
.47442 .64998 L
.48186 .67773 L
.48978 .70681 L
.4974 .73442 L
.50549 .76339 L
.51329 .79097 L
.5208 .81725 L
.52879 .84492 L
.53648 .87134 L
.54387 .89654 L
.55174 .92317 L
.55932 .94862 L
.56737 .97549 L
.57475 .99996 L
s
.5 1 1 r
.3893 .20289 m
.38953 .19011 L
.38973 .18546 L
.38997 .18146 L
.3902 .17838 L
.39104 .16985 L
.39196 .16316 L
.39296 .15747 L
.39497 .14875 L
.39682 .14265 L
.4008 .1331 L
.40281 .12947 L
.40503 .12614 L
.4088 .12165 L
.41287 .11811 L
.41484 .11677 L
.41699 .11554 L
.41904 .11457 L
.4209 .11385 L
.42274 .11327 L
.42473 .11277 L
.42582 .11255 L
.42683 .11239 L
.42779 .11225 L
.42881 .11214 L
.42932 .1121 L
.4298 .11206 L
.43027 .11204 L
.43071 .11201 L
.43112 .112 L
.43156 .11199 L
.43178 .11198 L
.43199 .11198 L
.43223 .11198 L
.43248 .11198 L
.43273 .11198 L
.43297 .11198 L
.4331 .11198 L
.43322 .11198 L
.4335 .11199 L
.43377 .112 L
.43405 .112 L
.43458 .11203 L
.43558 .11209 L
.4365 .11216 L
.43839 .11237 L
.44016 .11263 L
.44417 .11342 L
.44813 .11447 L
.45174 .11564 L
.45948 .11871 L
.46692 .12232 L
.47485 .12675 L
.48248 .13152 L
.49059 .13706 L
.4984 .14281 L
.50592 .14866 L
.51391 .15521 L
.52161 .16181 L
.52901 .16839 L
.5369 .17563 L
.54448 .18281 L
.55255 .19065 L
.56032 .19839 L
.56779 .206 L
.57475 .21322 L
.57475 .99996 L
.56737 .97549 L
.55932 .94862 L
.55174 .92317 L
.54387 .89654 L
.53648 .87134 L
.52879 .84492 L
.5208 .81725 L
.51329 .79097 L
.50549 .76339 L
.4974 .73442 L
.48978 .70681 L
.48186 .67773 L
.47442 .64998 L
.46669 .62062 L
.45866 .58953 L
.45111 .55959 L
.44327 .52765 L
.4359 .49669 L
.42824 .46324 L
.42028 .42673 L
.4128 .39009 L
.40503 .34827 L
.39682 .29604 L
.39296 .26441 L
.39104 .2437 L
.3902 .23151 L
.38973 .22239 L
.38953 .21683 L
.3893 .20305 L
F
0 g
.3893 .20289 m
.38953 .19011 L
.38973 .18546 L
.38997 .18146 L
.3902 .17838 L
.39104 .16985 L
.39196 .16316 L
.39296 .15747 L
.39497 .14875 L
.39682 .14265 L
.4008 .1331 L
.40281 .12947 L
.40503 .12614 L
.4088 .12165 L
.41287 .11811 L
.41484 .11677 L
.41699 .11554 L
.41904 .11457 L
.4209 .11385 L
.42274 .11327 L
.42473 .11277 L
.42582 .11255 L
.42683 .11239 L
.42779 .11225 L
.42881 .11214 L
.42932 .1121 L
.4298 .11206 L
.43027 .11204 L
.43071 .11201 L
.43112 .112 L
.43156 .11199 L
.43178 .11198 L
.43199 .11198 L
.43223 .11198 L
.43248 .11198 L
.43273 .11198 L
.43297 .11198 L
.4331 .11198 L
.43322 .11198 L
.4335 .11199 L
.43377 .112 L
.43405 .112 L
.43458 .11203 L
.43558 .11209 L
.4365 .11216 L
.43839 .11237 L
.44016 .11263 L
.44417 .11342 L
.44813 .11447 L
.45174 .11564 L
Mistroke
.45948 .11871 L
.46692 .12232 L
.47485 .12675 L
.48248 .13152 L
.49059 .13706 L
.4984 .14281 L
.50592 .14866 L
.51391 .15521 L
.52161 .16181 L
.52901 .16839 L
.5369 .17563 L
.54448 .18281 L
.55255 .19065 L
.56032 .19839 L
.56779 .206 L
.57475 .21322 L
Mfstroke
.3893 .20305 m
.38953 .21683 L
.38973 .22239 L
.3902 .23151 L
.39104 .2437 L
.39296 .26441 L
.39682 .29604 L
.40503 .34827 L
.4128 .39009 L
.42028 .42673 L
.42824 .46324 L
.4359 .49669 L
.44327 .52765 L
.45111 .55959 L
.45866 .58953 L
.46669 .62062 L
.47442 .64998 L
.48186 .67773 L
.48978 .70681 L
.4974 .73442 L
.50549 .76339 L
.51329 .79097 L
.5208 .81725 L
.52879 .84492 L
.53648 .87134 L
.54387 .89654 L
.55174 .92317 L
.55932 .94862 L
.56737 .97549 L
.57475 .99996 L
s
4e-05 4e-05 m
.01583 4e-05 L
.03305 4e-05 L
.04923 4e-05 L
.06478 4e-05 L
.08134 4e-05 L
.09727 4e-05 L
.11421 4e-05 L
.13053 4e-05 L
.14623 4e-05 L
.16294 4e-05 L
.17902 4e-05 L
.19448 4e-05 L
.21095 4e-05 L
.2268 4e-05 L
.24365 4e-05 L
.25988 4e-05 L
.27549 4e-05 L
.2921 4e-05 L
.30809 4e-05 L
.32509 4e-05 L
.34146 4e-05 L
.35722 4e-05 L
.37398 4e-05 L
.3893 4e-05 L
s
4e-05 .99996 m
.01583 .99996 L
.03305 .99996 L
.04923 .99996 L
.06478 .99996 L
.08134 .99996 L
.09727 .99996 L
.11421 .99996 L
.13053 .99996 L
.14623 .99996 L
.16294 .99996 L
.17902 .99996 L
.19448 .99996 L
.21095 .99996 L
.2268 .99996 L
.24365 .99996 L
.25988 .99996 L
.27549 .99996 L
.2921 .99996 L
.30809 .99996 L
.32509 .99996 L
.34146 .99996 L
.35722 .99996 L
.37398 .99996 L
.3893 .99996 L
s
1 1 .5 r
4e-05 4e-05 m
.01583 4e-05 L
.03305 4e-05 L
.04923 4e-05 L
.06478 4e-05 L
.08134 4e-05 L
.09727 4e-05 L
.11421 4e-05 L
.13053 4e-05 L
.14623 4e-05 L
.16294 4e-05 L
.17902 4e-05 L
.19448 4e-05 L
.21095 4e-05 L
.2268 4e-05 L
.24365 4e-05 L
.25988 4e-05 L
.27549 4e-05 L
.2921 4e-05 L
.30809 4e-05 L
.32509 4e-05 L
.34146 4e-05 L
.35722 4e-05 L
.37398 4e-05 L
.3893 4e-05 L
.3893 .99996 L
.37398 .99996 L
.35722 .99996 L
.34146 .99996 L
.32509 .99996 L
.30809 .99996 L
.2921 .99996 L
.27549 .99996 L
.25988 .99996 L
.24365 .99996 L
.2268 .99996 L
.21095 .99996 L
.19448 .99996 L
.17902 .99996 L
.16294 .99996 L
.14623 .99996 L
.13053 .99996 L
.11421 .99996 L
.09727 .99996 L
.08134 .99996 L
.06478 .99996 L
.04923 .99996 L
.03305 .99996 L
.01583 .99996 L
4e-05 .99996 L
F
0 g
4e-05 4e-05 m
.01583 4e-05 L
.03305 4e-05 L
.04923 4e-05 L
.06478 4e-05 L
.08134 4e-05 L
.09727 4e-05 L
.11421 4e-05 L
.13053 4e-05 L
.14623 4e-05 L
.16294 4e-05 L
.17902 4e-05 L
.19448 4e-05 L
.21095 4e-05 L
.2268 4e-05 L
.24365 4e-05 L
.25988 4e-05 L
.27549 4e-05 L
.2921 4e-05 L
.30809 4e-05 L
.32509 4e-05 L
.34146 4e-05 L
.35722 4e-05 L
.37398 4e-05 L
.3893 4e-05 L
s
4e-05 .99996 m
.01583 .99996 L
.03305 .99996 L
.04923 .99996 L
.06478 .99996 L
.08134 .99996 L
.09727 .99996 L
.11421 .99996 L
.13053 .99996 L
.14623 .99996 L
.16294 .99996 L
.17902 .99996 L
.19448 .99996 L
.21095 .99996 L
.2268 .99996 L
.24365 .99996 L
.25988 .99996 L
.27549 .99996 L
.2921 .99996 L
.30809 .99996 L
.32509 .99996 L
.34146 .99996 L
.35722 .99996 L
.37398 .99996 L
.3893 .99996 L
s
.57475 4e-05 m
.592 4e-05 L
.61081 4e-05 L
.62848 4e-05 L
.64547 4e-05 L
.66356 4e-05 L
.68097 4e-05 L
.69947 4e-05 L
.7173 4e-05 L
.73445 4e-05 L
.7527 4e-05 L
.77026 4e-05 L
.78716 4e-05 L
.80514 4e-05 L
.82245 4e-05 L
.84086 4e-05 L
.85859 4e-05 L
.87564 4e-05 L
.89379 4e-05 L
.91126 4e-05 L
.92982 4e-05 L
.94771 4e-05 L
.96492 4e-05 L
.98323 4e-05 L
.99996 4e-05 L
s
.57475 .21322 m
.592 .23162 L
.61081 .25242 L
.62848 .27256 L
.64547 .29242 L
.66356 .31403 L
.68097 .33525 L
.69947 .35819 L
.7173 .38065 L
.73445 .40255 L
.7527 .42614 L
.77026 .44911 L
.78716 .47143 L
.80514 .49541 L
.82245 .5187 L
.84086 .54366 L
.85859 .56789 L
.87564 .59135 L
.89379 .61648 L
.91126 .64082 L
.92982 .66683 L
.94771 .69204 L
.96492 .71641 L
.98323 .74245 L
.99996 .76636 L
s
1 1 .5 r
.57475 4e-05 m
.592 4e-05 L
.61081 4e-05 L
.62848 4e-05 L
.64547 4e-05 L
.66356 4e-05 L
.68097 4e-05 L
.69947 4e-05 L
.7173 4e-05 L
.73445 4e-05 L
.7527 4e-05 L
.77026 4e-05 L
.78716 4e-05 L
.80514 4e-05 L
.82245 4e-05 L
.84086 4e-05 L
.85859 4e-05 L
.87564 4e-05 L
.89379 4e-05 L
.91126 4e-05 L
.92982 4e-05 L
.94771 4e-05 L
.96492 4e-05 L
.98323 4e-05 L
.99996 4e-05 L
.99996 .76636 L
.98323 .74245 L
.96492 .71641 L
.94771 .69204 L
.92982 .66683 L
.91126 .64082 L
.89379 .61648 L
.87564 .59135 L
.85859 .56789 L
.84086 .54366 L
.82245 .5187 L
.80514 .49541 L
.78716 .47143 L
.77026 .44911 L
.7527 .42614 L
.73445 .40255 L
.7173 .38065 L
.69947 .35819 L
.68097 .33525 L
.66356 .31403 L
.64547 .29242 L
.62848 .27256 L
.61081 .25242 L
.592 .23162 L
.57475 .21322 L
F
0 g
.57475 4e-05 m
.592 4e-05 L
.61081 4e-05 L
.62848 4e-05 L
.64547 4e-05 L
.66356 4e-05 L
.68097 4e-05 L
.69947 4e-05 L
.7173 4e-05 L
.73445 4e-05 L
.7527 4e-05 L
.77026 4e-05 L
.78716 4e-05 L
.80514 4e-05 L
.82245 4e-05 L
.84086 4e-05 L
.85859 4e-05 L
.87564 4e-05 L
.89379 4e-05 L
.91126 4e-05 L
.92982 4e-05 L
.94771 4e-05 L
.96492 4e-05 L
.98323 4e-05 L
.99996 4e-05 L
s
.57475 .21322 m
.592 .23162 L
.61081 .25242 L
.62848 .27256 L
.64547 .29242 L
.66356 .31403 L
.68097 .33525 L
.69947 .35819 L
.7173 .38065 L
.73445 .40255 L
.7527 .42614 L
.77026 .44911 L
.78716 .47143 L
.80514 .49541 L
.82245 .5187 L
.84086 .54366 L
.85859 .56789 L
.87564 .59135 L
.89379 .61648 L
.91126 .64082 L
.92982 .66683 L
.94771 .69204 L
.96492 .71641 L
.98323 .74245 L
.99996 .76636 L
s
.3893 4e-05 m
.39682 4e-05 L
.40503 4e-05 L
.41273 4e-05 L
.42014 4e-05 L
.42803 4e-05 L
.43562 4e-05 L
.44369 4e-05 L
.45147 4e-05 L
.45895 4e-05 L
.46691 4e-05 L
.47457 4e-05 L
.48194 4e-05 L
.48978 4e-05 L
.49733 4e-05 L
.50536 4e-05 L
.51309 4e-05 L
.52053 4e-05 L
.52844 4e-05 L
.53606 4e-05 L
.54416 4e-05 L
.55196 4e-05 L
.55947 4e-05 L
.56745 4e-05 L
.57475 4e-05 L
s
.3893 .20289 m
.38953 .19011 L
.38973 .18546 L
.38997 .18146 L
.3902 .17838 L
.39104 .16985 L
.39196 .16316 L
.39296 .15747 L
.39497 .14875 L
.39682 .14265 L
.4008 .1331 L
.40281 .12947 L
.40503 .12614 L
.4088 .12165 L
.41287 .11811 L
.41484 .11677 L
.41699 .11554 L
.41904 .11457 L
.4209 .11385 L
.42274 .11327 L
.42473 .11277 L
.42582 .11255 L
.42683 .11239 L
.42779 .11225 L
.42881 .11214 L
.42932 .1121 L
.4298 .11206 L
.43027 .11204 L
.43071 .11201 L
.43112 .112 L
.43156 .11199 L
.43178 .11198 L
.43199 .11198 L
.43223 .11198 L
.43248 .11198 L
.43273 .11198 L
.43297 .11198 L
.4331 .11198 L
.43322 .11198 L
.4335 .11199 L
.43377 .112 L
.43405 .112 L
.43458 .11203 L
.43558 .11209 L
.4365 .11216 L
.43839 .11237 L
.44016 .11263 L
.44417 .11342 L
.44813 .11447 L
.45174 .11564 L
Mistroke
.45948 .11871 L
.46692 .12232 L
.47485 .12675 L
.48248 .13152 L
.49059 .13706 L
.4984 .14281 L
.50592 .14866 L
.51391 .15521 L
.52161 .16181 L
.52901 .16839 L
.5369 .17563 L
.54448 .18281 L
.55255 .19065 L
.56032 .19839 L
.56779 .206 L
.57475 .21322 L
Mfstroke
1 1 .5 r
.3893 4e-05 m
.39682 4e-05 L
.40503 4e-05 L
.41273 4e-05 L
.42014 4e-05 L
.42803 4e-05 L
.43562 4e-05 L
.44369 4e-05 L
.45147 4e-05 L
.45895 4e-05 L
.46691 4e-05 L
.47457 4e-05 L
.48194 4e-05 L
.48978 4e-05 L
.49733 4e-05 L
.50536 4e-05 L
.51309 4e-05 L
.52053 4e-05 L
.52844 4e-05 L
.53606 4e-05 L
.54416 4e-05 L
.55196 4e-05 L
.55947 4e-05 L
.56745 4e-05 L
.57475 4e-05 L
.57475 .21322 L
.56779 .206 L
.56032 .19839 L
.55255 .19065 L
.54448 .18281 L
.5369 .17563 L
.52901 .16839 L
.52161 .16181 L
.51391 .15521 L
.50592 .14866 L
.4984 .14281 L
.49059 .13706 L
.48248 .13152 L
.47485 .12675 L
.46692 .12232 L
.45948 .11871 L
.45174 .11564 L
.44813 .11447 L
.44417 .11342 L
.44016 .11263 L
.43839 .11237 L
.4365 .11216 L
.43558 .11209 L
.43458 .11203 L
.43405 .112 L
.43377 .112 L
.4335 .11199 L
.43322 .11198 L
.4331 .11198 L
.43297 .11198 L
.43273 .11198 L
.43248 .11198 L
.43223 .11198 L
.43199 .11198 L
.43178 .11198 L
.43156 .11199 L
.43112 .112 L
.43071 .11201 L
.43027 .11204 L
.4298 .11206 L
.42932 .1121 L
.42881 .11214 L
.42779 .11225 L
.42683 .11239 L
.42582 .11255 L
.42473 .11277 L
.42274 .11327 L
.4209 .11385 L
.41904 .11457 L
.41699 .11554 L
.41484 .11677 L
.41287 .11811 L
.4088 .12165 L
.40503 .12614 L
.40281 .12947 L
.4008 .1331 L
.39682 .14265 L
.39497 .14875 L
.39296 .15747 L
.39196 .16316 L
.39104 .16985 L
.3902 .17838 L
.38997 .18146 L
.38973 .18546 L
.38953 .19011 L
.3893 .20289 L
F
0 g
.3893 4e-05 m
.39682 4e-05 L
.40503 4e-05 L
.41273 4e-05 L
.42014 4e-05 L
.42803 4e-05 L
.43562 4e-05 L
.44369 4e-05 L
.45147 4e-05 L
.45895 4e-05 L
.46691 4e-05 L
.47457 4e-05 L
.48194 4e-05 L
.48978 4e-05 L
.49733 4e-05 L
.50536 4e-05 L
.51309 4e-05 L
.52053 4e-05 L
.52844 4e-05 L
.53606 4e-05 L
.54416 4e-05 L
.55196 4e-05 L
.55947 4e-05 L
.56745 4e-05 L
.57475 4e-05 L
s
.3893 .20289 m
.38953 .19011 L
.38973 .18546 L
.38997 .18146 L
.3902 .17838 L
.39104 .16985 L
.39196 .16316 L
.39296 .15747 L
.39497 .14875 L
.39682 .14265 L
.4008 .1331 L
.40281 .12947 L
.40503 .12614 L
.4088 .12165 L
.41287 .11811 L
.41484 .11677 L
.41699 .11554 L
.41904 .11457 L
.4209 .11385 L
.42274 .11327 L
.42473 .11277 L
.42582 .11255 L
.42683 .11239 L
.42779 .11225 L
.42881 .11214 L
.42932 .1121 L
.4298 .11206 L
.43027 .11204 L
.43071 .11201 L
.43112 .112 L
.43156 .11199 L
.43178 .11198 L
.43199 .11198 L
.43223 .11198 L
.43248 .11198 L
.43273 .11198 L
.43297 .11198 L
.4331 .11198 L
.43322 .11198 L
.4335 .11199 L
.43377 .112 L
.43405 .112 L
.43458 .11203 L
.43558 .11209 L
.4365 .11216 L
.43839 .11237 L
.44016 .11263 L
.44417 .11342 L
.44813 .11447 L
.45174 .11564 L
Mistroke
.45948 .11871 L
.46692 .12232 L
.47485 .12675 L
.48248 .13152 L
.49059 .13706 L
.4984 .14281 L
.50592 .14866 L
.51391 .15521 L
.52161 .16181 L
.52901 .16839 L
.5369 .17563 L
.54448 .18281 L
.55255 .19065 L
.56032 .19839 L
.56779 .206 L
.57475 .21322 L
Mfstroke
.3893 .20305 m
.38953 .21683 L
.38973 .22239 L
.3902 .23151 L
.39104 .2437 L
.39296 .26441 L
.39682 .29604 L
.40503 .34827 L
.4128 .39009 L
.42028 .42673 L
.42824 .46324 L
.4359 .49669 L
.44327 .52765 L
.45111 .55959 L
.45866 .58953 L
.46669 .62062 L
.47442 .64998 L
.48186 .67773 L
.48978 .70681 L
.4974 .73442 L
.50549 .76339 L
.51329 .79097 L
.5208 .81725 L
.52879 .84492 L
.53648 .87134 L
.54387 .89654 L
.55174 .92317 L
.55932 .94862 L
.56737 .97549 L
.57475 .99996 L
s
.3893 .99996 m
.39682 .99996 L
.40503 .99996 L
.41273 .99996 L
.42014 .99996 L
.42803 .99996 L
.43562 .99996 L
.44369 .99996 L
.45147 .99996 L
.45895 .99996 L
.46691 .99996 L
.47457 .99996 L
.48194 .99996 L
.48978 .99996 L
.49733 .99996 L
.50536 .99996 L
.51309 .99996 L
.52053 .99996 L
.52844 .99996 L
.53606 .99996 L
.54416 .99996 L
.55196 .99996 L
.55947 .99996 L
.56745 .99996 L
.57475 .99996 L
s
1 1 .5 r
.3893 .20305 m
.38953 .21683 L
.38973 .22239 L
.3902 .23151 L
.39104 .2437 L
.39296 .26441 L
.39682 .29604 L
.40503 .34827 L
.4128 .39009 L
.42028 .42673 L
.42824 .46324 L
.4359 .49669 L
.44327 .52765 L
.45111 .55959 L
.45866 .58953 L
.46669 .62062 L
.47442 .64998 L
.48186 .67773 L
.48978 .70681 L
.4974 .73442 L
.50549 .76339 L
.51329 .79097 L
.5208 .81725 L
.52879 .84492 L
.53648 .87134 L
.54387 .89654 L
.55174 .92317 L
.55932 .94862 L
.56737 .97549 L
.57475 .99996 L
.57475 .99996 L
.56745 .99996 L
.55947 .99996 L
.55196 .99996 L
.54416 .99996 L
.53606 .99996 L
.52844 .99996 L
.52053 .99996 L
.51309 .99996 L
.50536 .99996 L
.49733 .99996 L
.48978 .99996 L
.48194 .99996 L
.47457 .99996 L
.46691 .99996 L
.45895 .99996 L
.45147 .99996 L
.44369 .99996 L
.43562 .99996 L
.42803 .99996 L
.42014 .99996 L
.41273 .99996 L
.40503 .99996 L
.39682 .99996 L
.3893 .99996 L
F
0 g
.3893 .20305 m
.38953 .21683 L
.38973 .22239 L
.3902 .23151 L
.39104 .2437 L
.39296 .26441 L
.39682 .29604 L
.40503 .34827 L
.4128 .39009 L
.42028 .42673 L
.42824 .46324 L
.4359 .49669 L
.44327 .52765 L
.45111 .55959 L
.45866 .58953 L
.46669 .62062 L
.47442 .64998 L
.48186 .67773 L
.48978 .70681 L
.4974 .73442 L
.50549 .76339 L
.51329 .79097 L
.5208 .81725 L
.52879 .84492 L
.53648 .87134 L
.54387 .89654 L
.55174 .92317 L
.55932 .94862 L
.56737 .97549 L
.57475 .99996 L
s
.3893 .99996 m
.39682 .99996 L
.40503 .99996 L
.41273 .99996 L
.42014 .99996 L
.42803 .99996 L
.43562 .99996 L
.44369 .99996 L
.45147 .99996 L
.45895 .99996 L
.46691 .99996 L
.47457 .99996 L
.48194 .99996 L
.48978 .99996 L
.49733 .99996 L
.50536 .99996 L
.51309 .99996 L
.52053 .99996 L
.52844 .99996 L
.53606 .99996 L
.54416 .99996 L
.55196 .99996 L
.55947 .99996 L
.56745 .99996 L
.57475 .99996 L
s
1 .5 0 r
.01 w
.96075 .96075 Mdot
.71371 .72155 Mdot
.52941 .52549 Mdot
.13728 .14905 Mdot
.8784 .88232 Mdot
.11376 .10983 Mdot
.10983 .11376 Mdot
.77645 .78037 Mdot
.15297 .14905 Mdot
.13728 .12552 Mdot
.13336 .14513 Mdot
.14513 .13336 Mdot
.20787 .18826 Mdot
.17257 .15689 Mdot
.4902 .49804 Mdot
.14513 .13336 Mdot
.26276 .23139 Mdot
.23531 .21571 Mdot
.47451 .48235 Mdot
.89801 .82743 Mdot
.99996 .96859 Mdot
.13336 .12944 Mdot
.20787 .18826 Mdot
.24708 .20787 Mdot
.11376 .11768 Mdot
.34511 .16865 Mdot
.49804 .32943 Mdot
.65097 .53725 Mdot
.84311 .749 Mdot
.94898 .89409 Mdot
.14513 .1412 Mdot
.18434 .16865 Mdot
.20394 .1765 Mdot
.20787 .20787 Mdot
.55294 .39217 Mdot
.41177 .1412 Mdot
.42354 .22747 Mdot
.3608 .20002 Mdot
.38824 .25884 Mdot
.21571 .1961 Mdot
.21571 .20394 Mdot
.18826 .16865 Mdot
.22355 .20787 Mdot
.251 .251 Mdot
.52941 .1765 Mdot
.47843 .16865 Mdot
.41961 .1961 Mdot
.44706 .25884 Mdot
.33727 .1765 Mdot
.14513 .12944 Mdot
.14905 .11768 Mdot
.1765 .14513 Mdot
.24708 .23531 Mdot
.99996 .93722 Mdot
.58823 .18826 Mdot
.51372 .18042 Mdot
.45883 .22355 Mdot
.43138 .21571 Mdot
.4353 .26668 Mdot
.15689 .13728 Mdot
.21963 .19218 Mdot
.18042 .14905 Mdot
.26668 .26668 Mdot
.99996 .96467 Mdot
.77645 .3608 Mdot
.61176 .25884 Mdot
.45098 .20002 Mdot
.45491 .25884 Mdot
.42746 .18826 Mdot
.18042 .14905 Mdot
.251 .20787 Mdot
.14905 .11768 Mdot
.21963 .20002 Mdot
.50196 .50196 Mdot
.73724 .32158 Mdot
.58039 .21179 Mdot
.45491 .18434 Mdot
.51765 .32158 Mdot
.46275 .18434 Mdot
.21179 .11768 Mdot
.18826 .15297 Mdot
.1961 .16473 Mdot
.18434 .16473 Mdot
.16473 .16081 Mdot
.8235 .72547 Mdot
.65881 .251 Mdot
.53725 .16865 Mdot
.54117 .28629 Mdot
.54117 .34119 Mdot
.50588 .18826 Mdot
.23139 .07062 Mdot
.16473 .13728 Mdot
.23924 .21179 Mdot
.25884 .24708 Mdot
.1412 .13728 Mdot
.52941 .44314 Mdot
.37256 .12552 Mdot
.57646 .18826 Mdot
.54509 .17257 Mdot
.77253 .54509 Mdot
.64705 .43922 Mdot
.52549 .17257 Mdot
.28237 .09807 Mdot
.16865 .1412 Mdot
.27845 .251 Mdot
.18434 .18042 Mdot
.15297 .10591 Mdot
.29021 .17257 Mdot
.96075 .92546 Mdot
.6392 .23924 Mdot
.54902 .16473 Mdot
.55686 .20002 Mdot
.58039 .3804 Mdot
.49804 .25492 Mdot
.67057 .27061 Mdot
.23531 .11768 Mdot
.17257 .1412 Mdot
.22355 .21179 Mdot
.16865 .14905 Mdot
.29806 .1216 Mdot
.33727 .22355 Mdot
.89017 .8235 Mdot
.62352 .22355 Mdot
.5647 .16473 Mdot
.58823 .15689 Mdot
.55294 .33727 Mdot
.71371 .49412 Mdot
.53725 .20002 Mdot
.5098 .25492 Mdot
.20002 .13728 Mdot
.18434 .14513 Mdot
.18042 .14905 Mdot
.20394 .01965 Mdot
.67057 .51372 Mdot
.35295 .24708 Mdot
.88624 .83527 Mdot
.63136 .21963 Mdot
.59215 .16081 Mdot
.64705 .18042 Mdot
.78429 .55294 Mdot
.83135 .61568 Mdot
.67057 .41177 Mdot
.47451 .24708 Mdot
.27061 .15689 Mdot
.20002 .13728 Mdot
.19218 .10983 Mdot
.33727 .10199 Mdot
.63528 .47843 Mdot
.61568 .50196 Mdot
.34903 .23531 Mdot
.99996 .97251 Mdot
.63136 .19218 Mdot
.64313 .1765 Mdot
.67057 .20002 Mdot
.8039 .57254 Mdot
.41961 .21179 Mdot
.68626 .47059 Mdot
.79998 .62744 Mdot
.251 .12552 Mdot
.21963 .11768 Mdot
.26276 .08239 Mdot
.42746 .18042 Mdot
.66273 .52549 Mdot
.61568 .5098 Mdot
.41569 .29413 Mdot
.76076 .70979 Mdot
.53333 .1961 Mdot
.72547 .25884 Mdot
.66273 .19218 Mdot
.64313 .19218 Mdot
.83527 .6392 Mdot
.67057 .43922 Mdot
.58431 .40393 Mdot
.52157 .39609 Mdot
.37648 .18434 Mdot
.28237 .09415 Mdot
.49412 .18042 Mdot
.46667 .27453 Mdot
.5647 .47451 Mdot
.59999 .49412 Mdot
.50588 .40393 Mdot
.63136 .56078 Mdot
.44706 .16865 Mdot
.6745 .23139 Mdot
.90193 .44706 Mdot
.76469 .27453 Mdot
.90585 .65097 Mdot
.48235 .26668 Mdot
.9333 .76076 Mdot
.61568 .50588 Mdot
.59215 .40785 Mdot
.38432 .20394 Mdot
.61176 .25492 Mdot
.6392 .44314 Mdot
.72547 .60391 Mdot
.58823 .48628 Mdot
.64705 .54117 Mdot
.39609 .29413 Mdot
.78821 .749 Mdot
.60783 .21571 Mdot
.73724 .3804 Mdot
.83919 .38824 Mdot
.83919 .34903 Mdot
.94506 .6941 Mdot
.57646 .35295 Mdot
.76469 .61568 Mdot
.66273 .54902 Mdot
.39609 .25492 Mdot
.5647 .38824 Mdot
.65489 .29806 Mdot
.62744 .41569 Mdot
.72547 .59999 Mdot
.54902 .38824 Mdot
.6196 .51765 Mdot
.62744 .52941 Mdot
.34119 .23924 Mdot
.98035 .90977 Mdot
.71371 .25492 Mdot
.92154 .57254 Mdot
.67842 .251 Mdot
.85487 .38824 Mdot
.98428 .749 Mdot
.54117 .27845 Mdot
.72939 .60783 Mdot
.99996 .88624 Mdot
.99996 .89801 Mdot
.84703 .64313 Mdot
.6392 .32158 Mdot
.67057 .44314 Mdot
.68626 .54509 Mdot
.49804 .32943 Mdot
.61568 .51372 Mdot
.65881 .55294 Mdot
.27061 .17257 Mdot
.91369 .8784 Mdot
.64313 .18434 Mdot
.85095 .54902 Mdot
.89017 .59215 Mdot
.67057 .25884 Mdot
.82743 .41961 Mdot
.99996 .85095 Mdot
.95291 .78429 Mdot
.85095 .73332 Mdot
.83527 .71763 Mdot
.81958 .67057 Mdot
.53333 .22355 Mdot
.6745 .37648 Mdot
.47843 .25492 Mdot
.51372 .3255 Mdot
.53333 .35687 Mdot
.64313 .56078 Mdot
.6392 .54509 Mdot
.23924 .13336 Mdot
.92938 .89409 Mdot
.54509 .54117 Mdot
.38432 .38824 Mdot
.56078 .18826 Mdot
.6941 .26668 Mdot
.56862 .29413 Mdot
.84311 .5647 Mdot
.74116 .29413 Mdot
.77645 .43138 Mdot
.6745 .38432 Mdot
.75292 .63528 Mdot
.95683 .75684 Mdot
.50588 .34511 Mdot
.86272 .65489 Mdot
.47451 .16473 Mdot
.66665 .33727 Mdot
.64313 .4902 Mdot
.52157 .30982 Mdot
.63528 .4902 Mdot
.63136 .58431 Mdot
.63528 .54117 Mdot
.20787 .12552 Mdot
.93722 .90193 Mdot
.18434 .16865 Mdot
.21571 .20394 Mdot
.83135 .83135 Mdot
.749 .251 Mdot
.93722 .70194 Mdot
.99996 .86664 Mdot
.83527 .53333 Mdot
.77645 .34511 Mdot
.57646 .25492 Mdot
.69802 .38824 Mdot
.89801 .74116 Mdot
.91761 .58431 Mdot
.98428 .79213 Mdot
.90193 .66665 Mdot
.48235 .18042 Mdot
.53333 .21571 Mdot
.55686 .4353 Mdot
.5098 .29021 Mdot
.6196 .47059 Mdot
.60391 .58823 Mdot
.61568 .54509 Mdot
.31374 .22355 Mdot
.66273 .60391 Mdot
.11376 .10983 Mdot
.24708 .21571 Mdot
.23139 .21963 Mdot
.86272 .76861 Mdot
.73332 .23531 Mdot
.98428 .84311 Mdot
.95683 .84703 Mdot
.66665 .30982 Mdot
.94898 .49412 Mdot
.61176 .26668 Mdot
.81566 .4902 Mdot
.86664 .68626 Mdot
.74508 .33335 Mdot
.90977 .67057 Mdot
.77645 .53725 Mdot
.56078 .25884 Mdot
.48235 .17257 Mdot
.58431 .47843 Mdot
.50196 .23531 Mdot
.5647 .41177 Mdot
.47843 .48235 Mdot
.6196 .56862 Mdot
.52941 .41177 Mdot
.22747 .15297 Mdot
.71371 .71763 Mdot
.27061 .251 Mdot
.30198 .26668 Mdot
.10983 .10983 Mdot
.66273 .23531 Mdot
.59999 .27061 Mdot
.98428 .85095 Mdot
.72155 .59607 Mdot
.79998 .28629 Mdot
.95291 .48628 Mdot
.71371 .29806 Mdot
.80782 .52941 Mdot
.78037 .43922 Mdot
.86664 .49804 Mdot
.92154 .62744 Mdot
.82743 .56862 Mdot
.6941 .30198 Mdot
.81566 .6392 Mdot
.47451 .27061 Mdot
.54509 .22355 Mdot
.65097 .60783 Mdot
.42354 .41961 Mdot
.58039 .52157 Mdot
.51372 .3804 Mdot
.19218 .1216 Mdot
.1216 .1216 Mdot
.21179 .18042 Mdot
.21963 .1765 Mdot
.15297 .1412 Mdot
.59607 .21179 Mdot
.65881 .35295 Mdot
.83919 .68626 Mdot
.78429 .67057 Mdot
.80782 .32158 Mdot
.83135 .3255 Mdot
.94506 .51372 Mdot
.6392 .34903 Mdot
.99996 .78429 Mdot
.79606 .38824 Mdot
.64313 .29413 Mdot
.58431 .27845 Mdot
.60391 .251 Mdot
.41177 .11768 Mdot
.41177 .24316 Mdot
.55294 .18826 Mdot
.40785 .27061 Mdot
.40393 .41569 Mdot
.52549 .46667 Mdot
.46667 .33727 Mdot
.45491 .34511 Mdot
.10983 .09807 Mdot
.22355 .20394 Mdot
.27845 .23531 Mdot
.27061 .25492 Mdot
.46667 .27845 Mdot
.59999 .22355 Mdot
.76861 .60391 Mdot
.94898 .79213 Mdot
.64313 .40001 Mdot
.81566 .30198 Mdot
.81566 .32158 Mdot
.74116 .47843 Mdot
.69802 .46667 Mdot
.75684 .29806 Mdot
.69018 .42354 Mdot
.6941 .34119 Mdot
.99996 .75684 Mdot
.59607 .16081 Mdot
.70587 .5647 Mdot
.54117 .1961 Mdot
.53333 .22355 Mdot
.49804 .50196 Mdot
.52549 .41569 Mdot
.4902 .40785 Mdot
.43922 .31766 Mdot
.34119 .30198 Mdot
.13336 .10199 Mdot
.21179 .18434 Mdot
.21963 .18434 Mdot
.35687 .36472 Mdot
.73332 .24708 Mdot
.83527 .65097 Mdot
.86272 .66665 Mdot
.89017 .77253 Mdot
.73332 .42354 Mdot
.83135 .28629 Mdot
.64705 .32943 Mdot
.70194 .60391 Mdot
.76076 .36472 Mdot
.70587 .41177 Mdot
.74116 .46275 Mdot
.6196 .38432 Mdot
.62352 .20787 Mdot
.47843 .13336 Mdot
.64705 .45098 Mdot
.55686 .18434 Mdot
.34511 .18826 Mdot
.43138 .38824 Mdot
.45491 .33727 Mdot
.49412 .40785 Mdot
.3804 .29021 Mdot
.18042 .15297 Mdot
.18434 .16473 Mdot
.20394 .17257 Mdot
.28629 .27453 Mdot
.56078 .41177 Mdot
.74508 .26276 Mdot
.90193 .73332 Mdot
.8235 .6745 Mdot
.83919 .70587 Mdot
.94114 .55686 Mdot
.78429 .33335 Mdot
.73332 .61568 Mdot
.63136 .53333 Mdot
.74116 .28237 Mdot
.63136 .45491 Mdot
.68626 .4902 Mdot
.57646 .34119 Mdot
.66273 .18826 Mdot
.52941 .26276 Mdot
.41569 .16865 Mdot
.4902 .18434 Mdot
.54509 .47843 Mdot
.69018 .58431 Mdot
.38432 .26276 Mdot
.43922 .35687 Mdot
.50588 .45098 Mdot
.1765 .1412 Mdot
.15297 .12552 Mdot
.15689 .1216 Mdot
.1412 .14513 Mdot
.63528 .24708 Mdot
.50196 .19218 Mdot
.69018 .5098 Mdot
.94114 .79998 Mdot
.79998 .68626 Mdot
.79998 .28629 Mdot
.59215 .37648 Mdot
.63136 .58039 Mdot
.69018 .53333 Mdot
.74116 .28629 Mdot
.54902 .45883 Mdot
.58823 .46275 Mdot
.72155 .40785 Mdot
.66273 .21179 Mdot
.90977 .72155 Mdot
.5098 .21963 Mdot
.47451 .22355 Mdot
.67842 .64705 Mdot
.3804 .21179 Mdot
.52157 .38432 Mdot
.36472 .26668 Mdot
.13336 .09415 Mdot
.15297 .11768 Mdot
.22355 .1961 Mdot
.21963 .20394 Mdot
.81174 .80782 Mdot
.6941 .21179 Mdot
.90977 .74116 Mdot
.95291 .78821 Mdot
.82743 .67842 Mdot
.99996 .83919 Mdot
.72939 .31374 Mdot
.63528 .56862 Mdot
.61568 .57254 Mdot
.81958 .5647 Mdot
.66665 .28237 Mdot
.53725 .46667 Mdot
.52941 .45098 Mdot
.70194 .30982 Mdot
.63528 .25884 Mdot
.75292 .6196 Mdot
.54509 .24316 Mdot
.57646 .35687 Mdot
.54902 .53725 Mdot
.59607 .37648 Mdot
.49804 .32158 Mdot
.52549 .40393 Mdot
.14513 .11768 Mdot
.16473 .12944 Mdot
.1961 .16865 Mdot
.18826 .18434 Mdot
.44314 .21571 Mdot
.63136 .24708 Mdot
.96467 .79213 Mdot
.83919 .6745 Mdot
.83527 .70194 Mdot
.6745 .30982 Mdot
.65097 .45883 Mdot
.59215 .54902 Mdot
.60783 .5647 Mdot
.76469 .40393 Mdot
.56862 .29806 Mdot
.52941 .4902 Mdot
.61176 .45491 Mdot
.61176 .27845 Mdot
.60783 .31766 Mdot
.74116 .61176 Mdot
.49412 .20002 Mdot
.58823 .3804 Mdot
.23924 .1961 Mdot
.54509 .31374 Mdot
.55294 .36472 Mdot
.38824 .28237 Mdot
.19218 .16473 Mdot
.15689 .1216 Mdot
.24316 .22355 Mdot
.12552 .10591 Mdot
.57646 .45491 Mdot
.74508 .25884 Mdot
.83919 .6745 Mdot
.61176 .43922 Mdot
.8039 .65489 Mdot
.89409 .70587 Mdot
.66665 .47059 Mdot
.63136 .58039 Mdot
.59607 .55294 Mdot
.81174 .59607 Mdot
.69802 .31374 Mdot
.54902 .50588 Mdot
.56078 .46275 Mdot
.54117 .24316 Mdot
.63136 .4353 Mdot
.83919 .74508 Mdot
.40393 .18434 Mdot
.4902 .1961 Mdot
.6941 .64705 Mdot
.54902 .37648 Mdot
.53725 .31374 Mdot
.59607 .48235 Mdot
.14513 .10591 Mdot
.26668 .23139 Mdot
.15297 .13336 Mdot
.17257 .1412 Mdot
.8588 .79213 Mdot
.68234 .23139 Mdot
.54509 .21571 Mdot
.70587 .51765 Mdot
.71371 .52941 Mdot
.92546 .79998 Mdot
.64705 .33335 Mdot
.65881 .60391 Mdot
.6196 .57646 Mdot
.6196 .56078 Mdot
.72939 .37256 Mdot
.63136 .4353 Mdot
.52941 .4902 Mdot
.6745 .38824 Mdot
.57646 .45883 Mdot
.49804 .40001 Mdot
.79213 .69802 Mdot
.4353 .20394 Mdot
.37648 .18434 Mdot
.24316 .20002 Mdot
.59607 .42746 Mdot
.36864 .19218 Mdot
.77645 .70587 Mdot
.18042 .14905 Mdot
.24316 .20002 Mdot
.15689 .1216 Mdot
.15689 .08631 Mdot
.85487 .79606 Mdot
.67842 .20787 Mdot
.65881 .27845 Mdot
.77253 .58431 Mdot
.76469 .58431 Mdot
.74508 .62352 Mdot
.58431 .32158 Mdot
.60391 .55294 Mdot
.68234 .63136 Mdot
.62352 .56862 Mdot
.76861 .4902 Mdot
.57254 .3255 Mdot
.54117 .49412 Mdot
.61176 .31766 Mdot
.54902 .46667 Mdot
.53333 .46275 Mdot
.749 .6745 Mdot
.72939 .58823 Mdot
.36864 .20787 Mdot
.37256 .34903 Mdot
.47843 .36472 Mdot
.51765 .3804 Mdot
.79213 .72547 Mdot
.18826 .15297 Mdot
.32943 .27845 Mdot
.21571 .1765 Mdot
.18826 .11768 Mdot
.55686 .43922 Mdot
.84311 .73332 Mdot
.77253 .23531 Mdot
.38432 .1765 Mdot
.76469 .57646 Mdot
.75292 .58823 Mdot
.93722 .77645 Mdot
.68626 .5647 Mdot
.6392 .58823 Mdot
.67057 .63136 Mdot
.61568 .55686 Mdot
.70979 .36864 Mdot
.65097 .48235 Mdot
.57254 .47451 Mdot
.49412 .251 Mdot
.52157 .47843 Mdot
.53333 .47843 Mdot
.67842 .60783 Mdot
.8039 .70194 Mdot
.25492 .16865 Mdot
.42354 .40001 Mdot
.39217 .30198 Mdot
.64705 .54117 Mdot
.8588 .81958 Mdot
.17257 .13336 Mdot
.24708 .19218 Mdot
.20002 .14905 Mdot
.62352 .53725 Mdot
.55686 .41569 Mdot
.99996 .96859 Mdot
.75292 .22747 Mdot
.5647 .22355 Mdot
.87056 .68234 Mdot
.69018 .53333 Mdot
.8588 .72547 Mdot
.68234 .51765 Mdot
.60783 .5647 Mdot
.78429 .74508 Mdot
.63136 .58823 Mdot
.76076 .56078 Mdot
.59607 .29021 Mdot
.56862 .48235 Mdot
.55686 .29021 Mdot
.54117 .49412 Mdot
.50588 .45883 Mdot
.54117 .48628 Mdot
.72547 .65489 Mdot
.77253 .69018 Mdot
.56078 .57646 Mdot
.48628 .3804 Mdot
.34903 .25492 Mdot
.85487 .81566 Mdot
.43138 .40785 Mdot
.20787 .15297 Mdot
.19218 .13336 Mdot
.46275 .40393 Mdot
.57254 .43138 Mdot
.54509 .43922 Mdot
.68626 .53725 Mdot
.75684 .21963 Mdot
.77645 .47059 Mdot
.8784 .68234 Mdot
.90977 .76861 Mdot
.99996 .87448 Mdot
.37648 .29413 Mdot
.59607 .55294 Mdot
.70979 .67057 Mdot
.6196 .58431 Mdot
.78821 .57254 Mdot
.59215 .30198 Mdot
.62744 .46667 Mdot
.57646 .40001 Mdot
.52157 .47451 Mdot
.52157 .47451 Mdot
.52549 .47059 Mdot
.56862 .51372 Mdot
.83135 .76861 Mdot
.36864 .37648 Mdot
.57254 .45883 Mdot
.53725 .44706 Mdot
.87448 .84703 Mdot
.73724 .71763 Mdot
.18434 .13728 Mdot
.21963 .16865 Mdot
.42354 .35687 Mdot
.64313 .50196 Mdot
.5647 .46667 Mdot
.99212 .98035 Mdot
.68626 .18826 Mdot
.78037 .251 Mdot
.84703 .51765 Mdot
.71371 .57646 Mdot
.93722 .67057 Mdot
.72547 .5647 Mdot
.61568 .57646 Mdot
.6196 .57646 Mdot
.8235 .78429 Mdot
.63528 .57646 Mdot
.73724 .34119 Mdot
.63136 .49412 Mdot
.5647 .28237 Mdot
.52941 .48235 Mdot
.52549 .48628 Mdot
.52157 .47451 Mdot
.53333 .48235 Mdot
.57646 .51765 Mdot
.77645 .78037 Mdot
.66665 .54902 Mdot
.54509 .46667 Mdot
.74116 .68626 Mdot
.89017 .89801 Mdot
.71371 .69802 Mdot
.5647 .52549 Mdot
.64313 .58039 Mdot
.49804 .38824 Mdot
.54902 .47451 Mdot
.34511 .26668 Mdot
.53333 .23531 Mdot
.77645 .251 Mdot
.69018 .1765 Mdot
.9333 .74508 Mdot
.75684 .59607 Mdot
.75684 .45098 Mdot
.49804 .45491 Mdot
.6196 .56862 Mdot
.62744 .58431 Mdot
.69018 .65489 Mdot
.73724 .57646 Mdot
.59999 .25492 Mdot
.76076 .47843 Mdot
.57646 .48235 Mdot
.52157 .48235 Mdot
.52941 .48235 Mdot
.52549 .47843 Mdot
.52157 .47843 Mdot
.58823 .52941 Mdot
.42354 .44314 Mdot
.89017 .74116 Mdot
.76469 .70194 Mdot
.86664 .85487 Mdot
.91761 .92546 Mdot
.85487 .85487 Mdot
.83527 .78429 Mdot
.35295 .24316 Mdot
.51372 .42746 Mdot
.59999 .53333 Mdot
.45491 .43138 Mdot
.6745 .20002 Mdot
.69802 .21179 Mdot
.78821 .27845 Mdot
.99212 .8235 Mdot
.70587 .3804 Mdot
.69802 .4902 Mdot
.44706 .40393 Mdot
.62744 .58431 Mdot
.6196 .57646 Mdot
.71371 .6745 Mdot
.8039 .55686 Mdot
.6392 .3255 Mdot
.62744 .31374 Mdot
.52549 .48628 Mdot
.54509 .50588 Mdot
.52549 .48628 Mdot
.52157 .47451 Mdot
.54902 .49412 Mdot
.58039 .53725 Mdot
.47451 .44314 Mdot
.83135 .76076 Mdot
.78429 .74508 Mdot
.90977 .90977 Mdot
.88232 .88624 Mdot
.90585 .90193 Mdot
.75684 .69802 Mdot
.47843 .33727 Mdot
.40785 .37648 Mdot
.59999 .54902 Mdot
.81566 .72155 Mdot
.74116 .24708 Mdot
.78821 .25492 Mdot
.74508 .29021 Mdot
.52941 .25492 Mdot
.79213 .28629 Mdot
.61568 .54117 Mdot
.41569 .37256 Mdot
.61568 .57646 Mdot
.6392 .59999 Mdot
.75684 .70587 Mdot
.70979 .36864 Mdot
.69802 .34119 Mdot
.67842 .46275 Mdot
.55686 .50196 Mdot
.52941 .4902 Mdot
.53725 .4902 Mdot
.53333 .4902 Mdot
.5647 .50196 Mdot
.76469 .77253 Mdot
.9333 .83919 Mdot
.8588 .82743 Mdot
.8235 .79998 Mdot
.88624 .89017 Mdot
.87448 .89017 Mdot
.85487 .83135 Mdot
.49412 .40393 Mdot
.45883 .31766 Mdot
.41569 .39217 Mdot
.6745 .64705 Mdot
.5647 .23531 Mdot
.67842 .22747 Mdot
.78429 .24708 Mdot
.65489 .23924 Mdot
.99996 .65097 Mdot
.63528 .27845 Mdot
.60391 .56078 Mdot
.41177 .36864 Mdot
.61568 .57254 Mdot
.62352 .58039 Mdot
.80782 .72547 Mdot
.77253 .39609 Mdot
.71763 .31374 Mdot
.66273 .47451 Mdot
.56862 .49804 Mdot
.54117 .49804 Mdot
.53725 .49804 Mdot
.56078 .50588 Mdot
.57254 .5098 Mdot
.8784 .8784 Mdot
.66665 .54117 Mdot
.91761 .8784 Mdot
.85487 .85095 Mdot
.87056 .88232 Mdot
.88232 .89801 Mdot
.8235 .78037 Mdot
.50588 .38824 Mdot
.49804 .38824 Mdot
.43922 .41177 Mdot
.66273 .6745 Mdot
.66273 .23531 Mdot
.83527 .44314 Mdot
.74508 .251 Mdot
.73724 .27845 Mdot
.83135 .35687 Mdot
.68234 .45098 Mdot
.60391 .56078 Mdot
.53725 .49804 Mdot
.63136 .58823 Mdot
.6392 .59607 Mdot
.92154 .76861 Mdot
.8588 .50196 Mdot
.75292 .34903 Mdot
.68626 .44706 Mdot
.63136 .51765 Mdot
.57646 .50588 Mdot
.55686 .50196 Mdot
.59607 .52549 Mdot
.78037 .74116 Mdot
.61176 .58431 Mdot
.64705 .53725 Mdot
.94114 .87056 Mdot
.89017 .87448 Mdot
.88232 .89017 Mdot
.87448 .88232 Mdot
.79998 .749 Mdot
.51372 .41569 Mdot
.45491 .35295 Mdot
.46275 .42354 Mdot
.97251 .97643 Mdot
.66665 .20002 Mdot
.69018 .32943 Mdot
.6941 .27061 Mdot
.76861 .27061 Mdot
.81566 .28629 Mdot
.6745 .54509 Mdot
.60391 .56078 Mdot
.61568 .58823 Mdot
.6392 .58431 Mdot
.63528 .59215 Mdot
.95683 .70194 Mdot
.98035 .62352 Mdot
.82743 .44314 Mdot
.62352 .29413 Mdot
.67842 .47843 Mdot
.60783 .50588 Mdot
.61176 .54902 Mdot
.58039 .51372 Mdot
.84703 .81566 Mdot
.62744 .60391 Mdot
.41961 .27453 Mdot
.95683 .83527 Mdot
.95291 .90977 Mdot
.86272 .8784 Mdot
.86272 .87056 Mdot
.82743 .77645 Mdot
.61176 .54902 Mdot
.46275 .38432 Mdot
.45883 .40393 Mdot
.89801 .84311 Mdot
.72155 .251 Mdot
.70587 .39217 Mdot
.56078 .23139 Mdot
.77645 .26668 Mdot
.78429 .27061 Mdot
.6196 .54509 Mdot
.6196 .5647 Mdot
.62744 .59999 Mdot
.54509 .4902 Mdot
.64313 .58823 Mdot
.78429 .40393 Mdot
.83135 .45883 Mdot
.90585 .50588 Mdot
.64705 .25492 Mdot
.69802 .40785 Mdot
.65881 .50196 Mdot
.60391 .53333 Mdot
.77253 .73724 Mdot
.63136 .60783 Mdot
.63136 .59999 Mdot
.44314 .27845 Mdot
.78821 .65489 Mdot
.94114 .86272 Mdot
.89017 .86272 Mdot
.85487 .84703 Mdot
.8235 .78429 Mdot
.66273 .6196 Mdot
.64313 .58823 Mdot
.47059 .4353 Mdot
.45098 .32158 Mdot
.72547 .25884 Mdot
.58823 .36472 Mdot
.6745 .47059 Mdot
.77645 .26668 Mdot
.74508 .29806 Mdot
.58823 .54509 Mdot
.59999 .55686 Mdot
.61568 .58039 Mdot
.39609 .34119 Mdot
.65881 .5647 Mdot
.8588 .37256 Mdot
.66273 .24708 Mdot
.90977 .5098 Mdot
.77253 .36472 Mdot
.65097 .26668 Mdot
.71371 .47843 Mdot
.62744 .5647 Mdot
.77645 .75684 Mdot
.62744 .60783 Mdot
.62352 .59215 Mdot
.22747 .11768 Mdot
.62744 .49804 Mdot
.91761 .77253 Mdot
.92546 .85487 Mdot
.87448 .85095 Mdot
.83527 .81174 Mdot
.77253 .74508 Mdot
.82743 .79213 Mdot
.73332 .72155 Mdot
.49804 .26668 Mdot
.70979 .26668 Mdot
.89017 .73332 Mdot
.90193 .76076 Mdot
.79213 .26668 Mdot
.6196 .29021 Mdot
.60391 .56078 Mdot
.6196 .57646 Mdot
.6196 .58431 Mdot
.29413 .251 Mdot
.71763 .53725 Mdot
.83919 .30198 Mdot
.65097 .1961 Mdot
.8784 .46275 Mdot
.89017 .43922 Mdot
.70194 .27453 Mdot
.58039 .33335 Mdot
.80782 .76469 Mdot
.63136 .61568 Mdot
.62744 .60391 Mdot
.66665 .62744 Mdot
.29413 .23924 Mdot
.87448 .76469 Mdot
.73332 .58431 Mdot
.92546 .81566 Mdot
.93722 .86664 Mdot
.85095 .81566 Mdot
.77253 .749 Mdot
.79998 .77645 Mdot
.6941 .70194 Mdot
.57646 .26668 Mdot
.65881 .24708 Mdot
.94114 .81566 Mdot
.63528 .47451 Mdot
.78429 .251 Mdot
.71763 .50196 Mdot
.60391 .56078 Mdot
.62744 .58431 Mdot
.61176 .56862 Mdot
.36864 .3255 Mdot
.86272 .56078 Mdot
.85487 .3059 Mdot
.79606 .29021 Mdot
.75684 .31766 Mdot
.85487 .40785 Mdot
.82743 .41961 Mdot
.66273 .45491 Mdot
.72939 .68626 Mdot
.64313 .6196 Mdot
.63528 .60783 Mdot
.72155 .68626 Mdot
.84703 .82743 Mdot
.94898 .90585 Mdot
.69802 .60391 Mdot
.78821 .61568 Mdot
.99996 .85487 Mdot
.89409 .83135 Mdot
.80782 .77645 Mdot
.89801 .87056 Mdot
.64705 .65881 Mdot
.62744 .21571 Mdot
.6941 .3804 Mdot
.21571 .10199 Mdot
.57254 .3059 Mdot
.76469 .26668 Mdot
.61568 .54117 Mdot
.59999 .55686 Mdot
.61176 .57646 Mdot
.59999 .5647 Mdot
.4353 .37256 Mdot
.78821 .31374 Mdot
.83527 .29413 Mdot
.81958 .29806 Mdot
.6745 .21963 Mdot
.81566 .36864 Mdot
.87448 .46667 Mdot
.92546 .83919 Mdot
.63136 .59999 Mdot
.64313 .6196 Mdot
.61568 .59215 Mdot
.17257 .14905 Mdot
.90193 .89801 Mdot
.9333 .89409 Mdot
.91761 .82743 Mdot
.58431 .39609 Mdot
.89409 .73724 Mdot
.93722 .84311 Mdot
.79998 .76469 Mdot
.94898 .92154 Mdot
.90585 .86272 Mdot
.74116 .28237 Mdot
.55294 .34119 Mdot
.97643 .87056 Mdot
.65881 .29806 Mdot
.65881 .28629 Mdot
.59999 .55686 Mdot
.60783 .5647 Mdot
.59607 .55294 Mdot
.60783 .57254 Mdot
.54902 .36472 Mdot
.72547 .27061 Mdot
.81958 .29413 Mdot
.83919 .3059 Mdot
.68234 .18826 Mdot
.80782 .39609 Mdot
.72939 .35687 Mdot
.64705 .59607 Mdot
.62352 .59999 Mdot
.61568 .59215 Mdot
.61176 .59215 Mdot
.15689 .1412 Mdot
.92546 .89409 Mdot
.94114 .89801 Mdot
.96075 .90977 Mdot
.74508 .61568 Mdot
.67057 .45098 Mdot
.92546 .76469 Mdot
.8784 .80782 Mdot
.51765 .51372 Mdot
.60391 .41177 Mdot
.69802 .29021 Mdot
.8235 .68626 Mdot
.65489 .45098 Mdot
.70194 .23924 Mdot
.58039 .46667 Mdot
.60783 .5647 Mdot
.59999 .55686 Mdot
.60783 .57254 Mdot
.6196 .57646 Mdot
.75684 .3059 Mdot
.60391 .23924 Mdot
.81174 .30198 Mdot
.82743 .28629 Mdot
.749 .25492 Mdot
.81174 .3804 Mdot
.5647 .3804 Mdot
.62744 .60391 Mdot
.60783 .58823 Mdot
.6196 .59215 Mdot
.59607 .57646 Mdot
.96467 .94506 Mdot
.92154 .8235 Mdot
.9333 .90585 Mdot
.94898 .91761 Mdot
.92154 .78429 Mdot
.51765 .28237 Mdot
.89017 .81174 Mdot
.58039 .51372 Mdot
.97251 .98035 Mdot
.69018 .28237 Mdot
.68626 .41177 Mdot
.84311 .68626 Mdot
.90193 .60391 Mdot
.64705 .29413 Mdot
.59999 .55686 Mdot
.6196 .56862 Mdot
.60783 .5647 Mdot
.61176 .56862 Mdot
.8039 .55686 Mdot
.62352 .29021 Mdot
.57646 .27453 Mdot
.79998 .30982 Mdot
.83527 .28629 Mdot
.78037 .25884 Mdot
.68626 .26276 Mdot
.63136 .58431 Mdot
.61568 .59215 Mdot
.60783 .58823 Mdot
.6196 .60783 Mdot
.16473 .1412 Mdot
.97643 .87448 Mdot
.91369 .78429 Mdot
.92546 .91761 Mdot
.95683 .91369 Mdot
.97251 .89017 Mdot
.48628 .32943 Mdot
.64313 .54509 Mdot
.48628 .4902 Mdot
.33335 .25884 Mdot
.70194 .28629 Mdot
.55294 .28629 Mdot
.90585 .6745 Mdot
.63528 .16473 Mdot
.62744 .51372 Mdot
.60783 .55294 Mdot
.61568 .57254 Mdot
.61568 .57254 Mdot
.64705 .57646 Mdot
.80782 .30198 Mdot
.94114 .8039 Mdot
.58431 .29413 Mdot
.79998 .32158 Mdot
.85095 .28237 Mdot
.81958 .28237 Mdot
.56862 .35295 Mdot
.60391 .58039 Mdot
.61176 .59215 Mdot
.62352 .60391 Mdot
.56862 .54117 Mdot
.9882 .92546 Mdot
.69802 .50588 Mdot
.96467 .89801 Mdot
.38432 .36472 Mdot
.91761 .89801 Mdot
.97251 .87056 Mdot
.90193 .81174 Mdot
.88232 .82743 Mdot
.97643 .98428 Mdot
.61176 .25884 Mdot
.58823 .23531 Mdot
.52157 .16473 Mdot
.55686 .16473 Mdot
.6196 .34119 Mdot
.31766 .26276 Mdot
.6196 .5647 Mdot
.60783 .57254 Mdot
.6196 .5647 Mdot
.74508 .32158 Mdot
.63136 .36472 Mdot
.94506 .84311 Mdot
.57254 .29806 Mdot
.83527 .30198 Mdot
.85487 .26668 Mdot
.749 .34119 Mdot
.60783 .58431 Mdot
.62352 .60391 Mdot
.60391 .59215 Mdot
.65489 .63528 Mdot
.10983 .06278 Mdot
.5647 .36472 Mdot
.81174 .6941 Mdot
.59607 .57646 Mdot
.65881 .62744 Mdot
.90977 .89017 Mdot
.72547 .60391 Mdot
.57646 .52157 Mdot
.66665 .68626 Mdot
.41569 .30982 Mdot
.62352 .23531 Mdot
.59215 .16473 Mdot
.52549 .15297 Mdot
.74116 .28629 Mdot
.6392 .56862 Mdot
.59999 .54509 Mdot
.6196 .57646 Mdot
.61568 .57254 Mdot
.78429 .53725 Mdot
.81174 .31374 Mdot
.95291 .81566 Mdot
.93722 .82743 Mdot
.66665 .29806 Mdot
.86272 .27453 Mdot
.8235 .27453 Mdot
.65097 .57254 Mdot
.62352 .60391 Mdot
.62744 .60391 Mdot
.61568 .60391 Mdot
.20394 .16473 Mdot
.51372 .34119 Mdot
.94898 .76469 Mdot
.10591 .0667 Mdot
.87448 .85487 Mdot
.52941 .5098 Mdot
.99604 .88624 Mdot
.52941 .48235 Mdot
.85487 .84703 Mdot
.77645 .76469 Mdot
.6196 .30198 Mdot
.73724 .26276 Mdot
.76076 .30198 Mdot
.79213 .28237 Mdot
.6196 .52549 Mdot
.29413 .23924 Mdot
.62352 .58039 Mdot
.60783 .57254 Mdot
.6941 .51765 Mdot
.83919 .27845 Mdot
.78429 .44706 Mdot
.94898 .83135 Mdot
.95291 .76469 Mdot
.86272 .27845 Mdot
.83527 .26668 Mdot
.69802 .57646 Mdot
.62352 .59607 Mdot
.60391 .59215 Mdot
.64313 .62352 Mdot
.16865 .12944 Mdot
.77253 .66273 Mdot
.70587 .47059 Mdot
.90193 .86664 Mdot
.8784 .85095 Mdot
.79998 .76076 Mdot
.96075 .86664 Mdot
.87448 .83527 Mdot
.88624 .88624 Mdot
.97643 .97251 Mdot
.58039 .29021 Mdot
.74116 .251 Mdot
.76861 .27061 Mdot
.77645 .28629 Mdot
.62744 .56078 Mdot
.40393 .34903 Mdot
.63136 .58823 Mdot
.61176 .57646 Mdot
.83919 .55686 Mdot
.83135 .27061 Mdot
.60391 .22355 Mdot
.95291 .82743 Mdot
.99996 .81958 Mdot
.85487 .27845 Mdot
.81174 .26668 Mdot
.6392 .57646 Mdot
.62744 .60783 Mdot
.61568 .60391 Mdot
.52549 .50588 Mdot
.21179 .14905 Mdot
.9333 .79998 Mdot
.8039 .57646 Mdot
.58823 .54509 Mdot
.52157 .4902 Mdot
.66273 .63136 Mdot
.99996 .89801 Mdot
.75292 .72547 Mdot
.88624 .88232 Mdot
.8235 .75292 Mdot
.6745 .31766 Mdot
.77645 .251 Mdot
.81566 .27845 Mdot
.73724 .52941 Mdot
.60391 .56078 Mdot
.40001 .35687 Mdot
.6196 .58431 Mdot
.69802 .54509 Mdot
.82743 .28237 Mdot
.78821 .30982 Mdot
.57254 .27845 Mdot
.90977 .85095 Mdot
.82743 .3059 Mdot
.85487 .27845 Mdot
.61568 .42354 Mdot
.57254 .54509 Mdot
.43138 .41961 Mdot
.27845 .26668 Mdot
.21963 .1765 Mdot
.76076 .62744 Mdot
.92154 .72547 Mdot
.90977 .8784 Mdot
.68626 .66665 Mdot
.63136 .59999 Mdot
.94114 .88232 Mdot
.9333 .83135 Mdot
.86272 .8588 Mdot
.96859 .97643 Mdot
.55686 .30982 Mdot
.64705 .18826 Mdot
.81566 .27845 Mdot
.74116 .4902 Mdot
.60391 .56078 Mdot
.34903 .3059 Mdot
.63136 .59607 Mdot
.70979 .53333 Mdot
.82743 .28237 Mdot
.75292 .34119 Mdot
.49804 .23139 Mdot
.90193 .85487 Mdot
.8235 .31766 Mdot
.83919 .26276 Mdot
.63528 .44706 Mdot
.27845 .251 Mdot
.30198 .27845 Mdot
.45491 .44314 Mdot
.20787 .16473 Mdot
.36472 .23139 Mdot
.9333 .73724 Mdot
.89017 .87056 Mdot
.94114 .92154 Mdot
.97251 .95291 Mdot
.92546 .88232 Mdot
.96859 .84703 Mdot
.87448 .86664 Mdot
.96859 .97643 Mdot
.53725 .34511 Mdot
.72547 .22747 Mdot
.79998 .29413 Mdot
.57646 .48628 Mdot
.59999 .55686 Mdot
.25884 .21571 Mdot
.6392 .58431 Mdot
.72155 .28237 Mdot
.8039 .30198 Mdot
.76076 .61568 Mdot
.48235 .41177 Mdot
.99212 .83919 Mdot
.84703 .27453 Mdot
.75684 .28629 Mdot
.45883 .4353 Mdot
.55294 .53333 Mdot
.61176 .58823 Mdot
.59215 .56862 Mdot
.1961 .12552 Mdot
.99996 .89017 Mdot
.78429 .6745 Mdot
.24708 .21963 Mdot
.22747 .20787 Mdot
.69018 .67842 Mdot
.9882 .89409 Mdot
.90193 .84311 Mdot
.40001 .43138 Mdot
.6941 .63528 Mdot
.6941 .31374 Mdot
.77645 .24708 Mdot
.70587 .49804 Mdot
.59607 .55294 Mdot
.62352 .58039 Mdot
.62744 .58431 Mdot
.8235 .42354 Mdot
.80782 .28237 Mdot
.94114 .86664 Mdot
.91761 .8588 Mdot
.91369 .83919 Mdot
.84703 .29021 Mdot
.81174 .28237 Mdot
.63528 .59607 Mdot
.61568 .59215 Mdot
.61176 .59215 Mdot
.59215 .56862 Mdot
.15297 .11376 Mdot
.8784 .74116 Mdot
.55686 .42746 Mdot
.81174 .78429 Mdot
.28629 .25492 Mdot
.29021 .27061 Mdot
.92154 .8784 Mdot
.81566 .69802 Mdot
.89409 .90585 Mdot
.73332 .69802 Mdot
.71763 .31374 Mdot
.76469 .25884 Mdot
.60391 .46667 Mdot
.59607 .55294 Mdot
.6196 .58039 Mdot
.6392 .54117 Mdot
.8235 .29806 Mdot
.70587 .34511 Mdot
.88232 .8588 Mdot
.91369 .83527 Mdot
.9882 .79606 Mdot
.84703 .26276 Mdot
.65881 .31766 Mdot
.58431 .5647 Mdot
.59999 .57254 Mdot
.59999 .58039 Mdot
.6745 .65097 Mdot
.98428 .90585 Mdot
.91369 .70587 Mdot
.95683 .91369 Mdot
.34903 .32158 Mdot
.97643 .94114 Mdot
.94506 .94114 Mdot
.9333 .87056 Mdot
.21179 .14513 Mdot
.46275 .5098 Mdot
.54117 .3804 Mdot
.76076 .30198 Mdot
.68234 .3255 Mdot
.54902 .4902 Mdot
.61176 .56862 Mdot
.37256 .32943 Mdot
.77253 .33335 Mdot
.81174 .30198 Mdot
.89409 .86664 Mdot
.93722 .83919 Mdot
.97251 .79213 Mdot
.83527 .29413 Mdot
.79606 .29413 Mdot
.62352 .58823 Mdot
.59607 .57254 Mdot
.59215 .57254 Mdot
.58431 .56078 Mdot
.13336 .07846 Mdot
.91761 .6941 Mdot
.67057 .5647 Mdot
.81958 .79998 Mdot
.33727 .28629 Mdot
.5098 .4902 Mdot
.89409 .89409 Mdot
.3608 .251 Mdot
.87056 .89017 Mdot
.92154 .8588 Mdot
.64705 .27845 Mdot
.68234 .25492 Mdot
.54902 .47451 Mdot
.59607 .56078 Mdot
.61176 .57254 Mdot
.77253 .31374 Mdot
.81174 .28629 Mdot
.8784 .84311 Mdot
.94898 .77645 Mdot
.85095 .51372 Mdot
.83527 .29021 Mdot
.79213 .29806 Mdot
.61568 .57254 Mdot
.61176 .59215 Mdot
.58431 .5647 Mdot
.59215 .57646 Mdot
.20394 .12944 Mdot
.74116 .49412 Mdot
.96467 .86664 Mdot
.59215 .56078 Mdot
.8235 .78037 Mdot
.50196 .48628 Mdot
.89017 .89017 Mdot
.32943 .22747 Mdot
.86664 .89409 Mdot
.88232 .78429 Mdot
.6745 .24708 Mdot
.70587 .45098 Mdot
.55686 .50588 Mdot
.60391 .57646 Mdot
.65097 .46667 Mdot
.82743 .27061 Mdot
.47451 .16081 Mdot
.89801 .86272 Mdot
.66665 .25492 Mdot
.72939 .30982 Mdot
.84703 .27845 Mdot
.61176 .40785 Mdot
.62744 .60391 Mdot
.60783 .58823 Mdot
.59607 .57646 Mdot
.16473 .12552 Mdot
.8588 .70194 Mdot
.6745 .44706 Mdot
.93722 .91761 Mdot
.48235 .44706 Mdot
.44314 .41569 Mdot
.89801 .89801 Mdot
.93722 .87448 Mdot
.53333 .4902 Mdot
.4902 .54509 Mdot
.62352 .30198 Mdot
.61176 .32158 Mdot
.56078 .47843 Mdot
.58823 .56078 Mdot
.70979 .52549 Mdot
.8235 .26668 Mdot
.6392 .251 Mdot
.89801 .87056 Mdot
.75292 .3608 Mdot
.72939 .22355 Mdot
.83135 .27061 Mdot
.64705 .45491 Mdot
.61176 .58431 Mdot
.60391 .58039 Mdot
.59999 .57646 Mdot
.1765 .13728 Mdot
.49412 .33727 Mdot
.99996 .8039 Mdot
.39217 .37256 Mdot
.90977 .86664 Mdot
.84703 .81958 Mdot
.90193 .90193 Mdot
.94114 .8784 Mdot
.54902 .51372 Mdot
.73724 .77645 Mdot
.83135 .55686 Mdot
.72155 .4902 Mdot
.56078 .44706 Mdot
.56862 .53333 Mdot
.79998 .52549 Mdot
.81958 .26668 Mdot
.54117 .18434 Mdot
.88624 .84311 Mdot
.6941 .31766 Mdot
.81958 .3059 Mdot
.80782 .27845 Mdot
.67057 .57254 Mdot
.60391 .57646 Mdot
.59607 .57646 Mdot
.59607 .57254 Mdot
.21571 .16865 Mdot
.72939 .59607 Mdot
.60391 .42746 Mdot
.20787 .1765 Mdot
.40785 .36864 Mdot
.48235 .46275 Mdot
.89409 .89409 Mdot
.94898 .86664 Mdot
.88624 .87448 Mdot
.75684 .72939 Mdot
.6392 .3804 Mdot
.54117 .33727 Mdot
.56078 .46275 Mdot
.61568 .55686 Mdot
.78821 .29806 Mdot
.8235 .27061 Mdot
.94114 .73724 Mdot
.96467 .88232 Mdot
.63528 .28629 Mdot
.81174 .30198 Mdot
.62744 .32158 Mdot
.60391 .57646 Mdot
.62352 .58431 Mdot
.59215 .56862 Mdot
.52941 .51372 Mdot
.94506 .90585 Mdot
.59999 .43922 Mdot
.96859 .90977 Mdot
.15297 .13728 Mdot
.54902 .51372 Mdot
.94898 .94506 Mdot
.90193 .88624 Mdot
.25492 .16473 Mdot
.33335 .37256 Mdot
.78429 .6941 Mdot
.72939 .53333 Mdot
.60391 .40785 Mdot
.56862 .49412 Mdot
.79213 .48235 Mdot
.8235 .27061 Mdot
.77253 .31374 Mdot
.92546 .8235 Mdot
.83135 .67057 Mdot
.59215 .23531 Mdot
.76076 .31374 Mdot
.61176 .58431 Mdot
.60783 .58039 Mdot
.61568 .59215 Mdot
.59999 .5647 Mdot
.3608 .34119 Mdot
.97643 .88232 Mdot
.96075 .83919 Mdot
.44314 .42746 Mdot
.83919 .79998 Mdot
.52157 .50588 Mdot
.89801 .89801 Mdot
.40001 .3059 Mdot
.87448 .90193 Mdot
.38824 .39217 Mdot
.84703 .67842 Mdot
.70194 .47843 Mdot
.62744 .45098 Mdot
.6392 .48235 Mdot
.79606 .28237 Mdot
.81958 .27453 Mdot
.70979 .36472 Mdot
.92938 .83919 Mdot
.85095 .72155 Mdot
.79606 .32158 Mdot
.65097 .59607 Mdot
.59215 .57254 Mdot
.58039 .56078 Mdot
.56862 .55294 Mdot
.20394 .17257 Mdot
.94114 .88624 Mdot
.85095 .66273 Mdot
.78037 .73724 Mdot
.15689 .13336 Mdot
.55294 .52157 Mdot
.89409 .90193 Mdot
.97643 .91369 Mdot
.78429 .78429 Mdot
.83527 .83919 Mdot
.81566 .69802 Mdot
.86272 .67057 Mdot
.49412 .30198 Mdot
.62744 .46667 Mdot
.78821 .29806 Mdot
.82743 .28237 Mdot
.63136 .18434 Mdot
.97251 .81174 Mdot
.93722 .85487 Mdot
.77645 .33727 Mdot
.6196 .58039 Mdot
.61568 .59607 Mdot
.59215 .57254 Mdot
.5647 .54509 Mdot
.18826 .15689 Mdot
.93722 .87448 Mdot
.749 .52941 Mdot
.9882 .94898 Mdot
.78037 .76469 Mdot
.26668 .24316 Mdot
.89017 .89801 Mdot
.99212 .92154 Mdot
.85095 .8588 Mdot
.73724 .73724 Mdot
.72155 .61568 Mdot
.79998 .65097 Mdot
.43922 .31374 Mdot
.76076 .45491 Mdot
.77645 .28629 Mdot
.81958 .28629 Mdot
.68234 .22355 Mdot
.97643 .72939 Mdot
.97643 .8039 Mdot
.68626 .35687 Mdot
.6196 .59607 Mdot
.57254 .54509 Mdot
.47059 .45098 Mdot
.45883 .44314 Mdot
.9333 .91761 Mdot
.79213 .63528 Mdot
.55294 .40785 Mdot
.90193 .90193 Mdot
.91761 .90977 Mdot
.8588 .85487 Mdot
.89801 .89017 Mdot
.28629 .20002 Mdot
.90193 .9333 Mdot
.63136 .58039 Mdot
.88232 .79213 Mdot
.86272 .76469 Mdot
.68626 .47059 Mdot
.70194 .27061 Mdot
.79998 .29413 Mdot
.83527 .31374 Mdot
.60391 .20787 Mdot
.95291 .70194 Mdot
.71371 .36472 Mdot
.49412 .47059 Mdot
.29021 .26276 Mdot
.34511 .3255 Mdot
.47843 .47059 Mdot
.56862 .54509 Mdot
.94898 .82743 Mdot
.6196 .4353 Mdot
.92154 .89017 Mdot
.90585 .89017 Mdot
.78037 .78037 Mdot
.89801 .89801 Mdot
.43138 .34119 Mdot
.89409 .92154 Mdot
.66665 .6392 Mdot
.93722 .89801 Mdot
.55294 .42354 Mdot
.63528 .251 Mdot
.77253 .3059 Mdot
.80782 .30198 Mdot
.76076 .27845 Mdot
.63136 .22355 Mdot
.71371 .37256 Mdot
.36472 .34119 Mdot
.41177 .37256 Mdot
.53725 .5098 Mdot
.6745 .65881 Mdot
.83527 .81958 Mdot
.93722 .81958 Mdot
.97643 .8235 Mdot
.96859 .8784 Mdot
.92546 .89017 Mdot
.61568 .61568 Mdot
.90193 .89409 Mdot
.29021 .19218 Mdot
.92154 .95291 Mdot
.98035 .97643 Mdot
.58039 .37256 Mdot
.61568 .23139 Mdot
.74116 .28629 Mdot
.80782 .30198 Mdot
.8039 .29413 Mdot
.71371 .28629 Mdot
.58039 .53333 Mdot
.59607 .56078 Mdot
.61176 .58823 Mdot
.57254 .55686 Mdot
.08631 .07062 Mdot
.94114 .8784 Mdot
.86664 .6941 Mdot
.99996 .88624 Mdot
.89017 .73724 Mdot
.90977 .90585 Mdot
.89017 .89801 Mdot
.96859 .8784 Mdot
.83919 .87056 Mdot
.79213 .6941 Mdot
.57254 .24708 Mdot
.69802 .26668 Mdot
.78821 .31766 Mdot
.81566 .30198 Mdot
.72547 .36472 Mdot
.57646 .55294 Mdot
.58431 .56078 Mdot
.57254 .55686 Mdot
.63528 .61568 Mdot
.64705 .63136 Mdot
.96075 .8588 Mdot
.77253 .59607 Mdot
.89801 .68626 Mdot
.62352 .44314 Mdot
.90977 .90977 Mdot
.89409 .88624 Mdot
.26276 .18042 Mdot
.94506 .96859 Mdot
.66273 .48628 Mdot
.60783 .26276 Mdot
.70587 .28237 Mdot
.79606 .29806 Mdot
.73724 .34119 Mdot
.58039 .54509 Mdot
.57646 .55294 Mdot
.56862 .54509 Mdot
.56078 .54117 Mdot
.23139 .20787 Mdot
.97251 .88624 Mdot
.63136 .45098 Mdot
.94898 .71371 Mdot
.5647 .33727 Mdot
.93722 .94506 Mdot
.89017 .89409 Mdot
.5098 .4353 Mdot
.91369 .93722 Mdot
.71371 .58431 Mdot
.58431 .27453 Mdot
.71371 .27453 Mdot
.76076 .30198 Mdot
.64313 .52549 Mdot
.5647 .54117 Mdot
.5647 .52941 Mdot
.55294 .52941 Mdot
.19218 .16081 Mdot
.94506 .87056 Mdot
.76076 .61176 Mdot
.86272 .6941 Mdot
.749 .42354 Mdot
.52157 .52157 Mdot
.87448 .91761 Mdot
.9333 .87056 Mdot
.83527 .84311 Mdot
.9882 .92938 Mdot
.54902 .30982 Mdot
.62744 .23531 Mdot
.70194 .29806 Mdot
.57646 .52157 Mdot
.56078 .52549 Mdot
.57646 .53333 Mdot
.54902 .52941 Mdot
.1961 .16081 Mdot
.65881 .54509 Mdot
.58823 .45491 Mdot
.48628 .20002 Mdot
.62352 .45883 Mdot
.54902 .54902 Mdot
.71763 .76861 Mdot
.89409 .83527 Mdot
.86664 .89409 Mdot
.90585 .8235 Mdot
.53333 .27845 Mdot
.63528 .25884 Mdot
.60391 .54117 Mdot
.55686 .52549 Mdot
.5647 .52941 Mdot
.54117 .50588 Mdot
.20787 .16473 Mdot
.94114 .8588 Mdot
.8235 .68626 Mdot
.8235 .65489 Mdot
.56078 .35295 Mdot
.47059 .41961 Mdot
.40393 .46275 Mdot
.59999 .52157 Mdot
.83135 .86664 Mdot
.93722 .8235 Mdot
.57254 .29413 Mdot
.59607 .52941 Mdot
.54902 .52941 Mdot
.53333 .51372 Mdot
.55294 .51765 Mdot
.22747 .18826 Mdot
.92154 .8784 Mdot
.77645 .65881 Mdot
.97643 .8784 Mdot
.6392 .36472 Mdot
.44314 .3804 Mdot
.57646 .58431 Mdot
.41961 .34903 Mdot
.83919 .86664 Mdot
.98428 .90193 Mdot
.90585 .84311 Mdot
.55686 .55294 Mdot
.52157 .5098 Mdot
.55686 .50588 Mdot
.22355 .17257 Mdot
.90193 .89801 Mdot
.5098 .4353 Mdot
.96075 .90193 Mdot
.73724 .33727 Mdot
.51765 .4902 Mdot
.61568 .54117 Mdot
.48628 .43138 Mdot
.83919 .85487 Mdot
.97643 .9882 Mdot
.75684 .76076 Mdot
.59607 .59999 Mdot
.49804 .47451 Mdot
.53333 .46667 Mdot
.8039 .77645 Mdot
.92154 .89017 Mdot
.91761 .90193 Mdot
.41961 .23924 Mdot
.54902 .40001 Mdot
.63136 .53725 Mdot
.45491 .40393 Mdot
.83135 .8039 Mdot
.87448 .90193 Mdot
.83135 .84703 Mdot
.63528 .65881 Mdot
.79998 .69018 Mdot
.3059 .22355 Mdot
.94114 .91369 Mdot
.93722 .90977 Mdot
.91369 .89017 Mdot
.69018 .42354 Mdot
.57254 .55686 Mdot
.53725 .47451 Mdot
.70194 .63136 Mdot
.84311 .8784 Mdot
.98035 .99604 Mdot
.65097 .67057 Mdot
.63528 .52941 Mdot
.4902 .42354 Mdot
.94898 .89409 Mdot
.94114 .89801 Mdot
.92546 .89017 Mdot
.49412 .33335 Mdot
.69802 .68234 Mdot
.87056 .80782 Mdot
.81174 .77645 Mdot
.87056 .90977 Mdot
.86664 .83527 Mdot
.87056 .84311 Mdot
.72547 .66273 Mdot
.88232 .79998 Mdot
.96859 .89801 Mdot
.99996 .91369 Mdot
.91761 .90585 Mdot
.74508 .69802 Mdot
.6196 .53725 Mdot
.83919 .87448 Mdot
.99996 .99212 Mdot
.84703 .84703 Mdot
.81958 .749 Mdot
.62744 .53725 Mdot
.86664 .79213 Mdot
.97251 .90977 Mdot
.92938 .89801 Mdot
.48628 .42746 Mdot
.83527 .78429 Mdot
.87056 .92546 Mdot
.9882 .99212 Mdot
.85095 .84703 Mdot
.91761 .86272 Mdot
.66665 .59607 Mdot
.73724 .63528 Mdot
.95291 .87056 Mdot
.9882 .90585 Mdot
.79606 .71763 Mdot
.82743 .87056 Mdot
.99212 .99996 Mdot
.80782 .78037 Mdot
.92154 .87448 Mdot
.85487 .77645 Mdot
.61568 .54509 Mdot
.77253 .67057 Mdot
.49804 .43922 Mdot
.8235 .8588 Mdot
.9882 .99996 Mdot
.78821 .77253 Mdot
.82743 .79606 Mdot
.88232 .85095 Mdot
.8235 .78821 Mdot
.6392 .56862 Mdot
.8588 .83135 Mdot
.76076 .83527 Mdot
.62352 .62744 Mdot
.79998 .79213 Mdot
.75292 .749 Mdot
.75684 .76076 Mdot
.87448 .83919 Mdot
.84703 .83135 Mdot
.56862 .63136 Mdot
.96075 .96467 Mdot
.75292 .77253 Mdot
.79998 .8039 Mdot
.87448 .8784 Mdot
.94506 .92938 Mdot
.92546 .92154 Mdot
.85095 .88232 Mdot
.89017 .90585 Mdot
.93722 .94506 Mdot
.99212 .99996 Mdot
.99212 .99212 Mdot
.9882 .99604 Mdot
.628 .126 .941 r
.90585 .90585 Mdot
.49412 .4902 Mdot
.79998 .79998 Mdot
.1765 .16473 Mdot
.18042 .18434 Mdot
.13336 .11376 Mdot
.32158 .29413 Mdot
.36864 .37256 Mdot
.20787 .19218 Mdot
.28629 .251 Mdot
.24316 .23924 Mdot
.21571 .20002 Mdot
.26276 .21963 Mdot
.23531 .22355 Mdot
.17257 .16081 Mdot
.20394 .16865 Mdot
.30982 .27845 Mdot
.83919 .83919 Mdot
.29021 .25492 Mdot
.23924 .20394 Mdot
.29021 .27453 Mdot
.99996 .96467 Mdot
.79606 .74508 Mdot
.27453 .23139 Mdot
.26668 .22355 Mdot
.27061 .24316 Mdot
.90977 .81958 Mdot
.83527 .73332 Mdot
.72547 .51765 Mdot
.14513 .09415 Mdot
.18434 .1412 Mdot
.24708 .21179 Mdot
.16865 .15689 Mdot
.41569 .41569 Mdot
.55686 .55686 Mdot
.53725 .30198 Mdot
.64313 .45491 Mdot
.62352 .24708 Mdot
.15689 .08239 Mdot
.21571 .1765 Mdot
.27845 .251 Mdot
.1765 .14513 Mdot
.90193 .85095 Mdot
.6745 .68234 Mdot
.11768 .11376 Mdot
.39217 .40001 Mdot
.61176 .28629 Mdot
.60391 .40393 Mdot
.78429 .30198 Mdot
.25884 .09415 Mdot
.16865 .12944 Mdot
.251 .22355 Mdot
.19218 .16081 Mdot
.34903 .23531 Mdot
.53725 .46275 Mdot
.8588 .76861 Mdot
.94898 .94898 Mdot
.10983 .10591 Mdot
.09415 .09807 Mdot
.83919 .83919 Mdot
.61176 .23924 Mdot
.67842 .42746 Mdot
.80782 .3059 Mdot
.21179 .05494 Mdot
.18826 .14513 Mdot
.24316 .22355 Mdot
.18826 .13336 Mdot
.47843 .30198 Mdot
.34903 .20002 Mdot
.40393 .18434 Mdot
.55294 .4353 Mdot
.85095 .75292 Mdot
.99604 .95291 Mdot
.12552 .1216 Mdot
.22355 .22355 Mdot
.07062 .09023 Mdot
.71371 .27453 Mdot
.72547 .49804 Mdot
.749 .3059 Mdot
.73724 .251 Mdot
.22747 .12552 Mdot
.20002 .15689 Mdot
.16081 .12944 Mdot
.22355 .02357 Mdot
.45883 .29413 Mdot
.4353 .20002 Mdot
.35295 .16473 Mdot
.32943 .16865 Mdot
.37648 .27061 Mdot
.61176 .52941 Mdot
.89801 .81566 Mdot
.99996 .99996 Mdot
.10199 .10591 Mdot
.21963 .20002 Mdot
.20394 .20394 Mdot
.31374 .32158 Mdot
.8235 .27453 Mdot
.5647 .29021 Mdot
.81958 .29021 Mdot
.83527 .36472 Mdot
.21963 .1216 Mdot
.20394 .16081 Mdot
.19218 .13728 Mdot
.54117 .27453 Mdot
.59607 .43922 Mdot
.55294 .24316 Mdot
.52157 .39217 Mdot
.32158 .17257 Mdot
.29806 .16081 Mdot
.31374 .16081 Mdot
.4902 .28629 Mdot
.61568 .59607 Mdot
.11376 .11768 Mdot
.26276 .251 Mdot
.19218 .17257 Mdot
.09023 .09415 Mdot
.86272 .62744 Mdot
.6941 .22355 Mdot
.81958 .41569 Mdot
.86664 .3059 Mdot
.72939 .27061 Mdot
.251 .1216 Mdot
.22747 .15689 Mdot
.27845 .08239 Mdot
.68234 .46275 Mdot
.53725 .37256 Mdot
.58431 .30198 Mdot
.72155 .57254 Mdot
.59215 .45883 Mdot
.4902 .32943 Mdot
.41177 .18434 Mdot
.40785 .18042 Mdot
.36472 .35295 Mdot
.1216 .12552 Mdot
.16081 .14905 Mdot
.16865 .14905 Mdot
.10983 .10983 Mdot
.82743 .28629 Mdot
.99212 .54117 Mdot
.8039 .26668 Mdot
.86664 .28629 Mdot
.6941 .25492 Mdot
.28629 .09807 Mdot
.25492 .09807 Mdot
.47843 .0667 Mdot
.51372 .31766 Mdot
.47843 .28629 Mdot
.42354 .23924 Mdot
.35687 .20394 Mdot
.71371 .55294 Mdot
.62744 .50196 Mdot
.48235 .15297 Mdot
.53333 .39217 Mdot
.39609 .39217 Mdot
.12552 .11376 Mdot
.13728 .11768 Mdot
.13728 .11768 Mdot
.09415 .10199 Mdot
.83919 .251 Mdot
.84703 .32158 Mdot
.84703 .26668 Mdot
.85487 .25492 Mdot
.79606 .31374 Mdot
.34903 .07062 Mdot
.32158 .03141 Mdot
.77253 .27061 Mdot
.64705 .42746 Mdot
.49804 .26668 Mdot
.78429 .6392 Mdot
.30198 .16865 Mdot
.55294 .33727 Mdot
.64705 .54117 Mdot
.6196 .23531 Mdot
.55294 .44314 Mdot
.05494 .05494 Mdot
.12552 .11376 Mdot
.34903 .32943 Mdot
.14513 .12552 Mdot
.12552 .13336 Mdot
.86272 .27453 Mdot
.87056 .29806 Mdot
.85095 .25492 Mdot
.85095 .24708 Mdot
.87056 .32158 Mdot
.51372 .09023 Mdot
.50588 .08239 Mdot
.81174 .27453 Mdot
.64313 .3804 Mdot
.6392 .3804 Mdot
.68626 .54117 Mdot
.40001 .25884 Mdot
.46667 .19218 Mdot
.6745 .56078 Mdot
.61176 .24708 Mdot
.55686 .45098 Mdot
.08631 .07846 Mdot
.12944 .12552 Mdot
.34119 .32158 Mdot
.11768 .10591 Mdot
.09023 .09807 Mdot
.86272 .27453 Mdot
.88624 .28237 Mdot
.85095 .24708 Mdot
.86664 .26276 Mdot
.9333 .35687 Mdot
.88232 .36864 Mdot
.85095 .34119 Mdot
.84311 .28629 Mdot
.60783 .34903 Mdot
.58431 .33727 Mdot
.67842 .54117 Mdot
.52549 .38432 Mdot
.51372 .20002 Mdot
.72547 .61176 Mdot
.59999 .28237 Mdot
.59215 .4902 Mdot
.1216 .11376 Mdot
.14513 .1412 Mdot
.29806 .28629 Mdot
.11376 .10199 Mdot
.07454 .07454 Mdot
.83919 .29021 Mdot
.89017 .28629 Mdot
.89017 .28629 Mdot
.88232 .27845 Mdot
.90193 .30982 Mdot
.92154 .3608 Mdot
.87056 .33335 Mdot
.89801 .30198 Mdot
.6392 .38432 Mdot
.59607 .37648 Mdot
.66273 .53333 Mdot
.38432 .23139 Mdot
.73332 .46275 Mdot
.67057 .52549 Mdot
.52941 .32943 Mdot
.58823 .44706 Mdot
.59607 .57254 Mdot
.1412 .13728 Mdot
.1412 .1412 Mdot
.09807 .09807 Mdot
.12944 .12552 Mdot
.81958 .82743 Mdot
.86272 .28237 Mdot
.87056 .27453 Mdot
.8784 .28237 Mdot
.88232 .28629 Mdot
.87056 .31766 Mdot
.91369 .36864 Mdot
.92154 .36864 Mdot
.86664 .27453 Mdot
.53725 .30982 Mdot
.54117 .36472 Mdot
.749 .62744 Mdot
.53725 .41569 Mdot
.51372 .16865 Mdot
.6941 .5647 Mdot
.39609 .1961 Mdot
.35687 .23924 Mdot
.72939 .70979 Mdot
.12944 .12552 Mdot
.22747 .21571 Mdot
.21963 .21571 Mdot
.11376 .10983 Mdot
.52157 .52549 Mdot
.81958 .30198 Mdot
.86664 .28629 Mdot
.88232 .3059 Mdot
.87448 .29413 Mdot
.83135 .30198 Mdot
.89409 .40785 Mdot
.92546 .3804 Mdot
.90585 .31374 Mdot
.54117 .20394 Mdot
.50588 .3255 Mdot
.34903 .24708 Mdot
.38824 .24708 Mdot
.81566 .55686 Mdot
.68626 .52549 Mdot
.46275 .23139 Mdot
.52549 .3608 Mdot
.45883 .38824 Mdot
.1216 .12552 Mdot
.1216 .11768 Mdot
.20394 .20394 Mdot
.14905 .1412 Mdot
.4353 .43922 Mdot
.73724 .74116 Mdot
.81958 .28629 Mdot
.90193 .32943 Mdot
.92154 .36472 Mdot
.89801 .33335 Mdot
.87056 .38824 Mdot
.89409 .46667 Mdot
.90585 .40001 Mdot
.87448 .29413 Mdot
.67842 .28237 Mdot
.63136 .41961 Mdot
.41177 .31374 Mdot
.31374 .1765 Mdot
.65097 .39217 Mdot
.79606 .64705 Mdot
.55686 .28237 Mdot
.70979 .50196 Mdot
.57646 .47843 Mdot
.08239 .08239 Mdot
.11376 .10983 Mdot
.13728 .13728 Mdot
.1216 .11376 Mdot
.47843 .47843 Mdot
.44706 .45491 Mdot
.61176 .38824 Mdot
.92154 .33335 Mdot
.9882 .4902 Mdot
.96075 .41961 Mdot
.91369 .37648 Mdot
.95291 .56862 Mdot
.86272 .48628 Mdot
.8235 .3255 Mdot
.84703 .28237 Mdot
.79213 .40785 Mdot
.52941 .40785 Mdot
.73332 .56862 Mdot
.78037 .65881 Mdot
.53725 .30198 Mdot
.84703 .61568 Mdot
.64705 .35687 Mdot
.59999 .35687 Mdot
.95291 .94506 Mdot
.1961 .18042 Mdot
.13336 .12944 Mdot
.13336 .13336 Mdot
.05102 .05494 Mdot
.50588 .5098 Mdot
.41961 .42746 Mdot
.6941 .28629 Mdot
.89801 .30982 Mdot
.97643 .45883 Mdot
.95683 .41569 Mdot
.95291 .43138 Mdot
.96859 .56862 Mdot
.91761 .54117 Mdot
.99212 .50196 Mdot
.86272 .29806 Mdot
.80782 .37648 Mdot
.78429 .64705 Mdot
.44314 .26668 Mdot
.85095 .71763 Mdot
.3804 .23139 Mdot
.46667 .13336 Mdot
.64313 .32943 Mdot
.63528 .38824 Mdot
.89409 .89017 Mdot
.09415 .09023 Mdot
.13728 .13336 Mdot
.12944 .12944 Mdot
.51372 .51372 Mdot
.53333 .53333 Mdot
.47451 .48235 Mdot
.96075 .96075 Mdot
.93722 .34903 Mdot
.92938 .37648 Mdot
.94114 .39217 Mdot
.94898 .39217 Mdot
.92154 .42746 Mdot
.94114 .5098 Mdot
.91761 .44706 Mdot
.87056 .29021 Mdot
.89017 .33727 Mdot
.65097 .3804 Mdot
.89409 .71763 Mdot
.8235 .70587 Mdot
.45098 .30198 Mdot
.85487 .67057 Mdot
.70194 .33727 Mdot
.68626 .37256 Mdot
.74508 .67842 Mdot
.34903 .33727 Mdot
.08239 .0667 Mdot
.11768 .1216 Mdot
.18826 .18826 Mdot
.54117 .54117 Mdot
.51372 .51372 Mdot
.47843 .48628 Mdot
.99996 .97643 Mdot
.94898 .3608 Mdot
.95291 .3804 Mdot
.88232 .34903 Mdot
.9333 .38432 Mdot
.9333 .39609 Mdot
.89409 .40785 Mdot
.93722 .4353 Mdot
.88232 .31766 Mdot
.88624 .3059 Mdot
.62352 .28237 Mdot
.99604 .749 Mdot
.88232 .72547 Mdot
.78429 .65097 Mdot
.95291 .72939 Mdot
.77253 .38432 Mdot
.72547 .39217 Mdot
.76861 .69802 Mdot
.25492 .24316 Mdot
.34511 .33727 Mdot
.11376 .12944 Mdot
.21571 .22355 Mdot
.56078 .55294 Mdot
.35687 .35295 Mdot
.47451 .48235 Mdot
.55294 .54902 Mdot
.8588 .29806 Mdot
.9333 .34511 Mdot
.97251 .45491 Mdot
.91369 .3804 Mdot
.92938 .3804 Mdot
.94898 .41177 Mdot
.91369 .39609 Mdot
.96859 .4353 Mdot
.90193 .34511 Mdot
.84703 .33727 Mdot
.73724 .38432 Mdot
.8235 .52157 Mdot
.91761 .71371 Mdot
.92154 .72939 Mdot
.78821 .30982 Mdot
.8039 .43922 Mdot
.71763 .54509 Mdot
.35295 .34903 Mdot
.21963 .21179 Mdot
.28237 .30982 Mdot
.17257 .1765 Mdot
.63136 .62744 Mdot
.33335 .33727 Mdot
.36472 .36864 Mdot
.49804 .48628 Mdot
.65489 .31766 Mdot
.91761 .32943 Mdot
.93722 .37648 Mdot
.94898 .43922 Mdot
.94506 .42354 Mdot
.91369 .36472 Mdot
.94898 .40393 Mdot
.94898 .41177 Mdot
.95683 .41569 Mdot
.90193 .34511 Mdot
.76076 .29413 Mdot
.749 .31766 Mdot
.69018 .37256 Mdot
.82743 .56862 Mdot
.76076 .27061 Mdot
.82743 .37648 Mdot
.70979 .39609 Mdot
.81174 .8039 Mdot
.27453 .26668 Mdot
.42746 .43138 Mdot
.21571 .23531 Mdot
.09807 .10591 Mdot
.63528 .63528 Mdot
.54117 .54509 Mdot
.54902 .54902 Mdot
.76469 .74508 Mdot
.94898 .3608 Mdot
.95291 .3608 Mdot
.93722 .40001 Mdot
.92154 .41569 Mdot
.95291 .4353 Mdot
.89801 .3608 Mdot
.92546 .37648 Mdot
.93722 .39609 Mdot
.94506 .41177 Mdot
.88232 .3255 Mdot
.83135 .37648 Mdot
.76861 .33727 Mdot
.6745 .28237 Mdot
.69802 .26276 Mdot
.83919 .30198 Mdot
.8588 .41961 Mdot
.75292 .67842 Mdot
.15297 .15297 Mdot
.83919 .8235 Mdot
.15689 .19218 Mdot
.14905 .16865 Mdot
.69018 .67842 Mdot
.38432 .38824 Mdot
.60391 .58823 Mdot
.57254 .49412 Mdot
.8039 .30982 Mdot
.91761 .34119 Mdot
.94506 .38432 Mdot
.8784 .41177 Mdot
.88232 .41961 Mdot
.94898 .42746 Mdot
.94114 .38432 Mdot
.90585 .35687 Mdot
.9333 .39217 Mdot
.96859 .44314 Mdot
.8588 .38432 Mdot
.85487 .40785 Mdot
.82743 .3804 Mdot
.79606 .34511 Mdot
.85487 .30982 Mdot
.86664 .3255 Mdot
.83527 .64313 Mdot
.85095 .85487 Mdot
.50196 .4902 Mdot
.89801 .90193 Mdot
.51765 .52941 Mdot
.12944 .12552 Mdot
.66273 .66665 Mdot
.31766 .31374 Mdot
.60391 .55686 Mdot
.97643 .92154 Mdot
.93722 .34119 Mdot
.93722 .35687 Mdot
.88232 .40785 Mdot
.83919 .47843 Mdot
.87056 .45098 Mdot
.9333 .39609 Mdot
.95291 .40393 Mdot
.91761 .37648 Mdot
.89017 .39609 Mdot
.92546 .35295 Mdot
.70587 .38824 Mdot
.87056 .47059 Mdot
.85487 .44314 Mdot
.87056 .39217 Mdot
.86664 .34119 Mdot
.82743 .34119 Mdot
.81958 .77645 Mdot
.60391 .59999 Mdot
.34119 .33335 Mdot
.96075 .97643 Mdot
.5098 .50588 Mdot
.74508 .72939 Mdot
.6196 .6196 Mdot
.3059 .30198 Mdot
.93722 .70194 Mdot
.75292 .31766 Mdot
.91761 .33727 Mdot
.90193 .39217 Mdot
.81174 .49412 Mdot
.77645 .4902 Mdot
.81174 .40785 Mdot
.92938 .37648 Mdot
.94114 .39217 Mdot
.95291 .42746 Mdot
.84311 .37648 Mdot
.81174 .37648 Mdot
.47843 .21963 Mdot
.66273 .34511 Mdot
.8235 .45098 Mdot
.86664 .43922 Mdot
.8784 .3255 Mdot
.72939 .48235 Mdot
.84311 .82743 Mdot
.27845 .26668 Mdot
.94898 .94114 Mdot
.251 .24316 Mdot
.66665 .65881 Mdot
.71763 .71371 Mdot
.66273 .66273 Mdot
.59215 .51765 Mdot
.54117 .30982 Mdot
.94898 .36864 Mdot
.90193 .34903 Mdot
.79998 .47843 Mdot
.76861 .58431 Mdot
.91761 .6941 Mdot
.87448 .43922 Mdot
.94506 .39217 Mdot
.94506 .38824 Mdot
.83527 .45098 Mdot
.92938 .39217 Mdot
.33727 .14905 Mdot
.36864 .18042 Mdot
.45491 .24708 Mdot
.58039 .29021 Mdot
.71371 .34119 Mdot
.79213 .32943 Mdot
.86664 .78037 Mdot
.6745 .6745 Mdot
.96075 .93722 Mdot
.88232 .88232 Mdot
.91369 .90193 Mdot
.79213 .78821 Mdot
.72939 .71763 Mdot
.6392 .63528 Mdot
.67057 .31374 Mdot
.90585 .78429 Mdot
.9333 .35295 Mdot
.8784 .41177 Mdot
.82743 .67842 Mdot
.8235 .70587 Mdot
.69802 .53333 Mdot
.90193 .45098 Mdot
.93722 .3804 Mdot
.92938 .3804 Mdot
.58039 .3255 Mdot
.89801 .37256 Mdot
.22747 .12944 Mdot
.25884 .16081 Mdot
.30982 .17257 Mdot
.40393 .21179 Mdot
.57646 .16865 Mdot
.57646 .29021 Mdot
.54509 .51372 Mdot
.23924 .23531 Mdot
.76469 .74116 Mdot
.94506 .95683 Mdot
.84703 .83919 Mdot
.8235 .80782 Mdot
.76861 .75292 Mdot
.73332 .71371 Mdot
.78429 .31374 Mdot
.76469 .31766 Mdot
.9333 .37256 Mdot
.8235 .53725 Mdot
.74508 .67842 Mdot
.42746 .34511 Mdot
.36864 .22355 Mdot
.90585 .46275 Mdot
.94506 .39217 Mdot
.89017 .40785 Mdot
.43922 .21179 Mdot
.88232 .40393 Mdot
.18042 .11768 Mdot
.20002 .12944 Mdot
.22747 .14513 Mdot
.28237 .16473 Mdot
.79213 .35295 Mdot
.27061 .16473 Mdot
.23531 .23531 Mdot
.19218 .1961 Mdot
.45491 .44314 Mdot
.49412 .49804 Mdot
.85487 .85487 Mdot
.83135 .82743 Mdot
.77253 .76861 Mdot
.75684 .67057 Mdot
.71763 .36472 Mdot
.92938 .36864 Mdot
.8588 .39217 Mdot
.8588 .71763 Mdot
.90977 .86272 Mdot
.34119 .29021 Mdot
.99996 .85487 Mdot
.92546 .45491 Mdot
.95291 .40001 Mdot
.63528 .34511 Mdot
.34119 .0667 Mdot
.79606 .3804 Mdot
.15297 .1216 Mdot
.18042 .1412 Mdot
.20002 .16081 Mdot
.27845 .16473 Mdot
.78429 .39609 Mdot
.21179 .18042 Mdot
.1961 .19218 Mdot
.10199 .11376 Mdot
.27453 .25884 Mdot
.81958 .81958 Mdot
.87056 .87056 Mdot
.8588 .85095 Mdot
.81174 .80782 Mdot
.89801 .65881 Mdot
.62744 .52157 Mdot
.90585 .33335 Mdot
.84311 .47843 Mdot
.83527 .749 Mdot
.39217 .3608 Mdot
.37256 .33727 Mdot
.92546 .70979 Mdot
.92938 .46667 Mdot
.94506 .38824 Mdot
.3255 .15689 Mdot
.32158 .08239 Mdot
.79606 .3804 Mdot
.1412 .10983 Mdot
.20787 .1765 Mdot
.15689 .13728 Mdot
.21571 .05102 Mdot
.70587 .3804 Mdot
.1412 .13728 Mdot
.13728 .12944 Mdot
.29021 .29413 Mdot
.51765 .50588 Mdot
.88624 .8784 Mdot
.8784 .8784 Mdot
.87448 .87448 Mdot
.85095 .85095 Mdot
.74508 .41961 Mdot
.99996 .96467 Mdot
.88232 .32943 Mdot
.83919 .55686 Mdot
.8588 .81174 Mdot
.25492 .23924 Mdot
.81958 .78821 Mdot
.94898 .69018 Mdot
.93722 .47059 Mdot
.93722 .40001 Mdot
.23924 .16081 Mdot
.32158 .10199 Mdot
.80782 .39217 Mdot
.15297 .13336 Mdot
.14513 .12552 Mdot
.13336 .11376 Mdot
.34119 .08239 Mdot
.56862 .34119 Mdot
.1216 .1216 Mdot
.14513 .1216 Mdot
.72155 .72939 Mdot
.86272 .8588 Mdot
.89017 .88232 Mdot
.88624 .88624 Mdot
.88232 .88232 Mdot
.87448 .87448 Mdot
.52157 .13336 Mdot
.99996 .96859 Mdot
.89409 .35687 Mdot
.86272 .61176 Mdot
.86664 .82743 Mdot
.251 .23924 Mdot
.48628 .45491 Mdot
.80782 .47843 Mdot
.90193 .48235 Mdot
.92154 .38824 Mdot
.21963 .16081 Mdot
.55686 .40785 Mdot
.86272 .40785 Mdot
.14513 .10591 Mdot
.14513 .13336 Mdot
.14513 .12552 Mdot
.35295 .07454 Mdot
.54902 .3255 Mdot
.12552 .12552 Mdot
.10983 .07062 Mdot
.84703 .84703 Mdot
.87056 .86664 Mdot
.85095 .85095 Mdot
.87448 .87448 Mdot
.87056 .87056 Mdot
.87056 .87056 Mdot
.69802 .3255 Mdot
.99996 .96859 Mdot
.8588 .35295 Mdot
.89801 .65881 Mdot
.89017 .85487 Mdot
.30198 .28237 Mdot
.34119 .30198 Mdot
.73724 .41569 Mdot
.89801 .51372 Mdot
.90977 .39609 Mdot
.19218 .14905 Mdot
.75684 .66273 Mdot
.88232 .42354 Mdot
.16473 .07062 Mdot
.17257 .1412 Mdot
.1412 .1216 Mdot
.37648 .09023 Mdot
.54117 .31766 Mdot
.12552 .10983 Mdot
.29413 .24708 Mdot
.86664 .86272 Mdot
.91369 .91369 Mdot
.6941 .69018 Mdot
.87448 .87448 Mdot
.8588 .8588 Mdot
.86272 .86272 Mdot
.86272 .49804 Mdot
.99996 .97251 Mdot
.86664 .39217 Mdot
.97251 .73332 Mdot
.86272 .81958 Mdot
.26668 .23924 Mdot
.21179 .16081 Mdot
.83527 .58823 Mdot
.86272 .52157 Mdot
.8784 .38824 Mdot
.17257 .12944 Mdot
.43922 .36472 Mdot
.86272 .44314 Mdot
.23531 .03533 Mdot
.20787 .14905 Mdot
.15689 .12552 Mdot
.37256 .07062 Mdot
.52941 .3059 Mdot
.13728 .09807 Mdot
.79998 .75684 Mdot
.87056 .86664 Mdot
.74508 .749 Mdot
.45491 .45098 Mdot
.89017 .88232 Mdot
.88624 .88624 Mdot
.8588 .86664 Mdot
.79606 .43138 Mdot
.99996 .97251 Mdot
.83135 .39609 Mdot
.97643 .74116 Mdot
.79213 .74508 Mdot
.31766 .28629 Mdot
.50588 .45098 Mdot
.99996 .81566 Mdot
.87056 .5647 Mdot
.89017 .41961 Mdot
.1765 .1412 Mdot
.26668 .20787 Mdot
.72547 .37256 Mdot
.40393 .09023 Mdot
.27845 .1216 Mdot
.20394 .09415 Mdot
.38824 .05494 Mdot
.52941 .27061 Mdot
.20002 .08631 Mdot
.5647 .52549 Mdot
.88624 .8784 Mdot
.27453 .28237 Mdot
.3059 .29413 Mdot
.87448 .8588 Mdot
.88624 .88624 Mdot
.87056 .8784 Mdot
.76469 .40001 Mdot
.99996 .96467 Mdot
.81174 .41177 Mdot
.94114 .69802 Mdot
.76861 .71763 Mdot
.78821 .75292 Mdot
.80782 .75684 Mdot
.58039 .45098 Mdot
.94898 .67842 Mdot
.87056 .43138 Mdot
.1961 .16081 Mdot
.24316 .20002 Mdot
.64705 .36864 Mdot
.73724 .29806 Mdot
.42746 .09807 Mdot
.31374 .0667 Mdot
.43138 .04317 Mdot
.56078 .23924 Mdot
.29413 .05886 Mdot
.57646 .54117 Mdot
.90585 .88624 Mdot
.26276 .28237 Mdot
.20394 .17257 Mdot
.90193 .8784 Mdot
.8784 .8784 Mdot
.86664 .87448 Mdot
.72939 .37256 Mdot
.99996 .96467 Mdot
.76861 .40393 Mdot
.86664 .61568 Mdot
.83919 .79606 Mdot
.51765 .4902 Mdot
.47843 .43922 Mdot
.4902 .40393 Mdot
.99604 .73724 Mdot
.86664 .44706 Mdot
.18434 .15689 Mdot
.20394 .1765 Mdot
.80782 .59215 Mdot
.81958 .35687 Mdot
.65097 .21963 Mdot
.47451 .1216 Mdot
.46667 .02357 Mdot
.60391 .20394 Mdot
.47451 .12552 Mdot
.64313 .61176 Mdot
.51372 .50196 Mdot
.26668 .28629 Mdot
.16865 .12552 Mdot
.96075 .93722 Mdot
.88232 .8784 Mdot
.87056 .8784 Mdot
.68626 .33335 Mdot
.99996 .95683 Mdot
.75292 .41177 Mdot
.77645 .52941 Mdot
.94898 .92546 Mdot
.35295 .34511 Mdot
.4353 .42354 Mdot
.74116 .67842 Mdot
.99996 .75684 Mdot
.84311 .44706 Mdot
.18042 .14905 Mdot
.1765 .14513 Mdot
.62352 .44706 Mdot
.89017 .5098 Mdot
.82743 .36472 Mdot
.73724 .29021 Mdot
.61176 .13336 Mdot
.74508 .26668 Mdot
.749 .30982 Mdot
.84311 .80782 Mdot
.27061 .26668 Mdot
.22355 .23531 Mdot
.15297 .09807 Mdot
.89017 .87448 Mdot
.91369 .89017 Mdot
.87448 .88232 Mdot
.66273 .3255 Mdot
.99996 .95291 Mdot
.75292 .41569 Mdot
.66665 .43922 Mdot
.92546 .91369 Mdot
.19218 .18434 Mdot
.21571 .22355 Mdot
.91761 .87448 Mdot
.98035 .72939 Mdot
.83919 .46667 Mdot
.16473 .14513 Mdot
.18042 .14905 Mdot
.36864 .20394 Mdot
.99996 .68626 Mdot
.83527 .39217 Mdot
.88232 .41961 Mdot
.81174 .35295 Mdot
.85095 .3255 Mdot
.83919 .36864 Mdot
.68626 .64705 Mdot
.25884 .25492 Mdot
.15297 .15689 Mdot
.13728 .08239 Mdot
.63136 .61568 Mdot
.87448 .83919 Mdot
.86664 .87056 Mdot
.60391 .28629 Mdot
.99996 .94506 Mdot
.77253 .4353 Mdot
.61568 .42746 Mdot
.70194 .68626 Mdot
.56078 .54509 Mdot
.66273 .65489 Mdot
.94506 .91369 Mdot
.91761 .67057 Mdot
.80782 .46275 Mdot
.24708 .21963 Mdot
.18826 .15689 Mdot
.35295 .18826 Mdot
.99604 .58039 Mdot
.99996 .6196 Mdot
.86272 .45883 Mdot
.91369 .52157 Mdot
.90585 .36864 Mdot
.83919 .40393 Mdot
.3059 .28629 Mdot
.20394 .1961 Mdot
.16081 .16081 Mdot
.16473 .10983 Mdot
.57254 .55686 Mdot
.34511 .32158 Mdot
.86664 .87448 Mdot
.54117 .23924 Mdot
.99996 .94506 Mdot
.76076 .41177 Mdot
.66665 .52941 Mdot
.49412 .47059 Mdot
.90193 .8784 Mdot
.97251 .95291 Mdot
.93722 .90585 Mdot
.83527 .58823 Mdot
.8039 .46275 Mdot
.52157 .48628 Mdot
.18434 .15297 Mdot
.34119 .14905 Mdot
.90977 .44706 Mdot
.96075 .57254 Mdot
.98428 .58823 Mdot
.99996 .60783 Mdot
.92546 .38824 Mdot
.749 .38432 Mdot
.26276 .24708 Mdot
.15297 .14513 Mdot
.14905 .14513 Mdot
.17257 .11768 Mdot
.59215 .56862 Mdot
.73332 .70979 Mdot
.87056 .8784 Mdot
.52157 .21963 Mdot
.99996 .94898 Mdot
.81174 .4353 Mdot
.82743 .73332 Mdot
.36864 .33727 Mdot
.52157 .49412 Mdot
.92938 .90585 Mdot
.95291 .90977 Mdot
.76861 .51765 Mdot
.80782 .46667 Mdot
.47059 .42746 Mdot
.15297 .13336 Mdot
.33335 .10983 Mdot
.93722 .42746 Mdot
.92546 .45491 Mdot
.94898 .49804 Mdot
.97643 .53725 Mdot
.95291 .41177 Mdot
.52941 .24708 Mdot
.19218 .18826 Mdot
.14905 .14905 Mdot
.15297 .14905 Mdot
.16473 .10983 Mdot
.62744 .60391 Mdot
.69018 .65881 Mdot
.86664 .87448 Mdot
.51372 .21179 Mdot
.99996 .96859 Mdot
.83135 .42354 Mdot
.86272 .79998 Mdot
.34903 .30198 Mdot
.38432 .35687 Mdot
.91761 .89409 Mdot
.93722 .89409 Mdot
.72939 .47843 Mdot
.81566 .48235 Mdot
.29806 .24316 Mdot
.23139 .20002 Mdot
.32943 .07454 Mdot
.95291 .41177 Mdot
.94898 .43138 Mdot
.91369 .41569 Mdot
.92154 .4353 Mdot
.95291 .40001 Mdot
.43138 .1961 Mdot
.15297 .14905 Mdot
.16081 .16865 Mdot
.16081 .15297 Mdot
.1765 .1216 Mdot
.58431 .56862 Mdot
.20394 .17257 Mdot
.87056 .87056 Mdot
.5098 .21179 Mdot
.85095 .72155 Mdot
.8588 .49412 Mdot
.89801 .85487 Mdot
.31374 .26668 Mdot
.25884 .21571 Mdot
.93722 .90193 Mdot
.59215 .53725 Mdot
.95291 .72939 Mdot
.57254 .32943 Mdot
.27845 .23531 Mdot
.39609 .36864 Mdot
.47059 .09415 Mdot
.93722 .39609 Mdot
.93722 .40393 Mdot
.94114 .40785 Mdot
.93722 .40001 Mdot
.92154 .35687 Mdot
.23924 .09415 Mdot
.12944 .13728 Mdot
.22355 .23139 Mdot
.14905 .14905 Mdot
.59607 .54902 Mdot
.35295 .32943 Mdot
.45883 .43922 Mdot
.86272 .87056 Mdot
.83135 .45098 Mdot
.62352 .34903 Mdot
.79606 .48235 Mdot
.77645 .71371 Mdot
.70979 .65881 Mdot
.73724 .69018 Mdot
.95291 .91761 Mdot
.58039 .51372 Mdot
.99996 .75684 Mdot
.29413 .14905 Mdot
.251 .21179 Mdot
.54902 .5098 Mdot
.85095 .37256 Mdot
.93722 .38432 Mdot
.94506 .39217 Mdot
.94506 .39217 Mdot
.94114 .3804 Mdot
.92938 .36472 Mdot
.21179 .1412 Mdot
.15297 .1765 Mdot
.24316 .26276 Mdot
.12944 .12552 Mdot
.95683 .92938 Mdot
.55294 .52941 Mdot
.73724 .71371 Mdot
.86664 .8588 Mdot
.60391 .21179 Mdot
.88624 .40393 Mdot
.8039 .65489 Mdot
.81174 .71763 Mdot
.59999 .55294 Mdot
.94898 .90193 Mdot
.78821 .77645 Mdot
.99996 .84311 Mdot
.85487 .50196 Mdot
.24708 .20394 Mdot
.27061 .23924 Mdot
.59215 .49804 Mdot
.94506 .39217 Mdot
.95291 .39217 Mdot
.94506 .38432 Mdot
.94506 .38432 Mdot
.93722 .3608 Mdot
.87448 .37256 Mdot
.18042 .1765 Mdot
.27061 .28629 Mdot
.13336 .1412 Mdot
.24316 .21571 Mdot
.88624 .88624 Mdot
.64313 .6196 Mdot
.83919 .80782 Mdot
.90977 .85095 Mdot
.54509 .33335 Mdot
.87056 .37256 Mdot
.8784 .80782 Mdot
.3608 .28629 Mdot
.28629 .23531 Mdot
.3804 .3255 Mdot
.40001 .3804 Mdot
.74508 .46667 Mdot
.77253 .45491 Mdot
.24708 .22747 Mdot
.251 .22355 Mdot
.66665 .41569 Mdot
.94114 .38432 Mdot
.90585 .40393 Mdot
.9333 .38824 Mdot
.9333 .38824 Mdot
.9333 .37256 Mdot
.79213 .45098 Mdot
.18826 .18826 Mdot
.20394 .21571 Mdot
.25884 .24708 Mdot
.39217 .34119 Mdot
.48628 .48235 Mdot
.37256 .3255 Mdot
.88232 .87448 Mdot
.81566 .62352 Mdot
.99996 .95683 Mdot
.86272 .49412 Mdot
.81174 .74508 Mdot
.44706 .40001 Mdot
.30982 .25492 Mdot
.45491 .42746 Mdot
.83919 .77253 Mdot
.99996 .76469 Mdot
.39217 .23531 Mdot
.27845 .24708 Mdot
.251 .21179 Mdot
.83135 .3804 Mdot
.92938 .39609 Mdot
.69802 .31766 Mdot
.88232 .37256 Mdot
.90193 .37648 Mdot
.90585 .3608 Mdot
.23924 .10199 Mdot
.1412 .1412 Mdot
.29021 .28237 Mdot
.42354 .40393 Mdot
.71371 .68626 Mdot
.35687 .34903 Mdot
.81958 .76076 Mdot
.86664 .87448 Mdot
.75684 .42746 Mdot
.67842 .38824 Mdot
.89017 .70979 Mdot
.90585 .86272 Mdot
.87056 .82743 Mdot
.89801 .8588 Mdot
.53333 .51765 Mdot
.98428 .78821 Mdot
.85095 .47843 Mdot
.26668 .20787 Mdot
.27061 .23531 Mdot
.27845 .18434 Mdot
.93722 .40393 Mdot
.88624 .47451 Mdot
.77253 .40785 Mdot
.6392 .25884 Mdot
.71371 .30198 Mdot
.84311 .35295 Mdot
.15297 .12944 Mdot
.36472 .35687 Mdot
.3804 .3608 Mdot
.18042 .15689 Mdot
.88624 .88624 Mdot
.89409 .89017 Mdot
.43138 .39217 Mdot
.88232 .86664 Mdot
.56862 .3608 Mdot
.92546 .52941 Mdot
.52157 .47059 Mdot
.48628 .47059 Mdot
.47843 .44314 Mdot
.56078 .53333 Mdot
.23531 .16081 Mdot
.84703 .59607 Mdot
.78821 .49412 Mdot
.23531 .1961 Mdot
.24316 .21571 Mdot
.44706 .09807 Mdot
.92154 .38824 Mdot
.99996 .87056 Mdot
.54509 .26276 Mdot
.749 .54902 Mdot
.58823 .34511 Mdot
.77253 .43922 Mdot
.42746 .43922 Mdot
.26276 .251 Mdot
.16473 .14905 Mdot
.14905 .12552 Mdot
.88232 .88232 Mdot
.79998 .74508 Mdot
.87448 .87448 Mdot
.72547 .50588 Mdot
.91369 .78429 Mdot
.96859 .81958 Mdot
.43138 .40001 Mdot
.37648 .34119 Mdot
.3804 .35295 Mdot
.40393 .38432 Mdot
.86664 .60391 Mdot
.83135 .46667 Mdot
.29413 .21179 Mdot
.251 .22355 Mdot
.251 .19218 Mdot
.92154 .38432 Mdot
.8039 .47059 Mdot
.99996 .85095 Mdot
.97251 .87448 Mdot
.96859 .85095 Mdot
.99996 .74116 Mdot
.42354 .35295 Mdot
.23924 .24316 Mdot
.18826 .1765 Mdot
.18434 .16865 Mdot
.90977 .90977 Mdot
.92938 .92546 Mdot
.51372 .46667 Mdot
.8784 .87056 Mdot
.6196 .36864 Mdot
.86664 .50196 Mdot
.37256 .32158 Mdot
.34903 .31766 Mdot
.35687 .3255 Mdot
.34511 .33727 Mdot
.90585 .72547 Mdot
.98035 .72155 Mdot
.8039 .52157 Mdot
.27061 .23139 Mdot
.23531 .21571 Mdot
.48628 .11768 Mdot
.90585 .41177 Mdot
.94506 .85487 Mdot
.87448 .75292 Mdot
.94898 .76076 Mdot
.96075 .85095 Mdot
.79606 .45098 Mdot
.21963 .23139 Mdot
.23531 .22747 Mdot
.18042 .16081 Mdot
.12944 .10591 Mdot
.8784 .88624 Mdot
.66665 .60391 Mdot
.87448 .87448 Mdot
.57646 .34511 Mdot
.63136 .46275 Mdot
.6196 .44706 Mdot
.30982 .21179 Mdot
.29413 .20002 Mdot
.28237 .20394 Mdot
.40393 .32943 Mdot
.78429 .49412 Mdot
.92546 .47843 Mdot
.251 .1961 Mdot
.23924 .21963 Mdot
.27061 .16081 Mdot
.93722 .39609 Mdot
.50588 .36864 Mdot
.54902 .36472 Mdot
.99996 .85487 Mdot
.90977 .81958 Mdot
.60391 .20394 Mdot
.24708 .22355 Mdot
.25884 .26668 Mdot
.17257 .15689 Mdot
.16865 .14513 Mdot
.88624 .88624 Mdot
.89801 .88232 Mdot
.6941 .67057 Mdot
.90193 .85487 Mdot
.58823 .50196 Mdot
.73332 .33335 Mdot
.88624 .65489 Mdot
.77645 .6392 Mdot
.83135 .62352 Mdot
.55686 .52549 Mdot
.74508 .47451 Mdot
.94506 .55686 Mdot
.68234 .50588 Mdot
.251 .20787 Mdot
.23924 .20002 Mdot
.8588 .40785 Mdot
.81174 .47059 Mdot
.99212 .88232 Mdot
.94114 .8588 Mdot
.78821 .47451 Mdot
.99604 .84703 Mdot
.48235 .24316 Mdot
.21179 .22355 Mdot
.17257 .16473 Mdot
.15689 .15297 Mdot
.50588 .4902 Mdot
.88624 .88624 Mdot
.41569 .37648 Mdot
.87056 .8784 Mdot
.70587 .47451 Mdot
.81174 .4353 Mdot
.8784 .51372 Mdot
.91761 .68234 Mdot
.82743 .55686 Mdot
.95291 .88232 Mdot
.60391 .39217 Mdot
.94506 .55686 Mdot
.77253 .50588 Mdot
.21179 .16865 Mdot
.28237 .251 Mdot
.62352 .24316 Mdot
.83135 .44706 Mdot
.96075 .86664 Mdot
.93722 .87056 Mdot
.85487 .46275 Mdot
.96467 .83135 Mdot
.77645 .45098 Mdot
.20394 .21179 Mdot
.14905 .1412 Mdot
.14905 .14513 Mdot
.15297 .11768 Mdot
.89017 .89017 Mdot
.52549 .48628 Mdot
.8784 .8784 Mdot
.45098 .251 Mdot
.72939 .41569 Mdot
.90585 .43138 Mdot
.8588 .52549 Mdot
.78821 .50588 Mdot
.77253 .6941 Mdot
.81174 .60783 Mdot
.95291 .51765 Mdot
.78821 .52157 Mdot
.43922 .39609 Mdot
.27453 .23924 Mdot
.67057 .28629 Mdot
.8235 .47059 Mdot
.9882 .8784 Mdot
.9333 .86664 Mdot
.83135 .45491 Mdot
.99996 .83135 Mdot
.73724 .4353 Mdot
.22355 .22355 Mdot
.14905 .13336 Mdot
.14905 .13336 Mdot
.1765 .13336 Mdot
.88624 .88624 Mdot
.45098 .39609 Mdot
.8784 .8784 Mdot
.44706 .26276 Mdot
.59999 .35687 Mdot
.96075 .42746 Mdot
.89017 .48235 Mdot
.99996 .72155 Mdot
.54117 .45883 Mdot
.97643 .74116 Mdot
.93722 .45491 Mdot
.77645 .5098 Mdot
.53333 .4902 Mdot
.25884 .22355 Mdot
.6941 .29806 Mdot
.81566 .50588 Mdot
.99996 .87448 Mdot
.94898 .86664 Mdot
.84703 .49412 Mdot
.99996 .83527 Mdot
.72155 .43922 Mdot
.23139 .22355 Mdot
.14905 .13336 Mdot
.15297 .13336 Mdot
.21963 .1765 Mdot
.88624 .88624 Mdot
.62744 .56862 Mdot
.87448 .87448 Mdot
.58039 .41177 Mdot
.63136 .34511 Mdot
.97251 .42354 Mdot
.89409 .46667 Mdot
.96467 .67057 Mdot
.3255 .22747 Mdot
.90977 .56862 Mdot
.94114 .42354 Mdot
.51372 .34511 Mdot
.37256 .33727 Mdot
.21179 .17257 Mdot
.90977 .4353 Mdot
.40785 .23531 Mdot
.49804 .32943 Mdot
.97643 .85095 Mdot
.47451 .25492 Mdot
.6392 .27845 Mdot
.36864 .18434 Mdot
.23139 .21963 Mdot
.16081 .14905 Mdot
.14513 .10983 Mdot
.88232 .84703 Mdot
.89017 .89017 Mdot
.58823 .53333 Mdot
.87448 .87448 Mdot
.51765 .38432 Mdot
.90977 .42354 Mdot
.95683 .42354 Mdot
.90193 .48628 Mdot
.85487 .63528 Mdot
.98035 .75292 Mdot
.93722 .46275 Mdot
.92154 .40393 Mdot
.26668 .23924 Mdot
.47451 .4353 Mdot
.27061 .12944 Mdot
.87056 .4353 Mdot
.94506 .87056 Mdot
.98035 .90585 Mdot
.83919 .40393 Mdot
.94506 .85487 Mdot
.88232 .3804 Mdot
.21571 .1765 Mdot
.16081 .15297 Mdot
.1765 .15297 Mdot
.19218 .14905 Mdot
.88624 .88624 Mdot
.9333 .92938 Mdot
.51765 .49412 Mdot
.96075 .88232 Mdot
.99996 .96859 Mdot
.89409 .36864 Mdot
.95291 .41961 Mdot
.90977 .47059 Mdot
.94114 .65881 Mdot
.9333 .48235 Mdot
.94506 .40785 Mdot
.80782 .52157 Mdot
.26668 .24708 Mdot
.52549 .49412 Mdot
.75292 .33727 Mdot
.3608 .22747 Mdot
.45883 .28629 Mdot
.98428 .84311 Mdot
.47451 .26276 Mdot
.65881 .31766 Mdot
.53725 .31374 Mdot
.22747 .21571 Mdot
.14905 .1412 Mdot
.16473 .12552 Mdot
.45098 .43138 Mdot
.88624 .88624 Mdot
.85095 .81174 Mdot
.88232 .87448 Mdot
.70979 .61568 Mdot
.77253 .42746 Mdot
.92154 .39609 Mdot
.94898 .44314 Mdot
.89017 .49412 Mdot
.90977 .45491 Mdot
.94506 .40785 Mdot
.87448 .39609 Mdot
.28237 .24316 Mdot
.25492 .23139 Mdot
.63528 .39217 Mdot
.45883 .23924 Mdot
.99996 .87448 Mdot
.94114 .86664 Mdot
.83527 .48628 Mdot
.99996 .83527 Mdot
.83135 .42746 Mdot
.1961 .18434 Mdot
.15689 .15297 Mdot
.1216 .09807 Mdot
.44706 .41961 Mdot
.89017 .89017 Mdot
.86664 .85095 Mdot
.89409 .89017 Mdot
.54509 .45098 Mdot
.69802 .5647 Mdot
.86272 .43138 Mdot
.91761 .39609 Mdot
.95683 .46275 Mdot
.94506 .45491 Mdot
.94898 .40785 Mdot
.94898 .41569 Mdot
.3059 .22355 Mdot
.25884 .24316 Mdot
.46667 .3059 Mdot
.48235 .24708 Mdot
.99996 .88232 Mdot
.93722 .8784 Mdot
.80782 .45883 Mdot
.97251 .83919 Mdot
.8784 .40785 Mdot
.16081 .14905 Mdot
.15689 .14513 Mdot
.25492 .24316 Mdot
.33727 .31374 Mdot
.88624 .88624 Mdot
.91369 .91369 Mdot
.89017 .87448 Mdot
.94114 .87056 Mdot
.96467 .89801 Mdot
.76861 .42354 Mdot
.90193 .41177 Mdot
.94898 .42746 Mdot
.96467 .43138 Mdot
.95683 .40785 Mdot
.90977 .41177 Mdot
.3059 .23531 Mdot
.27061 .24708 Mdot
.38432 .13728 Mdot
.95683 .79213 Mdot
.65097 .4353 Mdot
.94114 .86272 Mdot
.45883 .25492 Mdot
.8588 .59999 Mdot
.81174 .46275 Mdot
.16473 .16081 Mdot
.20787 .20002 Mdot
.45883 .45098 Mdot
.15297 .12552 Mdot
.88624 .88624 Mdot
.69802 .68234 Mdot
.88232 .8784 Mdot
.36864 .29806 Mdot
.84703 .71371 Mdot
.81566 .4353 Mdot
.91761 .38432 Mdot
.95683 .40785 Mdot
.95683 .40785 Mdot
.94114 .40785 Mdot
.30982 .17257 Mdot
.27061 .23531 Mdot
.34903 .1961 Mdot
.70979 .41177 Mdot
.89409 .65489 Mdot
.94506 .87056 Mdot
.58823 .45098 Mdot
.99996 .79606 Mdot
.8235 .42354 Mdot
.18042 .17257 Mdot
.47843 .46275 Mdot
.21963 .21179 Mdot
.18042 .1412 Mdot
.88624 .88624 Mdot
.90193 .89409 Mdot
.90193 .89801 Mdot
.57646 .50588 Mdot
.93722 .81958 Mdot
.78821 .42746 Mdot
.96075 .41569 Mdot
.92938 .3804 Mdot
.94506 .40785 Mdot
.91761 .43922 Mdot
.21571 .15689 Mdot
.26276 .22747 Mdot
.75684 .37256 Mdot
.8235 .51372 Mdot
.64705 .36864 Mdot
.99212 .85095 Mdot
.98428 .87056 Mdot
.9333 .38432 Mdot
.39609 .29021 Mdot
.48628 .47059 Mdot
.16473 .14905 Mdot
.16473 .16081 Mdot
.95683 .94898 Mdot
.89017 .89017 Mdot
.32943 .3059 Mdot
.89017 .87448 Mdot
.74116 .73724 Mdot
.70587 .50196 Mdot
.92154 .40393 Mdot
.9333 .3804 Mdot
.92154 .37256 Mdot
.94506 .4353 Mdot
.22747 .1216 Mdot
.23139 .1961 Mdot
.749 .37256 Mdot
.87448 .45098 Mdot
.749 .36472 Mdot
.90977 .6392 Mdot
.99996 .78037 Mdot
.92938 .37648 Mdot
.43138 .35295 Mdot
.20394 .20002 Mdot
.17257 .15689 Mdot
.16865 .15297 Mdot
.9333 .92546 Mdot
.89017 .89017 Mdot
.40785 .37256 Mdot
.89017 .87448 Mdot
.92154 .91761 Mdot
.83919 .42354 Mdot
.94114 .41569 Mdot
.94506 .42354 Mdot
.89801 .37648 Mdot
.43138 .14905 Mdot
.18826 .10983 Mdot
.34903 .13336 Mdot
.93722 .42746 Mdot
.91369 .41569 Mdot
.78821 .39609 Mdot
.78821 .45491 Mdot
.91761 .40001 Mdot
.61568 .43138 Mdot
.16473 .14905 Mdot
.15297 .14905 Mdot
.17257 .15297 Mdot
.3804 .35295 Mdot
.89017 .89017 Mdot
.47843 .43922 Mdot
.88232 .8784 Mdot
.73724 .72155 Mdot
.8039 .45098 Mdot
.94114 .4353 Mdot
.90193 .44314 Mdot
.90977 .4353 Mdot
.55686 .20787 Mdot
.22747 .10591 Mdot
.38432 .07454 Mdot
.93722 .41961 Mdot
.9333 .41961 Mdot
.92154 .45491 Mdot
.88232 .42746 Mdot
.93722 .38432 Mdot
.26276 .18434 Mdot
.16081 .14513 Mdot
.15689 .14513 Mdot
.16081 .1412 Mdot
.96075 .95291 Mdot
.89409 .89409 Mdot
.81566 .76076 Mdot
.89409 .8784 Mdot
.91369 .91761 Mdot
.75684 .4353 Mdot
.84703 .43138 Mdot
.76469 .43922 Mdot
.81566 .45491 Mdot
.65097 .33335 Mdot
.24316 .0667 Mdot
.90977 .44314 Mdot
.94898 .41569 Mdot
.93722 .41961 Mdot
.94114 .42746 Mdot
.9333 .40393 Mdot
.90193 .40001 Mdot
.20394 .20002 Mdot
.16865 .14905 Mdot
.14905 .13728 Mdot
.15689 .13336 Mdot
.88624 .88624 Mdot
.90585 .89017 Mdot
.56078 .54117 Mdot
.94898 .92938 Mdot
.76469 .69802 Mdot
.69018 .43922 Mdot
.74508 .58039 Mdot
.65097 .47059 Mdot
.65881 .43138 Mdot
.53725 .251 Mdot
.42746 .05494 Mdot
.95683 .44314 Mdot
.92938 .41177 Mdot
.92938 .41177 Mdot
.95291 .41569 Mdot
.93722 .38432 Mdot
.30198 .18434 Mdot
.16865 .15297 Mdot
.17257 .1412 Mdot
.14513 .12944 Mdot
.89801 .89017 Mdot
.89017 .89017 Mdot
.62352 .58039 Mdot
.88232 .8784 Mdot
.84311 .86272 Mdot
.73724 .60783 Mdot
.99996 .96467 Mdot
.91761 .85487 Mdot
.58431 .47451 Mdot
.65489 .40785 Mdot
.67057 .30198 Mdot
.9333 .44314 Mdot
.94898 .43922 Mdot
.94114 .41961 Mdot
.94898 .41177 Mdot
.94898 .40001 Mdot
.30982 .16473 Mdot
.18042 .16081 Mdot
.17257 .13728 Mdot
.14905 .13336 Mdot
.95291 .94506 Mdot
.89409 .89409 Mdot
.49412 .46275 Mdot
.88232 .8784 Mdot
.96467 .98428 Mdot
.99212 .96467 Mdot
.70587 .63136 Mdot
.67057 .45098 Mdot
.81566 .41177 Mdot
.89409 .41177 Mdot
.95683 .45098 Mdot
.96467 .44314 Mdot
.95683 .40001 Mdot
.79998 .46275 Mdot
.18434 .13336 Mdot
.14905 .14513 Mdot
.16865 .14513 Mdot
.24316 .22355 Mdot
.89409 .89017 Mdot
.89801 .89409 Mdot
.88624 .88624 Mdot
.39217 .41569 Mdot
.89017 .78821 Mdot
.76076 .49804 Mdot
.78037 .41569 Mdot
.84311 .40785 Mdot
.89017 .41961 Mdot
.92546 .41569 Mdot
.86272 .43138 Mdot
.21179 .11376 Mdot
.05102 .04317 Mdot
.07062 .04709 Mdot
.24316 .23924 Mdot
.90585 .89801 Mdot
.88624 .88624 Mdot
.87448 .87448 Mdot
.39217 .39217 Mdot
.99996 .95291 Mdot
.85095 .70194 Mdot
.70587 .45883 Mdot
.76076 .41961 Mdot
.8039 .38824 Mdot
.84311 .38432 Mdot
.53725 .30198 Mdot
.4902 .48235 Mdot
.42746 .41961 Mdot
.44706 .44706 Mdot
.56078 .58039 Mdot
.89409 .89017 Mdot
.88624 .89017 Mdot
.94506 .91761 Mdot
.99996 .96467 Mdot
.9333 .77645 Mdot
.83527 .60391 Mdot
.77253 .46667 Mdot
.72939 .39217 Mdot
.77253 .65489 Mdot
.91761 .90193 Mdot
.90585 .89801 Mdot
.21571 .251 Mdot
.31766 .33727 Mdot
.89801 .89409 Mdot
.88624 .89801 Mdot
.28237 .27061 Mdot
.99996 .94898 Mdot
.95683 .83527 Mdot
.81958 .67057 Mdot
.81958 .78429 Mdot
.87448 .86664 Mdot
.60391 .59607 Mdot
.27061 .32158 Mdot
.28629 .32943 Mdot
.79998 .80782 Mdot
.78429 .8039 Mdot
.82743 .8235 Mdot
.62352 .60391 Mdot
.25492 .26276 Mdot
.61176 .61568 Mdot
.53725 .58039 Mdot
.69018 .73332 Mdot
.87448 .8784 Mdot
.89801 .90977 Mdot
.95683 .96859 Mdot
.39609 .44314 Mdot
.23924 .28629 Mdot
.90977 .93722 Mdot
.62352 .66665 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0 0 1 1 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.92126e-05 0.00392126 3.92126e-05 0.00392126 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00ool0000Po`00007ooooo00000ol00000oomo0?ooO`3o0?ooOa`0oomo0Ol00001ooooo`00
00?o00000?ooO`3oogl0o`3ooglL0?ooO`7o00000Oooool00003o`00003oogl0oomo0?l0oomo703o
ogl1o`00007ooooo00000ol00000oomo0?ooO`3o0?ooOa`0oomo0Ol00001ooooo`0000?o00000?oo
O`3oogl0=P3oogl2oomo0><0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0=P3oogl2oomo00@0
oomo0_nP8?140?ooO`;oX23`U`3oogl1o`00007ooooo00000ol00000oomo0?ooO`0l0?ooO`;oX23`
A03oogl2oj0Pl9L0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0o`3ooglL0?ooO`7o00000Ooo
ool00003o`00003oogl0oomo05P0oomo0_nP8?310?ooO`7o00000Oooool00003o`00003oogl0oomo
03l0oomo0_nP8?0G0?ooO`;oX23``@3oogl1o`00007ooooo00000ol00000oomo0?ooO`0o0?ooO`;o
X23`fP3oogl1o`00007ooooo00000ol00000oomo0?ooO`0:0?ooO`;oX23`J`3oogl2oj0Pl:80oomo
0Ol00001ooooo`0000?o00000?ooO`3oogl02P3oogl2oj0Pl0@0oomo0_nP8?1U0?ooO`;oX23`XP3o
ogl1o`00007ooooo00000ol00000oomo0?ooO`0@0?ooO`;oX23`:03oogl2oj0Pl=l0oomo0Ol00001
ooooo`0000?o00000?ooO`3oogl02P3oogl4oj0Pl2X0oomo1?nP8?0_0?ooO`;oX23`2@3oogl2oj0P
l:<0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl02P3oogl4oj0Pl2X0oomo0_nP8?0F0?ooO`;o
X23`6@3oogl2oj0Pl0T0oomo0_nP8?2S0?ooO`7o00000Oooool00003o`00003oogl0oomo0500oomo
0_nP8?390?ooO`7o00000Oooool00003o`00003oogl0oomo01/0oomo0_ooO`3n0?ooO`7o00000Ooo
ool00003o`00003oogl0oomo01<0oomo0_nP8?050?ooO`?oogl0903oogl2oj0Pl1<0oomo0_nP8?06
0?ooO`;oX23`9@3oogl2oj0Pl9@0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl04`3oogl2oj0P
l0;oogl00`3oogl00oooO`3oX23`oj0Pl00>0?ooO`;oX23`4@3oogl2oomo00030?ooOonP8?3oX23`
01<0oomo0_nP8?060?ooO`CoX23`1@3oogl2oj0Pl1`0oomo0_nP8?2D0?ooO`7o00000Oooool00003
o`00003oogl0oomo0140oomo0_nP8?020?ooO`;oogl0103oogl2oj0Pl0h0oomo0_nP8?0A0?ooO`;o
ogl06P3oogl2oj0Pl0@0oomo0onP8?040?ooO`;oX23`00<0oomooj0Pl?nP8?00[`3oogl1o`00007o
oooo00000ol00000oomo0?ooO`0A0?ooO`;oX23`0P3oogl2oj0Pl0/0oomo0_ooO`0f0?ooO`;oX23`
1@3oogl2oj0Pl0L0oomo0_nP8?2_0?ooO`7o00000Oooool00003o`00003oogl0oomo01<0oomo1?nP
8?0;0?ooO`03oomo0?nP8?3oX23`00@0oomo0_nP8?0L0?ooO`;oogl00`3oogl2oj0Pl0X0oomo0_nP
8?040?ooO`;oX23`;@3oogl2oj0Pl8`0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl04`3oogl2
oj0Pl0h0oomo0_nP8?040?ooO`;oX23`2P3oogl2oj0Pl100oomo0_ooO`030?ooO`;oX23`2P3oogl2
oj0Pl0@0oomo0_nP8?0]0?ooO`;oX23`S03oogl1o`00007ooooo00000ol00000oomo0?ooO`0@0?oo
O`;oX23`1@3oogl2oj0Pl100oomo0_ooO`0:0?ooO`;oX23`<@3oogl2oj0Pl0H0oomo0_nP8?0M0?oo
O`;oX23`RP3oogl1o`00007ooooo00000ol00000oomo0?ooO`0@0?ooO`;oX23`103oogl3oj0Pl0T0
oomo0_ooO`000`3oogooX23`oj0Pl00?0?ooO`;oX23`203oogl2oj0Pl0@0oomo0_nP8?050?ooO`;o
ogl06@3oogl2oj0Pl0H0oomo0_nP8?0A0?ooO`;oX23`2P3oogl2oj0Pl8X0oomo0Ol00001ooooo`00
00?o00000?ooO`3oogl05P3oogl2oj0Pl0X0oomo0_ooO`000`3oogooX23`oj0Pl00?0?ooO`;oX23`
203oogl2oj0Pl0@0oomo0_nP8?050?ooO`;oogl0=03oogl2oj0Pl9H0oomo0Ol00001ooooo`0000?o
00000?ooO`3oogl05P3oogl4oj0Pl0030?ooOoooO`3oogl00080oomo0_nP8?020?ooO`;oX23`0`3o
ogl2oj0Pl1/0oomo0_nP8?060?ooO`03oomo0?nP8?3oX23`02H0oomo0_nP8?040?ooO`;oX23`W@3o
ogl1o`00007ooooo00000ol00000oomo0?ooO`0F0?ooO`CoX23`00D0oomooomo0?nP8?3oX23`0?oo
O`02oj0Pl0040?ooOoooO`3oX23`oj0Pl0<0oomo0_nP8?0@0?ooO`;oogl0103oogl2oj0Pl0<0oomo
0_nP8?060?ooO`03oomo0?nP8?3oX23`00P0oomo0_nP8?020?ooO`;oogl0603oogl2oj0Pl0@0oomo
0_nP8?2M0?ooO`7o00000Oooool00003o`00003oogl0oomo01L0oomo2?nP8?001P3oogooogl0oj0P
l?nP8?3oogl00?ooO`;oX23`00<0oomooomo0?ooO`00403oogl2oomo00040?ooOonP8?3oX23`0?oo
O`;oX23`5P3oogl2oj0Pl080oomo0_ooO`2m0?ooO`7o00000Oooool00003o`00003oogl0oomo01P0
oomo1onP8?001@3oogooX23`oj0Pl?nP8?00oomo00?oX23`00@0oomooomo0?ooO`00oomo0_nP8?05
0?ooO`;oX23`00?oogl00?ooO`3oogl01P3oogl2oj0Pl1`0oomo0_nP8?0L0?ooO`030000003oogl0
oomo09l0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl06@3oogl>oj0Pl0040?ooOoooO`3oogl0
0?ooO`;oX23`1@3oogl2oj0Pl004oomo003oogl0oomo0?ooO`;oX23`8@3oogl2oj0Pl1P0oomo2Ol0
002M0?ooO`7o00000Oooool00003o`00003oogl0oomo01T0oomo0_nP8?000oooO`3oX23`oj0Pl007
oj0Pl0?oogl00_nP8?030?ooO`CoX23`00<0oomooomo0?ooO`00103oogl2oj0Pl0030?ooOoooO`3o
ogl000Coogl0<@3oogl2oomo0003o`00001oool0Oooo00L0Oooo0P0000070?ooO`;oX23`TP3oogl1
o`00007ooooo00000ol00000oomo0?ooO`0L0?ooO`KoX23`00<0oomooj0Pl?nP8?000_nP8?001?oo
O`3oX23`oj0Pl?ooO`020?ooO`CoX23`00@0oomooomo0?ooO`3oogl00`3oogl2oomo00030?ooOonP
8?3oX23`00;oX23`0_ooO`030?ooO`;oX23`1P3oogl2oj0Pl0<0oomo0_ooO`0O0?ooO`;oogl0301o
ool3000000040?ooOonP8?3oX23`0?ooO`;oX23`TP3oogl1o`00007ooooo00000ol00000oomo0?oo
O`0M0?ooO`KoX23`00?oogl0oj0Pl?nP8?002_nP8?030?ooO`?oogl000<0oomooomo0?ooO`000P3o
ogl4oj0Pl0D0oomo0_nP8?060?ooO`;oX23`0`3oogl2oomo01@0oomo0_ooO`090?ooO`030000001o
ool0Oooo00h0Oooo00<00000oj0Pl?nP8?00U@3oogl1o`00007ooooo00000ol00000oomo0?ooO`0O
0?ooO`CoX23`0_ooO`09oj0Pl0H0oomo0_ooO`000`3oogooogl0oomo00040?ooO`;oX23`1@3oogl2
oomo0240oomo0_ooO`080?ooO`03o`00001oool0Oooo0100Oooo0_nP8?000`000000oomo0?ooO`2B
0?ooO`7o00000Oooool00003o`00003oogl0oomo01`0oomo0_nP8?030?ooO`KoX23`00<0oomooj0P
l?nP8?001OnP8?060?ooO`;oX23`00?oogl00?ooO`3oogl00`3oogl2oj0Pl0X0oomo0_nP8?0U0?oo
O`03o`00001oool0Oooo01@0Oooo00<000000?ooO`3oogl0T@3oogl1o`00007ooooo00000ol00000
oomo0?ooO`0L0?ooO`;oX23`0P3oogl@oj0Pl0050?ooOonP8?3oX23`oj0Pl?ooO`000_nP8?000ooo
O`00oomo0?ooO`030?ooO`;oX23`00<0oomooomo0?ooO`001`3oogl2oj0Pl1D0oomo0_nP8?0>0?oo
O`03o`00001oool0Oooo00l0Oooo0_nP8?001@1oooooogl0oomo001oool0000000P0oomo0_nP8?0H
0?ooO`;oX23`KP3oogl1o`00007ooooo00000ol00000oomo0?ooO`0P0?ooO`_oX23`0_ooO`03oj0P
l0030?ooOonP8?3oX23`00;oX23`0_ooO`090?ooO`;oogl07P3oogl2oj0Pl0P0oomo0_nP8?040?oo
O`030000001oool0Oooo00l0Oooo0_nP8?000`1oooooogl0oomo000207ooo`8000001P3oogl2oj0P
l1P0oomo0_nP8?1^0?ooO`7o00000Oooool00003o`00003oogl0oomo0240oomo1onP8?001OooO`3o
X23`oj0Pl?nP8?3oogl000SoX23`0_ooO`000`3oogooX23`oj0Pl00`0?ooO`;oX23`0`3oogl00`00
0000Oooo07ooo`02oomo01L0Oooo00<000000?ooO`3oogl0S@3oogl1o`00007ooooo00000ol00000
oomo0?ooO`0R0?ooOa;oX23`103oogl2oj0Pl0<0oomo0_nP8?0_0?ooO`040000001oool0Oooo07oo
o`;oogl0601oool2000008d0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl08P3oogl4oomo00_o
X23`00Coogl0oj0Pl?nP8?3oX23`0_ooO`02oj0Pl004oomo003oogl0oomo0?ooO`;oX23`4@3oogl2
oj0Pl0X0oomo1?nP8?0>0?ooO`03o`00001oool0Oooo00H0Oooo0_nP8?0E07ooo`030000003oogl0
oomo08X0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl08`3oogl2oomo00030?ooOonP8?3oX23`
00goX23`0_ooO`02oj0Pl004oomo003oogl0oomo0?ooO`;oogl04@3oogl2oj0Pl0X0oomo1?nP8?0>
0?ooO`030000001oool0Oooo00H0Oooo0_nP8?0=07ooo`;oX23`1`1oool00`000000oomo0?ooO`02
oomo08L0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0:03oogl<oj0Pl0030?ooOonP8?3oX23`
00;oogl000@0oomooj0Pl?nP8?00oomo0_nP8?0:0?ooO`;oogl03P3oogl2oj0Pl180oomo00<00000
07ooo`1oool05P1oool2oj0Pl0P0Oooo00@000000?ooOoooO`3oogl0403oogl2oomo07D0oomo0Ol0
0001ooooo`0000?o00000?ooO`3oogl0:03oogl2oj0Pl080oomo2?nP8?000`3oogooX23`oj0Pl003
0?ooO`;oX23`00<0oomooj0Pl?nP8?002P3oogl2oomo00h0oomo0_nP8?0B0?ooO`030000001oool0
Oooo0240Oooo00<000000?ooO`3oogl0403oogl2oomo07D0oomo0Ol00001ooooo`0000?o00000?oo
O`3oogl0:P3oogl7oj0Pl080oomo1onP8?000`3oogooX23`oj0Pl0020?ooO`?oX23`103oogl2oj0P
l0030?ooOonP8?3oX23`00H0oomo0_nP8?030?ooO`;oX23`5@3oogl00ol00000Oooo07ooo`0D07oo
o`;oogl0301oool00`000000oomo0?ooO`0A0?ooO`?oogl0LP3oogl1o`00007ooooo00000ol00000
oomo0?ooO`0Z0?ooO`OoX23`0_ooO`07oj0Pl0030?ooOonP8?3oX23`0080oomo0onP8?030?ooO`04
oomo0?nP8?3oX23`0?ooO`;oX23`00@0oomooj0Pl?nP8?3oX23`0P3oogl2oj0Pl080oomo0onP8?09
0?ooO`;oX23`2P3oogl00`000000Oooo07ooo`0D07ooo`;oogl02`1oool2oomo00030000003oogl0
oomo00<0oomo1?ooO`000`3oogooogl0oomo00060?ooO`?oogl02@3oogl2oomo06L0oomo0Ol00001
ooooo`0000?o00000?ooO`3oogl09P3oogl2oj0Pl080oomo0_nP8?001@3oogooX23`oj0Pl?nP8?00
oomo00;oX23`0oooO`04oj0Pl0?oogl0203oogl2oomo0080oomo0_nP8?00103oogooX23`oj0Pl?nP
8?030?ooO`;oX23`00<0oomooj0Pl?nP8?000`3oogl2oj0Pl0<0oomo0_ooO`02oj0Pl0X0oomo00<0
000007ooo`1oool00`1oool2oomo00L0Oooo0_ooO`0607ooo`?oogl0201oool2oj0Pl0;oogl000<0
Oooo0000000000000_ooO`000`3oogooogl0oomo0002oomo00040?ooOoooO`3oogl00?ooO`;oX23`
0`3oogl2oomo00X0oomo0_ooO`1W0?ooO`7o00000Oooool00003o`00003oogl0oomo02H0oomo0_nP
8?020?ooO`;oX23`0`3oogl6oj0Pl003oomo0?nP8?3oX23`00;oX23`1?ooO`070?ooO`;oogl00P3o
ogl2oomo00@0oomo0_ooO`00103oogooX23`oj0Pl03oogl2oj0Pl0030?ooOonP8?3oX23`00;oX23`
0`3oogl2oomo00`0oomo00<0000007ooo`1oool00`1oool2oomo00L0Oooo0_ooO`0707ooo`?oogl0
1`1oool2oj0Pl00307ooooooO`3oogl00080Oooo1?ooO`070?ooO`;oX23`N03oogl1o`00007ooooo
00000ol00000oomo0?ooO`0X0?ooO`;oX23`0`3oogl4oj0Pl0050?ooOonP8?3oX23`oj0Pl03oogl0
1onP8?000oooO`00oomo0?ooO`090?ooO`;oogl0103oogl2oomo00@0oomo1OnP8?020?ooO`;oogl0
303oogl2oomo00030?ooO`000000Oooo01L0Oooo0_ooO`0:07ooo`Coogl000@0Oooo00000?ooO`3o
ogl06P3oogl2oomo00`0oomo0_ooO`1G0?ooO`7o00000Oooool00003o`00003oogl0oomo02P0oomo
0_nP8?030?ooO`CoX23`00?oogl0oj0Pl?nP8?002OnP8?0:0?ooO`;oogl03@3oogl2oj0Pl0@0oomo
0_ooO`070?ooO`;oX23`0`3oogl2oomo00030?ooO`000000Oooo0080Oooo0_nP8?0307ooo`;oogl0
3P1oool2oomo000307ooooooO`3oogl000@0Oooo0_ooO`0307ooo`;oogl00P1oool00`000000oomo
0?ooO`0I0?ooO`?oogl02`3oogl2oomo05L0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0;`3o
ogl2oj0Pl0;oogl00onP8?020?ooO`;oX23`00<0oomooomo0?ooO`002P3oogl2oj0Pl0<0oomo0_nP
8?040?ooO`;oX23`4@3oogl2oj0Pl0030?ooOoooO`3oogl00080oomo00Co000007ooo`1oool0Oooo
1?nP8?0207ooo`;oogl01P1oool4oomo00@0Oooo1OooO`0407ooo`;oogl01P1oool2oomo00040000
003oogooogl0oomo01@0oomo0_ooO`00103oogooogl0oomo0?ooO`1T0?ooO`7o00000Oooool00003
o`00003oogl0oomo02l0oomo0_nP8?000`3oogooX23`oj0Pl002oj0Pl0050?ooOoooO`3oogl0oomo
003oogl01?ooO`080?ooO`;oX23`0`3oogl2oj0Pl0@0oomo0_nP8?0;0?ooO`;oogl00_nP8?020?oo
O`;oX23`00<0oomooomo0?ooO`000P3oogl01?l00000Oooo07ooo`1oool4oj0Pl080Oooo0_ooO`06
07ooo`Coogl01P1oool2oomo00<0Oooo0_ooO`0807ooo`;oogl000<0Oooooomo0?ooO`000oooO`02
0?ooO`;oogl000<0oomooomo0?ooO`002`3oogl2oomo00040?ooOoooO`3oogl0oomo00<0oomo0_oo
O`030?ooO`Coogl0F03oogl1o`00007ooooo00000ol00000oomo0?ooO`0b0?ooO`?oX23`0P3oogl2
oomo00@0oomo0_ooO`0P0?ooO`;oogl00_nP8?090?ooO`03o`00001oool0Oooo00L0Oooo0_ooO`0E
07ooo`;oogl02`1oool2oomo00030?ooOoooO`3oogl00080oomo0_ooO`000`3oogooogl0oomo000?
0?ooO`;oogl00`3oogl2oomo00<0oomo1?ooO`1H0?ooO`7o00000Oooool00003o`00003oogl0oomo
02T0oomo0_nP8?090?ooO`;oX23`00<0oomooj0Pl?nP8?000P3oogl2oomo00H0oomo00?oogl0oj0P
l?nP8?002@3oogl2oomo01@0oomo0_ooO`050?ooO`030000001oool0Oooo01<0Oooo0_nP8?0807oo
o`;oogl03@1oool00`000000oomo0?ooO`0C0?ooO`;oogl000<0oomooomo0?ooO`00103oogl2oomo
05l0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0:@3oogl2oj0Pl0P0oomo1_nP8?000`3oogoo
ogl0oomo0002oomo00?oX23`00?oogl00?ooOoooO`000_nP8?090?ooO`;oogl03`3oogl2oj0Pl0<0
oomo0_ooO`050?ooO`0300000?nP8?3oX23`00D0Oooo0_ooO`000`1oooooX23`oj0Pl00907ooo`;o
X23`101oool2oomo0080Oooo0_ooO`0707ooo`Coogl00`1oool00`000000oomo0?ooO`0B0?ooO`;o
ogl000<0oomooomo0?ooO`000_ooO`020?ooO`;oogl0G`3oogl1o`00007ooooo00000ol00000oomo
0?ooO`0c0?ooO`;oX23`00D0oomooj0Pl?nP8?3oX23`0?ooO`03oj0Pl003oomo0?nP8?3oX23`00?o
X23`00<0oomooj0Pl?nP8?00203oogl2oomo00;oX23`3P3oogl2oj0Pl0030?ooOoooO`3oogl000L0
oomo00<00000oj0Pl?nP8?001@1oool2oomo000307oooonP8?3oX23`00;oX23`0P1oool2oomo00P0
Oooo1?ooO`0407ooo`;oX23`101oool4oomo0080Oooo0_ooO`000`000000oomo0?ooO`0F0?ooO`;o
ogl00`3oogl4oomo05`0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0=P3oogl3oj0Pl0050?oo
OonP8?3oX23`oj0Pl?ooO`001onP8?080?ooO`;oX23`00?oogl0oj0Pl?nP8?003P3oogl4oj0Pl003
oomo0?nP8?3oX23`00<0oomo0_ooO`000ol00000Oooo07ooo`0:07ooo`;oX23`0P1oool2oomo00P0
Oooo1?ooO`0407ooo`;oX23`1@1oool00oooO`3oX23`oj0Pl00207ooo`;oogl000<0Oooo0000003o
ogl02@3oogl2oj0Pl100oomo1?ooO`1L0?ooO`7o00000Oooool00003o`00003oogl0oomo03H0oomo
0_nP8?000oooO`00oomooomo0005oomo00;oX23`00@0oomooj0Pl?nP8?3oX23`0P3oogl2oj0Pl0<0
oomo0_nP8?0C0?ooO`;oX23`00<0oomooj0Pl?nP8?000`3oogl2oomo0003o`00001oool0Oooo00X0
Oooo0_ooO`0L07ooo`;oX23`0P1oool2oj0Pl080Oooo00<000000?ooO`3oogl01`3oogl2oj0Pl0@0
oomo0_ooO`0=0?ooO`;oogl0F`3oogl1o`00007ooooo00000ol00000oomo0?ooO`0f0?ooO`;oX23`
00?oogl00?ooO`3oogl00_nP8?05oomo00040?ooOonP8?3oX23`oj0Pl080oomo0_nP8?060?ooO`;o
X23`0`3oogl2oj0Pl0h0oomo0_ooO`020?ooO`;oogl000<0oomoo`00001oool00P1oool2oj0Pl080
Oooo0_ooO`0407ooo`;oX23`4P1oool3oj0Pl0X0Oooo0_nP8?0307ooo`040000003oogooogl0oomo
00<0oomo0_ooO`02oj0Pl0@0oomo0_ooO`090?ooO`;oogl00P3oogl2oomo00<0oomo0oooO`1E0?oo
O`7o00000Oooool00003o`00003oogl0oomo03H0oomo0_nP8?030?ooO`goX23`203oogl2oj0Pl0<0
oomo0_nP8?0B0?ooO`;oogl000<0oomoo`00001oool00P1oool2oj0Pl080Oooo0_ooO`00101ooooo
ogl0oomo001oool2oj0Pl003oomo001oool0Oooo00l0Oooo0onP8?0407ooo`;oogl000<0Oooooomo
0?ooO`001`1oool00`00003oogl0oomo00030?ooO`;oogl00_nP8?000oooO`00oomo0?ooO`020?oo
O`;oogl0203oogl2oomo00L0oomo0oooO`1E0?ooO`7o00000Oooool00003o`00003oogl0oomo03H0
oomo0_nP8?030?ooO`[oX23`00@0oomooj0Pl?nP8?3oX23`8`3oogl00ol00000Oooo07ooo`0807oo
o`;oogl00P1oool2oomo00P0Oooo0_nP8?0707ooo`;oogl000<0Oooooj0Pl?nP8?000P1oool2oomo
000307ooooooO`3oogl000P0Oooo00?o00000?ooO`3oogl01@3oogl2oomo00@0oomo0oooO`030?oo
O`;oX23`1@3oogl2oomo01H0oomo0_ooO`140?ooO`7o00000Oooool00003o`00003oogl0oomo03h0
oomo1?nP8?000`3oogooX23`oj0Pl0020?ooO`;oX23`8`3oogl00ol00000Oooo07ooo`0F07ooo`;o
X23`1`1oool2oomo000307oooonP8?3oX23`0100Oooo00?o00000?ooO`3oogl02`3oogl2oomo00<0
oomo0_nP8?050?ooO`;oogl05P3oogl2oomo04@0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0
>03ooglBoj0Pl0T0oomo0_nP8?000`3oogooogl0oomo00040?ooO`;oogl01`3oogl2oj0Pl0D0oomo
00?o000007ooo`1oool0401oool2oomo00<0Oooo0_ooO`0?07ooo`;oogl000<0Oooooomo0?ooO`00
101oool2oomo00@0Oooo00Co00000?ooO`3oogl0oomo0oooO`040?ooO`Coogl0303oogl2oomo0080
oomo0_nP8?080?ooO`;oogl0C03oogl1o`00007ooooo00000ol00000oomo0?ooO`0h0?ooOa;oX23`
2@3oogl2oj0Pl0040?ooOoooO`3oogl00?ooO`;oX23`0oooO`050?ooO`CoX23`1P3oogl00ol00000
Oooo07ooo`0507ooo`;oogl0201oool2oomo00<0Oooo0_ooO`0?07ooo`;oogl000<0Oooooomo0?oo
O`00101oool2oomo00D0Oooo00?o00000?ooO`3oogl00oooO`040?ooO`Coogl02`3oogl3oomo0080
oomo0_nP8?070?ooO`?oogl01@3oogl2oomo04D0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0
>`3oogl3oj0Pl0030?ooOonP8?3oX23`0080oomo2OnP8?0=0?ooO`;oX23`00?oogl00?ooO`3oogl0
1@3oogl2oj0Pl004oomo003oogl0oomo0?ooO`?oX23`00<0oomoo`00001oool01P1oool2oomo00T0
Oooo0_nP8?0907ooo`;oogl0401oool2oomo00L0Oooo00?o00000?ooO`3oogl00`3oogl2oomo00l0
oomo1?ooO`0;0?ooO`;oogl01P3oogl2oomo04D0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0
>P3oogl4oj0Pl0050?ooOonP8?3oX23`oj0Pl03oogl00_ooO`02oj0Pl0;oogl01onP8?030?ooO`;o
X23`2`3oogl2oj0Pl080oomo0_ooO`030?ooO`GoX23`0`1oool2oj0Pl0d0Oooo0_nP8?0907ooo`?o
ogl01`1oool2oomo00H0Oooo0oooO`0407ooo`Coogl0103oogl00oooO`3oX23`oj0Pl003oomo00P0
oomo0_ooO`000`3oogooogl0oomo0002oomo00d0oomo0_ooO`090?ooO`;oogl0@03oogl1o`00007o
oooo00000ol00000oomo0?ooO`0j0?ooO`CoX23`00<0oomooj0Pl?nP8?000_nP8?001OooO`3oX23`
oj0Pl?nP8?00oomo00SoX23`0_ooO`000`3oogooX23`oj0Pl0090?ooO`;oogl01?nP8?080?ooO`;o
X23`0`1oool2oj0Pl00407ooooooO`3oX23`oj0Pl0P0Oooo0_nP8?0;07ooo`;oogl01`1oool2oomo
00;oX23`101oool2oj0Pl003oomo001oool0Oooo0080Oooo1?ooO`000ol0003oogl0oomo0004oj0P
l0?oogl000<0oomooomo0?ooO`000`3oogl4oomo00T0oomo0_ooO`070?ooO`;oogl02@3oogl2oomo
0400oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0@03oogl3oj0Pl0030?ooOonP8?3oX23`00Ko
X23`00D0oomooj0Pl?nP8?00oomooomo0002oj0Pl0/0oomo0_ooO`00103oogooogl0oj0Pl?nP8?09
0?ooO`03o`00001oool0Oooo0080Oooo0oooO`02oj0Pl0P0Oooo0_nP8?0507ooo`;oX23`3`1oool2
oj0Pl004oomo0?nP8?3oX23`07ooo`;oX23`2P1oool2oomo00;oX23`0P3oogl2oj0Pl080oomo0_oo
O`030?ooO`;oogl02`3oogl2oomo05@0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0@03oogl2
oj0Pl080oomo1onP8?001@3oogooX23`oj0Pl?nP8?00oomo00?oX23`3@3oogl2oj0Pl003oomo003o
ogl0oomo00H0oomo0_nP8?000ol00000Oooo07ooo`0207ooo`;oogl02P1oool2oj0Pl0@0Oooo0_oo
O`02oj0Pl0`0Oooo0_nP8?00101oooooogl0oomo0?ooO`02oj0Pl0@0Oooo0_ooO`0807ooo`03o`00
0?nP8?3oX23`0080oomo0_nP8?03oomo00D0oomo0oooO`000`3oogooogl0oomo000?0?ooO`Coogl0
203oogl2oomo00030?ooOoooO`3oogl00140oomo0_nP8?0Y0?ooO`7o00000Oooool00003o`00003o
ogl0oomo03X0oomo0_nP8?080?ooO`;oogl01OnP8?000`3oogooX23`oj0Pl004oj0Pl0h0oomo0_nP
8?03oomo00H0oomo0_nP8?000ol00000Oooo07ooo`0=07ooo`?oX23`101oool2oomo00;oX23`00<0
Oooooomo0?ooO`002@1oool4oj0Pl0P0Oooo0_ooO`0707ooo`;oogl00_nP8?020?ooO`;oX23`1?oo
O`040?ooO`?oogl000@0oomooomo0?ooO`3oogl02`3oogl2oomo00040?ooOoooO`3oX23`oj0Pl0Co
ogl01@3oogl5oomo00d0oomo0_nP8?020?ooO`;oX23`:@3oogl1o`00007ooooo00000ol00000oomo
0?ooO`0j0?ooO`;oX23`203oogl2oomo00030?ooOonP8?3oX23`00;oogl000<0oomooj0Pl?nP8?00
0_nP8?02oomo0140oomo0_ooO`080?ooO`03o`00001oool0Oooo00d0Oooo0_nP8?0:07ooo`;oogl0
2`1oool2oj0Pl140Oooo0_ooO`000`1ooooo00000?ooO`040?ooO`?oogl0103oogl2oomo00<0oomo
0_ooO`0;0?ooO`;oogl00P3oogl2oj0Pl0Coogl01@3oogl5oomo00d0oomo0_nP8?0]0?ooO`7o0000
0Oooool00003o`00003oogl0oomo04H0oomo0_nP8?000`3oogooogl0oomo00030?ooO`03oomo0?nP
8?3oX23`00@0oomo0_nP8?090?ooO`;oogl02`3oogl2oomo0100Oooo0_nP8?0307ooo`;oX23`00?o
ogl007ooo`1oool00P1oool2oomo000307ooooooO`3oogl000@0Oooo0_ooO`0;07ooo`;oogl01@1o
ool2oomo000307ooooooO`3oogl000P0oomo0_ooO`040?ooO`;oogl00P3oogl2oomo0080oomo0_nP
8?030?ooO`;oogl02@3oogl2oomo00T0oomo0_ooO`0@0?ooO`?oX23`:03oogl1o`00007ooooo0000
0ol00000oomo0?ooO`160?ooO`;oX23`00@0oomooomo0?nP8?3oX23`0P3oogl00oooO`3oX23`oj0P
l0040?ooO`;oX23`103oogl2oomo00<0oomo0_ooO`090?ooO`?oogl00_nP8?0<07ooo`?oogl00_nP
8?0307ooo`;oX23`00?oogl007ooo`1oool00P1oool2oomo000307ooooooO`3oogl000@0Oooo0_oo
O`0707ooo`;oogl00P1oool2oomo00D0Oooo0_ooO`00101oooooogl0oomo0?l000040?ooO`03oomo
0?nP8?3oX23`00;oogl0103oogl3oomo00030?ooOoooO`3oogl00080oomo0_nP8?030?ooO`;oogl0
0P3oogl2oomo00<0oomo1?ooO`020?ooO`;oogl00`3oogl4oomo0100oomo0onP8?0X0?ooO`7o0000
0Oooool00003o`00003oogl0oomo0440oomo0_nP8?020?ooO`;oX23`0`3oogl2oj0Pl0<0oomo0_oo
O`060?ooO`;oogl00P3oogl2oomo00d0oomo0oooO`000ol0003oX23`oj0Pl00<07ooo`;oX23`0_oo
O`0407ooo`;oX23`3P1oool2oomo0080Oooo0_nP8?0307ooo`;oogl02`1oool3oomo000307ooool0
0000oomo0080oomo00?oogl0oj0Pl?nP8?001`3oogl2oomo00<0oomo0_ooO`000`3oogooX23`oj0P
l0060?ooO`;oogl000<0oomooomo0?ooO`000_ooO`040?ooO`;oogl00`3oogl2oomo00h0oomo0_oo
O`000`3oogooogl0oomo00030?ooO`;oX23`9@3oogl1o`00007ooooo00000ol00000oomo0?ooO`11
0?ooO`;oX23`0P3oogl3oj0Pl003oomo0?nP8?3oX23`00?oX23`00@0oomooomo0?ooO`00oomo0_oo
O`020?ooO`;oX23`00?oogl00?ooO`3oogl0103oogl2oomo00<0oomo0_ooO`040?ooO`;oogl000<0
oomoo`00001oool02P1oool2oomo00?oX23`1P1oool2oj0Pl0;oogl00`1oool2oj0Pl0L0Oooo0_oo
O`0207ooo`;oX23`1`1oool2oomo00L0Oooo0oooO`0207ooo`03o`00003oogl0oomo00@0oomo0_oo
O`090?ooO`?oogl00_nP8?000`3oogooogl0oomo00060?ooO`;oogl00_nP8?040?ooO`;oogl000<0
oomooomo0?ooO`000`3oogl2oomo00040?ooOonP8?3oX23`0?ooO`Googl000D0oomooomo0?ooO`3o
ogl00?ooO`02oj0Pl0;oogl000<0oomooj0Pl?nP8?009@3oogl1o`00007ooooo00000ol00000oomo
0?ooO`160?ooO`;oX23`00?oogl0oj0Pl?nP8?001?nP8?02oomo00030?ooOoooO`3oogl00080oomo
0_nP8?070?ooO`;oogl00`3oogl2oomo0080oomo0_nP8?030?ooO`04o`00001oool0Oooo07ooo`;o
ogl01P1oool2oomo00;oX23`1`1oool4oomo00<0Oooo0_nP8?0707ooo`;oX23`2`1oool2oomo00D0
Oooo0_ooO`000`1oooooogl0oomo000307ooo`03o`00003oogl0oomo00<0oomo0_ooO`040?ooO`;o
ogl01@3oogl6oomo00<0oomo00?oogl0oj0Pl?nP8?000P3oogl2oj0Pl0<0oomo0_nP8?001OooO`3o
X23`oj0Pl?ooO`00oomo00Coogl000@0oomooj0Pl?nP8?00oomo2?ooO`020?ooO`;oX23`0_ooO`0X
0?ooO`7o00000Oooool00003o`00003oogl0oomo04d0oomo1?nP8?0G0?ooO`;oX23`0`3oogl01?l0
0000Oooo07ooo`1oool2oomo000307ooooooO`3oogl000`0Oooo1?ooO`0>07ooo`;oX23`00<0Oooo
oj0Pl?nP8?00201oool4oomo00<0Oooo0_ooO`0707ooo`03o`00003oogl0oomo00P0oomo0_ooO`05
0?ooO`Coogl000<0oomooj0Pl?nP8?000P3oogl00oooO`3oX23`oj0Pl0070?ooO`;oX23`00?oogl0
oj0Pl?nP8?000P3oogl2oomo00H0oomo0_nP8?000oooO`3oX23`oj0Pl002oomo00<0oomo0_ooO`02
0?ooO`CoX23`903oogl1o`00007ooooo00000ol00000oomo0?ooO`1>0?ooO`04oomo0?nP8?3oX23`
0?ooO`;oogl000<0oomooj0Pl?nP8?000`3oogl2oomo0140oomo00?o000007ooo`1oool0101oool2
oomo00D0Oooo0_ooO`0507ooo`;oogl04@1oool2oomo00;oX23`1`1oool5oomo00H0Oooo0_ooO`05
07ooo`03oomo0?nP8?3oX23`00;oogl00P3oogl2oomo00X0oomo0_ooO`000`3oogooX23`oj0Pl005
0?ooO`;oogl01@3oogl3oomo00D0oomo0_ooO`030?ooO`;oogl00_nP8?000oooO`3oX23`oj0Pl002
0?ooO`;oogl000<0oomooomo0?ooO`000_ooO`04oj0Pl080oomo0_nP8?0P0?ooO`7o00000Oooool0
0003o`00003oogl0oomo04L0oomo0_nP8?000`3oogooX23`oj0Pl0030?ooO`;oX23`00@0oomooj0P
l?nP8?00oomo0_nP8?030?ooO`;oogl03`3oogl2oomo0003o`00001oool0Oooo00/0Oooo0_ooO`05
07ooo`;oogl0301oool2oomo00<0Oooo1?ooO`0207ooo`;oX23`00<0Oooooomo0?ooO`000_ooO`00
0`1oooooogl0oomo000307ooo`;oX23`00<0Oooooomo0?ooO`000P1oool2oj0Pl00407ooooooO`3o
X23`oj0Pl0;oogl00P3oogl4oomo00?oX23`0P3oogl2oomo0080oomo0_ooO`030?ooO`;oogl00P3o
ogl3oomo00@0oomo0_ooO`060?ooO`Coogl000<0oomooomo0?ooO`001_ooO`00103oogooogl0oomo
003oogl2oj0Pl0;oogl00_nP8?030?ooO`CoX23`7`3oogl1o`00007ooooo00000ol00000oomo0?oo
O`170?ooO`;oX23`00<0oomooj0Pl?nP8?000`3oogl2oj0Pl0030?ooOonP8?3oX23`01L0oomo0_oo
O`000`3oogoo000007ooo`0P07ooo`;oogl02@1oool2oj0Pl00307ooooooO`3oogl000P0Oooo0_nP
8?0507ooo`;oX23`0`1oool00ol00000oomo0?ooO`040?ooO`;oogl00onP8?020?ooO`;oogl00P3o
ogl2oomo00<0oomo0_ooO`030?ooO`;oogl03@3oogl3oomo00030?ooOoooO`3oogl000Koogl0103o
ogl2oj0Pl004oomo003oogooX23`oj0Pl0<0oomo1?nP8?0O0?ooO`7o00000Oooool00003o`00003o
ogl0oomo0400oomo0_nP8?060?ooO`?oX23`1P3oogl4oj0Pl080oomo0_nP8?030?ooO`;oogl01@3o
ogl2oj0Pl0T0oomo00?o000007ooo`1oool03P1oool2oj0Pl0@0Oooo0_nP8?000`1oooooX23`oj0P
l00=07ooo`;oogl000<0Oooooomo0?ooO`003@1oool4oj0Pl0D0Oooo0_ooO`000`1ooooo00000?oo
O`020?ooO`;oogl000<0oomooj0Pl?nP8?001@3oogl2oj0Pl0;oogl000<0oomooomo0?ooO`001P3o
ogl2oomo00<0oomo0_ooO`030?ooO`;oogl00`3oogl4oomo0080oomo0_ooO`04oj0Pl0;oogl000<0
oomooj0Pl?nP8?00103oogl2oj0Pl0<0oomo1?nP8?0N0?ooO`7o00000Oooool00003o`00003oogl0
oomo0400oomo0_nP8?060?ooO`?oX23`1P3oogl4oj0Pl080oomo0_nP8?030?ooO`;oogl00_nP8?03
0?ooO`;oX23`103oogl2oomo0080oomo0_nP8?0@07ooo`;oX23`101oool2oj0Pl00307oooonP8?3o
X23`00@0Oooo0_ooO`0707ooo`;oogl000D0Oooooomo0?ooO`3oogl007ooo`02oj0Pl00407oooonP
8?3oX23`oj0Pl0<0Oooo0_ooO`04oj0Pl0Coogl000<0Oooooomo0?ooO`000P1oool00ol00000oomo
0?ooO`02oomo00030?ooOonP8?3oX23`00D0oomo0_nP8?02oomo00030?ooOoooO`3oogl000D0oomo
0_nP8?02oomo0080oomo0_ooO`030?ooO`;oogl00`3oogl4oomo0080oomo0_ooO`04oj0Pl003oomo
0?nP8?3oX23`00;oX23`00Coogl00?ooO`3oogl0oomo0onP8?020?ooO`CoX23`7P3oogl1o`00007o
oooo00000ol00000oomo0?ooO`1?0?ooO`;oX23`0P3oogl2oj0Pl0<0oomo0_nP8?040?ooO`;oX23`
203oogl3oomo0080oomo0_nP8?0407ooo`;oogl02P1oool2oj0Pl0d0Oooo0_ooO`0;07ooo`;oogl0
00@0Oooooj0Pl?nP8?3oogl00onP8?000oooO`00Oooo07ooo`02oomo00@0Oooo1?ooO`0307ooo`?o
ogl03@3oogl2oomo00T0oomo0_nP8?02oomo00<0oomo0_nP8?080?ooO`Coogl00`3oogl2oj0Pl080
oomo00Coogl0oj0Pl?nP8?00oomo0_ooO`040?ooO`CoX23`8P3oogl1o`00007ooooo00000ol00000
oomo0?ooO`1?0?ooO`;oX23`0P3oogl2oj0Pl0<0oomo0_nP8?0;0?ooO`;oX23`00<0oomooomo0?oo
O`000`3oogl2oomo00@0Oooo0_ooO`0:07ooo`;oX23`7P1oool3oomo000307ooooooO`3oogl000X0
Oooo0_ooO`0307ooo`?oogl000?o0000oomo0?ooO`000oooO`060?ooO`;oX23`0_ooO`000`3oogoo
ogl0oomo00050?ooO`;oX23`0_ooO`020?ooO`03oomo0?nP8?3oX23`00H0oomo1_ooO`030?ooO`?o
ogl000<0oomooomo0?ooO`001@3oogl7oj0Pl280oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0
D`3oogl2oj0Pl0T0oomo1?nP8?030?ooO`;oX23`1@3oogl2oomo0003o`00001oool0Oooo00`0Oooo
0_nP8?0607ooo`;oX23`0P1oool2oomo00/0Oooo0_nP8?0707ooo`?oogl000@0Oooooj0Pl?nP8?00
Oooo0_ooO`0507ooo`Coogl01`1oool4oomo00;oX23`1@3oogl2oj0Pl0;oogl000<0oomooj0Pl?nP
8?001@3oogl2oj0Pl0;oogl00P3oogl3oomo00D0oomo0_nP8?08oomo00;oX23`00?oogl0oj0Pl?nP
8?000_nP8?040?ooO`GoX23`1P3oogl2oj0Pl1`0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0
D`3oogl2oj0Pl0D0oomo0_nP8?020?ooO`CoX23`2P3oogl4oomo00d0Oooo0_nP8?0307ooo`;oX23`
00<0Oooooj0Pl?nP8?000P1oool2oomo00T0Oooo1?nP8?0807ooo`;oogl000@0Oooooj0Pl?nP8?00
Oooo0_ooO`0507ooo`Coogl0201oool00ol00000oomo0?ooO`02oj0Pl0D0oomo0_ooO`030?ooO`;o
X23`2@3oogl2oj0Pl0?oogl000<0oomooomo0?ooO`000P3oogl2oj0Pl0<0oomo00?oogl0oj0Pl?nP
8?000_ooO`02oj0Pl003oomo0?nP8?3oX23`00;oX23`0`3oogl2oomo00030?ooOonP8?3oX23`00<0
oomo0onP8?000`3oogooX23`oj0Pl00L0?ooO`7o00000Oooool00003o`00003oogl0oomo04d0oomo
0_nP8?0;0?ooO`;oX23`103oogl2oomo00`0oomo0_ooO`0307ooo`;oogl03@1oool2oj0Pl0d0Oooo
0_ooO`000`1oooooX23`oj0Pl003oj0Pl0Coogl00`1oool2oomo01L0Oooo00?o00000?ooOoooO`00
0oooO`060?ooO`;oogl01P3oogl2oomo00@0oomo0_nP8?02oomo0080oomo0_ooO`030?ooO`;oX23`
00<0oomooomo0?nP8?000_nP8?020?ooO`Coogl000<0oomooomo0?ooO`000`3oogl2oj0Pl0030?oo
OonP8?3oX23`00<0oomo0onP8?00103oogooX23`oj0Pl?nP8?0K0?ooO`7o00000Oooool00003o`00
003oogl0oomo04d0oomo0_nP8?080?ooO`;oX23`0`3oogl2oj0Pl140oomo00?o000007ooo`1oool0
0_nP8?000oooO`00Oooo07ooo`0307ooo`;oogl05@1oool2oomo00<0Oooo0onP8?04oomo01<0Oooo
0_ooO`0807ooo`05o`000?ooO`3oX23`oj0Pl?ooO`00103oogl4oomo00<0oomo0_ooO`000`3oogoo
ogl0oomo00040?ooO`;oX23`00@0oomooomo0?ooO`00oomo0_ooO`020?ooO`OoX23`00<0oomooomo
0?ooO`00103oogl2oomo00@0oomo0_nP8?0:0?ooO`GoX23`6@3oogl1o`00007ooooo00000ol00000
oomo0?ooO`1G0?ooO`;oX23`0`3oogl2oj0Pl140oomo00?o000007ooo`1oool00_nP8?0607ooo`;o
ogl06P1oool2oj0Pl0;oogl05P1oool2oomo00T0Oooo00?o0000oj0Pl?nP8?001@3oogl3oomo00@0
oomo0_ooO`000`3oogooogl0oomo00070?ooO`;oogl000<0oomooomo0?ooO`000P3oogl2oj0Pl003
oomo0?nP8?3oX23`00<0oomo0_ooO`040?ooO`;oogl04`3oogl2oj0Pl1T0oomo0Ol00001ooooo`00
00?o00000?ooO`3oogl0H03oogl2oj0Pl0d0oomo00?o000007ooo`1oool0201oool2oomo00<0Oooo
0_ooO`0>07ooo`;oX23`1P1oool2oj0Pl140Oooo0oooO`0;07ooo`?oX23`00Co00000?ooOoooO`3o
ogl0103oogl00oooO`3oX23`oj0Pl00=0?ooO`?oX23`00?oogl0oj0Pl?nP8?001@3oogl2oomo00P0
oomo0_ooO`0;0?ooO`;oX23`0P3oogl2oj0Pl200oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0
B@3oogl2oj0Pl0/0oomo0_nP8?060?ooO`CoX23`1@3oogl2oj0Pl0H0oomo00?o000007ooo`1oool0
201oool2oomo000307ooooooO`3oogl000;oogl02P1oool2oomo0080Oooo0_nP8?000oooO`00Oooo
07ooo`0307ooo`;oX23`2P1oool2oomo00D0Oooo0oooO`0307ooo`;oogl000<0Oooooomo0?ooO`00
0`1oool3oj0Pl00407ooool0003oogl0oomo00@0oomo00?oogl0oj0Pl?nP8?002@3oogl4oomo00?o
X23`00?oogl0oj0Pl?nP8?001@3oogl7oomo00030?ooOoooO`3oogl000;oogl01@3oogl2oj0Pl0@0
oomo0_nP8?020?ooO`;oX23`803oogl1o`00007ooooo00000ol00000oomo0?ooO`190?ooO`;oX23`
2`3oogl2oj0Pl0H0oomo0onP8?001?ooO`3oX23`oj0Pl03oogl2oomo00CoX23`1@3oogl00ol00000
Oooo07ooo`0:07ooo`;oogl0301oool2oomo00;oX23`0oooO`0707ooo`;oX23`1@1oool2oomo00;o
X23`00?oogl007ooo`1oool0101oool2oomo00<0Oooo0_ooO`000`1oooooogl0oomo000507ooo`;o
X23`00<0Ooooo`00003oogl00_ooO`030?ooO`;oX23`2@3oogl4oomo00d0oomo1OooO`000`3oogoo
ogl0oomo0002oj0Pl0;oogl00`3oogl3oj0Pl080oomo0onP8?00103oogooX23`oj0Pl?nP8?0P0?oo
O`7o00000Oooool00003o`00003oogl0oomo04h0oomo0_nP8?0?0?ooO`03oomo0?nP8?3oX23`00;o
X23`00<0oomooomo0?ooO`001?nP8?050?ooO`;oX23`5@1oool01?ooO`3oX23`oj0Pl01oool4oj0P
l0;oogl00`1oool2oj0Pl0<0Oooo0_nP8?0507ooo`CoX23`3`1oool01?ooO`3oX23`oj0Pl?ooO`03
07ooo`;oX23`0P1oool01?l0003oogl0oomo003oogl2oomo00;oX23`6@3oogl2oj0Pl0L0oomo0_nP
8?02oomo00@0oomo0_nP8?020?ooO`;oX23`0P3oogl3oj0Pl0<0oomo0_nP8?030?ooO`;oX23`5P3o
ogl1o`00007ooooo00000ol00000oomo0?ooO`1>0?ooO`;oX23`3P3oogl5oj0Pl0@0oomo0_ooO`07
0?ooO`;oX23`5@1oool01?ooO`3oX23`oj0Pl?ooO`02oj0Pl0L0Oooo0_nP8?0207ooo`;oX23`1P1o
ool2oj0Pl0;oogl0401oool4oj0Pl0L0Oooo00Go00000?ooOonP8?3oX23`oomo000:0?ooO`;oX23`
00<0oomooomo0?ooO`001P3oogl2oomo0080oomo0_ooO`02oj0Pl1@0oomo0_nP8?020?ooO`;oX23`
0P3oogl5oj0Pl0040?ooOonP8?3oX23`oj0Pl1D0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0
E`3oogl2oj0Pl080oomo0_nP8?000`3oogooX23`oj0Pl002oj0Pl0<0oomo1?nP8?070?ooO`03o`00
001oool0Oooo00/0Oooo0_ooO`0207ooo`;oogl000<0Oooooomo0?ooO`000P1oool2oomo00`0Oooo
00?oogl0oj0Pl?nP8?000_nP8?0207ooo`;oogl00P1oool00oooO`3oX23`oj0Pl00@07ooo`03oomo
0?nP8?3oX23`00<0Oooo0_ooO`0307ooo`03o`000?nP8?3oX23`0080oomo0_nP8?070?ooO`;oX23`
0oooO`000`3oogooX23`oj0Pl0020?ooO`;oX23`0_ooO`000`3oogooogl0oomo000@0?ooO`;oX23`
103oogl2oj0Pl0@0oomo1?nP8?00103oogooX23`oj0Pl03oogl3oj0Pl1D0oomo0Ol00001ooooo`00
00?o00000?ooO`3oogl0E`3oogl2oj0Pl080oomo0_nP8?020?ooO`?oX23`00<0oomooomo0?ooO`00
1OnP8?020?ooO`;oX23`00?oogl00?ooOol000001P1oool2oomo00D0Oooo0_ooO`0207ooo`;oogl0
00<0Oooooomo0?ooO`000P1oool2oomo00@0Oooo0_ooO`0607ooo`;oogl000<0Oooooj0Pl?nP8?00
0P1oool00oooO`3oX23`oj0Pl002oomo00;oX23`201oool2oomo00`0Oooo0_ooO`0307ooo`03o`00
003oogl0oomo00;oogl00_nP8?000`3oogooX23`oj0Pl0050?ooO`;oogl00P3oogl00oooO`3oX23`
oj0Pl0020?ooO`;oX23`0_ooO`0=0?ooO`;oX23`103oogl3oj0Pl080oomo0_nP8?050?ooO`;oX23`
1P3oogl2oj0Pl0<0oomo0_nP8?0A0?ooO`7o00000Oooool00003o`00003oogl0oomo0640oomo0_nP
8?03oomo0080oomo0_nP8?020?ooO`;oX23`00Coogl00?ooO`3oogoo0000101oool2oj0Pl003oomo
001oool0Oooo00<0Oooo0_ooO`0=07ooo`;oogl00_nP8?0507ooo`?oogl000<0Oooooomo0?ooO`00
0`1oool4oj0Pl00307oooonP8?3oX23`00L0Oooo0_ooO`0207ooo`?oX23`1P1oool2oj0Pl0D0Oooo
00?o00000?ooOoooO`001?ooO`02oj0Pl0D0oomo0_ooO`020?ooO`?oogl0103oogl2oomo00@0oomo
0_nP8?070?ooO`;oX23`1@3oogl2oj0Pl080oomo0_nP8?080?ooO`;oX23`0`3oogl2oj0Pl080oomo
0onP8?0A0?ooO`7o00000Oooool00003o`00003oogl0oomo0640oomo0_nP8?0>0?ooO`03o`00001o
ool0Oooo0080Oooo0_nP8?0607ooo`;oogl03@1oool2oomo00;oX23`1@1oool2oomo00T0Oooo0_nP
8?000`1oooooX23`oj0Pl00;07ooo`?oX23`1P1oool2oj0Pl0H0Oooo00Co00000?ooO`3oogl0oomo
0_ooO`0B0?ooO`;oogl0103oogl2oj0Pl1`0oomo0_nP8?070?ooO`;oX23`4P3oogl1o`00007ooooo
00000ol00000oomo0?ooO`1Q0?ooO`?oX23`0`3oogl2oomo00L0oomo0_ooO`0207ooo`;oogl0=01o
ool2oj0Pl0<0Oooo0_nP8?0207ooo`;oogl03P1oool00ol00000oomo0?ooO`0>0?ooO`;oogl05P3o
ogl2oomo00/0oomo0_nP8?030?ooO`;oX23`203oogl2oj0Pl140oomo0Ol00001ooooo`0000?o0000
0?ooO`3oogl0H@3oogl5oj0Pl0030?ooOoooO`3oogl000;oX23`1@3oogl2oomo0080Oooo00?oogl0
oj0Pl?nP8?000_nP8?0507ooo`;oogl07@1oool6oomo00L0Oooo0_nP8?0307ooo`;oX23`0P1oool2
oomo00@0Oooo0_ooO`0907ooo`03o`00003oogl0oomo00d0oomo0_ooO`090?ooO`;oX23`103oogl2
oj0Pl0D0oomo0_ooO`02oj0Pl080oomo0_nP8?050?ooO`;oX23`0`3oogl2oj0Pl0D0oomo1OnP8?0A
0?ooO`7o00000Oooool00003o`00003oogl0oomo0680oomo1?nP8?030?ooO`?oX23`0P3oogl2oomo
00030?ooOol00000Oooo0080Oooo1?nP8?000`1oooooogl0oomo000207ooo`;oogl05@1oool2oomo
00H0Oooo1_ooO`0507ooo`;oX23`2`1oool2oj0Pl080Oooo0_ooO`0607ooo`;oogl00P1oool00ol0
0000oomo0?ooO`050?ooO`;oogl0403oogl2oj0Pl0@0oomo1?nP8?000`3oogooogl0oomo00020?oo
O`;oX23`0P3oogl2oj0Pl0P0oomo0_nP8?020?ooO`;oX23`0P3oogl6oj0Pl140oomo0Ol00001oooo
o`0000?o00000?ooO`3oogl0I03oogl2oj0Pl0<0oomo1OnP8?02oomo0080oomo00?o000007ooo`1o
ool00_ooO`0307ooo`;oogl05P1oool2oj0Pl00307ooooooO`3oogl000P0Oooo0_nP8?02oomo00D0
Oooo0_nP8?0;07ooo`;oX23`2P1oool2oomo0080Oooo00?o00000?ooO`3oogl01@3oogl2oomo00D0
oomo0_ooO`040?ooO`;oogl02`3oogl2oj0Pl0030?ooOoooO`3oogl00100oomo0onP8?000`3oogoo
X23`oj0Pl0020?ooO`;oX23`00@0oomooj0Pl?nP8?3oX23`0P3oogl3oj0Pl0`0oomo0Ol00001oooo
o`0000?o00000?ooO`3oogl0HP3oogl2oomo00D0oomo0_nP8?000oooO`3oX23`oj0Pl0040?ooO`03
o`00001oool0Oooo00D0Oooo0_nP8?0907ooo`;oogl02`1oool2oj0Pl0<0Oooo1?nP8?001?ooO`00
Oooo07ooooooO`02oj0Pl0<0Oooo0_ooO`0;07ooo`Coogl04@1oool01?l0003oogl0oomo0?ooO`02
oj0Pl0;oogl01@3oogl2oj0Pl0?oogl000@0oomooomo0?ooO`3oogl03@3oogl4oj0Pl100oomo0_nP
8?000`3oogooX23`oj0Pl008oj0Pl080oomo0onP8?0<0?ooO`7o00000Oooool00003o`00003oogl0
oomo0680oomo0_ooO`02oj0Pl0@0oomo0_ooO`000`3oogooX23`oj0Pl0020?ooO`?oogl01P1oool2
oj0Pl0T0Oooo0_ooO`0607ooo`;oX23`201oool4oj0Pl003oomo001oool0Oooo00;oogl0101oool2
oomo00L0Oooo0_nP8?0207ooo`Coogl00_nP8?0@07ooo`?oogl00_nP8?02oomo00D0oomo0_nP8?00
103oogooogl0oomo003oogl2oomo00/0oomo0_ooO`000`3oogooX23`oj0Pl003oj0Pl0/0oomo0_nP
8?000`3oogooX23`oj0Pl0020?ooO`SoX23`103oogl2oj0Pl0d0oomo0Ol00001ooooo`0000?o0000
0?ooO`3oogl0F`3oogl2oomo00L0oomo0onP8?050?ooO`03oomo0?nP8?3oX23`0080oomo0_nP8?02
oomo00@0Oooo0_ooO`0B07ooo`;oX23`1`1oool2oj0Pl0X0Oooo0_ooO`0907ooo`;oX23`1P1oool2
oj0Pl0X0Oooo0onP8?0307ooo`?oogl00P3oogl3oj0Pl0@0oomo1?nP8?0?0?ooO`;oogl0103oogl2
oj0Pl080oomo0_nP8?02oomo00030?ooOonP8?3oX23`00CoX23`00D0oomooj0Pl?nP8?3oX23`0?oo
O`09oj0Pl0<0oomo0_nP8?0=0?ooO`7o00000Oooool00003o`00003oogl0oomo05/0oomo0_ooO`08
0?ooO`;oX23`1@3oogl2oomo00<0oomo1?nP8?0407ooo`;oogl06`1oool2oj0Pl00307ooooooO`3o
ogl000L0Oooo0_ooO`0207ooo`03oomo0?nP8?3oX23`01@0Oooo0_ooO`0207ooo`?oX23`101oool2
oomo0080oomo0onP8?040?ooO`CoX23`303oogl4oj0Pl080oomo0onP8?020?ooO`CoX23`0_ooO`00
0`3oogooX23`oj0Pl004oj0Pl080oomo0onP8?020?ooO`SoX23`4@3oogl1o`00007ooooo00000ol0
0000oomo0?ooO`1U0?ooO`;oogl02P3oogl2oomo00;oX23`901oool2oomo00/0Oooo00?oogl0oj0P
l?nP8?00501oool2oomo00X0Oooo00?o00000?ooO`3oogl05`3oogl4oj0Pl080oomo0onP8?020?oo
O`;oX23`3@3oogl3oj0Pl080oomo2?nP8?0A0?ooO`7o00000Oooool00003o`00003oogl0oomo06h0
oomo0_nP8?030?ooO`03o`00001oool0Oooo00D0Oooo0_ooO`0:07ooo`;oogl01P1oool3oomo00D0
Oooo0_ooO`0507ooo`;oogl00P1oool4oomo00d0Oooo1OnP8?0;07ooo`;oogl000<0Oooooj0Pl?nP
8?000P1oool00ol00000oomo0?ooO`020?ooO`;oogl03`3oogl2oj0Pl0<0oomo0_ooO`020?ooO`?o
X23`3@3oogl2oj0Pl0L0oomo0_nP8?000`3oogooX23`oj0Pl005oj0Pl0030?ooOonP8?3oX23`00`0
oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0KP3oogl4oj0Pl0030?ooOol00000Oooo00H0Oooo
0_ooO`0307ooo`;oogl01@1oool2oomo00H0Oooo00?oogl0oj0Pl?nP8?000_nP8?0307ooo`;oogl0
1@1oool2oomo0080Oooo1?ooO`0707ooo`;oogl0101oool5oj0Pl0D0Oooo0_ooO`0407ooo`;oogl0
00<0Oooooj0Pl?nP8?000P1oool00ol00000oomo0?ooO`020?ooO`;oX23`0P3oogl2oj0Pl0@0oomo
0_nP8?050?ooO`;oX23`0`3oogl2oomo0080oomo0onP8?020?ooO`;oX23`0P3oogl2oj0Pl0D0oomo
0_nP8?070?ooO`goX23`303oogl1o`00007ooooo00000ol00000oomo0?ooO`1Z0?ooO`;oX23`103o
ogl2oj0Pl0030?ooOol00000Oooo0080Oooo0_ooO`0607ooo`;oX23`00?oogl007ooo`1oool01`1o
ool4oomo000307oooonP8?3oX23`00;oX23`1@1oool2oomo00<0Oooo0_ooO`0;07ooo`;oX23`0_oo
O`0307ooo`?oX23`201oool00oooO`3oX23`oj0Pl00407ooo`;oogl00_nP8?0307ooo`04o`00003o
ogl0oomo0?ooO`;oX23`0P3oogl2oj0Pl0@0oomo0_nP8?050?ooO`;oogl00_nP8?080?ooO`;oogl0
0_nP8?001@3oogooogl0oj0Pl?nP8?00oomo00;oX23`00<0oomooj0Pl?nP8?002@3oogl:oj0Pl0h0
oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0JP3oogl5oj0Pl0@0oomo0_ooO`0207ooo`;oX23`
1P1oool2oj0Pl0X0Oooo1?ooO`0207ooo`;oX23`0P1oool2oj0Pl080Oooo0oooO`0207ooo`;oogl0
2@1oool4oj0Pl0D0Oooo0_nP8?0207ooo`;oX23`1@1oool00oooO`3oX23`oj0Pl00407ooo`;oogl0
0_nP8?0407ooo`?oX23`4@3oogl2oomo00?oX23`1P3oogl2oj0Pl005oomo003oogl0oomo0?ooOooo
O`001OnP8?000`3oogooX23`oj0Pl0040?ooO`;oX23`103oogl5oj0Pl0030?ooOonP8?3oX23`00?o
X23`303oogl1o`00007ooooo00000ol00000oomo0?ooO`1[0?ooO`04oomo0?nP8?3oX23`oj0Pl0@0
oomo0_ooO`0207ooo`;oX23`00@0Oooooj0Pl?nP8?00Oooo0_nP8?0B07ooo`;oX23`0P1oool2oj0P
l0<0Oooo0_ooO`0707ooo`;oogl0101oool2oj0Pl0L0Oooo0_nP8?0207ooo`;oX23`3P1oool00ooo
O`3oX23`oj0Pl00307ooo`?oX23`2P3oogl2oomo0080oomo0onP8?030?ooO`;oX23`1@3oogl3oj0P
l0D0oomo1onP8?020?ooO`;oX23`00@0oomooj0Pl?nP8?00oomo3_nP8?0<0?ooO`7o00000Oooool0
0003o`00003oogl0oomo06`0oomo0_nP8?050?ooO`04o`00001oooooogl0oomo00;oX23`00<0Oooo
oj0Pl?nP8?000onP8?0<07ooo`;oogl0101oool2oomo00H0Oooo0_ooO`0607ooo`Coogl03`1oool2
oomo0140Oooo0_nP8?0507ooo`03o`00003oogl0oomo00H0oomo0_nP8?02oomo0080oomo0onP8?03
0?ooO`;oogl01@3oogl2oj0Pl0/0oomo0_nP8?020?ooO`;oX23`00<0oomooj0Pl?nP8?002_nP8?02
0?ooO`CoX23`2`3oogl1o`00007ooooo00000ol00000oomo0?ooO`1/0?ooO`;oX23`1P3oogl00ol0
003oX23`oj0Pl002oj0Pl0<0Oooo0_nP8?04oomo00H0Oooo0_nP8?05oomo00<0Oooo0_ooO`0507oo
o`;oogl01P1oool4oomo00@0Oooo0_nP8?0907ooo`;oogl06@1oool00ol00000oomo0?ooO`050?oo
O`?oX23`0`3oogl2oomo00d0oomo0_nP8?0;0?ooO`?oX23`0P3oogl4oj0Pl0050?ooOonP8?3oX23`
oj0Pl03oogl00onP8?020?ooO`CoX23`2`3oogl1o`00007ooooo00000ol00000oomo0?ooO`1d0?oo
O`03o`000?nP8?3oX23`00;oogl00`1oool6oomo00H0Oooo0_nP8?000oooO`00Oooo07ooo`02oomo
00<0Oooo0_ooO`02oj0Pl0@0Oooo00?oogl0oj0Pl?nP8?001P1oool2oomo000407ooooooO`3oogl0
07ooo`;oX23`0_ooO`0;07ooo`;oX23`2P1oool2oomo00D0Oooo0_ooO`0207ooo`03o`00003oogl0
oomo00D0oomo00Coogl0oj0Pl?nP8?3oX23`0P3oogl2oomo00;oX23`103oogl2oj0Pl0D0oomo1?nP
8?000`3oogooX23`oj0Pl002oj0Pl0<0oomo1_nP8?020?ooO`;oX23`0P3oogl2oj0Pl0030?ooOonP
8?3oX23`00OoX23`2`3oogl1o`00007ooooo00000ol00000oomo0?ooO`1d0?ooO`03o`00001oool0
Oooo00;oogl03`1oool3oomo00T0Oooo0_nP8?0407ooo`03oomo0?nP8?3oX23`00T0Oooo0_ooO`00
0`1oooooogl0oomo0002oomo00/0Oooo0_nP8?0:07ooo`;oogl01@1oool2oomo00<0Oooo00?o0000
0?ooO`3oogl01P3oogl2oj0Pl0@0oomo0_nP8?040?ooO`;oX23`1`3oogl2oj0Pl0030?ooOonP8?3o
X23`00;oX23`0`3oogl6oj0Pl0`0oomo1_nP8?0;0?ooO`7o00000Oooool00003o`00003oogl0oomo
07@0oomo00?o000007ooo`1oool00`1oool2oomo00X0Oooo0_ooO`0<07ooo`;oogl01`1oool3oomo
0080Oooo0_nP8?0507ooo`;oogl04@1oool2oomo00<0Oooo0_ooO`0307ooo`03oomo0?nP8?3oX23`
00P0Oooo00?o00000?ooO`3oogl01?nP8?0=0?ooO`?oX23`403oogl2oj0Pl080oomo1onP8?030?oo
O`;oX23`0`3oogl4oj0Pl0`0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0K03oogl2oj0Pl080
oomo0_ooO`000`3oogooX23`oj0Pl00507ooo`?oogl02@1oool2oomo00L0Oooo0_ooO`000`1ooooo
ogl0oomo0002oomo00;oX23`0`1oool5oomo0080Oooo0_nP8?0507ooo`;oogl01@1oool2oomo00T0
Oooo0_nP8?001?ooO`00Oooo07ooo`1oool2oomo00<0Oooo00?oogl0oj0Pl?nP8?00101oool4oj0P
l00307ooool00000oomo00CoX23`103oogl2oj0Pl0L0oomo1?nP8?0?0?ooO`;oX23`0P3oogl<oj0P
l080oomo1onP8?0:0?ooO`7o00000Oooool00003o`00003oogl0oomo06`0oomo0_nP8?020?ooO`;o
ogl000@0oomooj0Pl?nP8?3oogl00_nP8?001?ooO`00Oooo07ooooooO`02oj0Pl0D0Oooo0_ooO`0:
07ooo`;oogl000<0Oooooomo0?ooO`000P1oool2oj0Pl0<0Oooo0_ooO`0C07ooo`03oomo0?nP8?3o
X23`00P0Oooo0_nP8?0@07ooo`KoX23`00<0oomooj0Pl?nP8?000_nP8?040?ooO`;oX23`2@3oogl2
oj0Pl0;oogl01`3oogl2oj0Pl0D0oomo1?nP8?050?ooO`ooX23`2P3oogl1o`00007ooooo00000ol0
0000oomo0?ooO`1e0?ooO`04oomo0?nP8?3oX23`oomo00;oX23`00<0Oooooj0Pl?nP8?000P1oool2
oomo000307ooooooO`3oogl000<0Oooo0_ooO`0@07ooo`;oogl0401oool2oomo00<0Oooo0_nP8?0?
07ooo`;oogl02P1oool2oomo000307oooonP8?3oX23`00;oogl000<0oomooj0Pl?nP8?000_nP8?0>
0?ooO`KoX23`103oogl2oj0Pl0D0oomo1?nP8?040?ooO`;oX23`103oogl:oj0Pl080oomo0_nP8?06
0?ooO`7o00000Oooool00003o`00003oogl0oomo07@0oomo0_nP8?0307ooo`;oX23`0_ooO`000`1o
ooooX23`oj0Pl002oomo000307oooonP8?3oX23`0080Oooo0oooO`0507ooo`;oogl02@1oool3oomo
00X0Oooo1?ooO`000`1oooooX23`oj0Pl00707ooo`;oX23`1`1oool2oj0Pl080Oooo0_ooO`0:07oo
o`;oogl00`1oool2oomo00;oX23`00@0oomooj0Pl?nP8?3oX23`0`3oogl2oj0Pl0P0oomo1_nP8?0;
0?ooO`;oX23`1P3oogl2oj0Pl0030?ooOonP8?3oX23`0080oomo2OnP8?020?ooO`;oX23`1P3oogl1
o`00007ooooo00000ol00000oomo0?ooO`1^0?ooO`;oogl0103oogl4oj0Pl0<0Oooo0_ooO`03oj0P
l0<0Oooo0_nP8?0207ooo`;oogl01P1oool2oomo00X0Oooo0_ooO`0307ooo`;oogl01@1oool4oomo
000307oooonP8?3oX23`00L0Oooo0_nP8?0207ooo`;oX23`0`1oool2oj0Pl1@0Oooo00?o0000oj0P
l?nP8?000P3oogl2oj0Pl003oomo003oogl0oomo00CoX23`203oogl2oj0Pl0<0oomo0_nP8?020?oo
O`CoX23`0P3oogl2oj0Pl0D0oomo0_nP8?020?ooO`;oX23`0P3oogl:oj0Pl0T0oomo0Ol00001oooo
o`0000?o00000?ooO`3oogl0KP3oogl2oomo00D0oomo00?o0000oj0Pl?nP8?001@1oool2oj0Pl0;o
ogl00P1oool01?ooO`3oX23`oj0Pl01oool2oomo00D0Oooo0_ooO`0:07ooo`;oX23`00Coogl007oo
o`1oool0Oooo0_ooO`0:07ooo`;oX23`00?oogl007ooo`1oool00_ooO`0307ooo`;oX23`00<0Oooo
oj0Pl?nP8?00501oool2oj0Pl0@0Oooo0_nP8?020?ooO`;oX23`00?oogl00?ooO`3oogl00P3oogl2
oj0Pl0<0oomo0onP8?070?ooO`;oX23`0P3oogl4oj0Pl0T0oomo0onP8?000`3oogooX23`oj0Pl002
0?ooO`OoX23`00@0oomooj0Pl?nP8?3oX23`203oogl1o`00007ooooo00000ol00000oomo0?ooO`1f
0?ooO`;oX23`00<0Oooooj0Pl?nP8?00101oool2oj0Pl080Oooo00Coogl0oj0Pl?nP8?3oX23`101o
ool2oomo000307ooooooO`3oogl000P0Oooo0_ooO`02oj0Pl003oomo001oool0Oooo00P0Oooo0_nP
8?000oooO`00Oooooomo0003oomo0080Oooo0_ooO`0207ooo`03oomo0?nP8?3oX23`00<0Oooo0_nP
8?000oooO`00Oooo07ooo`0207ooo`;oX23`1`1oool2oj0Pl080Oooo0_nP8?0407ooo`KoX23`00<0
oomooomo0?ooO`00103oogl2oj0Pl0040?ooOonP8?3oX23`oj0Pl0`0oomo1OnP8?020?ooO`;oogl0
103oogl5oj0Pl080oomo1onP8?020?ooO`;oX23`203oogl1o`00007ooooo00000ol00000oomo0?oo
O`1f0?ooO`;oX23`00<0Oooooj0Pl?nP8?00101oool2oj0Pl0@0Oooo0_nP8?0407ooo`;oogl02`1o
ool2oomo000307ooooooO`3oogl000X0Oooo0_nP8?001?ooO`00Oooooomo0?ooO`0807ooo`;oogl0
101oool2oj0Pl003oomo001oool0Oooo0080Oooo0_nP8?0707ooo`;oX23`2P1oool4oj0Pl0030?oo
OoooO`3oogl000@0oomo0_nP8?0@0?ooO`;oX23`00<0oomooj0Pl?nP8?000P3oogl2oomo00H0oomo
0_nP8?070?ooO`;oX23`3@3oogl1o`00007ooooo00000ol00000oomo0?ooO`1]0?ooO`;oX23`1P3o
ogl2oomo00L0Oooo0_nP8?001OooO`00Oooo07ooo`1oooooogl000;oX23`3@1oool2oomo00@0Oooo
0_nP8?0C07ooo`;oogl00P1oool2oomo00L0Oooo0_ooO`0J07ooo`03o`00003oogl0oomo00h0oomo
1?ooO`040?ooO`CoX23`2@3oogl2oj0Pl0030?ooOonP8?3oX23`00@0oomo0_nP8?030?ooO`OoX23`
203oogl1o`00007ooooo00000ol00000oomo0?ooO`1]0?ooO`;oX23`1P3oogl2oomo00D0Oooo1?nP
8?001OooO`00Oooo07ooo`1oooooogl000;oX23`00?oogl007ooo`1oool02P1oool4oomo0080Oooo
0_nP8?000`1oooooogl0oomo000507ooo`;oX23`1`1oool4oj0Pl00407ooooooO`3oogl0oomo00L0
Oooo0oooO`0207ooo`;oogl05P1oool01?l00000oomo0?ooO`3oogl2oomo00X0oomo00Googl0oj0P
l?nP8?3oogl00?ooO`02oj0Pl0030?ooOonP8?3oX23`00?oX23`203oogl2oj0Pl0030?ooOonP8?3o
X23`00;oX23`0P3oogl2oj0Pl0<0oomo1onP8?080?ooO`7o00000Oooool00003o`00003oogl0oomo
07H0oomo00?o000007ooo`1oool00`1oool5oj0Pl080Oooo0_ooO`000`1oooooogl0oomo000507oo
o`;oX23`1@1oool4oomo00;oX23`00<0Oooooj0Pl?nP8?000_ooO`0307ooo`CoX23`1`1oool4oj0P
l0?oogl000@0Oooooomo0?ooO`00Oooo0_ooO`0207ooo`;oX23`1OooO`0307ooo`;oogl03@1oool2
oomo0080Oooo00Co0000oj0Pl?nP8?00oomo0_ooO`05oj0Pl0@0oomo1OnP8?000`3oogooX23`oj0P
l0040?ooO`GoX23`1@3oogl2oj0Pl0030?ooOonP8?3oX23`00;oX23`2@3oogl2oj0Pl0/0oomo0Ol0
0001ooooo`0000?o00000?ooO`3oogl0M`3oogl00ol00000Oooo07ooo`0207ooo`GoX23`0P1oool2
oomo0080Oooo0_nP8?0207ooo`;oogl00_nP8?0507ooo`;oogl00P1oool2oj0Pl00307oooonP8?3o
X23`00@0Oooo00?oogl0oj0Pl?nP8?000_nP8?0507ooo`;oogl00`1oool3oomo000507oooonP8?3o
X23`oomo001oool01?ooO`02oj0Pl00307ooooooO`3oogl000D0Oooo0_ooO`0=07ooo`?oogl000@0
Oooooj0Pl?nP8?3oX23`0P3oogl6oj0Pl080oomo1onP8?080?ooO`CoX23`1@3oogl2oj0Pl0040?oo
OonP8?3oX23`0?ooO`?oX23`00@0oomooj0Pl?nP8?00oomo0_nP8?000`3oogooX23`oj0Pl0030?oo
O`;oX23`1P3oogl1o`00007ooooo00000ol00000oomo0?ooO`1g0?ooO`03o`00001oool0Oooo0080
Oooo0_nP8?0907ooo`;oX23`0P1oool4oomo00P0Oooo0_nP8?02oomo00D0Oooo0oooO`000`1ooooo
ogl0oomo0002oj0Pl0<0Oooo0_ooO`0207ooo`Coogl000<0Oooooj0Pl?nP8?000_ooO`0207ooo`;o
ogl02P1oool2oj0Pl0h0Oooo0_ooO`00101oooooX23`oj0Pl?l000020?ooO`;oX23`0`3oogl2oj0P
l0030?ooOonP8?3oX23`0080oomo0_nP8?070?ooO`;oX23`303oogl2oj0Pl0050?ooOonP8?3oX23`
oj0Pl03oogl00_nP8?000`3oogooX23`oj0Pl0060?ooO`?oX23`1@3oogl1o`00007ooooo00000ol0
0000oomo0?ooO`1`0?ooO`;oogl01@3oogl00ol00000Oooo07ooo`0;07ooo`;oX23`00Coogl007oo
oonP8?3oX23`0P1oool2oomo00H0Oooo00Coogl0oj0Pl?nP8?3oX23`0_ooO`0207ooo`;oogl000D0
Oooooomo0?ooO`3oogl007ooo`02oomo00;oX23`1`1oool2oomo00;oX23`0`1oool2oomo00H0Oooo
00?oogl0oj0Pl?nP8?001@1oool2oj0Pl0H0Oooo0_nP8?02oomo00X0Oooo00?o00000?ooO`3oogl0
0P3oogl6oj0Pl0<0oomo0_ooO`050?ooO`CoX23`0`3oogl2oomo00H0oomo0_nP8?060?ooO`;oX23`
103oogl2oj0Pl0@0oomo0_nP8?050?ooO`7o00000Oooool00003o`00003oogl0oomo0700oomo0_oo
O`050?ooO`03o`00001oool0Oooo00/0Oooo0_nP8?001?ooO`00Oooooj0Pl?nP8?0407ooo`;oX23`
00D0Oooooomo0?ooO`00Oooooomo0002oj0Pl0?oogl00P1oool3oomo0080Oooo1?ooO`0307ooo`;o
ogl01@1oool00oooO`3oX23`oj0Pl00307ooo`;oogl01P1oool00oooO`3oX23`oj0Pl00307ooo`;o
ogl0201oool2oj0Pl003oomo0?nP8?3oX23`00H0Oooo0_nP8?000`1ooooo00000?ooO`030?ooO`Ko
X23`0`3oogl4oj0Pl0<0oomo0_nP8?040?ooO`?oogl00P3oogl2oj0Pl080oomo0_nP8?040?ooO`Co
X23`103oogl2oj0Pl0/0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0M`3oogl00ol00000Oooo
07ooo`0;07ooo`;oogl01?nP8?0407ooo`CoX23`00?oogl007ooooooO`001OooO`0307ooo`;oogl0
0P1oool2oomo00D0Oooo0_ooO`0207ooo`;oogl000<0Oooooomo0?ooO`00101oool2oj0Pl0<0Oooo
1?ooO`0207ooo`;oogl000<0Oooooomo0?ooO`000_ooO`0907ooo`;oX23`1P1oool2oj0Pl003oomo
001ooooo000000@0oomo1OnP8?000`3oogooX23`oj0Pl004oj0Pl0L0oomo0_nP8?02oomo00<0oomo
0_nP8?030?ooO`;oX23`0`3oogl4oj0Pl140oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0N03o
ogl00ol00000Oooo07ooo`0:07ooo`;oogl01?nP8?0607ooo`;oX23`00?oogl007ooo`1oool05`1o
ool2oomo00L0Oooo0_nP8?0307ooo`Coogl00P1oool2oomo00<0Oooo0_ooO`0B07ooo`;oogl00P1o
ool01?l00000oomo0?ooO`3oogl2oj0Pl0040?ooOonP8?3oX23`0?ooO`;oX23`2`3oogl2oj0Pl0X0
oomo0_nP8?050?ooO`;oX23`4@3oogl1o`00007ooooo00000ol00000oomo0?ooO`1h0?ooO`03o`00
001oool0Oooo0100Oooo0_ooO`0407ooo`;oogl00`1oool2oomo000307ooooooO`3oogl000<0Oooo
1?ooO`000`1oooooX23`oj0Pl00=07ooo`;oogl01P1oool2oomo00X0Oooo0_nP8?0907ooo`;oX23`
2`1oool2oj0Pl1X0oomo0_nP8?0O0?ooO`7o00000Oooool00003o`00003oogl0oomo07P0oomo00?o
000007ooo`1oool02P1oool2oj0Pl0@0Oooo0_ooO`0407ooo`?oogl000<0Oooooomo0?ooO`001?oo
O`0207ooo`Coogl01?nP8?0=07ooo`;oogl01P1oool2oomo0080Oooo0_ooO`0507ooo`03oomo0?nP
8?3oX23`00;oogl00`1oool2oj0Pl00407ooooooO`3oX23`oj0Pl0<0Oooo0_ooO`0607ooo`;oX23`
00<0oomooj0Pl?nP8?000_nP8?070?ooO`KoX23`203oogl2oj0Pl0T0oomo0_nP8?0D0?ooO`7o0000
0Oooool00003o`00003oogl0oomo07T0oomo00?o000007ooo`1oool0201oool6oj0Pl0L0Oooo1_oo
O`000`1oooooogl0oomo000307ooo`Coogl00_nP8?02oomo0080Oooo0_ooO`0907ooo`?oogl000<0
Oooooomo0?ooO`001P1oool2oomo00D0Oooo0_ooO`000`1oooooogl0oomo000307ooo`;oX23`00<0
Oooooomo0?ooO`00101oool2oomo00L0Oooo00?oogl0oj0Pl?nP8?000onP8?000`3oogooX23`oj0P
l0040?ooO`KoX23`2@3oogl2oj0Pl0030?ooOonP8?3oX23`00D0oomo1?nP8?0B0?ooO`7o00000Ooo
ool00003o`00003oogl0oomo07T0oomo00?o000007ooo`1oool0201oool6oj0Pl00407oooonP8?3o
X23`oomo00<0Oooo0onP8?05oomo00H0Oooo1?ooO`00101oooooogl0oomo001oool2oomo00X0Oooo
0_ooO`000`1oooooogl0oomo000207ooo`;oogl04@1oool2oj0Pl100Oooo00?oogl0oj0Pl?nP8?00
103oogl2oj0Pl0<0oomo0_nP8?060?ooO`;oX23`1P3oogl2oj0Pl0030?ooOonP8?3oX23`00L0oomo
0_nP8?040?ooO`;oogl0303oogl1o`00007ooooo00000ol00000oomo0?ooO`1i0?ooO`03o`00001o
ool0Oooo00T0Oooo0_nP8?02oomo00KoX23`00?oogl0oj0Pl?nP8?000_nP8?000oooO`3oX23`oj0P
l004oomo00H0Oooo0_ooO`000`1oooooogl0oomo0002oj0Pl0X0Oooo1?ooO`0407ooo`;oogl01@1o
ool2oomo000307ooooooO`3oogl000D0Oooo0_ooO`0307ooo`;oogl01P1oool2oomo00;oX23`1@1o
ool00ol00000oomo0?ooO`020?ooO`;oogl00`3oogl2oj0Pl0H0oomo0_nP8?090?ooO`;oX23`3@3o
ogl2oomo00P0oomo0_nP8?020?ooO`7o00000Oooool00003o`00003oogl0oomo07X0oomo00?o0000
07ooo`1oool02P1oool2oomo00;oX23`00D0Oooooj0Pl?nP8?3oX23`oomo0004oj0Pl003oomo0?nP
8?3oX23`00Coogl0101oool00oooO`3oX23`oj0Pl00407ooo`;oX23`0_ooO`0707ooo`Googl02`1o
ool2oomo000307ooooooO`3oogl00080Oooo0_ooO`000`1oooooogl0oomo000307ooo`;oogl01P1o
ool2oomo00;oX23`00@0Oooooj0Pl?nP8?3oX23`0P1oool00ol00000oomo0?ooO`02oj0Pl003oomo
003oogl0oomo00D0oomo0_nP8?00103oogooX23`oj0Pl?nP8?060?ooO`;oX23`3`3oogl2oomo00T0
oomo0_nP8?020?ooO`7o00000Oooool00003o`00003oogl0oomo07X0oomo00?o000007ooo`1oool0
2`1oool00oooO`3oX23`oj0Pl00507ooo`CoX23`0P1oool5oomo00@0Oooo00?oogl0oj0Pl?nP8?00
101oool2oj0Pl0;oogl01P1oool3oomo01<0Oooo1?ooO`0207ooo`;oX23`0P1oool2oomo00@0Oooo
0_nP8?0507ooo`?oX23`0`1oool01?l00000oomooj0Pl?nP8?080?ooO`;oX23`00D0oomooj0Pl?nP
8?3oX23`oomo00050?ooO`;oX23`3`3oogl2oj0Pl0d0oomo0Ol00001ooooo`0000?o00000?ooO`3o
ogl0NP3oogl00ol00000Oooo07ooo`0;07ooo`03oomo0?nP8?3oX23`00?oogl000<0Oooooj0Pl?nP
8?001@1oool3oomo0080Oooo0_ooO`00101oooooogl0oomo0?ooO`0307ooo`CoX23`101oool2oomo
0080Oooo0_nP8?0207ooo`;oogl00`1oool2oomo00/0Oooo0onP8?000`1oooooogl0oomo0002oj0P
l0P0Oooo0_nP8?0;07ooo`03o`00003oogl0oomo00/0oomo1OnP8?0F0?ooO`;oX23`2P3oogl2oj0P
l040oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0NP3oogl00ol00000Oooo07ooo`0>07ooo`?o
ogl000<0Oooooj0Pl?nP8?002P1oool2oomo000307ooooooO`3oogl000@0Oooo0_nP8?0607ooo`;o
ogl00P1oool2oj0Pl080Oooo0_ooO`0307ooo`;oogl02`1oool3oj0Pl00307ooooooO`3oogl001P0
Oooo00?o00000?ooO`3oogl02P3oogl2oj0Pl003oomo0?nP8?3oX23`0280oomo0_nP8?010?ooO`7o
00000Oooool00003o`00003oogl0oomo07/0oomo00?o000007ooo`1oool0401oool4oj0Pl0;oogl0
0`1oool8oomo0080Oooo0_nP8?0707ooo`Coogl04@1oool2oj0Pl0<0Oooo0_ooO`0607ooo`;oX23`
2`1oool2oj0Pl0<0Oooo0_nP8?0507ooo`03o`000?nP8?3oX23`01P0oomo0_ooO`0I0?ooO`7o0000
0Oooool00003o`00003oogl0oomo07/0oomo00?o000007ooo`1oool00P1oool2oomo00/0Oooo1OnP
8?07oomo00;oX23`1?ooO`00101oooooogl0oj0Pl?nP8?0707ooo`Coogl04@1oool2oj0Pl00307oo
ooooO`3oogl000;oogl01P1oool2oj0Pl0/0Oooo0onP8?0207ooo`;oX23`1P1oool2oj0Pl1<0oomo
0_nP8?030?ooO`?oogl01`3oogl2oj0Pl0l0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0N`3o
ogl00ol00000Oooo07ooo`0207ooo`;oogl02`1oool4oj0Pl0;oogl000<0Oooooomo0?ooO`000_oo
O`03oj0Pl0@0Oooo0oooO`02oj0Pl0P0Oooo0_ooO`0207ooo`;oogl02P1oool2oomo00@0Oooo0_oo
O`0F07ooo`;oX23`2`1oool00ol0003oX23`oj0Pl0060?ooO`;oogl01P3oogl2oj0Pl0030?ooOonP
8?3oX23`00;oX23`0P3oogl2oomo00L0oomo0_nP8?000oooO`00oomo0?ooO`0<0?ooO`7o00000Ooo
ool00003o`00003oogl0oomo07/0oomo00?o000007ooo`1oool04@1oool2oj0Pl004oomo001oool0
Oooooomo00;oX23`00<0Oooooj0Pl?nP8?000_ooO`0307ooo`?oogl00_nP8?0207ooo`;oX23`101o
ool3oomo000407ooooooO`3oogl0oomo00T0Oooo0_ooO`000`1oooooogl0oomo000207ooo`;oogl0
00<0Oooooomo0?ooO`00101oool2oj0Pl0X0Oooo0_nP8?0>07ooo`;oX23`1@3oogl3oomo00H0oomo
0_nP8?030?ooO`;oX23`303oogl2oomo00;oX23`303oogl1o`00007ooooo00000ol00000oomo0?oo
O`1k0?ooO`03o`00001oool0Oooo01<0Oooo0_ooO`0207ooo`;oX23`0`1oool2oomo00D0Oooo0ooo
O`0207ooo`;oX23`0_ooO`0307ooo`;oogl000@0Oooooj0Pl?nP8?3oogl0301oool2oomo0080Oooo
0_ooO`000`1oooooogl0oomo000407ooo`;oX23`2P1oool2oj0Pl0@0Oooo0_nP8?0207ooo`?oX23`
0`1oool2oj0Pl0D0oomo0_ooO`020?ooO`;oX23`3@3oogl2oj0Pl0T0oomo0_nP8?0<0?ooO`7o0000
0Oooool00003o`00003oogl0oomo07`0oomo00?o000007ooo`1oool04P1oool2oj0Pl00307oooooo
O`3oogl000@0Oooo00Coogl0oj0Pl?nP8?3oogl00_nP8?00101oooooogl0oomo0?ooO`0307ooo`?o
ogl00`1oool2oomo000307oooonP8?3oX23`0080Oooo0_ooO`0407ooo`;oogl00_nP8?0307ooo`;o
X23`101oool2oomo01D0Oooo0_nP8?000`1oooooogl0oj0Pl002oj0Pl0<0Oooo0_nP8?080?ooO`?o
X23`3@3oogl2oj0Pl1L0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0O03oogl00ol00000Oooo
07ooo`0A07ooo`?oX23`00<0Oooooomo0?ooO`000`1oool01OooO`3oX23`oj0Pl?nP8?3oogl000;o
X23`101oool2oomo000307ooooooO`3oogl00080Oooo0_nP8?02oomo000307ooooooO`3oogl000Co
ogl0101oool01?ooO`3oX23`oj0Pl?nP8?0307ooo`;oX23`101oool3oomo00D0Oooo0_ooO`0207oo
o`;oogl01@1oool2oj0Pl0D0Oooo1?ooO`0507ooo`03o`00003oogl0oomo00D0oomo0_nP8?0A0?oo
O`;oX23`503oogl1o`00007ooooo00000ol00000oomo0?ooO`1l0?ooO`03o`00001oool0Oooo0140
Oooo0_nP8?0307ooo`;oX23`0P1oool01?ooO`3oX23`oj0Pl01oool2oj0Pl0Googl00_nP8?000`1o
ooooogl0oomo0002oomo00;oX23`0`1oool4oomo00H0Oooo0onP8?0507ooo`;oogl00_nP8?00101o
ooooogl0oomo0?ooO`0307ooo`Coogl00P1oool2oomo00D0Oooo0_nP8?0707ooo`;oogl01P1oool2
oomo01P0oomo0_nP8?0D0?ooO`7o00000Oooool00003o`00003oogl0oomo07`0oomo00?o000007oo
o`1oool05P1oool2oj0Pl0<0Oooo0_ooO`000`1oooooX23`oj0Pl005oomo00;oX23`0P1oool3oomo
00H0Oooo0_ooO`0707ooo`;oX23`1P1oool2oomo00;oX23`00<0Oooooomo0?ooO`00101oool2oomo
01`0Oooo0_ooO`0^0?ooO`7o00000Oooool00003o`00003oogl0oomo07d0oomo00?o000007ooo`1o
ool06@1oool2oomo00L0Oooo0_ooO`0207ooo`;oX23`1@1oool6oomo0080Oooo0oooO`0907ooo`;o
ogl01`1oool2oomo00h0Oooo0_ooO`000`1oooooogl0oomo000907ooo`;oX23`0P1oool00ol00000
oomo0?ooO`0U0?ooO`;oX23`1@3oogl1o`00007ooooo00000ol00000oomo0?ooO`1m0?ooO`03o`00
001oool0Oooo01L0Oooo0_nP8?02oomo0080Oooo0_nP8?02oomo00;oX23`00?oogl007ooo`1oool0
0_nP8?00101oooooogl0oomo001oool9oomo00;oX23`00Coogl007ooo`1oool0Oooo0_ooO`00101o
ooooX23`oj0Pl01oool2oj0Pl0L0Oooo0_ooO`0>07ooo`;oogl000<0Oooooomo0?ooO`002@1oool2
oj0Pl0<0Oooo00?o00000?ooO`3oogl04`3oogl2oj0Pl0l0oomo0_nP8?020?ooO`;oX23`0@3oogl1
o`00007ooooo00000ol00000oomo0?ooO`1m0?ooO`03o`00001oool0Oooo00P0Oooo0_ooO`0=07oo
o`;oX23`00Coogl007ooo`1oool0Oooo0_nP8?02oomo00;oX23`0oooO`0207ooo`?oogl000@0Oooo
oomo0?ooO`3oogl00`1oool3oomo00;oX23`0P1oool5oomo00;oX23`00@0Oooooj0Pl?nP8?00Oooo
0_ooO`0407ooo`;oX23`3@1oool2oomo01<0Oooo00?o00000?ooO`3oogl04P3oogl2oj0Pl1<0oomo
0_nP8?010?ooO`7o00000Oooool00003o`00003oogl0oomo07d0oomo00?o000007ooo`1oool0201o
ool2oomo00d0Oooo1OnP8?000`1oooooX23`oj0Pl008oomo00;oX23`00?oogl007ooooooO`000ooo
O`0407ooo`?oogl00`1oool6oomo0080Oooo0_ooO`000`1oooooogl0oomo000407ooo`;oX23`1`1o
ool2oj0Pl0@0Oooo0_ooO`0C07ooo`04o`00003oogooogl0oomo02T0oomo0Ol00001ooooo`0000?o
00000?ooO`3oogl0O@3oogl00ol00000Oooo07ooo`0I07ooo`?oX23`00?oogl0oj0Pl?nP8?001?oo
O`0307ooo`04oomo0?nP8?3oX23`oj0Pl0?oogl0301oool4oomo00/0Oooo0_nP8?0907ooo`;oX23`
201oool2oomo0100Oooo00?o0000oomo0?ooO`00:@3oogl1o`00007ooooo00000ol00000oomo0?oo
O`1n0?ooO`03o`00001oool0Oooo01X0Oooo1?nP8?001?ooO`3oX23`oj0Pl?ooO`0407ooo`04oomo
0?nP8?3oX23`oj0Pl0?oogl02`1oool2oomo00d0Oooo0_nP8?0C07ooo`;oogl00`1oool2oomo0080
Oooo0_nP8?00101oooooX23`oj0Pl?ooO`02oj0Pl080Oooo00?o00000?ooO`3oogl05`3oogl00ooo
O`3oX23`oj0Pl00>0?ooO`7o00000Oooool00003o`00003oogl0oomo07h0oomo00?o000007ooo`1o
ool06P1oool2oj0Pl0<0Oooo0_nP8?07oomo00;oX23`00D0Oooooomo0?ooO`3oogl007ooo`03oomo
000307ooooooO`3oogl000L0Oooo0_nP8?0G07ooo`;oogl02P1oool2oomo0080Oooo0_nP8?00101o
ooooX23`oj0Pl?ooO`02oj0Pl0<0Oooo00Co00000?ooOoooO`3oogl05@3oogl00oooO`3oX23`oj0P
l00>0?ooO`7o00000Oooool00003o`00003oogl0oomo07h0oomo00?o000007ooo`1oool08@1oool:
oomo000407ooooooO`3oogl007ooo`?oogl000<0Oooooomo0?ooO`000`1oool2oomo000407oooooo
O`3oX23`oj0Pl080Oooo0_ooO`03oj0Pl0;oogl0101oool2oomo00P0Oooo0_ooO`0?07ooo`;oogl0
1@1oool2oomo0080Oooo00?o0000oomo0?ooO`000_nP8?0T0?ooO`7o00000Oooool00003o`00003o
ogl0oomo07h0oomo00?o000007ooo`1oool08P1oool2oomo00<0Oooo1?ooO`00101oooooogl0oomo
001oool2oomo00L0Oooo0_ooO`000`1oooooogl0oomo000307ooo`;oogl00onP8?02oomo00@0Oooo
0_ooO`0I07ooo`;oogl01@1oool2oomo00<0Oooo00Co00000?ooOonP8?3oX23`903oogl1o`00007o
oooo00000ol00000oomo0?ooO`1o0?ooO`03o`00001oool0Oooo0240Oooo0_nP8?000`1oooooX23`
oj0Pl00307ooo`Googl00_nP8?03oomo01T0Oooo0_nP8?0I07ooo`;oX23`201oool00ol00000oomo
0?ooO`0;0?ooO`;oX23`2P3oogl2oj0Pl080oomo0_nP8?080?ooO`7o00000Oooool00003o`00003o
ogl0oomo07l0oomo00?o000007ooo`1oool08@1oool2oj0Pl00407oooonP8?3oX23`oj0Pl0Ooogl0
0_nP8?03oomo000307ooooooO`3oogl000@0Oooo0_ooO`0=07ooo`;oX23`00<0Oooooj0Pl?nP8?00
3P1oool2oomo0080Oooo0_ooO`0507ooo`;oX23`2@1oool00ol00000oomo0?ooO`0:0?ooO`;oX23`
00<0oomooomo0?ooO`001`3oogl6oj0Pl0P0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0O`3o
ogl00ol00000Oooo07ooo`0K07ooo`;oogl01`1oool00oooO`3oX23`oj0Pl006oomo00<0Oooo1_oo
O`0407ooo`;oogl01P1oool2oomo0080Oooo0_ooO`000`1oooooX23`oj0Pl00207ooo`;oogl01P1o
ool2oomo00D0Oooo0_ooO`0207ooo`;oogl04@1oool00ol00000oomo0?ooO`0<0?ooO`;oogl02@3o
ogl2oj0Pl0X0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0O`3oogl00ol00000Oooo07ooo`0D
07ooo`;oX23`1@1oool2oj0Pl0L0Oooo2OooO`02oj0Pl0Koogl03@1oool2oomo0080Oooo0_ooO`05
07ooo`;oogl00_nP8?0407ooo`;oogl02@1oool2oomo0180Oooo00?o00000?ooO`3oogl0803oogl2
oj0Pl07o00000Oooool00003o`00003oogl0oomo07l0oomo00?o000007ooo`1oool0501oool2oj0P
l0D0Oooo0_nP8?0207ooo`;oogl01@1oool7oomo00;oX23`1OooO`0<07ooo`;oogl0101oool2oomo
00@0Oooo0_ooO`000`1oooooX23`oj0Pl00407ooo`04oomo0?nP8?3oX23`oomo01/0Oooo00?o0000
0?ooO`3oogl02P3oogl2oomo01@0oomo0_nP8?01o`00007ooooo00000ol00000oomo0?ooO`200?oo
O`03o`00001oool0Oooo01h0Oooo0_ooO`0607ooo`;oX23`2oooO`0<07ooo`;oogl0101oool2oomo
00<0Oooo0oooO`0407ooo`;oogl000D0Oooooomo0?nP8?3oX23`oomo000@07ooo`;oX23`2P1oool0
0ol00000oomo0?ooO`090?ooO`;oogl04@3oogl2oj0Pl0<0oomo0Ol00001ooooo`0000?o00000?oo
O`3oogl0P03oogl00ol00000Oooo07ooo`0V07ooo`;oX23`2oooO`0G07ooo`;oogl01@1oool2oomo
00d0Oooo0_nP8?0607ooo`;oX23`2`1oool00ol00000oomo0?ooO`02oomo01T0oomo0_nP8?030?oo
O`7o00000Oooool00003o`00003oogl0oomo0800oomo00?o000007ooo`1oool09P1oool2oj0Pl003
oomo0?nP8?3oX23`00[oogl00`1oool2oomo00h0Oooo1?ooO`0607ooo`;oogl00P1oool2oomo00P0
Oooo0_nP8?02oomo00P0Oooo0_nP8?0707ooo`03o`00003oogl0oomo00;oogl07P3oogl1o`00007o
oooo00000ol00000oomo0?ooO`200?ooO`03o`00001oool0Oooo02H0Oooo0_nP8?000`1oooooX23`
oj0Pl00:oomo00<0Oooo0_ooO`0>07ooo`Coogl01P1oool2oomo0080Oooo0_ooO`0:07ooo`;oogl0
201oool2oj0Pl0P0Oooo00?o00000?ooO`3oogl07`3oogl1o`00007ooooo00000ol00000oomo0?oo
O`210?ooO`03o`00001oool0Oooo02<0Oooo0_ooO`02oj0Pl0@0Oooo1_ooO`0G07ooo`;oogl0901o
ool2oj0Pl0H0Oooo00?o00000?ooO`3oogl07P3oogl1o`00007ooooo00000ol00000oomo0?ooO`21
0?ooO`03o`00001oool0Oooo02<0Oooo0_ooO`02oj0Pl00407ooooooO`3oogl007ooo`?oX23`0ooo
O`0407ooo`;oogl00_nP8?0707ooo`?oogl01@1oool2oomo00X0Oooo0_ooO`0A07ooo`;oX23`1@1o
ool4oj0Pl0D0Oooo00?o00000?ooO`3oogl00_ooO`0K0?ooO`7o00000Oooool00003o`00003oogl0
oomo0840oomo00?o000007ooo`1oool0:01oool3oomo00?oX23`0_ooO`0207ooo`;oogl000<0Oooo
oomo0?ooO`000_nP8?000`1oooooogl0oomo000407ooo`?oogl01@1oool3oomo00;oX23`1`1oool2
oomo00/0Oooo0_nP8?0407ooo`;oX23`1`1oool2oj0Pl0D0Oooo00?o00000?ooO`3oogl00_ooO`0J
0?ooO`7oX23`0Ol00001ooooo`0000?o00000?ooO`3oogl0P@3oogl00ol00000Oooo07ooo`0Y07oo
o`;oogl000<0Oooooomo0?ooO`000_ooO`02oj0Pl0;oogl01P1oool2oomo00`0Oooo0_nP8?001?oo
O`3oX23`oj0Pl?ooO`0407ooo`;oogl03@1oool2oj0Pl0`0Oooo0_nP8?0707ooo`03o`00003oogl0
oomo01/0oomo0OnP8?01o`00007ooooo00000ol00000oomo0?ooO`210?ooO`03o`00001oool0Oooo
02L0Oooo0_nP8?001?ooO`00Oooo07ooo`1oool2oj0Pl003oomo0?nP8?3oX23`0140Oooo0_nP8?02
07ooo`03oomo0?nP8?3oX23`00Googl00`1oool3oomo00D0Oooo0_ooO`0:07ooo`;oogl00`1oool2
oj0Pl080Oooo0onP8?0707ooo`03o`00003oogl0oomo01/0oomo0Ol00001ooooo`0000?o00000?oo
O`3oogl0PP3oogl00ol00000Oooo07ooo`0V07ooo`CoX23`0P1oool2oj0Pl003oomo0?nP8?3oX23`
00@0Oooo0_ooO`0;07ooo`;oX23`0P1oool2oomo000407ooooooO`3oogl007ooo`;oogl000<0Oooo
oomo0?ooO`000oooO`0507ooo`;oogl02P1oool2oomo00<0Oooo0_nP8?0307ooo`;oX23`1`1oool0
0ol00000oomo0?ooO`0J0?ooO`7oX23`0Ol00001ooooo`0000?o00000?ooO`3oogl0PP3oogl00ol0
0000Oooo07ooo`0X07ooo`;oX23`1@1oool2oj0Pl0@0Oooo0_ooO`0E07ooo`;oogl000<0Oooooomo
0?ooO`00401oool2oj0Pl080Oooo0_nP8?0B07ooo`03o`00003oogl0oomo01@0oomo0_ooO`030?oo
O`7oX23`0Ol00001ooooo`0000?o00000?ooO`3oogl0PP3oogl00ol00000Oooo07ooo`0Z07ooo`;o
ogl00_nP8?000`1oooooogl0oomo000307ooo`Coogl0501oool2oomo00;oX23`00<0Oooooomo0?oo
O`002@1oool2oomo00<0Oooo0_nP8?0207ooo`;oX23`1`1oool2oj0Pl0X0Oooo00?o00000?ooO`3o
ogl00P3oogl2oomo00l0oomo0_ooO`040?ooO`7o00000Oooool00003o`00003oogl0oomo08<0oomo
00?o000007ooo`1oool0:@1oool2oomo00;oX23`1P1oool4oomo01H0Oooo0_nP8?000`1oooooogl0
oomo000907ooo`;oogl0401oool2oj0Pl0/0Oooo00Co00000?ooO`3oogl0oomo0_ooO`0E0?ooO`7o
00000Oooool00003o`00003oogl0oomo08<0oomo00?o000007ooo`1oool06@1oool2oomo01@0Oooo
0_ooO`0307ooo`Coogl000<0Oooooomo0?ooO`00101oool00oooO`3oX23`oj0Pl00h07ooo`03o`00
003oogl0oomo01P0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0P`3oogl00ol00000Oooo07oo
o`0I07ooo`;oogl04@1oool3oj0Pl0;oogl000<0Oooooomo0?ooO`001?ooO`000`1oooooogl0oomo
000207ooo`?oogl00_nP8?0707ooo`;oogl00`1oool2oomo00T0Oooo0_ooO`0@07ooo`;oX23`3P1o
ool00ol00000oomo0?ooO`0G0?ooO`7o00000Oooool00003o`00003oogl0oomo08@0oomo00?o0000
07ooo`1oool0:`1oool3oj0Pl0<0Oooo0_ooO`000`1oooooogl0oomo000607ooo`;oogl02P1oool2
oomo00<0Oooo0_ooO`0407ooo`;oX23`00<0Oooooj0Pl?nP8?000_ooO`0507ooo`;oogl00`1oool2
oomo00@0Oooo0_nP8?0>07ooo`;oX23`603oogl1o`00007ooooo00000ol00000oomo0?ooO`240?oo
O`03o`00001oool0Oooo03@0Oooo0_ooO`0M07ooo`;oX23`00<0Oooooj0Pl?nP8?001`1oool2oomo
00<0Oooo0_nP8?0207ooo`;oogl0401oool2oj0Pl1P0oomo0Ol00001ooooo`0000?o00000?ooO`3o
ogl0Q03oogl00ol00000Oooo07ooo`0f07ooo`?oogl000<0Oooooj0Pl?nP8?000_ooO`0H07ooo`;o
X23`00<0Oooooj0Pl?nP8?002@1oool2oj0Pl080Oooo0_ooO`0B07ooo`03o`00003oogl0oomo01D0
oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0Q@3oogl00ol00000Oooo07ooo`0e07ooo`?oogl0
00<0Oooooj0Pl?nP8?000_ooO`0H07ooo`;oX23`00@0Oooooj0Pl?nP8?3oogl0201oool2oomo01<0
Oooo0_ooO`0207ooo`03o`00003oogl0oomo01<0oomo0OooO`01o`00007ooooo00000ol00000oomo
0?ooO`250?ooO`03o`00001oool0Oooo0380Oooo0_nP8?000`1oooooogl0oomo000307ooo`;oogl0
201oool2oomo00/0Oooo0_nP8?0207ooo`;oX23`00?oogl007ooooooO`000_nP8?0407ooo`;oogl0
00<0Oooooomo0?ooO`001P1oool2oomo00D0Oooo1?nP8?0207ooo`;oogl00P1oool00ol00000oomo
0?ooO`0C0?ooO`7oogl00Ol00001ooooo`0000?o00000?ooO`3oogl0Q@3oogl00ol00000Oooo07oo
o`0Z07ooo`;oogl000<0Oooooomo0?ooO`000`1oool3oj0Pl0;oogl00`1oool2oj0Pl0<0Oooo0_nP
8?0307ooo`;oogl02`1oool2oj0Pl003oomo0?nP8?3oX23`00;oogl00P1oool2oj0Pl0@0Oooo0_oo
O`0907ooo`;oogl01@1oool5oj0Pl0H0Oooo00?o00000?ooO`3oogl00P3oogl2oj0Pl0l0oomo0Ol0
0001ooooo`0000?o00000?ooO`3oogl0QP3oogl00ol00000Oooo07ooo`0Y07ooo`;oogl000<0Oooo
oomo0?ooO`00101oool2oj0Pl0;oogl00`1oool2oj0Pl0<0Oooo0_nP8?0A07ooo`;oogl00_nP8?0O
07ooo`;oX23`1P1oool00ol00000oomo0?ooO`020?ooO`;oX23`3`3oogl1o`00007ooooo00000ol0
0000oomo0?ooO`260?ooO`03o`00001oool0Oooo0340Oooo0_nP8?0@07ooo`;oogl01`1oool2oj0P
l080Oooo0_ooO`0E07ooo`;oogl0501oool00ol00000oomo0?ooO`0B0?ooO`7o00000Oooool00003
o`00003oogl0oomo08H0oomo00?o000007ooo`1oool09P1oool2oj0Pl0T0Oooo0_nP8?0507ooo`;o
ogl02@1oool2oomo00L0Oooo0_nP8?0207ooo`;oogl05@1oool2oomo000307ooooooO`3oogl000T0
Oooo0_ooO`0707ooo`03o`00003oogl0oomo0140oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0
QP3oogl00ol00000Oooo07ooo`0V07ooo`;oX23`1@1oool2oomo0080Oooo0_nP8?0507ooo`;oogl0
0_nP8?0207ooo`;oogl0301oool2oj0Pl080Oooo0_ooO`0207ooo`;oogl0201oool2oj0Pl00307oo
ooooO`3oogl000D0Oooo0_nP8?02oomo00T0Oooo0_ooO`000`1oooooogl0oomo0002oj0Pl080Oooo
00?o0000oomo0?ooO`001P3oogl2oj0Pl0T0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0Q`3o
ogl00ol00000Oooo07ooo`0/07ooo`;oogl00P1oool2oomo000307oooonP8?3oX23`00@0Oooo0_nP
8?0207ooo`?oogl02@1oool2oomo00;oX23`0P1oool2oomo0080Oooo0_ooO`0807ooo`;oX23`1Ooo
O`0307ooo`;oX23`0_ooO`0;07ooo`?oogl00_nP8?0307ooo`;oogl01P3oogl2oj0Pl0T0oomo0Ol0
0001ooooo`0000?o00000?ooO`3oogl0Q`3oogl00ol00000Oooo07ooo`0`07ooo`;oogl000<0Oooo
oj0Pl?nP8?000`1oool2oj0Pl0@0Oooo0_ooO`0607ooo`?oX23`00?oogl0oj0Pl?nP8?001`1oool2
oomo00T0Oooo00Coogl0oj0Pl?nP8?00Oooo0_ooO`000`1oooooogl0oomo000?07ooo`;oogl01`1o
ool00ol00000oomo0?ooO`02oj0Pl0d0oomo0Ol00001ooooo`0000?o00000?ooO`3oogl0Q`3oogl0
0ol00000Oooo07ooo`0c07ooo`;oX23`0`1oool4oj0Pl0X0Oooo0onP8?000`1oooooX23`oj0Pl00C
07ooo`;oX23`101oool2oomo00@0Oooo0_ooO`000`1oooooogl0oomo000907ooo`;oX23`1@1oool0
1?l00000oomooj0Pl?nP8?0=0?ooO`7o00000Oooool00003o`00003oogl0oomo08L0oomo00?o0000
07ooo`1oool0<@1oool2oomo00;oX23`1@1oool3oj0Pl00407oooonP8?3oX23`07ooo`Coogl000<0
Oooooomo0?ooO`003`1oool2oomo00D0Oooo0_ooO`0207ooo`Coogl0101oool3oomo000307oooooo
O`3oogl000<0Oooo0_ooO`0407ooo`;oX23`1@1oool00ol00000oomo0?ooO`0=0?ooO`7oX23`0Ol0
0001ooooo`0000?o00000?ooO`3oogl0R03oogl00ol00000Oooo07ooo`0`07ooo`;oogl01P1oool4
oj0Pl00407oooonP8?3oX23`07ooo`Coogl00_nP8?000oooO`00Oooo07ooo`0507ooo`;oogl01P1o
ool2oomo00D0Oooo0_ooO`0207ooo`Coogl0101oool2oomo00L0Oooo0_ooO`0<07ooo`03o`000?nP
8?3oX23`00`0oomo0OnP8?01o`00007ooooo00000ol00000oomo0?ooO`280?ooO`03o`00001oool0
Oooo03P0Oooo0_nP8?0:07ooo`;oX23`201oool2oomo00H0Oooo0_ooO`0Y07ooo`;oX23`3@3oogl1
o`00007ooooo00000ol00000oomo0?ooO`280?ooO`03o`00001oool0Oooo04h0Oooo0_nP8?0207oo
o`Coogl0101oool2oomo00`0Oooo0oooO`0=07ooo`;oX23`1P1oool2oomo00h0oomo0Ol00001oooo
o`0000?o00000?ooO`3oogl0R03oogl00ol00000Oooo07ooo`0m07ooo`;oogl0101oool2oomo0003
07ooooooO`3oogl00080Oooo0_ooO`04oj0Pl080Oooo1?ooO`0407ooo`?oogl02`1oool3oomo00d0
Oooo0_nP8?0507ooo`;oX23`00?oogl0o`00003oogl0303oogl1o`00007ooooo00000ol00000oomo
0?ooO`290?ooO`03o`00001oool0Oooo03L0Oooo0_ooO`0307ooo`;oogl0101oool2oomo000307oo
ooooO`3oogl00080Oooo0_ooO`03oj0Pl0D0Oooo0_ooO`000`1oooooogl0oomo000207ooo`;oogl0
0`1oool2oomo00<0Oooo0_nP8?02oomo01@0Oooo1?nP8?00101oooooogl0oomo0?ooO`0;0?ooO`7o
00000Oooool00003o`00003oogl0oomo08T0oomo00?o000007ooo`1oool0=`1oool2oomo0100Oooo
1?ooO`000`1oooooogl0oomo000607ooo`;oogl0101oool2oj0Pl00407ooooooO`3oogl0oomo0080
Oooo0_nP8?02oomo00P0Oooo0_ooO`0407ooo`;oogl0101oool2oj0Pl0<0Oooo0oooO`0;0?ooO`7o
00000Oooool00003o`00003oogl0oomo08T0oomo00?o000007ooo`1oool0@@1oool3oj0Pl0D0Oooo
0oooO`0207ooo`;oogl0301oool2oj0Pl080Oooo0_ooO`0=07ooo`;oX23`00?oogl007ooo`1oool0
0P1oool2oomo000307oooonP8?3oX23`00P0Oooo00?o00000?ooO`3oogl02@3oogl1o`00007ooooo
00000ol00000oomo0?ooO`290?ooO`03o`00001oool0Oooo03h0Oooo0_nP8?000`1oooooX23`oj0P
l002oj0Pl0D0Oooo0_ooO`0207ooo`;oX23`4`1oool2oj0Pl0X0Oooo0_nP8?0607ooo`CoX23`1@1o
ool2oomo0080Oooo00?o00000?ooO`3oogl0203oogl1o`00007ooooo00000ol00000oomo0?ooO`2:
0?ooO`03o`00001oool0Oooo03/0Oooo0_ooO`02oj0Pl00307oooonP8?3oX23`00;oX23`1`1oool4
oj0Pl0@0Oooo0_ooO`0307ooo`;oX23`101oool2oomo0080Oooo1OnP8?0807ooo`;oX23`1@1oool2
oj0Pl0L0Oooo0_ooO`0307ooo`03o`00003oogl0oomo00L0oomo0Ol00001ooooo`0000?o00000?oo
O`3oogl0RP3oogl00ol00000Oooo07ooo`0k07ooo`;oogl00`1oool4oj0Pl0L0Oooo0_nP8?0607oo
o`;oogl00`1oool2oj0Pl004oomo001oool0Oooo07ooo`;oogl00`1oool4oj0Pl0P0Oooo0_nP8?03
07ooo`;oogl03P1oool01?l00000oomo0?ooO`3oogl2oj0Pl0<0oomo0OnP8?01o`00007ooooo0000
0ol00000oomo0?ooO`2:0?ooO`03o`00001oool0Oooo03/0Oooo0_ooO`0407ooo`03oomo0?nP8?3o
X23`01D0Oooo0_ooO`0807ooo`;oX23`3`1oool2oomo00l0Oooo00?o00000?ooO`3oogl00_nP8?03
0?ooO`7oX23`0Ol00001ooooo`0000?o00000?ooO`3oogl0RP3oogl00ol00000Oooo07ooo`1707oo
o`;oogl02@1oool2oomo0080Oooo0_ooO`0307ooo`;oogl0201oool2oomo00D0Oooo0_nP8?0507oo
o`;oX23`0P1oool2oomo00d0Oooo00?o00000?ooO`3oogl01@3oogl1o`00007ooooo00000ol00000
oomo0?ooO`2;0?ooO`03o`00001oool0Oooo03d0Oooo0_nP8?0407ooo`;oX23`00@0Oooooomo0?oo
O`3oogl0201oool2oomo0080Oooo0_ooO`0307ooo`;oogl0201oool2oomo00D0Oooo0_nP8?0507oo
o`;oX23`0P1oool2oj0Pl0L0Oooo0_nP8?0507ooo`03oomo0?nP8?3oX23`00@0oomo0Ol00001oooo
o`0000?o00000?ooO`3oogl0R`3oogl00ol00000Oooo07ooo`0d07ooo`;oX23`1`1oool2oj0Pl0@0
Oooo0_nP8?0207ooo`;oogl04P1oool4oj0Pl00307ooooooO`3oogl000;oogl02@1oool2oomo0003
07ooooooO`3oogl000@0Oooo0_nP8?0707ooo`;oX23`101oool4oj0Pl0@0oomo0Ol00001ooooo`00
00?o00000?ooO`3oogl0R`3oogl00ol00000Oooo07ooo`0d07ooo`;oX23`2`1oool00oooO`3oX23`
oj0Pl00707ooo`;oogl000<0Oooooomo0?ooO`002`1oool4oj0Pl00307ooooooO`3oogl000;oogl0
2@1oool5oomo00L0Oooo0_ooO`000`1oooooogl0oomo000707ooo`;oX23`00Co00000?ooO`3oogl0
oomo0_nP8?01o`00007ooooo00000ol00000oomo0?ooO`2<0?ooO`03o`00001oool0Oooo0400Oooo
0onP8?0507ooo`;oX23`0_ooO`000`1oooooogl0oomo000J07ooo`;oogl000<0Oooooomo0?ooO`00
0_ooO`0207ooo`;oogl0101oool2oomo000307ooooooO`3oogl000P0Oooo0_nP8?000ol00000oomo
0?ooO`02oj0Pl07o00000Oooool00003o`00003oogl0oomo08`0oomo00?o000007ooo`1oool0@01o
ool2oj0Pl0H0Oooo0_nP8?02oomo000407ooooooO`3oogl0oomo00CoX23`0P1oool2oj0Pl0D0Oooo
0_ooO`0:07ooo`;oogl000<0Oooooomo0?ooO`000_ooO`0207ooo`;oogl0101oool2oomo00/0Oooo
0_nP8?001P1ooooo00000?ooO`3oogooX23`o`00007ooooo00000ol00000oomo0?ooO`2<0?ooO`03
o`00001oool0Oooo0480Oooo0_nP8?00101oooooogl0oomo001oool2oj0Pl0;oogl00P1oool2oomo
00CoX23`0P1oool2oj0Pl0;oogl00P1oool2oj0Pl0?oogl05`1oool2oomo00d0Oooo0_ooO`00103o
ogooX23`oj0Pl?l00001ooooo`0000?o00000?ooO`3oogl0S@3oogl00ol00000Oooo07ooo`1107oo
o`;oX23`00<0Oooooomo0?ooO`000P1oool2oj0Pl004oomo001oool0Oooo07ooo`;oX23`00<0Oooo
oomo0?ooO`00101oool3oomo000407oooonP8?3oX23`07ooo`;oogl00_nP8?0507ooo`;oX23`701o
ool2oj0Pl005oomo0?l0003oX23`oj0Pl?l000000Oooool00003o`00003oogl0oomo08d0oomo00?o
000007ooo`1oool0B01oool2oj0Pl0@0Oooo0_nP8?0807ooo`;oogl01P1oool2oj0Pl0D0Oooo0_nP
8?0L07ooo`;oX23`0P1oool00ol00000oomoo`000001ooooo`0000?o00000?ooO`3oogl0S@3oogl0
0ol00000Oooo07ooo`1:07ooo`;oogl01@1oool4oj0Pl2T0Oooo0_ooO`0907ooo`03o`000?nP8?3o
0000007ooooo00000ol00000oomo0?ooO`2>0?ooO`03o`00001oool0Oooo04@0Oooo0_ooO`0307oo
o`;oogl01@1oool4oj0Pl00507oooonP8?3oX23`oj0Pl01oool00_ooO`0B07ooo`;oogl01`1oool2
oomo00<0Oooo0_nP8?02oomo00X0Oooo0OnP8?01o`00007ooooo00000ol00000oomo0?ooO`2>0?oo
O`03o`00001oool0Oooo04@0Oooo0_ooO`0307ooo`Coogl00`1oool4oomo000507oooonP8?3oX23`
oj0Pl01oool00_ooO`0707ooo`;oogl00P1oool2oomo00D0Oooo0_ooO`0507ooo`Coogl00`1oool2
oj0Pl003oomo001oool0Oooo00T0Oooo0OnP8?01o`00007ooooo00000ol00000oomo0?ooO`2>0?oo
O`03o`00001oool0Oooo03T0Oooo0_ooO`0=07ooo`;oX23`0oooO`0307ooo`Coogl01@1oool2oomo
00H0Oooo0_nP8?000oooO`00Oooo07ooo`02oomo00P0Oooo0_ooO`00101oooooogl0oomo0?ooO`05
07ooo`?oogl02`1oool1oj0Pl07o00000Oooool00003o`00003oogl0oomo08h0oomo00?o000007oo
o`1oool0>@1oool2oomo00P0Oooo0_ooO`000`1oooooogl0oomo0002oj0Pl0<0Oooo0_ooO`0:07oo
o`;oogl00_nP8?0407ooo`;oX23`00?oogl007ooo`1oool0101oool2oomo00@0Oooo1OooO`0E07oo
o`7o00000Oooool00003o`00003oogl0oomo08l0oomo00?o000007ooo`1oool0?@1oool2oomo00<0
Oooo0_ooO`000`1oooooogl0oomo000507ooo`;oX23`00<0Oooooomo0?ooO`001?ooO`02oj0Pl0;o
ogl000<0Oooooj0Pl?nP8?000`1oool2oomo00P0Oooo0_ooO`0607ooo`;oogl00P1oool2oj0Pl003
oomo001oool0Oooo00;oogl03@1oool1o`00007ooooo00000ol00000oomo0?ooO`2?0?ooO`03o`00
001oool0Oooo03d0Oooo0_ooO`0907ooo`Coogl00_nP8?000`1oooooogl0oomo0004oomo00;oX23`
0_ooO`0607ooo`;oogl000<0Oooooj0Pl?nP8?004@1oool2oj0Pl003oomo001oool0Oooo00;oogl0
301oool1oj0Pl07o00000Oooool00003o`00003oogl0oomo08l0oomo00?o000007ooo`1oool0B01o
ool5oomo00@0Oooo1?ooO`02oj0Pl004oomo001oooooogl0oomo00L0Oooo0_nP8?0307ooo`;oogl0
1@1oool4oj0Pl0;oogl01`1oool2oomo00/0Oooo0OnP8?01o`00007ooooo00000ol00000oomo0?oo
O`2@0?ooO`03o`00001oool0Oooo04X0Oooo0_ooO`0607ooo`;oogl00_nP8?001?ooO`00Oooooomo
0?ooO`0<07ooo`;oogl01@1oool4oj0Pl0;oogl01`1oool2oomo00/0Oooo0OooO`01o`00007ooooo
00000ol00000oomo0?ooO`2@0?ooO`03o`00001oool0Oooo04`0Oooo0_nP8?0607ooo`;oX23`00?o
ogl007ooo`1oool03`1oool2oj0Pl100Oooo0_ooO`0707ooo`;oX23`0`1oool1o`00007ooooo0000
0ol00000oomo0?ooO`2@0?ooO`03o`00001oool0Oooo04`0Oooo0_nP8?02oomo00@0Oooo0_nP8?02
oomo00L0Oooo1?ooO`0307ooo`;oogl00_nP8?0?07ooo`;oogl00_nP8?02oomo000407ooooooO`3o
ogl007ooo`;oX23`0`1oool1o`00007ooooo00000ol00000oomo0?ooO`2@0?ooO`03o`00001oool0
Oooo04h0Oooo0_ooO`0607ooo`;oogl000<0Oooooj0Pl?nP8?000`1oool5oomo00<0Oooo0_ooO`0A
07ooo`;oogl00_nP8?02oomo000407ooooooO`3oogl007ooo`?oogl000<0Oooooj0Pl?l000000Ooo
ool00003o`00003oogl0oomo0940oomo00?o000007ooo`1oool0C@1oool2oj0Pl0@0Oooo1?ooO`00
0`1oooooX23`oj0Pl00307ooo`;oogl00_nP8?0407ooo`;oogl02P1oool4oomo000307ooooooO`3o
ogl000/0Oooo0_ooO`000`1oooooX23`o`000001ooooo`0000?o00000?ooO`3oogl0T@3oogl00ol0
0000Oooo07ooo`1907ooo`;oX23`0P1oool2oj0Pl080Oooo0_nP8?07oomo00D0Oooo0_nP8?0407oo
o`;oogl02P1oool4oomo000307ooooooO`3oogl000P0Oooo0_ooO`0407ooo`7oogl00Ol00001oooo
o`0000?o00000?ooO`3oogl0T@3oogl00ol00000Oooo07ooo`1907ooo`;oX23`0P1oool2oj0Pl080
Oooo0_nP8?000`1oooooX23`oj0Pl002oomo00CoX23`1@1oool2oomo000307oooonP8?3oX23`0100
Oooo0_ooO`0807ooo`;oogl0101oool1oomo007o00000Oooool00003o`00003oogl0oomo0940oomo
00?o000007ooo`1oool0C@1oool2oj0Pl080Oooo0_nP8?001@1oooooX23`oj0Pl01oooooogl000So
X23`00@0Oooooomo0?ooO`00Oooo0_nP8?00101oooooogl0oomo001oool2oomo01<0Oooo0_ooO`06
07ooo`7o00000Oooool00003o`00003oogl0oomo0980oomo00?o000007ooo`1oool0EP1oool2oomo
0080Oooo00?oogl0oj0Pl?nP8?000_nP8?0707ooo`;oogl00_nP8?000oooO`00Oooo07ooo`0307oo
o`;oogl00`1oool2oomo000307ooooooO`3oogl000@0Oooo0_ooO`0507ooo`7oX23`0Ol00001oooo
o`0000?o00000?ooO`3oogl0TP3oogl00ol00000Oooo07ooo`1J07ooo`Coogl02P1oool2oj0Pl0H0
Oooo0_ooO`0307ooo`;oogl000<0Oooooomo0?ooO`002`1oool1oj0Pl07o00000Oooool00003o`00
003oogl0oomo0980oomo00?o000007ooo`1oool0DP1oool2oj0Pl080Oooo0_ooO`0207ooo`;oogl0
00@0Oooooomo0?nP8?3oX23`301oool2oj0Pl0D0Oooo0_nP8?0707ooo`;oX23`1`1oool1oomo007o
00000Oooool00003o`00003oogl0oomo0980oomo00?o000007ooo`1oool0DP1oool4oj0Pl004oomo
0?nP8?3oX23`07ooo`;oogl000@0Oooooomo0?nP8?3oX23`1P1oool2oomo00<0Oooo00Coogl0oj0P
l?nP8?00Oooo0oooO`000`1oooooX23`oj0Pl00707ooo`;oX23`00<0Oooooomo0?ooO`000P1oool3
oomo007o00000Oooool00003o`00003oogl0oomo09<0oomo00?o000007ooo`1oool0D@1oool9oj0P
l004oomo001oooooogl0oomo00?oX23`0P1oool6oomo000407ooooooO`3oogl007ooo`Coogl000<0
Oooooomo0?ooO`000P1oool3oomo00D0Oooo0_ooO`0207ooo`;oogl00@1oool1o`00007ooooo0000
0ol00000oomo0?ooO`2C0?ooO`03o`00001oool0Oooo0540Oooo0_nP8?000`1oooooX23`oj0Pl002
07ooo`;oX23`1?ooO`03oj0Pl080Oooo0_ooO`00101oooooogl0oomo0?ooO`0407ooo`;oogl00P1o
ool3oomo0080Oooo0oooO`000`1oooooX23`oj0Pl00807ooo`7oX23`0Ol00001ooooo`0000?o0000
0?ooO`3oogl0T`3oogl00ol00000Oooo07ooo`1007ooo`;oogl04P1oool2oomo00<0Oooo1oooO`00
101oooooogl0oomo001oool4oomo00@0Oooo0_ooO`0307ooo`;oogl00`1oool2oomo00CoX23`201o
ool1oj0Pl07o00000Oooool00003o`00003oogl0oomo09<0oomo00?o000007ooo`1oool0@01oool2
oomo01<0Oooo00Coogl0oj0Pl?nP8?00Oooo0_nP8?0307ooo`;oogl000@0Oooooj0Pl?nP8?00Oooo
1?ooO`0407ooo`;oogl000<0Oooooomo0?ooO`000oooO`0407ooo`;oX23`00?oogl007ooo`1oool0
0_nP8?0307ooo`;oogl00OnP8?01o`00007ooooo00000ol00000oomo0?ooO`2D0?ooO`03o`00001o
ool0Oooo05@0Oooo00Coogl0oj0Pl?nP8?00Oooo0_nP8?0407ooo`;oogl00_nP8?03oomo000307oo
ooooO`3oogl000Googl000<0Oooooomo0?ooO`000oooO`000`1oooooogl0oomo000207ooo`;oogl0
0P1oool2oj0Pl00307oooonP8?3oX23`00;oogl00OnP8?01o`00007ooooo00000ol00000oomo0?oo
O`2D0?ooO`03o`00001oool0Oooo05<0Oooo0oooO`0207ooo`;oX23`0_ooO`0207ooo`Coogl00_nP
8?000oooO`00Oooooomo0004oomo00H0Oooo0_ooO`00101oooooogl0oomo001oool2oomo000307oo
ooooO`3oogl000<0Oooo0_nP8?00101oooooX23`oj0Pl?l00001ooooo`0000?o00000?ooO`3oogl0
U03oogl00ol00000Oooo07ooo`1C07ooo`;oogl00`1oool2oj0Pl0;oogl0101oool2oomo00;oX23`
4`1oool2oomo000307ooooooO`3oogl000H0Oooo0_nP8?01o`00007ooooo00000ol00000oomo0?oo
O`2D0?ooO`03o`00001oool0Oooo05T0Oooo1_nP8?000`1oooooogl0oomo0002oomo00<0Oooo0_nP
8?000`1oooooX23`oj0Pl00<07ooo`CoX23`00<0Oooooj0Pl?nP8?000_ooO`03oj0Pl07o00000Ooo
ool00003o`00003oogl0oomo09D0oomo00?o000007ooo`1oool0E01oool2oomo0080Oooo1_nP8?00
0`1oooooogl0oomo0002oomo00GoX23`00<0Oooooj0Pl?nP8?000_nP8?02oomo000407ooooooO`3o
ogl007ooo`;oX23`0P1oool4oj0Pl00307oooonP8?3oX23`00;oogl00onP8?01o`00007ooooo0000
0ol00000oomo0?ooO`2E0?ooO`03o`00001oool0Oooo0500Oooo0_ooO`0207ooo`;oogl00P1oool6
oj0Pl00307oooonP8?3oX23`00;oogl01OnP8?0307ooo`;oX23`0_ooO`000`1oooooogl0oomo0003
oj0Pl080Oooo0_ooO`0907ooo`7oX23`0Ol00001ooooo`0000?o00000?ooO`3oogl0U@3oogl00ol0
0000Oooo07ooo`1@07ooo`;oogl0101oool2oj0Pl0;oogl01?nP8?000`1oooooX23`oj0Pl004oomo
00;oX23`00@0Oooooj0Pl?nP8?3oX23`0oooO`0407ooo`;oX23`0`1oool2oomo00X0Oooo0Ol00001
ooooo`0000?o00000?ooO`3oogl0UP3oogl00ol00000Oooo07ooo`1A07ooo`Coogl00_nP8?0207oo
o`WoX23`1OooO`03oj0Pl0;oogl00P1oool2oj0Pl003oomo0?nP8?3oX23`00;oX23`00@0Oooooj0P
l?nP8?3oogl0201oool1oomo007o00000Oooool00003o`00003oogl0oomo09H0oomo00?o000007oo
o`1oool0D01oool5oomo00@0Oooo2OnP8?05oomo000307ooooooO`3oogl000@0Oooo1onP8?001Ooo
O`3oX23`oj0Pl?ooO`00Oooo00?oogl00_nP8?0207ooo`7oX23`0Ol00001ooooo`0000?o00000?oo
O`3oogl0UP3oogl00ol00000Oooo07ooo`1@07ooo`;oogl000<0Oooooomo0?ooO`001@1oool:oj0P
l0;oogl0101oool2oj0Pl003oomo001oooooogl000GoX23`0_ooO`0407ooo`;oX23`00?oogl0oj0P
l?nP8?000P1oool1oj0Pl07o00000Oooool00003o`00003oogl0oomo09L0oomo00?o000007ooo`1o
ool0DP1oool4oomo00<0Oooo00?oogl0oj0Pl?nP8?002_nP8?000`1oooooogl0oomo0002oj0Pl003
oomo001oool0Oooo00;oX23`0_ooO`0507ooo`;oogl00_nP8?001oooO`00Oooooj0Pl?nP8?00Oooo
oj0Pl?l000000Oooool00003o`00003oogl0oomo09L0oomo00?o000007ooo`1oool0E01oool2oomo
00<0Oooo0_ooO`0;oj0Pl00307ooooooO`3oogl000?oogl00P1oool2oj0Pl0;oogl01@1oool2oomo
000407ooooooO`3oogl007ooo`;oX23`0P1oool1o`00007ooooo00000ol00000oomo0?ooO`2G0?oo
O`03o`00001oool0Oooo05H0Oooo0_ooO`0307ooo`;oogl02?nP8?0607ooo`;oogl00`1oool2oomo
000307oooonP8?3oX23`00;oX23`00?oogl007ooo`1oool00_ooO`0207ooo`?oX23`0Ol00001oooo
o`0000?o00000?ooO`3oogl0V03oogl00ol00000Oooo07ooo`1E07ooo`;oogl00`1oool2oomo00So
X23`00?oogl0oj0Pl?nP8?000`1oool2oomo00<0Oooo0_ooO`000`1oooooX23`oj0Pl002oj0Pl003
oomo001oooooogl000;oogl00P1oool3oj0Pl07o00000Oooool00003o`00003oogl0oomo09P0oomo
00?o000007ooo`1oool0FP1oool3oomo00OoX23`00?oogl0oj0Pl?nP8?000_nP8?03oomo00<0Oooo
0_ooO`0707ooo`;oogl0101oool2oomo007o00000Oooool00003o`00003oogl0oomo09P0oomo00?o
000007ooo`1oool0F@1oool6oomo00_oX23`0oooO`02oj0Pl080Oooo0_ooO`0507ooo`;oogl00P1o
ool2oomo000307ooooooO`3o0000007ooooo00000ol00000oomo0?ooO`2I0?ooO`03o`00001oool0
Oooo05P0Oooo0_ooO`0307ooo`03oomo0?nP8?3oX23`00KoX23`00<0Oooooj0Pl?nP8?000oooO`02
oj0Pl0Coogl00P1oool2oj0Pl003oomo001oool0Oooo0080Oooo0_ooO`000`1oooooogl0o`000001
ooooo`0000?o00000?ooO`3oogl0V@3oogl00ol00000Oooo07ooo`1K07ooo`?oogl00_nP8?000ooo
O`3oX23`oj0Pl006oj0Pl00307ooooooO`3oogl000;oX23`0_ooO`02oj0Pl00507ooooooO`3oX23`
oj0Pl?ooO`000`1oool2oomo0080Oooo0OooO`01o`00007ooooo00000ol00000oomo0?ooO`2I0?oo
O`03o`00001oool0Oooo05/0Oooo0_ooO`0207ooo`;oogl00_nP8?000oooO`3oX23`oj0Pl003oj0P
l00307oooonP8?3oX23`00;oX23`00D0Oooooomo0?nP8?3oX23`07ooo`02oomo00@0Oooo0_nP8?02
oomo0080Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0VP3oogl00ol00000Oooo07ooo`1H07oo
o`;oogl0101oool2oomo00;oX23`00@0Oooooj0Pl?nP8?3oX23`0_ooO`000`1oooooX23`oj0Pl002
oj0Pl00307ooooooO`3oogl000;oX23`1_ooO`02oj0Pl0;oogl00P1oool1o`00007ooooo00000ol0
0000oomo0?ooO`2J0?ooO`03o`00001oool0Oooo05P0Oooo0_ooO`0607ooo`;oX23`0P1oool3oj0P
l004oomo0?nP8?3oX23`07ooo`?oogl01?nP8?08oomo00<0Oooo0OooO`01o`00007ooooo00000ol0
0000oomo0?ooO`2J0?ooO`03o`00001oool0Oooo06D0Oooo0_nP8?000`1oooooX23`oj0Pl00307oo
o`04oomo0?nP8?3oX23`07ooo`;oogl0101oool2oomo00@0Oooo0OooO`01o`00007ooooo00000ol0
0000oomo0?ooO`2K0?ooO`03o`00001oool0Oooo05T0Oooo0_ooO`0907ooo`CoX23`1?ooO`000`1o
ooooX23`oj0Pl002oj0Pl0`0Oooo0Ol00001ooooo`0000?o00000?ooO`3oogl0V`3oogl00ol00000
Oooo07ooo`1I07ooo`;oogl00`1oool2oomo00@0Oooo1?nP8?05oomo00CoX23`1@1oool2oj0Pl080
Oooo0_ooO`0107ooo`7o00000Oooool00003o`00003oogl0oomo09/0oomo00?o000007ooo`1oool0
E`1oool2oomo00D0Oooo0_ooO`0507ooo`?oogl00onP8?000`1oooooogl0oomo0002oj0Pl00307oo
ooooO`3oogl000<0Oooo0_nP8?001P1oooooogl0oomo0?ooO`00Ooooo`00007ooooo00000ol00000
oomo0?ooO`2K0?ooO`03o`00001oool0Oooo05L0Oooo0_ooO`0<07ooo`;oogl000@0Oooooj0Pl?nP
8?3oX23`0P1oool00oooO`3oX23`oj0Pl002oj0Pl003oomo001oool0Oooo00@0Oooo0_ooO`0207oo
o`7o00000Oooool00003o`00003oogl0oomo09`0oomo00?o000007ooo`1oool0G`1oool2oomo00L0
Oooo0_nP8?0207ooo`03oomo0?nP8?3oX23`00;oX23`1`1oool2oomo0080Oooo0Ol00001ooooo`00
00?o00000?ooO`3oogl0W03oogl00ol00000Oooo07ooo`1O07ooo`;oogl000@0Oooooj0Pl?nP8?3o
ogl02`1oool2oj0Pl0T0Oooo0OooO`01o`00007ooooo00000ol00000oomo0?ooO`2L0?ooO`03o`00
001oool0Oooo0680Oooo0_nP8?000oooO`00Oooo07ooo`0507ooo`04oomo0?nP8?3oX23`07ooo`;o
X23`0`1oool2oomo00@0Oooo0OooO`01o`00007ooooo00000ol00000oomo0?ooO`2L0?ooO`03o`00
001oool0Oooo06T0Oooo0_ooO`000`1oooooogl0oj0Pl002oj0Pl00307ooooooO`3oogl00080Oooo
0_ooO`0407ooo`7oX23`0Ol00001ooooo`0000?o00000?ooO`3oogl0W@3oogl00ol00000Oooo07oo
o`1X07ooo`;oogl00P1oool01?ooO`3oX23`oj0Pl01oool2oomo00P0Oooo0OnP8?01o`00007ooooo
00000ol00000oomo0?ooO`2M0?ooO`03o`00001oool0Oooo06`0Oooo1?nP8?0707ooo`;oogl000<0
Oooooj0Pl?l000000Oooool00003o`00003oogl0oomo09d0oomo00?o000007ooo`1oool0I01oool2
oomo00H0Oooo1OnP8?0207ooo`;oX23`0P1oool2oomo00;oX23`0Ol00001ooooo`0000?o00000?oo
O`3oogl0W@3oogl00ol00000Oooo07ooo`1T07ooo`;oogl01@1oool2oj0Pl080Oooo0_nP8?0207oo
o`;oX23`101oool2oj0Pl07o00000Oooool00003o`00003oogl0oomo09h0oomo00?o000007ooo`1o
ool0JP1oool2oj0Pl080Oooo0_nP8?0907ooo`7oX23`0Ol00001ooooo`0000?o00000?ooO`3oogl0
WP3oogl00ol00000Oooo07ooo`1^07ooo`;oX23`1`1oool3oj0Pl07o00000Oooool00003o`00003o
ogl0oomo09h0oomo00?o000007ooo`1oool0JP1oool2oomo000407oooonP8?3oX23`oomo00L0Oooo
0onP8?01o`00007ooooo00000ol00000oomo0?ooO`2O0?ooO`03o`00001oool0Oooo06T0Oooo0_oo
O`000`1oooooX23`oj0Pl00407ooo`;oogl0101oool1oj0Pl07o00000Oooool00003o`00003oogl0
oomo09l0oomo00?o000007ooo`1oool0K@1oool2oj0Pl0Koogl00`1oool1oj0Pl07o00000Oooool0
0003o`00003oogl0oomo09l0oomo00?o000007ooo`1oool0K@1oool2oj0Pl0Koogl00`1oool1oj0P
l07o00000Oooool00003o`00003oogl0oomo09l0oomo00?o000007ooo`1oool0L@1oool2oomo00<0
Oooo0_ooO`0107ooo`7o00000Oooool00003o`00003oogl0oomo0:00oomo00?o000007ooo`1oool0
K@1oool2oj0Pl00407ooooooO`3oogl0oomo0080Oooo0_ooO`0107ooo`7o00000Oooool00003o`00
003oogl0oomo0:00oomo00?o000007ooo`1oool0K@1oool2oj0Pl080Oooo0_ooO`0507ooo`7o0000
0Oooool00003o`00003oogl0oomo0:00oomo00?o000007ooo`1oool0L@1oool2oomo000307oooooo
O`3oogl000;oogl00Ol00001ooooo`0000?o00000?ooO`3oogl0X@3oogl00ol00000Oooo07ooo`1c
07ooo`Coogl00Ol00001ooooo`00ool0000Po`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00348436, 0.00348436}, {{0, 287}, {287, 0}} -> {-0.122445, -0.122445, \
0.889355, 0.889355}, {{0, 287}, {287, 0}} -> {-0.122445, -0.122445, 0.889355, \
0.889355}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Image classification", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1, pdf1, pdf2, {Red, Green}];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2, pdf1, pdf2, {Red, Green}];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1, class1}, {obj2, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55495 
%%ImageSize: 400 221.978 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.013213 0.47619 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.013213 0.477324 0.264889 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7E7E5CBCCC7D1D2CDECECEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F8F7F3DCDBD7B2B1AF7E7D7B4C4B472E2D2935343053524E
777672A5A6A1CCCCCAE9E9E700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00DCD8D59C999466635C3F3C3527241F2D2A25282421302C29322F2A2F2C27
2926212827222E2F274748428B8C86EDEEE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F6F7F2AEADA943403B221D17211E15302D243C3731433E3A443F3B4C4441524B45554E48
544F494D4A4137342B2222181B1B135E5F59D0D1CC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E0E1DC
7D7C7734312A1D181228241B353128413D3440393339312E3D3532423836473E3949403B
4D443D50493F494238433F363532291D1D153E3D39ADACAA00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3E3E15F5E59
28251E2521181F1B1237332A403C333B372E37302A342C293F3533403634433834443933
3F342E3F362D483F364A43394B473C3C39302825202A2925A5A5A300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F4F4F27B7A7525251D
2C2920242017322B21463F353B342A4740363D342D342B26362F29352E283C332E393029
3B322B4A41384F473C423A2F433F334A483C37342D1F1E193C3D38D6D6D400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3A09B28251E26231C
2F2A24261F17342B244A4138372E253F362D494039393029302722382F2A3D342F362D26
433A31534A414F453B40362C403A2E4A463B46433A2827221E1D196E6E6CF4F4F400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFF5F4FFF6F3FFF4F0FFF4F0FFF5F2FFF5F2FFF6F2FFF8F3CBBEB83C332C2017122A231D
312A242A231D2D221E463B37392E2A2E231D4237333F34303227213B302A443933382D27
3E342B4F453C493C343A30273A3128453E34514D442B2A2523221E21211FABA9AA00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFEEE8E8D1CBE1C9C5D8C3C0D4C2C0D5C3C1DBC9C7D2BDBCD5BBBCDEBEBFD1AAABC09495
CC9A99CB9894C48F89B9847EB7857EAF7E77A0756E92706760453C27150B251812312823
2E24222A201E291E1C382D2B4136322F2420372C283A2F2B3A2F29423731514640433832
3F362D4A4037362C2330261D372E25474038443F392B282326221F1B1716484242E7DEDF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDEDEDAFAFAF6A6A68
6565636566616565636667626768636A6B668E8E8CBBBBB9D3D3D1E8E8E600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FCD5CE
BF897F894D42A47065A97C76825D5783625DA4817FA27A78A47474B37978A55D5E8F3E3D
A34A46A64741A6453C9F3F33A34539953D3186382B7A3C2F5F332633150B28150E352724
3329272E24222A201E2C2220342A28372D2B382D293D322E393029443B34534A414F463D
4740363E372D302720281F1841383148413B372F2C2D2523251C1D271B1B251214887473
DCCAC6E0D1CAE6D9D1E9DFD6F1E7DDF8EFE6FFF6EFFFFDF500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEECACAEAB5959572525231A1917
1716121918131B1A161E1D181718120F100A1A1B1623241F2C2E29474944646663878986
AEB0ADE2E4E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFEAE7E5AEA9B26960
9C493B903D2DD08B7CBD83789867608E635D9467629A6764A96C6BC37978C86E6DA9413E
BB4A44BE473FC84D45C54B40C54D3FBD4C3EA33F2FAB584881433442180C2C0F0934211D
3729263328263126242E24222B211F2F2523382D293A2F2B3A312C3F362F423932403931
3F3B3239352C37302A3F383238302D362E2B312927281E1D2D1F1F3420222B0E1040211E
513329593C2E6D5241644E396D5941745F4A7B6955806D5C897665917E6DA18C7BAE988A
BAA496C8B2A5D5BDB3DBC4BCE0CBC6E6D3CFECDAD6F1E2DFF4E9E5FAF0EE00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00F2F2F0AFAFAD5757551E201B1516111F1E1A201F1B
1C1B161C1B162926212828201D1D151D1E161D1E18181913161711161912151712161815
1719164E504DD6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F5FFCECAD0837DB64F46BA4A3E
B045359C3D2BE29585C6887BB48075976860A3736FB27C7AAD6D6BCA7C7ADC7E7CB44845
C34E47C24740D3544DCE4E45CF5145CA5043AE3E30BE5D4D964A3C50160A360E06391D19
3723223424243A2C2B2F24222F2420302521342623332824372E29372E2938312B3A332D
3E393336312B362E2B372F2C2B23212B23212B2122302222352123381B1D320A0B552521
6A392B6B3B257A4D305E36125F391258350B5B350E5B3510552F0A59330E5C3410693E1C
5C2D1168341E672E1B632A19672F226E3A2F73473E734C4576554E7A5D578265618D6F6D
957673A58683AF908DB99A95C4A7A3CFB3AFD9C0BCDDC8C5E2CFCBE7D5D1EDDEDBF3E4E1
F9EBEAFEF3F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00C6C6C465666123241F171813151611191A15201F1B21201B
2F2C27302D26342F2937342D37342D39392F33332B26271F1C1D15181911151811131510
1217131015114A4C4BD2D4D300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F4DBAFACB4615BB6463BCB473BD04B3C
BF4635A83F2CE89583CB8878B97F73AB756BAF766FAA6D689D5652B6615EDB7873BF4E48
C94E47CC4B45D24D46D55047D14C43D04D43BC4034C25143BB5B4D6D1F124307003F120D
3F1D1B3A201F3723223523213A2B283A2B283D2E2B3B2D2A3328263026242E24222F2724
332B282C24212A222029211F2920212B21222D1F1F331F213E2123381112390605652A24
7D3F307C4026915B37794A1E794D1E754B197E5221805423764A197446157545177F4A1E
6F330E77351585391F873B247E35247A362970372C5A2A20542C244B261E4A231E4A2220
502723542B27542B25572E28532C254F2A224C2B24563732593C3660453E684C496F5652
745C587D6561866E6A937B779C8782A9948FB5A09DC1ACA9C9B4B1D7C2BFDEC9C6E5D0CD
EAD7D3F0DDD9F6E7E2FBEEE8FEF5EEFFFDF2FFFFF4FFFFF3FFFEF500FF0000FF0000FF00
00FF0000FF00E2E2E08888863435301C1D181A1B161C1D18191A151617122A2924393631
403B3538332D322D27322D2734312A38352C33302731312734342A2E2F2722231D13160F
171914161815181A19505251D6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FCD3CFA15650BC4A40D24A3ED44537D24635
C64736AC3D2AE68E7AC77C69B97465A76356904A40A65B559D4843C0615BE87B74C14840
CE4D47D14A44D64D47DB5049D84D46D54B41CB4136C94539D55D4FAE4436731910540B04
49120D451C183C1D1A381F1B3A25203C292542302E40312E3A2F2D3E33313429272D2321
342A2933292831272833292A302426312323341E203A1C1E441C1D3E0B0A480806753128
8A46338D4D32AB775294673D855C2E845E2D8A653198703D926A37956C389567369C693A
975C309B57308D3E1D8F3F249247308C4A3A6731275A2F288A685E85645B7C5953835D5A
8259555C302D643933653D35522C23542F2657352C59382F502F26502F264D2A264C2925
4F2C2848251F4E29234E2923502922532C25502922522923562924602D29682E2A6F342E
773E377D493E805044825B4A7F634E7F6B508D8262948E6C9D987AA7A58CADAC9ABBBBAF
C2C3BBA8A9A34D4E491D1E191C1D1721221C1D1C181E1D191F1E1A26252143403B312E29
2C2723302B2728231F2B26202F2A24312C2628231D28231D302D2633332B31302B23241E
1718131516111C1C1A191917505050E0E0E000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF6F3DCA098A7453AD04C40D64234D74132D54433
C74231B13928E27B68EB907DCC7466B75F53B55B52C5645DD16A63F0817ADF645DCA473F
D54C44D84B44D74840DD4E46DE4F47DD4D44D7443ACC3C31DD5346D25245BA453B8C271D
5F0F0653130A4B1610461914411C16401F1A3B1D1B3B212039211F3C2726372322362221
3A2828362424301C1D372123391F223C1C1F3E16174715164D0F104E040365120C903C31
9746339E563DAE76538F5F3782572D7852256B4518724C1D744C1B895F2D865A2B8E5B2C
884F229E5D33A45834974A2C954D358A4B3A55231A835D54AD8C83A1837BA88581B8928F
976E6C59302E633A36502922805B5298766C97756B916F658D685F8C655E8A615B875C56
865D577D544E774F47734B436C443C663B326539305B2A23692F2B6B27247C2E2A802D27
7D2A227B2D20722B19682E165227055C3F1567562260551F5A52235B562E5D5A3B5F5E49
3D3E301011091516101E1F1920211B1F201A201F1B1F1E1A1A19153A39353A3732292621
29262127241F25201C322D292F2A242B26202C24212B26222C272326231C2B282335342F
23241F191A151C1C1A1D1D1B16161689898900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFE7E3B76861BE4C41D3493CD64031D73F31D03D2D
D44736C23D2CDD6453FD8A78F38176E8736AE66D65DD605AD85952D8534CCD443CD3463D
D84A40D7473EDC4941DD4841E14C45DD493FDA433AD74035D94539DF5042DE5447CF5143
B1413389271A6B140A570D0453120C511713481512491917441B194921213A13143C181A
3E1A1A3C181841191A4115164715184B1012530D0F5807066607057A110D9F322BAD4336
AA4B379E4C34B26F5299614083512E885A387448255E340E6F451B7D52276D40177A4920
743E12995B32A86240944D3195533D7B41336C3D35B08B83B19089AE9088B59290BE9798
724A4B5B3435512E2C674641B3928BAC8E84AE8D84AA887FB68D87B58883A77672A77671
AB7E78A98179A38178A080759A7C7199796E96746A976C65A7726E7B37347B2725963934
97342E94342689341F8039196C380988642A856C29786721766B2B79723B817C528E8D6F
65645208080016160E23221D24231E21201B27241F201D181A171243403B2B2A25201F1A
2625201E1D18231E184B443E35302A25201A2D28242B26222A2521231E1A2A252135322D
3C3B361B1C171616141D1D1B181A1740423FE4E4E400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECC3BFAC4F47C84A3ED94B3DD64031D94133D43E2F
DE4B3BD84B3ACC4434DE594AD85247D95048DA4F48D4473ED4453DD24239D6433BD8443A
D64238D9453BD94239DC453CDF463EDA4237DA4139D84035DC4236E0483AE95345E45746
D85344CB5040AF3D328F291D72140C610C075B0C08570D0A5912105612114E0C0D501011
4D0D0E521011520E0F52080959090C5F06086C080A8212119F2522B4352EC5453CBE4638
B04734A54A35B86C54AE6C52A1654BA56D549761478350338B5A3A885736804E2D8C5634
7F4422B57655B372549151388E5341632F228F645DC8A39DBD9A94C09D99CDA6A7AB8286
62393D663F424D2B2A997A77B79893B1938BB4918BBE958FC796928D5653854A46864C48
8150497B50497D5B52A5897EA58A7FA4897EA4867CAC857EBD8785702C2B7D27269E3C39
9A332C9D392A943A22883C18793F0D9B72328D71278170227E712B8B8247948D5F9E9B7A
7978640E0E0217170F26252025241F221F1A27241F23201B201D18403D3835342F1E1D18
20211B191813231E1859544E35302A241F192A252126211D241F1B26211D25201C2C2924
41403B23241E191A151B1B191F211E20221FAFAFAF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF4F2C68F8CAE4740CE4940D64739DC4638DA4235DB4335
DE4839D84436DA483BDD4B3EDE4C3FDF4C42D9453BDA463CD9453BDC453AD94136D94136
D84035D94136DB4338D84035DA4036D83E32D93F35DC4236D93F33E2483CEB5346E55143
E05141DE5243DE584CD8584DCC5046B53E36A3322C8E211C8317147B120F78100F740C0B
700A08740C0B7D13138115158D1A1D9E2627AE2E2DC8413ED24440D84B42CF463CC84A3C
B74837AC4B3AC57260AC6352A05B4BA461519B59499F5E4CA46651B1735E9F5E4AA96854
A3614BB1705CAC6D5B995E4E774336603129966D67AF8A84AF8986B6908FCAA0A4895C63
673C4360373B664242C19F9DC1A09BC09D97C29995DDABAAB2757477312F944A4797524D
8D544D6839316B443DB0928AAC8F87AB8E86AE8D86C39A949F69676622218E3A389C3F3A
9C3B329D402F98442A863E1886511DA1793B8E732C8A7830807533968D549B9468A8A383
89867316140817140D29262125221D25221D26221F24211C21201B33322D3E3D3921201C
1C1B1712110C27241D57524C433F361F1A14211E1724211C26231E221F1A1E1B142D2A23
45453D22231D22231E1D1D1B1B1D1A17191668686600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FEDBD7A45F58BA4941D2483ED9473ADC4638DF4539DE4438
DB4335E0483BE1493CE1493EE2483CDE4639DE463BDE463BDF473ADD4538DD4337D93F33
DB4135DF4539DB4137DA4036DB4135D93F33DD4337D93F33DC4335E1483AE85042E95143
E85243EE5B4BE85649E9594EE95D50EE6459EA6459E46157E15E56D34F4ACF4E48CC4B46
C2423FBE3E3BC44443D95757D75253DA5050E15150E34F4BE74F4ADE4942D7493FC94739
B74636AC4B3AC87565B86F60A15C4D9B594B854335884638935143A56355955345975547
955647985A4D885043B17F745A2E257E5750B8938DAD8A86B28C8BB99192AD8085693C43
70464A50292C866262AB8987A88782B08B85BB8B8BD096958E46478333329E4D4A9D524D
91544F5F2E27916A63C2A19AB99C94BA9D95BF9E97CEA7A2794645713433934747994844
9A483D9548368F472F804422916234A8854D977D408F7D3F8C7F489C9463A19972ACA789
9996831F1D1113100928252027241F26231E27232021201C25241F23221D33322E393836
1918140B0A05312E274C494249453C1F1B121D1A13211E17221F1A1E1B161D1A133A3A32
3E3F3721221C21221D1B1B1919191713131130302EBABAB800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF7F5DFAAA49F483FC44B40D64A3DD84637DD4738DF4539E3493D
E95144E85043E3493DDC4236E2463ADE4438E0463AE2483CDE4438E3493DE4483CE2483C
E04739DF4739E2483CDE4438E1473BDF4539DF4638DE4537E04737E14838E64D3DE64F3E
EB5544ED5746F15E4EED5B4CED5B4CEE5C4DEB5C4EEE6052ED5F51ED6154EE6157F3665D
EC615ADE554FE55E5BF66E6EF16767E55658EB5757EB5350E54D48E04B44D44439CA4639
B74636AB4C3AAE614FA36250995E4C9C65519A634F9F6756955D4E9961549860539B6559
9561548E5E527F534AA67E7663403AA98883C19F9DBB9997C6A09FD8B0B18D636763393D
623B3C563433B49592B69794B79691B8908ECD9797BB76797E2D2C9B43429F4A479B504B
7E433D62332BAB867EB08F86B0928AB4968EBE9D98A8827F6D3F3F875453905654915650
965C51925A4B8F5C4983573C9672509D8058947D51917E538F82589C936CAAA18298927A
B6B3A2413F330C0B0623221E28272324231F24231F22211D2524201F201B22222033342F
34332E24241C2F2C2535322B3C3930221F161E1B1217140B19191120201832312C3B3C36
2728221F201A201F1B21201C1C1B171A19151716122C2D28858583A4A6A3D1D3D0EBEDEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF0ECB9766EAA453BCE5044D44638DC483ADA4435E85043F0584B
EA5245E44C3FDB4336DE4639E0483BE1493CE24C3EDE483AE34B40E1493CE0483DE34B3E
DF493BE14B3DE0483DE34B40E1493EE1493CE1493BDF4837E34C39E14C38E24F3BDE4E36
DE5136E85C41EE6249EE6249EC6047EA5E45EE624BE95E47EE624BEB5E4AEB5E4CEC5F4E
EB5C4EE95B4FEB5E55F96B67FA6B67EB5A57ED5854EB534EE74E48DD463FD44137CB4539
BD4A38AF4E3B8A3C268F4E38894F378B553D834F378A583F8E5C458757418556428A5D4A
8F66548B665484635487675C6C4F47B29591BFA09DC09E9CCDA6A7C9A1A2683F456D4649
4E2C2B896A67C6A9A5BC9D9ABD9B99CB9F9EE5A9AB974C50832B2AA64B4AA14B4A9B514E
5D2621865B54BD9890B19089B89790B89591CCA4A27C525367373782504F65322F703D39
68382E75473A693F2F623C297250375B3D21684D2F58412279664887785B7F7359948C77
BAB5A299978A1C1C1416151022211D25242027262221201C22211D1D1C1822211F282723
28272233332B3A37323C393239362F312E25312E2527271D33332B3837323A3B35262721
22231E1F201B22211D2625231D1C1A201F1B1716141313115F5F5D6163606C6E69858681
A3A49FC9CAC5E7E7E500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00EECDC8A05248BF5045D14D41D94A3CDB4739E44E40EB5547ED5749
E54F41DD493BDE4A3CE14F40DB4C3EDA4B3DDD4E40DC4D3FE14E44E35144DE4B41DE4C3F
E04E41E04E41E14D43DF4B41E14A41DD463BE04A3CE04A39DF4E39E0543BD44D2FCD4D2A
CF512BD1562DDC6138E1653FE86C46E46844DF6341E06442E16241E56444E76446EE664C
EC614AEC5F4BEE5F4FF26355FA675DE9564CE8514AE75049E14A41DD463DD6433BCD4539
C74D3EAC45328A341DAC6247AF6C4FA96C4D8C543395603E8C5A3981533181563485613F
7F5E3D674D2C6F5638725A42593F309E8277C3A29DC4A19FD9B2B39F7778633C41633F43
4E2E2FB69896C2A4A2BE9F9CC29C9BD8A6A7D08E907C2C2F95393AAB4D4DA25150823E3B
5B2824AF8682BE9B97B69590BC9995C9A09EC191915C282A763B3DAA706E8C524E97605B
9E6C659869618E6257865C508D66577F5A4894715D664631846853A2897375634DA89C86
B7B09DCDCAB98583771C1C141516101F201B29282425242025211E25221D211D1A1D1C17
1F1E1A2625202C2B272F2E2931302B32322A32322A34342C34332E2B2C2626272221221D
1F1F1D1A1A182624252624251B1B1B20201E1515151313116E6E6C6F706B6B6C6677776F
77776F75776C7E7F77999C93BCBDB7E1E2DCF5F6F100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FFF7F5C1948F9B4339C84F44D1493DD7483AE24E40EC5647EF594AE85244
E24E40E65445E05141DC5041D54C3CE1594BEB6154E85C4FEB5D51ED5F53E85A4EE4564A
E6584CE5574BE5554CE5554CE45449E35046E65447DF503FE45944D85539DE6342E7734C
D56639D96D3ED5693AD86C3EE27648E4774CE07348D86B40EC7D50D7633AE16B43E76D48
E76646E86245DF573DE45942E25541DE4F3EE14F40DF4B3FE34C41DD463DDC483ED2453B
CC4C3FC04C3DAD4834CC7258C06C50BC7050AE6544AB69469B5F3BA16B45986842906942
8D6D477F6540836C4C806B5069503C94766BCAA7A3CCA5A6D7AFB0734A4E6F484D502D31
7A5C5CCCAEACBFA19FC5A3A2CAA2A2E0AEAFA66468752629A54C4EA650519F5554612524
805350CBA5A2B99795BE9B99C29997D9A9A99C61656624268E4848C27B79B26F69BB7A74
AB706AA56C65A26B64B58078BD8880B17F74AF7D729C6E5FA98271A3826F937A66B2A18D
B6AE99D1CEBBE2E0D366665E1415101515131D1C1A2625232C28252D2A2526231E1F1C17
1D1C1822211D26252122211D26252024251F25251D23231B1F201A21221D25252321211F
1D1D1B1919171F1D20211F221D1D1F2626281212141F1F218787877A7A7871706B808076
84847876766A74766977796E727469777870909189B4B5AFD7D8D3EEEEEC00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FCE0DD9C635CA44237CD4F41D2483BDA4839E6503FF15A49EB5544E65041
E95646E65747E25645E96453FA786AFC7D6EFC786BF0685AEE6457F26657F4685BF3675A
F56B60F2685DF3665CF2655BF1645AEE6157EE6255E96050E5604DD2563EE17052F98E6A
DA754BF49265F39164ED8C5FF19264EC905FF59968F39562F69864DC7C49E5814FDE7546
E5764BE5714AD55D38D85C3AD25332D65337D74C35E25140E14B3DE34C41E04C42D8483F
D54B41D65447DA5F50D5624FCC5F4ACC664DCA684DC76C51CB7A5DC37C5EAB6E4FAD7A5B
A9826387684B9E8368987E678366569F7F74CDA7A4DEB6B7BB919562373E6F484D522E32
AF8F90CCAEACC5A7A5C7A8A5D6AFB0D4A3A67B3E438A4347A15559A0585B894D4D562624
AD8784CBA9A7BF9D9BC49E9DD1A0A3D89DA17B3239873539A34D4CC8706CB05D55BD6F65
A55B529A514A9C564EB8726AC68078A25E55A25E55995B50905B4B8D6251A3826FBEA996
B9AE9ACBC6B3F3F1E4AEAEA631312F454547282629171518201F1D322E2B332F2C2D2926
27232027232024201D231F1C22211C1F1E1924251D23241C1B1C161D1E19222220222220
1E1E1C1E1E1C1F1D202220231F1F211F20240D0E135B5C61A2A1A67C7C7C7A797486867C
8A8A7E8182748384768082757E80737A7C6F75776A7173686B6D6286877FA2A39BC7C8C2
E5E6E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00E4C1BD8A473FB1493ECF4D40D84A3CDA4737EE5847F05946E95342E54F3E
EA5747E65746E15544F26D5CFB7969F07162F97568EC6758EE6656EB6252F3675AF3675A
EE6459F46A5FF3665CF66A5DF46A5FF46A5DF2685BF36B5DF36E5DEF715BEA765DF68769
E87D59F48C65FA926BF79169FC9B71F49569FC9D71F99A6CEA8E5DED8F5CEA8A58EB8756
F98E62ED7E53E7734CF9835DEA724FFD8060E9634AD64834E24E40E34C41E04C42DF4C42
DC4C43E3564CDD5348DF5A4BE05E4ED45A45D45D47CE6049CE6A52C97159C0765DAF735B
87574198725DC8A592C0A091B39187B48F89D6AEAFE8BBC093646C71444B663D436E4A4C
D2B0B1CEB0AEC8ABA7CCAFABD9B7B6BD9395562427743C3F884D4F854F4F603232613B38
CAABA8C6A9A5C2A09FCBA1A3E7B0B5BD777F772229A14246AF4D4AA7463F993F369E473E
A7544CA4544BA75750A95A53A859529D4E47AC5D56A25950A2635493604FA6816FC4AA99
BAAD9AC3BDADE6E2D7E4E3DE3C3A3B3F3E435B585F58555C3C3A3D1A1917181715272322
302C2B403C3B29232328242127262223221D23241E23241F1A1A181C1C1A222222242424
2121212121232422272221261213180C0C140F0F1783838BABAAB0838383807F7A8C8C82
8C8C808B8C7E88887C898B7E888A7D8A8C7F888A7D83857877796C797B7075776C6F7166
7B7C74989993BABBB6DEDFDAF5F5F300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00DAB1AB8F463DBC4D42D44E42D94A3CE65041EF5948EF5948E74F41E54F40
F15B4CE85545EA5B4AED604FED6454E75F4FE96151EA6252E86050EC6353F06455F16558
F1645AF5675DF6665BF06153F36559F26456EF6354EF6354EE6253F16A57EC6754EE6D57
EB6D54E66A4EEE7256EB7255EE7759EB7859ED7A5BF0825FF0865FFF9870FF956EED8059
F4825DED7753EA7250EF7455EA6E52FF8468F46D57D94C3AE35142DE4A3EDF4B41E24E44
DC493FDE4E43E15146DC4D3FE35645DE5241DB5441D95A47CF5C49CB6654BC6957A66152
72392EBB8C84D6ADA7D0A9A4C8A0A0CBA1A3E4B7BEDCAAB378445083515C5F343BA57E81
DCBCBDD2B4B2CCB3AFCDB4B0D5B7B5C8A9A7866262734F4F734D4C674442674845AB8F8B
CCB3AFC7ABA8CDA9ABDAABB1ECADB69747528E2F35B54E51AF4945A6433DB3564EB45B53
B56059A4514BAE5D59994844B86861AF5F58AA5A539F524A995548793F31946958CBAE9C
BEAD9BC2BBABD8D1C7F4F1EC7F7D801E1B223D3A4559565F615F64838184575558262425
2725262422231511122521202D2C2A2928262323212426252021231E1F2128292D292A2E
1B1C2018191E21202815131E30303C4D4F5B23232F666670B1B0B68B8B8B8988838A8A80
8E8E8291938690928781847964675E7E7F7783837B85857D7A7A728B8B818C8C82838377
8183787A7C716E6F67707169878882A8A9A4D2D2D0F0F0EE00FF0000FF0000FF0000FF00
00FF0000FF00
00FF00FFF9F3D1A59C96483CC05044D24C40DB4C3EE75143F25C4DEA5443E54D3FEB5345
EB5546ED5748EC5949F36152E85B4AEC604FEE6555E75F4FE25A4ADA5244E1594BE1574A
E1574CE95D50EA5C50EE6052EF6153EE6253F06455EE6253F16556F06455F16556F36756
EE6552F06955EF6653EF6854EC6853E96751E76650E46850E16A4CE26D4CEC7555EB7253
EA6F50EF7256EF6F54EB6B52E86A53EC6B55ED6653E45B49E95B4DE15146E5554AE25247
DF4F44E15146DF4D40E14F42E24E40E14F40E25345D95040D65748CD5C4CC964589F483F
904540E6A5A3EAAEAEE5AAAEE8ADB3EEB3B9FEBFC8C5838D7F3B468F4D576D343BDAA7AC
EDC1C2E1B9B9E2BCBBDEBABADCB8B8D9B5B5CEAAAACEACABC8A6A5C1A2A0C9ABA9D2B4B2
D3B5B3D4B2B3D9AFB3F3BAC3E294A1862934B4474DBE4C4CBF524DC45C53C5625CCB6C66
C26762AA514BBD6561B35E59BE6964B9645DD27E74B06154AC6354834633A57861CFB199
C4B29CC4BCA9CAC4B8E6E3DECAC8C92B282F36333E413E493E3B44B0ADB4D3D2D76C6C6E
7472754D4B4E5856574442433636361C1D1F23262B24292F1F232C1D212A1E212A191C25
2D2D3712121C201F2D21202E373946555764595B6873737DA9A8AD908F8D928F888F8D81
9192849193869B9D927B7E7540433C5B5C565B5A554E4D484F4E4957574F606056727268
83857A797B708183787C7E7372736B696A6261605C7776728D8C88CECDC900FF0000FF00
00FF0000FF00
00FF00FFF7F2C9998FA04E42C05042D24D3EDB4C3EEF5B4DEE5849EB5546E54D3FEF5749
EC5648EE584AF55F51EE5A4CE75848ED604FF56C5CFE7668F87465F77366F57164F26E61
EE6A5DE56152E76253E96153E25A4CE25A4EE45C50E75F53E95F52ED6152ED6152EE6251
EE6553ED6452F26655F16554F26655F26957EF6654F36C58EC6851EC6851EA664FEB6750
E96550E8644FF06C57F06C57EE6956EE6958F0685AF76F61F46C5EF3695CF06457EC6053
E65A4DE25649E6584CE15146E04D43E24F45E04D43E05246D85042D85649D25950B3433F
A94140B65658B75B60B85D64BC626BC76D76D27780AA4D57A0434BAE535A87353BD2858B
EBA4AAE7A6ACE7AAAFE9AEB4EBB2B8ECB5BAEAB6BAF0BEC1EABCBEEBBFC0EBC1C2E8BEC0
E9BCC1EBBAC0F0B7C0FFB9C4BC5F6A9B2C35CA4F52CC4F4DC94F4AC44F48D96965DA716D
CD6763B1504AC66763CD7069BF655DC1695FEE9688B1604BB3694E925634B78B66CFB18D
CDBD9CCBC4A8C3BDADD3D0C7EAEAE85A595E2E2D353E3C4733313C78777FEDECF25E5D62
383639484649BBB9BABBBBBD5D5E63565A63555B69484F61464E61424A5D21283A2C2F40
A6A8B72D2F3C2C2D3F3031433235442125313133405656609D9D9FA1A09C97948D979589
9495879395889EA0957C7D75555650767570706F6B4C4B474E4F4A4F504A2526205D5E56
484941393B307E807584867B7D7F747F7F777F7C757974704C4741524F4AE4E3E100FF00
00FF0000FF00
00FF00FFF5F1C18B81A75144C55144D24D3EE35446EF5B4DF05A4BE65041EA5445EE5849
ED5749F15B4DF35C51F15A4FEE5C4DEF6050EB5F50ED6356EF6A5BEB6758EF6B5EF36F62
F27060F57461F47360F67562F57260F16D5EF47061F16C5DEC6454E86050ED6452EA614F
E85F4DE75E4CE95D4EE95D4EE75B4CEA5E4DED6150F36756F26754F26754F16653F26655
F26655F36A58F36A58F76E5CF26959F16959F2685BF46C60F56D61F1695DF2685BF46A5D
EF6558F46A5DEE6457F4685BED5F55E85A50E6584EE15349E2544ADB5146D9534ACD4C47
C94D4BC24B4DBD4A4FBE4F55BA4D52B3464CAF4047AD3E44BF5154C85B5EB24B4EAA4A4C
AA4E53AA5359B25D64B05F65AF6066B3666CBA6F74BE767AC47F82CC8A8CD39193D69599
DD9AA1EAA3ABF1A1ACD1767F9F3037C24549D24D4ED24B47D8554DC3443DCF544FD25C58
D3605BCC5D56E27570DA7269D67165D17260D17A5FB56540C37F50925B25A98048CAAF7A
D6C89BD4CEAACFCDB6CCCCC0E7E8E38E8F9124232B4947523C3A4746444FDCDBE1B0AEB3
5C5A5D4F4D509F9D9EEBEBED6D6E73262A3321273720283B253044343F553A4058373C52
BFC2D33D405125263A292C3F9FA5B56A6D7C191B28292933706E71B3AFACA6A39CA19F93
9E9E92A2A296ABADA272736B61605B878681807F7B8485808A8B868C8D8876777182837D
55544F4F50488989818C8C8484847C807D76827974857A767C716B3D342FC3BEBB00FF00
00FF0000FF00
00FF00FFF5EFB97D73AC4E42CC5446D74D40E75548F25C4EE85243E75142ED5748E95646
EE5A4CF35D4FF35C51ED564BF35D4FF35F51ED5E4EEF6251EE6251EF6654E96151E96453
E76450E3624DE86751E4664FEB6A54E86751EE6D57EE6D57EF6D57F2705AF16D58F36F5A
F26D5AF26D5AF06858ED6454E96050E55C4CE55C4CE55C4AE45847EA5D4CE95B4DEA5C4E
EF6153EC6051F16554F26655F46857F36A5AF5695CF06659EF6558F3675AF26659F4685B
F1675AF66C5FF46B5BF1695BF06A5EEC665AEC6359E75F53E05349E6584EE15349E1544B
DD5650D95853DA5E5CDB6362D86464D46060D35D5DD25C5CD1595AD25C5ACF5B5BC95756
C45655C25656C3595BBA5052B44C4DB74F50B44D4EAC4848AD494BAF4D4EAD4A4DAC494E
AE494FAD454CB2434AAF383EC13F41D64E4ED84D48D84B44D94F45D64D45D24B45D5504B
D7544CDA5A51E2665CE26A5CDB6B57D16A4BC26A3CBF7538A66C23805506B39442C0AD61
DAD093DDD9ACD7D6BAD0D2C4E0E2DDBFC3C427272F54525F4B495735313FABA8AFF0EBF1
E3DEE2D6D2D3CCC7CBEBE9ECDAD9DE888B9060646D444A562831421E263D3D425F4E526D
A7ACBF70768615182B262B3E8B91A1787B8A1A1C2925252F38363B928E8DB0ADA8A6A39A
A5A59BA4A69BA9ABA072736B77787262635D6465606A6A686667627475708988849B9A96
9A969383827D8A8782999691999490988E8C988888927E7D998481614E4A988D8B00FF00
00FF0000FF00
00FF00FFEEEAB26F67B55046CD4F43DE5245EE5A4EEF594BE85244E54F40F05D4DEA5747
EF5B4DF66254ED564BF35D4FF05C4EF26150F16251EE614FEC644EEB644EE8664EE7674E
E76B4FE0694BE06B4ADD6B49E06E4CDD6B49E16E4FDE6B4CE16B4FE1694EE66D52E5694F
E66A52E96B55EE6D5AF26D5CF36B5DF66E5EFA7161F46B5BF46756F36655F06254EA5C4E
E95B4DEA5C4EE55847EB5F4EE35746E75B4CEA5E51E85C4FEB5F52EB5F52EC6053EF6356
EE6459EE665AED6859EE6A5DE66659E9695CFB796CF77166ED6056EB5B50E9564CE35348
DC5248DA574FDB625AE1706ADD706BDD716EDF726FDB6E6BDD6D6BDA6867D96663DB6865
D96864D96965D76765D56362D36160D2605FD56561D0605ED0605ECF5F5ED05D60CB585B
C95558C85153C94C50D45254D95350D64D47DA4F48D64C42DB5147D3493FDD5049DF5249
DC4F45DD5348DA5246DB5949D25A42C85E37B55C24CF8B40D5A448BF9D3BC7AF4BC2B356
D8D087E2DFAADEDDBED9DACADCDDD8E8E9EB515159363441555361484452807D86F2F0F5
F3EEF29994986D686CB2ADB1EEECEFE5E6EADFE2E7D5D9E2CFD5E3596073313550545571
84879ACCCFDE434655181B2A23273325273319192521202819171C64605FB9B5B2ACA9A2
AAAAA2A8AA9FA9AAA283847C74736E6667618F8E8A72736E50514C51504C5756526B6764
74706D5C5855696562A098969A8E8EAB9798B99B9DBF9B9DCEA8A7A684827B635FF9EBE8
00FF0000FF00
00FF00FEE5E0AF665FB84D43D24F45E5554AF15D51EF574AE24C3EEF594BEC584AED594B
F36251F05F4EEF5B4DF15F50ED5E4DEF624EEA624CEA664DE7674AE16849E26D4ADF724B
E0764CDA7549DD7D4DDA7B4BD67A49D37748D97C51DA7A52DA7853DC7854DE7555DE7353
E17256DF6D52E46C54E56751E86553ED6555EE6555F46857EF6251F36454F56857F7695B
F66A5BF36758F36756F16554F26657F26959EC6255EC6255EA6053E55B4EE55B50E75F53
E55F54DF5B4FE36358E36559DE6459E1675CFA7A71F26D64F0665BED5D52EC5A4DE25446
D65245CF594BB95146AD5048B35E59B4635FB5615FBD6766C56B6ACA6C6CCD6B6AD67270
DE7874DB7571E07A76DE7673E07974DC7570DD7470DA716DD86C69DA6D6ADB6B6ADB6968
DC6868DC6664DE6463DC605EDC5D57D95852DC5C53D9564CD8534ADD574EDD524BE05349
E05045DF5143E05447DB5643D3573DCA5E37AF591ECC8A3CE9BD5ADABE50D4C252D1C65D
D9D37FE8E4A7E8E5C2E1E0CEE0DFDAF4F4F69A99A1201E2B454351555361595762DDDCE2
D8D6DB57555A656368838186EBEBEDEDEDEFE6E7EBE3E6EBF5F9FF979AA9232439484860
69687AE7E6F4C8C6D18281895A595F4443482A292E1A181D29272892918FBEBAB7B3B0AB
B0B0A8AEAEA6ABABA3A8A8A0A29F989E9E96ABA8A1A0A09896968E8F8E89807F7B61605C
4E4D484D4C475E59569D91919E8588AB878BDBA6ACEFB3B5F6B9B8C38C89714842E7CEC9
00FF0000FF00
00FF00F8DCD8AE635DC05148D65148E5554AF25E54E85146E65042EF594BEA5648EF5B4D
F36251EC5D4CEB5C4CF06351EC644EE6644AE56A4BE16C49DE724CD8754CD2754CD27B50
CF7E51CC7F51C87E4FD18959CA8355C27E51C67E56C67D5AC77C5CC67758C87458C77156
CB7159CB6C56CF6855DE6F5CE56D5CE86958E96453EB6451F06552ED604EF16453F16453
EF6153EE6253EF6352F26655F06455F26657F4685BF5695CF86C5FF46A5DF46A5FF36D61
EC6A5DE4685EE06B61DD6D62C4584EB7483FD7605AEA6B64ED675EE95C52EC5D4FE55C4C
D95A4BCF604F8F33247226197131286C312D6A2E2D7032337A38397A34348A403F924442
9B4C489F504CA04F4CA95854B05D57B4615BBE6964C46C68CA716DCF746FD27371D16F6C
DA7772DF7975DC7370DE726FDA6F69DD7069E3746DDD6C64DF6862E46761E96560E75E56
E05349E25649DB5144DA5848D35C44CE6842BD6C37BA7B34EEC367E3C85FD7C559D8CC68
E0D988D1CD90D7D3B0E0DDCEE1E0DCF0EFF4DEDCE7403E4B3330414744554D4957B7B4BD
D8D5DC3F3D4238333A8E898FF2F0F3EAE8EBE6E6E8E2E3E5EEF1F6C5C8D127283A403E54
454255BFBDCBE9E6EFD5D3D6C8C6C7BBB9BAAAA8AB989697A8A7A5C2C1BFBFBBB8BBB7B4
B4B3AEB7B6B1B6B3AEB3B0ABB1AEA7AEABA4AAA7A0A8A59EA9A9A1A6A69EA8A7A29C9B97
91908B8887827D7573978486AA878DB68189CC838AD88388CE7879AB5D598A4F49CEA9A1
00FF0000FF00
00FF00F1D4D0AA5D55C25348D75249E7574CF25E54E85448E85446EB5749EF5B4DF15D4F
F46253E65948ED6451E46049E66A4EDC6A46DD7349D8794BCC7A4AC88251C18458BE8760
C18F6CC08F6FC29473C49577CD9E82DAAC92E4B49EE3B39FDBAA99E7B3A5EAB1A6ECB0A6
EDADA4EFABA2E79E97D58176CD6959DF705DEA715CE96B54E7634CED654FF06351F06352
F16453EC5F4EF16355EF6052F26355F16254F16355F16355EF6153EF6354EE6255EA6458
E4695ADD6D61D57368CB7169A24B447C211E9B3332C75353E76862ED645CE95C52E86054
E16354CC6151822F1F5A1B0C56261C4C251E4A27254A26264F2829542A2C5A2C2E5E2E2E
5A2A285F2F2B61302C612E2B6B383464312D743F39733C37763B377D403B82413F823E3B
8E4745944A47984D4A994B47994B47A2534FAF5B59B05655B65755C75E5BD35D5BDB5B58
D6514CD6514AD05148CA5446C55C49C66C51BF754EB07440E1B671E7C876DDC771D9CA77
F0E7A2B1AB797E7A5F88867A969696ACACB4BFBFCB5655653D3C4E423F52453E508B8593
F5EFF9BBB6BDA69FA6E2DBE2F1EBEFEBE6EAE6E4E5E1E1E3E7E8ECE5E8EF41435228293D
2B293E797687E9E6EFD9D4D8D1CFD0D3D2D0CBC9CACCCACBCCCBC9CAC9C7C8C4C3C9C5C2
C3BFBCC2BEBBC0BCB9BDB9B6BAB7B2B8B5B0B3B0ABB4B1AAB1AEA7ADAAA3ACA9A4A3A29D
ADACA7B5B2ADB8AEADB89FA2B58A91CA8991AB5059B74E55C35757BE5D57A75D54B08179
FFF2ED00FF00
00FF00E7C8C5A3544DC35348DB574BEA5A4FEE5C4FE85446EE5A4CEB5749F05E4FEF604F
EA5F4CE7604AE7674EE06949DC7147D47442D17F47D08A4FC99158BF915FD3AD86E7C5A9
E8C9B4E6C9B7EACDBFEFD2C4EFD1C6D2B4A9C5A79FC2A39EF2D3D0BFA09EAF8B8DB1888C
B2888CAD7F82CE9A9CFDC0BBDC8F7FCA6E57E1785BE67354EA7152E8684BEC654FED624F
F26655F06352EF6153F26355F16254F16254F26355EE5F51F26456ED6152EF6558E76557
E06C5DDF7A6EA35146D18D8494534F5D17156716158F2D2EC65453E66965E8615BE55F56
E16355D9695B9D4434611E0E48180C411F163A211C372221351F213B25273A2222402627
4026254229254A2C2A452725503230492C2850312C4B2A254F2C284F2926552C2A592D2C
5D302D5F2F2D62312D67363263302D67312F662C2B723232772B2D893032932B2CC14D4D
CB4F4DC94E49BF4C45BF594DB55D4F934A377A3E246F411D886434846A317D692C807136
8B835279755058554255544F56555A5C5C665756643D3C4C3F3E503E3C51413E515D596A
A8A4B2ACA9B4C3BDC9D4CED8DFD7E2E6DFE7E7E2E8E4E2E7E1E2E6F1F4F9848692111320
14132142404DD7D4DBE1DFE2D8D6D7D7D6D4D5D3D4D4D2D3D3D2D0D4D3D1D5D1D0D2CECD
D0CCCBCFCBC8CDC9C8CAC6C5C6C2BFC5C1BEC4C0BDBFBCB7BDBAB5BAB7B2B6B3AEAEABA6
B1B0ACBBB6B3C5B9B9CDB4B7C99AA2D48D95B34F59B23F46C85052C15451B05C52915B4F
EED9D400FF00
00FF00E3C2BDA3534AC35146DC564AED5E50EA5849E55242EB5A49F46352EE5F4EE9614B
E56349DE6546DE6E48D57140D68045D28945CE9249CE9E56C9A567DABF90F0DBBEDFCCBD
BEADA6B3A19FF0DDDFDBC7C9907C7E6F595C5843486D585FD5C1CA6B576268525F6A5262
6C505F6747545E3940C49895FAC2B1C27D5ED07B52DB7A4DE0764CE7764EEA6F4EE7654B
EC6551EB624FF16453F16453F16453F16453F06352F06352ED604FF26657EC6758E36859
E2786AC66E6279362D89574EA47973A67974703634631C1A842928C35554E46866E76660
E46157E1675ACE6353933A2A5F1D0F4315083A1C14301D172E1E1E2D21212D1F1F2E2020
2B1D1D2E201F39272733211F463432392723402F283A27214B36313924213A25223B2623
402826422A28402723482C29402423482A2A442221512728511A1D611B1D691012B34B4C
CA5A58C95955CB6560BB645B9B584F5F2E20441F0F452A154731194435163F35123A3414
3433172A2B193C3C3440404044454A45454F3A39472F2E3E3130423132463A3C5146495C
5455674D4E60535166615F7474718284808F9B95A1DBD8E1E1E0E5E7E8ECC8C9CE7E7F84
65646A545358B8B8BAE5E5E5DBDBDBDBDBDBDADADADADADAD9D9D9D6D6D6D7D5D6D7D6D4
D6D5D3D4D3D1D4D2D3D2D1CFCECDCBCDCCCACBCAC8C9C8C6C5C4C2C5C4C0C2C1BDBCBBB7
ABAAA8A8A4A3B8AEAFC1ABAEC499A2DD9AA3B2535BA33238C24A4CC65652B75D5483473C
CAB1AA00FF00
00FF00E1BEBAA7544CC45247DF594DED5E4EEA5849E04F3EE65746EA5D49E65F49DF5F42
DB6442DB7046CF6F3CD27E40D18941D19646D7A858DBB76DCDB579E7D8AFD8CBB8E3D8D4
C6BBBFBCB2BAE8DCE68175816759665D4F5C392C36B3A5B2988C9A574A5B56495B4E3F54
564359675062452A33957270FFDAC5DCA47FD48E5BD28149DA7F48DE7A48E7784DEC7451
E9694CEB644EED624FF16453F06352F06352F36655EF6251F26554EE6555EA6858E26E5F
D9796BA2584B6430254F2A2272554FB59892B6918B6C393657110F862E2CC35B5ADF6967
E36660E0645ADB6559CB6153913E2E5B1C0D3F130832170E2C1A16271D1B271F1D261D1E
241B1C261D1E312726291F1E3A302F2E2422352C273229243A2F2B3025212E2422342A28
332927372D2B3628272F21202E201F423232352122472A2C4117195C1E21640F12AD4949
CA5A58CC5C58C8655FB161588E554C48231A30180E30221731271B362E21322C1E2C2A1D
2D2D231F201A2929272B2C2E32313735343C36343F2C2A372C2B392A2C392124331A1D2C
2326353235443437483C3D51474658484556464250BCB9C2E6E5EADADADCDDDDDFDBDBDB
DADADAD1D1D1D5D5D5DEDEDEDDDDDDDEDEDEDEDEDEDDDDDDDEDEDEDBDBDBDCDADBDDDBDC
DDDCDADCDBD9DCDADBDBD9DAD8D8D6D6D6D4D7D5D6D4D2D3CFCFCDCFCFCDCFCECCCBCAC8
B7B6B4A09C9BA69DA0AD9A9EC5A0A7E5A8B0BA5F689A2B32C54D4FC65551B85C5188483C
A0857CFFF8EF
00FF00E1BAB5AA574FC7554AE25C50F16252E75546E45544E65B46E35F48DE6143D3613C
E77E4FD77A41D48341CD8539D1933EE2AE58EDC06FD7B470D5BF8DE0D1B2CDC1B5E1D8D9
BCB6BAE8E1E9C0B8C5645C6B5C5461423745706671D4CAD56E6373453C4D5F5667706478
4739506350633B212CB18E8AFFD3BCECB58CF7BA81E7A261D18440D37E3DE08046E67A4B
ED7751E76848ED654FEF6250EF6251F06151F26355F16355ED6150EA6554E26958E37969
C473626F342653281F4A2D2544302959443F9F8681BF9E996E3E3A521512823432B45656
D76A67DD6763E36861DB655BCB6153984032601E103D110630150E291A15271D1B241C1A
292323241E1E29232325201D3C34322A221F352D2A2D26202B241E2A231D362E2B2F2725
322D2928231F271D1B2E2422251B19352A283123223D2427370D1158171B6A1012B54947
D55B56CB5249C05649B4615390584B3F1D132A1710261D1626211B27241F24231E1F1E19
2626241F1F1D1C1C1A1E1E1E211F222321262C272D2621282522291411183F3E43636267
4A4B4F363A3D1E23271F222B2424301D1B281D1A2584818AE9E8EDDBDBDDDAD8D9DBD9DA
DDDBDCE0DFDDE2E0E1E1DFE0E1E1E1E1E1E1E1E1E1DEDEDEDEDEDCE0E0DEE0E0E0E0E0E0
E2E2E2E3E3E3DFDFDFE0E0E0DFDFDFDFDFDFDEDEDEDDDDDDDCDCDCDBDBDBDCDCDCD9D9D9
D3D3D3C9C7C8C5BFC1D2C2C5E2C5CAF6C3CABE6B7391282DC34C4EC4534DBC5E548D4B3F
8C7065FFF6EC
00FF00DDB4B0AC584ECC574DE35D51ED604FE45545E15442E4604BDF634BDA6B4DD26F46
E18755DE8E4FD68E44D99846E5AC55F2C06BE2B86EA8884DDBC59EDBCFB9E3DAD5C1BBBF
CBC6CCEBE5EF777382524E5F413D4EA7A0B0F3EBFA958D9C453C4F3E3749D4CCE1D1C9DE
50445A4C3D50422B35E1BEBCCE9B88BC7D5AF2B07CFFBC7BF1AB63D98C44D6813EE08044
E27645EF7850E96849ED654DEF6250F26353F26355EE6052EF6654E56653DF6E5CD87B69
9E59495C2C1E45271C3D2922402E2A3E2F2A4C3935A9918DC4A5A0683F3B521A19772F30
AD5554CF6766E16B67DF665EDF695DCE64569F493A5F20113C11083017102D1B17261C1A
27221F262221221E1D272322332E2B26211E322D2925201C2A252126211D312C282A2521
2A2722282520221D1A352D2B2A221F342C29312525361D203B11155715196F1014C24E4E
D4554ED15347C65849BB64539157493D1D1026150D211C181D1C181F1F1D1D1D1B1F1F1F
2020201A1A1A1B1A181F1B1A1D1918211D1C251F2121181B140E103E3838B0ACABDCD8D7
C7C7C5B8BAB7A2A6A59094957E7F8466656D4B484F646168DCDBE0DFDFE1E0DEE3DFDDE2
E2E0E3E6E4E7E5E3E6E3E1E2E1E1E1E1E1E1DFDFDFDDDDDDDFDFDDE2E2E0E2E2E2E1E1E1
E5E5E5E6E6E6E0E0E0E2E2E2E4E4E4E1E1E1E0E0E0E2E2E2E2E2E2DFDFDFDFDFE1DFDFE1
DFDFDFE0DEDFE1DBDDE6D7DAF0D7DDFFD7DEC87B83852227BC4849C04F4BBD5F55914F41
8D6F64FFF5EC
FFF7F4DAAFA9AD564CCC584BE76253EA5D4CE25544E45B49DE614DD96B52D07155C87450
D28857DA9659DC9C54EAAD5DF5BA6AE9B5699E7537BD9E70E6D5B9DDD3C7DFD6D7A7A0A7
EAE5ECBFBCC7595669504D62403D52948FA3AAA5B95850654840584F475FA39AB57C748C
50445A352738816B77F6D2D6AD7169B56854CE7A55E3905CFFB672F9B469DF9347D9873D
E28343E67B45ED734CEB684AEF674FEF6250EE6150F06455EB6353E46957DD7461C57461
79402F4C281A3C261B382922382A273527243D2E294E3B35937B77BEA29E8E686550201E
692929A35251CD6765DE6D69E26960DC685BD0695AA34D3E5D1F103C1206331811291A15
251B19231E1B272320282421302C29221E1B312D2A25221D2E2B262C2924322D292D2824
27241F2C292225201C312C2827221F372F2D25191B3A1F244114195A1319761316C54D4E
D8544FD25245CA5B4ABC63518C53423C1C0D23120A221D191D1D1B1618171A1A1A202020
1E1C1D1D1918211C191C17131F1A16241C191C1210251A18746A68CFC7C4DAD5D1D7D3D0
DBDAD6D8D8D6DBDBD9DCDCDCDDDDDFDEDCDFD3D1D4CBC9CCDEDDE2E1E0E6E5E2EDE7E3F1
D9D7E4BDBBC6B7B6BCD9D9DBE0E0E0DEDEDCDCDCDCDDDDDDDFDFDDDEDEDCDFDFDDDEDEDC
DEDEDEE0E0E0DFDFDDDFDFDDDFDFDDDEDEDCE0E0E0E0E0E0E0E0E0E0E0E0E1E1E1E0E0E0
DEDEE0DFDDDEE1DBDDE6DADCF2DBE1FDD4DAC17A82B25359B24143BE4E4ABC5B52975346
937368FFF4E9
FFF7F2D5AAA3A65247CD5C4CE56152E95D4CE25645DB5A47D86854CB6B55CB7B64DD987B
E1A37CE0A470E5A869F5B973F2B771B38041A07847E3C9A8DDCCBAE3DAD3C9C0C3CCC5CC
F9F4FB88828E4E495D504D624D485E5A55695C5469574F64544C64534B635D536C574D65
4237482F2130D1BDC8FFE0E7E9B1B2BE756EBC6A55BD6945D88F58FDB873FBB669DC9346
D58139E58344E77747F1754FE76448EB634DEF6352EE6555E86553DF6A58DB7A67AB6251
5E2F1F40231536251B31262031262231262440322F3D2E2942302C83706AC1A9A5987674
5427246D302F954441C5645EE06F67E16C62DE6D5FCC6657A14E3E62231445160C381710
2A120E2C1A163224212B201E332927271D1B362E2B2C24213029232D26203029232E2721
241F192E2923241F1B2D282429242130282627181B3E212543121860171E7A1317CC5251
D9544DD45245C85745BF67538A513E3D1D0E25140C211C181C1C1A1717171D1B1C201C1B
201B18231B18251A161D130A1D13071910014B3F33A99C93DCD2C9C5BEB88C8783B0ACA9
E2E1DDDDDCDADDDCDAE0DFDDE2E0E1E4E2E3E8E6E9E8E7ECE9E9F1E5E4F2D1CFE4A7A5BB
6E6C814F4E5E514F5AB1B0B5EFEFEFE2E2E2DEDEDEDDDDDDDEDEDCDFDFDDDFDFDDDFDFDD
DFDDDEDFDFDFDEDEDEDCDCDADBDBD9DBDBD9DDDDDDDADADADCDCDCDBDBDBDBDBDBDCDCDC
DCDCDEDDDBDCDFD9DBE3D7D9EED9DEF5CDD5CD878FDC7F87A33538BD4D4BBB5A519D574B
99776DFFF5EA
FFF8F2CFA79FA65448CA5A4CE56355E35B4BDD5847DD6453CC6657CA7769C17F73AF7567
D09881ECB491F8BB8CF8BC86D89C68A87546C7A582EFD9C4EBDAD2DCD1CFC4BABBE0D5D9
EEE5EA918790362D3E40374A443D4F484151463D4E443B4C443B4C43374B3F324436293A
3426338D7D87F8E3ECFDDFE7FFDCE4FDCBCED59691A35B4CB26845D38C58FCB877FBB76E
E1954ADC8540E67F45EC794CF07150EF6950ED6452ED6857E06351DE715DD47B69914E3D
5126163E241738271F2C211B2E25202F2523372E293D322C42352F473831705D57A68F89
8667646F43406B302C8F443EBE6058DC7167E37166DA685DCD6558A84C3F6F2115511108
3C09053B120E43211F361A173D25212E1B1533221B35261F32251F2D201A32251F362B27
281F1A332C2628201D362E2B261E1B3227252E1B1D4324294510185F12187D1418CE5250
DA544BD25042C75844BC6551874E3B3E1E11291810211C181D19181B1718231A1B231918
2A1C192B1C1528160C1F0E002B1D02706343CCC1A3C9BFA67973638F8B82AAA7A2D0CCCB
DFDEDCDEDDDBE1E0DEE3E2E0E7E5E6EAE8EBEAE9EFE1E1EDBEBFD38C8EA7606180565678
6667855E5E76343341747379F0F0F2E6E6E6E1E1E1DFDFDFE0E0DEE1E1DFE3E1E2E4E2E3
E9E4E8E8E6E7E4E2E3E3E1E2E2E2E2E2E2E2E1E3E2DEE0DFDFDFDFDDDDDDDEDEDEDDDDDD
DBDDDCDDDDDDE0DCDDE4D9DDEDDADEFCD4DCD8929ACB6E76A03235C0504EBB5A519B5549
9C7A70FFF3EB
FFF8F2CDA59DA6574ACD5F50E36556DE5B49DA5D4BD46554C26A5ECA847C9F686562312C
8C584DE3AC97F9BD9BDBA078B67F58B28663F2D3BEE6D4C8F1E3E0CABEC0E0D4D8B5A9AD
BFB2BBDED2DC817485605566514958534B5A5E5363625765675C6A655A686C5E6D817380
C3B3BDF5E4ECF9E4EDF9DFEAFBDDE9FFDBE6FFD0D6E2A8A6D69382B56C4BD6905CFFBC79
F9B469DE9046DF8342E87E4AED764EEB6C4CEA6651E76653E36B5ADD7663C1705F773C2C
4C2619422A1E3829222D241F2C24212D2522332C26362D28352A244237314435305A4942
6E59549A7D79A37A747E47408B4138B95F56D87067E5756ADD6B60D16356B853478F352A
6717105E1711662521511612541F1947160F4F231A471F17421D153A180F43201A43241F
371A143F231F3418154024213118143E22213B191A491C2154161B630E138B1A1CD65653
D94F45D65142C95643C469548745353F13082E110B2A15122812142C1316301413331612
381A123114042E1400523C159E8C5AB3A6719086558179529A967DDEDACEE4E1DCE3DFE0
E2DEDFE2E0E3E9E5E6EEEAEBE5E3E6CBCAD0A1A1AD696A7C464861464968595C7F6D7093
5B5C7A3E3C542C293A4E4B54E3E1E6E9E7EAE1E1E3E0E0E0E0E0E0DFDDDEDFDBDCE3DEE2
EAE4E8E7E2E6E6E2E3E1DFE0E1E1E1E2E2E2E1E3E2E0E2E1E2E2E2DFDFDFDFDFDFE0E0E0
DEE0DFDEDEDEDFDDDEE5DCDFEBDBDEFFDBE2C9868FC3666EAD3E44BC4A4ABD5A549D544B
9E7C73FFF3EB
FFF6EFC59D95A8594CCA5F4DE36856DD5E4BD35B4ACF695AB96D60B77E77C6989AB98F91
814F4ED29990F0B29DC08367946345CAA68CE3CDBFDFD2CCE7DBDBC4B7BEF2E2ECDCCCD6
DCCCD9F0E2F1E4D7E8D6CBDCC9C0D1C7BFCEC9BECEC8BDCBC1B6C4BFB5C0D2C4D1CEC1CB
C9B9C3C5B4BEC6B2BDB8A0ADBBA1AEB496A294737EEEC5CBEFB8B5AC6956BA6F48E3985F
FFBF78F2AD60E9974EE18144EA7C4BEC744FE8684DE66955DE6E5ADB7C68A75E4D622E20
4E2C203E2A213528203229243028252D28242C272129241E302923332C263E332F473A34
4C3D3865524C9E827EC7A29AA8736DA55E58B75E58D7726AE7786FDF6A60DA6659CF5E50
BC4C41A73B319B30288D261F88261D7B1D13721A0E6D190E6012065E140B5D140D5F1A13
55120C61221B50110C591C195217135B1F1E5416195E191C610F156E0B0E991E21DB5451
DC4D45D84E41D35848C861508F3D2F4E0B02450B09420F0E3F080B480D0F490C0B4B0F07
4B1302582A08926E34C6AB64B19E52887A31938A49CEC793E9E4C4E9E3D3E9E4E0E8E4E5
EAE5EBE7E2E8D6D1D8ACA9B077767E50505A4042513C3F5243485E4B4F6A656986686985
3F3D552E293D261F2F342C39C9C4CBF0EBEFE2E0E3E1E1E3E0DEE1DFDADEE6E0E4F0E9F0
AAA0A88D878BE9E5E6E5E3E4E0E0DEE0E0DEE1E1E1E1E1E1E1E1E1E0E0E0DFDFDFDFDFDF
DDDFDCDDDFDCDFDDDEE5DCDFEADBE0FFDFE6B87680BA5F68BB4951B94649BC5954A15851
9A786FFFF5EC
FFF6EFC19991AB5C4DCE6351E16654DA5D49D46450C46756C17D7292615DDDB4B89E767E
68353AD49A98DD9D93AB7060A17663EBD0BFCABBB4D5CBCAC4BBBED6CBD3EDDFEC9F91A0
9A8D9E988D9E8E8296898093847D8F867F917C75877E7787716B79716B7779717E7A707B
7A6E7A887A878C7C8987737F8C7683745E6A7D6773F6D8E0FFD8DAC88D85BB6F55C57749
F1AD6EFEBC72EEA459E58E49E68149EA794FEA7152E06850DD725ED47B69995A4B4C2013
452A1F3B2A22372C262F2822332B282E292527221C25201A2A251F2A251F342D2739302B
4439354A3C3955443D806762BC9590CE9794C57C76C86D68C9605AED7B71E47063D76153
D15B4DD15B4DD1584DCD5449C34A3FC14B3FB14032A6382B9E3427912B1F8F2A2089281F
7E20187E211A791F17741B156E17106D18136C14136F13146F0B0D770608A02021DC5250
DB4C44DD5144D25344CF5B4C9A34286A0D065E09065E0A08630B0A660C0B6D1009792012
7C2F15A06233E8BC73EED07AAB953F645502A49C54EEE7B0F3EDC9F1ECD9EDE8E4DFDADE
B7B2B98380895C566047444D46464E454851474B573F425344495C52576A5A5B6F3F3D52
322E3F2B24342D22322B202EA79DA6F4EFF5E3E1E4E0E0E2E2E0E3E3DEE2F5EFF3D4CBD0
261F262B2529D7D1D3F0ECEDE3E2E0E1E0DEE2E0E1E1DFE0E1E1E1E0E0E0E0E0E0DFE1E0
DEE0DFDDDFDEE0DEDFE2DCDEE9DADFFFDEE5BA7B84AF555FBE4F58B54247C05D58A25952
99776EFFF5EC
FFF4EFBB938BA65446D06553E16654D85E49D36652C06958BE7F76906360D8B1B68F666E
A67177CC9092C687829C665CD8B3AAE2CEC7DCD0D0CEC8CCB0ABB1F2ECF6B7AFBE635C6C
6B667A615E735C596E57556B5A586E5C5A705D5B71615F746263776364766B6A7C6F6C7D
6E6A797872807D72827B6F7D736670544750BDADB7FCE7EEFFDFE4EDBDBBBF7A6AC77B59
D89560FFC17FFCB86FF2A55FF19356F48859ED7857DC6A52D7725ED382719C64574E2920
39251C352A242E27212E2623332C262F28222E26232A25212C27232C27232D2522352D2A
3C3431413833463B37523F3B6B4C499F726FC88888ED9E9ACC6D67C05950E68072EF8B7B
E3826FD77461D06555CA5A4CCF5B4CD35D4FCF594BD35D4FD25C4ED35D4FD05A4ECB554B
C44F45BF4D43BC4A40B34338B14237A93A31A33631A1312D9F2C299C2221B63230D54E4A
D64D45D74F43D34F42D05043BE4439A32C249E2721A02923A12A24AC332AB0372CBF4F39
BD5B38B16430F2C175F7D782A9903E8E7E31D7CE8BECE6B2DFDABAC4C1B094908F67646B
4B485145444C4A47504B4A5247474F3F42493C3F463B3E47393C45393C4533313C2C2934
322C382D25322F23312719288F858EF6EFF6E5E0E4E2E2E4E2E2E2EBE9EAE3DFE06A6466
6560643D393AB7B1B3F4EEF0EBE5E5E9E3E3E6E2E1E5E1E0E3E1E2DFDFDFDFDFDFDDDFDE
DFE1E0DEE0DFDFDDDEE2DCDEEADBE2FFDEE7BE808BA9535CBC5159B8474BBD5C56A35A51
9A786FFFF3EB
FFF3EFB78C85A75547D26755E26956D85F4CD26755C06A5BC0847AAB7E7BC29B9EBD9299
C69197C3888AAA706EAA7A76F0D3CFDCCDCAD3CACFBAB5BCD3D0D7ECE9F47D7988636073
615E734D4B603E3C51323045312F452F2D4337354B43445952536855586B424355373948
343341403C4A4B45514C444F3F353D685F64EADFE3F4E5E8F8DFE5FFD8D8CF9186C47D61
C78352FABA7AFFC277F3AE63E78D4EF18956EC7C57D5694FD67765C175679F6B607F5E55
5948403E352E312A242A251F2F2822312A242F2724352D2A2A25212C27232E2623312926
302B27322D294036344738355238375E34357E4242BA6C6CB85955BB544BE88274FD9C8B
FFAF9DFFA894FC9584ED7F6EED7E6DE87765DB6A5AD56454DC6957DA6554E1695BE1695B
E46C5EE86F64E16B5FE26E61DD6C5ED56557D56559CE5E53D05E54CF5A51D35650DB5C55
DF5C52E36154DD594DE05A4FD9534AD9534AE25951E45B53E1584EE05A4EDA5647D65E46
D06946B36332E5B271EDCC85C8B16DBAAA6EAFA57089865D6C6A5158564A4745464B484F
4A49514241494241473C3B4137363B2F303433323726252A27282A2727292B2A2F2C2A2F
2F2A312F252E2C1E2D2315248B7F89F8EEF6E5E0E4E3E1E4E2E2E2F5F5F5A19D9E706A6C
E8E4E57A7677ADA7A9BAB4B6B6ADB0DFD6D7E9E3E3EBE5E7E8E4E5E3E1E2DFDFDFDCDEDD
DDDEE0DDDEE0DDDDDDE2DCDEE9DAE1FFDEE7C38A939A4952CA6168AE4043BD5C55A0584C
9A786FFFF4EC
FFF1ECB1867FAB594DD26757E36A57D9604DD06553C56F60B77B70B98C87C69C9EE2B8BC
C79397B683829D6D6BE1BBB8E4CFCEDED2D4CEC4CCB7B1BBF2EFF8B3AFBD5653645C596C
4440517C78879F9BAA94909E8F8B99908C9BA5A2B35F5C6F535065403D504A4856A9A7B2
A19EA5A6A1A7AFA9ADB5AFB1B8B2B4D2C9CAF1E9E7F0E4E4F4E1E3FFE2E0E3AFA4B27257
BA7846EAAB68FFC778F9BA6ADA8542DA7740E0744DD97156CE7662AD65576F3D347A5952
86756E7E756E5E574F3F3832342F292D2822292420302B272D2522322A273028262B2321
312C28302B27382E2C3D2D2D482E2F5A30326725297D2426A43B38E37069F48277F9897B
FE9484FF9787FF9281FB8D7CFF9583FF9C89FF9E8BFF9E8BF5927FE88371E47A6ADF7565
DD7363DC7264DC7566DA7666DC7D6BDE816FE68978E98979E78676E98575E67A6DF18175
F47C6EF5796DF9796EF57067E75E56EF645DFD7069F1675DE95F55E66255DC6151D66753
CA7153B5714CB3875A977B4C6E5B315D502D4E492C44422D4E4E424B4A46464646424146
37353A3432373634372823272823272B262A2A28292321222929272727252929292A2A2C
2E292F2A232B3024322A1C2B827680F4EAF2E7E1E5E4DFE3E8E6E7E9E7E8928E8DA39D9D
877E7F867D7EC7BEC182797C433D3F585254857F81ABA5A9C6C0C4D8D3D7E1DFE0DEDEDE
DDDFDEDCDEDDDDDDDDE2DCDEE9D8DEFEDDE6CC949F8A3D47D46C75AC3F42B857509D5549
9B7970FFF5EC
FFF1ECAA7F78A8564BD46959E36A59D65D4AD36554C26957C68476E0AEA3AB7E79C39794
B88B86A97E78AA8781EFD3D0E0CECED6CACEBEB3BBE1D7E0EEE6F17E78865B5768524D61
3B3748C2BBCBF1E9F8E7DFECE6E0ECF0EAF8D7D3E26763744B465A242031A8A5B0F8F3FA
EBE6EAECE8E9ECE6E6EDE7E7EFE9E9F0E8E6EFE7E5F2E6E6F7E7E8FFE3E2F7CBC2B27A61
B37343D59653FEC775FCBF6EDC8C45CC6C32DE774ED77254CD7662AB655965352B52312A
594640776C66918881857C756A635D453E38342C2929211E28201D332B282F27252F2A27
2D2824312C28352B2A3E2C2C44272957262A63181D7C1C1EC75554E86D66E96D63EC7265
E87264EB7567E97161EE7968EB7A68F08573F48D7AF5927FFF9A88FF9887FE9484FF9484
FB9181FD9383FB9684FC9986F99A86FDA18CFFA694FFA694FFA290FF9B8BFD9687F98B7C
F37D6FF07468E9695EEF6960EC635BEC6258F2655CE95F55E86257DF6455D76759BF6250
A159438A573C6C482E513C2142361E463F2C433F333A3A323E3E3C383A39323234333237
28272C27252A2C2A2F262125292428292428292526292524262521282924252523232321
262427251E262E22302C1E2D796D77F5EBF3E6E0E4E4DFE3EEECEDDBD9DA9791917D7777
89817F83797ACDC4C7D3CACDD2CCCEBBB5B78882842C26283E383A9B9597E8E4E5E2E2E2
DEE0DFDEE0DFDEDEDEE2DCDEE8D7DDFEDDE6D29DA7853842D9717AAC3F42BB5C56995349
9F7E75FFF5EC
FFF2EEB28780A65449D5675AE66B5BDD604ED86552CF6F59D08570BD84718455457C5544
A88474AD9080D3BBAFDBC8C2EAD8D8CEBEC1CCBBC1F8E9F0CCC1C95E566160596B524D61
49445A736E82827B8D7D7688857E908B84967770825B5466393242453F4DE4DFE6EDE7EB
E9E3E5EAE4E4ECE3E4ECE3E4EDE4E5F1E6EAF3E8ECF6E7ECFAE7EBFCE2E3FFDAD3BC8A73
B6774BC48444FBC474FBC16FE1934BCD7033DD784CD77455CE7763A6615265342D54332E
4D38354D3E3B5B4D4A786D699186829085816E65604F4842362F292A251F27221E2B2622
2C27232F2724352A283E282A462226551C2265101793292DDD6362EE6A65ED685FF26E62
EF6D60EC6A5DEE6A5DED695CED6B5DED6F60EA7160EC7463EE7666ED7364F07669F47A6D
F47C6EEE786AF27F6DF38270F48675F88D7BF88A79F78978F98B7AF9897BFA8679F67D72
F2766AF37368F57165F56C62F3695FF2685EEE645AEC665BE36557DD6D5FBE6255873F31
6231224F2F204734263D3327332F242F2C2531302C2F2F2F2B2C2E25292C26272B2A2B30
26262E26263027242F28252E27242B2A282D2D282C2C2827272622242520242520252523
2725282A232A291D292A1C2B827680F5EBF3E6E1E5E3E1E4F0EEEFCFCECCA09A9A4D4747
6F67657F7775C8BFC0918889B0A7A8B0A8A6C7BFBDB1A9A7C3BABBDBD5D5E4E0E1E0E0E0
DDDFDEDDDFDEDFDFDFE2DCDEE9D8DEFDDEE6D39EA8833640DA727BAF4245BB5C5697534A
A6857CFFF6EE
FFF7F3C59E97A25249D4685BE66859DE5D4ADB624DD46C53DD896FC17F6588553A795439
BD9F85DAC5B0DCCCBDDCCDC6E4D4D5CBB8BCE9D4D9D1BEC4D6C5CD594D574A4251514A5C
4F475C5850675D556A5D5668625B6D645B6E5C53664E4556261E2BA9A1ACF4EDF4EAE4E8
EBE5E7ECE6E6EDE4E5EFE6E7F0E7ECECE1E9EFE4ECF1E1EBECD8E1F5DCDFFFE0DAC89A83
B97C50BA7A3CF6BE71FFC473E5974DC96F31DB794CD17050D07B669E5A4D63342C50312E
4B36334D3E3B4537344C3E3B594B4872676391868291888379726C55504A3B33302E2925
2A25212D25223628273E2626461C205413196A0E13AE3D3FE96966ED6660F1675DF46A5F
F3695EF2685DF2655BF5685EF1675AF0685AF16C5DF26E5FF36F62ED695CEE6A5DED695C
EC6A5DEF7061E96A5BF07263EB7061EB7162ED7263ED7263EC7064EB6F63F17367F27267
EF6C62F56F64F36A60F46A60F3665DF2655BEF6258E76155E16657D76D5FB9655A6E3227
4520173A261D2E231D2C29242B2A2826262627262B292A2F22252C20242D20242F242833
242736292B3A2726362C2A382D2D392C2B332A282D2A2829292728262523272725272727
2A25292E272E2A1E2A2D1F2C8F838DF7EDF5E5E0E4E4E2E3F2F1EFC1BDBC959190464040
655D5B958D8BD0C7C8675E5F534B49342C2A7C7472ADA5A3C3BBB9DED8D8E4E0DFDFDFDF
DEDEDEDEE0DFE0DEDFE1DBDDE9D8DEFDDEE6D4A0AC823640DA757DA83B3EB0534E98554C
B0928AFFF5EF
00FF00D9B8B39E544BCE6457E7695BE05D4BDC5F49DC6D52DB7E5FC77C5CAA724FBC9672
D1B698E5D5BCDCD0C2E5DAD6CBBBBCD9C4CBD3BAC0886F75E0C9D1B8A7AF504450382D3D
312839382F423F3649403748413948423747403543443A458C828BF0E6EEF3EAEFF1E8ED
EFE6E9EEE5E8EDE7E9F6F0F4C8C1C98E8693A497A897899883717DEBD4DAFFE4DFCC9F8A
BB7E51B57434F3BA6BFFC473E7994FD07638D8774ACE7150C97B65925447562B244C302C
483632483D37483D39453A36473C3A4136345449476C6260887F7A948D87847B76655E58
463E3B372D2B3020203B2122481B1E56111478181ACB5456EA6662EE635CF3665DF1645A
F2685DEF655AF26659F4685BF4685BF06659F36A5AF46A5DEF675BF26A5EF0665BEE6457
EF655AF1695DEE665AF0685CEF695DEC665AEB6559EE685CEB655AEA6459EF665CEF655B
EC6258EF6259F06159EE6056EE5E55EB5B50EB5D51E86054DF6153DA6F5FC06A5D6A2E23
3D181034211B2F2724292826262628292A2E26262E21232F2127331D243421283B2B3348
292F4532374D393B52373A4D36384725273323232B26252A2B2A2F26262827272929292B
2B262C29222A30232D2C1F29988C96F6EFF6E5E0E4E4E2E3F5F1F0ABA7A68884835A5454
706866A39B99E7E1E1D9D3D3DBD6D3BCB7B475706D332D2D5F5959C3BFBEE7E6E4E0E0DE
DFDFDFDCDEDDDEDCDFE2DCE0E9DAE1FBDDE5D8A6B1863E49D4737A9E3637AD524D97574E
B89B95FFF7F3
00FF00E6C9C59F5951CD675BE66A5EE25D4EE05F4ADF694FDD7959CB7B58BC825CC9A27B
E0C7A8DBCBB2EADED0DED1CBC6B6B7EBD6DDD8BDC6CBAFBBE2CBD5F8E4EFDDCDDAB5A8B9
A59AABA299ACA097AAA398A9A095A5ABA0AEBCB0BCCEC2CCEFE4ECF3E8F0E0D5DDE1D6DE
F0E7ECF3EAEFF2EBF2F6F1F89C96A4736C7C7E72865F5063948393FBE4ECFFE0DCCA9A84
BC7D51B67535F3B86AFFC171E89A50D1783CDA7B4FCA7151C67E68834B3E4B261E48302C
483934443B364B423D4138333F3533403634433937483E3C4B423D675E59817873958C87
8C8280786D6B5B49474F3131522021550D0E882122D95F5EEF6A65F0635AF06258F16359
F1645AF1675CEF6258F4675DF2655BF06359F3665CF2655BF4675EF1645BF3655BF3655B
F1645AF4675DF2655BF1645AF1645AF4675DF4675DF06359F4675EEF6259F2635BF06159
EF5F57F16159EE5E55F25F57EF5C52EF5C52ED5D52E95F52E26255D7695AC56F626D3126
3D1B123624202F272529292B27282D2F2F37292B37292D39272D3D293043373F563D445E
3B425C3C425C3B3F583E435732354625273424242E22212929282E25242A21202529272C
211C23241A23281B2530232DA0949EF4EDF4E4DFE3E5E3E4F3EFEE9D9998938F8E585252
8D8787B0A7A8CEC8C8B9B3B3D2CAC8C9C1BFC1B8B9BCB6B6DAD4D4E3DFDEE4E0DFE2E1DF
E0E0E0DDDDDDDDDBDEE2DCE0E9DAE1FBDDE5D6A7B1823C46D6777D9A3636A9544D91554B
C1A5A100FF00
00FF00F1D9D5AA6963C6655CE2675FE05C4FDF5B4CE16853DA7257D27F5FB17752CDA783
D7BE9FD3C3AAE5D5C6C9BAB3E1CFCFEAD5DCCFB7C4A890A0AB94A6A893A6A18FA5A092A9
998DA5998DA593879D988AA1978A9E9D90A27F7381988C98F2E6F0B0A4AE837582847884
B2A8B1F0E9F1FAF4FEC9C6D1716D7E726D81675E73504357D7C4D7FEE3ECFFD7D6C88F7B
C27E51BF7A39FABF71FDBE6EE19148DA8044D3764BCA7558BC796677453A4D2C2548352F
3F3430433B3849413E443C393F37343C3431413936453D3A3E3731433C36443A38594F4D
6E605D8C7A78977F7D926F6D8C54537F312FA33B38E56A65EB655CF1645AEE6056F26458
F3675AED6056F3655BF2635BF3645CF1625CF1625EF36460F1625EF46561EF605AF1625A
F5665EF06159F4655DF1625AF2635BF2635BF1625AF2635BF1625AF2635BF16159F06058
F15E56EF5C54F25F57EF5A53EF5B51F05C52EF5C52E85E51DF5F52D86A5BC9736673372D
3D1A143826242D27292E2D332D2D352C2C362F313E3134433A3F5241465A454962434760
4347603F445A3D42584042572E2F412224311C1A271C1A251E1C2723222A1F1C232C272E
3E373E5349526D606A60535D9F939DF3E9F1E3E1E6E2E2E4F2F0F17E7A79BBB5B7C5BFC1
837D7FCFC9C9A49E9EA79E9FD4CACBD7CBCDD9CACDDFD3D5CCC2C1D6CECCE6E2E1E1DFE0
DFDFDFDEDEDEDFDDE0E3DDE1E8D9DEFADFE6D3A1AC7E3840D2787A983B36A6584C8B5549
C4ADA700FF00
00FF00FEEBE7B17670BC6259DD685FE16156DE5F50E26B57D87259CB7C5EB87F61E4BD9E
E7CDB2E0CEB8E5D4C4E6D5CDDCCAC8EFDCE07D69755C47585C495C5443565041564C3E55
4C3E55473B5146384F493C504D40524F42532B1F2DACA0ACF6EAF47D717B6153606A5E6A
594F5ADCD4DFF3F0FB908C9B63607366617740364E8F8095F8E3F4FDDEE6F6C3C0C4836D
BE7749CC8746FFC277FBB96BD98640E2854CCF734AC57457B778666B3F344C2F29493733
3C32303D38343F3A36403B37433E3A3E39353934303A35313C37314039333D3532433836
4436334C3935674B48885C5BAA6A68AD5855C75C56E46860EC665BED6154F16357F06256
EF6356EF655AED6359EE655FEA6560E76563E76768E56468E86869E96769EC6667EA6262
EB615FEE6360EC615EEE6360EE6261EC6260ED6361EB615EEE6360EA5F5CF06260EC5E5C
EB5D5BEB5D5BEB5B5AEE5F5BED5C59EA5954ED5E58E75D53E16156D6665ACA7369783C32
3D1A163E2C2C322C302D2C3230303830303A3434403032413A3D4E373A4D303146323348
34374A282B3E2526381E1F31201F2D24222F2E2B36423F485A57606B686F716C73756E75
777077746A72645761382B35A296A0F3ECF3E3E1E6E3E3E5F6F4F57C7B795A5657544E50
8B8788F6F2F386808062595A5F53555F5053605053635356443838BAB2B0EDE7E7E1DFE0
DEDEDEDEDEDEE0DEE1E2DCDEE8D9DEFADFE4D09FA5813C41CB7274933C35A560517F5142
CDBAB400FF00
00FF00FFF4F2BB8680B46257D76B5FE66C5FD75D4EDF705DDC7E65BF755CBD876FD4AE97
D9BDA8DFC8B8F2DFD1CFBEB4C7B8B3E5D7D782737A7A6D77766875746675726674756879
7467786F62736E6071695B6A695B6A4F414E71656FF1E6EEFBF1F9C1B7BF6D626A544852
746D75ECE6F0C4C0CE696677676278574F663D3147D6C5D7F9E1EFFFDBE0E6A7A0C67E65
B87241E4A061FFC37AF9B36BD37B3CDE7E4BCE724DC7775CAF7561643C30482F28443530
4036343E3634403836423A37473F3C443D373D35323B33303C34313B333039312E403634
42333047322F52302F5B2928691F1E8A2C2AD4615CEA6A61EA6458F26657F16355EF6153
F16558ED6559E8655DE56A65DB6B69BD5556B24F54B15059B2515ABC545DD25E6BDC606B
E4626CE6636BE6636BE15F67E3616BE3616BE3616BE36169E36066E66067E66069E45E67
E45E67E45E67E7616AE65F66E85F67E75C63E75C5FE8615EDF5E58D7675CCB746A80443A
3D1A163F2F2F322C3026252B2A2A3228283026263024242E272733232230201F2D2B2A38
3434403C3C484A48555A586367646D6F6A717D767E827B827A737A6C676B5751554D474B
3B3539362C342E242D291F28B6AFB7F1ECF2E3E1E4E3E3E3F2F2F2B8B8B82826275B595A
D0CFCDEEEDEBD3CFCEDBD5D5857B7AB0A4A6D1C2C5CEBFC2A89C9CD6CECCE8E4E3E1DFE0
DEDEDEDDDFDEDFDFDFE2DCDEE8D9DEFDE0E4CB989D843F42C16D6B924239995E4E795444
D6C7C000FF00
00FF00FFF7F4CB9E98AD6358CE685CE06F5FE37463D26D5BD27F6DA1604EE3B5A6DFBFB4
DFC4BDDDC9C2E5D4CDE0D2CFE4D8D8E7DCE0DFD5DDE0D6E1DED4DFDCD1DFDFD4E4DCD1E1
DED3E3DED3E3DDD0E1DCD0DED8CBDCCABECCD0C6D1E5DBE6DFD8E0E6DFE7DBD1DCCFC7D2
E9E3EDEEEBF6888495635E72665E7534283E857487FFE7F7FFDEE7FBC9C8CE8979C97D5B
BD7743FAB977FFBF78F0A561D97A42D67445D17452C4785EA66F5B5F392C4B342E443532
4238374038363E36343F3734453D3A453E38453C373F36313D35323D35323A322F3C3230
40312E472F2D522B2C5B2324691719993331DE6761ED6A60EF6759F06455F06453EF6354
ED6557E9695EDE675FE27975A44C4AA5595BD8929AC37F8AB56E7CB26472C5687BB34C5F
D36776D76B78B74F5AAC4651A94551A3424DAA4652A94551AD4752AC444FAF4752B9505E
B64D5BB74E5CB54C5ABC505FBE4E5CC04C59C95059D75A5EDF6361D4655ECF786F82463C
3D1A162F1F1F27212523222826262E33333B36343F403E494E4C595D5B68615F6D6F6D7B
7775827D7B8673707B6B6871615C62524D514741453C3638322C2E312B2D2C26282E282A
2E282C2C262A2E242C362F36CBC6CCEEECEFE2E2E2E2E2E2E5E5E5E5E5E5B0B0B0C2C2C2
E5E5E3E4E3E1ECE8E7FDF5F3786E6D685C5C7F7073786C6E6E6465DCD3D4E9E5E6DEDEDE
DEE0DFDCDEDDDEDEDEE1DDDEE8D9DCFFE0E5C59195894544B8676392483D915C4C856556
ECE2D900FF00
00FF0000FF00DAB3ACA76559C86B5CD86F5CEC8775D17868A35F54BC8B84E8C8C97E696E
83727A8578818D818B877D86978F9A958D9A827C8A817D8C7C78897F788A7D758A786F84
7A71867D74897B72877A7184766E83766F817F788A8B8496867F918780928F88989891A1
A5A1B29893A76E667D6B61795749603C293DD7BED3FFDFEDFFD0D5DD9D93CF8467BF7244
D8985AFFC178FAB46CE18E4CDB7743DC774DD07556C97E679863515B392D4E3632463837
3E3232473D3E3C3231403634413936463F39453E38433C34413A343E37313B312F3B302E
40312E492F3051282C5F212672191BAA3E3CE56864EF6960EE6457EF6354F06455EB6355
EA685ADF695FD9736EC77371713433CD9FA1FFDEE4FCD4DDFAD0DEFFD4E5E8A5B7964B5F
C175828B434F9E626AD6A1A9DFAEB4CFA0A6C997A0C3919ABF8C93B27F86A9747CAA757F
A06B759B636E9A606C965865A25B6BA95867B45664AE444ED05E5ED66A67C570698A4E46
5C39355C4A4A5E585A605F6566666E6D707971717D6F6E7C6E6D7D6E6D7F5C5B6D525163
434051403E4C34303E302D362E292F2F2B2C2B27282A2625322E2D2D29282E2A292B2726
2C28292924282620243E383CD9D7DAECECECE1E1E1E3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
E4E3E1E6E2E1E1D9D7EFE3E3CCBEBDB4A4A4B1A3A3AB9FA192898AE3DDDDE4E2E3DFDFDF
DEE0DFDEE0DFE0E0E0E3DDDFE9DADDFFE1E3B98184964F4DA85851A0584C8757499C8275
FEF5F000FF00
00FF0000FF00E9C8C1A1675CC7705FCF6A58EA8B79BA6B5CA97067F7D1CEB1989E685863
6A5C6B685D6D6D6272675F6E6E66756C66745E5A68605C6B615D6E615D6E5E566B60576C
60576C61586D635A6D5F586A5C55675D5668615A6C665F716A6677666273635F70656275
68657A676279675D766A5A74402A3F937486FFD8E8FBC6CCDD9A92CD836ACA7D53C47C42
F9BA73FFC076EFA159D4773ADF7646E07853D67B5EC77F6795645355352A4B3631453736
413535453B3C403635423837413936403933453E384A433B40393137302A3F36313E332F
40312E462C2B53262B5F1E22791D20BE4E4CEC6D67EB625AF16558EF6354F06757EA6659
E46A5DD76F66CD7875995959885E5FF9DCDEF5DCE0F2D8E1F9DAE9FFD9EB99647892596A
885260956771FAD9E0FADFE6F8DFE5F7DEE4F8DDE4FBDDE5FFDEE7FEDDE6FBDCE4F7D9E1
F2D7DEF1D6DFF0D2DCF5D1DFF7CBDCFFC8DAFFBDCDA74753C25457D06764C8736C8E4F48
623F3B6C5A5A5F595D53535B4C4F584345514042514142563D3E5238394D3A3B4F3C3B4D
3A374838364434313C302D34332E322B27262F2B2A2F2B2A2D29262C28252F2B2A2C2827
2925262B2527211B1F544F53E5E3E4E8E8E8E1E1DFE3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
EDECEAD9D3D36F6566C1B3B37E6E6E8A7A7A8C7C7D8377778E8586EDE9E8E2E0E1E1E1E1
DEE0DFDFDFDFE0DEDFE5DCDFEBDBDEFFE0E3A96E70A55B5AAA5D559E5E527D5647C5B1A6
00FF0000FF00
00FF0000FF00F6DAD6A47269C06D5FCC6B5ADD806EA05444CB9B8FD1B2AD52373C66515A
5C4C575F525C5C505A5B515A5A50595C555D58515958505B59515C5A525D5B505E5B505E
594F5A594F5A5E545F5B535E574F5C564E5B5A525F5B53605B5561595661585664585566
5D59706058706757715A425A513043E7B9C4EFAEB2DA9087D6866BCE7F54C88247F3B06A
FAB86CF6AC63EC9253DB7640E17449DF7452D4795CCD856D956654513328493630473938
463A3A403635453B3A443A39423A373F37343F3A36423D37443F393C37313C352F39302B
3E2F2C4529285325285A15187C1E1FD05E5DEA6964EF665EEE6255F16858ED6557E7695B
DE6F64CF756DBC7877724144CCAFB3FCE7ECF1DAE0F3D9E2FEDFEEE2BCCB8350619C6978
6D4550DFC0C8FEE7EDF2DDE4F4DDE7F5D9E5FDD7E6FACEDDF2C2CEF4C6D1F3CBD6F3D4DC
F6DFE7F1DDE6F0DBE4F5D9E7F8D6E6FFD4E5F6ACBB963642C95B5ED56967CB736F81423D
4C292740303338333A31313D333542383B4C3B3D5242445B494B6245475C414256414050
3C3A473130382E2B322E2C2F2E2A292925222F2A272E29262B27242A26232925242E2828
2A24242C2626211B1D615D5EECEAEBE4E4E4E2E2E2E2E2E2E2E4E3E0E2E1E1E1E1E2E2E2
E8E6E7DDD9DAB3AAADD6CACCAA9A9BAA9A9BA898998C80809A9494F2EEEDE1DFE0DFDFDF
E0E0E0E0DEDFE1DDDEE5DADEEDDAE0FEDBE193585CAA6462A46055965E4F856558E8DACF
00FF0000FF00
00FF0000FF00FEEBE7A1766FB1675ACD7260C76A58AB5846FEC2B7CD9E989E72738E676C
664349614247583B3F51373A4A31344F36394C37364935343E2B27412F2B46332F49342F
4B332F4E36324E36324C3432483030452C2F442E3148343647373A44393D48424C4D4B59
544F655E526A67546A4125349F777FEDB7B5C37A6BD28163CF7E4FC87E41FAB771FFBE74
F6AC63F5A05DED8850F38456EC7A55DA6F4FCF7459CB846EA97C69573B2D3C292240322F
433836403634473D3C3D33314238363F37343D3834413C38433E3A3F3A343B342E39302B
3F302D4529285726295A1416862725D86560EC6B65ED645AEF6558ED6557EB695BE36D61
D27067CF827C925C5C815E62F7E2E7F1E0E6F0DBE4F6DAE6FFDDED9E75858C5D6D7C505D
8C6E76FAE5EAF3E0E6F1DCE5F5DBE8FFDAEBF2BBCEB57586A46270AB6D78A16F7A94707A
E8D1D9F1E0E8EEDAE5F0D8E5F7D7E6FFD4E3BF6E7D9A343FDA676AD36663CE76727F403B
5531314130363F39433635433638473A3D503B3D523D3F564A4C63424459444557373743
2D2C342E2D322624272725262C28272A26232C28252D29262A2623282421251F1F2B2525
2B2223342B2C201A1C6E6A6BF2F0F1E4E4E4E2E2E2E2E2E2E2E4E3E1E3E2E1E1E1E1E1E1
E2E0E1E5E1E2F6F0F2CEC3C77C6D7095878794888A7B7172B1ABABEEEDEBE0E0E0E0E0E0
E0E0E0DEDCDDE3DDDFE6DADEF1DCE3F4D1D791595AB2716D9C6055895B4C968073FCF3EC
00FF0000FF00
00FF0000FF00FFF7F5C1A29D9D5F54C87263CB6757BB5546EC9486FDADA2F4A7A1F2A8A5
EFAEAAE8ABA8E2A7A3DDA49DD9A29BDAA69BD7A799D2A794CAA58BC6A387CBA689CAA384
CC9F80D0A183D29E86D29E89D49F8FD19D8FD1A092D4A89DD2B0A6CCB5AFD7CBCD8E8691
5044586051665A42524F2F34ECC2B6D19B81BE7950C27942D09049F7B86BFEBA6FF3A960
F49F5EF18E55F28355F27C56E66F4FDD6F54CF735AC67F69AE816E896D5F67554B42352F
3328243D322E433836403533413634433937423A38453D3A433B38473F3C3D33313E332F
43312F462A29552427601A1A8E2F2BDB6861E96960F1695DEC6456EC6859E4685CDB6F65
CF7871BB7B796F4748CAB1B5F9E6ECEEDDE5F1DBE7FDE1EFEBC4D6865B6C976D7B613D49
D0B9C1F6E5EBF0DBE4F3D9E6F9D8E9FFD0E5B3667AA95062CB717DC97982AC70786C434B
DCC2CBF6E2EBEFD9E5F1D5E3FED8E7F8BBCA963944C35258DD6765D66964CA756E7B3E3B
532F314231393C3441383745393B4A393C4D36394C40415545465A3F3E4E3838442C2B33
28272C2C2A2B252422252422282723282723282725282725282725282423251F1F292021
3026273128291D1719817D7EF5F3F4E5E3E4E2E2E2E1E1E1E2E2E2E2E2E2E2E2E2E2E2E2
E4E3E1E8E7E5F7F3F4D8D2D45E53576A60617D74775D5757B3B2B0EAEAE8DFDFDFE0E0E0
DEE0DFE0DEDFE6DDE0E8D9DEF5DEE4E6C3C7824C4CB479738C5B4D825E50B8A79F00FF00
00FF0000FF00
00FF0000FF0000FF00FAE7E3B1827AB46C60CF6F61C5594CD96F61E57B6ED26A5FD87369
DF7E75E0837BDC8279DF877BDE8879E59481E29780E4A184EAAE89F7C195FBC797EFBA88
D99F6DCC8E5DCA875CD38E67D28C68D79271D89578D49A82BE917EB4968BF3E1E17B6F79
53465863506343293297746EE2B69B9A6438C68649E7A45DFFC172FFBE6EF1A75EEC9756
F18E57F18254F17954EE7153E56951E0705AD57964C5816C885B48674D3E88766C8D807A
6459553D322E362B273C312D403533483D3B443A38443C39443C3948403D413735413634
412F2D4729295220216019179F3E38E16F64E9695CEB6657EC6758EA685AE26C60D47269
CE837E8C59587B5D5FF5E2E6EFDEE4F0DCE5F5DDEAFBDCEBA77C8D90647377515E8B6D77
F9E6ECEFDEE4F1DCE5F6D7E6FFD7EAE0A1B6A14457D66D7CDA7680D48288A0636A885F67
F6DCE5F1DDE6EFD5E2F6D4E4FFD6E6C17987A33840DE6366DC655FD46961C6736B723834
502E2F402F373B333E3A38453A3C4B3436453334463D3C4C403F4D3A38452D2C34262429
2624252827232726222524202726222827232928262625232322202A2625282222281F20
2D23242F2428271E21A29C9EF3F1F2E3E1E2E3E3E3E1E1E1E2E2E2E3E3E3E3E3E3E2E2E2
E4E3E1DFDBDAF7F1F19E9596867C7DF8EEEFF4EBECE1DBDBDEDDDBE2E2E0E0E0E0E0E0E0
DEE0DFE0DEDFE6DBDFE9D9DCFAE1E5D1ADAF73403DB38178855E4F7D6656DDD2CC00FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E7CEC7A37369BA6A5FC66054DD685EF2766CEA6C60E86A5E
EB7166E76E63E87062E77163DF6E5CE37661DB755CDB7E5DDB865DE39766EEA970F8B679
F7B676E5A462D48E50C98146C47940C47844C57D4DBD7F588B5D43D6B6A9C5B1B2574A54
5F51624A3844503B38F0D1BDD0A47DCF9B62FCBF7CFFC076FBB367F0A059EC9253ED8852
F38457F07855F17156EB6953E86956E3705DD27563C985728557484E3427513E376B5E58
877C788C817D70655F4A3D37372C283C312D433834443B36433A35463D38463C3A413332
412D2E49292A552221671D1AAB4940E57164E66758EF6A59EB6657E96B5CDE7063D2786F
BB7C776D4442D2B9BCF8E7EDEDDCE2F0DBE4FCE0EEE0BECC8051619C707D63424BD7C0C6
F7E6ECEEDDE5F4DAE7FBD5E4FFC9DBAE5D6EBC5161DE6E7AD47478C77B7F7E4C4FCCACB1
FCE5EDF0DAE6F1D5E4FFD4E7FCBBCF9C4150C55056E46765DC655DD56F63BC6F6567322A
4C2D2B3B2B2E362F3635343C3C3A473939453838443D3B483D3C443431382E2C31262223
26221F2A27222F2C2724211C26231E26231E2A262326221F231F1C2A25222D24252B2223
2D22262A1F252D2228C0BABEEEECEDE2E2E2E2E2E2E2E2E2E2E2E0E2E2E2E3E3E3E7E7E7
E8E7E5746F6C887E7D564A4A736564998B8A8B807E827876DFDAD7E6E5E1DFDFDDE0E0DE
DEE0DFE0DEDFE6DBDFEBD8DCFCE2E5AF8B8B72433DAE8476775C498D806FF4F0E700FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF8F4C7A9A1995B50B85E53D9675DEF6C62F2695FEE6459
F76D62F56D5FF36B5DF57061F3705EF1725FE76F57E47557E37B56E28355E48F59E9995C
F4A968FDB470FFB571FFB874F9AC68EDA261E49E63BD8353B88D6DF5D8C88A7574634F58
6A56613520259E8378FEDBBFEEBB8CF9BD81F6B36FEA9F5BEA9554E6884BEA824FF28157
EF7453F17156EE6A55F16C5BE76555E06D5BD57866C6826F855A4A51372A493830493E38
4D443F6B625D887D799186827B706C5348443E332F392E2A3E35304239344238363C2E2D
412D2E4F2D2E561E1F702220B14C44E56F63EA6B5AEC6957EB695BE16B5FD9746AD0817A
8A55518D6B6AFAE6E8F1E2E7F1DEE4F3DCE6FFDFECA6808F9264717B515D8F747BFBE8EE
F2E1E7F2DDE6F4D8E6FFD7E7E69DAE923442D86972D96A71D87E809E5A5B895F61F8DDE2
F3DEE5F0D8E5F4D5E5FFD5E8CF7E91982F3DE3666AE2615CDB665CD06F5FB87062633128
4628263A2A2B3329312D2A31322F383B39443A38433E3D453D3A413432352F2B2C282423
26221F2926212B282324211C2A27222A27222A252227221F25201D28222230272831262A
2D2027291C23382D33D7CED3EEECEDE2E2E2E2E2E2E2E2E2E3E3E1E2E2E0E3E3E3E6E6E6
E8E7E59D9895968C8B948685A0918E9687848C7E7B908583EBE6E3E7E3E0E1E0DEDFDFDD
DDDFDEE1DFE0E8DCE0EED9DEFEDFE4926C6B9469629E786B6B5945A7A28FFFFCF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F9E6E0A57970A1584FCA6259E66A60F06A61ED6056
F4675DF96D60F86C5FF46B5BF56D5FF67263EF6E5BEC725BE67356E47756E78159E58658
E78D5BE58E58F09C60F3A263F6AB6AF9B473F6BA7EDFAF7EF8D8B2AF9680472E29533A3D
462E2E553832EFC9B6E9B796E29E71EA9A65E8915BE88A54E6804FEF8355EE7854F27557
EF6D55F06C57F26A5AED6859E96757DE6B59D47765CB877483584750392B46382F49423C
4C4441473F3D4B43405F5651827773988D89847975655A56463D3838312B362C2A3B2D2C
3F2B2C4E2A2C581D1F762625BB544DE86F64EA685BEB695BDF6558DB6F65D27975B97876
683C3DCCB2B3F9E5E7EFDEE4F0DDE3FCE2EDE1BBCA7F54659E727F603A45CEB7BFF6E5EB
F0DDE3F4DAE5F9D9E8FFD0E0BA6373B54B55DF6E74DB7276C77778794142CAA7ABFBE4EA
EFDAE3F2D8E5FCD7E9FFC4D8A34756C34E57E76567E4635DD56456D27564AB68585E2F25
432724392B2B372C34342D3537313B39363F3B3843403D463B383F2B292C2824252D2928
2B272429262128232027221F2C27242C27242C2324281F20251C1D2E252632272B30252B
2B1E27271A234B4048E1D8DDEDE9EAE0E0E0E2E2E2E2E4E3E0E0DEE2E2E0E3E3E3E2E2E2
E1E1DFEAE9E5E4DFDC8C8280998E8A9688859B908EA39997A49C9A7F7B7AE1DFE0E3E3E3
DFDFDDE3DFDEE7DBDDF1DBDEF5D5D886605FB0857E846256665647CECABE00FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E5C8C298635BB8645AD16559E86C62EA665A
EA6256F2685BF3675AF56C5CF56B5EF46C5EF46C5EF06D5BEE705AE66C54EA775AE77958
E67C55E68155E58352E68854E18A54E1925AD7925BDAA273FFDDB7D1AC92B88E82B1867F
AB8079DDAD9FFAC0A8D58E6EE58D67EB8A5FED8359EB7E55EF7B56EF7657EF6F54F16D58
F16A57F46C5CF1675AF0685AEB6758DF6A59D57662CC85718E614E543A2B473930443D37
47423F45403D48403E473F3C453B39584E4C796F6D9389879088857068654E44423A2C2B
301A1C4521235B1F217A2928C05753E66F67E86A5EE3695EDE6F66D0736EC88081824E50
927275F9E5E7F1DEE2F1DEE4F3DEE7FDDFEBA97E8F93677681596496777FFAE7EDF1E0E8
F1DCE3F7D9E3FFD9E7E2A4B3983844D6676EDB6E71D67878A25E5D835557F4D9DEF2DEE7
F1DAE4F5D5E2FFD6E7D18A9C9A303CE2636AE86261E16158D66658D178689A5B4A4F271B
41292535292B372D35352D383A343E3B35413D3A453B3841302D3429272A232122272624
2925222622212824252C28292D27292C26282920232920232E25282E252831282D31262E
2C202A1E121C5B5159EAE4E8EAE5E9E1E1E1E2E2E2E1E3E2E3E3E1E4E4E2E3E3E3E2E2E2
E1E1DFEEEDEBCDC9C8696461877D7B796E6C817674635958847E7E6F6B6AE8E6E7E4E4E4
E0DFDDE1DDDCE8DCDEF5E1E3DEC0C264413FBF9A916F53477D7367ECE9E000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF7F4C5A6A1995F54B96759D26C5DE06A5C
E7695BE45E52E96153E95F52EC6255F06457F4685BF3695CF36B5BF3705CF1705BEB6D56
EC7358EC7557EA7854E87852E97D56E88359DB7B53DA855EF1A686F1AA8EF0A892F3A797
F2A998F8AA96E18971E07E63EB7F62EE7B5CE97254EF7357EB6D54EF6D57ED6855F16A57
F16858F16858F76B5EF1675AED675BE16959D97865CE8572916250573A2A49382E463D36
49413E443F3C443F3C46413E453D3B463E3C4139374E46446B6361867E7B958B898A7C7B
6B565550292A531719701F1EC05656E6706CE16A62DE6F66D67972AF65628F5B5D5C3A3B
D3BDC0F6E7ECEEDDE3F1DCE5FCE2EFD8B6C675495AA074835E3D46D4BBC1FAE7EDF1DEE4
F5DBE6FBD7E3FFD1DEB56B78AF4954DB6E74D57173C87776794343C8A6A7FCE5EBEEDAE3
F2D8E5FAD4E3FFC7D6A85161C04B54E86165E7605CE4665AD36858D17E6C89503F472519
37261F3128293932393B353F37343F3A3742413B47322C362D2A312C2A2F282629252525
26242527252828262B28252C2A252C2D262E2B212A2A20282A2126251F23251F232B2129
3329322D262E736E74F0EBEFE6E4E7E2E2E2E0E0E0E3E3E3E4E4E4E2E2E2E1E3E0E1E3E0
E3E3E3F2F0F1B6B2B3736D6DD9CFD0D9CFCE9F9594A69D9EEDE9E8DBDAD8E2E2E2E1DFE0
E2DEDDE3DDDDE8DCDEFAE7E9B89E9D5A3E3AB59D91635346A8A19900FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F8E9E499786F8D594CB0685AC56D5F
D26D61DA6C5FDC665AE56B5CE06053E26052EB6559EF6759EF6759EE6656F16959EE6958
F16E5AF2715BED6F58EF7359EF7357EB7456EA775AE5785BE37E62DF7D62E07C64DD7962
DA7762E07A64E4765FE8745DEC725BEE705AF06F5AEF6C58F16C59F06858F16858F66D5D
F16858F2685BF4685BF2685BEE685CDF6556DA7563D1836FAB73645E382B4D342D4A3B36
483E3C423D3A433E3B443F3C423D3A453F3F423C3C413B3B473E3F48403E58504E7B6D6C
9F8689A87F83A264678D3B3DBF5756E2726EDB6E67D7766FBC716C753D3CC8A4A6D2B9BD
F1E1E4EFE0E5F0DCE5F8DEEBFFDFEEA982948F60727B515F95777FFAE5EAF3E2E8F0DDE3
F5DBE6FFD8E6E0A3B28C3C49C8646ED87077D57C7EA05A5C835659F6D9DDF6DFE7F1D9E6
F5D6E5FFD5E5E096A5932F3BE16367E95F5DE66057DF6558D46D5EC97A6B7A4638402217
31221D2B25252E2B32322F3A3632403834423C3642302A3429262D26242928272C28282A
28272C26252A1F1E24201D261E1B241F1923251D28302931302A2E3832364D464D5F585F
726B735550568A888DF3F1F4E4E4E4E3E3E3E2E2E2E3E3E3E3E3E3E2E2E2E1E3E0E0E2DF
E3E3E3EAEAEADDD9DA7872725B5253574E4F746B6CD3CDCDEDE9E8E4E3E1E0E0E0E2E0E1
E1DDDCE5DCDDE8DCDEFCEAEA8B7371776058A69687655B4FDEDBD600FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3D6D0C0A9A1B29087AD7E74
AF756AB97367BF6D61C96D5ED36D5EDC6E5DE16C5BEA6F5FEB695BE86455EC6758EB6655
EA6552E96451ED6857EF6A57F06C57EF6D57F06F59F47660F17762EF7661EE7763EF7864
E8705FEC7362F17462F1705DEF6C5AF06B5AF06B5AF36B5BF06858F2685BEF6558F66A5D
F1675AF2685DF4675DF1645AF26A5EE46658DF7162DA7E6FB672676E3C335635304E3938
493B3A443C3A413B3B423C3C423E3D413D3E423E3F423E3D453F3F45403D433E3B463A3A
533A3E774E54A86A6FB9676BC76363DA716DD3706AD7847E7B3F3E9D7575FFE7EAF2DFE3
F0DDE3F2DDE4F3DCE6FFE1F0DBB2C48152669C6D7F633D4AD6BFC7F5E6EBEFE0E7F0DCE5
F5DDEAFCD3E1A1616FA04E5CD0757ECE757BC4797D743C3FBF9CA0FDE4EAF1DAE4F3D7E5
F8D6E6FFCFDDB65C68B9464DEA6465EB605BE35E55E0685ACF6D60C2786B6A3A30351A13
2B201E2B262A29262D29273232303D3634413733412A27322E2B3428252C252229262429
1A171E1F1C232A273035323B413E475C575E6E69706E696F726D716F6B6C696367565054
443F452C272DA09EA3F3F1F4E3E3E3E2E2E2E2E2E2E3E3E3E3E5E4E2E4E3E2E4E3E1E3E2
E2E2E4E9E9E9F2EEEDA49F9C473F3D534B49C4BCBAF1ECE9E3DFDEE1E0DEE0E0E0E1DFE0
E1DBDBE4DADBEFE1E1F0DEDC614A44AB998D84786A8B877BF9F8F300FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF4F0F6E5DE
ECD1CADAB5ACCC9D93C0867ABA7669BF7164C46C5EC96959D66F60DB6B5DE36F60E66E5E
E56A58E66957E46254E76354E86352E45F4EEE6656EB6353F26D5CF16C5BF36E5DF4715F
F36E5DF67160F46C5EF66E5EF16959F06858F56B5EEE6457F3695CF1675AF4685BF3675A
F1675AF1675CF5685EF3665CF1695DE8695AE26C5EDE786CC8766B793A335D312E543837
4E3C3C473D3C483F40423C3C403A3A3F3B3A433D3F453F3F433D3D403A3A464040473B3B
4F363A5A313762232B823036C76363DB7370D97872B665618A4E4DF4CACBFFE2E5F8DBE0
F8DAE2F8D9E1FEDAE6FFD7E5A66F82975E6F81515F9B7580FDE6EEEEDFE4EFDEE6F0DCE5
F9E2ECF0CFDA743C498A46519F58609D5A617541458D6468F5DADFF2DDE4F3D9E4F5D5E4
FFD7E8DB99A799313ADF6164EA605DEB6258E46457D56557CF7668AD6B5F582D27311917
2B21202523262B282F2A2931302D382E2B362A27322F2C35302D342D2A313533384B464C
5A555B6F6A70807D84838087807E837573786560644843473C3839363233302A2E2D262D
27202739343AD3D1D4EDEBEEE2E2E2E2E2E2E2E2E2E2E2E2E2E4E3E1E3E2E3E5E4E2E4E3
E5E5E7EEECEDB2AEAD888481A39E9B918C898B8683E2DEDDE6E5E3E1E0DEE0E0E0E0DEDF
E3DDDDE6DADAF4E4E5C9B7B35E4C42B1A1946B6557D1CEC500FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF5F0FBE6E1EED3CCD8B6ADC79C93B9877CB5776AB87061BE6F60C76E5C
D06F5CD66D5AE06F5FE46C5CE86D5DEB695BE96455EA6252EA6151EB6250EE6553EC6351
F26655F06453F46859F86C5DF66A5BF36A58F66A5BF66A5BF26657F46859F26959F16858
F36A5AF1675AF5695CF4685BF0685AEA6657E6685AE47468DC7B728C4239531E1A4F2C2A
432E2B413332463C3B3E3838443E3E3F3A37453C3D443B3C443B3C433A3D413B3D413537
493336593237602129752329C35F61DE7572DA726FAB4E49B56969FFC3C4FEC6C9FECBD2
FFCDD6FFCDD9FFD3E1E4A7B6914957B06A75804B55E9C1C9FEE3EAF3DEE3F1DEE4F2DDE4
F4DFE6F6DDE3C6A3AAB28A92AC858A967377A08689E0CCCEF7E4E8F0DBE2F3D9E4FDD7E6
FFCBDCA55361BC4851EB6566E9605AE76357DF6757D26C5DC97B6E91584F44211B321E1D
281F202321222E2C2F363437413C424D484E534E546560646E696D7A76777D797A807C7D
777374676364585357474246383637302E2F29282624232122211F2824252922292E242C
2319216B646BF1EFF2E4E4E4E1E1E1E4E4E4E2E2E2E2E2E2E4E4E4E3E3E3E3E3E3E4E4E4
E9E7E8E6E4E58A8687D0CCCBD7D1D1C8C2C28B8786D6D5D3E6E5E3E1E1DFDFDFDDE1E0DE
E6DDDEE8DCDCF9E9EA93817D8072678D8377827E75F7F6F100FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F0FAE6DFEFD1C7D9B3A8C6988BB77F72
AF6D5DB96D5DBD6A5AC96D5ED0695ADC6B5DE66B5CEE6A5BF36B5BF46B59F56A57F46956
F26752EC614CEC5F4DF06351EF6352ED6150EF6354F36758F36758F66A5BF5695AF36A5A
F16858F36A5AF26659F66A5DF06757EF6759EE6A5DEA7063EB7F72AF574B5D1A11501F18
401F18321A16372825382D2B3B313038302E403635433938443A3B433A3D42393C433739
4C383A542F365D212974252BC15F60E17573DE6E6ACD615EC46561CA7270C97779D28388
D78A90E1949CED9DA8B05D67B45761BE676DA55E64FFCACDFFD1D4FCD3D9FCD5DAFED6DE
FDD9DDFDD9DDFFDCE1FFDEE2FFDDE1FCDDE2FBE1E4FDE2E7FBDEE3FBDAE3FFD7E2FFD4E2
DF93A09B3743DE6064EE6261EC6258E46254D96858CB705EBD796C825349654A43695B58
6A6464706E6F7975767E7A7B807C7D7C78797571726A66675B57564C484744403F3C3837
2A26252E2A292E2A292B2726322E2D2C2B272A29252A2925252422262223261F262C222B
2319219F999DF4F2F5E4E4E4E3E3E3E5E5E5E2E2E2E3E3E3E3E3E3E3E3E3E3E3E3E3E3E3
E5E3E4F0ECEDCECACB938D8F544E4E6D6767AEAAABE9E7E8E1E1DFE2E2E0E1E1DFE3DFDE
E5DCDDEBDFDFF4E4E462534E9C90847F796BBDBCB700FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FFF1EDF5E1DA
E6C9C1D1AFA5BB9389B48073B16C5DBF6759D06658E06858E36451EC6A54EB6750EC684F
F06D51EF694EF56B51F46952F16450EE614FEE6150ED5F51EE6150F06352EC5F4EEA5E4D
EB5F4EED6152F16558F06457F26659F2685BEE6457F16F5FEA7564D66F5E863021611D10
532214431F133A1F182C19132A1C192D22202F25242E2423352C2D3B32333A3132403436
4B37395330365D262C74292EBF5F60DF726DE36E67E46B63E9726AE9766FE3746DDF7370
DC6E6DD86A69CF6162C85759DE6C6CDB6F6DBF5D5EDB8181DC8A8CDF9093E0959AE39B9F
E29BA1E8A3A8EFADB1F1B0B6F6B9BEF7BEC4FDC6CCFDC8D0FFC7D0FFC8D1FFC3CFEF9FAC
A43F47C54E52EB6564ED6059EC6458E26455D46B58C87563AB73627854466E5A516D645F
635E5B585453575153464243403C3B3433312F2D2E2725262A29272625232D2C2A2C2827
2C2825312D2A2F2B282A26232F2B282A272226231E2B27242C28272521222822262A2028
332C33CDC8CCEEECEFE3E3E3E3E3E1E3E3E1E4E4E2E1E1DFE2E2E2E3E3E3E3E3E3E3E3E3
E6E4E5F1EDEEC5BCBF70676A685F60A49E9EE8E4E5E5E3E4E1E1DFE0E0DEE1E0DEE3DFDE
E5DDDBF2E6E6D1C1C1463835B9B1A69E9C8FEBEAE600FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF4EEF9E2DACCA49AA2685AB86B5BC86957D66C56E47059E87057F07458
EF7455EC6D4DE46143F06A4FEE664EEF6751F46956F36A58F46B58F26B57F16C59F16C5B
ED6A58F16E5CE96556E66253E35E4FE56051E76253E36151DF6653E87965BD5A47913A29
6E26175F24165323174721183C1B162F1612331B19301C1B2C1C1C2A1C1B302021332022
3C23264824285922286E2327B15250E3746DE66B63EB6B60F16F62EF6D60F17367F2736A
F07168F17168EB6A64EE6D67E96A64E86D66E9736FE2726EDE726FD66E6DD46D6EC96567
C26263BF6162C06263C06668BA6467C06B6EC9747BC6747AC6747ACC757DC76A74B64E55
CB5355EA6664E95E59ED6057EB6559DF6556CF6B5BC67D6C9D6E5E52382B40312A3A3531
34302D2B2726302C2D2A26272C28272F2E2C2726242827252B2A282B2A282726242C2B27
2B27242E2A27292522282421342F2B2C272328231F2723202F2B2A2C28292A24281F181F
615A61EFEAEEE6E4E5E4E4E2E3E3E1E3E3E1E3E3E1E3E3E1E2E2E2E3E3E3E4E4E4E3E1E2
F0ECEDCFC6C77A70719E9495C2B8B9A39D9DAEAAA9EBEAE8DFDFDDE1E0DEE2DEDDE4DFDC
E6DEDCF7EDEB998E8A574E47BCB8ADD0D0C600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFF0E9B3988D89604EA96F5BBB7059CD735BD06A53E6785D
E17052F07A5CF37A5BF57A5BF06F52EF6D53EC6851E9674FE86A53E76D56E56E58E6715D
E67360E5725FEA7764E97462E76F5EEA7261E86F5EE16A56DA6551DB6B57DB6E5AD36A57
AA49368E35237C2A1C722A1C6E3025511D124B1C16441D183A1B1634181533191835181A
3414173F15194F1219621318A74544E5746EE76B61ED6B5DEC6859F06C5DEF6B5EF16D60
EF6B5EEE685CEF695EEF6B5FED685FEE6B61EF7067EC7066ED726AEF766DEA7169EA736D
EB746EE6706CE7716DE16E6BE16E6BDF6C69E36F70E16D6EDC6869DF6969DC6163E26563
EB6562EF645FEF6259EA6055E96559DD6759CD7162C684767E564A432F263C332E373330
373634312F302B292A2E2A2B2925242B272426221F29242126211E2D2825292522282520
292621292621262520272621332F2C2D28252924212C26262A26252D292A2A2529221D21
989699F5F3F4E2E2E2E3E3E1E5E5E3E4E4E2E2E2E0E3E3E3E4E4E4E3E3E3E4E2E3E7E3E4
F7EEEFB4AAA9A09292D0C2C2CBC1C095908DB8B4B1EBEAE8E0E0DEE2E1DFE4E0DDE4DFDC
EAE2DFEDE6E07F7B709492869A9A90E9EAE400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00EEE7DFA391838A6D5B946754A76D59B56D57C16F57
BE674BD07256DE7C5FDC7759DE7558D76B4FD86E54CF674ECF6D54C0644DC26A56C6715D
C26F5DC3705EC56F5EC6705FCB7260D17663D07361CD715CD0745FCC7059D2735DD37762
C56954C16953B15C48A65544944B3A7E3B2B692B1E581F144C1A1144150D3E110C3E0E0C
400D0C480C0C52070B5D0305A23936E8716BEB6D61EB695BE86553ED6857EF6759EF6759
F26A5AF06858EF6759EE695AEE685CED695DF26E62EF6B5FEE6C5FF27063EF6D60F06D63
F06D63F26F65F06D63F26F67EF6C64F26F67F5706BF26D68F26D68EE6763F16862EF645F
ED6059F3665DEE6157EA6256E66659DB6B5DD07A6DB97D725F3D343D2C253B3330343331
3433312C2A2B2927282A26252824212925222B262327221F2D25232E29262E292528231F
28252026231E27241F27241F2723202824212822222F29292822222E2A2B2F2A2E2E292D
C6C4C5EFEFEFE3E3E1E2E2E0E4E4E2E5E5E3E3E3E3E3E3E3E3E3E3E4E2E3E7E3E4E5DFDF
F4EBECE6DADAA59796726463675D5B8F8A87E6E5E1E5E4E0DFDFDDE1E0DEE2DEDBE3DEDB
F2EDE9CBC8BF8587797B7F719EA19800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F2EEE2D9D2C3B2A89F887A92715E946B55
9E6F55AA745AB1735AB07055B67359AE6D51AE6E53B1755DB27F6ABD8F7FBE9486B89084
B28C7FAE887BA98175A47A6CA37868A67868A0715FA1715DA27059A6745BA47058A77157
A86E56AA6E54B2745DB3725CB26F5CB06C599A51408940317D3425772D206D201667190F
67170E69120B6D0E0A72060397201AE0645CEE6E63FB796BF4715FF4715DEF6A59EF6A59
F06B5CEB6657EE695AEB6657ED695AEB695BEA685AED6B5DEE6A5DEF6B5EED695CED695C
ED695CEE6A5DEF6B5EED695CEE685DF16B60F36A62F56C64F0655EF0665CF2655EF0635A
F2655CEF6258F06359EB6559E26859D66F60CD7F72A36D614D2F2741322F3E3634353130
302C2B332F2E2D29282B27242A26232925222C26262A252227221F2B26222C24222D2523
2C27232A252128232026221F1F1B1825211E2723222925242721232B25292620244C474B
E5E3E4E8E8E8E3E3E3E3E3E3E2E4E3E3E5E4E2E2E2E3E3E3E4E2E3E7E5E6EFEBEC908A8A
968D8E998F8E9F9492978C889A938D97948FDAD9D5E7E8E3E1E1DFE1E0DEE1DDDCE4E0DD
EFEEE9B1B3A88E94866B7366D7DCD500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F5ECE4DACEC4B4A4
AD9887B39A86BA9B89BC9B8AC3A08DBE9E89C0A18DD8BDACF1DED0FFF2E8FFF6EDFDF3EA
F8EEE5F2E9E0F2E5DDEDE0D8EBDDD2EADACDDDCBBDCFBCADC3AE9DB8A390AA947FA28772
95796391715C8E68559166539665549B6654A36858A76857AB6858A86353A155479C4E41
9C4A3EA24A3EAB4D43AC453CB6463BD86457DF6759E56B5CE96E5CEE715DED6E5DEF705F
F07160F17261F47262F57363F27060EF705FF27062F16F61F36F60EE6A5BED6859F06B5C
EE6A5BED695AEC6756ED6859EF6759EE665AF2695FEA6056EF655AF06359F06359F16359
EF6157F26659EE6255EC6859E06657D77061CB7D708F564B4F2A22472F2B40312E3B302E
342A28352D2A2F2A272E29262D2926302C292C28272925242E2A272D28252C23242B2223
27221F2D28252C27242B26232824232622212624252725262722262B242B1C151C928D93
F3F1F4E5E5E5E3E3E3E4E4E4E4E4E4E5E5E5E3E3E3E4E4E4E4E2E3E9E7E8EAE8E9979392
817B7B7D75737E767381797679767163625DDCDDD8E5E5E3E2E2E0E1E0DEE2DEDDE9E5E2
EBEBE3A0A398626A5D8E968BF6FBF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFBF5FFFBF5FFFBF5FFFAF5FFFBF4FFFAF300FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDF6EEF5EEE6
EDE4DBE7DDD3DDD0C7D0BFB5C1AFA3B4A193AB9387A4887C9F7F729E786B9A6F5F9D6C5D
AB7364AA6D5BB57061BC6E61C06A5BC76A59CC6858D06958D36854D76855D86755DE6B59
E36B5AE16857E46959E56758E96C5AEA6D5BEE6F60F37463F3725FF47360F26F5DF87563
F67361F77462F77364F67263F67162F67162F16B5FF36B5FF0685CF66E62F4675DF4665A
F36559EF6153F16556E96455E06556DC7063CC76697E3A2F521D154B231B3F21173A2218
3320192F221A2E272128242124231F2726242523242422232625232A26252C26282C2628
2E282A2B25272C23262B25252C2829201E1F211F2228262B2621282520273E3940D9D4DA
EEECEFE5E3E6E4E2E3E5E3E4E4E3E1E4E3E1E4E3E1E4E3E1E2E2E0E3E3E1E1E1DFE3E3E1
E5E4E2E5E4E2E7E3E2E7E3E2E4E3DFDADAD8E3E3E1E2E2E0E2E1DFE1E0DEE4DFDCF2EDE9
C1BEB5787A6F646A60CFD4CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFFAF4FBF2EBF5E8E0EFDED4EAD6CBE3C9BC
DDBDB0D0AC9ECCA093C79688C68E81C38576C27F6FBE7566BF7363C07160C16E5EC46C5E
C76B5CC76A59CC6B5BD06C5DCD6758CF6857D46959D46657D76855D56452DB6A58DB6856
DA6554E16C5BE06858E36B5BE26859E56A5BE56A5BE76C5DEB6D5FED6D60EC6A5CEB675A
E76253E56051E66152E46252DD6354DC6E5FC165567325185E1C0C511C0A461C063E1E07
361D07291806190F03100C030B0A050B0C070C0A0B0D0B0C110F10100C0D100B0F171216
1B1519161014120C0E140E101D1B1C2A282B2F2E342F2E36302F373E3D4598979FDEDDE3
D7D6DBE0E0E2E4E2E5E7E5E6E7E5E6E6E5E3E5E4E2E2E1DFE0E0DEE1E2DDE0E0DEE2E2E0
E3E3E1E3E3E1E2E2E0E3E3E1E1E1DFE2E2E0DFDFDDDFDFDDE0DFDDE1DDDAE9E1DEF3ECE6
6E6A5F64645894978EF6F8F300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFAF5
FFF9F5FFF9F5FFF7F2FFF3EFFFEEE8FAE3DDF6DDD6F2D5CDEBCDC3E3C1B7D9B3A8D0A59C
C79890C09086BF8B7EBB8678B67B6DB47566B87467B76F61BA6E5EBB6E5CBC6B5ABF6C5C
C26B5AC16654C26554C1604FC66252C86152CB6455CD6355CA5F4FD16153CE5D4DD25E4F
D25D4CD5604FD76250D76251D2614FCE6351BE5D4AA551399C5537894D2977471F6E4B21
61451D4F3D19797053837E6A7D7B6F75746F807C7B7975767975767874757772766D6B6E
7672737F7B7C858182908C8DA6A4A7A1A0A672727C4B4D59474B564A4E576D717A74797F
787D838F94989DA0A5B0B1B5C0C1C3CACACADAD9D7E9E8E4E4E3DFE4E3DEE5E4E0E4E3DF
E5E4E0E4E5E0E3E4DEE2E3DDE3E4DEDFE1DCE1E3DEE0E1DCE1E0DCE3E0DBF1EAE2DED8CC
423F30807E71D2D3CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3FFF9F3
FFF6F2FFF0EAFDE9E2F9E1D7F5D8D0F2D1C8F0CBC2EEC6BCE8BEB2E6B8ABDEAEA2DBAA9C
D9A397D49A8ED59A8CD29286D18D80CD877BCD8579C77D72C87C6FC5776ABE6F62C16F61
BD6A5CC46E5FBD6758C0685ABA6455B66353B26553AE684FA76A4BB3825AD0AA7BC5A775
C0AC7AC7BA8EE9E0BFEBE7CEE7E3D7E9E6E1EAE6E5E6E1E5E5E0E4E7E5E8E6E4E9E2E0E3
E4E2E5E7E5E6C2C0C19B999A757678393D4022272D2F363C3740453A4446424C4E485254
4C56584D5758535B5D51565952585850545370726FE3E4DFEEEDE8E6E5E0E5E4DFE3E3DB
E4E3DEE4E5DDE3E4DCE0E3DAE3E6DFE2E5DEE1E4DDE0E3DCE0E1DBE7E4DDE4E0D7A39F93
484536A2A094F6F5F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F5
FFF8F4FFF8F4FFF8F4FFF2EFFFEEEAFFE9E4FFE6E1FDE1DDFCDFDBF9DAD5F4D5D0F3D2CB
EECCC3ECC7BEE3BDB4E0BAB1D5AFA6D1ABA0C9A599C09F8EA98D75B09979A8966EC6B98D
D1C89DA09B75A6A285D7D4C1CCC9C0A6A5A1B4B2B3DFDDE2D1CFD4B0AEB3B8B5BCBEBBC2
E7E5E8E7E5E89A98997577767379777F88854C5753333F3B45524B45524946534A48554E
48554E4A56524F5A564C575349545047524C495049ACAEA9D2D3CDC8C9C1C6C7BFCCCEC3
C9CAC2C8CBC0CACDC2C9CFC3C7CDC3C9CFC5C8CDC6C4C9C2C5C8BFC1C4BB9B9C947A7A70
8B8B81D3D2CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFBF500FF00FFFAF4FFFAF4FFFBF1FCF3E4DBD5BF9F9A7D9A9778
908F70616145373923A4A698BDC0B7414340404143A0A1A5C0C1C53034374142475B5C60
9C9D9F9698977C7E7D646867737975B8C1BCABB4AF89948C909C92939F959FABA19FABA1
A0ABA3ACB7B1B0BBB5AFBAB4B7C2BCBCC7C1BFC5C1D1D6D0DFE2DBDFE0DADEDFD7E3E4DC
E0E3DAE0E3DAE4E7DEE4EAE0E5E8E1E7ECE5EAECE7E7ECE6EDF0E9F0F3ECEEF1EAF4F7F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8F8F0DDDFD4
ACB0A1838A7A5860515A6459657167303B35333C39505B57C2CDC939444035413F3D4945
47524C4C5550464C48797E7AC9CBCAF5F7F600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00E8EFE8CED5CEBAC4BCA5B0A895A09A87928E76817D9FAAA458655E4B575348554E
5D6A639EA9A3D5DBD700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00ECF0EFE3E9E7DAE0DCD2D8D4
DAE0DC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.013213 0.97619 0.264889 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF800000FF00
00FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF800000FF00
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF800000FF00
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF800000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF800000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.290056 0.477324 0.541732 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F5F5DCDCDABEBEBC959593767674
898B86B6B8B3D7D9D6F0F0EE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEECD3D2D0AEADAB8786845D5C5A3E3F3A2425201E1F1A1C1D18
23261F23261F3A3C375355507C7D77A9AAA4E0E1DC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00D4D3D15D5C5834332F1F1E1A24201D1D1C181D1C171B1A15201F1A20211B
22231D1C1D151B1E17181B1421221C22231D54554FC6C7C200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00F3F2F0726E6B211E1923221D25241F27262125241F22211C221F1826231C292621
23201B23221D201F1B22211C26272123241E22251E3D3F3AA7A9A6F6F8F500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A5A4A02F2C2725221D29262126252024231E2926212D2A2535302C3A3531393430
35302C37322E36312E2C282529282323221D2627211E211A2527227D7F7CE8EAE900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D0D0CE41403C23221D27241F25221D23201B2A272238332F3B3632423A38433B3939312F
3C3431433B38423A374139363C37332F2A262926211E1D181E201B1A1C19797B7AF5F7F6
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E8DAD9D1BFBDD8C6C4DDCBC9E5D3D1EAD8D6
EEDFDCF6E7E4FBEBEBFFF1F0FFF7F5FFF6F4FFF7F500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F0F0EE
6C6D681D1E1922211C25241F211E19211E193B36323D383435302D39312F393031332B29
372D2B3B312F3F35333E3432443C39423D393D383425241F1D1E191B1D18323431CDCFCE
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECD7D47C5751582B2561302C6534306D3C376E3F39
784B467F544E865D598D6661916B6892716C987974A68985AB8D8BB59996BB9F9CC5ACA8
CCB3AFD7BFBBDBC3BFE1C9C5E4CFCCE8D6D2ECDDDAF2E4E3F4EAE8F7EFEDFAF6F5A6A5A3
2F2E2A25241F24231F22211D1C1B162B2A25413D3A2F2B28312D2A2F2A272F2A27312C29
37302A342D273C332E3B322D3B342E3D383245403A35352D24251F23241F232321878785
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F7DFDD8D64606B302A75302973292670262370292369241D
6A272164251E6A2D287E433D733C376C3A336A3934683B366236336438355B322E5C332D
5B342D5A332C5530285D3832623F3963423D6B4E4A6C534F6D5A565E504D554D4B37322F
26221F272621262521231F1C19161137342F423D3A27221F2C28252B2724282320302B27
332C262F2822382F2A3B322D362F2939352C38332D43403938373221221C23241F40403E
DCDCDA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAE6E59D706D75312E873633872D2C862D29832A26812927812C29
7F2C287A2B267729257D33307A372F7B3C357136306B322B68312C713C3667322C6D3830
6D3B327242386F3E376C3B3471403974453F673A34562D2753352D2F1812130502211916
2E292625211E26221F221D1A221A173A322F463C3B261E1C36312D312C2827241F292621
2A25212D2522332927372D2B362F2938332D2D28243F3C3740403828292323221D21201C
91918F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFEFEDA88281702F2D87322F8829278C282896302E8925238E2C2B8F312F
882D2A882E2D832E2B81302D7A2F297C362E77342C692A237539317A3F376F342C70372E
69332969352A6E373070393278413A8F564F7C433C622D276F443D47261F1F0A05271C18
2E262326211E28232025201D221816352B29493E3C2F252338312B39342E29241E27221E
26211D2B23202E2624352D2A342D2739342E26211D34312C44443C30302823221D1F1E1A
424240D8D8D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5BC9693692E2A8938359B3C3AB34B4AC65C5C9D3534932D2B9836359E3E3F
993B3B9C4241933B3989363280312C7F362F8C474073332A7C40388449417F463F763F38
7C473F744239713C366C37316F3531753833793A356D302B7D48406237302E110B2D1B17
2F24202E26232A252227221F271D1B2F262144393540352F382F2838312930292329211E
2B2320261E1C2A221F2E2623342D27453E382A252138332F4B48432F2E29252420272622
26262480807E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00C6AAA7662F2A732521A14341B74F4EBC5252B94F4FA03837A94543A64445943435
943636903534943A398F3A378637327C312B742F2875362F6A2F297039327A453F7A453F
84524B814F48723D37753E39743734712D2A762F2B752E2A8946407C433C4C1F1A3A1914
361E1A3526232E23212B23202D23212B221D3027223C332C443B343E352E312A242F2822
322A27271F1C231B18302923413A34423D372F2A26423F3A413E392A292424231F292824
2A29272F2E2C706C6DA6A0A0CFC9C9F0EBE800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D2B9B4693C3669201A89302CAB4541AA413EA8403DA33D399634318E2F2B8A2C2C882A2A
892B298A2F2C8D32318A32308736326D241E8A49439A5F59753E3979464285544F895853
8A5753925D5987504D8B4F4E904F4D843A3981302D83302C8C3935984944813E38561F1A
3B120C3A1D1735221E2E231F2B211F2A231D2A231D2B241E4138334A413C49403B3D342F
3D3630332C26322D2739342E3D38323D3A33423F3A3E3B3634302D2A29252524222A2927
242321201A1A1E14151D0D10422E2F715B5D877173B6A4A4D9C9C9F4E9E700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7D5D1
7249435F20197D28239B3735A63E3BA23A379C363293302B8A2B27842624882A2A8B2B2C
8C2D2B8B2C2A89292A872C2B822D286C211B92514BC58B87AB767094635E92615D93625E
A3706CA5706C9A6261935757945253863C3D8A3636862C2B8E302EA04240A149478B3D39
5E221A4819133D1A16361E1A2F201D2E252029221C2B241E2D241F382F2A453C3747403A
47403A47403A47423C46413B423F3843403943403B2F2E292A29252A29252B2A28262221
261D1E271B1D230E1326090E3F1F225E3C3D5737384A2C2C4C332F65504B897871B8ABA3
DBD0CAF5ECE700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B19591
622B2671241E9132309F3937A33D3B9F3937932F2D8F2D2A8F2D2C8E2C2B8C2A2B8D292B
922A2B8C242591292A8D2B2A8E332E8030296D28218A4D48BB867EBC8A8394615D895653
B07D799C6763AA72719A5E5E7F41426F2B2C7526297C26278F2F30A23E3EAB4543AA4B47
9B433F762D27551B174519163C1E1C3724203325222E23212C22203228262C2421322D29
312C283B3632403B373C373339363136332E2C2B262A29242928242726222B2623291F1E
2A1A1B341B1F2D0C133910184C1F245F32358E6465916B687D5B5265453A5639294D3221
5B41306F5848957F72C1AFA5E3D2CAFCEFE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FBE9E5835E58
65221C842B279F3937A2383898302F9D3735993331952F2D902A288C2425942A2C972A2D
962829962527962829992F2F922F2A8A312B7C312B81403A8D564FBC8A83C79491875451
A26F6CC18E8BB67E7F9A5F61A66A6CAA6A6BA75F629242458933348E32339D3D3E973939
933B39984A4882413F5C29263B15143D211E4028283A26273323233325242D2220312725
352B292F25232F2523362C2A2F2724332B282A25212D28252E26242A201F2D1D1E2C1618
38191E38101834050D4D1A215A252D5C282C7141419A6F69AB83799A756397745E907155
8265476E51335A3F2450361F573E2A6E5948938175BFB1A8E2D5CDFAEFEB00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DBC2BD653630
70221E90312DA13835A537369C3030992F2F9C302E982A299729289A2A29A02C2DA32C2E
A22B2D9E2729A52E30A43031A133328B282395403BEDA6A0C88D87915F58D29F9CAB7978
703E3FDBA7A9D49DA26E353BB77F82DB9FA1C8878BB16F71AB696A894546B97375D99395
BE7C7D8E5051793F3E734140653D3D4927264E2C2D48282B45282A43292C3D27293B2729
3523233422223323233626263424253222232E1E1F311E22311C21361B2039141B390E15
410E15430C12561A226B2E36682C34652E33643032764642A27A6EA27F6B937457937752
9880529A7F509D805495784E80623C6F512F5D3E2253351D593C2A725849978176C3B1A7
E3D4CDFAEFE9FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE8D88602622
7D2A269C3836A33735A13130992B2C99282A9D2A2DA12D2EA83435A42D2FA62E30A92E30
A92E30AA2F31AE3336AB3335A733349F3130842221B86561F2ADA8CD928EA06966D7A4A3
926063D6A3A8F1BCC26B363C935A60DFA4A8B07378BB8082905A5AAF787BF0B9BCF8C1C4
F0BCBEDDABAC916161CCA09FF0CAC9BC98985D3639553133502D3140202548282D523237
4525284022243E2123381E213C21263B1E233A1B2334131C3B152043152048101B4C0D18
53101964212A7330396D2E36894D5570393E6935375727237B5349A98672A5876B8E744F
8D7545917A44957C449D824BA1834FA384559D7C5193714B8463426A4B2E593D254A311B
543F2C716050948477C2B5ACE3D8D2FAF2EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8EAE7825B5663241F
883231A23B3CA336399D2C2E99262BA02C2FB94246B94045BD4449BE4648B73F41B1393B
A93133AB3335BA3F44AF3437B2373AAE3739A431348C2624A44C4AEBA29CCC8C8AC08887
D5A3A6BC8B8FEBB9C2925F685E272DCB9298AB7076CC9497AD797B875556F0BEC1EAB9BC
956769BE9495EBC3C3F9D6D4F8D9D7E8CAC8856566D0B0B3D8B8BDA8858B5C333B5C2D35
602F3557292C471E223D161B4118204B202A481826440F1F511628591627681B2B792636
7E2E397D313B78353C70353BA77278916064774649693B3B5D342E7E5A4CB1917CA68B6D
90794F8B7543917B42968044947E42957D41997E47A28752A78D5AA38958A2875A927950
8167426E5433583E234D351D5A4331705D4FA18F85C9BAB3E8DAD7FEF4F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D9C6C26B3C36722B27
9439389D34389D2F32AA393D9B2A2EAC3B41B7484EA9383EBB484DC45156DA6669E67273
E36C70D2595ED55A5FCA4F54CC4F55C3464ABD4245B541429F39379E4541D58783E7A6A4
FBC5C5C49397A27379EDBBC4AC79807B444AB57C83E3AAB0EDB5B8804C4EDAA9ACEEC2C3
D4AAAB855F5EC09E9CFFE3E1E9CDCA9D817E856968F2D4D6F8DBDFFDDCE3E2B9C1976870
79464D6F3E429B7175C79EA69A6F79623441834E60C1869CA36278BD74888F3A4F9C4153
98404E86353E833C42A96C71A87174A37174966666956767986C697A544B967264B99A85
A58B6A8C754B8069378A743B927940967C419B7E449B7E469E844B997F469E834CA58A55
AA8E5CAB8F60A78A609476507D6040654B305B422C4D36245946386F5D539E9087C9BFB6
E8DDD7FEF5F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE918D6B302C85312F
9B37399E31349D2E34A6373D9D3438B55255BC6166B85D62AF4C51AB4447AE4144BE5051
D66368D96268DF666DEC7176E3666CD95A61D6595DD2575AC65253B64D4AA54644BF6E6B
F1B1B1FFCBCD98676A96696CF7C8CED29FA4935A61A4656DCA878E7C3E43C79598EAC0C1
C39D9CCAA9A4977873ECD0CCFEE5E1DFC7C5A98C8EE7CACEFADFE4B6999EDDBEC4E4C1C7
654145AE8A8ED0B0B5DDBEC6F4D3DEBC98A6906377EEBAD1DCA2BAD38FA6C16F86A0475B
A74C5D822C37B0636BCE8C8EA46868AE7675A06A6A996766A3736F996C66986D66A98376
B99984B193777D613C583B11714F22815D2D8C6335976F3E9E7A489F7E4B9F804A9E8149
9E844B9F864D9F864DA58C54A58E5AA58D5DA0875E957B587B604362462E4C311C472D1C
573D2E735D50A08C83CCBBB3EADDD7FDF4EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAE8E6845C5A77302E943636
9A2D30AE3B40B64147BE4F55A43D41AA4E51EE9FA4FFBABFEB9296DB7C80CD6A6DBB595A
A94448AA4146AD4046BA494FC45158CD5860D96268DA6166DA6365D56363D16563BB5C5A
BE6E6DF7B3B2FBBFBF8C5656B17D7FFFD1D5F4BDC3995C638A474E88464A8C5457F6C8C8
BB9592B1928DBA9B96B39793F9E1DDF2DAD8E1C4C6D4B7BBFFE2E6CFB2B6A88B8FF3D4D9
997B7DE2C5C7FFE5EADFC4CBECCED8FFDEECC79DB1B2859AD8A4BBEAAFC5E69EB49E4C62
A750618E3845A3525BC87D829D595AB87878B07372AE7271AB716FA26B6897625C7E4E44
A97F71CCA794AF8B717B583869411D7C50297F52298051277F5429875E30936D3C9B7743
A3844DA4874D9D8346A38B4DA28A4CA28C52AA915BAB9160A88D62A48861977A5A826448
694B31563A24452C163D26145441327563579F9089C9BEB8E9E0DBFDF5F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E1C5C2753F3D832E319E3438
A42F35B93E43BA3F44B84349B0464A95393ED98C92F6ABB0C0696FC56A6FD98384DB8B8C
E3979BD08186C56E74B55860A2454D9E3D44AB4249BC4D54C55458C75457D05E5ED26463
D36B6AD77977FAA6A4DE9292AD6664D39695FFD9DCFCCBCFB77C82A26467884849BA807F
F3C8C2A3807ACBACA7BCA09CE2CAC8D2BABAD9BBBDE6C6C9E4C4C7FFDFE3DEBBBFF0CDD1
D5B7B7CFB2B4FFE7EAC4A7ACC2A3A9FFDCE6D1ABBAAD8496BA8FA2D5A4B7FCC1D5B36E81
88394C8C384886323F903F4686373A8D3E41AC6062AF6566B3696ABF7876B6716CA3625C
7A4136BE8F7FC99F89A880667D553270462083532B87562E84532B87562E84502B86552D
885B31976E40AC8854AC8D54A58B4EA58D4FA48F50A28E51A08D559B8A56A08B5EA18B62
A38B659E8660957D5979613F664D2E4E34193D220D3E2413533D2F78665AAA9C93D0C6BD
EDE4DDFFFAF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E9E8E4D4D3CFC3C2BEA7A6A28B8A886C6B67
65616063625E69686465645F62635D767771B7B8B3E9E9E700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BA94917232328F3034A43138
B63A42C24048B43338B93E43B14449983C3FE19A9EE1A0A48F474AA65C5D914B4B935655
FFCACACE9697C18182D79295D79096E99CA4CE737CCA656DBB4E54B54448BD4B4BB84645
C14F4EC55957CC6868C96B6BC66E6CAE605EDEA3A5FFD9DBFFC9CCBD7D7EAC6263A15A58
D99F9BE6B7B1DAB5AFE8C9C6C0A2A0EBCDCDB99798E4C0C4D4ADB2D0A6AAF4C1C6F1BDC1
FDCCCFEDBFC1FFD8D9E0B8B981585CDFB6BEE0B6C0A37985F6CCDAE2B4C1DCA7B7DC9FAF
9952647E31417B2D3A7E2E37792A2F7B2C2F9141448331359D4B4DA55053AA5656A25450
6F2A238C5246C39482C79D84A47D5C7E583173491F774A20794A207E4D25854F2B854F2D
844F2D784621805028906538A27D49A98A51AA9053A49053A39459A69B63A195639D9063
998A5F9E8D629E8B619E885FA28A649A805D8B7150785D40664C33472E1835200D362513
5040307A6C5FA89B92D3C9C0EFE6E100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00EAEAE874757048474232312C2625212F2B28322E2B302C29
312C2939353239363137342F32322A2C2C242F2E294D4C4890908ED4D4D200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F9E7E58F625F782E2D983337B13A40
BF4047C03A43BC363FC14249B7494C893130EFB3B2F1C4C1AB7A767D4A4661322CC79C95
FFDDD7ECC9C37C504D704242DEB1B4FFD3D9D58892E48791F28A91EF8285E27676D26463
C65857BC4E4DBD5053BF5557C86061AD4D4E934143E8A0A3FFD0D4FCB8B9D37F7FC66E6C
B2635ED7948CFECBC7FFD9D3C39C97D2AAA8E5BDBEB48A8EEABDC4C28B91D98E95E48F96
EA959AD98789CF8584EEADABDFA5A4C08C8EFBCAD0B4858DC6949FF6C2CEBE8895D9A1AC
E6AAB6A7697472333CA3626AAB696D934C527B2E348332388D363C92373C8F3034903636
883734702C23925D4DD0A68EBB9878A181588E6F408665327C58267C542376471D75411C
824A29854A2C82462A8247297E48248C5D339E7847AA8F5AA3925CAFA570A39D6D959267
9A96709C96729C946F9A916A9C8E679C8D649D8B63A08D659F8C64947E57806947664F2F
50391A452D11381F093B241258423478665AA99A93D2C7C1EEE7E1FCF9F400FF0000FF00
00FF0000FF0000FF0000FF00898A85191A141D1C1723201B2825203B36323E39363A3532
3F3734473F3C473F3C453D3A403B353C37313B3831312E291D1C1731302B8E8F8AF4F5F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DCC4C277403D843330A1373BB73E45
C1444CBB3C45BF4049BD464CB44D50742521D2A099FBD7CBFED9C9BC9785A7826FF3D3BC
BDA18BF4D8C2C0A18DBB9B8CF7D6CFFFD9D8C27B83AA4F58CB6068D8656CE57275EF7C7F
F58182F27E7FE67275D86467C75457BB4F4FA23E409C4443D6878AEE9E9FCD6D6ED16D6B
D77874D07D77DD9A94FFC7C3DAA5A1925F5CE2B2B2DDAFB1F8C7CDEBAEB6BB646DC65E67
C55A60BE5559A24444CA7473F6AAAAE39FA0E5A7AAE8ABB09C5D65E6A7AFC1848C8A4F55
E7AAB1C68990A96B70DB9DA2DD9FA2D29195C47F848F424A852E3690333B902C34903034
8F35357B2C276F2F25C79783DEB99CB99C74A68A5A957A457B5C26906A3997683C905A34
85482B803C2589402F8E4534813D287C3F2378441F90693EA28A5AAA9C6B9D996A68693F
6365407A7B598A8A689895729B95719C946DA1956D9E9167998A5F9D8C619E885F927B52
93775087694574533461422654361E3B200B2C15053A2719544437766A5EA9A097D0CCC3
EFECE500FF0000FF00B6B7B22A2B251B1A152E2B2627241F39343045403C3C343239312E
3C34313B33304E44424D443F3B322D3D342D433C36433C343431281C1C12212119979892
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B59693793937913736A93C3FB84147
B94248B23F46A3363C9532379945455B1812C5998CD0AD97BC997BEFCCA6FBD9ACD0B081
AE8E5DD2B281FCDDB1ECCEA8B8987FFBCDC0E39D9DAD5058CB5561D04E5ACC4951D55258
D45358E16367EE7175F2777AF37C7EEB7979E17372C25A59AE4C4BC15D5DB64C4EC45858
BA5050B65451B25D5ACA7C7ACE8785B87775AF7372EBB5B5FFD5D8FFC6CCC77079C95F69
D36268D05F63C65C5EDF7B7DDD7F80C86E70B76164E28D92A65156AD5B61EBA0A5B87074
BE7679EEA6A9A75C60DD9598D391927D3F40D09297CD878F8A3942AF545DB14D57922D33
8E2B2E892F2F6F241F854A3CD0A38CCDAA8AAF8F66AB8C5D7B59295E330679451D8D512F
A35D439548347D2B1F8B372D8B392E873A2A7C3823763F21805A339C8657A69B6D8F8E60
50552D4B532E555A3A5E61446C6B4F817C5F938A6B998E6E9D9370A3967394855E947E57
9A7E5686663F7C5A3484613B83613E81603F7152355E4026492F1638220A311F093B2E1B
544D3D7B776CA29F984948431F1F1725251D2A27222C272345403A403B35362E2B372F2C
3A302E332A255449454E433F382D273B312845383242382F4841373D392E27241B32322A
B0B1AC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9EAE78C64627B3432983637B64549B43D43
AD3C40A73E42B85E60A85A5AA8635E854D40D7AD95D7B391C7A172D6AF76D5AF6EC6A059
EBC57CCCA760D5B771C8AB6FA98A5BE5BC9EF9BBB0A85454C1535CCE525DD1525DD04E58
D14D58CE4B53D24F57D45358D5575BDF6466E97172EE7A7AEE7E7DF18382EA7E7EDC7272
CB6765C16361AE5A58A35956A35F5CAD706DB07473A3686AE1AAADFFC8CCDE838CCA5C65
CE5961D05B61C95B5ECB6364C9696ABB5F60BB6264BA6467B65D61A44B4FA65458D18184
DA888AE69496BF6D6F954747DB9796A26564A1666AF4B5BDA0505B9A404AA23C4790272E
972E35912C30872D2D691E18925948CDA188BF9B79AC8B62A58258693E1466300A7C3B1B
893D258A37277F251D8D302B8D322D8D342E86372A803C276D3A1B68451D907B50A8A173
83845A484E28424727676A4F7D79606B634C6B5F4770604676674A8677568474509A875F
947B5281643A7F603477562B73522785643B75532D71512B785832745833614A28534224
372B13231C0A1912081C1912201D1625221D26211D27221E4A453F39342E3028252F2724
2C251F332A254C433E473C382F241E372C2641342E3D332A433A314541363E3A2F24241A
3B3C36C0C0BE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00DAC5C27747457E2E2DA63D41B84147B53C43
A6353999393AEDA3A0FFCCC4F4BFB1ECBCA5F4C8A5C49A68D4A869EDBF74E4B460DEAC53
E1B457F2CA6BBD9C3FDDBE6BCBAE68C9A873FFD6BAA466598C38369F3E45A9414CB44452
C54B58D04D5BD54D59D54C54D64D54D24B51CB484DD05255CE5858CF6160CF6B69C86F6B
BA6B64BD7A72B67D76B1827CAF8682BA8E8BC89697B2777BA56367D7868CC25D65C45359
C64F55C14C52AE4446BA5C5CCC7B78B9726EB57170B06C6DB3686CB7686DB35E63A85157
BD6267B15759AF595A803031894343BD7F80D4999FFFC1C9A85C68872F3BA139449D2E37
9F2D37982930942B2F852A276A2118A56C5BDAAE95B4906EAC89639E744C6C3813773618
893B258A32248E2F298F2D2C9331309132308E342C88392C7B392366331464421C8D7A4F
ACA5777F805440401A535031A1977E93816B7A5F4C866A54775C41705738604A25746137
7C673C7D683B826C3D7D6537816639937748795A2C70512378592B7E6233604A1B655228
746544574D3421190C1B140C27221E27221E27221E221A17433E3839342E201B17211C18
241F19362F293B33303B312F3128232E2520332824382F283B342C3A362D454138282820
1C1F165B5D58F2F2F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00B19391703837872E30AC3F44BB3F47B6393F
B5424592302F904943FAC4B8D5A692BC9171DBAF80CB9D61E7B76FDEAC57DCAA4BCA9932
BC9025DCB347CBA93DDBBB56E3C56DB5974FFFDAA9EEC09FD59A88CB867FBB6C71BA5E6B
C65767C84A58D34B57D54851D44950D44D53CF4E52C85153C85C5CB55755A554509A574F
A97369C09489B9978EBB9E96B39A95AA8D89AE8887BD8B8EBC7B7FAD5B61C25D63C15056
C24B51C04C4FAF45479C4140B46963B67A72AD7874A87773AB7374AF7174BD767ABB7074
B9686EAE5E61A95D5F7933359E6262A87073B0757BFEBDC5DB8F99A349559F3541A93540
A32B35A42C359D2A2F9830317A221E732D23C18978DBAF96B7906FAF8763A573506F3213
782D168C392990332B8F302C8E2F2D8E302E913830873529823B27753D2258300D61481F
9C8E5DABA573706D403C38126E6347A8937E77584665422E815D457C5B3C7456326F562D
664F236D5829725D2E76602F7E68378A73419379468E733E876C37866D37614A165F4A1B
8071486E6345271E0D1910072E27212B2622261E1B271F1C362F2945403A2F2A26211C16
25201A2F2A243D36303B342E342C29241D172C231E2D241F39322A39352C49463F33332B
1E211843463FE5E5E300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F7ECEA8F6968763636933438B23F46B3343BB8373C
BE4346B14747802D29AC6E61F2C4ACCAA37CE6BB86EEBE7CEFC072BC8D35B58926C59C30
D2AC3DC5A22EB3901CB69524EDCC65C9A74ED6B46AE4C084F0C69CF2C6ADFECCC5FFCBD2
F08E9BC04756D34C5AD44851D44B52CE4D51C85558BB5958A6575395564FA4736CBA948B
BB9D93AF978DAC988FB3A099A5948C9D8A84A18884A78383C28E92C37C82B95E65C1565C
BD484EC14A4EC251539C3A37944741AA6E66A1746E97746E9876749B77779F7778A67A7B
AF7D80AC7A7BA47275956467F1C7C9F4C7CC93575FB8727AF3A3ACD47982A3353EB03841
A93037A92E33A72E339F2E30932D2B7A221E874338DFA796D4A88FB28969B18560A06C47
6A2B0C7E331C8936268B3329893229822E247D2F2277301C76361B754021653C1E422400
8B7A46A69C61ABA8715D5B2B3D3413827259B0958266432F774E388C6045825A3775522A
6243175B4011674F1F523C0B564210634F1C705B2677622B786229836D347C672E776330
8173466F624021190621190E2F281E2F28202D241F261F192A231D3B342E453E38332C26
27201A2E271F403931463F37372E29261D16281F18292019362F273A362D48453E33332B
24251F3C3D38D9D9D700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00DBC9C77345457D3536A23F44B03B43B4353CB93B3F
BB4748AC464480312A6E3323EBBFA2E7C194C29659E6B86DB0822DB78B2CEBC259F1CB5C
F1CE5AF3D058F0CC54D1AC37BC982ADBB955D0B157DDC074CCAF75A5855EF7D2C2FFC5C7
BE616CC44E5ECC4957CD4A52CB4E52C55456B25454974E4897605BB08A81BEA199A9958C
9E8D859B8D84A1948CA59890AB9E96AEA199AB9995A58B8AB08889CC9195C27379BC5B62
C6575EC14C52BD494CB64C4C933E399A5A51A4756F95776F8C756F8D7A768C7474907677
957978997B7B967677957779CFB2B6F7D3D7BD8890A36069B86871BB6067B74C54B34047
AF3A40AC373DA9363BA436399D353695373571221DA9695FE8B8A4CDA488AF8763BA8E67
97633C6C2D0C82381F8A39268736257425147A2F1C8B473079391D70391A5D30114E2B05
997E479F8D4FADA567AFAA73534E24483D1F947E67AF8E7B6136238858429F6D52956746
7F552F724D238562385C3D115034055D43125D4310634A145D440C5A410870581C89733A
76643261532C221800231C0A2A2414312B1F332A212E251E271E172C231E3A312C49403B
40393130292139322A342D252F261F2B221B2A211A2B241C38342B3F3C353E3E362D2C27
1F1E19343530CFCECC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00BFA7A76C3636883839A63D42B13A40B1363BB74344
A33F3F81312AA3675CDAAB97E8BD9AC9A16ED8AD69E2B564A37619EBBE57F3C95DF3C959
E5BE47D0A930F5D157F8D35ED3AD40A7841ED9BB5BF2D683AF9451D2B385FFD6C3C28081
B95561CF5667C94B59C54C55BA5052AF5554924F49A06F68C8A7A0BCA59DA291899A8B84
988B83998F869B908A9A8F899D928CA49993AFA19EB3A09CAA8C8CBB8E91D19096C06A73
C45C65C8545DBE474DBC4B4DAA4847863732A46B64A37C759178718A79728977758A7A7A
897A77897A778B7977897576877374A4878BAC8188B97D87CA7E88C06971B34F57B0474C
AE474BB14C50B04D52A64348A24244A145468935336F2A23D7A195EBC2ACC09E7BB49167
BC9262925F326A2B0880391B8B3E227E2E13792B14994F36A560439D5E3D935B38996A40
A9824BA185449F8D4DB6AC6F8C895648431B53452AA98F7E956E5F8A594B98604F8F5541
9A61469D6647A671518D5D397F522B7F552B6C471A6947175C3B086E4D17866727866828
674E15635121312402221B01251E0B302A1A332B20372E25342B222D241D2A211A2D261E
433A3349403941383339302B322B25332C2638312B3C3731413C363E3B36302F2A282722
1D1C172C2B26C7C3C000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A88C8B7137368F393CAB3E43B43B40B63B3EAF3B3C
A13F3CE2938CFFD6CAE2B49DB38865DDB381F6CA8BCEA052B18427E7BA53D9AD44B28717
D6AC36E1B93FDFB73EECC550F8D265B59028D5B352DDBF69AB9147FEE0ACF3CBB1965954
AC4F59C75868C3505DBF545CA74F4E96514CA6756EBB9A91C8B4ABA79A919B8E86988D87
978C869A8F899B928D99908B998E889B908A9B908CA69794B19C99B59394C9969BD18A92
C36772C15660BD4952B9464BBD535599403C914C47A3726B977971907C758B7C778A7F7B
877D7B837977827775867A7A8373748D74789C747CA7727AC37A83B15B64A3484D9B4143
9C474AB96A6DB4686CAC6064A4555A9F50539B51526829249A6A60F9D4C2E0C3A5B89B73
BD9C67C59E677D4D1D652A007C390F8139137E33147F3518843A1D8039198442208E532B
96612FA1773D9C7E42A18E53B0A7707F784A3D3212594731AE8E81A67C70915D50814739
8B503E7C3F2A824832A0684FA76F549462418D5D3990643D8B62368B66319B78388A6C24
6348018C7937796C37271E00241D0028210E312A1A3D33293F352B42382F362D262F261F
281F183027203C332E463C3A4038353E39353E39353F3A363733302C282526221F24201D
201B172E26239F9892F2EBE5FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF5F3937472793C3B973E40AD3E44B3363CBA393EBE4244
A0302EBA5D56EBA299FDC5B4E7BA9DD6AC84DDAE7AD3A25FB2842FF9CD6EDAAF499C7003
E8BB46E0B43BB58811CFA433F5CC62CDA742AE8728E9C56FC9A95ED7B87FFCDBBAE4B4A8
A35B5FA24A56B65661AD545A96504EAA7871B08E85AE968CBCABA1B4A79EA89B93A1948E
9D928C9C918D9A8F8B9B908C9A8F8B988D89998C869D8E89A59391B59B9AC29B9ECF989E
CB7F89BE616BB84D57BD4B53C05356B2504F9445419A5D589E756F977C75907F788C817B
877E79897F7D867C7B84787887777A8F767C987079A46F77B86F789F4E549C4A4C8A3E3E
9C5F5CAA7774A77777A37577A67477A16F709E6C6D855855714C46E7CABCFFE5CED6BE9A
BCA06ECCAE72B49253764E116B3A02672F006628016D2B097730107E33147C2F117D3212
7B360F76390D71421491713EB19D68B1A573695D374436196C5A46927668906C5E8C6053
8C5C4E774335764133824A3B8E564589503D8A533E925F44865834926A39A27F3F987B2D
967E24B7A448BFAF5A70631F281C00251B022E2311332A1B392F234B41374E443B443B34
3B322B2B221D2B211F291F1E2B232127221F2923232B2726251F1F221C1C241E1E2C2422
2C222032251F37261F6B594FB5A399DBCAC2F7EAE400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00F4E5E286605D7F3B3A9E3F43AE3B42B13239BF3940C13C3F
B83E3DA338328B372DB67768E9B9A3F5CCACCEA275E0AF75B4843ADBAD57FDD170D2A63D
EBBD4DCFA02CB68715E9BB4CF8CF65C69F3AB68F32EFC974ECCC83AE8F58C3A281FFDBCE
F7B9BCA65D68A5555E91494DA16C68BA958DA48980A08E84A89A8FBDB0A7CDC0B8BEB1A9
ABA09AA0958F9E938D9E938D9D928C9D928C9F928CA0938D9E8F8CA4908FAF9392C2999D
CB8F97CD818BBA5F68B64E57C4595FC35C5FA74D4C8D4340A16F68A07E75957E768E7F78
877C78897F7D877D7C877B7B8676798F747B986F77AE757EAC636A98494E954B4C854543
A3736F97747093757394787796787A9779799878799576747F6662B69F97ECD7C6EBD6BB
CDB78ECAB37FCAB276C5A96AB79558A67D459464347843176F3408702F05702C0776300C
77330C7A3C13602F06633D109A804DB6A672A89C6C5F562D3E33155141287158427B5C47
8B685498725D986D5A8D604D895A488B5A498956437F4F385E3112906A3DAB8949A08431
A68F29BAA636C6B446C4B6557A6D272F2300281E002E24092E26133B3223463C3252483F
564C434D443D3E332F342A282E26242A22202620202C2626281F202920212D2322352B29
3628252B1C1528160C5E483B8D76688972649A8479B5A29BDACBC4F1E6E000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E4CFCC764A478B3D3DA63F43AD353EB5323AC1383FC23A3E
C24040BC4642A8473E863C2F6B3825E0BBA0C9A27BDDB27FC59555B07F32F2C36BE6B856
D5A63CD4A637C39526E2B649F6CB62B18A25DAB356D2AF5DBE9F5CD5B584E1BCA2FFD2CA
FFCACFE29EA99552598D5254B58D8BA58A839C8A809E90879A8D84A39990BBAEA6CABDB5
CFC2BAC0B3ABAEA199A4978F9E948BA297919E918B9F918E9F918E9F908DA18D8CAF9294
B89194C38E94C47D85B35E65C05C64C15A5EB5555697444092534CA77B729C7E76948079
8C7F798B807E8A7E7E8A7C7C8C777C94757BA1727AB778819C51569B4C518741438B5352
A079748F736F8C77748B77768C7A7A8C7A788D79788E7A798876748876729D8C84A79587
A6947EB29F7FBFAC82CAB684CEB87FD3B97ED0B276C6A669BA9658A67E408F652B754811
6537035E32015E35074E2C005D43129F8E56B0A468877E435F5927514A1E60522B614F29
59431A745B337A5D3B8164448D6E4F96775A916F54936F558461419B7A4DAA8C4CA38932
A99123BBA72ACAB935D8C948D2C7539B91324B42002B2300302708322A15372B1B3A2E20
44382C4E443A54473F4E433D4136323F34303E3432403634372D2B332927332824352724
352822271910301E127B6859987E6F8C71608E71619474678E7065997D71AE938AD2BEB5
F2E0DCFFF6F200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00D7BBB774413E933F3FA83B40AC3038BB353EC53C43C4393E
C64041BC403EB64B45A04E43622D1FDEB8A3C09B7EE5BB93DFAF7FC08E51C39349DAAC56
E0B254F3C661F2C761E4B953C09634BB9437E4C06CD0AE66C4A56EFFE0BAEFC6B4B58480
B3767DA86972894E54AA797CAF908D9A87809B8D849B8E86998F869C9289A3968EAC9F97
BEB1A9D1C4BBD3C6BDBDB0A7ABA198A59B92A0938DA0928F9E938F9E938F9D8E8B9E8C8A
A58D8DAF8C90C59096C27C84B55E66B6565ABA5559B459589244409C6159A67B74A0837D
98857F90827F8D7F7E907D7F92797D99747BAB737CB06D76914549994F507E4041966664
9B79778C77728D7B798A7C7B857A78887D7B857A78847977867877817372887A77887974
8A7C718E7E6E9080679C8C6BAD9B73BCAA7AC7B380D1BC85D4BE84D1B97BCDB378C2A56B
B798619F804A8767346A4C18412B00665416ADA35BB5AE66A2A063706F396C663684794C
67562A6C572A70592F533C12644D236750266D542C7D643C8B6F48907442A58A45A38A2E
A9931CBEAA23D2C22FD7C934DBD13EDFD653C3BC546A6514322C00251E002C220031260A
352A143B301E3E32224234273F31263B2D243D30273A2D2435281F2E211833261D36281D
25180824140442311D7A68529F8974937865917260916D5D9974649B76668E6A5C866659
8E7368A18D84CDBCB4EDE3DAFFF7F200FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00C3A29D8045419D4142AD3C40AB2E36C03A43C23940C93E43
C43E3FBF4240BF4F4D903932834A41EEC6BAAA8372D9AF97D6A98CDEAE86D2A36FCC9C5C
C6964AB88B38C89F47B08831C09A47E8C277D8B573E6C38DA4845DDBB9A0F6CEC48D5B5C
8E5055A160689B646AAE8486A188849C8D869C8F87998E889A8F899B908A9B908A9F948E
A29791ACA299BCB2A9C8BEB5CCC2B9BDB3AAA99F969E938DA19690A196909B908C9F918E
9F8F8FA48E90B69296C28F94C37E83B25D64B45458B95659A94E4D984A46A16763AD847E
A387839A8783928080917B7E98777EA1747BB4757EA1585F9045498E4A4986504E9E7674
9379788977758A7C7B8A7E7E867A7A887C7C857979857B7A877B7B817575897E7C8B7D7C
8779768578728779708A7C6F8C7C6C8E7F6A93836A9F9073AD9D7BB9A77FC7B48ACEB98A
D6C08ED2BB85CDB77DC5B071A28F4A83752AA39B48BDBA69D2D38D8F93585E5C2C817952
80714A6D57307D62377C61327F6630776127614B116D591E69521C5941038E7525AB942E
AD981BB8A616D5C62BDAD030D4CC2BDBD63ADED949D3CF51A39F346E68123E37002B2100
231A00261D002F240835270D34251032231038271535241232231031220D30210C281A00
1F110037280770623F76674675654C8A756293796A9B7E6EA18071926E5E95705E96715F
94715E8766538367528B705DA08B7AC8B6A8ECDFD6FFF9F400FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF6F5AF89868645419F3F41AB363CB2333AC23C45C13840C94047
C33B3FC44244BC4445922C2AC67874FFCAC3F2B6AEF7BDB1F5BCABF7BFA8E0AE8BD3A478
E2B57EC99D60D9B26FDEB877E8C486B6915CCDA67BE7BE9ECA9D86D9A99DFFDFDBE8B1B4
9654588E5055B07D828B6767604B468B7E769E938D9B908A9A8F89988D87988D879B908A
9D928CA29992A2988FA99F96B5ABA2C5BBB2CEC4BBBAB0A7ADA29CA297919E95909E9590
9D9391A19191A58D8DB18D8FC99297BA7379BB616ABA575CB95659A34948974D4AAE7772
A7807BA48783977F7F997C7EA0777DAA757DB67078974A50984E4F7F3F3D9366619D7E7B
8E79768C7C7C8A7C7C897D7D857979867A7A857B7A877D7C887E7D837978857979867A7A
887C7C837777897B7B887A79867875887B7585787084766B897C6B8B7C679183699B8C6D
AE9E7AB7A67BC7B585D4C38BD4C486CCC078C5BC6DB9B667D1D58BC3C98B5E603158542E
918464B39F7E8A6E4984653792753B8B702B7D671C8673267D6A1E604B00897212AC9724
B09C15AF9E08C9BB1CDBD22BDFD82FD8D42ADFDC37DEDE42DEDD51D8D65BBCB75397913D
6C651D524D0D3B3200372C002F23002B1D002E20002D1F002D1F00322400382B004A3D06
6B5F239A8E527C6F3A75673A6C5B3D705E4A725B4B81675A886B5D9B7A6BA480709F7C69
9070598C6C538F70549D7F6390775976614672604C867667BCB2A8E9E2DAFDFAF500FF00
00FF0000FF00
00FF0000FF0000FF00FEEEEE9C706F853F3DA43F43AF383EAF3037C23C45C0373FCC434B
C63D44C53C43C74046B4363AC55255D56D6CD77371DA7D78D8847AD38B7DF4BDA9D4A88D
E4B999D2AA86B6936DCEAC87DBB898AC876DFCD1C1F5C0B8EFABA8F5AEACFCB8B9FFC6C7
BB797A884E4DB9908EA789876C5953554842716660968D869D938A998F869C8F879B908A
9C918B9C918B9E938D9F948EA49993ABA09AB9ACA4CEC4BBD2C8BFB7AEA5A9A099A19891
9D948F9E938FA2938EA8908EB79091C99297BD7078BB6069BC575DB654559B43419F5650
AE7770AB827CA17E7CA17A7BA9767BB97B80AB606796474C904849854A46A07773957975
8D7B77897B7A877B7B897D7D847A79857B7A897E7C877C7A867C7B857B7A857979857979
877B7D82767885797B857979867A7A857979857A78877976887B7582756D86797085776C
897C6C8C7C6C93846D9D8E71AD9E77C2B483C9BE80C5BE7AC6C781E6ECAC9CA37043451E
6D684BDBCBB2AA8C726E4A26B9945DBD9B51957A219D87248B7714705D00A28F19B5A21F
B6A414B1A106BDAF0ED0C51EDDD52CE0DC32E6E43AE4E541E3E546E4E44EE6E559E2E260
D9D95FCECD59B6B244A7A33897922C8B862289811F8B812090862499902BA89B35B5A840
BEB14BC4B759A494476C5C21624E2968523B816758866A5F7F635787695E7D6153987E6D
87715A8C785D8C7959937F5AA08D63A9936A9E88637C674858442B625340867C70C4C0B7
00FF0000FF00
00FF0000FF0000FF00F0DEDE906060883C3CA63F43AC353BB8363EC13B42C43E47C64049
C03A43C33B45CA3E47CC4049BA3339B02D32B23638AF3B3BA33A367D241EBC7E73EEBEB0
AB8070CBA191F2CDBBF3CEBEA27C71C19892FFD5D7BF7C839A4147A8484CAB5254C17371
A15D5A9B6662B5908AA68F899D8E897F746E584D47574E477D726C9C9289A1948E9E918B
9E938D9B908A9F948E9E938D9F948EA0958FA2958DA99F96C2B8AFCBC2B9BEB5AEB0A7A0
A59C95A09790A19690A69490A88E8DBC9397CE8F97BC6C75BE5F67BB565AB4545599413F
A66058B47971AF7C78AF7979B77778C27A7DA351579B4B4E853F3F915C58A4817D937B77
8B7C79887D7B897D7D897D7D867C7B857B7A887C7C877D7C867C7B867C7B877B7B877B7B
84787A85797B877B7D84787A867A7C867A7C85797B85797B867A7A867A7A837876857A78
877978897B7885766F8676678B7B6196875E9F9059A39A55BDBE72DCE29AE1EAB36C7148
3D3C1EB4A892EBD0BD65422498703CE3BD72CBAE4AC3AE3BB9A930AB9C1DB8A821C3B322
BFB019C1B314BBAE0ABFB40CD3CB20DDDA2DE6E439E7E63CE2E43BE2E53EE7E946EAEC4D
EAEB51F0F05AEEEE5CE9E85ADDDE54DADA54DAD756D6D151D6D151D6CD4CD7CD49D5C845
CEC043C4B745B09F47927D3C5E471D5A3E266E51417A5C518362598A6C6281675A836D5F
705F4B897D63978C6E9D906D9C8F6599885CA18F61AF9970A5916E7362443B301C746E60
FAF9F500FF00
00FF0000FF0000FF00E2CDCC8451508B3D3DA73E43AC333AB7393DBF3E43BC3D44BB3E46
B73D48B23641C53F4AC73E48C93D46C93E45CD4549C94749C54D4CAC4441843731EFB4AE
D8A9A3FDD2CBF5C6C0ECBDB7DBAFAEE9B8BBFFC7D0B4616BB84952C54E54B44848B05250
954E48B27D77AE8D869E8A839B8E889D928E988D89726763514642574C468274719D8F8C
A39894A0958F9F948E9F958C9F958C9D938A9E938D9E938DA49A91ACA299B7ACA6BEB3AD
C1B7AEB6ACA3A89B95A2938EA38F8EAB8F8EC3949ACD8E96BA6970B5595EB75457B65453
A04743A3534CBD6F6BC47674CA7978C77172A74E50A05051834240A1706CA0817C907D77
8C7E7B867C7A8A807F897F7E8C817F877B7B877D7C8B81808A807F867C7B887C7C8B7F7F
857B7A867C7B887C7C887C7C867A7A877B7B897D7D857979857979877B7B867A7A867A7A
8579798C7E7D8C7D788B7B6E907F659584588B7B3D94893AC4C369CDD27EEAF3B0B4BA8A
53523379715CF4E2CEB7997D744F1BD9B569E0C85ED4C244C9BD35C9C130C7BB27CABF25
CBC124C8BE1EC6BD18C6BE15C9C317D6D324E2E033E8E83AE0E236DDDF34E3E53CE2E43B
E2E33DE1E23CE5E640E5E843DBE03EDCE045DBDD4BE7E658DEDB4ED8D246D8CD40D3C73D
D0C340C1B23DAF9C4098813D71542860412584614E7A564A643E357A584E7E60567D6559
77675868604D736D57A09A80AEA888A59D769B9063998C5FA89B6FB9AD856760436E6C57
F9F8F300FF00
00FF0000FF0000FF00D0B8B87C4644903E40A93E44B0373EB93B3FBD3F43B63B40B13942
F68790E77481BB3D49C9414DC93D48CA3D45CB3E46C73F43C54345BE4A4B852624C77977
FFD1D1F9BCBBA66060874143E8ACAEFFCED4FAAAB5AD4955CB4F59CA494EC14B4BAE4C49
9A534DB98881A688809D8A849C8F89968D889A8F8B9C918D958A866A5F5B4E403D5A4F4B
8075719A8F8BA297919D938A9D938A9E948B9C918B9D928CA39990A39990A79C96A99E98
B8AEA5C7BDB4D1C4BEC1B4AEAE9F9CAD9897AF8B8DCD989EE39AA1B55E66BD5D61BE5A5A
C96A66C56863AD524FB25756CA6A6BC06061B557579D4746964F4DAD7673A37C77997D79
927D7A8F7D7B9384818E807F8F81808D7F7E8C80808D8382897F7E877D7C8A7E7E8C8080
8B7F7F897F7E867A7A897D7D877B7B8A7E7E8B7F7F877B7B8A7E7E887D7B8B7D7C8B7D7A
8C7F798E807790807190806796845C9281498D7D32ADA14BCDCA6DC3C571DCE19FE1E4B7
7473576F6856D6C6B7EED6BE7E5D32B79651F5DD7BE3D35ADDD14BDBD344DAD03DDBD13C
D3CC35D2CC30D1CB2DD2CC2CD2CD29CDCA23DAD730E2E139E3E43EE2E33DE0E239E1E338
E1E337DFE233DEE132DFE334DEE236DBE139DDE142E6E74DE3E24ADAD440D1C732D6CA3A
CEC137BEAE34B5A13E7E671B6B4D196D4C29947056754F3C7D564775514367473A5C4235
6150405F5241675F486A644A827D5DAFAA84B6AF83A59D6E9B9364ACA5799B997386866E
F9F9F100FF00
00FF0000FF0000FF00B89C9B814745903C3CAC3F44B0373EB73A3EBE4145B43B40AD3A41
F78D97EC828EB23A46C4414FC8414FC83F49C43B45CA4149C94248C7464AAB373AA73D3F
F79497BA575AB44A4E9D3438973B3EFFA6ABE9848CB9474FCD4F53C7494ABE4C4BA24742
9F5F56BA8F88A286829C8A869E908D9A8F8B9B908E9A8F8DA09591A196928D8280695E5C
4A3F3D59504B867D78978E87A0958F9D928C9D928C9E938D9B908A9D928C9F948E9F948E
A59A94ACA19BC5BAB6D9CBC8D4C5C2CEB9B8BD9B9CC69599E39EA3BF6D73D77B7EC56566
C76967D27772C96B69AF504EB85454B75051BF5859A64846AA5654BA736FB07571A97975
A47D789A7B769A7E7B99817F927F7B917F7D91827F9082818F81808C817F8F81808A7F7D
8E83818C817F877D7C897F7E897F7E897F7E8A7F7D8B807E8D7F7E8B7D7A8E7F7A8F8178
92817195846A97855F94834F948240928234AB9D44C3BA5DCCC86FC9C77CDBDBA7E0E0BE
918C798B8279B3A29AE8D1C1876A4AAA8A57FAE093F2DB7BEFDD6DEEDE65EBDE5EEAE05C
E4DC55E1DB51E0DA4ED6D443D8D645DAD943D7D63EDAD940DBDC42E6E74BE1E344DEE13C
E2E63ADFE334DCE031DFE334DEE235E1E539DCDF3AE3E441EBE748E0DA3CD7CE33D2C72F
CCC02EBDAF2ABAA83A78630A573E008163317C5C33603D1D8A664C6A473193725F7F634E
6047315540255D4A2A6F613E695D3770693D9E9769B7B384B2AE7F949367AAAA84A9AC91
F8F9F100FF00
00FF0000FF00FFF6F49C7E7C844744953F3EA93C41AD3439B83D40BB4045BB444AAF4248
D5717BDD7985A93B48B74252BB4251C04351BE404CC3444FC2404AC2434AC2474CAB3239
BC474DBC434ACC4D54CC4F559D282EC55259D45B62C94C52CF4E52C44A49BE524F99443D
AE736BB590889D8581998A879A8C89998E8A9A8F8D9A8F8D9A8F8B9D928E9F9492A19795
897F7D5E545248413B58514B847B769F948EA196909D928C9B908A9C918B9A8F899F948E
A39892A29791A89D99B1A3A0C3B1AFE3CBCBEBC4C7E3AFB3CD868CB25D62CE7275CF6F70
DB807DE58A87F09290DA7B79C86464C35C5DC0595AB85454A94B49A85350AA5C5AA96361
AF726FAF7875A97874A87C79A37D7A9E7C7AA18480997D7A99807C977F7B95807D927F7B
93817F9283808D7F7E9385858C817F8E83818E807D8F827A95847A90807197867494846A
98866294825490804492843DA59547B0A450C7BD68D2CB7BDDD894D7D49DC5C29FABA994
9C958DA29897A39594C3B0AA6D5342694F2EA58957BFA260DEC171F0D57AF4DA79F3DE75
F0DE70EFE36DEDE36AEBE366E9E162E7E05EE3DF59DFDB53D7D449EBEA5AE7E753E0E147
E1E340E2E53CE1E539DFE337DEE235DDE135DFE138E0DF39E6E33EDFDA36D5CD2CD3C92A
CCBF25C9BA2BBEAF30A99729806B107D6618836A27785E239F8353775A308266419A805D
745A37765F36816B3C6A562362521E6A5E2A766C3B847E4EABA778A6A579A8AA83B3B69B
F8F9F100FF00
00FF0000FF00F7ECEA8A6B688144419B4341A53B3DAA3337B63E40BA4347BA494FAA4249
9A3B43B0545FA44654A84758AF4A5CAD4657B04555B14554B2424EB7454FB94550B8434C
BE454EC4454ECD4750CA444DC9434CC23C45CF4751D04950CB484DC04A4AAE4A48974843
B9847EAC8B849E8984978A84978C889A8F8B988D899A8F8B9C8E8B9A8F8B9A8F8B99908B
9D948F9D96908C8481574F4C483E3C665B578C817DA39592A49791A396909E948B9D938A
9E938DA29791A49693A79895B09B9ABC9C9DDEADB1F4B3B9C17077B2555DAB4B4FB55255
DE8080FA9F9CF79C99F29794F69B9AE58787D17270D37170BF5B5BB35150AA4A4BA24746
9D45449F4B49A65554A95D5DB16B69B0706EB57B79AD7A77AD7C78A77B78A27C79A0817C
9D807C9B818097828199858693817F907E7A93827A9C8C7C9A896F9886629A875C94834D
8F7D3D94833BA09344B1A656C0B76AD5CC87E0D79CD8D0A1C1BB97AAA68D9F9B8F9D9A95
9F999BA09A9EA399A1B3A7AB8D7B795138316546346B462B875B34B18352DAAC71E8BB77
EFCA7AF4D57BF4DA79F9E37DF4E178F4E475F2E573F3E872EEE66AEDE868E8E65FE5E456
E0E34CDCE043E4E643E2E540DEE13AE2E53CDDDF36DCDE35DBDA32D6D32CD4CD27D5CC29
D0C325D3C62CCFC331CBBE34B9AC2CAA9B26A08F259C8C2D9C8A368E7C34715D1E7A672D
77642A766225B09E56B8A65A8B792F5E4D0866551D756736797142C3C095B0B28DADAF97
F8F9F100FF00
00FF0000FF00E5D7D47B5A55864742953D3BA53B3DAB3438B84042B84447B04348A03B41
AE535CB15B66B46471B66876A65969A254649342517F2D3B8F3B488B333F983B46A13D49
B3434FBB434FC64450CE4650CD414ACC3F48CD3D47CF434CC8454ABE4A4BA849479D5650
BD8E88A2857F9E8B859B8E889B908C9A8F8B978C88998E8A9E908D9B908C9A8F8B99908B
99908B9B948EA099939E9791897F7D5E55504A3F3B685A578B7D7AA2958FA398929E938D
9C918BA29791A49693AA9695AF9294B98F93D4959DD5858EC86770C75E65AE41479C3236
9B3435BD5B5AD47573D97B79E08282E48686E68785EA8684E7817FE47C7BD87071CA6364
B85152B65252A541439F3F40A14343A24848A85452AB5B5AB26867B26E6BB67976B27B78
AD7C78AB7D7DA88081A17D7D9E817D9980799A84769E8A719A886092814D917E439D8C46
A69649B6A95AC5BC6FD8D189DAD496D2CC9AB8B290A8A28CA19B8FA09B97A09C9DA09BA1
A19CA39F9AA1A199A4A89EA7B7AAB36F5C6046292B65423E71473B71422EA7785AB0835C
A37947BB975DC9A767DABC74E9CE81EED583F1D983EFDA7FF0DC7BF0DF77ECDF6FEFE56C
EAE160E4DE54E3DC4DE4E049E3E047E2DF42E1DE41DFDD3DDAD838D9D536D7D133D8CF34
D3CA31D5CA32D2C832D5CB35D0C633C7BF30C8BE38BAB034A99E2B9E932A8E832782771E
7A6B166E6008A49635E1D26DE8D974C0B1547B6B1E635516786F38BBB788B2B28CADB095
F8F9F100FF00
00FF0000FF00DBCDCA73524D844540973F3DA73A3DAE373BB94045B94248AD3E44A23D43
B35C64B66973AC6873965D66935F6BAF7D89B5838EB2808BCC9AA5AC7884B87E8ABD7986
903C4B9E3947BD4753C6444ECC454CCD4048CD3D46CE434AC7464ABE4C4C9E4443A96864
B38A849F867F9D8C85968B859B908A9A8F899B8E889A8D879B908C998E8A9A8F8B99908B
9B928B9B928B9E958E9D948DA198939F96918279745C514D4638356557549183809F9490
A0958FA0958FA3948FA8908EB58E91C38A90DD8D96C2616ACA565FDB5F67CD5056C74A50
B0393DA63336A03434A93F3FB95351D46E6CDD7775E07A78E47E7CE8827EE98381E27C7A
E47E7CE47C7BDF7778C55D5EBA4D50BF5154B24548B14749B24B4EA64445A74B4CAE5655
B26160B76B6DBA7677B67A79B2817CA781769C7D69977F5D927E4CA09052A99B54BBAF65
D1C57DDAD190DAD39DC6C197B2AD8DA09E899D998DA19E99A09C9DA09BA19F9CA39E9BA2
9C99A29A97A09F99A39F97A2B7ABB597879139262C402A2D4026253A1E1A957A6FEFD5C6
CBB09DBA9E88A98970A07F60AE8E68B6956AC7A373D4AF78E2BC7EEAC57FF2CE80F2D27B
F2D673F0D86CEDD863ECDA5EEADC59EADE58E4DB52E4DD51E3DD51DFD94FE0D851D8D049
DAD24BD4CC43D4CD3ED5CF3BD4CF37D5CE35D5CE37D2CC38CAC335C5BE39B6AE31A59C25
A097228B820D9E9419D3CA49EAE15EEAE065E3D86E8E842B605915BBB883B1B288ADB093
F8F9F100FF00
00FF0000FF00E9DBD87B5C577F444096403FA73D3FAC3539BA4146B63F45B5444AA13C42
AD565EB96E759A5D6498676DE3BBC4EDCAD1E0BFC8E6C5CEF1D2DACDADB8E6C2CEAF7F8D
7C3A48842D3DB24854C44A55CA444DCF434CCC3F47CB4249C6484BB7494A9E4A48B27570
AE8983A18A849D8E879A8F899A8F899C918B9E918B9D8F8C988D899B908C9E938F9A8F8B
988F889C938C9A918A9B928B9E958E9D948FA097929C938E857A765D524E4B403E645955
897E7AA0958FA99795AC908FB7898CD39097D57984B84854CA4D55D44E55D64D54D75056
D04D52C84A4DBC4144B13A3CA63233AB3B3AAB3B3ABE504FD06462D96D6BE07676DB7171
D96F6FE47A7AE87E7EEB7D7EE37073E16A6ED2595EC75054C75457BF4E50B34649B04849
A94547A54748A04847A3555394554EB08072D3B09ABDA583B39E6FBDAE75CEC385DDD396
D6CC97C0B78CAAA4849F9A86A19D929D9A959D999A9D9BA09C99A09F9CA5A09AA4A09AA4
A09BA29D989F9F9AA19F98A0AAA0A9B3A8B04B3E472E1F262A1B1E2F21214B3D3CF1E3E0
F8E9E4FAE7E1F7DFDBEDD4CDDFC3B7C8AB99B79780AF8C70A67F5EA88359BB9566C3A068
D5B272DBBB70E3C471E9CC70ECD06FEED56EF2DA70F0DA6DEFDB6BEFDB6BEFDD6FF2E072
F4E473E5D65FDBD054DCD24ED9D043D8D03DDDD640D8D13BD6D03CD5D040C5BF33BFB931
C8C13CBBB52DBCB529B6AF20CCC634E5DE52EFE76BE2DB73726B1DABA96EB1B384A9AC8F
F8F9F100FF00
00FF0000FF00EEE3E17E625E79423D934440A03C3EA73439B63D42BA4148B7444BA83F44
A1464DB96C729D5F6488575BF3CBD3F0D0D58F6E758A6B71C3A5ADBFA4ADCAAAB7A27987
A76D7C984B5BA34150BC4855C74853C8404AC94048CA444BC2474AB34B4A964844B78079
AA87819C88819D8E899E938F9A8F8B9A8F8B9C8E8B9B8D8A988D899A918C9A8F8BA09591
958C879B928D9A8F8B9B908C9C918D9C918D9B928D9E9590A39A959B928D857C775E534F
4C413D685A57917B7DB08E8FC18A90DC8F97C5616BC14C55CD4B53D44B52D5484EDA4E51
D74C51D54D51D44B52CE494ED14E53CB4A4EBC3E41B5393BAE3637AE3838B33F40C15150
CF6361D86C6AD66A68DA6C6BD76766DA6868D56164CD5A5DCF5F5ED66867D86E6ED36B6A
C96162C0595AC35F5FB25955934A41A97464FDDAC6F2DAC0D6C6A4D1C3A0CCBF9DBAAF93
A89D879F9685A49B92A29A97A19B9BA49EA0A09A9EA29DA3A09BA2A39EA59E979FA29BA3
A29BA29E979EA19AA1A099A09E979EB8AFB45C5358291E222D23242E24232B2622D8D3CF
F1ECE6ECE4E1EEE4E2F0E6E4F1E8E3F2E7E1F3E4DDEDDCD2E3CFC4D6C0B2C3AD98B29A82
AD9072A48360A38056AC8453B48952C99D60CEA15EE4B56FEEBF77F1C57AFBD283FFDA89
FFE089FFE286F9E17FF3DE75EBDA68E4D45AE1D452DBD14BD8D047D3CD43D8D049CEC63F
D0C83FC7C032CEC836C4BE2ACBC330E5DE50E2DB59F4EE808C8534A09E61B2B483A5A889
F9FBF000FF00
00FF0000FF0000FF00B8A39E73484281403A933A3CA0373BB34045B74046BA454BB4474C
A14145B16164A66569804E51E1B8BCF9D9DCA38386371A1E80656AD7BCC59F818DBC96A3
E1ACBC924E5D953D4DAD4453BF4753C44550C7434EC3444BBF4B4CAC4846944B45B7857E
A688809D8A849A8B869A8F8B9B928D9A908E9B908E998E8C9A8F8B99908B9B908C9B908C
99908B9C938E9C918D9A8F8B9C918D9C918D9A918A9990899F98929C958F9E95909D948F
8E83816F5F5F684E51795054B1727AD57F88B84E58C95057CA4C4FCE4A48D24C49D34E49
D34C49D54B49D44A4AD74D4DD4494CD64E50D54D51D14C4FCC4A4CBF4142BD3F42B3383A
AF3939AC3839B03C3DC24E4FD56162D15F5FD25E61D05E5ED06261D06462DC7370E8807F
EC8483DF7774CC6461B85953B2645A995E50EFCAB8ECD6C1C5B4A0AA9D8CA09486A59B92
A69D98A19997A79EA1A2999EA29CA0A39DA1A19B9FA49EA2A19CA2A19AA19F98A0A1979F
9E989C9D979B9E989C9C969A999397AFA9AD736D712C2628362D2E2A2522201D18C5C4BF
F2F1ECE6E5E1EAE6E5EAE6E5EAE6E5ECE7E4EDE5E3EEE4E2F1E6E4F2E7E3F5E6E1F7E6DE
F1DDD2EAD3C5E1C4B4D0AD99BD987EB48B6BA0745195653FA7764DA6754AB18352C79C67
D5AB71E4BC7EEDC786F6D18AF8D584F4D57BF6D876EFD76BE8D360E9D65EEBDB61E1D452
DBD249CCC336DDD546D0C839D2C63CE1D754DAD057F2EB819992418D8C4BB3B583A4A887
F8FAEF00FF00
00FF0000FF0000FF00E7DCD879625A7E534A904C4B913739B04349BD4850BC454BBC494E
A84144A85253B26E6F8D5757A17778F6D4D3E7C9C9674D4EA68D91F9DEE5A88792B68C98
A773807A3A4ABA6C7CA84C5BAC4351BB4754C44853C1484FBE4D4FA8494598534CBA8B85
A586819D8A869A8B88998E8C9A908E9B918F9C918F9A8F8B9B908C9B908C9C918F9B908E
9A8F8B9A8F8B9E938F988D899D928C9F948E9B928B9C938C9E95909B928D9D95929E9693
A59B99A49494A285878C5D63B16A70C1666DB84950C85153C04B42B94536B2412FBF4C39
CC5342D05243D25043D14B42D44A47D64A49D5494AD74D4DD44C4CD64E4ED64E50CE4849
C84648BF3E42BF3E43AE3034B73C3FB33B3DB84143C14F4FCB5E5BCE6561D46C69D6706C
D56F6BDC7672D06A66BA5B55CA7A71AE6E64C59B8FBA9E93A6938CA598929E9492A2999A
A09A9A9F999BA59FA39F999D9F999DA09A9E9D989C9F9A9EA09A9E9D979B9C959C9C969A
9B95999C969A9E999F9C979D99949AABA6AA847F833531322E2828282421161510B3B2AD
F5F1EEE8E4E1EAE5E2ECE4E2EEE3E1F0E2DFF2E3E0F3E4DFF2E5DFF0E5DFF1E6E0F1E6E0
F1E8E1F1E6E0F3E8E2F5E8E0F6E5DDF0DED2EAD7C9DDC6B8D0B3A3BE9D8CA4816E8E6853
8B5F469061459E694AAB7350C48B60CE9462DBA368E5B06CE8B768ECC369EBCB64E3CC58
E3D453CBBD38DACC45E0CE4EDDC7579A87209D902AFAF194AAA353848340B7BA85A2A685
F9FBF000FF00
00FF0000FF0000FF0000FF009C928963483F9A6964A258599E3E42B8464EC0494FBA454B
B24A4BA34748AD6364A26666835150C89E9FD2AFADC6A6A7BEA0A2E1C1C6A07B83C398A2
A7737F894C5B8C4555DD8A9A9A3A48AA3E4BB33D49BC454BBE5051A04540A15E56AE817B
9477739B8884988A87988D8B988E8D988E8C9B908C988D899B908C9D928E9C918F9B908C
998E8A9A8F8B9C918D978C889F948E9C918B9B928B9D948D9C938E9C938E9E94929C9290
9E9391A59192B08D91C28B91D88891B7535BC14E53C7514FB7493CAC4830B55B39984018
9A3D14B04D26B94E2CC65439CB523FCF5142CF4D40D24D44D55047D34C46D54C46D84D4A
D34949D34B4DD44C50D24B51CB484DC24146BF4145B4393BB23C3CAB3938C75756CF6160
CF6160D86C6AD56966C3605BB560599C584F906159AD8E89A59190A39797A09599A0979C
A09A9E9B969A9993979E989C9C96989B95979B969A9E999D9E989C9C969A9F989F9F999D
9E979E9B969C9A959B9D989F98969BA5A3A89893993C373B2A262726222114100DA4A09D
F6F1EEEDE3E2EFE3E3F1E1E1F4E1DDF8E0DCEBD2CDECD3CEF6E2DBF6E3DCF7E6DEF4E7DF
EEE7E1EBE8E3ECE8E7EBE9EAEEEAE9F0EBE8F2EAE8F5EAE6F6E7E4FAE7E3F9E1DDF2D5D1
EBC8C2D7AFA7BF9088B07F71A16C5A89513A84482C763C168149168B5A17BD9840DEC358
E3CF56CFBD3DDAC64BE6D060AE9435594100948327FBF096B7B05F7E7E38B3B67FA2A683
F8FAED00FF00
00FF0000FF0000FF0000FF00D3CEC8594B4274534CD39C999C474AB0484FBB484FB9464B
B54B4DA9494BA35155AF696B7E40415820218C5958EDBFBFEBC1C2D7AFB07A4D52B28389
D7A5AE9C6771874853E69AA7AF5360B94F5BA02B34B33C40BB4F4DA54B43A15E56B98D84
6E514B705F58948582998E8C9A8F8D988D8B9B908C9B8E889C8F899E918B9D8F8CA19390
988D899B908A9D928C9B908A9B928B9990899D928E9E938F9D928E9C918D9F94929D9290
9D8F8EAA9194B1868DCD8E97D57B87BC4E59C84F54C9524EAF48399F4A2BF8B682E7B270
C59044A1651C8D490893460EA0491CB1512BBB5232C65439CB533ACC4F39D34F40D24A3E
D44942D64B48D5494AD5494CD84B51D54A51D3484FCF464DD14A50C74247C23F45BD3C41
B93D3FAA2F31AC3636AF43419B403B89403A8D5A56B2908EA28E8FA19597A0959BA0969E
9C969AA09A9E9A94969D97999C979B9893979B969C9D989E9691979B969C9B969D9B969C
9E99A09B969D9D97A19E9BA49A979EABA9AE9792982E282C2C26282A2426161010A19899
FCF0F0F1E1E2F4DEE0F9DFE0FFDDDCC8A29F744B47B8918AFFDBD3E9C8BFB7998FBCA39C
F2E3DCEEE6E3EDE9E8ECEAEBE7E6E4E8E4E1EAE5E2EFE8E2F4EBE6F4E9E3F1E6E0F2E5DF
F2E5DFF4E5E0F9E6E2F8E3DEF2D9D4EDCEC9E0BAB1C89D8CCDA1847C5423B8944AEDD16E
E5CE5AD5C148E2CB5BA48B277C620E5B4200AC9C3DF8EE8DBEB95E7C7D31B0B57B9EA480
F9FBEE00FF00
00FF0000FF0000FF0000FF00F5F6F17F787055423BD1AAA39753529D4448B34A4FB8494F
B3494BB34F51A1484C9342489145496D25298D494AC88888E5A9A9C08587692B2E8D5055
E7ACB2E8ABB2D6959DA85B658F333EA13741A22A33B53E42BE514EA34941A36058BE9289
A0837D725F595A4B487769689486859C918F9B8D8A9C8F899C8F89A0938D9F918E9F918E
9D928C9E938D9E938D9F948E9A918A9D948D9D928E9C918D9D928E9C918D9E93919F9190
A59393A98B8DB9888ED78F9AC86371BF4955CE4D52CA4D4BC3574A7C2708CE955EFBD185
F0CD71F1CF6DE3BA5ECB9B47B1792E93520E954B0C9B4911AA4E1BB55024C35731C55233
CC523BD14F3FCF4B3FD34A44D74948DC4B50D9484FD7464DDA4A53D6464FD94952D2454D
D1484FCC474AC24447BA4646AE4C49924440915A57B69391A59192A095999E959A9E979E
9A94989C969A9B95999A95999E999D9B969C9C979D9893999C979E9E99A09C979E9D989F
9F9AA19F99A399969F9C99A2A09DA4B6B1B7918A912923272C26282E2528180F129F9395
FCECEDF3DADDFBDDDDFDD7D6B98D8C7B4B47B2817CEDBEB8BD908A704840542F26856860
F6E5DEF3EAE5F0EAEAD3CFCE8F8B8A716D6A625D5A76716D9B948ED3CCC6EFEAE6ECE7E3
EAE5E2ECE8E5ECE7E4ECE7E4F0E8E6F4E4E5F8DEDFFFDED9FFE2D286623EBD9C59F3D678
E6CF5BE5D059BDA83F715A00796109846F14E1D36AEBE378CBC766797B28ABB1759CA27C
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF00BEBDB84D453A9E887D895A54843E3E9C4244AC4548
AC4445B14A4DA44448983B43963C459C424B8B32387B22267C26297A2427852A2F792326
A15154DA8B90B8696E8732398E2A34BA4B54C1484FC3484DBE4C4CA849459E5751BE8D86
A68782A48F8C8775736052515143427668679687849F908D9D8F8C9C8E8B9E908D9F918E
A398949E938F9C918D9A8F8B9B928D9A918C9C918D9A8F8B9D928E9C918D9E908FA19191
A5908FAD898DC1888FDA8A95BE525FC84A56D14A51CD4849CE574F94341CA15D2EFFCF8C
EFCC70EACF64EFD868F3DC6AF1D769DDBE54D8B551BE9335A2701B925709924C0799490E
AB4F20B34B24C55233D0523CD54D41DA4C48D74649DB484ED9464ED94650DA444FDA474F
DA474FD6474BD44C50C84E4DBF5754A4534F97605DB59191A69294A095999B95999F989F
9C959C9C959C9C979D9C979D9F9AA09B989F99969D99969D9F99A39D97A19A979E9B989F
9D9AA3A09DA69C99A29C99A0A7A2A9B5AEB5857F81292023342B2E32272B1C1012A19194
FAE6E8F8DBDDF8CFCDA97874905D59F3BEB8E1AEAAA3746E784D46A17A73CFB1A7F2DBD3
FBECE7E5DBD97A72706F676598938F9A959189848177726F46413E56514EA8A09EEBE6E3
E8E3E0CDC8C4D8D5D0E5E2DDE8E3E0EDE3E2F5E1E2FADEDBFFE1D6795837B99A59EDD374
E5D059EDDD63A0912A625400938518D3C751E6DE61E4DF67D7D26A7F7F29AAAF6F969A75
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF00F0F1EC89867D655B516A4F467A4B45914D4C974645
9B403F9838399F3C3F98353A98333BBE565FA83F46A4393F972A3094272DA6373EA83B41
9D363AA0404286272DD26E76A33840B13C44C64951C6474EBD494CAC48489F5451BD8884
A5827E9F8A85A3918F9A8C8B7668674F41405446457F716E998B88A19390A193909F918E
9F9490A196929E938F9B928D9B928D988F8A9E938F9B908C9D928E9C918D9E908FA89696
AB9192B38A8EC88992D57F8AB54551CC4A56D2474ED3484BCF504AB34433923718E29A68
F5BD73F6CA71F3D06AF5D769EED465ECD563F3DC6CF3D96AEFD368E5C45DD4A94AC49138
B172259F510FAA4C18C0522DD1533CD54B40D54544D84649DC464FD9434ED63F48DE4750
DD464DD8454BD24649CA4C4DBB524FA4534F955E5BB39190A69294A2979B9D979BA39EA4
A099A0A19AA19F9AA19E99A09D9AA19C99A09D9AA199969DA09AA49C96A09C99A29F9CA3
A19EA79F9CA39D9AA1A6A1A7A59EA5B5AFB3746B6E261D1E342A2B332729231314B7A4A6
FFEAECE3C5C58357545D2A26AA756FD09B95C28D89DBA8A4F2C3BDF5CCC6F7D9D1FBE4DC
FEF1EBB6ACAA1B110F887E7CF7F0EAF3ECE6F4ECE9EFEAE7DFDAD7938A8B3F3637B0A8A6
C1B9B78A858187827E8E8B8686827FB8B0AEFAE7E9F6DEDEFEE2D77C5D40B7975AF1D67B
E4D15BEBE062877B0B887E0BDBD251DCD64CDCD94EE7E463DAD86B81812BA6AB6B91966E
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF00EEEDE9C6C3BC958B8277635A744F497E4943
914E489E4D4A9D42419C35389D3035AE3B42B13A40BC434ABD4149BD4048C2434EC2444F
C0474EC24D53B13D46C14D569C242DB2353DC94550CA4852C1484FB34A4E9D4C4BC08483
A9817F9E86829E8F8A9B908C9E938F9388866C615F4B3D3C594B4A857776988D899F9490
9E938D9F948E9D948D9B928B9D948D99928A9D948F9B928D9C938E9E938F9E908FA59393
AF9294B18489D28F98C86E78BA4852D04D55D1464DD6474BD44A48D04C47B3392EA33420
AC4A27C87241E89E61FABC73FDC975FCD173F7D46EF2D466EDD460EBD55DEED85EF0D65D
F0CF5EF3C361E19F53A04611CA5836D44F3ED54642DC474BDA474FD9464ED64049DA444D
DA454BD54449D4494EC94D4DBD55529F504B96635FB29391A59393A4999DA09A9EA29BA2
9E979E9F989F9E999F9D9BA09D9AA19C99A09D9AA39A97A09F9CA79E9BA4A09AA4A39DA7
A49FA6A49FA6A39EA5A19CA2A59EA5B1ABAF645B5E2B21203125252C1E1D301E1EDCC8C7
FFEDEAC5A9A6AD8784DAAEABE9BCB9C99894AE7473B478778E57547948438B6960AF968F
FAEBE4E6DDD8BAAFABDFD4D0D4C9C3BFB6AFC8BFB8E0D9D3FFF7F4D0C8C62016158F8584
A39998CCC2C1877F7DA49F9CCAC4C4CDC3C4F7E4E8F5DDDDFFE3DB917357AD8E57F2D883
E1CF5FDFD552A69E19CEC73BD6D03AD8D53CDCDA47E2E25CDEDE707D7F2B9FA5678A906A
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F8F3E3DCD4B6A59E8D706A
815650905652944A47A14B4AAD4B4CAB4145AB383DB43B40BD4046BF3D45C8444FC9434E
CA4651CD4B55C4454EBE3F48B6343EC33F4ACB434FCB4752C64951B94B4E9F4545B67271
B285829E827EA08F88978C869A8F8B9C918DA095938D81816759584C413F5F5450847975
9D928E9F948EA196909D948D9C938C9A938B9D948F9B928D9C938EA196929D8F8E978281
AF8F92B6858BD68E99BE616BC04C55CF4C52D4474DD44348D44547D04443D54B49C94540
B73F2FA63A209A39169D491AB46D2FD2944BE7B35FF4C96BF3D36CEAD35FE3D550E4D74B
EBD953F1D45CFFD175AC6621B94F27D1533DD84B42D94748DA474DD7444CD7414AD7414A
D9444AD7464BCF4449CA4E50BD5755984A469C6B67B39593A39394A39A9DA19AA1A49DA4
A099A0A19AA1A09BA1A09EA39E9BA29D9AA39C99A29C99A49D9AA59A97A29B95A198929C
948E988D888F8681887873796D676B7C767A4C43462D21213626262C1817503836F2D8D7
FBE2DEFADDD9EECCCABA9795A27A7AE5B7B7E2AAABCB8F8FCD9391C49490C1A0997B6760
F0E5DFD6CFC9968B87887D796C635C685F585049434E4741857D7AA59D9A857B7AC7BDBC
948A89A89E9DA9A19FD3CDCDE8E2E4F0E5E9F0DFE5F2DCDEFFE5DEB3947F937344F4D88E
E0CD66DCD153C0B92DE1DB45D0CC2DD5D333DEDD45E0E05AE2E1776D711D8E94568C926C
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6EBE7
D2C0BCA88C8887605B834E4A96524FA45551AC5150AE4647B24143B83F44BB3C43C03C47
C6404BC9434EC8404CCF4753CF4753CD454FD04751CD4750CA4850C24E51A54143AC5E5C
BC8783A07F7A98847D9A8D87998E8A9B908C9A8F8D9D9290A196948D82805F545249403B
665B578B807C9E938DA0958F9C938C9E958E9E958E9D948D9D948DA0958FA3918FA3898A
B28B90BF868DD88B95B7565FC34E56CD4A50D3484DD44549D64548D64749CF4543D04C47
C94F44C45542B74F36A14321983F138C3A0892470EA06324B08139E2C164EBD75CE3D649
E8D94CE9D250FFDF74C98E40A54714D25A3FD34E3FD44642D54344D9464CD8424BD9434C
DA474FD8474ED1464BCA4E50BD5755994B499D6C68B294929F8F909F9699989198958E96
928B928C858C878289817C837C768077717B6E6B766864725F5B6A5D59685A54624F4955
47444D423F464B464D4A454B4F4A4E5C565A382D313626293B2225321414826361E8C6C4
C2A09E916F6D694A488A6A6BEBC7C7F1C7C8EBB9B8D9A3A1AD7C78C29B96FFE8E4F1E4DE
E8E0DD44413C3E36339D9592B0ABA5BCB7B1AFAAA68D8884615C5967625FBCB4B1F6EEEB
A199967F7A77847F7C6B6766747071F3EAEDF0E1E6F2DEE0FDE5E1D9BCAC795531E8C689
EED47DDECE5DC2B834DFD947C6C326D5D235DCDB43E0E05AE4E57F5C61117D85498E966F
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF5F3E7D5D1BDA19D966F6A824F4B8E4F4A954A45A44E4DA94B4BAB4447992C31
A53039B93D48BD3946CB434FCB434DCB434DD04751CC444ECC464DC74C51B94C4F9F4746
BD7D7BAB807A957A7397867F978A849B908C9A8F8D988D8B9C918FA398969F9492857A78
594E4A473C38655754897E789F9490A39A93A198919D948D9C938C9F928CA69291A98B8D
B5888DC5868ED7818CB74F5AC54C55CF4950D3484FD3444AD5464AD14747C94843C85248
C05744A5472B8C37108939088E41098841037F3B00753C005327009E7F25F1DF63E3D747
E6DA46E7D54BF3DA64ECBD619A480EC35733D2513CD2483ED64645D64447D84349DA444D
D6434BD6474DCF474BC84D4FB85454974C49A27270947877685A5A5953575750574E474E
474047443D4446414746414848434A4A444E4D475354505E595563635F6D66606E6A6470
74717A7C7980837E858B868CA29DA1928C8E352A2E3C2C2F41282C3214167858597F605D
5D3B397F5D5BCCAEACFFE2E0D2AFAD956C6AEEBCBBBF8E8A8B5F5C805F5AFBE8E4F9F0EB
E3DEDA34312C615C58D9D4D0EDE8E4F0EDE8F0EBE8EFEAE7EBE6E3807B787E7975F6F1ED
F8F3EFF1ECE8FAF6F38A8685878384F4EEF0ECE1E5EFDFE2F6E2E1F8DDD489654DB28D63
F7D895E3CB71C0B03FDCD350CFCA3BD6D441DFDD4CDFDF5BE5E8815F66187880448D956E
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F0E5E1CDBCB599807B75544D7E534C895851834945C58180
AB565B99353DAF3945B93A45BF3B46C43E47CA424CCC444ECE474ECC4B50C24E51AB4747
AC5E5CBF85819C7771937C7693817D958784968B87988D89998E8A998E8A9D928EA09591
9D928E847975564B47423733685D5B918682A196929F94909D928EA39592A4908FAD8D90
B6838ACE8691D47684B84856CA4C57D34B55D4474FD4454BD14649CD4D4AC35348B65741
7B360F7B470EAB8032C29D42CBA844C7A43CBD9D36AF922C88700E7B6900DDD14BE8DE4B
E4DA44E2D646ECD958FDD66DAB6621AE4D22D0573CD64E40D54743D84647D84349D9444A
D7444AD34448D1494DC1494AB95A5889443F9F73709A82807C7070756F737C757C7D787E
827B828781858B868A8D888E918A919792989A959C9F99A39C96A09C96A09D97A19E99A0
A29DA49C979D9D969D979195ABA5A9837D7F31282B362A2C36272A322020CFBBBAD7C2BF
DEC5C0FCE0DCFFE6E2FFE3DFE3B7B4C49490EBB8B5E6B6B2A47F79C8ACA8F9E7E3F0E5E1
FEF7EFC3BFB65750483F383257504A97928CD8D0CDCCC7C39B96933A35326A6762E9E6E1
E1DCD6E1DCD6D7D2CEB0ADA8D6D5D1EDECEAE9E3E5EBE0E4EFDFE2FCE4E4CBA8A26A4431
D2AC85EDCD90CAB15DE6D770DCD35ED3CE4EDAD650DEDF5FE6E982666E1B777F43848C65
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9F4F0DBD2CBB1A29B8E7A71644942C7A29C
FCC6C6B06569B15057BE4F56BB434CB93C44BE3C44C13B44C63F46C9464CC74A4EBE4D4F
A14343BA706DB47F7B997672937A76907E7A938582928783988D89998E8A9C8E8B9C8E8B
9C918DA59A969F94927F7472584D4B473C3A6C615D908581A09591A49693A28D8CB08D91
BA828BD98B98D26C7ABD4755CA4653D24651D6464FD2454BCE4849C64F49C25E4F7D3213
8F6028E3C676F0DD74E9DE62E9DC59EBDF59EEE15EEEE161EADB64D7C94FE2D552E7DA4E
E4D74AE6D94FE9D656FFDE73D99F55984211CC593CD34E3FD84A46D34343D84347DA454B
D8454BD7484CCF484CC34D4DB055528B4A44A57E79AB9894A298979D979999949A9E999F
9E989CA29CA09D979B9C969AA09A9E9C959CA19CA29E999F9C979D9B969C9C979D9B969C
989399959094979195979193AFA9AB635D5F292021362C2D271D1E4E4242F4E4E4FEE9E6
FFE6E2FADBD6E0BDB7D8AFA9EAB9B4D29F9BC08D89996C678E6D66FBE4DEF4E5E0F1E8E3
C7C0B8C9C2BACFC8C298918B5E5751615A5499908B81787349413E817976E1DCD677726C
3D393089857C4A453F9A9792EBEAE5E8E9E4E5E3E4E8E2E4EBE0E4F2DFE3FDE0E4A68580
67422FBA9873D0B27CD8C47D998A35979028D9D55AE1E167E4E7806C741F7A8445838B64
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDE8E4BBB2AD93827B
B396908E5E5A8A4645A65051B75054C25157C44B52BF4047BA373FC44149C34247C84D50
B44647A94B4BC17774B47F7B9A77738F777392807C8E817B8E837D938882988D89998E8A
998E8A9B908CA196949F94929E94927E74725D52504D42406D6260908080A38A8DB28B90
BD7F8ADE8A99CA5E6EC54858D24C57D2464FD4444DD3484DCC4A4AC5524BB45849672502
D4B066F0DD76E6DB5BE2DC4AE1DB45E5E048E4DD47E8DD4FE8DA55ECDA5CE9D55AE9D55C
EAD65DE7D25BECD261F7D571FCCB7F9E5522BA4E31D25043D54A47D64548D84349DC474D
D74548D34748D04B4CC14F4EA8514A884C44AB8884A3918F9E95969F9B9C95909699949A
9994989D979B97919598929699929999949A9D989E96919799949A989397999498999498
948F93969195958F939B9597ACA6A84842422C2324352B2C211515827272FBE7E6F8DCD9
D2AAA8AF827DCB9C96E2B1AAE9B4AE996662B4857F956C66694C44F5E1DAF4E9E5E8E0DD
494440423D3956514D51494659524C5F56516D625C968983C4B7B1DDD2CCF9F0E7C1B9AE
8A81788780763A352FC1BEB9F1F0ECE6E6E4E4E4E4E5E3E4E8E4E5E6DDDEEEDEE1F9E0E3
A487837E615394765C6149233625006E6218E2DB71E0DD6ADEE37C6B731E7682427A855B
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F0EC
DACDC7B097928A615F894F4E8D4344A1484AAF4D4EBB4E51C24D53C1464BC2434ABE4044
BD4547B14545AE5352BF7876AE7B779976709279748E7B758C7D788D827C928783958A86
978C889A8F8B9C918D9A908E9F9593A29896A095938479775F5452554545775D60A1767D
BE7C88E28A98C55565C64655D04854D2454ED3434CCF4449CF4D4DC3524AAD544475350F
ECC978EBDB6AE4DD51E2DF44E3E13FE3DF3EE5DC41E3D445EFD658F6D466F3C965F3C669
F7C971F7C971F8CA74FAC778FFD394CB7E52A2351ECE4E45D54B49D34247DB484EDB484E
D34245D34949CB4B4CC45655A4514B8A514AB0918EA191919F96979C979B97929699949A
9B969A9994989892969892969691979893999A959B9792989792969A9599979296969195
969195969195958F91A7A1A3A09A9A3930312E2425362A2A221414B4A2A2FFEDEDBB9998
5A2A26BB847FEAB1AAD09790CE9490E6B1ADFCCBC788615CAB9089FAE9E2FCF3EECCC7C3
2C2825B5B1AED1CCC9BEB6B3524A47261D186356505E514B56494170635BD7CDC3BBB3A8
C8BFB6C9C2BA827D799D9C98F1F0EEE6E6E4E4E4E4E4E4E4E4E4E2E4E0E1E4D9DDF6E3E9
FFE7EBA98D8A5C4034381E07352300776C2EE3DB78DEDC6DDEE37D717B2471803F758257
F7FBED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5EBDBDBC9AFAEA07A77885552834240924241A54748B54B4FC0494DC6494F
C74A50C0474CAE4144A94D4EBC7573B8837D99746C90756E8C79738C7F798D827E8E8580
918883958C87988F8A988F8A9D948F99918E9E9492A096959C92918A7A7B785B606F414B
995260E38796C55062CB4858D24855D44750D1414AD0454ACF494AC8514BB75749742F08
E4BD70EBD969E0D74CE3DE44E3DF40E4DB3EE6D843EFD655F2C663CA8F43B36729B55F2C
BE6638C86F43D98354E18F60FCAD86FDA486AD392ACB4743D54A4DD7484ED5424AD9464E
D54449CE464ACA4C4FBD53539F4F4E945C5BB09091A191929D92969A94989A94989A9498
9B969A9A95999C979B9893979893999A959B979298989399959094948F93959094999498
969293959192979394AAA4A687818333282C36272A382829342123E3CECDFFE9E8E5C2BE
C08F8BD19692BD7E79CC8C8AD19191C58B8A9A64628B625EF6DDD8F4E7DFF6EFE9E7E4DF
6A65615D5854978F8C9B9390322A27251B19A09593DBD0CCD2C7C1D2C9C2E4DBD4736C64
221B155D5854807C79BBBAB8EDECEAE5E5E3E5E5E5E4E4E4E3E3E3E9E5E6ECE1E5EFDFE2
FEE8EB9C837F543A2D442C123A2800837838DED876E1E171DDE47D6F7C2469793874835A
F7FBEC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBECE9E1C8C4B6938F8E5D5981403E91403F9D3A3DAC3F44
C14952C74F58C35057B64F52A65252B4736FA7787295726C9175718C77728B7C778E817B
8C817B8D827C8E857E938A8398918B9A938D9B918F988E8D9E9493A59596A78A8EA6777F
AA626ED87A8ABE495BD14C5DD24857D34551D64650D0434BD1494BC64B46C55B4E792908
BD8A48F6DA77E3D453E7DF4CE6DF46E5DC43E8DA46FCE365BB8C32833F00AA4F22AA4121
A6361EA6331EA0301A9E311AA03A24BA4F3FA52921C74140D64B4ED5464CD6454CD8474E
D4454BD0494FC24A4CBA5356964A4C9C686AAF91939F8F929D92969B95999D979BA09A9E
999498948F939C979B9893979A959B9B969C969197999498989397938E92969195989397
959192979394979394ADA9AA6A64662A20213D2D302B181A624E50F6DEDEF6D6D7DBB3B1
CD9D99D19A97E4A8A7DFA2A1844647AC7271B37D7D633A38E4CCC8F6E9E3EDE5E2EFEAE6
DFDAD688807D5C534E4C433E7C736E7B726D453A384A403E978E89E4DBD4958E88716A64
514C49696461D3CFCEE7E6E4E5E5E3E5E5E3E4E4E4E4E4E4E4E4E4E8E4E5EBE1E2EFDFE0
FCE8E98F7773503627472F13382700887D3BDFD977DBDD6FDEE4806D79255261267D8B67
F8FCEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEDBD7C4A5A29A6D6AA665639F4D4F
96353C9A303AB0424BB44C53B3595B9C5251975F5EA579789B75749778758D74708F7A75
8D7C75897C768B807A8C837E8E8781968F8998908D9A908E9A908EA09090A98C8EB5868C
C8808BDC7C8AC0495CCE495AD14756D24450D4444ED3464ECF4449CA4848CA534BA34029
8A4315EABC6FF1D769E2D650E4DC49E5DE47E2D843FCE966C19D3C783F00AF5D2DC05C3A
C4553AC74E3BCC4E3FCA4C40BC4036BA3933CA4340D24647D4484BD6474DD3444AD4454B
D1464BCA494DC14E51B355568E484AA57477B19395A090939E93999D939B9A939A9C959C
9C969A9993979B949B9B949B9A94989A9498999498969195948E92948E90969092999395
959094948F93989697A7A5A6453F3F2D23243B2B2E271416978385E9CFD28F6B6F7E5657
D0A4A3D4A6A6D3A3A3D2A09FE3ADABFFCDCBE7B5B4B99191F2DAD8F8EAE9E5DDDA645F5B
7A726F978E89A19690BEB1A9D7CDC4E8DDD7D6CBC78C82804A413CA7A09AA29994D8D1CB
E7E2DFA39E9B918D8CEAE8E9E7E7E7E6E6E6E3E3E3E4E4E4E5E4E2E7E3E2EBE1E2F0E0E1
F7E3E2866D68523829452D113425008C8340DEDA79DCDF74DEE586606C204F5B2BBCC6AB
FBFEF500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F4AD9893A6817BB27D79
D48E909D4B4F973C4393383D9B46497B3132B87D7FE9B9B9A6787A926667A07878967472
8F726E8C74708E7B778B7C778A7F798D847F918883938987988D8B9E8F8CA78D8CB4878A
CC8690D67886BC495ACB4B5ACF4755D24450D1444DD2454DD1444ACD4547CE4C4AC65547
8A2F149A5723F2C572F2D669E9D757E6DB4EE2D749EDDF5AF6DC6EB68D358C4D08954510
B15127BE5333C7553BCA533FCA4F40CD4F43D14E46D04B46D44A48D04646D24649D04548
CE474BC74B4DBE5154AC56578A4C4DAB8383AB92959F90959E93999C959C9D969D9C959C
9A939A9B949B9A939A9C959C9C969A9892969893979691959690929690929A9194958F91
989296959192A19FA09C9B99353130302826372B2B261617C6B6B7D1BBBE6F51538D6B6C
BA9897BE9B99E7BFBFDCB0AFB585819665619A6D6ADDB7B6FBE3E1F5E7E6EDE3E1726A68
352D2A1A100E1F1410312620483D37524743685E5C7E74728D8680A099936D645F5F5852
7B76727E7A77989795F2F0F1E4E4E4E4E4E4E4E4E4E4E4E4E5E4E2E6E2E1ECE2E3F1E3E3
F2DDDC7B625B4A301F432C0D35270089823CE2DF7EDDE077D8E1884D58147A845FF1F8E6
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C1BAB277695E786153
DAB5ACD09F98D29695A36162985455642424976161FFD4D5E6B4B78A565A8D5558AA7376
A0727298706E9273708F76718F7C768E7F7A90837D9186829287839D8E8BA58B8AB08688
CA8C91CF7982B74B58C94C5ACE4A57CF4650D1444DD54850D1444AD2454BCD4547CE4F49
C2504585250CA35B29F0BC73FBD776F2D963E7D857E6DA54E9DA59F6E16ADDBC55A97B25
90560C8741039A4A17A2491FB0502ABD5635C25538C45039CD503ECF4D40CF4844D04848
CF4A4DC44C4EBA5658A05252885655AC8E8EA390949F949A9A939A9A939B9D969E9F98A0
99929A9891989F959D9F959D9D969D999299999397969094958F91979191989292958F8F
988F92958C8FAEA8AA8783822E2828312C29342C2A2D2522DDD5D2F1E7E5E9DBDAEAD8D8
F3DEDDFFE5E2D5B2AE99706CC59C96BC938D522B26B79593FDE8E5F7E8E5E1D6D4D5CBCA
D3CDCD8F89893D393A272324514849968D8E9E9493756B698B827D8C837CC3BAB57F7872
A9A4A055514E8C8B89F2F1EFE4E4E2E5E5E3E4E4E4E4E4E4E4E4E4E6E2E3EBE1E2F0E2E2
ECD7D46F564F482F1B412A0A362900979147E1DF7ADEE47AD0DA84555F23C7CDB300FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DDDED8716F624E4737
766656C8B1A1F6D1C8D1A49EC18E8AB17B79835150BA8889F3BFC3DAA1A7884B507E4146
8F57589A68679E70709C7472937471927672947D77917E7890817A9885819C8281A98182
C2878BCA7B81B54F5AC6505CC84954CF4751D1454ED2454DD2454BD2454BD4474DCF4749
CF4D4DC5504796321B94421ADB9B5BFACA76F7D470ECD263E6D259EBD85FF0DB68F4D96E
ECCA68D4AB51B58533A1691E9554108D460694430B973C0DAF4722C65338CE5041CE4E45
C64947C25050B35758914D4E936B6BAA95949B8F939C959C99949A99949B9C959D9D969E
9891999B949B9F959D9B949B9C959C9992999993979D979B948E90979193979193948E90
958C8F999091B3AAAB635D5D302B28332E2B1E19155C5753F0EDE8EBE8E3EDE5E3F0E4E4
F4E4E4F9E1DFD3ADACE2B6B3E3B8B2A87F799A756FF5D6D1FDE6E0FFEFE8A697944C4240
5B5555716D6E4846492523262924284E484A9C9394D6CCCBF3E9E7ADA49FA09694CEC6C3
E8E3DF85817ECCCBC9ECEBE9E5E5E3E5E5E3E5E5E5E5E5E5E4E4E4E7E3E4E8DEDFF5E5E5
E4CFCC664E42452C16422E093B3100A5A251DFE277DFE67EC1C97C969E6DF6FAE900FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F8F3B1B2AA636456
4D4A37887D69CEB9A8CDB0A2B38D84D8ADA7BC8F8CA77777AE7C7FDBA7ABC89196B37A80
B57D80A86D718E53599C6467A26F6EA0736E9C776F95776F927972967F79997C78A37B7B
BA8187C3787FB4535EC2505AD25660CB4850D04950D1464DD2474ED4474FD2454DD1464B
D4494ED24D4ECE514DA83729922C13B55D37E49D67FBC27DFACD78F1CF6DEED368EDD666
EBD661F4DF6AF4DD69EFD866E5C95CD9B851D1A94ADDA656B4692F9F4217C9573CCB5241
C64F47BA514EAB5A57814948A0817FA69898988F9298939999949A9B969C99949A979298
9992999A94989A94989A9498999299948F9596919799949A969195969195948F93918D8E
948E90A09A9AA79E9F3C3432332B29342C2A1813109D9895F7F4EFE9E6E1EBE3E1F0E2E2
F5E3E3F3D7D6A97D7EDBA8A7D19B9BD9A9A7FED7D2F9DBD3E0C5BCA79088B7A69FC7BCBA
9F99998C8889716C704E494D3A34382822241B1517473E3F7D75735A5250534B498D8583
CEC9C66B6764E9E8E6E8E7E5E4E4E2E4E6E3E4E4E4E3E3E3E5E3E4E6E0E2E8DEDFF9E9E9
D8C4BD5D463848321A3D2C014B4200C8C86ED9DF73E2EA87C6CF90E1E7C5FDFFF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D5D6CE
7E80725C59487165557968585D4539D0B2A895706ACCA39FC19594BE9293D7A9ABDCABAE
EDBBBCC08C8EAC71779D62668751517E4D498D625B9D7B71987A70987C71987770A07773
B67B7DBE7378A94A52C0525BC44F57C94C52CD4C51D04B50D14A50D0494FD1484FD3484F
D5484ED64B50D34B4FD55053C34745A12F24922E17AC5732D48B58EFB26FFAC776F8CF73
F4D16BF2D668EFD662EDD863EFDC66EFDA67F4D86DFFDC7FEFB66F914511C05936C6563E
C35548B5574F9F5854885856A98F8E9E94959B959996919799949A9A959B99949A9D989E
9B949B9B95999891989C959C9A959B979298969197959096959097989399938E94908B8F
8A86879E9A998C86862B2321372F2D30282626211ED2CECBF1EDEAE8E4E1EDE3E4EFDFE2
F7E1E4EFCFD2A17074D1999CAF7375BF8786F9CEC8B5948BC5A8A0705951B8A7A0FCF2F0
F0EAEAEDEBECECEAEBE5E1E2D5D1D2C7C3C4A39FA08C8889888284ACA6A6C0BABA443E3E
6864636C6865EEEDEBE7E7E5E3E5E2E3E5E2E4E4E4E5E3E4E6E2E3E7DEE1EADBDEFDEBE9
C8B2A7523B29442F123A2C00787224D9DB7AD7DE76E4ED94E1E7B7FBFEE900FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
ECEDE7BCBCB496928780786D50443888766CA78F85B89D94F2D5CDAD8F8795706AD5B0AA
FAD7D3CCA6A3916564A07473A17876A8817C86615970504582625598786BA17B70A87770
B77A77C274748D2E32A0373BBB4A4EC34F52C44C4EC6494DC7494CCA494DD04E50D34C50
D1494DD1494DD24950D14A50D0494DD14F4FC84D48AE392F952A169D3A1DB35934D68454
EBA368F9BA75FCC477FCCC77F8D071F5CF6CF3CB69F9CD74FFD38BA56630A34924BF5B41
BC5B4AAF5B5090534E946C6AAE99989F95969F999D9E989C9A94989992999790989C959D
979098928B928F8A918E8990847F86837E85807B8278737A68656E67646B625D645E5960
4341447571726C66683C36365A51522920214F4949EEEAE9E9E5E4EAE4E4EEE2E4F3DEE3
FCDFE4CAA2AA926167DBA0A4A76567A56867B786818D6860A98E85B7A69EE8DDD7EDE8E4
E7E6E4E6E6E4E6E6E4E6E6E4E8E8E6E8E8E6E9E7E8EAE8E9E6E4E5E8E6E7E9E7E89C9B99
8E8D8BDBDAD8ECECECE5E5E5E3E5E4E3E5E4E3E5E4E5E3E4E9E0E3ECDDE2EEDEE1FEEBE7
A08A7D49331C402D0C3E3300B9B85ED9DE77DCE384E6EEA5F3F6D7FBFCF400FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEE6D4D0C7A89F96A1948BB0A297D2C1B7BAA89E563E349D857B
E1CAC2E1CAC4B79B97B59996D1B5B2F3DAD6DCC3BEA58C85846C6270554A7D5D5290655C
AF7873C6827F954441913635A03C3CAF4545B34546B94747BE4A4BC24A4BC74B4DCA4C4D
CC4B4FCF4C51CC494FD14B52CE494ED24B51D55055D25052CB4E4CC04641AF3A309E311D
9A3519A24420B45D30C97944D38C4CE8A55FF3B36BF8B976FFC78EECA87B9A4121B85842
B65D4DA75D52895450A2807F96848483787C7E787C7872766D676B6861686059615A535B
4A434B4C454C4F48504A454B4B464C544F5558535A58535A5752595F5A61635E65676268
7A787B908C8D423E3F3F3939625C5C241E1E918B8BF5F1F0E6E2E1EAE4E4EEDFE2F8E1E7
F2D3D9C49BA1E9B8BCDEA6A7A366659055519E6F69C39E96D8BDB6F9E6DFF2E4E1ECE2E0
EBE3E0EBE4DEECE3DEEBE4DEE8E3DDE8E5E0E7E3E0E6E5E3E7E5E6E5E5E5ECECECDDDDDD
C7C7C5E9E9E7E5E5E5E3E3E3E3E5E4E3E5E4E5E5E5E7E3E4EADEE2ECDCDFF4E0E1F0DBD6
6E5747453013382900756E2ADDDF7CD0D770E4EB9BEDF4C0FBFEEB00FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F4EFE4DFD9D0C9C3AAA39B857C738E847A
A89F96BBB2ABD2C9C4EFE5E3FFF6F500FF0000FF0000FF00F6EDE8DBD0CABAA9A2977E79
8D6C658F625C8A514A8B463F9647429A413DA2403DA8403DA73E3BB44645B64444BF4949
C54E50C34B4DC44C4ECA4F52CB4E52C94B4ECE4D51D04F53D15152D05051CD4D4CCC4F4B
C2473FB73E33B1392B9F2C199D2D179F3319A1391CB75437C2644BDD7E68A33D2EB65145
B65F569A5550906360987C7B6C5E5E5B55575D575B5B565A5C565A5E585C6258606B6169
695F67756C717C727A7F797D8781858983878982898D868D918B8F948F93959192918D8E
ACA8A78A86852D29282824212A26232C2825D5D1CEF1EDEAE7E3E0E9E4E1EFE1E1FAE4E6
EFD1D3AC8586A97C79C1908BA5746DA4786FF9D2CBF7D6CFE3C4BFF1D8D4F4E1DDF5E2DE
F7E0DAF6DED4FAE0D3FBE1D4F6E3D5F0E2D7ECE3DAE9E4DEE9E6E1E6E5E1F1F1EFC2C2C0
9D9D9DECECECE5E5E7E4E4E6E2E4E3E4E4E4E6E4E5E9E0E3ECDDE0EEDCDCFBE6E3BBA29B
4A311D402C07483E01C5C370D9E078DDE786EBF3B7F8FDDDFBFDF200FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEE6D7D7CF
E6E6DEFAF9F400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F2
F1E0D9D8C1B9BB9A93A1766F945F598A4D4887403C90413C97423F9D423F9D3B38A53F3D
AE4444B14543B64645BC4A4ABD494AC24B4DC74F50C84D4FCC5052CA4C4FCE4D51CF4C51
CE4C4ED14C4FD14C4DD04B4CCD4B4BC44441BB3E3CB13734A7342FA2322EB64944B95852
AE5D5A894D4C977170A58F9194888A928C8E918C90979296989296958F93988F949E959A
A1989D9B92979A91969B95979C9698969092958F939A9496958F91948E8E928E8D999594
ABA7A458545124201D312D2A16120F64605DF1F0ECEAE6E3E9E4E1EBE1E0F0E0E0F8E0E0
F8D8D9E1B9B9DCACA8CF9E97DDB1A8FDD5CDD5B0AAC5A49F674543B29391FFE2E2FBD9D7
F8CBC6E7B2AAD29C90CF9E8FE3BCADF5D9CBF6E4D8F0E6DCEAE6DBE7E4DDE8E7E2DEDFDA
DDDDDBE6E6E4E4E4E4E4E4E4E3E5E4E4E4E4E7E1E3E9DFE0EBDBDBF3E0DCF7E0D87B6454
432B113929008D8638E2E385D6DE79E6EF9CF1F6CDFBFDEF00FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAECE9E9D6D2CAB1ADA78681926963814F48874B438D443E923F3B
9C413EA13F3CA43E3AA63D3AAD413FB24443BC4C4BBF4D4DBE4C4CC45051C34C4EC95153
CA4F51C94D4FCF4E53CF4E53D14E54D04D52CE4D52CF5155CC4F53C44D4FC15457B95D5E
9A5351814F4EA587879D8B8B958B8C938D8F928C8E948E90948E90938D8F938D8F958F91
988F92948B8E948E90958F91948E90928E8D918B8D948E90918B8D918B8B8F8989A29D9A
948F8C3934312C2724322D2A181413A5A1A0F5F1F0E8E2E2EBE3E1EFE1E1F6E2E3F5DBDA
D5B3B2AF8382B7817F743D3AC59490C59895AC8482D2ACABA6807FE1BABBFFE1E2E5AFAF
A052509A413D91383087372C8B4D409F7162CAAD9DE9D8C8EBE2D1E6E3D4E9E7DBE8E8DE
E7E8E0E4E5DFE5E6E1E3E3E1E3E5E4E4E2E3E8DFE0EBDDDCEFDED7FEEADFC2AD9C432E13
3A2800594E10CFCA6CDBDC76DDE38BF1F7B9FAFCE400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF8F3F5E6E1DEC7C1C6A59EA97C77915A57
8645419046438B3E3896433D9B433F9D423DA44541A4423FA94341B04646B44846B94948
BE4A4BC44D4FCA4F54CB4E54CB4C53CB4C55CD4E57CD5058CA4E56C45158BC575BB15F61
824646956D6DA58D8D948686948B8C8F898B908A8C908A8C908A8C8F898B938D8D928C8C
958C8F91888B948B8E938D8F918B8B908C8B8E888A8C86868E8888908B888F8A87A6A19E
615C592B2623362E2C251D1B3B3535DFD9D9EFE9E9EBE1E0EFE1E1F4E2E2F8E2E4BCA09F
C19E9CECC0BFE7B4B3915E5DA173737D5354AD8687D3ABACDDAFB1FFD4D6F2B6B88B4142
A74949C35F5DC36961B2655B905648673E2C604530615339797258BDBCA0EFF1D9E8EBD6
E6EBD7E4E8D9E3E7D9E3E6DBE3E4DCE7E4DDEADFD9EDDCD2F3E2D0F7E6CC826F4F3A2900
3A2F00A49F4DE5E47ADCDE79E9EFA9F6FBD2FBFDEF00FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF3F2EFDBDA
D9BDBAB695909E756F8B5C54814B4184453C8A443C954641A04844A24540A6433EA83F3C
AC3E3DB64645B94649B84349BB444AC04851C34B55C24D56C04E56BE565DB55F62975354
805252A4868698888993898A92898C8E888A908A8C908A8C8F868991888B91888B948B8E
938A8D90878A92878B94898D928C8E8C86888C86868D8787908A8A8E8986A199978E8683
372F2D3129273B32331C1314756C6FF6EDEEEEE2E4F1DEE0F4DEE0FAE0E3F9DFE2DFC1C3
CBA9A8C29C9B9B7270865E5EC8A8A9E9CBCDFFDFE6DCB1B875373CDE8F92C1686A9C3E3E
CC6F6ABF6C6495574C885E4E9F8672A99D85A09B7D858561B2B48CD7DEB2C4CDA2C6D1A7
DBE7C1DFEAC8E3ECCFE6EBD4E4E7D2E7E5D0EBDECBEEDEC4FBEBC7C6B88B433300403600
797418D5D76AD8DF6FE5EC8FF1F5C3FAFDE8FBFCF400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FCEDE8E8D4CDCAADA5AB867E986B658A554F8C4F4A86413C8E403C984541
9C4241A04240A03C3CA63F40A63C40A93C41AB3E44AD4248B34C50AB51539B53547C4644
96736F9D8883938582938B899088868E89868E88888E88888F868791888B8F86898E8588
90878A91888B93888C8F8488948B8E8B85878D87878C86868C878496918EA29A98564E4C
2B2321372E2F32292A22191CBDB7B9F7ECF0F2E3E6F1DDDFA88B8FAE8F94E9CACFFDDDE0
EFCBCBD3B0AE967472EDCFCDFFEAEAFAE4E7FFE8EFBE939C7C333AB2565BA94245C35D5B
C77067924E439F7567E8D3C2AEA8928080647879577A7B518C8C5A8C8F5663682E5F682F
6E7B45869461B7C499C1CCA4CFD0AEE1DDBAEEE0BDF7E6BAE4D59A7C7028817722A7A23E
D3D25CDDE369DDE47AEAF3A4F8FCDBFBFCF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF4F3F7E5E3E7D2CFD5B9B6B79691A07974976763
8D56538847438D423D923F3B9A413D9E403EA34142A24243A048469146415F2420875C55
A0857C9A8A7D90867A8E867B8D847B8D867E8C857F8E86838C87848F89898D87878B8585
8C838690878A91868A8E83878E85868E858692898A8A8182908B88A5A09D706866302728
33282C352A2E1A1114595357E9E4E8EDE7EBF4E8ECF0DBE294767E95747BE9C5C9EAC3C6
BD9697D2AFAD7F615F927877F3DFE0F5E2E4FFE9EFD2A7B08B4249CA6B71C65D61C76562
B5685E8F5A4CE4C9B8867B696B6650918D728E8662786B3E65591F635816766F27797931
6B753067763566783E5966315F612F756D3C9B895799854894842FACA137D4CC50D5D24D
DDE156D4DD60E3EC91ECF4BBFBFFE800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF5F2F9E4E1
EFD2CEDCB7B1C89993AD7671A0635E96524F924B478D48437C3D3669342C785046AF9387
9887759388728C866C8B856B8D876F8C86708C87748A84748A867A8D897E89847E898480
8883808C84828D83848E84838D83818A807E8D847F948B86A49B967A736D362C2A372D2C
3A3031241B1E393033D0CACCECEAEBE6E1E5EBE0E6F0DFE7F6DFE7F5D7DFB49499806063
C6A8A8E5C9C8957D7D705C5DF0E0E1F3E0E4F9E0E6FFD5DFAB5F69AF5058CB6468C86A68
A35D55A6786BB19B8D564F3DDFDAC6D7D0B671613F644F20CAB576A692499C8C3FC2BB6D
93954A6C76316D7738686E306D692A6B601E6B5911695701B1A434DAD14ECDCB38DBDE47
D6DD4FE1EA77E6EDA7F7FDD9FCFEF100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFF5F3FBE6E3EBD2CED8B9B6BB9C998A6F68AF998EE7D7C8E9DECA
C4BFA19D9B7599976E9291638E8D5F8B8A5E87845B88866086876586866A85826F858273
8A867D837F768B827D8B807A8E81788F8176988A7DA89C8E82766A392C23392C243C312D
221A17423D3ABEBAB9F1F0EEE6E5E3E5E3E4E9E3E7EDE2E8FAEDF4B09FA5826F73BBA8AA
B7A7A8AB9D9DB8ACACE3D7D9F5E6EBF5E0E7D8B9C1E2AEBAFDAFBDB05260BC5661C06467
A15B59A77A749A837B645A4E847D6B867A6256422194794AEED390DEC77B9D8A3BB8AC60
E5DE9A7B7738666024776F307C6E257A6A15968722CCC04AD6CE45C8C731D6DA3FDAE04C
DDE665E5EF8FEFF5C7FAFEEDF9FCF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3F9F5ECF7F3E7F0EFDD
D8D8BEC1C2A0B8B892AFB086ACAD81A3A4789E9D7198996F8F946C84886583866B85846F
8584727F796B8B7F719585759A88729B876EAC987D88775B3E2E143D2D1445342031220F
38301DCDC6B4FAF4E4EBE8D9E7E5D9E9E6DDECE4E1EBE3E0F0E8E6D8D0CEE5DBDAF7EDEC
ECE7E4EAE6E5F1EBEBEEE8EAEEE3E7FAE9EFD0B2BC6B3D48A86171B46070BC626EBE6B73
A569698C6663AF9C96574E45BFB7AAD2C7B35C492BA1895DECD297ECD58FA5924DB8A966
B7AB717467307F6E3682712C72600CB1A038DFD156D4CD41CCC831CECF33DBE247D8E057
E4ED82DFE6A0F9FDE200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F9FAF2F7F9ECECEDDDE3E5D0D4D8C1C0C4A9B4B79AACAF90A6AD8C99A07FA2A88CA7AB92
797961736B56AA9A83D4BCA0CCB08BAC8F638368394E38063F2A004B36094E390C3C2A00
A99D6DFEF3C5F4EBC2F0E8C4F0E9CCEFE7D0EFE7D4EFE6D5EDE5D8EDE7DBEFE8E0EAE5DF
E9E6E1E5E4E0E8E4E1E7E3E0E9E3E3EEE3E7F9E6ECAB8B96804C599F5F6DB06C79AF727A
8C6264745A59E8DDDB999490928E85867E7151452F746443D4C196F1DFAD897948918354
7362379582578D78436B540EB3A13DE0D257D0C73AC8C52CCCCC30DCE147D7E051E2EB76
D7DF94ECF1C8FBFDEF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBFEF5FAFEF0F7F9EBEAEDDADDE2CCC7CFB8B6BEA7A6AB95
71705C827B68D3C3ACBCA78A967C57A28758B7A06AB39F649D8A4F8E7C3E82702E7D6C27
C9BD73E7DB93EADD99EFE1A4F3E3AFF2E4B5F4E5BAF5E7C0F6E9C6F3E8CAF2E6CCF0E5CF
EDE4D3ECE5D5ECE5D5EAE4D4ECE6DAECE3DAF3E5E2FBE6E5D2AEB295686D8053587E5559
715554AD9E9BF7EFEDECE8E5C9C6C1B2AEA3B8AFA0AEA38DBAAC8FCBBC9BA0926FDECEAC
E6D4B0ECD7AC887034B19B46E5D460CFC63BC9C62DC9CB2CD5DB3DD9E14ED8E363DEE888
D6DDAAFBFEE900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F7F1
E8E8E0E1DED5DDD5CAB4A89894886EAEA17FCEC396DBD29BDED793DCD68AD0CA76BFB85E
BCB253BEB250B9A949AB983AAD9742BEA759C9B266D5BF76E1CC89EED89CF3DDA4F5DEAC
F6E0B7F5E1BCF7E5BFF4E6C1F3E6C4F1E6C8F0E4CCF5E6D3FFE9DBF2DCCFDCC6BBD1BDB4
DED1C8F0E9E1EAE7E2E7E6E1E9E8E3ECE9E2F3ECE4F6EEE3BEB2A4948774D4C6ACCCBD9E
E3D1AD9A86519E8936E7D567CFC33BD0CB33C6C628D2D83AD6DF48D5E15BDFEA82C7D18A
EFF4D6FCFDF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFDF4FFFCEDF7F2DEEDEACBDEDCB3D5D49ED8D898D7D78FDCD98A
DAD480DFD67BDDCF6ED1BF5BC5AF4CBAA23EAD962EA58E269F8926A089299F862CAF9541
B89E54C3AC68C9B570DDCA88E8D89AEFDEA6F1DFAFF2E1B5F5E6BFF8E8C6F9EAC9F9ECCC
F7ECD0F3E9D0EDE5D0EDE5D2EDE4D3EFE6D5F0E8D5FCF1DDD8CBB87C6D56EEDFC2E4D4B0
AA986884712CE6D470D5C848CAC334C7C62DCBCF34D8E04CD1DD55DEEC7AB7C475CBD3A4
FCFFEE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FDFDF5FEFEF4FCFDEFFDFCEAF9F9E1EFF0D1EAEAC6
E0DFB3D9D8A0D0CB87D3CB78E0D470E7DA68E8DA5DEADC59E4D651E0CF4BD4C341CAB83C
BBAA38AA982AA39125A4912A9B87289F8731AB9240BCA257BFA864CBB675DAC582E7D291
EFDB9EF3DEA7F4DEADF6DFB3F6DFB6F8E2B9F8E3B8FCE7BAF4DFB2E3D1A1FCECBBDFCE96
796421CBB760D8C956CAC23BC5C233C9CB39D8DF51D3DE5BDCED7BC3D37B9FA977F2F7E0
FBFCF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4
FCFFEEFCFFE4F1EFC6C1BF84C1BC6ACEC75FD1C851D8D04BD5CC3FDFD444E3D745EBDF4F
EBDF55ECE058ECDE59E8D95AE4D159DAC656CFB850C2AC49A9963A9E8D359F8E369D8B35
9C8736B29C50AB934DB29957C0A669C5AB6ECFB674D4BD7ADCC784E2CF8DE4D5947F702B
968638DDD070C4BD4BBFBE40CCCF4ED2DB5AD1DC62DAEA7FD1E38D829254CDD6B9FCFFF4
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FCFEF3FFFFF2EDEDD1B3B181B2AF6AC9C56CD2CE63C9C349C9C13CC8BF34CBC334
D3CB3AD9D140DDD244DED548DCD24CDFD655E1D95DE3DC68E3DC71DED973DDD777D8D274
D2C96ECFC46AC5B75FB8A853B3A250AA9844A3913B9886309787329C8D3C988C408F8639
DBD483C5C46AB3B756C6CE69CDD973CADA78C2D57BACC1746E824797A581F7FEEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00E7E6D19FA0789D9C63B9B76DCCC86DD5D26BD3D05DCCCA4F
CECB4ACCC946CAC746CDC94CC8C34BC0BF4BC5C458C0C05CBDC163C0C36CC4C577C1C276
C8C578CDCA7DD6CE83D9D186DED58ADFD689DED286DDD185D7CE83D6CE86D3CB8AD8D494
BFBE7D8487427B823E8B965288975491A16280915A697A4D798869E2EBD800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FDFDF5F5F6E8DFDFC7CFD0AEC1C296C1C289BEC17CC0C573
C5CA70C6CB6DC4C76EC9CB78CCCD81CCCD89D1D298CBCF9CC9CC9FD8DDB5E2E3C1DFE0BE
DEE0BBE4E6C1E9E6C3ECEAC4F0ECC7F1EDC7F0ECC6F3EFCAF3EFCAF2EFCCF0EDCEECEBCD
DEDFC0CACDAEC8CDAFCDD3B7D3D9BFD9E1C9E1E9D4EBF2E2F5FBF100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAFDECF1F5DCE3E7C4CCD2A6
AFB682B5BD84CFD3A0E6E9BCEFF1CAF2F6D5F7FBE2FBFEE9FAFEEFFBFEF300FF0000FF00
00FF00FDFFF2FDFFF2FEFEF2FDFEF0FDFEF0FDFDF1FDFDF1FDFDF1FDFDF1FDFDF3FDFDF3
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4FCFEF1
FAFDECF9FCEBFCFDEDFDFEF0FCFEF1FDFFF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.290056 0.97619 0.541732 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF800000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 221.938},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000gB000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`003_oooon/003o01[ooooo[000o`0@ooooo`003_oo
oolZ003o00030=WJeP3Ad/d0k>cZ07l00?l06_oooolZ003o00<0oh00O`00o`0@ooooo`003_oooolV
003o000;0?Sgl`3LfmL0/[6_07imN`0m?3P0=C@`05=BCP1gMW80YJJQ0<c<bP3YjNL0N`00o`0Joooo
obH00?l0103oP0030:0Pl0@0oh00N`00o`0@ooooo`003_oooolT003o000?0=cHe@2LVI@0IV=L03ll
=@0W91l0;BXU02`X9@0b;bX0;b`W02TV8@0X9b80;RlW04M8@P2;S8H0kNkY07T00?l06_oooolT003o
0080oh002`2P8?020?n007T00?l04?ooool000kooooo8P00o`004P3fmo80[ZfY04=0>`0R7AL08AhE
030]900l=c40@chj04Q2?P1BBdD0EDi805A?B@1=BT40=c@[028R600K6a<0GUmI0=3Ac7P00?l06_oo
oolR003o0080oh003`2P8?000`3oP0000?l0003o001f003o013ooooo000>ooooob400?l001@0h>7L
07elM`0d<BX07APB02PT6`0e<BP0@Cdd040i<`0i<Bh0@3Ld04Ln>@19@3/0CD@m0519?`19@SP0@clf
03Db:@0M7AD0?Sdi0:f/ZWL00?l06_oooolQ003o0080oh004@2P8?000`3oP0000?l0003o001e003o
013ooooo000>ooooob000?l001H0hn?Q05mNF@0X9Ah09B4H01lK4P0g<bX0@3`c03/g;P0g<2X0=2`Y
040f=013>3@0A3Tc03ld;P0o=Rd0B3lf04Y3>@1;Ac`0?3T`02PU800Z:BD0YJFSMP00o`0Jooooob00
0?l000<0oh000:0Pl02P8?004P2P8?000`3oP0000?l0003o001d003o013ooooo000>oooooal00?l0
01P0m?Cb07]jM@0U9Ad0;2TP02@P5`0b:b40ASle03/d:P17@3H0?C@]03@[9P0f;bT0?3<^03T`:@0k
<R/0BT4h04m7?012>Rl0@clc04Y8?00g=2d07ahI03`m>03Fe]Ae003o01[ooooo7`00o`020?n001D0
X23`00<0oh00003o0000o`00L`00o`0@ooooo`003_oooolG003o0003083jNP20ngX0P?Yh0080P?Yi
01`0P?]i083lNP1Vge`0L6YT02@N600X8ad0<2XT02PQ6P0a9b40B3hh03P^:00g;BD0AS`f03`b;@0f
;2H0@CLa03L]9`11=bh0DDPo04a1>00m<bX0?CH[04Q2>01<B3l0:RTT024P7018B4H0d<o?M000o`0J
oooooaL00?l02020`0000`3@D7P0X23`0:0Pl00D0:0Pl0030=1@N03oP0000?l007<00?l04?ooool0
00kooooo2`00o`00;P3ok^P0j=7;0>79a@3H`l00e<;00=G3`@3KbLL0d[fl0=Fk_03N_[l0dJZ[0<2D
U@3<VYT0biRD0;n:Q02gQGh0[gig0:1eKP2BL6L0H4Dl02LE2`0U6180<BPS02hT8P0Z81h0:AhL03P]
:`11=S80;b@P03L/:00j;b/0?S<]0556@013>380?cH]04Y0=`0f;2<0<2HM03L^9@17@3P0A3li02/X
8`0V8Ql06aLF04Q2@P3Wg]m1003o000<0>g]k@2_[jl0JVYX06EUH`1UIV40IFES06MXH`1ZJfH0SXj<
0;^k^@3Cdm40j>SV9P00o`0Jooooo`/00?l04`3oP00J0:0Pl0030?n00000o`000?l003l00?l00P3o
P0060:0Pl0@0oh009P00o`0@ooooo`003_ooool9003o000g0?ohm@3leLh0_hUo08U=@P2TL6D0ZGaf
089ME`23HUd0Y85o0:9jN02TM7@0/gUh0:EMGP2??Sd0XdY60:I7@@2S@SP0XdDi09Dm<@26>2/0NS`_
05lc9P0c5@/0:1D>03DW900c:BL0;R@R02XP7P0/8R00=2XX03L]:`0h;BT0?C8^03lf;`1CBT40CdHm
04M0=P0n=bd0<2LP02PO6011>340B44k03L_;00]9B<09A`M02LK6`0U4Q@0R7Ac0=c:aP3PdLX0i]WA
0>gSfP3hknH0ooK_0?omm@0h003o000B0>k^k02/[Z/0FEUG02DU8`0J6AL05aHB01TH4`0K6QH06a/E
00l@2P0J6aH08b@O02`^:@17BD@0I6IS08N9QP2^/:d0h^CQ8P00o`0Jooooo`T00?l03`3oP0030:0P
l0<0oh006P2P8?080?n003P00?l00P3oP00=0:0Pl0<0oh008P00o`0@ooooo`003_ooool8003o0016
083eM03U[ZT0/VUP09a9>`2@?Bd0d8]l0;f3N02HIf00SV=M09AWHP2JIf@0ZFa[0<=iN038KVd0ZD4n
0;]:A02nAcl0ada30<E=?`2mC3h0Xcl_0:]HB021@c@0@QP<02`?2@0d8Ad0=bTV03<X9P0a9R@0;R@R
02/Q7`0_9B<0>2dY03X_:`0m=2h0@STb040i<@0o>c80>CD/03L`:P0o>380>30]03H^:`0a:BL0:1hM
02dO7`0d8280:`h@040Q7P1A<bT0FC`^06eB@@1YE3d0M5m:07]YE@20KE`0RGIU095nK@2QS7/0[YR:
0;ZTUP38/ZD0eKfc0=_4_03PblH0i]??0>cJeP3ah]l0m>WU07ghMbP00?l000L0l_;`0:n_[@1GEeD0
7R0K01DF4@0O7QX081lK008071/F00`0:BHQ02<S6`0M7QH07AhH01PI4`0F5a405QTB01DG4P0F61D0
5aTF04i@C@3Fe]HQ003o01[ooooo2000o`000`20`000oh000?n0000:0?n000P0X23`0P3oP00L0:0P
l0030?n0003@D7P0oh0000l0oh0000<0P<00003o0000o`009P00o`020?n00180X23`00<0oh00003o
0000o`007`00o`0@ooooo`003_ooool7003o000Z0?ofm@3XZJ@0]Tm60;Y:?P2`ACD0W3d[0>:EQ@36
R7/0]81e09MXH02SLfl0/Waj0:e]J`3:O7X0g7il0;A8A@33CTL0`TM00=5AB@3?DDD0bU130:hn<02n
GDd0UTXl050F2P0f3PH0>AdI03LS8P0d92@0>R`[02lT8P0_9200<2DQ03@V8`0c:2@0=bhY03Pa:`0j
<bd0?STc03Ha:`0f;R/0=bl/0P0[8b40:P0[8B80<28R03DQ8`0h6ad0<PX;05DU8@1Z>B/0Jc/U07Y=
<01O>180F3D;05/e3P1K=A00EBl:05Tc3P1L=100JChL05`]4@1X=1h0IbhK06<Z6@1W;b80KSX_07=7
?P1cC4D0MUE>07iQG02=Kfd0UGIc0:F6P`2_T8d0^IZE0<BWX`3?/jl0fL2l0=g8a@3Rcl/0imGA0>gN
f`3ci>40nN_Z0?kclAP00?l001L0a/K406EVH@0S91l05aPC01DF4@0I6QD081lK024P6`0_;2L0<2dV
03@_:@0g=2d0>CT_03<c:`0V9al071dE01PI4@0E61404aD@018G4`0@5A40BTa;0=;Dd`0P003o01[o
oooo1`00o`020?n000D0X23`1`3oP0090:0Pl0030?n0002P8?00X23`01P0X23`0`3oP0070:0Pl005
0?n0002P8?00oh000?n0002P8?005@3oP00H003o00030?n0002P8?00X23`01<0X23`00<0oh00003o
0000o`007P00o`0@ooooo`003_ooool6003o000P0?oem03K[j`0]EA;0<]7>`3@Bc`0_dHe0:Po;03X
UH<0bhQh0;UoL`2[MF/0[gI_0:Y]J02MEU80]V5N0=]hL`2oCTP0bDi70<a;A@3DCdL0dDa30=1=@`2l
@3@0`U530;]KC@1]7a80@`L003lB3@0o7A/0>R0O03LS8P0e8b4203X[:01703d^:`0k;BX0<RLU02hT
8P0_9b@0<b/X02`T8@0Z8R00:B4O02TP8@0[8B80;AlO03<O8@0n8B<0>14B03T61@1U:R@0OCl`07a0
9P2AFcL0ND`N07E;6@1nDR40P5@S07I:6@1dAQD0MDDG07m:7P1_<`h0McDE08Di7`27>b@0OSDT07Xf
:@1`=b`0FRXP05@/901;9Ah0BR8P050W8`1D:bL0E2/U05L^:01C;2D0CbXR04`[901F=c80FC`f0615
?P1XC4T0KeIB07ALF01mIF40QViZ09R1O@2YU8l0]J2M0<6/Z@39];40el:o0=k9aP3Ud<d0j]OC0?3M
f@3fin80nnkX0?kekP3ooO80oood0?ool`3oo_D01000o`006P3Rh^00R8R603@e<00L7AP06Q/F01`M
600I6QD05QLB02XY900i=S40@3/e03Pc;@0b;BL0<blY03Pe;00c<2L0<C4W03@d:P0^;bL08R<M01<F
3`0G6A@05QPE01PJ6@1@DU40e]KF7`00o`0Jooooo`H00?l00P3oP0000`3@D7P0X23`0:0Pl0030:0P
l0L0oh002P2P8?000`3oP000X23`0:0Pl00F0:0Pl1<0oh003P2P8?0F0?n000@00?l00P3oP00G0:0P
l0030?n00000o`000?l001d00?l04?ooool000kooooo1P00o`00D@3ldll0XEI@0<M:?`3DACL0dTHe
0<I7=P2/?BX0iXij0<MlJ@2iM6D0Yf=F091:@02VFeD0WDQ30<1QF`3XNg@0`DQ00<i=A`3ABT@0fDm8
0=Q=AP3EBd40bd4f0<U5>@3EGDl0[T@f07<I401D2`@0BA8=04DL600l7AX0>1lK03XU800l:BD0@S0^
040a;P0l<Bl0=2TW02dS8@0d:RT0<bTX034W:00c:BX0<2@V034S8`0d7R00>Q`N04@L7@0n2`X0B0P6
07Da:02:AS<0SDdb0:]gDP2=HSH0Q5h]08YU<@2HL3d0TVXg09E/>02EIcH0W6Tj09ML<02KEc00SChM
08lo902BAc00S4Xj06La9`1J;bP0RVQN085OE`23GEX0PUUE05``;@1T>C<0ICde058/8`1D;bH0EcD/
05Th;`02050_9P0Y04dZ9P1<:BD0Cb`X04PU7`1>:B<0CbTS05</9@1@:B80DRTS05HY901P;BT0J2hZ
06ld;P1g?SL0ODTn081@A022FdX0Of=>07m[D02=PV80U8i/09fHNP2ZZI<0^k^_0<;3^`2XZJ<0CDi9
01dN6@0L7AL08B8L01dL600N7AT07ahJ02HU8@13@3/0<BhY02`W8`0`:bL0:2<O02dX8P0a;2H00P0X
8ad02P0`;BH0<c<[034`:`0S91h05aPC01DF4@0L71X06ATG051@D03Ph>0N003o01[ooooo1P00o`02
0?n000H0X23`1P3oP00T0:0Pl1<0oh0000<0X23`0?n0003oP0000P3oP0000`2P8?00oh000?n0000A
0:0Pl0l0oh006P2P8?000`3oP0000?l0003o000L003o013ooooo000>ooooo`D00?l007L0ooKc0=bP
V02WACX0ddLj0=M1<P3EA3<0ad8a0;4i:03RNfP0ji1m0<adIP2gGe<0]E]B0<ETG@3AJV<0l85j0=mT
G@3:Acl0eDa40=Q;A03JBd<0gTm70=e=A03GA3X0c3`a0=eCAP3BDTD0^TDk08`W7@1O3`H0Da<:04/F
40166A@0@A`F040O6P0k7A/0>b4P03/T8`0g8b80=R8Q03XX:00f92@0<1`M03LQ8`0i7b80?1`O03hF
5`175AH0C@l@04h40`1U4P`0T3`a09M6<`2NESd0[WIC08UK<P1hDRD0JdDH079<7@1dC1/0REl]08IJ
:`2>Fb`0R4lR09iM<`2TF3@0UdX/09E==@2:BcX0EB<J08=ME02]S8<0YHAn0;RBS`2GKV`0FC0^06<j
=P1@:B80P5]B09QfK02GMF/0TFmU08eXG`2<IEh0RV5K08MLEP26GEL0OEA>07M?A`1`B400IS/b06Di
<01K:R<0JBl[06/W901l;RX0P2dW07dZ8P1k;B00LR/I06P^5P1B9`D0G3lE06MF8P1PEAl0FU8S05aH
=@1OGTT0?Ch`010A2@0E5Q007QlI020Q6`0O81X081lK01lN6P0J6AD0>STe03Xg<P0202TV8@0@02LT
7`0U81`0<B`W02/V800/9240:bHR02`W8`0V8a`0:bPS03Dd;`0S91l06AXE01`L6P0M7A/05QHF08V9
RAh00?l06_ooool5003o0080oh00<@2P8?0B0?n000030:0Pl03oP000oh0000<0oh000`2P8?0>0?n0
00030:0Pl03oP000oh0000H0oh000P2P8?000`3oP000X23`0:0Pl00N0:0Pl0030?n00000o`000?l0
01`00?l04?ooool000kooooo1@00o`00RP3oin<0]fQQ0;i<@@3EACL0ecla0=0m;@3DAcH0`Sd/0=eT
D`3mRWP0lh5f0>QcJP3VKFD0gF1J0=QIDP3HDd`0cD@l0==6?@3HBT00edLn0=e9@@3QC4D0gDTo0=Y3
>P3G@3D0fDDi0=m@@P3NE4L0ce530;51<`299aX0Ja@:05L=101C4P`0DALC04PE4P196AL0AahM03XC
500l61X0?QXJ03`H60116AX0@ADF04LE601;4180D`d?05P71P1V1`D0NQ4=09lb:`2]@cH0ZT/g09i<
=02bKe80SUTg08QJ>01dB2D0GS@>06m56`1mDRL0KD0G07Y9801d?Q80VE/b0:QR@02DCC40UE<m07]1
<`1/?CD0/8^30;6@R@2bTH`0_YNH079:B`1K=3D0DBh/06M6@@2cTX/0[8j40:j=Q02ZR7l0]Xf70;F8
P`2WMW80YgIa0:]nN02YPGT0Xh5h09enL`2INFh0UWAZ09M/I@2WLVh0NcLd07/W9@2F>C@0Uc@^09@d
9P29=1l0P3TI06`h2@28I2X0QF`Y07QW8@1fJb/0OGM708j=K`1UI58020P001HF3P0S8Qd092<N024P
6`0W91l081dH01XG4P13@3/0:bXU020O6P0V9B007QdH02<N6010>S@09B0J02dX900[9R80:RDQ02<N
6P0Z9B40=C8]03`k=P0K71L05QHD01dM6`0H6QL0@48o0>CTi1d00?l06_ooool5003o0080oh00<`2P
8?050?n000030:0Pl03oP000oh0000h0oh000P2P8?0C0?n000<0X23`2@3oP00M0:0Pl0030?n00000
o`000?l001/00?l04?ooool000kooooo1@00o`00RP3/`kl0[4m70<Q:?P3HASL0fD4c0=@n;`3NBc/0
f4/j0<a4=03NFDX0f5970=U@B03JCdP0e4Ln0=A5?@3B@ST0eT<k0=Q4>P3F@SP0fDDk0=]4>`3OASh0
fT8g0=Y1>@3H@3D0g48f0>18>P3YDdD0i5M60=QCA03;D400[cdb08lY7@1b50`0H@`705/<201G3@X0
F18A04h<3@1@4140C@d>058@4@1B3Pl0DPP905T9301O1PP0K0P:088B4@2O9B80]3D^0<E5?02nASP0
/4Ld0:E:=@2hK5@0Z6U?0:E]E02GHDL0Pe0c08]J>P28EcH0P4h]08aF=01oA280]GIE0;=bE02ADCP0
SU=106<_8P2?I5d0b:>M0;fJU037XZ00Zh:6068i?@1V?d80CB/Z09UjM`2gV9<0/I>;0;BAR`2nUHl0
aiJB08eFD`25BTH0QTa8085@B@1kD4T0OE]B0:F:O`2TRGh0Y8Il0:b5OP2mQhD0L2`[07dW9P2N?3T0
VS</09di:P2D>R80R3`H07To3@2KLS80SG4W085`8P1nLB/0T8QC09jKNP1iN6@03Ph201LG3`0V9B00
9B@O028O6P0W91l08b0K020M6010?CP0=C@_01hM600P8A/06APC02<N6017@S`091lI02XU8@0V8Ad0
91lK02HQ7@0U81`0;2TT0450>`0S91h06AXE01/K6@0O8Ah0828O0:n_[ad00?l06_ooool5003o0003
0?n0002P8?00X23`03<0X23`3P3oP0000`2P8?00oh000?n000030?n000030:0Pl03oP000X23`01<0
oh000`2P8?0:0?n001`0X23`00<0oh00003o0000o`006`00o`0@ooooo`003_ooool4003o000A0?od
lP36Sh`0[TM00<i9@03IAcT0fT8e0=]3=@3NB3T0f4@f0=Y8>`3MBch0gT`o0=m<@P3IAC/0fTHl0=U5
>`3LACX00P3I@CH0GP3H@3D0fD4f0=Y2=`3J@3H0f3hb0=To=@3L@SH0fClc0>98?03[DdH0iE530>1A
@@3NDT<0gUQ<0=QHC@3<D4H0]Chf0:<b;02>8A`0OaDB07P@3`1d30/0L0X807@<2`1m4a<0PADE08dJ
7@2N9RL0[Rh]0<Q1?P3BA400f4]20<m6?038BS`0]dPg0:a;>P35LV00YUm?0:AQD@2KFDT0Wei<0:AV
D@2aLeh0Wei:0:UXE02SHD/0/G1L0:a]F`2IGTh0Md<f060a:@2FKFL0[hZ40:n9QP30V9X0REaS06Ll
@`1P=c/0IT920<6OW@31X9/0`9fG0<:IU@3MZjX0/WEd07La;`2DBTL0Ue9=08eDC@1X>C40Jd@m0:jA
R@2[SXH0[Xf60<>JU02OJFL0IR8Q08hj>02L?cX0W3/b09e0;`2HA2X0QShH08IA7@2QNC/0SW</08Yh
<020MC<0VI5N0:RSP`29QW<05Q@801LD3@0Y9R4202DR7@0H02HR7`0T8A`08B0K03<b;@0n?CT08B0L
01`K5`0B4@`09b@M04e9@@0O6Q@08AhG02@Q700V8ah08QlJ01hK500]:R<0ADDm028S7@0R8ah07AdK
01/M6P0G6AH0J6QV7@00o`0Jooooo`@00?l00P3oP00f0:0Pl0d0oh0000<0X23`0?n0003oP000103o
P0000`2P8?00oh000?n0000@0?n000030:0Pl03oP000X23`0080X23`2P3oP00M0:0Pl1d00?l04?oo
ool000kooooo1000o`003@3nfmL0Y5mH0;Y9@@3BB3h0fdLi0=m5>@3NA3P0fd<e0>18>`3QBC`0hDTn
0>98?03NAST00P3NAS/0O@3OAcX0gDDh0=e3=`3I?c<0fd4e0=m5>@3K@CL0fd4e0=To<`3M@cL0fClc
0=a3=@3QB3X0j5120>UA@`3XDT<0kU];0>QFB@3YFDh0jEe@0>iTF@3ZI5T0i65G0=YGD03?CTP0c4]6
0<92?`2n?S/0a4A30=UGE`3GDU<0fU1@0>5AD03SCd/0idm:0=i9@P3GBCl0bDLi0;M6=P2/BcX0b7EU
0:eVE`2KFD/0QD<e08Q6>02CDD<0YF=E09ECA@2GEDL0UEI709QJC@28D4<0/Gmd05X^9@1nEe00^9>=
0:f:QP2bS8/0/hV<06Tl@`1`ATX0D2T/08IRHP2[RHL0Z8N20;2;Q@2kRh/0d9JE08i6A`23<c80WTe:
09eBC@2AE4l0GbhW095ZH`2nWiL0^YfE0;nNU`3>Yj80NDI5074d<`2CAdL0VDQ409Y8?@2EB3H0SdL_
08148P2AHS@0Z8E=09Mm@02?OCl0S7m809nGJ`2/YhT0VIJ301lM4@0C40T0:2DP02LT7`0V8ah09b<P
024P700U91l08b8M03<b;P0i>3H06APD00/:1@0a;RL0BdLo01lK4P0M6Q<08AhG028O6P0N6aH07AXC
03Xj<P0n?cL08B8L024R7@0K6aT06ATG01<C4@0`<2h0^[Zh01`00?l06_ooool4003o0080oh00=P2P
8?0<0?n000030:0Pl03oP000oh0000D0oh0000<0X23`0?n0003oP0002@3oP0000`2P8?00oh000?n0
000C0?n001d0X23`00<0oh00003o0000o`006P00o`0@ooooo`003_ooool3003o000R0?ogm@3OZZ@0
WdPo0<A;@03FBSd0fdLh0=m5>@3SBCd0jE540>Q@@`3SBCd0g48f0>96>P3NA3P0h4Hj0>98?03NA3P0
hdTm0>A8?03RB3`0h4Li0=m7>@3PASX0hDLk0=m5>@3OASP0gTDg0>17=`3QB3P0iTdm0>I??P3[ED@0
kEM60?5NCP80kE]<04l0kUa=0>]LCP3^H580kF1C0>iQE`3cIUd0k65J0=iEC`3UGU/0mVi^0?5WI`3U
EUP0jeMG0>]CD03UCDP0h4]40=A4>@3:AST0]dHf0:]<>P2^HDl0WV1>09aUD@2JHdl0WfMF09EMCP2I
HE@0V61C09]UF@2EHE@0SUiB07mCBP2VOWH0Hd0j0:V8P`31Wid0^iVG0<JPW`2cRX`0HcTm068k?01F
=3<0]9FB0;JGU02gUY40^92>0<fGU`2kMWT0ORd/09]3@P2OBTL0Ve1;07i3?@1R<b/0ZhIn0;2AR02d
UXh0_YfH0:R2O`1]?cl0QeAC091FE02AEU00UUaA099JB`2?G4T0PeLl09IbD02MP5P0U7eA095nD`2?
PUP0XiYg09RBNP2f/j80@Clc00`;1P0S8Qh0:2LS008092<O01/08R4M02DT800O81/08R8P03<d;`0d
<bh092@L02l/9@0i=Rh08QlF01hK4P0G50/06ATA020P600b<B`0>c`f02LX8P0O81X081lK024P700L
6aL06QTE01LF4P0/;BP0QHF30:BVX`3Nh=d06@00o`0Jooooo`<00?l00`3oP00e0:0Pl0d0oh0000<0
X23`0?n0003oP0000`3oP0030:0Pl0/0oh0000<0X23`0?n0003oP0004`3oP00N0:0Pl0<0oh006@00
o`0@ooooo`003_ooool3003o000Q0?o`k02iMVh0ZTDk0<i@A03DASP0fdHh0>Q@@`3`F4/0jU950>A<
?`3K@cH0gTHi0>18>`3QBC`0hT`n0=i8>P3SBd00hDTl0>18?@3SBch0gdTk0>5;?@3RBSl0hDTn0>59
?03QBC/0gdPg0>=<>@3QC3P0hTlk0=i>=P3NDCH0j5a10080kV9905/0k6170>YNA@3^HT/0jEi70>eP
B`3[GT`0k5m>0>]LCP3YFdl0jeiE0?U[I`3jJfL0jeYG0>eHE03[Ddh0idi80=e6?`3D@CL0bdDi0;e:
>02_CS/0RS`V08a?>02;ECd0Pdlg08YH?`2>G4D0QeM108EF@P2:GDX0SfID08]VE024He@0QfML06a?
A`2bUI40_j2M0<2NW03=YZL0VG1d06e6B@1>;2/0RFYW0<JYY@2lWIX0_I^I0<^OWP3UZJ/0Uda@08<[
:P2VBdX0XD]:09]ACP1M9R40QU]D0;fHT02eU8d0^9FA0<bTXP1lDU<0IcLg089@C`1U<Rl0L3di06Ph
;P1eAcX0JCl_068l:@1bD3L0FcdQ06Q=;`1H@B80NFI808=fFP2DS7L0^[FR09VGRP0L71@05QD@028Q
7@0U92009bHR024P700R8Ad07A`H028Q7`0X9b<0:2LR03<c:`0j=c80>cPa0080<BhU01<09bLM03<c
:`0h=c80>S/e02HW8@0R8ah07b0K028Q7@0V9B<07A`J020O6`0G5Q@04a<A05mOG@1QHf00NGYe0:>T
W`39b/D0inOU01H00?l06_ooool3003o0080oh00=P2P8?0D0?n000030:0Pl03oP000oh0000H0oh00
00@0X23`0?n0003oP000X23`3@3oP0001@2P8?00oh000:0Pl03oP000X23`00D0oh007`2P8?040?n0
01H00?l04?ooool000kooooo0`00o`00503^cLP0X5980;m@A@3ACD40fDXl0>1;?@3[EDL0kEM90>E?
@@3MBC/0gTXl0>5?@03KC3h0fT/m0=e>@03LCCl0hDi40>=AA03NBd40gT`o0P3PCT40J03PC480hDY1
0=e6>`3PBS`0h4Xi0=m>>@3PE3/0e4d_0<e=:P3?DB/0dEH]0=aQ>03QICl0j6a60>AXA03OHd40h6A2
0>=S@`3WI4H0kVI<0>aQBP3/Gd/0kUm?0?9SE@3jIed0jEI<0>QABP3WD4T0hDY10=e6?@3F@c/0cDDi
0<M=?P2/AC80RS@M0:iWB`2YK4d0S5@c09EP?P2<FST0PE<a085F=025HCl0Oehm06M=;01_ESP0LUY2
05To<02NPWL0`j:M0<BQW`3I/[<0PEYM06<o@`1>;Rl0]YRF0<:TXP2nWi`0`YbK0=RVY`3@SY00O2`_
09Di>P2[CDd0XU5@088n>`1K:2@0[hJ20;jKU`2iUi<0bJ2N0<6AT@1L:2X0MS/m0:Y`KP2<DTh0Uf1K
09i/I@2HJF40SV9G08ILD02=IUL0OeY809AaG@1VAS40Q6QC08afH02XW8H0]k2M0<g:^@25PgL071`D
01DF400O81/0:BPT02DT800U8Ah09B8M024M6P0M71L07ahJ02HU800/:bL0<2lZ0P0b<RX01`0d=2`0
=3<^02//9P0V9b808B8M01lO7@0J6QP00P0V92D03P0K6a/0820N01DE5@0C4a40KVi/06m`J`1aLV/0
MgM_07EgK01nOgL0VIbC0;bm]`3Qh]`0mOKa4P00o`0Jooooo`<00?l00P3oP00f0:0Pl0d0oh0000<0
X23`0?n0003oP0000P3oP0000`3@D7P0X23`0:0Pl0080?n000040:0Pl03oP000oh000:0Pl0D0oh00
00<0X23`0?n0003oP000403oP00L0:0Pl0X0oh004P00o`0@ooooo`003_ooool2003o002K0?ogm@31
U8l0Vd<i0<Q?A03ABCd0edPj0>MBA03_FDX0j5940>9>@03VE4D0h5510=a@@@3EC3`0hEU;0>]QE03X
G4l0jeeA0>eOD`3XFTh0i5I:0>IHC03UEd/0iEE<0>ADB@3SD4H0iUA70=m@?`3TFD@0f5Di0=iS@P3W
Ld`0eFHi0=U]?P3EJCX0f6`n0>9fB03TMd`0h7=80=Q[@03RL4D0hF]30>M]B03WITH0j6950=mG?@3T
FD80hUE10=i??P3QCd00gd/o0>=<@@3MASd0g4Pn0=95>`3<C3l0`4`m0:e8=036Ke@0_71@0:iUA02[
JDH0Velk0:5[A@2HJ480T6U208e]A`1oID00Pfa<081[D01YD3`0U7I[0<ZWX`3<YJH0ejn`0759CP1@
;C40NUaL0<b^[02oXIl0aJ>R0<ZRXP3P[Zl0YVAX07DV:@2UC4h0YU1A09mEE01Q9B@0P5=@0<^UXP2i
UiD0`9ZH0=VYZ@2LHFD0IR@V08i8B032NgT0/VmY0;]jM02[L6X0YFaU0:9[I02eP7P0_HR00;5oM02_
OG80W6iO0:V2L@2KOV/0/Z6=0;J^V@3Ac[/0h^3C06IVGP0D5A005ADC01dL6P0V9B<0;2PU02dZ9@0V
8ah07a`G01dL600R8Ad09RDQ02@S7`0T9Al09BDM02<S6`0O81X08B8M02DU8`0Q8Al07AdK01TI5`0O
7B008AlR01dM7`0V9RP04Q8D01lO8@27QhL0NWYh07UhL@24Q7P0MWIZ07AfJ@1gNFh0LWAY07MhL02@
THT0];F_0=OHd`3^k^`03`00o`0Jooooo`800?l00`3oP00h0:0Pl140oh0000<0X23`0?n0003oP000
2@3oP0000`2P8?00oh000?n0000G0?n001`0X23`3@3oP00?003o013ooooo000>ooooo`800?l006T0
o>3M09aSG02T@SL0cDm10=98>`3JB3T0k5E40>]EA03VD440jEI60>IGA`3RETD0jFAC0?YhJP3lOFh0
o7Q[0?1XFP3^I5L0lVIG0?AXF`3cIeX0mF]P0?9XG@3cIU`0lFAJ0>iQE`3^HUD0jF1@0>EPC@3BESh0
hG1B0?V>JP3JMD/0m99U0?>AI03]S5l0lI9T0>b@G`3eVFP0liER0>V:E`3UPDl0gWE60>EfB`3ULDX0
eEdh0=QL>P3BDc80eU<g0=M<=@3RDD00hD/m0>=<@@3PC480f4Po0=E;@@3FE4L0fUm@0=5QC@3<ITd0
bVQ=0<M/D@3;NUd0`gaN0:]^C`2]NU/0ZH9S08MXB`2NPfP0V7iW08=VEP2OOg@0cJNT0=jf]`2kTID0
JD16058^<P2_Si00c:j/0<FWY@37Z:D0eZn`0=BSYP1k?T<0RT=70:5EF@2PF5/0RDe=05HV902]Qh@0
bjVW0;nMV`3;Wj00f9fQ07/b>@27=CT0Xde<0<Q`K02`GED0_FmU0:EKDP2JDDX0W5I>0;QbJP36P7P0
0P2RGUD0402IFe00T5];09QbH02nZIH0^JjJ0<_6/`3clN@0[ZjV034a;`15ADL0:2HY01LE600P7ad0
<Rh[03<_;00]:BH202LS800702@P7@0S81`07ahI02@U7@0S91`06a`F01dN6@02028R80807QhL01H0
7adP028P8`0O7b407b0T00d>4`1KG640XZ6V07alO020P7P0RXYn0862M023Q7H0P89e07j0L`1jO6l0
MGMZ075cJ01[KF80QXMo0::SV`37b<80iNKQ3000o`0Jooooo`800?l00P3oP00m0:0Pl0`0oh0000<0
d51h0:0Pl03oP0002P3oP0000`2P8?00oh000?n000060?n000030:0Pl03oP000oh0000l0oh006`2P
8?0;0?n000030:0Pl03oP000oh000080oh003000o`0@ooooo`003_ooool2003o00220=ni]02=Ach0
]d]00=9>@@3IBS`0h4`l0?1IB03XDD80iDlo0>iIBP3WETH0iUQ70?1WEP3dKel0k6QI0?5[G@3[IED0
jf=C0>aSD`3bIUP0lVII0?1TFP3eJEh0m6IJ0?AXG03cIeX0lFIH0?5WF@3aJ5P0l6iI0>]_F@3bNV00
jWEG0>ekFP3dPV40lH9O0?F9I@3`Qf40mHaV0?F>IP3bSf80mI1S0>b4F03gR600kG]C0>UcCP3dO5T0
jW1A0?j2I03_J540f4Xg0>=@@@3QBd00h4a20>5=@`3LBd40hE980=mBA`3PEdP0fEI30=QIA03DGDP0
cf=>0<Y/E`2nL5X0ZfYG07e8>02ZOg40cjVM0<RUV`2nVI@0`9RF0=fc]`3R/kX0QUAN06m2BP2:I6L0
ekJg0=2b/03:[j/0cK:^0=Ng]P33WYh0KT=507A6A`1nCDh0MTY906@m?026IF80bjn/0<NZY`38YJD0
gj^`0:YOJ@23:Bl0ZdQ<0:m;B02WACh0YT]20:UAB@2^FU<0Y5=;0:]JE@2QDD`0/65J0:IGD02[G5D0
XEI=09iLCP2BHe80b:bK0;b]V`33_:`0gm[?0>cZi@1NG5h0;bdc04a9DP1IEUh0CdeA04m=CP0h=SL0
9b@T02`Y:@0b;bl07aXK02TV900V9B808b@P02@U8P807AhN02009BHX02LW:@0N7b407AdQ02<Q:00L
6R808B8Z02d^>00I6B<0MGEn0:j]/`27QhL0R8R008f=P@2>T880S8f208F8O01fNFh0Q8Ik08J7O024
QG/0NGY_08:3N@21PWL0NGY_07j0MP29Rh80U9F?0:NXXP29bXL0JNUX07ShM`H00?l06_ooool2003o
0080oh00?P2P8?0;0?n000030>QX?03oP000oh0000D0oh0000@0d51h0?n0003oP000oh000P3@D7P5
0?n000040=1@N02P8?00X23`0:0Pl080d51h3`3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030=1@N02P
8?00X23`0180X23`00<0d51h0?n0003oP0001@3oP0000`3@D7P0oh000?n000090?n000030<2P0020
`000P<0000H00?l04?ooool000kooooo0:P00?l00?oil`3AYI`0UTPl0<1@A03BC400fd`n0>MA@`3^
F4P0iDdo0>]CA@3[EDH0kEM80>aIB@3cHE80j5]:0>aPC`3^IED0iem?0>9JBP3JDT@0hEU;0>5GBP3Q
Ed`0jEe@0>aND@3_HE<0kV9C0?1TE@3^HU<0lFEF0?1TE@3aIEH0lfMF0>iUDP3`JED0kfIC0>mXE03/
J5<0jFMA0>MVD03TJ500hVa<0>aeE@3[LU<0jVm@0>mbEP3_Ke@0jf]B0>QZD`3/JeD0kFIC0>AKB@3Y
Fdd0hE560>EEBP3RDTL0gdm40>5AAP3OCD00hTm10>5?@03RDdD0fE100=IGB03=G4`0bFAH09m8?`2@
AD00iZFS0>Z^[P3UZZh0j:fc0>jc^@3n_lP0aH>=07lkAP1n@DT0fZN/0>g1`P3Q^KT0h[bk0=jj^P3L
^;P0fKFe0<jZZP3>[:/0b:JU0<6RX039ZjT0d[Bb0=>e/`3D/[<0fJnc0>^W/P26:C@0]4M=0;i<C02o
DTd0a5aC0<ERG03;K6H0`VMR0:YAB`2mIF40/eiI0;iYI02iI5d0dWid0;1QE02/He@0U5m:0<naV@34
/Y`0a;bY0<[4^03Vhmh0b/S902/X;`0f<ch0@Ci903hkA02`[K@0dm;G06a/KP1dLWD0CD]>05QFE`0m
?3d071dO02<V:`0T:Bl07b</01dQ:P0N8BX06A`U02d]=`0B4Q`081l]024P;P0g>DH0EEMT05UKJ01c
Lgd0ZJR]092?S@2ASXD0TI:4096CQP2KWI80Ngie0413?01KG5H0FeYE04i=B01?CTT0EeM?061PEP1b
LVP0PhEj07UkL021PgP0O7ic06i_I`1QH5`0MgIb08f<R03>cLT4003o01[ooooo00@00?l00?n0003o
P000oh00?`2P8?070?n000030:0Pl03oP000oh000140oh0000<0d51h0:0Pl02P8?00202P8?00103o
P000X23`0?n0002P8?090?n000@0X23`103oP00A0:0Pl0P0oh001`2P8?050?n000030=1@N02P8?00
oh000080oh001000o`0@ooooo`003_ooool07`00o`00ooOb0<VIS`2PCT80`5120=9=?P3KC3h0ke]=
0>eGB03UCCl0keM90>aFB03^F4X0mEmA0>iJC03WF4P0kF1?0?E/G03nMVP0n7AU0?McIP3eLF@0lViQ
0>iZG@3UHE80j69C0>9JC03RFTh0i5a@0>MOD`3YGe800P3]HE803P3^HU40kVEC0>eTDP3bIUD0lFED
0?9VE@3bJEL0kfID0?=/F03/J540jVI?0>]WD03YIE00j6A?0P3`K5L0N03^JEH0kVUH0?1XFP3gKf40
m6aN0?=YG03`I5L0k61C0>IJC@3RETT0iUQ<0>5?A@3RCdD0h4e30>1BAP3HD480f5I90=9ID02c@cl0
ZD500;IFF02gFf00^5eT0;aRJ`37KGH0dWN00:Y=E`2P@d/0VdA;0=:5R`3[Y:X0ijJ/0>NZ[`3Y[[@0
jk:h0>be^P3Z][X0l;k10>Zl_P3[_l00jl720>Rn`03Y_<40jk[00?2g`03NS9L0Vb`e0<Y?DP3<Cdd0
bDm:0<A?B03IJFD0fW5]0<eWH`2aD4X0aVMS0<e`J@2oIEd0`FUO0>jFR02aH4/0/fU>0:EaC@3?/Hd0
cKfL0<_4Z033_Jd0dm370>[Zj01JFEh0;Rde03hlA`0c<C`0N7Mo0>g/lP1NGF80>3Hi04Q6B@2k^KX0
S8f@05IJH`1EFfT0B4mQ04I>H@12BUd08BPj02`_@02VZ;L0;Bll02`]?`0`<D<0<SE4024U<@0a<d00
EUIP09fMW`2QX9`0UiF;09BEQ`2CUHP0WZ2E07amM@1EEU00MWE`071_J`1<BdL0CTm:04m@BP0U9R00
GEiF04Q9@@0i>c00OX1e08B6N`1nOgH0Ogae07UdL01<Ad40DTm:0>CSh@<00?l06_ooool01000o`00
oh000?n0003oP0190:0Pl0030=1@N03oP000X23`00h0oh003`2P8?090?n000@0X23`0P3oP0030:0P
l0030?n0003@D7P0X23`00H0X23`00<0oh000:0Pl02P8?001@2P8?070?n000030:0Pl03oP000oh00
00L0X23`1@3oP0020:0Pl0040?n00000o`000?l0003o013ooooo000>ooooo`0H003o003omO40`H^1
0:MAA035DD@0dTdn0>=DAP3_Fdd0jeE60>YDA@3^F4T0kEM90?5KC@3cG540lEY?0>iLC@3_H500jem@
0>eSEP3_JU/0jfMH0>m[GP3cKf80lW1P0P3eM6402P3eLV00lFeN0?A`H@3aK5d0k6AD0>QPD03]I580
jV5?0>QOC@3WGT`20>UMCP060>MKC03ZGTd0kF5@0?=WEP3bIe@0lFIC0P3bIUD20?=ZF01i0?M^G03b
JET0lFUI0?9XF`3dK600mFeQ0?5YG@3bJ5/0m6YM0>mUF03dJUd0kVAG0?5TF03XFU00iUQ>0>5CB@3R
E4X0fe560=UCBP3=C4L0bDe;0<9;C@2mBTl0_TmE0;Y=DP2cAT`0[d170:dnA02oDE@0_E=F0:Y:C02Z
CU<0ZU=I0;9MI02`GfD0[f1V0;=VK02jKg@0_WIj0<AoPP3<RX`0di6C0=JEV@3MVZ40jZ>[0?6Q[02h
De/0`TE90=9=CP3BBdL0f5E=0<=4?@3?E4l0dUaH0==PF`3<GEH0hWE`0=YbJ@3FLFD0dG9P0=5jG`2e
ID00`gm@09i^=`3:[gX0e/RK0=C>ZP3?cKH0c<c00>OXh`2>Si4092<[04U7DP0l>TL0ATA?0=cKh@2`
[[<0G5YM04m=D02OWIh0[:f`02HZ<`0Q9cL082Pk02D`A00d?eD0>T1H03LlDP2o`]<0?D1A02DV>P0Y
;3l0WjFe06Y]O00I6bP0:BTc071^L@2c[j`0Y:6H09jNTP2RXYH0ZjfR079cJ`1QH5/0QhJ1081oN`24
QH00RX^608b=R01fMg40PX=m05EDC`1?D4P0RHV108b<Q022PGT0PWUd08EjMP1lLF/0?C@_0<>n^`03
003o01[ooooo00@00?l00?n0003oP000oh00C02P8?0<0?n00140X23`2P3oP0040:0Pl080oh000P2P
8?020?n000L0X23`00D0oh000:0Pl02P8?00X23`0?n000030:0Pl0L0oh0000<0X23`0?n0003oP000
1@3oP0020:0Pl0H0oh0000<0X23`0?n00000o`000P00o`0@ooooo`003_ooool07000o`00ooG_0;Um
L`2/CT80c5A60=M=@03WEDP0lUa>0>QB@`3]EdP0jEI60>iJC03cGDl0leaA0>eFB`3cGDl0lemA0>eN
CP3_HU40kV9A0>mVE03YHE40jFAC0>MTD03SHTd0iVM@0>]ZE03XIe420>i]E`040>m]E`3bL5X0lFeH
0?=_FP80lVeJ00<0l6QH0>eTE03YH5000P3UG4`0P03UG4X0ie]:0>UKC@3ZG4h0kf5C0>aPD@3aIE@0
lVIE0?AXE`3cJUX0mFUL0?1VF@3_IEP0lfMJ0?9VF@3dJ5/0lFMJ0?I/G`3dJe/0lFYM0>aVFP3/HeT0
iemC0>1CB@3VF4h0hE=90>5DB`3MEU00fEQC0=YNG03KHf80f6AT0=APH03CGEd0dUaL0=5IFP3AG5/0
bEMF0<AFE@32EUH0`eUK0;Y@DP2dC4d0]dm@0;A=CP2/B4P0[DU;0:m=CP2]BTd0[4U>0:i9C`2]AD`0
/T=:0;Pl@03FCTh0f4e80=Q;A03ICdD0eTe50=9;A@3ED4/0eeA<0=YJD@3RIU`0hVYL0=][E`3AJT/0
`VXl0;me>02VK2<0VWDT0<2]H@3Jd9<0gMV/0=OF^P3@d/@0h>;M0;o3a00W9bl0E59O04]9E`0e<Cl0
ZjR_0?3[l@3Sg^80e];C0<c7b`3ShND0R8^@061TK@14BUH0:35201hV?@0m@Ul0CU9]0:N/_`1`MXH0
5AP[02H[?P2;TJ40N7^:01XL:@0U9Bl0>3Hk09:>S@2[Z:40YJFK0:BVV`2YZj00LW=[07MhLP1RHed0
I6EP06YZJ01VIf80M7E`08V8Q02KVYH0VYJC08>2O@2:Qh80VIJA09VASP2HR8P0TWim09V4P@1QCTX0
V8f;0`00o`0Jooooo`03003o003oP000oh0006X0X23`2P3oP0040:0Pl0L0oh001P2P8?020?n00080
X23`0P3oP0030:0Pl0L0oh00102P8?0;0?n000030:0Pl03oP0000?l000800?l04?ooool000kooooo
03D00?l00?o^jP2bKfL0]E160<e?@`3NDTD0kUY>0>mIB`3WDD80l5e=0>YGA`3_Fdd0mV9D0>eFB`3c
GDl0l5a>0?9QD03aHU40kV5?0>aTCP3[I4h0j6I>0>MWCP3WJdl0h6U;0=m[BP3PKT`0gF]90>5^C`3N
Jd`0hF]?0>5YCP3VKE80iFU?0>IZDP3YJeD0kVeJ0?9]G03cJed0mViN0?YaH@3dJe/0m6MF0?1RE03Z
G4h0jE]=0>YLCP3UF4L0jem>0>=GAP3WFd`0jUiA0>QLC`020>]ODP0O0>aPD`3_HeH0kVAI0>iVFP3]
J5T0jVQK0>UYG03kNF`0mg5V0>ePEP3[Fe00jEI<0>=CB03LDTP0fUM?0=]RFP3QL6X0gG1[0=eaKP3O
LVl0ffi[0=e]J`3JIfD0ffQU0=UXI03IJFD0efMU0=ESHP3CHF00dV1O0=EUH@020=1PGP1B0<mOGP3@
GF00beQK0<UEF038DE<0bDa@0=MCDP3FCDL0fTm80=I<@P3KDDL0ddTo0=e@B@3ODTT0g4m50=eCB03J
DTH0feU90=9J@P38GSL0]E`T0<n;@03EY4P0`jI30<:cEP3Hd8L0h]nZ0=kM_P3If/X0g=gH0>SYj`1A
DET0=SA105ECH@18A580P7f60?;`m@3ck_80VIBH06eXK03@cM00iNKZ0=oRi`3EfN80cmGS05UPL`0a
=E00E5Ea08B7VP3<cmh0@dIE01PK:P0S9c<09BLc01TI9@0Q82P06ALL06APG`2c[jX0ZZZR0:RZW`2Y
ZZ80PhAl07AcKP1VIf40Shj:079cKP1@DD`0DE1<05MFDP1[If@0M71]05aHE@1YIF80X9RF0:>CT`2i
Vid0_i^M0<jXY`2VQ880Nf=O0?W[j0800?l06_ooool00`00o`00oh000?n0001Z0:0Pl0X0oh00102P
8?0:0?n000<0X23`0P3oP0080:0Pl0H0oh0000<0X23`0?n0003oP0000`2P8?020?n00080X23`203o
P002003o013ooooo000>ooooo`0c003o003niN00[fIO0;Q=@`3BCdD0iEE:0?5MD@3_EdX0jE=50>aH
BP3]FD/0lf9A0?1OCP3_Fdd0lEm@0>eNC@3_HTh0jV9<0>YVC@3WIdX0hFQ90>9]BP3OLT/0h7I<0=Ye
B@3LO4`0eWY90==gB03IO540fWYB0=YhD`3LN5@0gWEE0=icD`3QLUH0gfeB0>A/E03UIe40j6EC0>eU
E@3^IED0m6QG0?5SD`3eJ5L0mfUK0?IZF`3cIeP0lfMF0?5UE03bIUL0lVUI0080k69E07D0jV1C0>EK
CP3UFe00iemC0>EOE03OFdl0hf=H0>5UF@3QIe`0nWYa0?9]I03`IU/0kEeB0>aJC@3RE4H0eU950<mI
B`2iDDH0[E180;=NF@2dHel0]F5O0;eWIP35JfX0c6a[0=IbL03NN7@0fgEa0>1jMP3NMW<0h7Ud0=ae
L03MM700fW5]0=Q/J@3JKFX0ff]Z0=]YJ03LJ6P0g6IT0=iTH`3LGe/0fEQB0=aLD`3IET`0f5=:0=eG
CP3MDT/0h5=90>1@A@3ODD<0h5A70=]F@`3CEcd0bUhg0:mI7P3<RS`0jKeJ0=O0D@3AaUd0fM=o0>ST
Y`3XiL80hN3>0>3OfP3dm?H0VYVQ020N:`15@e40EE=Q05UGHP3Mg>80f=KK05MEFP1UHfP0]kJj0>g]
k`3Vin/0hnK[0?Gio`2GVZT08b@i04Q8H01YJ7X0inKd0<S6d@22PHT0FUUO04A3B00Z:Bh06QPM02TW
:02BTHl0^KFa0;2`Z02^[ZH0Zj^S0:RXX02RWiP0WYjF0:^XX@2PX9P0UYJ>08n>R@20Og/0HF1L04i=
B01=C4L0GUUF09fAT@2UQXX0fjJ/0>nc]@3f^KP0`hb90758@P3Wc/T00P00o`0Jooooo`03003o003o
P000oh0004D0X23`0`3oP00Q0:0Pl0`0oh00102P8?020?n00080X23`1P3oP0030:0Pl0<0oh001@2P
8?0=0?n000@0X23`203oP002003o013ooooo000>ooooo`0[003o003hg=P0[V=M0<1AB03FDDP0iEE:
0?9NE03XDDH0jeE70>YFB03_Fdd0lf9A0>aMC03[G4`0l6=A0>aTCP3VI4X0iFY;0>5/B@3NLT`0f7E<
0=9eC03BNe00cgiA0<aoD@3=Q5@0bX=E0<9nD@36OUH0aWeJ0<MlG036MeP0b7AH0<MaEP3;LET0bfaF
0<mXE@3NKe`0iFeL0>QYF03YI5<0jfAA0>mSD0020?5TD`1m0>mQD`3^HU<0kf=B0?9VE@3`I5D0lVIG
0?AXF`3eJE`0n6aO0?AZG@3dJUl0lfeQ0>aZG@3TJ5h0h6]Q0=5SF02gB3l0ef1J0>Y[I03]Ieh0jEaB
0>aMC`3UG4`0fEY;0<mPC`2?<b@0LRHI074a:01/<Bd0JRh]070b<`1j>3T0PSXj0994@P2KC4P0We1<
0:1?C02YF5@0/5eG0;AQF`2nJF@0a6aX0<YaK@3?M6l0dW=a0=5_K03JMg80ggUe0=acL03LLF`0gG1Y
0>=dK@3MK6@0gfQR0>AWH@3YIF00ieiF0>1CB@3RETT0fe540=YHB03CG4@0cVQ20;e/=`2jNc@0k/=W
0=g7G03Hc6P0h=V80=7=T03Gdk00h=g>0>7Pg03`ko@0g]cW040nB`0c<440AdAE04e9E`2g];d0f=GL
03lm@P0h<cX0`;g10>[Xj`3Vi^P0h^?U0>kamP35b=409bPj040nE015@UD0_kg;0>WVk`3EdmH0b<K7
0;^i^P2ZZ:/0V9JG0:RWY@32`Kl0_KVf0;Bc[P2g][40][>^0;>`Z`2a[ZL0[Z^T0:ZWX02XYIh0ZJVQ
0:JVWP2XYj80W9^G096@R`28Qh80OGEc09N4QP2`Q8/0c8>:0=R3R03>N7T0ZeeI08Y?B@3>ZJ400P00
o`0Jooooo`03003o003oP000oh0001D0X23`203oP00V0:0Pl0l0oh005`2P8?0<0?n000@0X23`0P3o
P0020:0Pl0H0oh000`2P8?0L0?n00080X23`0`3oP002003o013ooooo000>ooooo`0c003o003ae=00
ZUeE0<9CB03GDTT0ieM<0?9NE03XE4P0jUI80>mKC@3aGDl0m69C0>IIB03]I540i6190>IZCP3LJTH0
gG=90=QiB`3<NTX0b89A0<64F02nQf00`Hm/0<2?K`33UGD0cIj20=Z/TP3T]9h0hk>O0=^ZV@3W/jD0
j[6V0>b`YP3][J@0kj^R0>NNU`3EPGH0cFUI0=m`G@3ZLE`0jF]D0>YTCP3`He40l6=B0?5TD`3/Gdh0
lF=E0>mPDP3bHeD0lF9D0080lF=E07L0kf5C0>mSE03^HUD0jVAH0>AYFP3MKF40eG=X0;MNE`1l8Ah0
Vc<b0<MCD`3WJ680kFAL0>ULDP3XH5@0hF=D0<aQD@22;al0FQ/<05HV701<9Ah0BRLU04XV9P1?:2T0
Eb/]05h^;P1J:RP0Gbl[064`;01Q;R/0JcPd06@a;@1d?cT0Lc`g07Hk=`1m@3/0PT4o088n>`2>AdD0
U4Y709Q=BP2IBdL0XU=?0:mKF@2`EUD0]UME0<MNF`3CGE/0fe]H0=IAC03FDDX0d5580<YDAP35G4T0
aVaA0;meCP2`M400hKIa0>;8M03IbWL0l>NR0;6[N@1nNUl0R8Ij09JFUP2/[;@0_ko;05IEI@0m?4h0
@SmB04DnD02;QI<0mNoi0;^f_@2VWjH0j^?Y0>_VjP3Vi>D0hN7S0>OXk03Uj>l0@D=B02PY?@0[:Ch0
NGJ70>WVk`3Ie=P0dLo@0=?Bd03;bLX0c<[;0<c;b@3:bLL0bLG30<>o_032_[/0`;bi0;fi]P2j]k80
^;F`0;>`Z`2d/JX0/JjW0:fZX`2/ZJ@0Xj:M0:f/Y`2e/Zd0^:j]0;ROXP30RY40Ze1I0;M>E@33EeL0
_UeG0:MME02`PGT0oo;]003o000Jooooo`03003o003oP000oh000140X23`3`3oP00I0:0Pl0030=1@
N02P8?00X23`00L0X23`00<0oh000:0Pl02P8?002P2P8?0>0?n000/0X23`303oP0040:0Pl0X0oh00
0`2P8?0K0?n000@0X23`0`3oP0000`00o`3oooooooooo`0>ooooo`003_ooool0<@00o`00ilS50:=D
C@33DdP0feM;0>YJC`3^G4l0j5A60>eIB`3`GTl0kf1?0>YOC03WH4X0ifM>0>1YB@3LLDL0e7A20=5o
A`3@RTl0bI5H0;nAG`3C[HH0ilFY0>S9]03VbKL0kM320>oAaP3B]:T0aJNO0<:SWP3bdm00_j2N0:n;
S@2aR8`0/XR<0:eoPP3>VY`0oL2k0=b?O`3:KUL0hGQK0>IcE03YKDl0k6E?0>eRC`3bIUD0l6=B0>mQ
D`3bHeD00P3aHU@0N@3bHeD0kUmA0?9TEP3]HE80kfEH0>MUE`3PK5d0ggY^0:=AAP2cL6X0GALE06LF
5@2?;Bh0aUAC0>IYI@3XHE/0iEmF0>5SE@3IJE/0WD@d064N3P1860`0@AlF03XQ700g8R40=AlQ03/T
9@109RL0@2HU048Y9@1:;2X0ABLU050b<019;2P0D34/04/Z9@1?;2P0CbTV05D/:P1I;B`0GC0]05l_
;@1R<Bd0IC<`06La;`1V;2/0LS8b07L[;@29<380Tb//0<5=C@3;Cdd0bDi90;m<A@2oFDd0]Ee?09=:
=`1j?R@0Kd4M08QT=021JRl0P74f08^3DP1iME00F5E205EDC`1FEEX0G5aV05MFI00m?4`0?ci@03hl
D@11?U40GEUZ0:RT/P2/ZK@0`kg90=[Cg@3VgnL0in;X0>CRi`3Qh^H0lOCi08B6TP0A4b0051<Q0490
C@3Ge=/0hMoR0=SFe`3Ge]@0eM?D0=CBd`3Cd]00e=?A0=C@c`3@c</0cl_80<g9b03:a/D0a/:o0<G1
_P34`;d0_kbg0;fj]@2j]k80][>^0:j[YP2a/:`0^kJc0<Fi^@3=];L0ciBL0;=?F@2b?dH0b51B0<5D
D@2`G580TE]?0>kIe000o`006_ooool00`00o`00oh000?n0000?0:0Pl1<0oh005P2P8?020?n000T0
X23`00<0oh000:0Pl02P8?005@2P8?000`3@D7P0oh000?n000030?n000L0X23`203oP00:0:0Pl0X0
oh000`2P8?0J0?n000@0X23`0`3oP0000`00o`3oooooooooo`0>ooooo`003_ooool0;`00o`00hl:m
0:=CBP33DDH0g5I:0>eND03ZF4T0iE920?1OCP3^Gdh0jF5;0>ESB@3NIDH0gVi80=Ea@03FP4D0dXU5
0<jBB@3>WUH0bJEW0=ZoT03`fkh0glbm0;j]YP2cXIl0i];D091lOP1_FE`0F4=806eHG`3E`LX0JeMR
06QBG`1ZDV80K51O06M7E01N>D00a9RE0?[2/@32OEh0d7]B0=]jC@3TMTd0jVm>0>MUB`3/IE40jf9?
00@0lFAC0P3`He80E`3]H4l0lVIG0>aWF03SJ5T0hWQZ0<I^HP1i=Rd0UfQQ0:IiM01`=S@0Ha`J08@Y
:033EE@0i6QV0>MVH03THEL0hFMJ0<iSD`2C>RX0Gad?04<E200j71@0<1dG02hN7P0]8200;R0P02/M
7@0^81l0>BLW03<Q7`16=380>BLS040_:00j9b40BcHa03TT8@0j9B80>bHS040X9P12:RP0@2LS04@X
9P18:RX0A28Q054W:01A6Qd0HA/M06T@4P2cBd`0bUYH0<UIE@3;IF00^fAK09]HC`1O;R00A1l?04DZ
5@17<AT0@SDD03Xd500d<aL0:R/I03`l=010@400A4E:04E5C`0j>DL0;bhn034`@P0a<TH0>SaA04I9
G01DEFL0CDiP05=AIP1[J7/0Q82?09^EX@3Kf>40hN3U0>OXk038bLh0OWn406ETJP1DDeP0^;Rj0>GU
i@020=_Kf`80f][J01`0fMWI0=KFeP3Ge]D0e]GC0=CCd@3Dd]<0d]7?0<k=b`3=c<X0bl[80<W8aP35
a<80aLC00<;1_@2l^kL0ZjZX0:RTX`2h[Zl0`J^^0=6JX`2bDe/0Xc8h0<9:C036EU80]eeD08=7?03:
/JX00?l06_ooool00`00o`00oh000?n0000=0:0Pl0`0oh0000<0X23`0?n0003oP0001@3oP000102P
8?00oh000?n0003oP00C0:0Pl0@0oh0000<0X23`0?n0002P8?001@2P8?000`3oP000X23`0:0Pl00P
0:0Pl0030?n0002P8?00X23`01<0X23`00<0d51h0?n0003oP0001@3oP0020:0Pl1X0oh001@2P8?02
0?n00003003o0?oooooooooo00kooooo000>ooooo`0a003o003Q_[X0YeA<0<ABA`3OFDd0kEi>0>YH
B@3PCch0j5Y80>IOB@3OGd80ffA20=]`AP3?Kc`0dWi00=69@@3AUTH0ejQH0=^gK@3=]GT0imR_0=S;
^03Sf=@0a[^o0;bb^P2eZK@0IeUV05e?G00i;3H0/jFb09R<VP1GBU/0ETUK04hoE01F@eT0Ie1R04DZ
<`2ELW00om[50=bTO`3DSU/0dX590=amB03WN4d0k7AA0>UYC03[I4h0kF9?0?5TD`020?1SDP1J0?=V
E@3_HU40lVED0>iUE@3ZJ5P0hViO0=UiJ`2RF4/0I30U0650>@2eV980]Y6;06`i=P1G4@l0QRh/0<=K
FP3OJFL0hfIP0>1TFP3KIET0bf5C094n;P1K70d0?a<8038G3P0/6QH09ahL02HM7P0T6a`09QdN034W
9P0Y7ah0>S0_02hT8P0e;2L0<RTT03X_:`0`9B40;R@R03@Z:00c:BL0=bd[03HX9`0_8B00@S8b03DQ
8P17:R`0@ALI05`N8@1T3a80[DU90<YJF03<G5P0b6EO0;5QF02>ED`0B2<J030H3P0`8QL0<BLK03@]
800/:Qd0;BdS01lP6P0Y:BL0:b`^038a=`0e=3`0=S@o02`Z=`0/:cT0:R`i024T<`0J7B`08bHe038e
A00d=dP0@T9E04Q5EP16@U00_;W20>KUjP3Jf]`0gMgO0=_Kf`3Jf]X0dM7A0=GEe@3Ng]h0gMgM0P3N
g]h0303MgMd0g]kN0=_Kf`3Mfm`0gMcJ0=cKf@3Lf]/0fmWJ0=SHeP3Fe]@0emGF0=CBd`80clo=00l0
clk<0<_:b02g][@0X9bK0:JMX02]VYh0eJB/0;YOJ02J:c80aDe?0<IED@2hG540R4Pl0:25O03on>l0
6_ooool00`00o`00oh000?n0000<0:0Pl0/0oh000`2P8?020?n000@0X23`00<0oh000:0Pl03oP000
0`3oP00A0:0Pl080oh0000H0d51h0?n0003oP000oh000:0Pl03oP0060:0Pl0030?n0002P8?00X23`
01h0X23`0P3oP00H0:0Pl240oh001@2P8?030?n0013ooooo000>ooooo`2<003o003Q^[D0ZUM?0<ME
BP3RG500lF9B0>MEAP3TED@0iEe70=iQ@`3CHC`0igi?0=Mj@@3DPd40cHDi0=6C?P3R[UP0kL1_0=Nd
L03E_hd0h=6b0<g1]@3Qf=T0_;Jj0>SQj@2BRYP0G5AQ048gA@1`IW40e<[E06iSL`15?4d0GeIW071T
N017>E00He1S03/Q;02aSXX0om>l0>beS03g^X40ij9Q0=:1?`3PP4H0iWY;0>egD@3WJ4P0kFE?0>mR
D03_HU40l65A0?9SE@3aHeD0kF5@0>YUE03RJEP0hgUY0<AcHP1_=2H0DbPO04L_9`1IA3l0WhJ10;nN
V@1^?SX0DQDB088d<P2dEUH0efYW0=eWH`3SJ640ffEK0<]QD`2H@380H1h@03dA1P0`5@h0:1`H02@L
6P0Y8b<091hN02TS8`0U81d0?3@b02XR7`0e;BX0;BHP02/T7P0Z8ad0=Rh[02lW9@0b;BT0:2<O02LM
6`0Z81h0=BXX034S8P0m92L0=`dA05PG6`1Z4180]DU70=EKEP3;DTT0`5I90;AQD`2@F4/0?adC02XG
400V7AH09R4K02HT7`0O7QT09RHT01lO7@0L71X07QhN024O8P0S8BH0;2L]02HQ:00U8RT0514H03ln
@`1SHVL0BT]?03Hj?@0N8bL08R<^01dK:00M6RD0Q86:0>WXk@3Kfmd0f]SI0=_IfP3Mfm`0h=oM0>;P
h@3Qgn030>7Qh@080=kNgP3Ng]`0h>3N0>3Ph03Rh^80hn?S0=oOg`3Ph>020=oOg`0C0=kNgP3MgMd0
g=cL0=_Kf`3Lg=`0fMWI0=?Cd`39alP0aKo10=;2a@3/a<X0_V]c094X;@33C4h0a5==0;aNE02=Bcl0
S71U0?ofk00Jooooo`03003o003oP000oh0000/0X23`2`3oP0000`3@D7P0X23`0:0Pl0030?n00080
X23`00@0oh000:0Pl02P8?00X23`1@3oP0000`3@D7P0X23`0:0Pl00<0:0Pl080oh000`2P8?030?n0
00030:0Pl03oP000X23`00D0X23`00<0oh000:0Pl02P8?007@2P8?020?n001P0X23`8P3oP0040:0P
l0<0oh004?ooool000kooooo08`00?l00=fd/02/F4h0c5M=0>=MD@3]H4l0i5E50>5D@P3RHT/0fV]=
0=9_AP3QQeD0gXi?0=J>A03IV4H0iJaE0?;0J`3R^6h0Z8Q=0=_5WP3KckT0hm[E0<6k_`3;a/`0jnG_
06EQL@11?Dh0Yj2`0??[nP2ESI`0ACa?03hgB@3Dc>40dLWN0514FP1<?E00@R/e0>6n_03>VhP0_7eJ
0?:`O03o_7/0iIaD0=J1?P3PP4@0hWI50>mhD03YJ4T0kFE=0>mRD03bHe<0lV=E0>iPDP3_IU@0iFIC
0=m^G03HNfT0WUU905`/7P159a`0?b`V03h_:P1<>CD0ZI6=0<BUX01X?c/0DQXI07L_<02]EE@0cfMV
0>5[I`3OIUh0gfUM0<iTEP2OBCX0Gb0A03`A200_6A@09Q`J02LR7`0V8R408QhM02LS8P0c;R/09R4N
038]:@0U81`0:RDQ02HQ7@0a;2P0:RDQ02XW8P0X9B008QdJ030X9@0d;2T0<BDU03HM800k4AD0EaDI
06l@5032CTh0e5E>0=5CA`36F4T0^fAC095GB@0m7A009QD=024L600M71P07QhL01lO7`0P82006QXJ
01/J600O6aX07ATH024M700U7b408APK01@>400n>3P0/:b[0=cHe`37alD0^;Zg0::VY@27RXd0IVE]
04]8C`1THFP0g=_P0=oOh@3Pg^<0gmgR0>;Ph`3Vi>L0iN?V0>?QhP80hN7Q00`0gmoO0=gMg@3Ogmd0
h^;P0>;RhP3UiND0i^KV0>3Ph03Rh^80i>CT0>7Qh@3Ph>020>;RhP0@0=oOg`3Ogn40gmoQ0=oOg`3P
g]l0hM_M0>KGfP3hemh0b7^308DR9`2lB4T0`4m;0;eOE@2ACd40SFmT0?oek1[ooooo00<00?l00?n0
003oP0002P2P8?0<0?n000030=1@N02P8?00oh000080oh000P2P8?020?n000<0X23`0`3oP00A0:0P
l0030?n0002P8?00X23`00<0X23`0`3oP0000`2P8?00oh000?n000050:0Pl0030?n0002P8?00X23`
01d0X23`00<0oh000:0Pl02P8?003P2P8?060?n000<0X23`8@3oP0040:0Pl0<0oh004?ooool000ko
oooo09D0ooOd0=Z_Z@2]ET`0c5Q;0>MRD`3ZGD`0hUE40>AKB@3LIU00d75E0<QdD03BR5L0fYII0=bL
E03Z[Ed0mKYZ0>VeJ@2NMCL0_Ii`0>KE^@3MdlL0gmKG0:NPY`3ZiN`0_kc705EBIP10?E80U8nS0:ZU
^@1HD6D0B41H04m7G`2SV[D0O7B<0514FP0e9cP0PF]g0?KBeP2]LFT0]FQD0<ijE@3ST5`0o;E^0=nC
A`3IQcd0hX=30>IkA@3]Ld`0jfQ:0>mWC`3_HU00kV5@0?1TE@3[He<0i6UG0=edH@35M640ND0_04`X
6P0l9Q/0>2XU03DW900m;RT0CS/e09=kM`2nXYh0SVQU050P7P1Y:BT0Xe9A0<eWI@3NKFT0hVUP0=aX
F`3@JEX0Xddn05dO400h5@`0:AXE02DK6@0S7Q/09b<P02PT8@0`;2T08QhK034]:P0U8Qd0;R/V02`Y
900b;BT0;BPT02LT7`0/:B809B0L02`W900g;bd09ATK03XO901151T0FQ<I07HC5P35CDh0f5A?0=9B
A@3:FdX0_6=A08aC@P0l70d08a8:028M6@0M7A/061TI020P800N71d07ATH024L6@0L5a<07aXF02@L
6@0L4Q009AXH07AZJ03?al@0f]GA0=OCd03Kf]H0f=SF0=_Kf@3MgMh0g]cO0=?Ae03;bL`0g]gR0>7P
iP3Uh^d0in?a0=WGi02m^lH0]kJl0=WIf`3Ph>00g]kL0=cLg03MgMd0gmoM0=kNg03Ogmd0g]kN0>3P
h0030=oOg@030=kNg03Ph>00h>3P0080h>3P00l0hN7Q0>3Ph03Ng^00gmgN0>7Kg@3Vf]`0n=SN0<5j
PP2bDeT0/T530;i>BP2lFe80Ue=609=cJ03om>T06_ooool30?n000P0X23`3P3oP0020:0Pl080oh00
0`2P8?020?n00080X23`103oP00@0:0Pl080oh001P2P8?030?n000030:0Pl03oP000oh0000D0X23`
00<0oh000:0Pl02P8?00702P8?000`3oP000X23`0:0Pl00<0:0Pl2`0oh00102P8?030?n0013ooooo
000>ooooo`1n0?oglP3EZZ<0YU970<eLC03UHE80jEe<0>9FA@3KFTL0dVYE0<]kI03MV7/0hJ=l0>2T
L03UZ6T0mKUc0?:gL@2cP440X7Q70>?9Z03Mc;X0hm[C0<W0``3<aL`0nOCk08R2SP1?Bf00CDQN05YE
J@1LE6T0EdmT05A<I01CBf<0GE=/05M=I@12=dP0;b4`0=6mb03oh>L0jK6b0;ieKP2lJUD0_FU50>^T
IP3k]VT0g9=60=F1>@3UPd@0igM70?5eC`3WI4P0jf==0>mSDP3^IED0j6EC0=mZF03KNVL0Zf9A05h_
7`108aD0=RDK034V8@0a9R@0@38_03d^:@12<2`0Pg1Z0<6YY@2HMW@0E2LT06d`;`2EA440aFAN0>1_
I`3QK680gVeO0<aVE`2QCSh0E1d@03PG400Z4Ph0;1XF038T8@0[81h0<bTW02LM6`0f;R/0;2@Q030Y
8`0]9R00<2TS02hW8@0T7aT0;RTS02@O6`0[9R<0<2PV02LH6`0n8BD0@a8H060G7P1j4aL0c59A0=UD
C@3DDTD0b5M50;mWD`2:DCh0?Ad>02DD300Q71P071`J01XI6P0P71/081/H02<K600U6QH07A<:01dC
1`0I4040Bclc0:VLT`3Ld/T0aKjh08b7P`2`[:T0h^7M0P3Mg=X04@3Qh=l0i>;S0>SVj@3Xin`0jNWa
0>GTlP3Acn@0YjFk06i/P@1?CUh0DDmJ0;6`]@3_knl0h^;R0=kNgP3MgMd0g]kL0080gmoM00@0gmgN
0=oOg`3Ng]h0g=cJ0P3KfmT00`3MgMd0f][J0=cLg0020=_Kf`0>0=cLg03Lg=h0gM_L0=oIf`3SemT0
l]?J0<f7S`3LOhL0XcDh0;e=B`2kFU40WEM;09UgK@3omNXJooooo`<0oh001`2P8?0?0?n000/0X23`
1P3oP0000`3@D7P0X23`0?n0000;0:0Pl0030?n0002P8?00X23`00H0X23`0`3oP0000`2P8?00oh00
0?n000050:0Pl0030?n0002P8?00X23`01/0X23`00<0oh000:0Pl02P8?002`2P8?0A0?n00080X23`
6P3oP0040:0Pl0<0oh004?ooool000kooooo01d0ooSb0<nWW`2VE4P0bUY<0>ESE@3SFd/0gEQ70=eT
D`3;Kf00`Gmc0:meI`3@V840k;BA0?RkS03h_8H0f9aX0:QeAP37YH80kmW40>_JdP3LdLl0a;Zk0>3E
f@3^iNX0THN@03/bA014?Dl0B45A04HmCP0204@kC01h04<gB`0o<T@0=RTj03@V<`2=OHL0n>?/0?gO
i`3og>@0oL_>0=FFT@2SFd`0`gY?0?bhM`3k]fh0hIE:0=b5@03VOdD0k7U<0?1aD03_JE00kFAB0>eX
E`3PHe40gW5M0=AkJ@2ACSd0DBHF03hT5`0h9al0;B<N02lU8`0g;RT0?C8/048e;`17>340L5eG0:J?
R@26If@0Kd=006/`;02?A3h0_V1H0=aaI`3SLFH0fVQM0<eUF02<=bX0DA4803`91@0k4Ph0@b4O03HJ
5`0m9B40;Q/E03<R6`0e9Ql0<RDO02dP6P0b9Al0=R/W02PO6P0c;2H0:20M02hV8`0b9bD0;Q/M04<T
:@1541P0Ga8H07dD603>DU00fUA;0=9@@P37F4@0_6EA08M>>`0n7Q40:AP@024L600M6AP07aTJ02<I
600Z71T0:a`E02PF300O3P00:ad2071S@`3<`J<0bKnV07UcH`2?Rh80ZZNR0=3<b`3Og]`0g]gK0>7P
gP3Ui><0j^S[0>[Yk`3QhNd0_[oC08b>Y`1PHH00EUIh06IWQ@1NGWH0=3=107AcN@3`l?80i^KV0>7Q
h@3Ogml0h>3N0>7Qg`3Th^<0jNCX0>SVi`3Th^<0hn7R0P3Rh^804`3Qhn80g^3O0=oOg`3MgMd0g]kN
0=gMg@3KgM`0gMgM0>3Lg@3TfMd0mMOM0=RBVP3;KWH0X38e0<1@CP2kFU40VeE909ajL03oln/06_oo
ool30?n000H0X23`403oP00:0:0Pl0P0oh003@2P8?000`3oP000X23`0:0Pl0070:0Pl0H0oh001@2P
8?000`3@D7P0X23`0:0Pl00J0:0Pl0030?n0002P8?00X23`00T0X23`403oP0050:0Pl1X0oh00102P
8?030?n0013ooooo000>ooooo`2?0?ohlP3=YId0YUM:0<eOD03SIEH0gU]90=YMB`3DIE@0aWM]09mX
I@1R<B`0S5Q=0>>/U`3i_I/0fj1h0;IoF02bQV<0l]>n0>KDb03ahn00b[k00>3Df02eZJd0_k:k0=kB
g01aIGH0DDUH05=;FP1NDf<0HUMU06MLJP1UFVP0K5i]085cP033/kd0mNC/0?WTk@3ignX0nmgY0?oK
iP3od=H0hZRV0<J0I`3FT5`0okai0?VdJ@3NT4H0gh=20>QnBP3]MTh0jfa<0>YVD@3WIU<0hf]J0=ef
H`31L5l0Mc`/04`V6@12:Qh0>2TR02dT800]9B80<b`V03H]:00e:R@0@SLa04@e<01JBD80KUUD09Ym
N@2SNW@0OTM008]1>02iGeH0f71W0>EeJP3MJf00aE]?08le:P1W5a00GQLA06HU8@1A5Q80E1lI04LF
3`1?8aX0AalG048M5@0j60l0@b0J04<T7`0g6Q@0?b<O03@H5@0i7Q/0?R8Q03/I6P197240E1HK06<>
4`2;6Q`0eUIC0=U?A@3FDD80bEI30<AYE027ACD0?a<802hA2`0Z5A80:18D02hD5@0c5Q80>1XB034D
100^5000DS`E09j<FP2cYW40T8IE085iDP2JUWd0g][>0>CQg03Sgn00h]kO0>;Ph`3YiNH0j^OY0<_:
d02QXJd0JFYl04I8H@16BFP0FEao06e`T`1KG7X0?SaD02`Y>P1>Be@0hn7V0>WWjP3QhN<00P3Ph>00
2`3OgMh0hMgO0>[Tj03Wh^H0i^;S0>7Oh03QhN40h^;R0>7ShP3Ph^40h^;R0080gmoO00h0h>3P0=kP
g`3Ng]h0gmgN0>GLg`3efn00bHJ?0<=VKP2]?T@0_4Y:0;eJE02ME4/0WWac0?ocja[ooooo0`3oP005
0:0Pl0030=1@N03oP000X23`00h0oh0000<0d51h0:0Pl02P8?00102P8?0<0?n000/0X23`0P3oP00;
0:0Pl0D0oh001@2P8?00103oP000X23`0:0Pl03oP00H0:0Pl0030?n0002P8?00X23`00P0X23`3P3o
P0040:0Pl0030?n0002P8?00X23`0080X23`6@3oP0040:0Pl0<0oh004?ooool000kooooo01X0ooK_
0<>KT`2ZFdd0c65?0>9WE@3LGTX0e61=0<YXF02aLfX0dZJY0:b3R01e@T@0diZD0>NXV02fNV@0VfeD
0=^kYP3Ga;X0f/o;0=K;c@3=`LT0l>7/0;j_^`2k[K`0a;S80;FZ_080Yin`0800XiZ[0:>JZ@2ITIl0
V92L0:JKZ02TVJ<0XYBO0:NGX`2YUj<0X8ZF0:B<V@2DNXH0RFei0?;?eP3IXY/0^fm?0=B8E03h]W<0
n;EY0>bNE03SR4L0j7m:0>]gC`3YKE00hfUC0=i`G03HO6T0X5a<05LW6P1::b00?BXR03HZ8`0b:RD0
;RTU02XU7`0W8Q`0;BLQ02lY8`0i<2/0@3D`04Pk=`1HAd<0NV=N0:B5OP2bQ7l0^W]f0;i]I`3@L6T0
f6aU0>=_I03CH580aeA70;a;?`2fA3/0[Cdd0:Hh;P2N=2T0TRdP08XY7@1o8aL0N20E07HO5`1d8AT0
JQTB070R6`1U6180I1XE06@L6@1P5AH0IaHH06P=4@1c2@/0WAlQ0=aCD@3LCDD0fe130==FAP3<GTh0
UCT/05`<101B2PP0D0d;054:2`1I3P`0HQP=06@Q301lAQh0_IED0=ZnK`2^VTT0MVPJ09bCC`3Nej80
k^W70>gXeP3[i^80i=oR0=7<dP2e/KT0VIBL06e[L`1;C5H0A4MD03i1D`14BEd0Ce=Z061RN`1DDf`0
>CI:02dW>@0Z8C40<2Hd0;Ra^@3bkO80hn7T0>7Qh`3Qgn80hMcP0>SQiP1XH6L0G5IJ0>3Kg@3[j>T0
h^7O0>7PgP3RhN40hN3Q0>7Qh@80h>3P00h0gn3P0=kPgP3Mgmd0h=kO0>CLg`3egN<0^GV20;EJI02m
C5D0]dA80;iKEP2RFE80VWQ_0?oek1[ooooo0`3oP0050:0Pl2@0oh0000<0d51h0:0Pl02P8?00202P
8?000`3oP000X23`0:0Pl00<0:0Pl0050=1@N03oP000oh000?n0003@D7P07`2P8?000`3@D7P0X23`
0:0Pl0040:0Pl080d51h0`3oP0000`3@D7P0oh000?n000060?n00080d51h2`2P8?070?n00080d51h
403oP0040:0Pl0<0oh004?ooool000kooooo0400ooC_0;^CR`2VE4H0d6EC0>5VE03HGTT0dfIB0<1Y
F02WLF/0f;6f08mVKP2VLGL0c92B0<J7PP2LIU`0f;>Z0>;>a`3Ld=00c/S<0;2[/@3bk?H0]jnn06=L
K01[IWX0HEic05YGK@1JF6h0G5Y`05eKL@1QGg@0HV=g06=TMP1[JW`0Kfam06iZN@1hLX00OG:207]_
O@1cIW00E4M@0;f]]`3linh0m/k@0;mjJP37NeT0f9EP0?o1O`3l^6l0lZEO0?6CEP3dR5T0kGQG0=aZ
DP3GLUh0dh9a09aTE`1>:B00>BDL03DZ900^9b40<BTU02lX8P0^9R<0:RDQ0P0/9b<0@P0]9B80=BdZ
03`d<@11>3<0AS/g058o>`1[C4T0Wg9_0<R8R03]WYX0c6eW0==]H@3_Rg/0hh9_0=MdH@3@IED0bUY<
0<mKC03CGDl0ceU;0==MC`3BG4h0dee?0=1JCP3;ED/0a4m50;m=@`2lBT00/T<h0:Tj<@2S=S40XC4]
09l/:@2L8R40]S8`0=E>BP3FCDD0edm30==?@P3@D4<0_T@i0:</902N9b40X2TS0:4Z902^=B/0_dli
0;eK>02aI300l/5e0?OGPP2YT3h0SWha0=O>R`3/i[80gmZj0<C1/02DT8l0IfA[04]8D@15A4`0BTM@
04U9D@0o@TT0?3m603/nA`80>Ca501H0<c4l02`Y=00b;3P0;BDb02lS<@0W6BP0ShF>0?K_mP3Uh>@0
h^;T0>;RhP3[jNX0Yj:S06EPI00m>CX0]k6c0?C^l03[iND0jN?S0>KRh@3UhN00hn7R0P3Ogml03P3M
gmh0gn7P0=kPg`3OgMh0h]cN0?GMi@2nP8/0ZE=L0;aAF@2hAd/0_EaF0:=JD@2JN6l0oo?[6_ooool3
0?n000D0X23`3P3oP0000`2P8?00oh000:0Pl0070:0Pl0L0oh0000<0X23`0?n0003oP000103oP009
0:0Pl0030?n0002P8?00X23`00h0X23`0`3oP00W0:0Pl0X0oh00402P8?070?n00080X23`4@3oP003
0:0Pl0<0oh004?ooool000kooooo05T0oo?_0;N<Q@2WEDL0dVME0>9YEP3HGd`0dVME0<1ZF`2fPG/0
`Y^N0;fBV@36TIL0`hR:0:Y`KP2ZNWH0l=??0=c=bP3Cb/l0^[Fl0=?@e`3/jO@0OGV806=PL`1QGW<0
CD]P03PfB`0a;dD0;be303LeB`13A5T0DU=X05EHJ`12@eD0=cU803@c@@10?4X0BdEA04a4C`0o=Cd0
J5mT0>[Oh`3diNP0o=cO0<nAQP34OF40ah=B0?ZjNP3o`WL0ljiS0>N=CP3aREH0k7aG0=EYC`3FMfD0
`GEW09m[H01oGUD0FDQ003he;P0a:R@0;BLQ034Z900_9b@0=BdZ02XU8@0/9b<0;RHS034Y9P0`:bL0
<RdY040f=017>3D0DSPg05hd=@1n@T80^Va/0;QIE@3BJf00oIb;0?n_W@3oZ9@0o9F40>eoKP3]OVd0
j7MU0=]ZFP3EI5@0g6UG0=YUE0020>5YF`0?0>A/GP3XKf@0hF]O0>1]H03EIEL0eFEI0<iND`3@GU@0
ceYA0==FD03KG5D0geaB0>=QE03MFDd0h5Y?0080fE=:03<0hUUA0>AKD`3QF4h0gEQ;0=INAP3@JDH0
/f<b0>FbL@3]c8D0b;5]0;ZZKP2_YG00RHIM06aZD@1HETX0AdE604]8C`1:BE40@T590491A`0j>Ch0
;c0d03<b=`0V9BX09bPZ02LW:@0[:Rl0;2X_02lZ<@0_9Bh0;1h]02<E902;OhT0n>kf0>GPi03ShN@0
h^;R0?Gem@29Q8D0j>CU07YfM`2]YjT0^[Bf0;J]/03Oe]L0jN?S0>_Ui`3Xi>D0hn7R0=oOg`3Lg]d0
0P3Mg^002`3MgMd0h]cN0?CLi033RY<0VTUB0<YQJ02^@4<0_EaE0:1HC02JN6l0ooC/01[ooooo0`3o
P0050:0Pl0h0oh004P2P8?060?n000P0X23`0`3oP00A0:0Pl080oh009P2P8?080?n00180X23`6P3o
P0030:0Pl0<0oh004?ooool000kooooo05D0oo7/0;66O`2[FDd0dVMG0>=ZE`3IH4d0d6EC0<E_H02h
Q7`0aYbN0>:h_037TiL0]X>209e]J`3Q^kP0i<o>0=kBe03>a<`0]k6k0?;_n02c[kd0EU=T05aIK014
@540O7R709ZFY02?RiT0T8bK0:FR/`1OG6l0De1U040mD01:B5H0ZJNb0:6NY@2VXJL0[jV]0;F_/@2h
/[@0d/W:0?7Yi`3`i>@0n^;R0>>_Y02bLUL0^WQ60>Z[J03oagP0nKYZ0=Z5@P3JMd00h7A=0=UaEP3>
MV80[FEG06lm=01jFE80QWE^07ieKP1NEdl0>S@^02dX8P0Y9200<2/W02dU8P0b:RL0<2PV02/S8@0a
;2P0<2/W03P^;00m;Bd0B2h_05X`<P1W9BT0OB@V0:@k>03/NG00nHUk0?jDQ03oUhL0oi:10?^=O03o
UH<0oib90080oij;05D0mI9o0>R3L@3TNVX0ggEU0=ecH`3LLV@0g7EV0=]jJ@3NPFl0iXUh0>V9N@3W
QWH0jHEe0>IjK@3aPGD0m7a^0?EiK@3iNFh0mG1W0>MNEP3_I5d0oG1Y0?5WG@3YGeD0hF9C0=IWD`3:
LE<0]G5<0;>7FP2GNd`0KU/a05e@;@1>BB`0A48]04i>@P1;BTH0ATI60491AP0g=CX0=38g03Hd=`0X
8bL0:bHZ02XX:@0S8B80:BTW02LW9@0Y:BT0:RX/02hY;`0Z8b/0<2@b02XL:`22MX00m>[b0>OQi@3T
gn<0j>KW0>WWj02KUYD0Qgio08ImOP37_/40PWUl04<m?`1HDU@0QGn10:^UZ@36`<@0f=?G0>7Oh03N
g]h0gMoN0=cNg@3MgMd0h]cN0?CKhP3<U9l0RSe70=A/M@2/?d80^5M@09eEB@2KNG00ooG/01[ooooo
0`3oP0050:0Pl0d0oh000`2P8?050?n000@0X23`3`3oP0060:0Pl0D0oh003`2P8?020?n002H0X23`
103oP00F0:0Pl0/0oh000P2P8?0=0?n000<0X23`0`3oP00@ooooo`003_ooool0H03olN`0ZWmh0:QF
B`3DJET0hfYI0=IMBP3CIE@0`VUG0=>IS@2[OWT0`iND0;R;QP2YOWP0ZXN10>oCd03Pc/h0e/[>0;jc
^`3Qen00k^Ka07ihQP1KEfP0DTeQ03/gB032^l/0k>Cb0>KPk03`j_P0em?R06MSM01;AUX0920a0:RU
/03hloX0jnKZ0>cXj@3/i^H0kNOW0>oYj@3`j>H0knOU0?;ViP3kiND0ml_20;9jH@2cLd<0eIIC0?k7
M@3l_fh0g8a50<a/<P3NMdh0eg9D0<efHP2[IET0ICD[058a:P1IAT00MfaV0968P@1hL6T0AChh03@/
:@0Y8Ah0:20M03<[:00_9bD0;bXW02dX900a;2P0=B/Z03h/;0149bT0EbHZ06<H7@1l71h0aeED0>U]
I@3/LVD0j79T0>]eI`3YLF40kWUX0>]jJ03`QG<0m8ej0?FBO`3oVXP0oiR70?jDQ03oU8@0ni610?fC
P`3kUX@0niZ60?fQS080ojJD03d0oj:@0?nKR`3mUXL0nH]l0?=mK`3`M6P0jFUN0>mYH03/He/0k69H
0?9UG03YGeD0j69G0=]VE`2oHU00XEU308YG?01/B2h0DC`Q048f7P16?b`0@clc03Xj<P0n?S`0>3Xi
038b=00c<SL0:2L/02LU:P0/:Rl0:2<W02TT:00Y9BH0:BDT02HU8@0X:B@09BDS02<S8@0V92L09AhV
02hR<00/7Rd0NFeg0?G[l`3Vh>@0i=oS0>k/k@3KfMX0RXB408V1O`23NGX0cLC70=?:c@3Bc<h0^kFg
08R2Q00/9RP0?SPj09^EU`3Xi>D0h^;R0080g^3O00/0g]kN0>;LgP3cf^80dYfW08Dh@P3ILGX0[3m2
0;]LEP2IDdT0Wgie0?oek00Jooooo`<0oh001@2P8?0=0?n000<0X23`1@3oP0030:0Pl100oh001P2P
8?020?n00080X23`0`3oP00d0:0Pl0<0oh00602P8?0>0?n00080X23`2P3oP0030:0Pl0<0oh004?oo
ool000kooooo02@0oo;^0;:7P02VE4T0eFMJ0>I[F`3MH4h0f6EB0<m_F@37QG40Q5E507aEA02XQ7@0
[I200=>k[`3Kb<80j]SH0<jn`@3<^l40n>W`0<c1b@1NEV40H5U[059=H@19A5X0Lfj2081iR`25OY00
RhBF07M`PP1KE6H0>C9204DoC@3TgnH0kNO[0>WSi@3Zi>@20>cSi01O0>gTi@3ai^X0lnS/0?KWk03k
iNL0om[C0;b:L`2fMd/0a8A40?_4M03k`Fl0hI=;0<e`<`3MN4`0egAE0<igH`2VHE80IC@]05@c;P1=
>3D0CChk05]=BP25NWH0T8F106iUH01?B480=RlY02XU7`0W8Qh0:bHR02`W8`0_9b@0=BXX03hX:P16
8RH0EA`R06D@5`2C:Bd0gF=R0>iYHP3bKV80kfeP0>aZG@3^JUd0kFUL0>e[G@3]Kf00jW5P0>adH`3^
MVH0kG=T0?1fJ@3dNVd0m7a^0>ihJP3bOfd0m8Ac0?R=N`3hRWT0mhUh0?V;NP3iRG/0nXIi0?ImLP3b
MVX0lg=X0?EaI@3eK680lfUO0?9XGP3^I5X0k6IK0>=UE`3>J5X0Qcla068a8P1?;b00Ac@V03dc9`0c
;b@0;b`U034`;00_;bl0:b`^02DY;00V9b/0:R/`02HV;P0V9S009b@_02PU;@0Z:2d0;BP/02`X9`0W
9R800P0T9B00600U9B<09bDX02XS:P0Y7BT0:Q`[089fP03ejo<0i^7U0>?Qi03`k^l0clk<07MaL@1_
IfD0OgMe0<Ro`02AR8T0/:NX0;2XYP37_kd0/JVW0<>j^`3KeMD0i>3Q0>3Ph080gMoN00/0gmoO0>;L
gP3cfn80dijX08<f@03JLW/0[d950;]LEP2GDdX0YXEl0?ofkP0Jooooo`<0oh001@2P8?0<0?n000@0
X23`1@3oP0030:0Pl140oh001@2P8?020?n000@0X23`0`3oP00a0:0Pl0030?n0002P8?00X23`01T0
X23`1P3oP0000`3@D7P0oh000?n0000A0?n000<0X23`0`3oP00@ooooo`003_ooool0H03omo<0aIjG
0:9BB@3DJ5/0iVQI0=iMBP3KHTd0e6aC0<n4JP28ECX0NE@i0;fOQ@3JaK00g<bm0=c=aP3Te=D0bkRl
0>WDf@3A_/@0e/G=05U=E`1:@U40DDYL04m7G01HD6L0GEIY069KK@1TFfh0G5=V04i5EP0V7R/0ZJ6/
0?C]m03Zi>P0jnGW0>cViP3]i>D0knKW0?3Wk03/hNT0knC/0?7Qj`3af^00on3J0<RJP`2iO500^WXl
0?JnL@3oa7<0iIM=0<U_<@3KND`0dG1@0=1kIP2NFTd0Hc@/050a;P1;=S<0CChk04Dg=01CAD80LVMS
0966PP2AR8<0NG9/05E@BP0k<c00;RTU02XU8@0]9B80=RPW03hV9P167200E1<I06X>4`2^?Cl0jFUV
0>mWG`3dJUl0lfUN0?9XG@3bIE/0mFQN0?5WFP3`J5X0lFaM0?9^G`3cKf80kFUL0>iZG@3]JE`0k6YM
0>m`H@3YJU/0kW5R0>]aHP80kG9S04X0k71T0>]_H`3aLfL0lW9W0>m/HP3eKf@0lfYP0?AZH03cIUd0
lVEK0>mRF03WHED0hFIG0<QYG@1^<RL0AB0G03XV7@0^8ad0;2TT02/Z:00V9RH09bH[02TZ;`0R9B`0
82@]020T;`0T:3<092Lf02T[>P0W9SH0;B`i02`[<`0Z:2d0:RPY02TW:00V9B<09bLU02LW9`0Z9BT0
;RL^02XN:P0]7b`0Sh>=0?O]m@3Uh>@0i>;S0?;ak`31_K`0KVUX06EMF`2ESH/0d<O806MNG`1CBdT0
=2`Z07adLP2]YJ<0`k^i0=kHf03Th=l0gmoO0=kNgP3Nh=l0h=kO0>7Kg@3cfn80e:2/088f@03JMGd0
Z3/n0;1CCP2HED`0/9::0?oeka[ooooo0`3oP0050:0Pl0030=1@N03oP000oh0000T0oh002`2P8?0B
0?n000D0X23`00<0oh000:0Pl02P8?00102P8?040?n002h0X23`00<0d51h0?n0002P8?006P2P8?06
0?n000040=1@N02P8?00oh000?n000<0X23`3@3oP0030:0Pl0<0oh004?ooool000kooooo05800?l0
0=Vh/`2NE4/0cVAG0>MYF`3PGD/0g5m90=a]DP3AOEh0ZW9?0;bFLP3A]YP0iMFl0=c@`P3Uf]H0bk^l
0=W4b`3C^/00R6me0>39d@2hYjl0D4A@03P]?@0a:3T0>2m2040gB@11>DP0@SM7040e@`14>TD0S8:;
0?3VkP3cj^l0lNS]0>oVj@3^iNP0kNOY0?K`m038`LT0SXJC0:BGZ02GRIP0]j>/0?oTg`3<WhX0^giA
0;Ed=03c^V/0olAc0>NIC`3@MSP0f7M:0<iaD039NfD0TUA705H[901<<2`0B3Hb04Pm=`18?CT0AS/h
044f=01DBDL0K69P08QoNP2DSHL0Q7]f06ENF016?S/0=bd[030P800k8B80B1/N05HA501h61X0beAF
0>YVHP3aIEd0lFAJ0?9XG@3_IEX0lVII0P3dJ5/0F03`IUT0lfYJ0?AZG@3_Ie/0lVYN0?1VF`3^I5L0
kfEJ0?5YG@3^IUX0l6UM0>aVFP3[IET0kVQL0>]UFP3ZI5T0kfIL0>mUF`3/HUP0kf9I0?1QF@3^H5H0
kUiE0>]KD03[GE40j61D0=mQD`3=KEh0JRhS03dH400d8A/0;bLT02TX9P0V9RP0:BX^02HV;P0Q8bl0
8BLc01dT=00Q:3/0:c=802T_A@0b=dd0>C]B03LiBP0U9c<08b<[02HU:P0[:Rl09RHX02LW:@0Y:B/0
:bH/02TR:P0`8bd0;1lY09R<UP3fkoH0iN3T0>CRh`3elO00ZjNV075/K01`J6H0Xi^I0>OQh@3Idm<0
fmKC0;bg]01eL6d0<bd]05mIF@33_kh0inKT0>3PgP3Ogml0g=kM0=kLg`3Rg>00l]cS0=RV/@26?TT0
e7=j09hf=`2]DTd0UeM>0;RKU@3omo<Jooooo`03003o003oP000oh0000D0X23`00<0d51h0?n0003o
P0002P3oP0090:0Pl1<0oh00102P8?020?n000P0X23`103oP00]0:0Pl0030?n0002P8?00X23`01T0
X23`1P3oP0000`3@D7P0oh000?n000050?n00080X23`2P3oP0030:0Pl0<0oh004?ooool000kooooo
05T00?l00>K9a@2OFE40cFMK0>IZGP3RGDh0h5m:0=mYC`3DNUT0_89L0<VRN`3PajP0fl^b0>[Nd03N
dL/0a[Jg0>_Fg@3H_LH0bjnk0>;;e@3hi>l0gLgJ0;FX^@2UVZ/0XYV/0::HZP2PUJD0Zj2^0;b`_03>
`/`0knC/0??Xl03PeMd0hMKN0?3Wk03cj^l0l^_b0?Kan02LUZ@0Lfal07ibQP1OD6<0b;C00?oPg03:
VX@0_7eA0;Ie=@3c^6X0ol5a0>RJD03AN3`0fW]?0<YaD@36OVP0Pd/n04/V7P18<2`0B3Td04@k=P1;
@Sd0@3Lc040f=013>CL0B3hl04]2?@1WGUT0PGQc09F<Q`2<PX00N6e[05]9A`1?<C40DR0Q05D=3P28
8B80fEmN0>mZI@3`HeT0lF=I0?5TFP3aIe`0kf9H0?AWG@3bIE/0l6=I0?=VG03bIE/0m6MN0?5TF`02
0?=UF`040?5TFP3dIed0lVEK0?5TFP80m6MM00T0l6=I0?AWGP3_HUT0lV=K0?1QF@3_GeL0lF5I0>iN
E@3bGeL00P3_G580@03]GE80jEmB0>9RE@3>K5h0KC4V03dK4P0f9200;bLU02TY:`0W:2d0;blg02T[
=`0Y;CT09bdm02T`@`0g?eH0?DAN03]2G00l@U`0>cmH03PlC`0U9c@092@^028Q:@0Y:2h09B@Z024P
9@0Y9b`08A`S02@J8`0X6bD0<2<]0:2DWP3dkO@0i=oS0>GSi03cknh0WIVH07IaL02=QhL0/:NX0<k8
b02i/k<0d/[80<W1_`31^;T0_;Jf0=[De03Sgmh0i>3O0>;Qg`3Ph>00gMgM0=gKgP3Rg>00l]cS0=JW
/@22?4H0eWMm09Xf=P2YE4d0TEE;0<6UX@00o`0Jooooo`03003o003oP000oh0000H0X23`803oP000
0`2P8?00oh000?n000040?n000D0X23`0P3oP00;0:0Pl0@0oh00:P2P8?000`3oP000X23`0:0Pl00I
0:0Pl0H0oh0000<0d51h0?n0003oP0004@3oP0020:0Pl0<0oh0000<00?l0ooooooooool03_ooool0
00kooooo01L00?l00?7Ie@2ZJF<0aVEL0>9WG`3PG4l0ge]<0>5XD`3FNE/0/GMB0<fWP`3G_Yl0dl>Z
0>GEaP39^[<0hLo?0>[Eg03?]l@0Z92P0:^DYP2XTjH0XHnU0:2BZ@0209V=Y@1509J9W`2GRYh0WI2R
07mcP@2HS9P0l^K`0;2T[P23MH80Q7R40;:X/@3`jO40n_Cn0<W6d@1aKGh0LVf106MNL`1@@eL0jmCR
0?oGeP38Sg/0`WiA0;mj>@3j_g40oKi^0>6AB03JP4@0dgI;0<YeF02lNFH0MdDj04d/9@18=Bl0?c@`
04<k>019@Ch0@SXg03`d<@11>CH0ACdj03hg<@13?3H0A3Xh05U?C@1^H5d0S7Yh09MoO@2BKfd0S5AC
07la;`2S>cP0iFYU0>]UG03`HUP0lVAH0?=WFP3]H5H0lfEK0?9SF`3cI5`0lF9L0?5RGP3cI600lF9N
0?AUH@3_H5X0lF9J0?EVGP3`HET0m6EM0080lV=K01`0lF9J0?9SF`3aHUX0lV=K0?5QF@3`H5P0lEiF
0>mLE03bGeL0keYC0>mKD@3`G580keaB0>QND@3OGe80dFmQ07<g;@0m6Q@0>2HT02dW:@0^;C<0;Bde
02`/=P0_<Ch0<CA303XoDP11AUX0ADUR0P13Af00;P0oA5X0?D9H03LiC00R934071XW01`J9@0N72L0
8b8Z01lL8`0/9bh0?SLn05=9DP1]H6X0H5=M09nCW@3cjO40hn7V0>;Ri03bl?40OWYi0<2j_023OGl0
clW90:BNWP2WWYl0e<[;0=O;c@3Ib/d0gm?E0<c2`@3Fc/`0i^;Q0>7Oh03Ogml0g]kN0=oMh03SgN40
lMcR0=>Q[01n>400dWQj09Pk=P2VF4`0ReE90<B]Y`00o`0Jooooo`03003o003oP000oh0000H0X23`
7`3oP0020:0Pl0H0oh001@2P8?020?n000d0X23`1P3oP00V0:0Pl0030?n0002P8?00X23`01L0X23`
00<0oh000:0Pl03oP0006@3oP0020:0Pl0<0oh0000<00?l0ooooooooool03_ooool000kooooo01H0
0?l00?k[i`2aMW00_69I0=eXG`3QHEH0gUm@0>9[E`3BMe`0^7mQ0>BmWP3WcK80h<jh0>GDa03VeLd0
g<[80>oLh01mJGD0G4MH05a9G01D@eH0D45F0P1<?UD0CP17>e40B3Y@04e0DP1?@U<0:al]0:bP[03f
j_@0OG5k065CH01ZGVX0FDmJ0=cDg`3cl?/0T8bK06=PL`1VHGL0@3I>08n0U@3khNd0m/?00<B3K@2n
MdT0c8M60?o2M`3k^F/0fHI00>:5C03?LdX0aGAG0;MhIP1[?c@0C2lY04Tg<`0l<S00?CPd03lj=P12
?CT0?STe03Td<00j=C40?3La040i<`0m=C80@cPf04@f<`1<>CD0Id]808QLF`2ZJVP0[EQE0<MLEP3T
J600k6IK0>mREP3`HUH0kf=F0>mUFP3]HeT0kVEO0>YUH03WIF<0ifMX0>ETJ03XJ6T0jFMY0>aVI`3Z
HV80jf5O0>iSH03/HEh0kV=Q0>aRH03]Hf40jf5N0>iSH03ZGe`0l69P0>aNG080jeeK03L0je]J0>iO
F`3]G5T0jUUD0>eNF03WGE<0hF5F0=1]HP1h?380?AXF03h/;00b;300;B`b030`>00`<3X0=3A0030b
@@0j?Dh0=cY=030aAP0b<dP0=3M:02P[?P0U9SP07al_02@R;`0^:cH0@Sm805YGH01[J6l0LFac07E^
M@1gL7L0M6Yb06AGH@0h:cD0XYJP0??/l`3ShNH0hn?U0?Kdm@1lNgT0Ee9D08^7R03fl_<0QX20069I
FP1ODeD0Ge1C061@D`1SDeH0A3Ph0;Zb/03]inL0hMoP0080g]kN00/0h=kQ0>;LgP3ag>40d9nU084l
@@3;LW@0Tc`e0:EPD@1oDD80cKZd003o000Jooooo`03003o003oP000oh0000D0X23`00<0d51h0?n0
003oP0001`3oP00;0:0Pl0<0oh0000<0X23`0?n0002P8?000`3oP0030:0Pl0H0oh001@2P8?030?n0
00l0X23`103oP00V0:0Pl0030?n0002P8?00X23`0180X23`1@3oP0020:0Pl0H0oh0000@0X23`0?n0
003oP000oh001P2P8?0:0?n000030:0Pl03oP000oh000080oh0000<00?l0ooooooooool03_ooool0
00kooooo05`00?l00?odlP2kQX00]69G0=M[G`3VK5l0eee>0=m`G@3>NV40_HM_0=B^U`3I_JP0glRh
0?;Od@3?_[@0akRc0>GGe`22LgX0NVeg07IXM@1dIWD0LVId07EXN@1dIgP0Kf9c06aNKP1YFfX0Cd5>
075UK`3ai^h0no7i0<6g_`1]HVX0E4QB07A]M@3/i_00a<3>06UVM`1WHWP0EdmV03daA`3FaML0o=kX
0>JWX036OVD0^7910>BPH@3o`gX0nK=[0==k?03NOT/0cW9=0<MgG02_MF40I3``04P_:014=C00@3Hd
03hf=010>3H0ACdj04@m=`0m=C80>c<`03`d<@0k<c00>C4^040f=012<c00Ac8_058`;`1K:BP0JAlN
08X/:P3DHE`0jVYQ0>YTF03bIEH0kf5C0?5UF03]IET0j6EM0>EZI@3KJfT0_EEF0;9?E02aD5T0/U5J
0;aDG@3BGV/0g61[0>ARK080iV=[00L0hV1Y0>=QJ`3SHF/0hf5Y0>=PIP3VH6L0iV1Y00<0i5iW04@0
if5Z0>IOIP3XGfL0ieaS0>MLG`3XHEh0geiH0=5^H`20A3X0?AXF03l_;`0b;3009RD[02XZ<P0X:300
9RH`02@T;P0W9c<08b8`020O;@0[:SP0=3A003`lB01:B5D0HEiX06mZL@1mMWh0PW^207YcNP1/If/0
Ee5E04e7B`0k=CT0=R`d02hT;@0Y7bP0]Zng0?7/lP3ShN@0hn?S0?;blP2h^;P0@T110=3?c@3^kN/0
dlo>0=_Ee@25NgX0/:BV0=72a@3>_l80Z9bL0=K>c03Xi><0hMoP0=kNgP3Mgmh0gmoO0>;LgP3cgN40
biRM08@o@P31KF/0TT8i09UNCP1iE4@0e/O0003o01[ooooo00@00?l00?n0003oP000oh00102P8?00
0`3@D7P0oh000?n0000@0?n000030:0Pl03oP000oh0000<0oh0000@0X23`0?n0003oP000oh00102P
8?060?n000D0X23`0`3oP00A0:0Pl0030?n0002P8?00X23`02D0X23`00<0oh000:0Pl02P8?003P2P
8?050?n000H0X23`1P3oP0000`2P8?00oh000?n0000A0?n000030:0Pl03oP000oh000080oh0000<0
0?l0ooooooooool03_ooool000kooooo01L00?l00?ogm03;WYP0[F=H0<iXG03PKel0hgAS0=9]F`2j
L5h0hkFV0=no]03Oa;d0gLW20>GDc@3Pd/l0i=SH0>OLh03OeMd0h=KQ0=kDg`3LdMl0gmCT0=cAh@02
0=kCh`0W0=g@h03Hbm`0b[k<0=36d@3UfnH0gmSP0>KOi`3KdM`0clOB0>WSk@3^joH0R8BE06=NLP1V
GWD0=2Pn08EdQ`3oioL0oMCH0<j9N@39OE/0_GM30?ZiM`3o_gP0l:EQ0=Uj@P3FM4D0dGAB0<AhGP2V
Ke/0GcT/04/d;P14=C80@SPg040h=P0n=S@0@SXg04Dn>015?3L0?cHa0080?CDb04`0>S8_03`b<010
<Bh0Abl]058[;01K8b@0JALI09Tc<@3NIf40kFYP0>mWF@3`I5@0kf=D0>eUE`3YJEh0gVMO0>9iM@2T
C4X0YEUK0=RBVP33OhX0]Fil0;9TLP35J7/0/daO0==WMP3GJgP0]dmJ0:]6D@2S@Td0ZTIB0:U5D@2]
Ae80[4A?0:m7DP2iD5h0]TeK0;M>G02eC5X0_51O0;i>G030C5T0bE1I0=MJGP3OHf40dVmW0896?00m
6QH0;alO02LQ9@0S8RP09RH^03<c>`0f=3l0@3i904i<F@1MFfP0HEm]06m]N`1gMH80OG^607=`N`1V
HVX0DTeA04M1A@0l=SP0<R`^034[;@0/9RP0;RPZ02hX;00/9RX0;R@/03H_=P3;a/`0k^c_0P3Rh^82
0>GUi@0J0;Vi^@3UiN<0i>?Q0>cXi`3mmO<0N6i]06QLG01oL7<0N6a^06iTI@3Ldm@0jNGV0=kNgP3N
h=l0g=kM0=kNgP3QgMh0m=gQ0<FAU@29AD@0^6MS0998?@2AG4`0QFEF0>cRf@00o`0Jooooo`04003o
003oP000oh000?n000@0X23`00<0d51h0?n0003oP0006P3oP0030:0Pl0H0oh001P2P8?020?n001d0
X23`1P3oP00G0:0Pl0030?n0002P8?00X23`00T0X23`103oP0000`3@D7P0X23`0:0Pl0090:0Pl1l0
oh0000<00?l0ooooooooool03_ooool000kooooo0P00o`00SP3J/j`0YfEI0<Q[G03HKe`0k8Me0=5h
J02`MF`0j<S907iYKP23LWX0QGR108f1R`27OHH0UhnJ09F=VP22O8X0PGf<07ahR@1oN8X0OGF:07Q_
Q01jLHH0OGB907]bQP1fKX<0MVn107mhRP2;Q9H0QWnA08N0TP2?R9P0V96Q0:FQ/P2HTjL0KVIm06]Q
N@1GBF00?2Tm0=Nnd`3ognd0k[Nd0<n4I`2oLT@0f9QJ0?o1N03j]6`0hHi<0=]g@`3LMdd0d7EF0<Un
I`2HHe40FcT]04hf<P16>3L0?S8b04Lm?P0l<S40@CPe04Ho>@15?SP0@c`d044j=00n=c40>c4_03/`
;P10<Bh0BBl`054X;01O8BH0LQTK0:Xn?03UJ6@0kfUP0>iTE`3`I5D0jf=E0>YXFP3OJEl0fG=^0<Mc
L@1a=3<0cInQ0?oNi03le=d0n]3N0?oDi@3XYKL0UT]O0<5ePP2;@dl0WV9Z0=^X[`3?X:H0bINP0<>A
VP2oS9<0/Wn60:UdO02ZMGl0X6]e09]SKP2JH6`0UUQU0:9KJ`2YF6L0]5IT0:i4CP3@GUh0cVeX08Y>
AP1L>CD0G4Y:05iHFP1PGfD0IVI^06e`N@1aLGd0Kfil06i]O@1^KGl0G5]]059AH`13@540@3i<03@`
?P0_:c<0;b//02/W:00Z9RD0<Rh]02dY:00^:RT0:bLV02`X:@0Y92P09R0T03hh?03IemX0k>c/0>7Q
h@3Shn420>7Qg`0=0>7Qh@3Thn40i^;Q0>7Ie`3_hn<0c;jm0;BTY02aXj<0ZinQ09:9RP3SgMd0i>;S
0=oOg`020=kPg`0;0>3Ph03SgMl0m=kP0;V1Q02FCdd0Z5QA0:1HC027EdT0W89e0?kel000o`006_oo
ool2003o0080oh00102P8?0N0?n00080X23`1P3oP0060:0Pl080oh007@2P8?0I0?n000@0X23`00<0
oh000:0Pl02P8?000`2P8?050?n00140X23`7`3oP0000`00o`3oooooooooo`0>ooooo`003_ooool2
003o000A0>W8`@2QIe`0ag1O0<mZF03ZRgT0^V]L0=2QV`2aV9h0J5QS06YLJ`1XGFd0KF9b06MOKP1^
IWD0K6Id05iJJ01PG6/00P1QGFh0K@1NEV/0H5M/061GK01QF6d0HEU/05aEI`1MEVP0HEY/06IOL@1Z
IWL0IV9c06=OL01UHWD0J6Ej06MRN@1WGGH0JUYd040Z?`2CM8H0omSX0?_6c03ESgh0bWeC0<Al@P3i
^W<0ol1f0>nQF@3DMcX0ggI60>1hD`3FNeh0agmW09ETD`1E=BX0BcHa04Dg=P11=CD0AC/l040f=@12
>CL0@3Tc04Dn>01:@c/0@3Ta03L`:P0o=S40?S<_040a;P16;2/0DbH[05lN8P1i7B00_Ti<0>a]I`3[
HUX0lFEH0?1UEP3ZIUT0i6YM0=M_IP3=N7D0VEUI08QNG`3ig=h0mMcP0?;Hh@3if^T0omW[09UTN02B
FFX0R59P09EWL@3jfN00nMoV0?ONi03hgN@0nmgU0?oNi`3ngNH0nmcT0?OIh@3bemh0lMKO0?3Bg03e
dMl0ml_L0?o8fP3o_Ld0YdMC0<9DE`3<KFP0STm8068o>`1/FUX0GeUM05=CF`1<CeP0@dEA0412D@11
@UH0?CiB03PiC@0j>dl0?3]=03XgB00h=T@0=34l038^<`0[9bH00P0_:bX0300]:BH0;2PU02l[:P0/
:2L0:BDV02/U9`0Q6al0E4mC0>GSi03Xj>P0hN7O0>?Sh@80hN7O01P0hN7Q0>g/jP3Idm<0KfEV0<6c
/`1nKVh0RWYj08alO@23MgL0SXF60>gYj03Rh>40hN7Q0=kPg`3Ogml0h=kO0>GLg`3eg^40ZFi`0:EK
FP2ZGED0WUiB07eFA`35/JH2003o01[ooooo0P00o`020?n000<0X23`1@3oP0000`2P8?00oh000:0P
l0020?n000d0X23`00<0oh000:0Pl02P8?00102P8?000`3oP000X23`0?n000050?n000L0X23`0P3o
P00L0:0Pl1X0oh00102P8?000`3oP000X23`0?n0000I0:0Pl1h0oh000P00o`0@ooooo`003_ooool2
003o000C0?KJeP2TLVT0`6eO0<a[FP3MP6h0X5A40<jWWP1B=c`0IU5J05a<E`1ODU`0G51J05]AFP1J
D5T0G5EM05QAF@1HD5/0FE5L05YBG@0205]@GP80FDmJ07D0GEAO05M?G01FCU/0FU9O05]CH01KEF40
FEIQ05QFI01HEFH0GEU`061HL01WEg40FT9J054`@`3W^L@0kjjb0=Z@Q`3BPf00b8970?>`JP3j^6`0
mZaS0>bBD`3KMT00hGA90=mdDP3DNE`0cHE]09EVE01A<bP0BCH`04Li>016>SX0@3He04Dk>P13>SP0
?cLd03lj=P12?CL0A3li03`g<@0l=Bl0>C0[03h_;015:BP0DbDX05XE601l7Ql0d5iM0>YYI03_IUh0
kV9E0>mWF03WJE/0gVmT0<meK@2lN7L0LT540<b_/`3lin`0lM[P0??IhP3ngnh0h[c;08=@H@2LJGP0
KDE@0=o0b03nind0lmgV0?GIi@3menH0n/kM0?;2cP3da]40ll_F0??Dg03fgnL0lMgV0?3Ki03efNL0
n=KV0?oDi@3f[;/0USI20<UKGP3@KV/0PD8m04`Y9`10<3<0>3<j034a?@0c=D80>3]<03/mDP12A5/0
BD]R04E7G011@UH0@D1@03`jA`0a<3P0;R/b02h[;00Y9B80;bXW02hY9P0[9b@0:RHS02TU900^:2P0
:R@T02`V9P0Q6ad0HEeN0>cZj`3Ti>@00P3Rh^801`3Ri><0h>;Q0>;RhP3Xi^L0gMWJ0;>Z[@3Fb/`0
0P2ZVY/04@2XV9T0S82009ZDU03bk^d0hMoP0=oOg`3Ph>00h=kO0>7MgP3Uf]h0m]_Q09=HG02ZI680
Y61E09INC`25IEP0j=[?00800?l06_ooool2003o00<0oh000P2P8?020?n000030:0Pl03oP000X23`
01P0X23`00<0oh000:0Pl02P8?000`3oP0000`2P8?00oh000:0Pl0070:0Pl080oh006`2P8?0K0?n0
00@0X23`00<0oh000:0Pl02P8?006@2P8?0N0?n000800?l04?ooool000kooooo0P00o`00S03njnL0
XGI_0;5WFP3=LV00afYH0:]HAP3V/:P0WW9c08iWK01V@dT0HD9705Pk?`1A=cX0BS4d04lf>@1<=cH0
BCDd03h[9`11;b/0AS<_04Td;`1;<bl0CSHb04de<P18<300AB`_04@^<@18=3H0AcLj04@i?@18@T`0
CD]I05A?I@1NDVX0IeAZ044U=02OMgl0kKNe0<=jJ`3BPF<0c7i80?ZgL@3o_W@0mZaS0?FPG@3]R500
lhAF0>ajE@3JKdl0cgAI0<^4KP2YO6T0Ec/]03`Y8P10<Rl0@cPf040f=017?C`0@3Hd03lg=00m>3@0
@C`h04<n>P0o>S@0>c@^03T`:`0o<2d0ABTX05LV:@1J51H0QRLU0=QUH03/JfD0kFAJ0>mUF03/IeT0
hfeQ0=9`I`3?PW`0TUaL085NHP3gh^L0lN3V0?3Ki03ff^H0omg]09ieQ@2<GFd0O51M08a^MP3jiNX0
ln3V0??Li`3of^/0l[_>0;EeQP2THW00Zfeh0:5_NP2DL7X0j=7I0?7Pj03^f^D0l=SU0?OGiP3oe><0
_fim09Xd?`3JIfX0dFi[07m0>`1E<C40@C0f03li@`0f=D<0=SQ703XmD00k?E80?CmF04Y<H`12A5T0
A4EG03Lg@`0];3@0;Rdb02HT9`0Z9bL0:RHS02`X9@0]:BH0:RHS02PT8@0U7al0:bDU02/R8`0d:b`0
81XL06iZJ`3bl?40i>CT0P3Rh^803@3Ri><0hN?R0>7Qh@3Rh>40iN7R0?K`lP3>`lL0O6e`09F7Q`2D
R8X0Ng5b0;6[Z`3^kN/00`3Ph>002P3Ng=d0hmgO0>KJgP3cemd0TEUJ0;9aK@2LH5D0RE]<09J0L`3l
ln`2003o01[ooooo0P00o`030?n00080X23`1@3oP00H0:0Pl0030?n0002P8?00oh000080oh0000<0
X23`0=1@N02P8?00202P8?020?n001X0X23`7@3oP0030:0Pl0030?n0002P8?00X23`01P0X23`7`3o
P002003o013ooooo000>ooooo`800?l008l0P?]k0=k5`02WLFL0_VmR0<e[G030EdT0jX]n0>>9P03U
SXL0iiJ@0>BGTP3OUHh0gYJ<0=bERP3PWHh0gIn=0=^TS03JZXX0gk:>0>>gT03M[hH0dimg0<jHL03A
UGD0diIl0=BHP03EVhD0e:6@0<RQTP30YYd0iMKG08EkQ@1BAEP0HU5U04lf@P1cDU40ikbY0;J0G@32
P4d0eHm@0?:bIP3h/FL0l:1K0?>GF`3aR5D0lWiE0?1gE@3VK500gg1G0=9fG`36P6/0VfiK07QMC`1h
IU`0J5]E04a1?@0m<Rh0?C8_040e<P16>cT0@cXh04Dm>P14?3T0B40m03le<`10=C80@S0^04LZ:@1D
8R@0H1XI09Lg<P3NK6<0jFUN0>iXFP3/IUL0ifUL0=QaI`3?OWP0Y6YY07EBE03Pb/h0m>;X0>oMi@3c
g>T0o=o]0<VP/P2;H700Qem]07IEH03Ud=L0ln;X0?7Li@3if>P0l;W>0:YEJ@30Gfl0dgAo0<mnQ@2V
JW40NU5I0>W?f03dh>T0kmOT0?CEi03oenL0gIZY09di@P3AFel0gFIR0<m_J01g>cP0DRl`044`>00l
=400>CQ503XlB`0g>DT0=CM903loD@13@e@0?C]:03<b?00Y:2h09bHY02XY9`0V9B809bHR02PW8`0Y
:2H09bHT02HU8`0Y9B@09b4Q02TP8@0_9BH0<2HY028K7@2BSHh0m?;c0>CRh`3Shn<0hN7Q0>;RhP02
0>?Sh`0:0>CSh@3ThN00mo;c0;^d]@1bJ6X0/JNX0;V`/P2OVIT0bLS60>KVi080h>3P00X0g^3O0>3N
g`3Vg>00jMWM0>[<d01kATD0]7ef08UMCP20HU<0bkff0`00o`0Jooooo`800?l000@0P<000?n0003o
P000d51h1@2P8?070=1@N100oh000`2P8?000`3@D7P0oh000?n000020?n000030;Ph]02P8?00X23`
00L0X23`103oP0000`3@D7P0X23`0:0Pl00D0:0Pl0030=1@N03oP000oh0000P0oh0000<0d51h0?n0
003oP0000`3oP0020=1@N0030:0Pl03@D7P0oh0000L0oh00102P8?000`3oP000X23`0:0Pl00H0:0P
l0`0oh0000@0d51h0?n0003oP000d51h3P3oP003003o013ooooo000>ooooo`@00?l008T0ilk70:=c
J@2jJUl0aV1D0>Q_I@3ZK600j6YN0>]aIP3WKV<0j71R0>MaH`3OKU`0hgIQ0=]eG03KOUd0fhIM0>>G
IP3^ZG00n;Ii0?NfMP3UY680chQ;0<Ai@034N4@0aGe=0;eoF02;GD<0e[JY0<Fa/P1GBU@0Ge5R04Xh
A01@>cP0l=6m0=2TO@3?Vf80o;ml0?o0MP3fZV00k99C0>f8DP3cQ5L0l7QE0?5aEP3[JE<0j6UF0>=`
G@3BMF<0bHEb08EGB01>=2L0DChg06]NF027O7P0S85m071UG`11=C00?34]04<h=014>cH0@cXe04Hm
>016?3X0@C<b044];P19:BX0EB8Q06LM6P2[BD00iG5T0>IWF03_JUT0jfIG0>A^H03BN6l0^gag06e4
@P3B^K`0n>O]0>gLhP3`fn@0o>3^0>2nc020DF40W71m06=2B`3G`<H0mnK/0>kMi@3df^L0oLoP0:iM
KP2lDF40gVij0=AdN037Ngl0OTa?0<b//@3liNd0l=[V0?7Ei03oe>L0o;_?09a1D035D5H0i6MU0=aU
G@39Kf@0Ic8Z04`]:`0k:bh0=Rlf03Dd?00l>TL0>CU503PhA00m>dP0?Ca403@a>00^;3409R8S02HR
7`0Z9b80;b`W02DR7@0V8ah0:RHS02HR7`0S7a`0:RDR02dT9@0[8R<0;B8V02XO9@0]8RP0`;Zn0>k/
k@030>;RhP0I0>;Rh03Rh^80iNGU0>SWi@1dKf`0R7im05I:BP1cIF@0VH^:08^0OP22N7H0gm[G0>KU
h@3Ogmd0h>3N0=kPg`3Pg]l0i]_O0>_Hg03F]kP0LT<m0:j4MP1gG4T0SH1_0?C`i`03003o01[ooooo
1000o`030?n00140X23`2@3oP0040:0Pl0<0oh00302P8?020?n00080X23`103oP00C0:0Pl0X0oh00
00<0X23`0?n0003oP000103oP0030:0Pl0L0oh0000<0X23`0?n0002P8?000P2P8?000`3@D7P0oh00
0:0Pl00I0:0Pl0/0oh0000<0X23`0?n0003oP000403oP003003o013ooooo000>ooooo`@00?l008T0
ooSd0<NYX@2IFe00^5iC0>AZH03bJEl0kVAI0?M]HP3eKEl0lf]M0?E`H@3cL5h0lG9O0>M_E`3TMEL0
hg]F0>:3E@3TSeT0jIUL0?BYJ03m]700okMc0?V/J03]XV40i9iS0;f3D`2hSFd0mMS808YeM01SCeP0
JUIQ03DP9@2NPgP0o]^o0>jkS03i_H40m[=_0>ZOF`3XSe00jX9?0?:1E`3_M5<0lG5F0>iZE@3aK5/0
ifEE0>1]F`3EN6H0aX9_08EJBP1A=bX0BCP`04Tn>01=A3l0Jf9M08QmN@26NgL0DdQ403hc;`0i;RX0
?SD`048i=012>3H0?2h]044];P1?;Bh0EQhO070R802aC4@0iFmS0>Y[FP3/JEL0jfUK0=e`I@3@PGX0
RUEA08e[JP3ji^P0lN;W0?7Ni03cg>H0omo/0:J0S`2BI740Ne5M08mdN`3kj>h0l^7W0?;MiP3df>H0
lk[;098d@P3HJG80fFYa0=QnP02NFU/0REmQ0?SMhP3cg^D0l=SU0?CEi@3oeNP0cgjA09P_?@3SIVX0
hV5L0=]VG034L640Hc4X04HX9P0j:R/0<bTa02dZ<@0b;cP0>cU403Xh@`0n?DD0?CY103@b=@0_:b`0
:2@S02HR7`0Y9R40:bPS02LT7`0Z9b80:RDR02LR7`0U81d0:28R030W:00a9RX0;B0W02TL8`0h;C<0
elkC0>k/k@030>;RhP0I0>?Sh@3Rh^00iNGU0>SWi@2MV9D0UXb;09B6Q@2PTHh0UXN408anN`2@QH<0
jnKS0>OSh03Qh=h0gmoM0=gOgP3Qgn00j=cP0>kIgP38YZP0U6UR09ihJ`1[FDD0Yj:?0?olm@03003o
01[ooooo1000o`030?n001D0X23`1@3oP0000`2P8?00oh000:0Pl0040?n000`0X23`0P3oP0040:0P
l0<0oh002P2P8?000`3oP000X23`0:0Pl0050:0Pl0l0oh0000<0d51h0:0Pl02P8?000P2P8?070?n0
00D0X23`00<0d51h0:0Pl02P8?006@2P8?0N0?n000<00?l04?ooool000kooooo1@00o`00X`3ii^00
YGU`0:5HC`3HIUd0l6YQ0>ePEP3dIed0nFeP0?Q/G`3dJe/0mFeO0?IbH`3_KU/0k79K0>IcEP3TMeH0
ih5I0>F6F03WSE/0iHiH0?:OHP3fZfX0nKAc0?JjOP3O[gh0n=Rb0:nFP017;RT0DcXm04H^;P1E>380
klVf0>VgUP3RWW40jYYU0>RAF`3XRU@0jh9B0>ihE03bMEL0kfeE0?1/E`3bJUX0kFQI0>UWE`3NJeT0
e7MU0<^7M023F4L0D3T[04Hh;`19@S`0C4A104Lo?@1;@d00LFMR09R=R@24NGD0IEYF04Hm>00h<B/0
=R`Z03/];00o:b`0CRX/05PM7`1f9RD0^eA=0>Q_I03ZJ5/0jfUK0=mUF03GM6d0^GQf06Pl?@3</[<0
nNGW0>oNi03`gN<0o>;]0>6kbP1oE6D0WW9o060jA@3>]kl0m^G[0?3Mh`3df^D0nMWX0=fJZP2eBeD0
gfid0=]bMP37MgP0ND520<ZWZ`3ki>X0km[S0?;Hi@3lenT0olCH0:=7EP33CUL0ifEW0>ASG@3EI5H0
_fmN05h_9@139b@0>B/[03L/=00d;CD0=c4k03Tf?`0k>4<0@3e603/h?`0[:B`0:2@U02dY:00[9b@0
:BHQ02PS800Z9B80;2LT02`S900X7b009A`M02hU9P0b9b/0<2D[02/N9`0W6R<0Bd180>7Hg@3]jNX0
h>3P0>;RhP3Ri><0h>3N0>;Rh03Shn<0hN7O0>[Yi@3Tgm`0S8:009V>RP2FR8D0Vi2>0:>IU`2TW9X0
Og]j0>7Oh03Shn<0gmoM0>?OgP3Wfmd0lM_N0;jKW02`QGh0Q69F06IFA`3>b[h01000o`0Jooooo`D0
0?l00`3oP00D0:0Pl0@0oh00102P8?030?n000d0X23`0P3oP0060:0Pl0030=1@N03oP000oh0000P0
X23`00<0oh000:0Pl02P8?00102P8?0:0?n000030:0Pl03oP000oh0000<0oh0000@0d51h0:0Pl02P
8?00X23`203oP0050:0Pl0030=1@N02P8?00X23`01T0X23`6`3oP0000`2P8?00oh00003o0003003o
013ooooo000>ooooo`H00?l000X0iLS209QSF`35IEX0j6aR0>YVFP3ZHUH0lVQK0?=WFP3eK5`0mF]N
0P3dK5h0L03`KE/0kW1J0>I/E03ZMeX0igUH0>IlE@3VPED0iXIC0>6:E03QTUX0ei9K0=ZRL`3ogKL0
dJbB0;R>PP2aQWl0Zh1i0=f]W`3j`:P0eHi^0>F=I`3[RUl0kH=I0>]nE@3_NEL0kfmD0?5]F03aJUL0
m6aL0?5WFP3`J5X0jfMH0=mZF@3EMV80c8Ea08iQCP1D>R/0AcT`04@m=`17@Sl0AD0m04Q0?P16?C/0
F4i<07U_K@2CRHL0T8R5071XI@1>A480>R`[030J70158B<0FalQ07XY:030Ee<0iVmW0>QZGP3SJEh0
gVmV0<ajN022CU00TW9e0?WUi`3ag^80lMkT0??Ni`3mgn/0ZGj?09=WMP21FF@0UWMo0?[Wk@3ah>P0
lMcS0?OIh`3ofNL0_Fil0=IWKP3KKW40eWQh0:9NG@23EEL0m=WN0?;Ni`3af^@0mMGR0?oFi`3ARY`0
VS0l0>9SJP3XHV40hF5H0=IVF02fJUT0CbLK044Y9@0e:B/0=bde03D]>00j=3h0>cE103djA@0k>440
<2dd02TW:P0S8B809bHT02TU8P0V8R40:2@U02dX:@0/9RP202TP8`80;RDX0280<BP]034V;P0/82X0
7Q8L05]AF@3Zi>P0j^GY0>7Qh@3Rh^80hN?R0>?Sh@3Ti>80hn?S0>7Qg`3^kN/0cLW806UTH@27OG/0
NFi/085fM01SFEP0Q7in06m[JP3Xi^L0i>CT0>3Og@3QgM`0j=cN0?GQh`2QPH40_iZA06mCA`1mLfL0
k>WP1000o`0Jooooo`H00?l00P3oP0000`3@D7P0X23`0:0Pl00A0:0Pl0X0oh003P2P8?020?n000P0
X23`103oP0050:0Pl0030?n0002P8?00X23`00<0X23`00<0d51h0?n0003oP0003P3oP000103@D7P0
X23`0:0Pl02P8?080?n000D0X23`00<0d51h0:0Pl02P8?006@2P8?0;0?n000050:0Pl03oP000oh00
0?n0002P8?003@3oP004003o013ooooo000>ooooo`H00?l002L0ooOd0<FVX@2YHeL0dVaM0>1ZG03W
JE/0i5iB0>UQD`3YGe80k69E0?1TE`3dJ5/0lfUL0?=[F`3cL5`0lG1K0>]]EP3/LeP0k7EG0>UhD`3Y
OEH0j8=I0=]kD`3JQEh0lJJ60?6ZSP3`Z980ljNG0?:YV03hZYH0hHUa0>1nH`3[Of80kW]L0>UbE03_
LeL0kFeF0>eXE@3aJUL00P3aJ5P02`3gJeh0lFMJ0>eWF`3QJET0fGQU0<j5LP2AHU00EcXZ04Th;P16
?CH0BD4n0080A3ll04T0ASlm04Hn?011>CL0CTI406]SH@26OW/0UH^908YlN`1[EUD0D2TZ05<G6@1`
7ah0`5IF0>I`K03QJV80gVmV0=IiLP2OH600G3Xk0=>m`03fin`0k]gS0?7Li@3lh^l0f;K607E9FP2P
M8<0GSe60=Bk`@3jind0lMkT0?GKiP3ken<0om7N0;9JIP3KKW@0eG5c0<QgMP1i@d<0b:JW0?cUj`3^
f^<0l]SU0?[Dh`3oamH0Z55Q0<1;E03XHFD0if1L0>AVFP3CJ5P0[FMF04LU6@0g9Ql0<BPY03Tb>@0k
=Cl0=c@o03Xg@P11>dL0<R`f02dZ<@0/:Rl0:2HY02DU9@0V92D09bDX02PV:`0Y9B`0;BH^02/Q:P0Z
82P0:R4V00809AlS0200:b4Y03<Y<P0]9Rh0Lfid0?3[k`3Vi>L0h^;R0>3Ph03Shn<0i>CT0>;RhP3Q
hn00hn?S0?;`l@2f/[<0Lfe]0=W?d03Iclh0WiFD0:JMWP3]jNP0fm[H0>;RhP3Qgn00h]kM0>?Mg@3X
g=h0n^OY08U^K02eWI40He=60:RQV@D00?l06_ooool6003o00<0oh00:`2P8?020?n000X0X23`1@3o
P0020:0Pl0030?n0002P8?00X23`00<0X23`00<0oh000:0Pl03oP0001`3oP0000`2P8?00oh000?n0
00040?n000040=1@N02P8?00X23`0:0Pl0P0oh001@2P8?000`3@D7P0X23`0:0Pl00H0:0Pl1T0oh00
00@0d51h0?n0002P8?00oh001@00o`0@ooooo`003_ooool7003o000;0?SYi02CJEh0/6QJ0<E]G`3B
KF40fVaO0=aVFP3UJe`0h61C0>9PDP3[IET00P3_IeT09`3^IUH0lFUI0>iYF03aKUX0lW5K0>iaF@3_
LeL0jgAF0>YgFP3UN5/0hgiR0=mmHP3PO6@0gGUR0=YgHP3PNV@0i7IO0>QdG@3/LU/0kW1J0?1_FP3_
K5P0lFYI0?5XF03fKEd0lFQH0?9XF`3dJ5/0lVQK0>iXG03OIEH0fWES0=63K`2[Lf@0GSP[04dd;@1:
>cH0B3hl048m>P0204<n>`1B04Do?`12?3`0@C/k04Ln?`18@3h0F51>07]]K02OQXT0Z7n30:9TI`2=
>cd0_eMF0>9bKP3KKVL0egI_0;aaK02OLG40d[Vm0?7Qi03_h>D0l=cU0?SNj`3ognh0ZH:D08mPLP1k
DEl0UGMo0?[UjP3ch^P0l=gS0?GKiP3of>H0h:>b0:Y@G03HL7L0eGan0:1JG023EUT0m]WM0?KOi`3a
fNH0mMKU0?oEi@3PUZD0Tblk0>5SI`3YGed0iV1G0=mUF03DKEh0XV1B040R5`0a8Qd0:bDU02h[<P0b
;cX0=S9003Pd@P0l=T80<2Xd02TV;@0V92T0:2L/02PX:P0X9b`09RDZ01lN900O72D07aTS02DM:00`
:C40<2X^03Pb=P1=ATd0GeQO079[L`1ED5H0RXR=0??am03Ti>@0hn?S0>;RhP80hn?S01H0h^;R0>7S
h03Shn<0j^[Z0=gIfP1hLW80Fe9C05M>C`1dJf`0dlg=0>gYj03Thn40h>3P0>;Ph@3QgM`0iMcM0>SL
gP3lj^X0PFYU0:JFQ`1UFdl0g]_F1@00o`0Jooooo`L00?l00`3oP00[0:0Pl0030?n0002P8?00X23`
00/0X23`1@3oP0040:0Pl180oh0000<0d51h0:0Pl02P8?001`3oP0070:0Pl0030?n0002P8?00X23`
01H0X23`00<0oh000:0Pl03oP000303oP0020:0Pl0`0oh0000<0X23`0?n00000o`001000o`0@oooo
o`003_ooool8003o000O0=;0^@2bT8L0[Gid0:meJP2iLfL0_feQ0<U]GP3CKEh0g6iM0>5/F`3ZKel0
jfUK0>QTE@3/IeP0jfIE0>YUDP3YI540kVUG0?1/E`3_KEL0l6mI0?AfH03aMf80kgIQ0>igH`3_N6@0
j71O0>acHP3aM680lG1M0>m/FP020?1[FP1T0?=[F`3aJ5X0kfEH0?IZG@3aIeX0lVQM0?AWG@3aI5X0
lVYN0>AVF03OLF80fWi_0;IbI`1^?3<0ESD`04hi>019>cX0A3`j044k>`12?Cd0@Cdn048n?`12?Sd0
AClo04E0?@13?S/0ASXj05<j?P1gCU@0Z6Y_0;UWJ`37Hf<0fW5]0==`JP3GQ7h0Ncln0<j^/03bgn<0
l=gS0?;Mi03cg>H0on7`0=^ba021DVH0W6eo06<mBP3F_lL0mNK[0>oPi`3`g>D0mMgZ0?cCh@2QHFl0
^69]0<ieN`34NGd0M3`o0;nLX03mi>X0lM[T0??Gi@3he^H0oloM0;ILJ02iATd0jVAU0>]PF`3SGUD0
h6QJ0<m]H02FFDh0=AXC02/P7P0[9RX0:BH]02TW<P0b<3d0=SA103Lc@@0Z9c80;R/d02PU;00U8RT0
9R@Y01XG7P0O72<0:RL`03/h@@1LEeh0KVU`06iYK`1bKG40Kf]/06USI`1FD5@0A3m502`W;@2PWZ<0
lo7d0>?Sh`80h^;R01P0hn?S0>?Ui03Ri><0h^CS0>;Ri03YjNT0l^k]0:BOW017?cd0Dd]90<Bl^P3a
k>T0hmoN0>7PgP3Ph>00hMoP0>7Kf`3Tf]/0kn7Q0?3Ng026LVT0Q7QZ08^7N`3in?<5003o01[ooooo
2000o`060?n002L0X23`0P3oP00>0:0Pl0<0oh00102P8?0:0?n000030:0Pl03oP000oh0000D0oh00
00<0d51h0:0Pl03oP0001`3oP0070:0Pl0030?n0002P8?00X23`0100X23`103oP0040:0Pl0d0oh00
0P2P8?0:0?n000040=1@N03oP000oh000?n000D00?l04?ooool000kooooo2@00o`00P`3om?00m^GN
0>cAbP3J]J`0c9fC0<26NP2jMVT0_g5T0<A/GP39JET0eVmP0=][G@3SKf00iViN0>EZF03VJEL0iV=D
0>QSDP3TGdh0kVIF0>]SD`3bKE`0lFaK0?=^G@3dLEl0lfiM0?IaH03dK5h0mViN0?5YF@3`J5P0mF]N
0>iTE`3bJ5/0m6QK0?=WFP3aIeX0lFML0?EXGP3cIU`0lFUM0>QYFP3RK5h0gWQ/0<QfJ`1i>S<0GC4^
05@h=`1>?3`0Acdl04Po@011>c/0?c/j04<m?`15?cl0@cdm040j>P16@400Ac/k04lf>P1J<CL0HR<[
088`=P37Hf<0fg=`0=UhLP2fIF40RTi=0?[Ff03hfn00n=[R0?SIh@3nf^H0omOU0:I_PP2GGVl0PE5O
09]eP03mi^h0k]oT0>oNiP3`g>D0nN;/0?3?fP1d?4T0UDmI09eJH@1e@DD0SFAX0?GJg`3bgN@0lmWT
0?GEi03oenP0fiVW09Ta>P3OHF@0jV1M0>]RF03TI5L0eFEG0<mfJ023C4<0<ATG02/Q800U8bH0:bP_
02XY<@0`;CP0;R/f02XW<P0_;3D0<2dd02dZ<@0e<cP0BdI<05YEF`1_JW00P7f4089oQ@1eLgP0IF1T
04Q3A`0l>3T0=S8c030Z;P0]9Rd09b0W03Td>P3CdM@0kN_^00@0h^;R01H0h^CS0>7ShP3SiN@0iNGW
0>k/k@2b[Zd0R8B10:>NV`2AS8T0RhJ30>;Ng@3ViN<0hN3N0>3Ph03Pg]l0hmgM0>KJfP3di>D0bKNc
08QgJ`1[IEL0dLk51P00o`0Jooooo`T00?l0203oP00U0:0Pl0030?n0002P8?00X23`00h0X23`00@0
oh000:0Pl02P8?00X23`7@3oP0070:0Pl0030=1@N02P8?00X23`00`0X23`103oP0080:0Pl1T0oh00
00<0d51h0?n0003oP0001P00o`0@ooooo`003_ooool=003o000K0?oel03ki^40k]?<0=Rf[@37W9<0
^HMl0;EgJP2hL640_VmP0<M^G03@Ke`0eVeJ0>9^GP3XKEd0jfUK0>UTE@3ZHU80jV5A0>]RD03^IE<0
k6=A0?9VE@3`I5<0m6QI0?Q/G@3fJU/0lfYH0080mVYK01D0lfMH0?9YF@3aJ5P0lfYJ0?5WFP3eJE`0
m6QK0?1XFP3ZIUL0iVQJ0>AdJ03LNg80S48i05<N6P1?;2X0@bh[044c<P16?3/0@C/k03lj=`15?3d0
0P14>c`0C@13>Sd0@C/m044e=`19<cH0FC8g060Q:@1e8bT0`emQ0=ieLP3JLVl0Zdi90;EYJ@3oaLL0
o/_B0?o=eP3ocMT0om?Q0>BW]P2ABEL0/6Ye081;E@3Y`LT0o^?Z0??Nh`3ag^@0l]gT0?COiP3fgN<0
aZ>Z0:n8SP2FLgL0X8J90>3<cP3gi>P0l=_R0??Ii03menH0ol_L0:ECH@2lB540jfEV0>UPFP3WHeL0
gfMG0=9/G@39Nfh0Jcde038N7@0X7b008b4R02h/;`0f=3L0@Ca204e8CP1CCU@0IF1T06iYK@1jMWL0
OGUj081lO@1gLg@0If=T05QCE`10?3l0<2h_02TX9P0T8b408R4O02PT9@0Y8RT0;R@/02<I8@1[I6/0
lNob0>CTi03QhN40i>CT0080h^;R01H0i>CT0>?Sh`3Ti>@0jNOX0>KTi@2:QXL0d<c;0=OAd@38`/80
RhN60=KEd`3ViN<0hN7O0=oOg@3Qh=h0i]gN0>SLg03ijNX0Th5m08MkK`22OWD0moKa1P00o`0Joooo
o`d00?l02@3oP00P0:0Pl0030?n0002P8?00X23`00h0X23`00<0oh000:0Pl02P8?000P2P8?000`3o
P000d51h0?n0000I0?n000H0X23`00<0oh000=1@N02P8?00202P8?050?n000/0X23`7@3oP006003o
013ooooo000>oooooa400?l001T0ooG`0?[Vg`3_dLL0fK>X0<JHR`2gOg80[feM0;U]G@33K5`0d6UJ
0=a[G@3VJe`0kVYK0?=[F`3dJeT0mFYG0?AYEP3bIe80k65<0>aOC@3`He40kf=B0>eQD03_He@0lfMH
0080mFUJ02l0lfYJ0?5XF03cJUX0lVII0?IZG@3`IeL0kfMI0>iZG@3ZL6<0jgmb0:mGB`1M6Q40D1lH
040O600b6QH0=bPU03X_;P0h<2h0@3He04<i>014>S/0@cXm048i?013=cT0C3Pj05@_=P1M8BT0M2D[
0<5OH03QMG<0gViZ0<eQGP34IF40bWEe0=:3R03GRY00hIBL0>fMZ02`GFL0]5MQ0;iWK@2UGV@0ol[=
0?oAe03ldmT0o=GJ0?kFgP020?gIg@0Q0?oLh@3og^80o=gR0?_Qi03mh^L0nmkS0?_Jh`3oen80omCR
0=nCX02K=d<0gV1T0>iRH@3/HUP0i69D0=UXF03;L5h0_GU/07A?AP1YFeP0JVAT071^K`1iMGH0OWYk
081lO@1lN7T0MG5b06YVI`1KEeH0C4Q704A0?`0l>3L0:RHU0080;RXY00l0;b/Z02`[9`0Z:BD0:RTU
02DT8P0V8R<09QlV02`R:`0S6B40WiVM0?Cbm@3Ti>@0hn?S0>GUi@3Rh^80103Shn<04P3Uhn@0l>c]
0<k:b`2CSHl0E4i>06eWI`2^ZZ/0jNOX0>7Qg`3Rh^00hN7O0>?OgP3Ug=d0jmoO0?CTi01RDdh0SXEh
0;fl]`L00?l06_oooolA003o00P0oh0000<0d51h0:0Pl02P8?00:`2P8?000`3oP000X23`0:0Pl008
0:0Pl0030?n0002P8?00X23`0140oh00202P8?0;0?n00100X23`3P3oP0000`2P8?00oh000?n00008
0?n000030:0Pl03oP000oh0000L00?l04?ooool000kooooo5000o`00N03on?D0oo7]0?GQfP3VbL40
dJnU0;R:OP2aK5d0_fMI0=1VF03PJ5P0hfAA0>aZE03[Ie00k6Q?0?1]D@3_JDh0mF]A0?AYDP3aI500
kV5?0>iQD03]Ge40kf9A0>aOCP3ZGTd0jem>0>eQDP3aIEP0l6AG0?9VF@3bJ5/0kVAG0?5_G`3ZMF@0
eVmN08H`8@1Q7A00Db8D04<O4`0j7aP0:a/F02dR800_9B@0;R@S03D/;@0k<S<0>S4b040d=P1;=cT0
Dc0f05dV;01d:Bh0_emP0=mbK@3SKVL0i6]S0>UbJP3VMFh0gg=`0=a^K@3HJVT0cf5R0<QGF@3NK6`0
ffm]0;mMGP3KPH40g8Z<0=n@T`3PUIX0hi^O0>:KX@3XXjP0kjfa0?Be^P3g_/@0oLK<0?g8d03oam00
olSA0?o3c`3_Wj`0Y3m70<E>DP3[IF@0kF1I0>aTF03RI5D0e6]H0<QeH`2[Lf80LeM<06eTG`1SGU/0
F5AC05MAD`16@T<0@3`k03@c<@0_;Bh09bDV02XY9`0V9B<0;B`Z02`X9`0/:2D0<BdZ02l[:00]:BH0
:RLR02HS7P0[9b@0;2PW02DQ8P0X8RH0:R0X03</<`3=b<`0k^c_0>?Sh`80hn?Q00<0i>CR0>7Qg`3R
h^800P3Shn<04P3Vi>D0lNg^0<Fl_`1`IfX0J5mP0:BNWP3Xi>D0iN?T0>7Qg`3Ph=h0hN3N0>?OgP3U
gM/0l^KV0=71`@16>3D0[:NK0>_ZiPL00?l06_oooolD003o00L0oh00702P8?000`3oP000X23`0:0P
l00=0:0Pl0030?n0002P8?00X23`0140X23`2@3oP00:0:0Pl0<0oh00602P8?0>0?n000030:0Pl03o
P000oh0000P0oh0000<0X23`0?n0003oP0001`00o`0@ooooo`003_oooolI003o00180?c[i03<Y9X0
XVQJ0;Q[F`38JEL0eVaF0>A`F@3XL5L0l7AH0>mdE@3/KDd0i6530?1ZC`3^ITh0kfMA0?AYEP3cJUP0
lf]H0?5/F@3aK5/0kFYH0?5^G03YIEH0iV9C0>=NC`3UH540if9C0>=QD@3OIU<0j7UU0;eJA`2A>RT0
KRHG05lT5P1C8aL0@QhG02lF4P0c6aT0<1`K02`L700Z71/0<20Q03<P8P0l8bH0B2@X05TR:01^8bL0
/E9@0>=dK@3VJf<0jf]P0?5_HP3`L6@0lW=Z0?1aJ03aLFP0jfYT0>i]I`3YJV@0j6eV0>UcK`3RLVh0
gW9_0=I^K@3DKFh0bFEW0<9RH`2oHF80`69S0;eUJ030Jfh0bGAk0P36M7X05P3<MGd0afYd0;I>E@3;
DeD0jVIT0>UNF@3]H5L0jfEI0=mUEP3?Je/0aWe/09e^GP19=B/0>SDa03@`;@0[9bH0<2`]02XV9`0/
:2L0;bh/02LV900X9bD202/Z:00A02LV900/:bL0:bLT02hZ9`0Y9B80;RXV02`W8`0X8al09b<P02l[
:P0/:2T0:R@X01lH7`1QFV40kn[^0>KTi@3Ti>80103Shn40503Rh^80hn?S0>CSh`3`k>d0clK707Y`
L@2NU9D0`[Ri0:>MW@2^ZZT0jn[X0=oOg@3Qh=h0h]kM0>COg03Vg]`0mng[09V>RP1GCTL0a/Bj2000
o`0JoooooaT00?l0103oP00K0:0Pl080oh003@2P8?000`3oP000X23`0:0Pl00S0:0Pl080oh006P2P
8?0I0?n000030:0Pl03oP0000?l000L00?l04?ooool000kooooo6P00o`00H`3ol>T0/iR=08UPCP2Y
Ke/0^g1I0<ecF`3@JU<0iWQM0>5`DP3`NU`0lgYK0?EjF`3`Ke80kfeC0>aXD@3YIdl0j6aE0>E^F03V
LEd0iW=P0>EbG`3ZMf@0jGAR0>M_GP3ZLV40j6mN0>5ZEP3JIE40ff]G0=]^FP3CJUL0ZTTf08he8`1l
:Q`0L2dQ054M4P1;71H0A1dH03XK5P0d61D0<aTH03DH6P0d51L0?aDI04lB6@1R4aP0YdE40>EdKP3W
Jf40kF]M0>aXF@3`K5h0lFeP0>m[GP3^J5`0kfUN0>m[G`3]J5l0kV]Q0>m`I`3/L6H0kG9Z0>mfK@3Z
LFT0jW=]0>]dKP3VL6`0ig5]0>5^J`3OK6T0hfm`0>5]KP3LJ6T0gfUY0=aQH`3RIF<0jfER0>mTG`3_
HUT0jV1E0>UUF@3MIeT0cG5R0<J4MP1nETX0@34Z03Lc<00g=S@0<Bl`02/Y:P0^:R/0:BDT02/W900V
8Ql0:B@Q02HQ7P0]:2D0:BDR02PU800202TV8@0U02HU800]:bL0;BPU02TT8@0/9RH0:RHU02dY:P0Z
9BT08QdQ09RFV@3elo@0h^;R0>?Sh@3UiN<0i>CR0>;Rh03Shn<0i>CT0>?Sh`3Vhn@0mnk_0;BZZ@2P
TY80d<;20<_1`02ET8d0^;Ba0>_Zj03Ph=h0h^7O0>CPg@3Tgm`0j^;O0>gVh01oNg00U9:60<;2^P08
003o01[ooooo6P00o`050?n001/0X23`0`3oP00`0:0Pl080oh006@2P8?0L0?n000P00?l04?ooool0
00kooooo6`00o`00?`3^iml0Xi6308Y]F`2DIe@0YfeI0;E]E`31KeL0_VM;0=1bEP3NO5l0g7MI0=ie
F03GJdl0f6iD0<mWCP38JE40`VYF0<IaG@32Ked0`g1N0<E_GP36L5l0bg9P0=5fH`3@Lf40cG5L0=1d
G`3<L5T0dW=M0==gHP35JE@0`FUC0;5LB02MD3l0OS/[06T[7P1H7a@0C1XA04@E3@0n4@`0?Ph<040=
301830`0DPL;05d31@2R>CH0j75[0>]]H@3[JE/0j6EC0>iXF03_IeT0lVYJ0?1XF03_IeT0kVUJ0>iX
G03]JEd0lViR0>m[G`3^K5l0lW1S0>m]H0020?1]H`050?9_I@3`KF<0lFiV0?9_I`3eL6/00P3bKFP0
3@3^If<0lFQR0>mTG`3]H5T0lfIM0>iQE`3ZHUH0iVII0=][G@3@NVd0^Geb05lm=00l<2/00P0d<c40
700/:R/0:BLX02XV9@0X9240:BDR02/V8`0W8Ql0;BDS02hY9P0^:BD0:2<O02PU800V8ah09b@O02LT
800X9240:28R02lY:@0X8R80;RX[02lZ;P0^:Bd0a/C50>o_k`3Shn40h^;P0>CThP3UiN<30>?Sh`0C
0>CRh`3VhN80m>_/0>KJfP2UUiH0LVAS06MMF`2?RXL0i^GQ0>GTh03Ogmd0hN3N0>;Nf`3Sg]/0l^gY
0<_8_`25QgT0Ngma04o@C008003o01[ooooo6`00o`070?n001T0X23`103oP00^0:0Pl0030?n0002P
8?00X23`01P0X23`3`3oP0000`2P8?00oh000?n000090?n0000308300000o`000?l000H00?l04?oo
ool000kooooo7000o`00?@3gl^h0h]WB0<>bZ02OR7X0TW5N09A[E@2NKeD0ZWAJ0;5cFP2`L5D0]W=I
0:i]D@2^KU<0/GEM0;R7M@2nU8H0^9240;:<O`2^R7/0ZH5e0:AjK02SN6P0YWQX0:1aG`2QLEd0XW1I
0:IdF`2TL5P0Yg5G0:Q^EP2ZKU@0/WAM0;=aG02`K5T0VU5008U0<@1m=2D0MbdP06dP5P1W6@l0IaL>
06TB2`1]3PX0LPH309LP6P3PI5`0kViS0?]iJ`3dLEl0lViK0>mZF@3`Je`0jfIG0>iYFP3[IUL0kFUJ
0>]YF`3ZJ5X0kF]M0>iZG@3_Jeh00`3]JE`0;P3^JUd0kf]N0>iYG@3aJf00lfYR0?E/I03`IEh0l6IL
0?9UGP3`HeX0lVEL0>mRF03`HeT0jfEI0>9XF@3FKf00cGmb0:=]H@1=;bL0@3@b03Da<00`;2/0<bl^
02dY:00[9b@0:RHS02TU8P0/9RH0:RDR02LR7`0[9R80;2@R02dU8`0/9b<0:RDQ02PS800S7a`09B4N
02LS8P0Y9B@09b4S02/U:@0V82@0C4M;0>GSi03Xj>P20>?Sh`0H0>;Th`3SiN@0h^;R0>?Sh`3Th^<0
inGV0<2k^`2FSHh0VHn>09nDTP2GS8P0VY>=09NDS`3JfMD0inSS0>7Qg`3Qh=h0hMgL0>CPg@3_k^T0
/K>X08jDQP1[LfH0K>i[2000o`0Joooooa`00?l09`3oP00Y0:0Pl080oh006P2P8?0J0?n000030:0P
l020`0000?l000L00?l04?ooool000kooooo7`00o`00A03imN`0i=[>0<BdY02]V8L0/iZ60;ZKR@2l
VhX0`j2=0;jNR@30XHd0f;f/0?SXg03om^d0oO?Z0?S^i@3bjN00l^GM0>gPf03[gM80j][=0=g;_@3?
_:d0`jjM0;RST02ZU7l0XXMb09EiH`2ALE`0SVQE09AVE02KIU@0XfQH0:MXE`2[J5P0Z6=C0:5EA`2L
CT40W4Xn0:9:?P2[CD<0[4Dl0;I6>`3HI5L0gfMI0>E[G03YKU`0kW1M0>m`G`3`LF00lG9Q0?AbHP3e
Lf<0lW1P0>m`G`3bL680lFmQ0?=_H03^JU/0kFQI0?1[G03^JU/0kFUJ0>aWEP3^J5T0kVIJ0?9YG`3Z
H5H0kfEJ0P3`HeT09P3aHeT0kf5G0?9VF@3^HUD0k6QI0>1VE`3GL640bge`08mFB`1?:R80A30]03/`
;P0d:RP0=BdZ02lZ9`0^:BH0;BTV030/:@0/:2L0:BDT02hZ9`0]:2D0;2<T02/R8`0W8Ql0;BPU02`W
900Z9B<09R8Q02HT9@0W9BH09b8V02/T:`0L5A`0TXfC0??am03UiND0hn?S0P3Ti>@05`3UiND0hn?S
0>CTi03Th^<0jNOX0<6n_P21Ng/0OGEc07ifL`21NGH0NGIa06=RG@3LgMP0iNGS0>;Rh03Qh=h0h]kM
0>WUhP3[jn<0X:>H069ZG@2>UX/0Noek00P00?l06_oooolO003o02L0oh009P2P8?020?n001T0X23`
4@3oP0000`2P8?00oh000?n000060?n000030:0Pl03oP000P<0000P00?l04?ooool000kooooo8P00
o`04083mN`80P?ej3`00o`00@01ongL0NoMc07ObKP1dkVX0KnQT06GKE`1Jd4X0eLNn0=2m]03:]:T0
aj^P0<:SU@30Vhd0a9R:0;f=O@31R7X0`X9e0<=lKP35N6P0agAT0<M_G`39KU`0cFaK0=5/G03EJe/0
e6UH0=QZFP3KJU/0ffYI0=e[F@3QK5d0i6eM0>E]FP3UK5T0ifeK0>Y_G@3XK5/0k71O0>a^GP3]KUl0
kViO0>][G@3]K5h0kV]N0?9^H@3`JEd0l6MJ0>eTEP3ZHE80k6=D0>MSE03OI5D0g6mQ0<M^H01i<2@0
F1dA04TP4@0l8100=Al@02`M400T6a8071PB01PG4P0I6AH201TG600D01`J6P0M6AT07QTL028L7`0U
7b808A/N01lH6P0S7Ql09B<U02PW:`0/:S40:bP`038_=P1[J700g=WO0>?Qi@3Sh^@0i>;T0>KTi@3V
i>@20>GThP040>?Rh03QhMl0h^?O0>;Rh080i>CR00@0iN?Q0>GShP3Sh]l0g]kL0P3QhMl0203Qh=h0
hMoL0>OPg@3ckNP0V9B:06i_I01lPGL0hnKP2@00o`0Jooooob800?l01P20`00?003o00L0P<002P3o
P0050=1@N0030;Ph]02P8?00X23`01d0X23`00<0oh000:0Pl02P8?005P2P8?000`3@D7P0oh000?n0
000G0?n00080d51h00<0oh00003o0000o`001`00o`0@ooooo`003_oooom3003o000e0?ojm@3onOD0
ooWe0?oglP3olnl0onkX0?[Sg@3fgMH0l]G=0>_=``3N^[00d:FL0<NHT030T8H0_h]n0;^6N02fNfd0
]7EV0;QdI`2gKf40^ViN0;]^G02lJeX0_faL0<9[FP31IU@0`VED0<AQD@38HE80bfAE0<eSE@3:Gdl0
dF5C0<iMC@3BGTl0dUe<0=EPC`3GHU00ef9A0=9QC`3>He40_Ue:0:EA>@2LECL0P4XT06i;8@1QAAd0
CcdI07U`D`23OVX0OG]_07EdK`20O7/00P1iMGH0601hM7D0Mg9f06e[KP1fLW<0Og]l08F1PP2KV9X0
XJ2V079bO01;CET0Ad]F04Y>E`1]LGX0M7Uo07QmP`2?U9P0WJ2U0;2a]@30`L<0b/[:0=[Ie`3Yj>@0
i>?O0>CSgP80iNCP00h0i>GP0>?TgP3Rhmd0hnCN0=oQg03Qhmh0h>7L0>7Pg03Sh=/0lN[R0=kHc012
?c00P7ia0=;Cc@X00?l06_oooom3003o01P0oh004P2P8?040?n00080X23`403oP0030:0Pl1T0oh00
00<0X23`0?n0003oP0002P00o`0@ooooo`003_oooom=003o001E083lNP3onO<0ooKb0?o`jP3mjN80
nN7G0?GHd03bdLP0l<_20>k6_03X_[80i[R[0=j^XP3KZY`0fJ>G0=BJSP3EVX`0dY230<f7N`3=QGT0
ageb0<QlK`35MfX0_VmR0<5_H@2mJU`0a6iO0;eWF030J5X0^VAE0;ISD`2bIE<0[VQ?0:MZB`32UV/0
aJMe0<2/NP37^Xh0jN2o0>_WcP3WhmL0jNKQ0>[Vi@3VhND0iN3T0>OUj03Vi>T0h^3S0>CRi@3WiNH0
`/3108R8R@0i?D008RL]02lf?00g@4D0>TA6049<CP18DU@0C5IH04eGF01CFed0DEII059HF01@E5<0
L79_0>?Tg`3^kNP0i^GP0>CTg@3Thmh0i>GM0>?Tg03PhmX0hnKO0>;UgP3Qi=d0h>?L0>3Qf`3Wi=d0
i>3G0:>OT`18ACH0XZ2D0?Kel@0:003o01[oooooC@00o`000`20`000oh000?n0000G0?n000@0X23`
5P3oP00=0:0Pl140oh0000<0X23`0?n0003oP0002P00o`0@ooooo`003_oooomJ003o000S0?oim@3o
n?@0ooSd0?ohm03ol>d0onWT0?oVh@3mhMd0o=oK0?WJe@3deM00lm;;0>k<``3/akh0hkfd0>2j/@3E
[jH0dJ^P0<VUV@30Whh0ZHee0:bHM036^Hd0dLRM0:2KM@2VXXD0emC10<c9`02VYJ40];:c0=oMhP3A
cm@0/:jc0;Re_02n^l800P3WiNP0202JV9T0M7Qg07n8Q@1<Ee<0<clk04EBB`15DTT0AU=:0P18EDh0
601:EU80CeYF04aGD`19E500Ae9<04U@B@2/[ZT0d]?=0<S9`@39bl40bL[20<S;`03:cL80bLo30<O=
``39clD0b<g60<C9`P35b;l0`LBk09^LU01jNW00Rh^10=?Bc@/00?l06_oooomJ003o02P0oh003@2P
8?0B0?n000/00?l04?ooool000koooooJ@00o`007@3onoD00?l00?ojm03on_@0oo_a0?cci02m^9h0
VYMh092?L01QHDD0=cTS0:BVV02m`;L0@D=00411@`2PXJD0`<75030d=`11@TL0FeaP09bMW`2FV9L0
O7im06aaKP2h`K`0ZkB_08VDS02@W980TinE0080Wj^Q00/0X:^S0:bg/@2`^kD0[kZd0;O2_02lal40
_lG10=7Fd03Oh]/0gn3J0>7RfP020>3SfP0:0>CWgP3Tj^00iNSQ0>O/i@3Zk>L0incV0>g`j@3`ln`0
k_7Z0?Cgl0d00?l06_oooomY003o00030?n00000o`00oh0000H0oh000P2P8?020?n00080X23`0P3o
P0030:0Pl0<0oh0000<0d51h0?n0003oP000703oP00=003o013ooooo000>ooooofl00?l001<0O?ah
0=gOe02//:40PhYj05QPD@1JI5T0IG5W030k=@0c?3T0D5]G0<;=b@0iA400=D4o03e9A@17DT`0C5E@
04I<B02QYJ80mOOf02X00?l06_oooom_003o00040830003oP000oh000?n000H0X23`00<0oh000:0P
l02P8?00102P8?020?n002X00?l04?ooool000koooooLP00o`003P3XknP0c]G>0;[4_02U/:P0UJ2J
08NBSP1fPGd0WjZT05QUGP1;Ee<0B5E>05eZH`2NZJ<0eM_G;000o`0Jooooog800?l0203oP0040:0P
l080oh00;000o`0@ooooo`003_oooomi003o00050>c`k`3SjNL0f^3L0=;He03Jh=`0;P00o`0Joooo
ogT00?l01@3oP00^003o013ooooo000>oooooj`00?l06_oooon/003o013ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000>oooooj`00?l06_oooon/003o013o
oooo000>oooooj`00?l06_oooon/003o013ooooo000>oooooc@00?l000T0mOGe0=cLfP2n_[`0UIFC
07IfM029RhH0][Rc0=OIeP1hn7L0K`00o`0Joooooc@00?l0203oP0000`20`0000?l0003o001]003o
013ooooo000>oooooc000?l000T0k^k/0=?Bd02^[J/0QhJ405eLFP0n?cX092DP01hO6P0L7AP00P0S
9Ql0100j?3L0J6UT0:VZY03PhMa]003o01[ooooo<000o`040?n000P0X23`00<0d51h0?n0003oP000
K@00o`0@ooooo`003_ooool_003o000A0=CCd@1MG5P0=3<_01lN6P0T81d07A`H01dL5`0K6QD081lJ
020Q6`0R8ad071dE01/N5`0M7aP08R<M05AEC`36al80K000o`0Jooooobl00?l000<0oh000:0Pl02P
8?003@2P8?000`3oP0000?l0003o001Z003o013ooooo000>ooooobh00?l001@0lo;`079^J`0Q7QT0
8b8M02DT7`0W9R409B@O028Q700R7aP09R<L02TV8@0S81/08b8M020O6`0T91l08b@N028U7P0m?cX0
YjVV0?KhmFX00?l06_ooool^003o0080oh00402P8?020?n006X00?l04?ooool000kooooo;P00o`00
5@2UY:00;b`W02DR7@0Y9R409RDP02@S7P0Y9R40;BXU03D`;00j=C40>C@`03D`;00g<Rh0=S4^02/X
900S8Qd09RLQ01hQ6P0U9b80OGml0>SZj@1Y003o01[ooooo;P00o`000`3oP000X23`0:0Pl00@0:0P
l080oh00J@00o`0@ooooo`003_ooool]003o000G0=3@cP11@3`08b8M02LT7`0U8Qd08b0K02XW8P0h
<bl0>cHb048j>013>cT0>C4_03`d<@13>cP0@SXg03lh=@0_:RH0:BHQ01hM600N81/06Q`I07UkNP3e
moH0J000o`0Jooooobd00?l000<0oh000:0Pl02P8?004P2P8?020?n006P00?l04?ooool000kooooo
4@00o`00303Xf]T0dKnm0=S6a03MblT0iM?A0>[HeP3^gm`0m^OT0?g^kP3omoD0ooKd0?ogm@l00?l0
00D0l?3^06a]J00M7QT08R4L02DT7`02024N6@0A03/f<P0m>3@0=C0]03Ta;`0i<340<b/Y03L]:`0k
<Bl0?cDc044h=P12?CT0?CPd02DT7`0M7QT06adH038d<@3=clh0J000o`0Joooooa400?l0303oP00?
003o0080oh005@2P8?000`3oP0000?l0003o001V003o013ooooo000>ooooo`l00?l003H0O>m_0;fN
VP1dA3h0IbhW06X]:@1[;BX0Kc<]06`b:`1a>C@0LSdf07m=B022E500OeI@085IE027HUh0Qf9O08eY
IP2;JFD0TG1[09AdKP2ING@0V7Yd09n1O02SQh<0YXb80:bFTP2_W9T0[Z6N0:RRX01_K6T0:bPU02HU
800U92008b0M01/I500a;bX0@Sdj02/W900_:bP0;BTV02`W900a;2P0=BhX038[9@0j<B`0>S8]03/g
;`0o>S@0?3/c02h^:@0R8ah08b@P06ATHP1^kVeW003o01[ooooo3`00o`000`20`000oh000?n00002
0=1@N0@0oh0000<0d51h0?n0003oP0000`3oP0000`3@D7P0oh000=1@N0070=1@N080oh0000<0j6Pl
0=1@N03@D7P05P2P8?000`3@D7P0P<00003o001V003o013ooooo000>ooooo`h00?l003L0n^KU09e`
K@1e<Bh0QcHc08L];026;BT0PbXV084Y9`21;2T0Ob`X07X[9P1j;R/0NSL_07/l=@1a=S00Jc8[06Pa
;01a?3H0Ic8/06dh<01]>c80LT8h06ln=`1/>c@0LD0i07A5?`1W>S@0ERdW044W800C1@808ATF02hY
9P0U8Ah09R8O028M6P0R6QL0>S8_04Hl>`0V7Q`0=S4]034/:00W91l0:BHQ02XU8@0]9B80<bTW03L^
:P0h<bd0;BPT03ll=`10@3P0:2TS02<R7@0Q81`0TI6?06L00?l06_ooool>003o01/0oh006`2P8?00
0`3oP0000?l0003o001U003o013ooooo000>ooooo`d00?l003T0ono]0:R2P@1`;bd0Qc8_08PY9`2<
:2P0US0^08TU8`2>;2/0Sc4_08P]:P28;Rd0PRl/07X_:@1l=Rh0Mc@/06TZ8`1e>C40NSlg06ld;01`
=bh0JC<Y06Te:P1^=c00L3Tb07Q1>P2?ETl0O4<l068]9`1K=Bh07`X502LL600^9R<09R4N02PS800U
81d08QPF03D[:@19?S`0;bDS03Pa:`0i=2h0:B@N02LR7P0V8Ad0:b<P02hV900e;BT0>C@^02HQ7@0d
<B`0A4@l030`:00S8Qd07ahJ0492@03Hf=H0IP00o`0Jooooo`d00?l0103oP0060:0Pl180oh0000<0
X23`0=1@N02P8?006@2P8?000`3oP0000?l0003o001T003o013ooooo000>ooooo``00?l003X0ooKe
0;bFT`1Y;RX0RCPe09/l>P2cBdX0aUaL09de=02C;B/0V3He09hn?`2I>c/0W49108hi=P20<B`0OcH_
08a7@01c<bX0O40h08A9@@1oASl0MSlh07a7?`1d@ST0LC`f06`g<@1_=C40MCPc07Tj=@1]<2/0L40h
02hA2`0]6aL0;b@P02hV8`0Z9B809b8O02LM6`0_9R40A3Te040e;`0h;bP0>34Y030Y8`0Y8Ah0:b<P
02HN700Z8Ql0<BXU04Dn>00Z9B40>3<_04]8@`0_;RT09B@P02LV8P0V9R@0P81nIP00o`0Jooooo``0
0?l0103oP0080:0Pl180oh0000<0d51h0:0Pl02P8?00602P8?000`3oP0000?l0003o001T003o013o
oooo000>ooooo``00?l001@0aZZW06H_:P1c9B40XD=10;M?CP2lDU80^Dm?0:0h=`2YAD<0YTA509@d
=@2D=SH0T3Dd098j>026=c80O34[07@_:01e=Rl0JRlY070i<P80NTDo02P0Q59;085?B01b?CL0MChi
07@g=01a;BX0MRl[07D^:P23ACh0C1lJ03XI500f7QX0=BHS02hS8@0[8b00;B<Q02/R7@0`9b80?3</
04@k=00n=Bh0<BXT02lX8P0b:RL09alL02<K600i<R`0@Sdg02lZ9P12?cX0@Chi02XY900T8al0:BPT
02XY9`0_;R`0L6a]0:JPX03?bLT0l>_XHP00o`0Jooooo``00?l00`3oP0090:0Pl1<0oh006`2P8?04
0?n006800?l04?ooool000kooooo2`00o`009`3B^K@0JC`f06TP6P29<2`0ZdE10:Y1?P2X@3d0Xcdi
09Hd<@2>;b/0RR`/08PZ:P29:bT0RRl/08`b<@27=S80KB@N08Y9@`2JGeT0MChi07U6@P25E4l0REQC
08YGD`2BGET0Qe1=08]?CP2@Cdd0Q3Xi084`;@23<2`0TT4m084n>01F7aX0>a8<03XM5`0e8Qh0;R<O
02/Q7`0202XS7@0J02/T7P11>3<0BT4l04U0>`0m=2l0?CH`03</9P0b;BL0>cH`03dj<`12?cX0?S/f
03@`;@0Z:BD09B@R02XY9`0T8b4081XJ01hD5@0M3A00@Rh_075KG@27LG<0]ZBT0=W9b@1jm7AN003o
01[ooooo2`00o`040?n000T0X23`503oP00M0:0Pl0@0oh0000<0P<00003o0000o`00G000o`0@oooo
o`003_ooool:003o000^0>OEd@1bBD<0Gb0I07dX8`2K=cD0YShk0:8j=`2L=S80Tc0[08X[9`249R@0
R2XZ08/[;02<;B/0Rb`Z08P[:`22;BP0K24K099AB`35RhL0ZgI`09ASGP2BHEd0Tf9N0:=`K02UL6`0
VV9Q09=GE`2DDU<0QS`m08Xf=P26;2/0UcTg0:59A`2;?CT0GR8J04PI4`0m6QH0=QhJ02lP7@0^9B00
:B8L02/T7P0]91l0>2lZ04Dl=`<0Ad0j00D0Ad8l04A0>P13@3T0@d0k02l^:@0202XY9@0?02/Z:00V
8R409QdN02LK7@0S3Q<09PT>03lO8P1N?3d0EcLh04X/;01<<bl0MfAN0;R[X`3Kd<X0mNcW05/00?l0
6_ooool:003o0080oh0000<0X23`0?n0002P8?002P2P8?000`3@D7P0oh000?n0000>0?n000030:0P
l03oP000oh000200X23`00@0d51h0?n0003oP000oh00F`00o`0@ooooo`003_ooool:003o001;0;6E
T@1R:bH0LB@N094b<02O>CL0Xcdk09li=`2C;bd0SbdZ08l];02>;2/0S2X[08dY:`2B:R/0S2@U08lZ
:P2><bh0P30Y06dX8@2:CDP0^hIn0;b:P`2DHEd0REIC0;1mN@2LIf<0ZW9a09YNGP1o@D80Kb//07DV
:@1l9RL0VCLg0:]5@`2ZBdL0Vd<o07H]9`1E6aL0AATF03`N700g9200<bDR02hS8@0/8R00<RPV02`T
8@0b;BT0<B`X03/f<P10>cL0>cLb03Hc;P0/:bH0:RTT02TX900W9R80:bHS02TO7P0Z6Q/0=1/O02d<
4`0i41P0C1lT05lb=@2>I6D0TF]X07eKDP1N?c80CC8Q05]1<01_F4P0UGmb0<6_Y@3Sd/X0o>oY05L0
0?l06_ooool:003o00030?n0002P8?00oh0000d0X23`403oP0030:0Pl080oh006`2P8?030?n00003
0=1@N02P8?00X23`00D0oh00E`00o`0@ooooo`003_ooool9003o000a0?_Yi@23GUP0IB8L08@[9`2O
>CL0XSPh09P`;`2M=cD0VC<a09D_;@2@:RP0S2@U09@Z;02G:Rd0URPY09HU9`2H;2`0TRlZ08Xa:`1l
<B/0PD0j08eFC`2lRX<0aiBA08MDD@2RKf`0`Hj;0;InO`2JGf40YVY/0:YZJ`2WGf80TT9508`c=02M
?Ch0UcTi09<k>@2HBTP0PT4o05`Y9P0k5A@0?B4N040X:00j9RL0<b<S03<U900]8R00<BLU03D[:@02
02lU8`0M03<Z9`0c:bP0:RDQ02dX9@0^9R@0:R0O02dM7P0/5QP0>1TN03P@600d1@d0CAXQ05XU;@1L
:2`0LD5109Y_J@2[PgT0VGEQ091aE@22IDL0KU4c05Xo901@=Ql0EchZ06iIB02CPGD0_k6X0>;Ec@3j
kn/0D`00o`0Jooooo`T00?l00P3oP0000`2P8?00oh000:0Pl00=0:0Pl100oh000P2P8?030?n001X0
X23`1`3oP0030:0Pl0D0oh00D`00o`0@ooooo`003_ooool9003o001E0=_2_@1U=S00L28N090a;@2Q
>3D0YCLf09``<02I;bl0W30^09PZ:@2G:BP0VRXY0:0/;@2S;2h0XR/]09hW:@2U;c40XC<b08/X8`2E
@3/0kJJP0<R=Q`2AGeP0dYnL0:]iN01`?Sl0fjNY0=BMXP1^=C/0]gn20=^OX@38Qh/0/Fma09YGF02i
LgD0fI>E0;ilO@2>D540NCln07=1@01U?Cd0BBLV04h/;@18:2/0ABPZ04<Y;00m9bT0>bLY03DS8`0d
8R80<b<S03DU9P0b8R<0;QhO034N8P0a7240=Q/P03TD6`0i3QD0@@hE04<<4P1F6R80Jbhf06P/=01U
;S<0I30b07I6@P2RNVh0VgYQ09=gDP2HP580VWm@09f0E02EN4h0P68l06mA;`1M?R80DcDM05Tl:P1b
F4T0Uh5f0<>aY`3Se<d0n^oY0?ohm@1>003o01[ooooo2@00o`030?n00100X23`00<0oh000:0Pl03o
P0004`3oP00E0:0Pl0h0oh000`2P8?060?n004h00?l04?ooool000kooooo2@00o`003@2^SHP0H2HR
07dZ9P2L>3H0XcLe0:4a<02I:b`0VBPZ09dZ;@2Q;Bh0Z3@e0:@];`2V;S000P2Y;S00B02Z;c40[C<f
0:Lc=02O<C00Q28Q0;QUH@3b[JP0cI:>0:1YIP3GY:<0TV1S0=JSZ03a_<80JcHl09=JH03OY:P0/7=h
0;^0PP2PJF/0l;Vl0?S1a03`_;h0gJ^/095QH@3<X9l0l<[90;bHV01M=ST0EC4c050]<@1082D0B2P]
058b=`159BP0@28T03hQ8`0j82@0>ahS03XK8`0d4a`0>aDP04<E801841/0C0dH05<@6@1T8BX0Lc0i
06d^=P29CED0L3Tn06Te=`1G9b<0Ne=90:N7K`2>M4l0SGE5095jA02EO4@0WH9;0:63C`2SQ5D0WGaA
09=aB`24Hd80JT/^05Tm9@1:<A/0E3l/075PD02DQ7L0dlNo0?[bkd`00?l06_ooool9003o00030?n0
002P8?00oh000140X23`00<0oh000:0Pl03oP0004`3oP00C0:0Pl0D0oh0000<0X23`0?n0003oP000
2`3oP0030:0Pl0@0oh00C000o`0@ooooo`003_ooool8003o001L07ceM022FeH0Hb@O08Pb<@2R>c`0
XcHi09d/;P2I9R/0X2`_0;U2AP2i@4D0_DA90;i6B02g?d40/CTk0:Ta<`2[<cD0]CXn0;8g>P2^=cT0
Y34d08`V902TC4X0jj:L0<b<RP30R8L0eJ>V0;b;S`3[^L80TUmX05hW;@3;TYP0Zg1f0<bDU`2JIfT0
l;k10>Zi_02EIfT0_YBE0>_3``3ie]@0n=WG0>S:b025IFH0d;2c0=Rh_@2XQH/0G3<k05`]=@1P;cD0
EbT/04LN8P0o5ah0Bb0Z04PH9P143al0DAHX05TF9`1X6b/0NBHf07h^>@1m<C/0N3Dl070e>`2WLWP0
TF1T07M6B@1Y>c/0GC@^09QfI02VRfd0T7U?08]e@`2ANd80UX1409An@P2EOD40VGi70::7DP2WSEX0
XhUH0::7FP2BNE00PFM206iD<`1H?R<0E3`W071MC`2QShD0bKZc0>SJe`3nm?98003o01[ooooo2000
o`001020`000oh000:0Pl03oP00B0:0Pl0030?n0002P8?00oh0000D0oh0000<0X23`0?n0003oP000
3P3oP00<0:0Pl0T0oh0000<0X23`0?n0003oP0003P3oP0020:0Pl0D0oh00B000o`0@ooooo`003_oo
ool8003o001P06gSH@1[?3H0LR/W09@i>02M=3P0WBlb0:Xi?@2K:Rh0[3]10;M8CP2Y>3h0^dQ=0<AA
EP3JIVT0iW9c0>=/L03BFEh0d5EJ0<a?E@33ATX0_D950;E1@P2O>CL0WTE10=F7P`3WYZ@0nlG50<BC
U`2RLgT0kK_40:aiP01kA4X0]Gb30>>Z/02gPH<0fZV/0>k2``3DZZ/0QEmN0<2NW03ohn40jLg:09f1
OP25JFP0l]CF0?SKg`3mg><0h[W109MXL01iATd0Kci209]aM@2aQi00HSA108=>H031QY`0Xf9h0;ed
R02?>Tl0W45C09Q0CP26=Ch0Pca20:U/L@2XLG@0Xg5d09IVIP2EIfL0V6aY08QSF02iVXD0YH]Z08ae
B`20JCL0RW@k099i@02FO440Vgi409]nAP2NQ4/0VGm609j3C02URUD0ZXiL0:^?H02WRV00RF]806E;
<01K@R`0CCHT05U6>01_GE<0WY270<Vo]P3XgML0o_G`A000o`0Jooooo`P00?l000@0P<000?n0003o
P000oh004`2P8?000`3oP000X23`0?n0000K0?n000030:0Pl03oP000oh0001l0oh00102P8?050?n0
04@00?l04?ooool000kooooo2000o`00E01Gb4L0Jc0/08Da;`2K=cT0WS4d09d^=02V=cd0WC@h0;EB
E@2lHFH0^5eR0:m<D@2[A4L0[T540;i@D@3FHfP0fF9X0>I/LP3SIV`0fEYQ0=IIG@3BEeX0aU9C0;I=
BP2UAT@0_fi[0?6a/@3obld0V6MZ09IYK03gb<h0dYnT09=JH@2TIFd0Xf=Y0<NEV03Z`<40`ifL0<ZY
Y02GN7<0k=3<0?kUh@3OalD0ZHb>0>O:cP3jgn@0]YVN0=fna03T`LL0ID550:j:SP3@/;D0jLWB0;bH
YP2@HgL0k[[A0=bR^P3CSjH0`Fn60:17F`2WC5d0PR`g0;1SJ`3>S8h0Y6QX0:ifM@2PJVX0VFMV0:=c
K`2IKFH0ZH=f0;VIQ02aTgL0OF4l05Pk4@1aCb80PEd]08aS=@2GKch0WWY809mnB`2OP4X0WX5909j4
B`80WhI=00h0YHeG0:F=G@2PQeh0UG]H07]P@`1RARh0C34L04L]701G?Bh0Lee@0:2<P`3<^k<0j]gG
0?gdkd000?l06_ooool8003o00030830003oP000oh0001H0X23`8`3oP0000`2P8?00oh000?n0000;
0?n000030:0Pl03oP000oh0000h0oh00102P8?050?n004000?l04?ooool000kooooo2000o`00J02o
XZ00Mc0^09@f=P2J;C00[S]00;I1A`2nCeD0Y3e10:Y>D@3^Wj@0okZo0>^BUP3KO800cFY]0;]IFP2Y
A4P0ZT560;A5B`34DEP0cEQP0=URJ03JHFH0fV=U0=ESH`3AIF<0^eaJ0;i^K@3g/k80nkno08aFEP2a
OGl0om7E0?Bm``2IG6<0RDM<08aDE`3fb<P0^iFB0;6BS@2jViH0/iNC0?WQg@3bf]P0hLC60=Bg^`3o
h^H0ck:f0:R;S`3ce=T0VG]m0>;5a`3oiNX0i/WB0?oNk037WK40/XFJ0=RT^`3Z[lD0iYjd09i<HP2W
D640SSQ50:=BF`38OH80WEUJ0;QhN02`Lg80[W9a0:]aK`2MIf80OTi40:UoL@3<Yi@0[h]a07]H>01Y
@Ad0O50Y07mB:@20DBL0Oe@Y08MN<02CKC`0VgM30:>4C@2TQdd0WH=60:>;C@2RS580ZY5K0:^AH02X
SF80Y8QQ09MjFP22I4P0JD/a05Hj9015;1H0?BHD05A1<P1eHeL0Wi290<Vn^03Yh=/0OoYi?000o`0J
ooooo`P00?l00P3oP00H0:0Pl0030?n0002P8?00oh0001d0oh0000<0X23`0?n0003oP0008P3oP004
0:0Pl0@0oh0000<0P<00003o0000o`00>P00o`0@ooooo`003_ooool8003o001[0:^2P023;S40WS@h
0:@_=@2i?T<0^Sm40;Q3B@2`ATX0UCTn0=V<TP3fZk00`6U_0<EZK`3IPh@0fh^<0>>GV`3@PHH0_F=Z
0:95C@2N?D@0Zd990;a=E035E5P0aeAG0=1NGP3BI6<0df]Z0=MiM`3jYZ@0gY:B0:eVI03CUYD0omWL
0?c;c`2]L7D0R4Q90;Z0O`3cb<80Xh1j0<^/Y`2lX9`0h/[80=:j^P3I^kd0i/K90>C4a`3ogn<0g[^o
0?3=d@3E]kL0ck:d0?oWjP33YJ/0omcV0=6[^P2]Q9H0^XnR0=FT]`3l`MD0/fj108PiC02<>4P0QS8o
090oAP26=cX0SCi10:aPHP2_IFH0/fUZ0;]eL@2SHU`0NT4f0;j?O`39WhT0Z81V07eE<P1`AR00Pe<[
08MF;P24Db/0QeH^08A@:`26EBd0R5/a09M^@02/R5@0ZHaA0:F=C`2TSe00XXiA0:2=E@2KRUH0X8]N
0:6;HP2SRfD0WXIP09EmF@1iHCl0ITd^04hd6@0m8Pd0?R@C05<m;`2APGL0d<Jm0>gTg@3on_@03`00
o`003P3Yj>@0e=??0<?2_P2WYZ80RhZ806a[I`1UHF00Hf9N06UXI01UI5l0HV=M07IgL@2g^;<0jNWW
7000o`0Jooooo`P00?l00P3oP0060:0Pl0030?n0002P8?00X23`01<0X23`A@3oP0040:0Pl0@0oh00
3`00o`060?n000D0X23`0`3oP00L003o013ooooo000>ooooo`P00?l006h0UV=R08l`=02T<CP0]SY2
0<90B02d<cP0^Ci30;54B@2H?3l0hIZN0>6PY02?AdX0YUaM095;B`2CEUD0ol[:0<jFU`3<RX`0ei2F
0>VLY03>Lg`0bVE]0;]>E02eA4P0_D];0;Q6A@31Cdh0aEUG0<aXJ039Jf/0aVi/0:iPGP3NXjD0omWK
0=jSY@2/HV<0XEYH0=VOV`3V]k40f[F_0>S9aP30XZ00jlg=0;VGV03T`<@0e:fb0=2VZP3d`LH0lKg1
0?g<c`3]_l40omSI0;68R`3O][h0h;K00:=iQ@3fc=X0h[C10=bW]`3LWjl0VE9T07ha@@1k;CX0ORhg
07TZ;`1k;2l0TD5408<a=@2MBdd0Z5=E0:9DD01_:R<0S5960<>DPP37WH@0Y7eL07iH<@1cBAl0MdXP
07U:801nCBD0QDl[08E?;@24Cbd0N4HQ081@:02ILD40ZHYA0:Z@D`2TT5<0XiAI0:JKH`2QUF<0WI1S
09V:G`2NSF80WX]Q09j8G`2RRV@0VX1M08]aD01hGD00IT`c03hW4`0f9A<0D40`07Y/G`2XVi80dlW0
0>oVh@X00?l00180MOEd07AeL018Ad80<S4/02HU8@0_:bP0<Rh[030/:@0a;2T0>CDb03Tf<@0g=2l0
<S8Z02`/900_;RT0CDa8092@SP3De=8J003o01[ooooo2000o`000`3oP000X23`0:0Pl0060:0Pl0X0
oh00302P8?180?n000<0X23`103oP00:003o00030830003oP000X23`00d0X23`0P3oP00J003o013o
oooo000>ooooo`L00?l007@0nNOU08A8AP2H<cL0/CY00;m0A`30>T<0_3Ho0<52B@2gBD`0RC4`0>nc
/P3aa<40ZgYf07e:AP1Q<R`0aibE0?oMe`3/bL<0MTU80=ja]03odmT0eHRB0>B7T@3bRY40kh:50>9f
MP3BI6<0aUQG0;a>C@2mD5<0_eEG0<QPH@2]CDh0Td530>RPX`3na<L0dgmo0<I^K02bHeh0eiB<0?k;
a`3ofM<0`ibG0=:ZZ03U_Kh0]8Z>0>Zma032Ri40fHjE0>B?UP3ZUIX0fHN90<n5Q03WZJP0`8b>0?_:
d02dQHd0aYBO0?K2cP2nR9D0fJ6/0>JZ]P2WJG@0LS<l0:=RJP2[JFd0TdaB07/^=023<SP0SCHl094d
>02@=SH0R3Ld070/8`2BGDd0d:J>0;^HN02QPEP0SVm008IU<P1lF2H0O5@S07I77@1e@A`0PTXY08E:
;022ARX0P4PW08aM<`2NN4L0ZXmJ0:>BG02_YG00Xie]09FBI`2JUW00W9Ib09bDK`2JTFX0W8iW09b=
I02MRf<0X8eU09n<I02:M4l0ITl_050i6P15;A40>1l903/T4P1H@S@0N6IJ0:VJT`3Bal40k^OQ0?ci
m0D00?l000T0ALE301TJ500M71L08b0K02PU800k=S80?STf03Xe<P0o=c@00P17?c`02015?CX0@3/e
03`g<@0k>340<BhY01dL5`0a<2/0`L:m6@00o`0Jooooo`L00?l00P3oP0070:0Pl0D0oh0000<0X23`
0?n0003oP000103oP00<0:0Pl0030?n0002P8?00d51h0080X23`2P3oP0040:0Pl180oh0000<0d51h
0?n0003oP0008@3oP0050:0Pl0D0oh001@00o`000`20`000X23`0:0Pl00?0:0Pl0030?n00000o`00
0?l001L00?l04?ooool000kooooo1`00o`00M`3La<80OSXg0:4g>`2g?TD0`DA<0;/lA@2o@4T0_DI<
0;A=D01d9B40dZ2I0?_Gb`3nfLT0_9N50:N2K`3cdk`0_J6;0?CH`P2nWXd0mmK?0?oIf032Nh<0ZTmH
0<]PJ03HIF`0iG9e0>mlO`3ePH80lWio0>IbM@3HI6L0aeAG0;]?C`2R?T00W4A30>:CU@3=KFh0dFe[
0=MhM03@OGL0gIZD0?o7``3JYJ40TUmL0>:b/P3M[k40n<O=0>^^]P2kI6d0aUiW0<EJH02nEET0XTA4
0>2?S`3SWj00iJNZ0>R[/02LGFD0iZN_0<64S02:CeD0ijZa0<J9T02YJg00fifR0=fOXP3BTID0a7n4
08m2BP25;SH0T30h090`=02?=CD0Nb`W06l_9@37Uh<0g[VL0;VLM02VRUX0UGY507]L9P2@JST0UfPl
091J=025B2/0P3`U08U0;`28@Bh0O3lS07Q47`2@JCh0XXYJ0:ZLJ`2MVFX0J6To06=U@01jNeT0RXYX
09RELP2KUG40W9A]0:6EK@2NTFL0VHYO09j:H02BNe80TgM@08MYA@1dDc@0HD8V05@f7P0k80/0;1D5
03XW6@1DA3L0MVYN0:VPU`3@c<<0kncU00800?l001<0L75/01/J5@0^:bH09b@O03Td<015@3`0?3@b
03Ta;P0l=340>c<`04i4@P1=A3l0>c8]03dd;@13?3H0@c`d03@a:00L7180G5eF01T00?l06_ooool7
003o0080oh001`2P8?0=0?n000`0X23`00<0oh000:0Pl02P8?000`2P8?080?n000H0X23`403oP002
0:0Pl1H0oh000P2P8?0=0?n000H0X23`103oP002003o00030=1@N02P8?00X23`00l0X23`00<0d51h
003o0000o`005`00o`0@ooooo`003_ooool6003o000K07geM02QOG/0R3Lf0;11A02f?dD0/cm40:do
A02^BTh0WdI90:5DDP1`<bT0cZ>A0=B`U032WGL0hkj>0>S4S@3;Z6d0cJY]0<n]L@3Ra8l0/I5]0?35
[`3^[:L0Ze9F0<IDG`3?D5`0cdiG0080de1H06<0f5MM0>1PIP3SIFT0i6Y]0>E_L03ULW80f6YZ0=A[
JP3@IFH0d6EU0<=LF`2lG5T0/5aI0;M[J02iLg40/gAa0;1dL`37Si00l<330?o7c03CNX<0bUiW0=5N
I@3@GF80b5aN0=AbL`32IfP0^F9T0<iiO@2^Ee`0ZE=H0<UjO`35NG`0c7n20>ZMX02cIFP0^Fi`0=ND
U02@DU80^Gb10>6NYP2EADl0Z4QB094Z<@2C;C80SBh`07/Y9P1g=2X0/GiZ0<fVR@2gUG00[8aP091^
@@1T>@d0L3/D08E69@2FCC@0T40^07hX7P2<=Bd0RSL/084h9`1k?R@0MdXW089V>P2KRel0W9QZ06Y]
A01:DB/0C54a06=VBP1eLUP0MW1F07meF@25MeX0RWeM0962GP2GPe/0UgeD08AU?@1nGC@0OU`c07]J
<`23HSd0Le<a06Q9:@1QA2@0ESdO04Te6@17>200AS`X04m:>`1NFE00:RPQ02DT7@0X9200:RDQ04Q3
?@0m>3800P0c:bP03@0c:bL0<bXU0516@P1;@3`0=2TS03T_9`13=S00@3H]04Hn=011?C80;bdT07Ig
L@1Ph5l05`00o`0Jooooo`H00?l000<0P<000?n0003XJ3`01@2P8?000`3@D7P0oh000=1@N00<0?n0
00030=1@N02P8?00X23`00l0X23`203oP0090:0Pl0030=1@N03oP000d51h0080d51h00<0X23`0?n0
003oP0001@3oP0001P2h>;@0X23`0:0Pl03@D7P0oh000=1@N0D0oh0000<0d51h0?n0003oP0000`3o
P0000`3XJ3`0oh000?n000050?n000040=1@N02P8?00X23`0:0Pl0h0oh000`3@D7P30:0Pl080d51h
4`2P8?000`3@D7P0P<00003o000F003o013ooooo000>ooooo`H00?l007/0f/G207M7A@2B=SL0^457
0;Dl@`2V=CT0VCTj0>fSX03oc<@0m;na0>blY@3db:D0a9YX0=BXJ@3]_g@0i;AP0=j/D`3Q]5L0l/Y[
0<f]E@3;[VP0bJQc0?oF^P2TIUT0S3Pf09lnA@2Y@D`0]4AB0<E;F03@CE/0eDeI0=E<E03FCE@0dT]A
0<]8C@3@DUD0ceeL0<m[J@38Kf/0^V]T0;ejLP2fOGH0/H9l0:n6PP2jSX/0b9JG0;9gN`2UHfL0ehJ<
0<9MI@34DeT0aTmE0<5<DP2^A4H0`faZ0;UbKP2eLG00/6a]0;=XK02gJ6d0/eiS0:QAE`2mHVL0/EMI
0:mIFP20<340RD=30;eoP03DVIl0ol790:QLJ02D=400WBhg09l]=`2H:C00U2/_08DZ9`1Z8AP0YFaK
0=Z^U@2dT6h0[8US09idC01/>1<0McHH08Tk9@2:<R@0SRlY094_;P2A<S00SS@/08Pi;01k>B<0IS<D
06A2702=NTl0[:Eg07n0E010@1X0De0a0:6GOP2CPF/0NUm<08IZE01gG440J54_07AQ=`1lIc`0OFPk
089/?@1mICL0PFHi09=gB01iFR`0L54S07QI:`1nHS<0H4XK06EB:01dID@0Eddd024I300Q6aD00P0W
8Qh04`0R6QL0@chh03Td;P0P6aL08A`H02@O6@0f;bT0>c<`03/a;`0a:2<0;RDP03<X900h;bP0>c@/
03Xf;@0g=B`071lF05]MF03bl_005P00o`0Jooooo`H00?l00P3oP0000`3@D7P0X23`0:0Pl0030:0P
l140oh003P2P8?090?n000L0X23`1`3oP0020:0Pl0D0oh0000<0X23`0?n0003@D7P0102P8?0;0?n0
00<0X23`103oP000102P8?00oh000?n0003oP0020:0Pl0D0oh0000<0d51h0?n0003oP0002@3oP002
0:0Pl0030?n0002P8?00X23`01D0X23`00<0oh00003o0000o`005000o`0@ooooo`003_ooool6003o
002@0;6CT@1`>3L0VSLj0;/oA`2f>Cl0]D95098`;`2@BD<0n/Bh0=FVTP2lTG40fjn00<^MH@3W]fl0
gZaG0=bZB`3:VC80_90U0=bcA`3C/TX0hlE]0;FGC`3ofZT0k/2O0=FJR03;QWl0^faa0;YNJ`36EfL0
b4YH0==;E`3EB540e4U@0=A=D`3?CU80b55C0;mJF@2UE500VUM?0:UcJ@30U8T0^IN>0;^NUP2cVYD0
ZXf90:j8Q`2mRhh0_7]o0:eKH@32GF<0`E1F0<9;D@30C4l0[dE70:QEDP2fNW80[GQd0:QgL`2[Lg@0
[g5d0;efNP2kL7@0^FQ^0:iNH@2YGEl0NC<e09iRHP2XL7<0/7Ek0?jma@3KSiT0XCm;0:Te@02S:cD0
Y2`e09dZ;`2H<340NR8N07<]8`31RGP0fjnF0;N@K`2_Qf<0YG=@06lb4`1h;AH0S3TY090c:`2?<2d0
SS0^094h<027=BT0PS/W07Dm8P1H<0d0HDPO09b>G@2[YG<0L6e003`h4P1^HdL0Z9=n07MHAP1U@Rh0
PEe507QI=`1_ERd0ITlS06eH:@1bGBh0MV0_07iX=`2:Ld40TgU608ic?P27K3L0QVdg065:5P1OBQ/0
P75806iSA@0W7Pd091`D02/V8P0V7Q/09alL03H_:@15@3X0;bXV024L5P0U81X0;bXT03df<00k=2h0
=2`Y02@M5`0/8ah0;B@O03Tb:P0i=B`0?Sde01hQ6013ASl0iNGS5P00o`0Jooooo`H00?l00P3oP000
0`3@D7P0X23`0:0Pl0020:0Pl1@0oh002P2P8?0<0?n000D0X23`3`3oP0020:0Pl0030=1@N02P8?00
X23`00<0X23`2P3oP0030:0Pl0@0oh000P2P8?030?n000030:0Pl03oP000oh0000l0oh000P2P8?02
0?n001H0X23`00<0oh00003o0000o`005000o`0@ooooo`003_ooool5003o002A0?O/jP2?JFP0MSHf
0:<j?`2c=3/0^3Ll0;i3AP2aAdL0P2dY0:a^H@3ba:`0bZ=l0>JkQP3^_W`0kl1b0;b==@2eRBH0aI``
0=:/?@35XRh0]I<P0>g<I@39Ydh0e[AZ0>C0Q03`aY`0l/J]0?k<a@3obm80l8jK0<17EP3CC5X0e4QA
0=A;DP3>CE40b5EH0;]IF02NEe40Y7=/0;ZDR`2kWI<0[iN=0:bHS`2cX9T0YIB<09f:Q02QR8@0Yh>3
0<:>TP33O880^EiU0<5FG02mB4h0`DY>0<9AD`2H@C`0ZViV0:5dKP2GM6h0V7Id09]gM`2OMgP0YWYk
0:mmP02/NW/0Y79e09ETI`3aalT0m<O<09=GG`2hLWX0lj>/0;aGH02`>440ZC0g0:T^<`2W;S<0Wbh`
09<]:`1j8Qh0Qd<h0=nWUP3DZ8l0/XUY0;65H02PK4L0JR/<07hc7029=RH0RS<Y088^901m;b80Mc0L
07Hf6`1e@240IC`N048T002;NTH0YYaQ0:^XL@1MFb/0?C@C089bF@2`UH80IT<_07M>>027GCh0ME8Z
06935`1K@140IdlO058l2`1F@Q00HdlL071K9P1gHR/0N68Y08=]=01lIbh0Mf<`085cAP1_HT008AT6
02PQ5P0_:200;B@O02HO6@0Z8ad0>c@^04Dn>00c;2H09b0J02hW7`10>C40ASlg03L^:@0V7AH0:1lH
02TP6@0f;bL0>SH]03hl=@0T9Al0?3dh0=WIe`0F003o01[ooooo1@00o`030?n000D0X23`5@3oP008
0:0Pl0d0oh001@2P8?000`3@D7P0oh000?n0000=0?n000P0X23`4@3oP000102P8?00oh000?n0003o
P0020:0Pl0H0oh000P2P8?00103oP000X23`0:0Pl02P8?080?n001H0X23`00<0oh00003o0000o`00
5000o`0@ooooo`003_ooool5003o002A0=_9a`1cADD0OCDf0:TmA02d=C`0^C/o0;]7B02/AT@0P34Z
06hc8`3[_j80il6D0<:FF@3V^6d0/88]0;N;;03[`UT0lL]L0?7>FP3cd5P0hKa60;bH:P3K^ED0d;5G
0=g0M03<[gD0YHEN0?OB`P3oaLL0_V5/0<A>GP3<BEL0cDYB0<]>DP35E5H0/UAD09M>B02TMFh0_Z6I
0:VES02NSHD0Vhf40:6DS02UV900ZijF0:jQV@2[VID0YH^:0;28R@3<TID0`W=i0;aKHP36Eeh0`DaB
0;e9C02UAD<0VUYA0:AeK`2EMfl0S7E_08ejMP2<M7@0T7Ig09EiN02INg/0UWIg09EgN@3?/[H0mm?G
0;f8T02SH6T0^6Qa0;UFGP2c@4L0[cY00:`g?@2Y=S/0Y3Hi09de=P2E=cD0LB8M0:UYG`3X^:@0cJB8
0:n7H`2jSVL0Uf<l06`]3022>1l0RCPV07@U501j;a`0RdL`07Ti7@1`>AX0GC0A04h[1@2IOTL0Whe?
0:fUI`2_ZW<0DdhT04Pm7`2DOVL0[hik064f8`2DHdX0UFM607mE;`1bCB<0QF8h05`m4@1@=0D0GD<B
05e3401SBQ@0GD@<05Y1201`F1`0RG<j07IT<P1QDb`08QP002LP3`0a:al0<bXQ02hU7P0W7QL0;2<N
03Xa;019@3/0@3Ta030Y8@0i<RX0=2dU02lV7`0[8Q/0:R4J02/T700h=2/0?c`e03He;`0O7QT0=3D`
0<o>c00F003o01[ooooo1@00o`030?n000D0X23`5@3oP0070:0Pl0l0oh00102P8?000`3@D7P0oh00
0?n0000>0?n000P0X23`3`3oP0020:0Pl0@0oh000P2P8?020?n000030:0Pl03oP000oh0000<0oh00
1`2P8?030?n001L0X23`00<0oh00003o0000o`005000o`0@ooooo`003_ooool5003o000o0;nWY`1/
=SH0R3Pi0:`l@@2a=S/0]d=40:<o?`21<BX0XfML0=Z[U`3X_IX0bJ5^0=R]J@3R]F@0XgHI0>^nE`3c
bEd0llUI0>FnA`3@ZC00mm9K0=>]@02WQ1h0fK]K0?;FP`2_U540d[>50?oF``32P840^EEQ0<mFI`39
BeT0aDaE0;Y@DP2_EE@0TTm90:1_J032YYl0XY6909Z;Q02HRh<0VHn609^@RP2JShT0WI:<0:BIT`2_
XIh0/j2L0:Z<S02kSY40dI2F0<1ZL`34G6D0b5AM0;i7C@2cBTX0QSLb0:A[I02SO7D0TGQa08YiLP29
MgD0RWYj0080RGYg0500RgUg08UeMP27Lg@0Y8N;0:b1R02iOHL0bWj80;YLI02`Ad`0[TM;0;5<D02`
CE80YT=80:92A02QADH0RCDc06lZ8`3GXID0jl:/0<2NN`2dTFL0_99R099O<P1Z:`P0QS`O07h^4`1i
:a@0VDlf0:EP@`2MGSd0Te/h09UZ@02YPT/0XHE409n=C@2f[6l0S8UF04Q36`1CABX0ZHmn09E^G`2A
GDd0SeE109YQAP2MITL0YW5A08eM>@1oDR/0OeD[06a76P1YAaL0G3/806i=5`26IbL0QVPX06M>5@1S
DB40<B@202@M1P0`:QX0<b/P03L^9@0d:b80;B@M02XQ6P0]9Qh0@cXc04U0>@11>3<0>C0[038[9@0c
;2H0>34[03`g<@11?3H0?S/f02`[9P0M71L0;2/V0<O3`1H00?l06_ooool5003o00<0oh00102P8?0F
0?n000H0X23`403oP0050:0Pl100oh00202P8?0F0?n00080X23`303oP0000`2P8?00oh000?n00002
0?n001L0X23`00<0oh00003o0000o`005000o`0@ooooo`003_ooool5003o00280:R<R`1a=cH0ScTl
0;0m@P2f>ch0[c/l0:4o?03RTh`0omK:0>:dW@2cR6D0gK>10?K:R`3>X580/H@W0>NjD`3I[D@0/XLG
0=J/=P3Q^Cl0i[i70?SBI@2eT2P0eK=B0=foJ@2[TDL0o^2/0??;/@2FFE@0[4mI0<MHJ033D5d0_eAL
0:M?CP2FDD`0YWE^0;^JT@2hYih0Vhj609R=Q`2GS8H0VXn909^BS@2IT8/0VHj809^@RP2KT8`0YYND
0;6LV@2eTi@0bIJK0=6:TP33Ig80`EIP0;e9DP2kCE00VD0l095<A`2SLV/0UgUa091lM@2;O7L0RWmk
08MmN`23NGL0PWMe08IjNP23Lg@0SGAh09adO02WLWX0`gZ30:YBF@2K@D<0W4M:0;UZK@2dJ6`0[61T
0:AEFP2OD5<0Ve5B06PY902JJV00nMC20>33Y@2hVg<0_IaW0<FNI`1mCAd0LC88084i4`1n<a@0OcDH
08@j7@20>AT0Q48P08iC:`2FHBl0XGLm09an@P2QSU<0/:M`07mhBP0m<Q80FDLa0:j>P@2LKF00PDLi
08]@?P1l?bX0PTPb0:1XC`2WKe@0U69108eM>@2@I3d0Rf8f08]V<@2KN3P0RV`T06=80@2<NCL0NF`g
02HN000X8@h0<BXJ03dc:@0o=B/0@SP_03H]9P0_9Ql0:1lH030W800l<bh0AS`j040h=@80?STe00T0
?cXf03Lc<00/:2D09B4N020K5`0^9R<0WiRB0?;[i@3on?D05000o`0Jooooo`D00?l00`3oP0050:0P
l1D0oh00102P8?0C0?n000@0X23`403oP0000`3@D7P0oh000?n0000L0?n00080X23`3`3oP0000`2P
8?00oh000?n0000E0:0Pl0<0oh005000o`0@ooooo`003_ooool4003o002F0?oel`2CM780NC`k09Ln
@02`>T00^STn0;i2A02P<2h0^UeF0>^RV@3maK@0ikZM0=J/Q03M[WX0dj9O0;:4;`3icFh0fZm909a`
0`3X^dH0h;@k0<:F8P3ec680cJM20:j7:03YaFl0bJUN0=NhO`3lfkX0i;BX0:=KG`2RBUH0]UIQ0:eD
FP2FD4h0ZWQa0;2>Q@2^UX`0^:VP0:RKT`2QU8h0WI:<09bAS@2JSh/0Vi2<09Z?R`2HSHT0VHb609f>
R@2UTi40]I^J0<:KWP3?V9h0bgn90;iQJ`2hCEL0_dmE0;9@C`2DAD40VUeH09ieK`2GO7D0T7mh08b1
N`27OWT0RGmm08IlN`24N7P0QgMj08mfO02HL7T0Y6mg0;Q_N02NC500RShn09aOG02ZMg@0YgMg0:=e
M`2VM7L0XFm`09i/K@25F5D0LDa60>O:_03oiLh0e[jJ0;bPKP3<[W80]99C07542P1W;`00IRP106d[
2@1g<100OS<D07`_4@1m<Q80NcH?07Hi3@1a@Q@0TG4n0;6MJ02aYG<0JEdg04@f6@1/FTH0TG5S08aP
D`2<G4h0Md<e07I1<`22BS/0SUI508U@?@2:Dch0TUm408IH=02BJST0XWlo09Qk;@2FOR@0]jA80;n_
FP1<@1009A/202hS4@0c:Q/0>BlS04]1=`1>A3/0A3/d03/b:`0[8Qd0:b4O02TO7P0[8b409b8O02TS
8`0[9bH09AlO028L700X8B00;28P038U7`0g9Ql0JeU?0;FSV@3Kb/80mn[T4P00o`0Jooooo`@00?l0
103oP0060:0Pl1H0oh000P2P8?0D0?n000@0X23`;`3oP0000`2P8?00oh000?n0000@0?n000030=1@
N02P8?00X23`01<0X23`103oP00B003o013ooooo000>ooooo`@00?l002/0m>GR08IPG@1o>cX0WSm3
0;0g?P2o>D00`C`o0;Pn?@2S>380RcL]0;IgJ03Y^J<0mLb/0<jRM@3P[gD0]8@j0=^]E`3mdG00dZHm
0>^mC@3?X2`0d:4a0?S?I@36WcX0]Xlb0>o9M03/c8<0[XmH0<>RP@3oflh0mkVl0:IMJ02UEEh0TDU=
0:5/J02jUHd0Y8V00:2>Q02cYI/0cL2h0;jaZ@2[X9X0X9F?0080WY>=0P2MTX`0JP2OTX`0X9>=09j?
S02TT8l0[i>B0<:IW@3;SiL0cH6;0;YOJ02mE5/0`eaO0:M=C02=@d00XFmX0:1nM@2EOWH0SWmh08Ml
N029Ogd0Qgel08MkN`26MWT0SgAk09Q_M`2^MGh0[6=Z09M:C@25AD<0Xg=_09MdL02CMG<0U7Qg09Ih
NP2GNGT0V7Qi09EfM01oIV80]YnG0>cGaP3[e[/0cKN>0<ZcO`3:/WH0_YmQ0:ImA@2DI3@0N4<G06ld
201`;`D0L2`707H`301g<``0NS`C060_1P1S?A00VX1=0;JVLP2XW6`0GeH]03hc5@1QCCD0Nea708]X
E02HLUd0V6eJ08ePC@29FTP0ReY908UF@`1oCcP0GS4B091Z?@2[RDT0X8@a0:J?:@2jYSH0a[A609nB
?P0_8`00:1h002hT2@0^9Q<0>c8S04Hl<P1BB3l0ETa304e4?@0n<bl0=2XX02hV900Z8R009R0P02`V
9P0X7b00:B0Q034W9P0f:2D0:a`E02PF301NB3/0SGIX08UbI02JQ7T0]J:K0=[;a03ai^0?003o01[o
oooo1000o`030?n000H0X23`;P3oP0040:0Pl2T0oh000P2P8?030?n00080X23`00<0d51h0?n0003o
P0001`3oP0000`2P8?00oh000?n000050?n001H0X23`1P3oP00?003o013ooooo000>ooooo`@00?l0
0300i<o<07I:A`2;?Cd0YSm30;4d?031>3l0`SXn0<90@02lAT80Z4Ln08Hl;`1[>2D0h;^P0<VRN`3M
/Wl0aIEE0;1o<P3b`f/0i[QF0=FV?03DYSL0djHh0?K;HP2aRRD0f[=F0=:_G@2nWe`0eKF40>6lXP3o
d/X0ol[?0>:NZ@2EDUT0SE9D0;F=R`2URX<0W8Z009j@Q`2OThX0^jjV0<Zm]@3?`[X0`;>[0:jQV@2T
Uhl0WYB;0::GT@2NTH/209nASP1[09n@S@2QSH`0[i:D0;RAU033SY@0a7f50;YMI@31FUh0]EEF09M4
@02BDd`0Yg]b09anMP2DP7T0S7mi08^0OP2:OWh0RWal08agO02DMG/0XG9j0;MhP@2LDEH0TDM:08]C
DP2PNG@0Sg=_08agM02;MgH0S7Yj08ajN02=NGP0SWYi08QfM028MW80WHb40:NEQ`2VU7h0/Ymo0;n/
PP3<]h80dkUn0=2bMP36YVT0^YIH0:In@02?IB/0MDPA06Dg0`1N<P40GSD704h/001M@a80WhiF0;2T
J027OT<0GeTW05U>9@1QCbT0FD<J07AK<`1jGC/0PFA408e^C`2FMeX0TFmD09=_E@24HD40VgY=0:Z<
C02SRC80ZI4S0;^W:P3:^CD0eLQ>09^A<P1;@P00:b<0030W200b:QD0=b/K03X^8014>2`0CT@j05A7
?`1>@cd0@CHb03ld<00n=380@3Hd03L]:`0c:BL0=2PT03DX8P0W6A00<1hB07]XF@2HOVl0S75P08ia
H@2DM6L0SW1U09UmL@2^ThX0d[je0?;Pg03om_802`00o`0Jooooo`@00?l00`3oP0070:0Pl2h0oh00
00<0d51h0:0Pl02P8?00:03oP0040:0Pl0<0oh00102P8?0@0?n001@0X23`2`3oP00;003o013ooooo
000>ooooo`@00?l00340ek^g07A1?P2C?cl0Z3]00;@c>`35?4<0a3Tn0<I0@@2l@3h0]T]50:1>@`1R
;Al0g[RS0<2KOP3U^i<0gjmo0<2>D@33TdT0fZaF0>2bE03caV40jl1J0<2F=02kU3L0i<1/0=2^IP34
YFh0on2j0>o6]02eQ800/gIm0:QYLP29CU@0ZWUl0:n@S@2JQh00Vhf409^>QP2KTHP0XiJ>0:bOU`2n
/JT0dLBk0=?6_@2m/:L0Zj6H0:FKTP2PThd0X9:?0080WY>?06d0WHj;09j<RP2USHd0[hb@0<F@UP2l
KGD0]UIJ0;YEF@2dFEP0TTA009aQF@2VNg@0X8=m09R5O`2@PWl0SGmn091mO`2BNGd0VGAk0:]cO02`
KGH0TDE908a8B@2FIV@0VgUg08agLP2=NgT0RWak08EjN028OG/0QGYh08AiM`26N7L0PG=b08QjM`28
NG@0RWaa08inKP2@P6L0YIA_0;bZNP37/h00dKb50=BnQ03A^G/0cK=h0<:UJ`2gV640Wh1:08MW=01Z
C1P0@B/006ID5P2]Xe/0]JiV0::PH`1^JcP0Q7U<06MF:P1/EbX0L5T_05<l4P1TCB<0Ie0V06eD;01m
I3`0Rfm8091d@P2URTD0XhX^0:VC702nZR<0d/8_0=W=>@3OeU<0`kaD06YU500b;0009Ah002`R000a
9PX0=BXD03/`7P0n<R80@S@W03la9P0k;B@0?C0W03X]900e:1l0;R4H03DW7@0U60P091@4048a7@1j
J580WhUd09=hI@2ALV00TFeM09UdI02KMVH0SVYL08IVF@2>LfP0XHf40<fl]03]hmX0P?]i00P00?l0
6_ooool4003o00<0oh001`2P8?000`3oP000X23`0?n0000[0?n000040=1@N02P8?00X23`0:0Pl2X0
oh000P2P8?080?n00080X23`3P3oP00B0:0Pl0d0oh0000<0P<00003o0000o`001P00o`0@ooooo`00
3_ooool4003o000V0<>RW@20AD40WD520:dl@02f=3d0`SU00<Tn@`34?Sl0_d900;m?C@2@>C80PdY1
0>k6^P2ZPg80fJnG0=JYS03N[XH0dZ=_0<bLG036UTX0^8/h0;bD?030VTL0j<9g0=ReL`3V`hd0Y8AM
0=^iX03fc/@0SE]L08i@E@2QH6P0VfAZ0:j4QP2QR8@0W8f609b?Q`2ISXP209^@RP0909nDSP2RUi40
[::I0;bbZ@38_[D0c<:i0;fcZP2YWiH0WY>=0080XIJ@06l0Vi2<09nASP2OShl0Y8j@0;JBUP33Qh`0
/UeT0;ADF02iEUT0ZDi=09Q:AP2QIf<0[HAn0:>7P`2JQh<0TX20095kOP2HMgh0XGAk0;AeOP2QF5l0
T4E908Y=C02NMW@0TgUh08UgM@2:O7/0RWin08IjNP28O7`0QGUi08EkNP27Ng/0PGEe08UnO02;OG`0
QgUf08EhLP27NG00Rga^08ioJP2CPfX0Wi1c0:fMN`2iYgl0akB:0<jiRP3F`8h0d[^50<fgO@35/740
XXm:08=e:P2SVdP0_KYY0=;CS@1gN480PGUB081aBP1]Ec00OF8g07aQ<P1oIS00Mf4W065;4@1]FAh0
JE8L05U10`2>MBD0Zi@^0:fH6`2hYQH0eLH[0=O>;P3KeSX0g]U90=??D@2SWc@0KVPB03hg000[8@00
8aX002HM000_90P0=BL=03@U400b8a00>2LE03DT4P0b8a00<B8=02`N1P0O4@00=bP7071R?`1fIdH0
MFE<08YeHP2CNFX0Vgi^0:60L@2BKUh0UG1N09IaG`2DLEh0QfIC08=WDP2;L5d0]:6A0>cOeP3onO@0
1P00o`0Jooooo`@00?l00P3oP0080:0Pl300oh000`2P8?0^0?n000030=1@N03oP000oh0000D0oh00
00@0X23`0?n0003oP000X23`2`3oP00?0:0Pl140oh001P00o`0@ooooo`003_ooool3003o000d0?of
m@2_RHH0QTE109lo@@2[=S`0^SQ00<4h@039@4L0`c/o0<A2A02lA4D0TR`Z0<IhM03ob/<0l[J^0?Nm
/@3e_:/0mknX0>2^R`3CY7P0h[En0<VMH03L]G<0j<B60;JAG03=YW/0ikjN0<ZMQP3IZId0omoK0>Ra
]02FE5P0SU1E0;1mPP2;IfL0H4]608]nMP2NThd0Vi2:09V>R02HSHL0Vi2:09fBS02RVI80XYR?0:VO
UP2eZj80aK^b0<k4^`2j/:L0[J:L0::GT@80WYF@05H0WI>A0:6AT@2USHd0_I2C0;YcN@2kHFX0^UML
0;UFF@2SBDP0Ude:0:igLP2WP7/0Y8N309MoO`2IO7h0X7Mm0:YeO@2fL7P0UdY@09Q>C`29Ddl0WGik
08iiMP2<O7`0RWal08UmO@25NGT0QWYj08EkNP27OG`0R7im08=iN025NGT0QWYj08QlO023MgL0RG]k
08MiM`28NgD0QGQ`08AfJ`29O6/0RgaW0963J@2KS6d0[Yij0;NVN`37]HD0e<>;0=C4QP3<`7P0aKa]
0;VfI`3AeH/0TIEN05QD;P2AQ6@0/imn08Y^B@24ICL0TWDk08]`:`1mIa`0QW<V07eZ7P1PB`00RG8B
0:bG902`W1D0[ih80<Vk703MeBd0f=@Z0=oL=`3NgT80g]eA0=SFF`2l]e<0Ui4m06aU7@1BC@d0>c80
03L/000_8`00:ad002hP0080;Al001P0<R@0044d0`1[Gb<0VXiB07a_>P1eIcX0K5/m071NBP1bFd/0
PFMJ08Q[G@2KNV/0Y81`09mlJ@2@L5T0S6aC08m`E02MOf<0Pfa@079PC026MVL0_;:X0>WRfP3mn_D3
003o01[ooooo0`00o`030?n000T0X23`5`3oP0000`2P8?00oh000?n0000E0?n000<0X23`;P3oP000
0`3@D7P0X23`0?n000080?n000030:0Pl03oP000oh0000`0oh002P2P8?0F0?n000<00?l04?ooool0
00kooooo0`00o`00:P3nk^h0W71_08Do?@2T?d<0[cPn0;Tf?P30=cl0c4=;0<HmA035?4<0ad160;@f
>P35DUD0eFe/0=McL@3JOGP0f8Aj0=>;O@3d_JT0e:R=0>BiV@3BZXH0`Z1j0=^hV02/Qfd0o=710?G0
^03_ZjP0mJj/0?bh^@3oa/L0^gUj08Q>C@2iT8h0YhV706aID`1EB480LFIP09J=QP2KTHP0W8n709^@
RP80W96;02X0WY>=09nDSP2TVI<0Zj2J0;V/Y03>a;/0d/Ro0;N^Y@2YX9T0XIRA09fDS`2NThl0XY>>
0;2@T039TYL0_G1h0;]PJ@2lEed0]UAE09]3@@2OEU00[WM`0:^2O02QOW`0XGYk0:UfN`2iNh00Zf1W
09I7C02@B4T0Tf5M09EiM@2=NgL0RG]j08MkN`29OGd0Q7Yi08EkNP29OW`0Qgaj08IlN`25NgX208Ei
N@1?08MkO@22MWP0QGUk08IjNP25NGT0QGYh08MiMP28NgD0PWE]08IiL025Mf`0RGa/08alK02CQ6d0
WHia0:fNM`32]8<0bKj00<FnNP36ah40`LR>04=57P1]J4/0fl^b0:Z<LP1^BRH0^IAM0;fKD@2ENR40
WHLT08]g501`G@00XXlI0;FR7`2fY1@0/J460;f_3P3GcBD0h=`b0>KT>P3TiD40hnE60>CTCP3ViET0
h^9P0=WIG`3>cET0][940:NS>02GTR`0RhHR08V17`2;PB00T8HT09V@:`2_XS/0_[5;0<BgF@2TU4L0
K5`Q069>:@1XDS/0PFMH08IZG`1oHeL0QfUN07eQD`2HOVd0Qg5J08ahG@2<NET0TgmJ0:F@I`2NR6<0
O6M805Q4:`1RDd00QWa`0<C0]`02003o01[ooooo0`00o`030?n000h0X23`2P3oP0030:0Pl0H0oh00
00<0X23`0?n0003oP0005@3oP0030:0Pl2h0oh0000<0X23`0?n0003oP000903oP0000`2P8?00oh00
0?n0000<0?n00080X23`0P3oP002003o013ooooo000>ooooo`<00?l004h0l=kN091PH028?3`0YSm3
0:`e>`2m>D00a3i70<I0B@30>T<0`c]50<XnA`3<@4T0^S<i0;0]<P2b=SP0[c/k0:<j=P1m91h0_7ic
0>jn/02[P700bj6A0??>_@2RO740`IRB0?oEe`2oO8<0VT570:Q8C02[DU@0`G=a0:5MFP2KIV80]I2:
0:J?R@2MSXT0OgA^05Q=A`1GCTL0SH9k0:6DSP2NTH/0WY>=09^@RP2OU8h0WY>=09nDSP2PUHl0XYF=
0:VOUP32^:l0bl:i0;je[P2`Yj00YIbE0:2GT02QUY00Yi6?0;bCU`3>SiL0_6ae0;iOI`2kEUX0]5AE
09U1?`2VH5P0]7Ua0:mlN02_NGT0]gMh0<9jO@2SDEL0Vd]>08Do?`2KKf/0Tg]g08]lN@28OG/208Um
O@0408IlN`25NgX0R7al08MmO080QWak0P27Ng/01@24N7X0QGUk08MkO@25NG/0QWYl0080QGUk0P26
NWX0:`23N7H0QGYh08MiN029NgP0QGI_08IfI`2;Nf40UXMN09n@F@2SVUD0_Kib0=oVY`1/LDP0?C`N
0;BXTP3[d;d0ID8T09Q`?03S_G80bji:0<>^>`2iZC00Zi`M0;RX8@33/b80_k0I0<6c502k[PX0bL0F
0=gJ;@3Vi3T0inHl0>;T>`3RiCh0inU60>[/C@3Zje40l?1J0>k^G03Yj5X0gMiD0=[JE03JeeH00P3F
dE406`3FcD`0e/]70<k0@`34]dD0/9m7099m?01NAad0FShV06iA@@1jG540Pf9I08Y/HP21IeX0PfeO
071OB`29OF<0Uha^09f@K@2KS640XHmQ0:nIL02UTFh0Lf9403/`701dKV00n_We003o000Jooooo`<0
0?l00`3oP00>0:0Pl0/0oh000P2P8?070?n00080X23`5P3oP0030:0Pl2d0oh000P2P8?0U0?n00080
X23`3`3oP000102P8?00oh000?n00000o`0@ooooo`003_ooool3003o000]0>;=c024DE00Rcdm0:Ln
@`2/<cX0^ca00;`mA02k?TH0]ce80;8f@@35?dX0aci80<TmAP39?TD0cDE90<U7B@35CD`0[4A108@g
<@3_]:h0f:VS0?gBb`3a`[`0fjn^0>Vh^`3oam00]65[0;Q9DP35CU@0]4Q80;1BD02ECTP0/Weg0:j=
QP2NRX<0Vhj809fBSP2HSHT0LVMS05A9A022M740WHn<0:>HU02PUHl0WiB>0080WiF<02`0WI>:09jC
S@2NThd0Y9ZA0:bRV@2g[:H0_[>]0<6g[P2f[:<0Z9^E0:>ASP2[Shh0`iBJ0<f>UP2jJG00]EUN0;MD
E`2fE5<0X4M30:=CC02mKf/0a7Id0<YiN037LG80Ydi@0:1@D@23@T00XGUd091mM`2<OW/0QWaj08Z0
O`29Ogh0S85o08MkN`27OG`0Rh6008Z0O`26O7/0R7al08]oO`25NgX0QWak08QlO080Qg]k00@0RGem
08EiN@25NGT0Qg]k0P26NWX0AP25NGT0S7im08amN02;Nfh0T7mU09F4F02;Ncd0U8Tj0<C3J@3LhiL0
];Z:05=B<`1iLE`0m>;>0;NIO@1dCa/0fKEY0>38GP3D`T@0bKde0<W1<037^bL0b[lU0<_19038_Qh0
a[dH0<S15P3Fdb@0h^0c0>SX>P3PhSH0gMld0>?U?03Ri3/0h^<m0>7R?03UiT00iNQ30=_P?P3Lh4D0
fme;0>OVF03Nfdh0f=960=K:?`3@`d00`K8m0:nL@02HPCd0LE@X06119@24HDh0NUI:06@n=@1jF4h0
OV1F07eUF@1gIeP0J61=07=]E`2PVX00ZZ=o09^@H`2IS5l0Z9]_0;V]Q@1WH4<0KVaG0?Whl`00o`0J
ooooo`<00?l00`3oP00?0:0Pl0T0oh00102P8?080?n000030:0Pl03oP000oh0001@0oh000`2P8?04
0?n00080X23`9`3oP0000`2P8?00oh000?n0000T0?n000030:0Pl03oP000oh0000D0oh0000<0X23`
0?n0003oP0001@3oP000102P8?00oh000?n00000o`0@ooooo`003_ooool3003o000]0=2h^01lAT@0
T3i00:TnA02`=ch0^ce10;Hk@02a>D80mXN@0>MdP@2k?DT0bD5=0<TmB03:?DD0bci60<Lo@`35@dD0
_TY;08DV9037NGL0om7A0?Vl^`2GDE80j:b^0?o>e03jZ[D0[DUE0<]?F@3:BDh0`D];0:i<B@2JDdd0
^HR10:J8P02MRX@0W8n909J=R02JSh/0W96=081eL@1>@3d0FTm;081eL@2JSh/0XYNA0080WI>:00<0
WYB;09bAR`2MTX`00P2SVI00M@2WW9H0ZIjH0;R^Y@37_K@0dLBn0;RZY@2]V9L0[h^=0<fHWP3SVZ40
]EiV0;eMH@2nFUX0bFYV0<EXH`2]DTl0/UMF0<YZJ`30H640]EMG09e7AP2FCdd0Z7Ue09UmN@2BOGX0
Sgek09>4P@2>P7l0Sh6008eoOP2<P800SH>208UoOP27OG`0RWin08b0P02;Ogl0RGmn08IjNP28O7`0
RWin08]oO`27Ng/0RWin08QmN`2;OG`0Rgej08aoN@2>P7L0T81a0920I`2FQ5`0TX5908em<P2]XD/0
cLY]0=3CR03Qi;L0M7=G06mXEP3Fa[L0k]Jn07iM<P2gUU40mMek0>?CFP3MdD/0fm=40=[@?@3KdC`0
dl`e0=;<<03Abbd0d/d[0<g:8`3Jec00h^4i0>?T?P3Rhcd0h>8i0>7S>03QhcL0gn8c0=kQ<P3Ohc@0
g^8f0=_Q>@3MhD80i^M=0>?RBP3Je400e<Tf0<k1=`2n[S@0]J4n07iW6`1[CAT0KD`Y09A`EP1eCc`0
OEI707EA@`1WAcX0G48e065@@01ODT40Iem806YTBP2IU740]Zn30:FMKP2KTf@0[:Ei09^IL`26QVh0
nOWa003o000Jooooo`<00?l00`3oP00@0:0Pl0H0oh001P2P8?090?n00080X23`4`3oP00;0:0Pl5<0
oh00102P8?090?n00003003o0?oooooooooo00kooooo000>ooooo`<00?l002l0^9bK0857A@2@?3`0
[3m40;0g?P2k?T80]3]00:dj@@3gSIL0k8:>0;8jAP34@Dl0b45?0<PoB@34>dD0bT590<U2B037ATX0
ZcLj0:Lm?`3gU9L0^UMJ0:To@`2G>ch0ojJ[0>V4S02iAdl0cDmC0<M9BP2nC4/0XTM209mOEP2jShP0
XXJ209b:QP2NT8d0VXn;09^@SP2JShd0XIJB08f2P01YGU`0BSlm05U@B`26OGP0Uhj70:2ES`0209fB
S00309jCS@2KT8X0WI:<0080WiB>02D0YIZD0:bQV`35^[H0elS50<ji^02mVi`0aYFI0>>NX`2oKG<0
eg]n0<EUIP37JFL0dWMb0<U[J@2_D4h0^5AD0;M@D@2oF5T0YTQ60:YFE02eM700ZGUe0:AmN02JNgH0
VWik09V1O`2BOg/0TGmm0962O`2@PX40Sh6008b1O`2?PH00RWmm08j3P@2<PGl0Qgel0080RGmn04`0
RWmm08^0OP2=Ogh0Rgej08ioNP2?PGP0TX5a09F4JP2GQEl0U8=?09B2@02BPS@0Zie40<>jG@3<b6l0
d]6B0>3P_P2AS7T0Rh9i0;>RVP3XdL40QfY:0:Z:E`3jh9<0l]]k0>oMK@3^gVD0jmiN0>[PG03Tg5D0
hM]A0>3JCP3GeD@0f]U30=OF?P3JfD00fma20>KWB`3Qhd@0g^4l0>;V>P3Ohc@0g>0a0=oS=03NhSD0
hNDi0=cO>P3Si440jnM80>3J?03Ebc40c<0^0;f_:P2jZ3X0N6<:05Ln0021Hc40O5`c060m7@2:IT`0
JTLa09=bG`1oHdh0H4La05E09@1MBRX0Kf4n06eS>P2NUfT0]k>40;:^O`2DTfL0ZZZ40:V/T@3hnO40
0?l06_ooool3003o00<0oh00702P8?0;0?n00080X23`4`3oP00:0:0Pl4/0oh0000@0X23`0?n0003o
P000X23`103oP0030:0Pl0T0oh0000<00?l0ooooooooool03_ooool000kooooo0P00o`009P3om_@0
W7il08A7A02E?ch0ZCa10:dd>@2j?d<0^dA:0:m2B03ELG/0gGV50:TkB02g@U80^d9A0<13D@2n@4`0
`dA?0<90BP32@dX0`TM<0:/b>@2lAdd0_4=:0<a>E@2M:2h0aE9I0=AKHP39C580cdiB0<A:B@2nDTl0
VD@m0:icJ`2eT8P0WHF109V:Q`2JS8T0VHj:0P2JShd0PP2LTHd0WiBB0:6GU@29Ogd0GUAB04Q1>`1H
DD/0Q7]f09nDSP2QUY00WI:<09^@RP2LTH/0VXn909nDSP2SV980XYNA0:RMV@2jZZP0hl_;0>_4a`3S
[k<0cHJ<0;9MHP3>LWD0cfm`0=^0O@3URXL0l9:@0=YkN@38I6@0`eaM0<1IFP2hE5@0ZD]90:UHE@2Y
Hf40[g9_0:mhM@2YN7@0Z7ai0:=mNP2NO7X0XHB009UmNP2IP7`0Ugmk09F0O@2BOg/0Th5o09:3P02=
Ogh0T8>208j3P@2>P7d0Sh9j09F4NP2@P740UhId09B4JP2HQV80U89D0920A02BQ3d0YIE70;2TD037
_FP0d/]k0=gHU03>bih0ZjVD09bES@2RV9L0XiFD0<>`ZP1]Dd80JDl^0:F9E`2oXV00g/5a0?3ENP3d
fWT0lmie0?3NL03_hfd0kN=Z0>[RI03Wh5h0hmmI0=oKD`3Ge4T0jnYJ0>OWD`3PhDL0hN=00>;U?03Q
iCT0gn<g0=kR=@3MhCD0gn4h0>3O>@3Vhch0gmXf0=C;:`3<_bD0bKX[0;j_<02YUbT0P6/@07eV6023
JRL0N5hS09n3D`1gFS00PVI109Z0G@1dFSL0MUlf085[?01ZER<0IUPT07I/>`24OTh0ZjMh0:JUN@2X
ZX<0/kJK0?Sil@00o`0Jooooo`800?l0103oP00K0:0Pl0d0oh000`2P8?0A0?n000/0X23`EP3oP000
0`3@D7P0oh000?n000050?n00003003o0?oooooooooo00kooooo000>ooooo`800?l00:X0mncZ08Y[
J021A440Vd=10:Dk?@2Z<cL0^4540;Y9C`2Z@TT0VS]30;1DG`2TAU@0Z4MH0:m:G02]AUL0/4EE0;55
E02b@Th0]dE?0;U5D02h@d`0_TE>0<A5CP3<ATl0bD=<0<8lA@3?Ae40d4U@0<]8C@30BTX0[TY809M8
@`2iQ7h0[8^409j9Q02GRX@0Uhb809Z?R`2HSHT0VXn;09^?R`2JSh/0VI2;09fDS`2MUY00S8B105M?
C018?S`0IU]G08b1O@2SUI80Y9NA0:>FT02NU8/0WI>:09jCS@2RUi40Y9JC0:bJV02lW9d0gZfa0?Bc
^@31L7L0/UEM0:];C`2eDUD0gX200?ZOW03gW9T0lYND0?JKVP3UQhL0dG9`0==aL02oFe/0[di>0:97
AP2MAD@0Wd]90:IEE02YGEd0/F]Y0;1`KP2eNgT0[GYg0:elN02WNgP0XWai0:21O02MP7`0Vh6009N2
P@2FPh<0T7ij09>2NP2LS7`0VXU_09R6HP2JQe`0U8==08mm?@2DPc/0X9=40;6VEP30]fX0eLb70>3G
W03Hd:40`K^G0:FQSP2MVYD0WiVK0:2JWP2SVJ40/jN[08ekN@1A>340IDHd06]6:`27Fc@0/H=B0=Z/
L@3X^gL0klYj0?CEN`3dfWT0mn9k0?CTM@3biG<0lnQb0>kVJP3]j6P0j>IO0>GTEP3Phd`0g>130>CV
@`3RiD00g^4j0>;U?03MgcH0g=he0=_J<P3Fdb`0eLdX0=339@3CaR`0cl<a0<^n=02i[2`0ZY/V0:2?
9@2LS2d0W8Xf08il=01aGAh0NVL]07MT:P1fHRD0/9iF0;RVFP1eHa`0IUDM07EW=P1iLD80`l2E0;2b
S@2][iL0n?Wa003o01[ooooo0P00o`040?n001/0X23`3`3oP0030:0Pl0`0oh0000<0X23`0?n0002P
8?003@2P8?0W0?n000030:0Pl03oP000oh0002X0oh0000<0d51h0:0Pl03oP0001@3oP0000`00o`3o
ooooooooo`0>ooooo`003_ooool2003o002Z0>3Bc`1gEU40QDI109Hn?02V>cd0[CHj0;U2AP2_@DH0
XCa20;5HH02dHVd0/6Ib0:ISKP2MG6X0ZFUg0:ASL02IEf<0[V]g09aFHP2XGFP0[e]X0:90C@2]?T/0
aTIA0<e3B`3=@4P0cCe70<m3B`38ATX0_T]<0:=7A@2SGeX0^8b60:66O`2NS8D0VHf709^@R`2JShX0
VHf809Z>R@2LT8`0VXn;09V@R`2JTH/0Vi>=09nGT@2NUXl0UHb807mfL@1VG5P0HUIB06UKF024MW80
VXj909nDS`2NThd0XIJ@0:BET@2^TY<0_XfB0=VAVP3<Lg`0bEmX0=5OIP2nBDl0/Si30:Hg>@2bAdP0
^UED0<5MG03=JfX0g7Yi0>9oO@3UP7h0iX1n0>AmN`3FL6l0cVQW0<eWI`32G5h0/Ti?0:i8BP2aCDh0
[De=0:iADP2bFU/0[5UH0:mRH@2`JFL0/6m/0;5dM@2aNg`0ZWml0:21N02KPG00VhEW09J3EP2IRE00
WHe<0:bNEP2l[V<0b;ee0=38QP3?bI00a/6B0;VeTP2[YXl0YJ2C0:6LUP2PW9h0Wi^R09nKX`2MVJ40
X9VT0:BKY@2gZk@0Pg9i040X;01C=SH0FCL`05H`902NNFD0d:bA0;NELP2kVg<0^IQ/0<FVL03B]GL0
g;ik0>;5O03Yc7d0kM9k0>oGN03ag7@0k]aZ0>[KH03XfUP0j=eD0>OND03Vgdd0hme:0>;MA`3OfdD0
g=M30=[C@@3GcSh0eL/k0=?;>03EcCP0d//e0<k7<`3?aSP0a[hf0;Za<02bZC80XYT/09B:8P2=PA`0
OG4;0:6E9`3JcU/0gm=S0:nRAP1iKB40K6@W0;^hQP2b/XX0[K2D0?Sil@00o`0Jooooo`800?l0103o
P0060:0Pl0T0oh000`3@D7P80:0Pl0030=1@N03oP000oh0000l0oh001@3@D7P70?n000030=1@N02P
8?00X23`01<0X23`1P3@D7PM0?n000040:0Pl03@D7P0d51h0=1@N2X0oh000P3@D7P40?n00003003o
0?oooooooooo00kooooo000>ooooo`800?l002<0jM_H07]LE`1oA400UT0o0:Lm?`2/=CT0^4160;E4
BP2Q?480[EIN0;U^M@2JGF@0V6M]0>>ka03]b]40h;o80>K5cP3ad]X0cJfh0>K2cP2_Ohd0O3Y808@]
?@2kBED0bTA=0<m3C03<?dL0bd990<I8B`2gBDX0WTY80;9eL02^RH<0XHZ409f>Q`0209Z?R@0R09bA
R`2NTH/0WHn<09Z?R`2NThl0VXn;09R?R02LTh`0VY6:09^BR`2NUHh0WIB?0:2GTP2LThh0QGYf05eB
CP1;@3h0I5UE08UnNP2PUHl0ZINE0;:=SP3CT9L0eGV40;Q8E03:CED0e4iE0=I=E03GD5H0d4eB0<Q:
C@2l@D@0/CXl0:Hb<`80Zc/j04D0_U1?0=1THP3MLW40fg5a0=U_K`3TNWX0j7in0>]mOP3SL7<0hFY^
0=9IGP37D5@0aeAG0;m>D02cATT0/4Q90:U5A`2UAdP0X4Q709aED@2`P780dk2J0;fUP`2cWVl0_Jie
0<k3Q@3MdiH0e/bG0<2gS02ZY8@0WiZ60:6MTP2MVYD0WIVJ09fKX02LVJ00X9^U0:2JY02PVj80WIRO
09nJX@2OV:00ZZ2Y0;>X/01;?TL0;QlV02XK7P0_8B40Bcdl0?7Sh03hjN@0n^OQ0?OOf`3Vc<80b:^I
0;NGP02_S700YWmN0:R3F@2kUFH0`j1X0=FbLP3K^g00hlAa0>W<L03/d6l0k]E^0?;JL03`fVd00P3_
ff/06P3agg40m>Ac0>GFG`3Kd5@0g=9>0=W@@`3Hd3d0gMI00=SA>`3Fd3`0eM100<Fo<`2o^C40b<4l
0;^e;@2l]BT0]ZlP0=WB@`3_if/0h]]c079[7@2[ZFh0/K>40:V/S`3hnO400?l06_ooool2003o00@0
oh001@2P8?0>0?n000L0X23`5P3oP0030:0Pl0D0oh007`2P8?0J0?n000D0X23`;`3oP0000`00o`3o
ooooooooo`0>ooooo`003_ooool2003o000T0>kSh@1nHUh0ND8m09=4@02P?3h0Yc@i0;PoA@2gA4/0
Z3m40:56C@2iK780WEmT08QGF`3cbm<0l=3E08m^M@2:Jg40`jF]0;nT[@3:Z[L0XWV70:M]O02HBe/0
/4EC0<M8D`38@4X0bD180<Y4B`32AdX0/d]:09I8A02gP7T0ZXN109b8P@2MSXT0WY>?0P2JSh/02@2L
SX/0Vhf:09V?R`2JSh/0X9FA09F<Q`2KTXd0VXn;09^@S00209bAS@1i09^BS@2NUI00XiZE09^BS@25
O7L0GU=?04a1?@1XFUL0TG]m0;V<T03LSiL0aF5[0<5<E@3=Be<0e4]B0=E8CP3JCU40edaA0=E=D@3D
Be80cTU>0=5>D`3;BTh0_3i10;Di>`2^=SL0/C`l0<5AD03?Hf40f6aZ0=IZJ03JK6/0efMV0=YXJ03E
HF@0cEYM0<mOGP3FJ6L0f6i^0==[JP39HF80`5UJ0<=OG`2SDT/0ZGAT0?gJaP3bf/00e/JT0=73X03<
_id0^ZnC0:RMQ`2OUXD0Y9^B0::JU`2QVi/0Y9jP0:2JWP2RWJ<0X9^R0:6KXP2RVj<0XY^R09jGWP2Q
VZ40X9VP09jGWP2h[k@0G5=H02TN8P0]8b@0;R@S02/V8P3Hdll0lNcV0>cTh@3^i>80lNOT0?;Wh@3c
i=d0kMcB0>??a03F`;80`jfH0;:JPP2]T780Y8=P0:>0EP2/Q5<0]8UB0<VMH03>XEh0i;E_0>joM`3a
aGX0oMJ60?oPR@3ohXH0nN5o0??NM@3[fVP0i=AJ0>7DDP3KdD/0f=170=?=@`3Hd4T0c/Ho0=38?`37
`380c/Pf0<Bn:P3HdD00h]]I0?C^P02<QC@0X9iQ0;:dP`2UZ8T0nO_`003o000Jooooo`800?l0103o
P0060:0Pl0d0oh001`2P8?0H0?n00080X23`0`3oP00Q0:0Pl0030=1@N03oP000oh0001H0oh001@2P
8?0_0?n00003003o0?oooooooooo00kooooo000>ooooo`<00?l002P0^:>N07=8@P21@3X0TcXl0:0g
>`2e@4H0^TE;0;A7C02Q@DD0/F5T0:IUJ@20CU40hKRl0?WIg02SPhH0=aXN081UJP3G_<D0Wh6=0;bF
X`3Q[;`0TTiM0:51D02oAe<0a4E@0<M3CP33A4/0_d]<0:a8AP2DBdD0]hEn0:J8P02MRX@0VX^609Z?
R`2KTXd0VY2>09^@SP2ISX`0VY2;0P2KT8`0102IT8/0W9>>09bAS@2JSh/209bAS@1<09ZARP2IT8T0
WiRB09bES`2NUI00WIB?08j3P@1_Gel0J4iA09EQI`3EOhP0^4iH0<U@E`3:C4l0cTY80=9<B@3CCTT0
dda90=E;B@3DBTX0ede=0=A9C03FCU00eDeA0=5<C`3<BT`0_T120;<h>P2_>CT0[3Pi0;0l?@32CTl0
eF5R0=5OG`3BGV40d5iN0=1RH@3@I680g7=`0>R0O`3/Q8<0ggMd0<aTH@2eGeL0VEi@0>o:^03/e/40
aKBP0:ZMS02PU8H0YI^B0:JMV02QVIL0YijQ0::IWP2RW:00XifQ0:6KW`2TWZ80XIbR0:2IX@2QUil0
WYRL09fGV`2NV9`0W9JJ09VCU`2_ZJd0Lfea02`V:00f;Bh0:RDR020M6035a;l0l_7/0>KUh@80j^KU
02/0k>OT0>gUh`3^i>80lNKT0?;Wh`3ei^40mnKN0?7MdP3ZdlD0hLBd0=2]V@2mV7h0]8][0:1dD@2E
ICl0YgI=0:IeBP2lT5d0eJ]a0>BlOP3]ahH0m]6:0?SEQ03deG/0m]Qf0>oGJ`3Xdf00jMIN0>_KH@3Q
e580fm990<c3=P3MeDH0d<Pi0=[?B03Jd5L0l^^109VB@@2=S4/0/kF30:BXQ`3hn^l00?l001[ooooo
0`00o`040?n000D0X23`1P3oP0000`2P8?00oh000?n000040?n000030=1@N02P8?00X23`00@0X23`
7@3oP00Q0:0Pl0030=1@N03oP000oh0001L0oh00102P8?0_0?n00003003o0?oooooooooo00kooooo
000>ooooo`<00?l002X0imcH07URFP1nDdX0T4a;094g>@2gATd0_4E;0;a9CP2X@D@0Z59C0;9^K`2=
EeL0XGMh0?KDd`3WbLT0Ide>0:J=T@3ig^D0Z8NB0;J<V02WLh00NSY:0;5LK02/@e40^dMD0<A8D`31
B4l0_Te?0:Q9A@2HDd`0^X^50:F6P@2MRXH0VX^809V>S02JT8h0Vi6?09bAS`2JSh/0Vi2<09bAS`2K
T8h209Z?R`0j09jCS`2HSHT0WI:<09nDSP2KTX/0W9><09jET02KTXd0WIFB09jFT`2UViT0Y9BD0::5
Q`2OI6X0`FI]0;Q9D038DE<0`4]20;U5=P2b@Bl0_d`i0<aC@P3@DT<0dU130=5;@P3DBTL0eTY90=E9
BP3GCDd0e4a<0=I>C`3>B4T0b4I80;ln@P2o?T<0[S0d0;Ll?`2c>cd0^4530<5?C`3;GU/0cVEQ0=A/
J@3FL6`0eFm[0=afLP3@JVH0`V]S0:i^I035Vhl0^YjC0:JCS02UV980WYBB0::IVP2PVYX0WiVK0:FO
X`80WiVM01/0X9ZN09fHW02OVYh0X9ZN09fFW02LUYX0ViFI09bFVP2NVIl0W9NM09VDVP2[YZX0Q7n3
03Da<P0^:2P0:2@Q01HE402c/Zd0mO7^0>STh@3ZiN80kNCR0?3Rg`3bhn00lnCO0?;Ug`3`iMl00P3a
i^00903aj>40lNKP0??XhP3ej>00m^GM0?3NdP3ZelT0gLJh0=2cX`2nWH`0VGEQ08]OAP2@HDD0WVU:
0:]cD034Rf00cYAR0=^SJ03U/6`0j;MX0>c3J@3[bf@0hlaH0>?DD`3;_CP0f/a50>3>CP2lYc`0WI0Z
0?[aU02ZXe<0Q8=00;NjQ@2RYXD0nO_`003o01[ooooo0`00o`050?n000@0X23`3@3oP0000`3@D7P0
X23`0:0Pl0040:0Pl1d0oh008@2P8?000`3@D7P0oh000?n0000G0?n000@0X23`;`3oP0000`00o`3o
ooooooooo`0>ooooo`003_ooool4003o000a09bBR@1SB3l0VVUT0:9HF@2[@TP0`4U?0;Y5B`2bBT/0
XdM80:eSI02RIVH0Pe5@0<RNW`3B[jd0aZJW0;jPXP3Q`LH0X7^30<>HXP2WLgl0RDaK0;EXN02J>TP0
ZSi;0;<mB@2lAD/0_U1A0:15@02QGUH0[X5k09AgL`2KR8@0V8Z709R=R`2HSXd0V8j<09^@S02HSHT0
W96=09bAS`2KT8`0VHj:09Z?R`2LTHd0Uhb809nDSP2LTH/0Vi:;09fDS@0209bCSP0S09jDTP2LTY00
WY>A0:FATP2`SI40cHZA0;MCF`31CU<0ae5?0;M9?02/B300]E/i09Q0602J?A@0/4dV0;U>;036E3T0
be8o0<mA@P3?CD00dTe40=E@A`3DC4H0f4e:0==9B@3CBdd0e4a@0=9;D@3;B4d0`T560;m1A@2d>C/0
/S`l0:/i>037EeH00P3?HF00D03HK6X0eFUV0;aPFP2LF4l0T65I0:f>R@2UTI00XiNG0:2EV@2PUi`0
X9ZN09^FVP2ITiL0WYRL09bFV02KUIL0ViJJ09jIW@2NV9`0WYNM09nIW@2NUih0ViJL09ZEV`2MV9l0
V9JK0:FSZ02HTiT0?3Lk02XV9`0V8R40510=0:BPW@3flNh0kN?R0>oSh`3chMl0n>3L0>_Bc@3/dlh0
m^;K0?KSg03gi]h0m>OO0>kWh@3[j><0k>SW0>_YjP3^j^T0l>_X0?;Zj03ej^H0m^OT0?[Wh`3ffmL0
jlS20=N_Y`2oT8P0/7ma0:5/FP29DCX0Q4P/07Hl5P21BAH0ReXG0;fH@03N`eP0hlmF0<nm?@3JaT/0
i]1P08A[6`2DPbL0no2F0;N`G`1nOSP0/kIo0::VP`3hn^d00?l06_ooool4003o00040?n0002P8?00
oh000?n000D0X23`303oP0000`3@D7P0X23`0:0Pl0040:0Pl1`0oh0000<0d51h0:0Pl02P8?00102P
8?000`3oP000X23`0:0Pl00H0:0Pl0030=1@N03oP000oh0001L0oh00102P8?0W0?n000030=1@N03o
P000oh0000D0oh0000<00?l0ooooooooool03_ooool000kooooo1000o`00Z03Cc/P0FD]207ACC03C
W9T0YTQ=0;]8C`2iAT/0]D]=0:U9B`2SDED0[fU[07i0@@1H8240S5UH0>fo_`3[`L80ejn`07Y=DP2b
PhT0ejF^09aWL@2gLGd0[e=P0;U?F`2P:c@0/ca00;]?C@2UBd<0XEiF0;V=Q01^DD/0L5mH09B5PP2I
SX`0VXn=09R=R`2KT8`0Vhj809f@RP2MSh`0XI>@09R=R@2KT8X0WI:<09^@RP2KTX/0VI2909fBSP2N
Thl0WI:>09bAS@2OU980WI:@09f?SP2ZTI@0/HJ=0=65S`2lCUT0b4mD0<UBCP2_B3T0WdX[0?RfPP3W
/W00aI140:5U702=B@P0TdH>0:19702aDB/0^e8b0<ID>@3;DcX0d4lm0=9:?P3DBD80eT]80=E9BP3E
BD`0f4]A0=E:D@3CB4l0cdI=0=5:D037@TL0`Sm50;dl@@2i?Cl0ZRla0:`f=P2U@Sh0RD0j08eJEP2b
T8h0XXj?0:6EU`2PUI/0X9JN09bFVP2PVYh0VYBF09fGV@2LUi/0V9>G09^FW02MV9h0UY6G09^FW@2K
UY`0WYVP09^FW@2MUj40WY^T09ZGWP2[ZJh0Ui:H02hX;00/9RP0:R@V01H@402QV9T0o?3`0?7QhP3d
g^00o=kN0<RRW`1dBdL0^96:0?oKd`3Yb;l0]iV?0;bSW03bhm`0k^KS0>gYj03/j^/0inKT0>STh@3Z
iN80knSR0?C[iP3djN<0l^KP0?;Ug`3diN00nNKR0?SSgP3bfM@0kLk90>2j/@38WH`0cJ6407aD8`2h
U4X0kM5^0>G>FP3E`DP0h/]K0:B;9`1/DPL0[9`m0?S^S@2n^Eh0O7da0;2eN`2NY800nO_^003o01[o
oooo1000o`001@3oP000X23`0?n0003oP000d51h00@0X23`0`3oP0000`2P8?00oh000?n000060?n0
00030=1@N02P8?00X23`00@0X23`703oP0000`3@D7P0X23`0:0Pl0020:0Pl0030?n0002P8?00oh00
00D0oh005@2P8?000`3@D7P0oh000?n0000G0?n000@0X23`9`3oP0000`3@D7P0oh000?n000050?n0
0003003o0?oooooooooo00kooooo000>ooooo`@00?l002L0mOKa07mhL01E@S/0dJZS09Y<C@2cBTl0
^4U?0;=9B`2cCe40XDQ<09=2B02AADT0KBDY08e9BP38R8P0iJVY0<25Q`1Y:bh0SE1E0>N//P3XZk80
_gR108lc?P2Q=d40XRXc0;Dn@P2nDDh0XdU10:=PF02nTXT0X8=m079OF@1JBdP0MfUX09B6Q@2LTHl0
Vhf:09b?R@2NTH/00P2OTHh0@P2MTX`0WY>=09jCS@2OU8h0VY6:09fDS@2MTXh0W96=09fBSP2LTHd0
WY>A09nAT02UTi<0ZH^=0;V8SP3@NHH0_dUE0<i=DP3:CD/0`eM:07`W203>UEh0nm650?3=L@3acfd0
hkYN0<^KA`2aNBh0Te8>09E;302KBA40ZThK0;aD:`35DS<0c58k0=5??`3?Bcl0ddY40=M9B03LBe00
fDQ?0=M6C@3JBU<0eTI?0=U9DP3BADd0dDQ?0<a7BP32A4L0]4U80994@02AFUL0]Y>A0:FATP2PUIT0
WYFJ09jGWP2JU9P0W9JJ09^EV@2JUIT0WYVM09^FW02LUid0V9>I09bGWP80WIRO02@0WiZQ09nIX`2I
UYl0W9VR0:2MY02f/KL0THZA02TS9`0/9RP0;RDX01P?4P2OTiD0o>c]0??Jg@3kgMd0fk:a07];A`2b
PG`0kKjh0;f@RP1`B400E2lV08EXH03fiMh0ln[U0?3ZjP3Cclh0Sh^:075]JP1RGEX0MW5]09^DSP3C
c<H0k^WU0>[UhP3/j>D20>cWi00E0?3XiP3di>D0n=kO0?oNf@3oh]80QV8n0;fLF@3ceWP0i/mK0>G@
F@2mZ3l0LEX007mX3`3QdfX0jn=h0<_7IP1iNbP0Zk5e09bRO03innh00?l001[ooooo1000o`020?n0
00030:0Pl03oP000oh0000@0X23`3P3oP0040:0Pl0D0oh0000<0X23`0?n0003oP0005@3oP0000`3@
D7P0X23`0:0Pl0020:0Pl0/0oh004`2P8?0I0?n000@0X23`2P3oP0000`2P8?00oh000?n000050?n0
00030:0Pl03oP000oh0001X0oh0000<00?l0ooooooooool03_ooool000kooooo1@00o`00E@2n_KP0
CDDj09j8O@27C4T0W4940:a5B02/A4D0/DY=0:A4B02H>d<0USa509a2B`2;<SP0Nb8V07`V:@1j92L0
QBX_07TS9P2QDE@0fX^@0:1>E02>:S@0^T]D0<58C`33B4d0_Ta<0:Q9A@2NEe40_Xf60:J7PP2TSh`0
QgEc061BD@1A@d80MVQW09J7Q02OT8d0WHn<09j@S@2OTHh0XiRD09jCS`2LTHd0VXn;09^BS@2JTH`0
W96=09Z?R`2MTXh0W96=09j@S`2QTI40YI2?0:f9S@31R8l0c6ij0<Q:EP3ABU40cDQ90<iGC`2D=1`0
XEd^0?o?S03_c700j/mT0>oHJ03cg6X0lMMY0=fnE03H]E40_Y<e0:9`6`2BDPP0VDT>0:]?802cBb@0
aE8c0=1B?03ECD40fTa80=M6B@3KB4h0fDI>0=U6D03JA4l00P3JAdl02P3FAd/0e4a@0<ACD@2TDdl0
Uf1M0;FAT@2VTY@0X9FI09^EV@2OV9l209bEW080W9NM0480WiZP09^HW`2IUYd0VIJM09nIX`2LUj00
ViRO09fJX`2PWJH0W9VR09bIX02WXZT0]Jje08EoP@0Y82<0=2/^038W:`0L4180XI6D0?[Vj03hfmd0
n<o=09e[I`3c_[P0hJjZ0:=dKP1hCDH0XGYc0<naY`3bfm<0nncW0>GKf@1jLW00KfMU09RCS`2JUI40
RHB107MbK`16@Ch0EU5>0<[3`@3Xhn00cLS40=SEd03Uh]d0j>?P0>gShP3ehN80n]kK0?oQeP1iF3L0
^IYI0>gCM03Ud5T0kMeS0:2A:P1RE000/jHe0>KNH@3TgfL0em9Z07mo:@2Z[fl0UYYe0?Sjk@00o`0J
ooooo`D00?l000<0oh000:0Pl03oP0000P3oP0050:0Pl0T0oh0000<0X23`0?n0002P8?001@2P8?05
0?n00080X23`5@3oP0060:0Pl0d0oh00402P8?0I0?n000@0X23`503oP0020:0Pl100oh0000<0X23`
0?n0003oP0001P3oP0000`00o`3oooooooooo`0>ooooo`003_ooool5003o000[0?3ak029QWd0IE]A
079=AP2ACD`0UdI509]0?`2H>3T0Wc`o09Pe>P2H<c/0_UIO0:PoAP2T>Cl0UbX`09@W;@2V=ch0Z3]1
09df>P2P@480[4]B0:<h@02a?4@0aTUA0<I7CP2mBD`0[4Q809mDD@2mR8@0YH9n09n:Q@2STHl0VXb;
07IXI`1?@D00E4I507maKP2MSh`0XI>@09nASP2OU900XIJB09jCS`0209^BS@1j09R?RP2NThl0Vi2<
09fBSP2LTHd0WY2?0:RFUP2[TI80/hZ>0<R9TP35HVh0c4YF0=97CP3CB4/0ce1:0;=4<`2B=aP0hYYX
0?FmL`3fbW40lm1Z0?GGJ@3^e6D0k=ES0??LK03cfFX0km=X0=fgE034TCP0/G8U09mA3`2ZC1P0`58]
0=5C?03EBd00eDE40=Q6B@3LATl0fD=>0=HoB03NAe00gDI=0=Q5B`3BATT0`dm>0:ACC`2EGU/0/i6@
0:JBU02RUi/0WINK0:>NY02PVJ00XIZQ09nJX@2NVJ00WIZQ09bIX02MVZ40VIJM0:2JY02LV:40WibS
0:6NY`2OW:<0WIZQ0:JQY`2UWZD0]Jnc07A[KP0V7Ah0=2X[03<W:@0S4a@0]jBV0?oZk03SaLD0PeMD
08A@B`3@ViD0`Xf90=^XY03b`kd0mLc60?OId@3ki=`0o_7[0;J/ZP0K4@l0R7il0?O`jP3ck>H0m>cY
0>oZi`3Of]L0ThZ;07Q_K`31^KL0RXF108N2OP2>RhH0QX9o0;R`[P3jinT0m]kN0?kRe`1lGD00]iMJ
0?7FN`3TdE/0jn1R08Mk2`28OP/0g=A?0=cICP3Wi6<0f]Q[0861:`2VZf/0TII^0?Sjk@00o`0Joooo
o`D00?l00P3oP0000`2P8?00oh000?n000020?n001@0X23`1`3oP0020:0Pl1<0oh001P2P8?000`3o
P000X23`0?n0000<0?n000h0X23`6@3oP0040:0Pl0@0oh0000<0d51h0?n0003oP0001`3oP0000`2P
8?00oh000?n000050?n000030=1@N03oP000oh0001H0oh0000<00?l0ooooooooool03_ooool000ko
oooo1P00o`00J`3^kNT0a/>l08IgKP1dCdT0OTU3095>B02NCDX0WD9109`e>02M<3D0[S]20;4j@02l
@dX0_D590;e0B032@dh0`TA?0<17CP32CE<0^DE>09`T;@2b=Cd0bDE@0<Y8DP31B4l0/dY>09e<B`30
Q8<0ZH5o09j6PP2NShX0Vi2<09jCS`2CR8H0K65O04/m?01_HF00V8f909nDT02NThd0WiB>09fDS@2K
TX/0WIB=09VBRP2MU8l0Vi:=09bCSP2NThl0WY2?0:FCT`2_TY@0/HB90=:?V031FfD0d4eE0=56C@3F
Ad/0e4Y80=1<A`2c>Bh0Xc@P0:a:9`38LT40j9iQ0?ZlL`3mbGD0o=5c0?ODKP3be6H0kMAP0>gGGP3`
eUd0l<mN0??3H@3QWe<0X4HA0<YH=P3DCch0eDI20=a7B`3JAdl0fDI>0=I0B@3JA4d0fTE;0=E4B@3D
BDh0`e5@09m@B`2FHel0/Y>A0:FCT`2TVId0X9ZN0::KXP2NUih0WiRO09jIW`2MVj00WIZQ09bIX02M
VZ<0VYNP09nLY`2OVj@0XifW0080Y9nV03T0XijU0:6LXP2UWZD0/J^_06AKGP0[8B00<BDU02`N7@0`
7Qh0g<S70?o]jP35ZJH0[HN40>:e/P39V9@0[WAc0;AhM`2>Ee@0NDQ308]YH02_UXl0n^_T0>KMf02j
[j/0gmC@0=C9``2o]Zl0b;nh0>3Id`3omo@0d<S605Q>C@2SVIP0c<;108MoO@2TWi`0b/C40<g3a03g
i>P0mMgM0?oSf`2ALeL0[HiG0?;HP`3Qcel0gmEB0:JN6@3>ac/0em<k0=cJA`3RhU`0g]i`07eo:`2O
YFL0RY1Z0?Sjk@00o`006_ooool6003o00P0oh004P2P8?090?n000030:0Pl03@D7P0oh000100oh00
302P8?0;0?n000`0X23`603oP0050:0Pl1H0oh0000<0d51h0?n0003oP0005P3oP0000`00o`3ooooo
ooooo`0>ooooo`003_ooool8003o001A0>kZi02fYIh0SG1Z085FD02@EU80U4Y70:5;BP2]Bd`0Zd55
0:/h?@2d>d00_D160;lmA@38A4l0bD=>0<Y6D@3=BeD0`D9;0;Hd?P33?dX0bd=?0<]7DP36BE40^D]>
09m5A@2fLW40/XF209j2OP2PShP0Uhb609Z?R`2LTHd0X9FC08f1P@1JCD`0GeA@08AiM@2MTXh0WiB>
0:6FT02MU8d0W9><09ZCR`2MU8l0Vi:=09bCSP2QUY80WHn>09N2P@2_Si80]XF;0=J>V@2oEf00cdaB
0=A7C@3D@dP0e4E70=14@`3EBdT0bDE00;Lo;`2V>R00VSTF09e96P2dKBl0dYA;0>NcG`3dbF/0lm=/
0>ODF03Ted/0jmUC0?7DG03odGD0[6HQ0;U?9`3ADcd0f4]20=U7B03JAdd0edA<0080ed5:0540fDA:
0=M6B`3?A4T0a5=C09Q:AP2LJfL0/iFC0:>CU02SVYd0XIZQ0:BMY02PVJ00XIZQ0:2KX@2PWZ<0WY^R
09fJX`2LVJ80W9VT09fJY@2KUZ80V9:L09B>V02=R8l0QX6807QcN@1]If/0O7Ij04a3AP0]8B40=RHV
02`H5`1@>3H0l]SG0?_RgP3jgMT0k/c:0:j9R03U]kL0hZZ[0<^?S`3=Ti40a9B@0<6PV@1kIf00l>GO
0=K?b@2FRhL0R7ei06aSG01XGeP0D4U304i7@@25OGX0YIfJ0:JLV`2DRXT0Z9jM0:VQW`3CcLd0j>;T
0?3Uj@3`gnD0l]cN0?oUgP2cU7l0Tg=40?CHSP3PcFH0g=5C0<2i;@3QfdD0dm0`0=kMA@3Ph5X0h^5g
06ea7@2>U5H0S99/0?Sjk@00o`006_ooool8003o00L0oh004@2P8?0:0?n00080X23`403oP00;0:0P
l0`0oh00302P8?0H0?n000D0X23`4@3oP0030:0Pl1/0oh0000<00?l0ooooooooool03_ooool000ko
oooo2P00o`00:03fjnL0d/2l0:R<R027H5/0Pdi:09IBC`2TEE40[55@0:i6A`2b@D<0^3m40;/l@`30
?4L0aT1;0<U3CP3<A500cdMC0<e5C`3@Ae40cDM@0<Y8D032CU40YD530:aNG02lQh<0X7mj09R4O@2J
SHL0VHj:09^@S02JShd0WI:@09N<RP1OE580BD0k06IKE`2;P7`0WY>=0:2ES`2LTh`209jESP80WIB=
07H0X9F?0:>AS`2SRHX0/X^@0;n6S@3HRiD0_E9K0<e:D03CB4d0e4E90=I5B03FAdT0cdE30=1<A`39
Cd@0a5E20;M?=P2Q@b40V3lC08`j202BA`h0X6<T0;21>@3Wc600hmI90>SIC03YdU00ommd0<V>@02U
Aa@0dUXo0==>?`3DAT80eD=40=U6C03H@T/0fD=<0=Y7C`3HAdh0dDI;0<ACD`2IBdT0WFaX0;:DTP2O
Si00WiJI09RAV02ESYH0TX^B08b5S027PXT0PGb307afP01gLG/0KV]f06QTLP1OFfX0G5MU04m9E@17
A4d0@Sm604]6C@1:AD/0CdY>05aFFP0h;C40=RHY03/R9@0b51@0PV=Q0>S6a032X9h0TFm]06U:B02k
VIT0lLO80>^i^03IXj40[Gah0<:KUP3oj>@0lNCN0>SPg@14@C`0?SHc09fETP2`ZjD0_;Na0:nZYP2=
R8@0HEaI06MRG`3IdLh0XIVF07mjM`24Og`0JfMV07A`L@3cj^d0l>7V0?;Nh03miN40fKb/07UE<@3X
aXT0k]Am0=k>G@32^3@0gmU70<k;;P3Lfd<0h>1J0>CUO`1LHA40OHE908jFK`3gnN`00?l06_ooool:
003o00L0oh00402P8?0:0?n000<0X23`3@3oP00=0:0Pl0/0oh00302P8?0>0?n000h0X23`3P3oP002
0:0Pl0D0oh000P2P8?0E0?n000050:0Pl03oP000oh000?n00000o`004?ooool000kooooo3000o`00
3P3omO<0imGA0;fQW@2FKfX0PTm;08i?BP2EBTD0Y4i=0:U;B`2[A4L0VB`a0:D`>@2i?DP0a3i;0P3;
@dd0T03@Ae40c4A>0<a6C@37C540^Da?09m7AP2mOG/0Zh1j09EjL`2GQWl0UhZ409^@S02JShd0V8f;
0:2ET`2OU980QGYh05U>BP17?3P0IEMD08UnN02OU900XiZC0:6HT@2MU8d0W9><09nBS02VTY40ZH^=
0;F8S@35QXh0eh6<0;i>F03?BE00ddQ?0==4BP3EATX0dDM70<U8@`38DTP0`5M40:E7:`2<=a00RCT8
08i12@28@@<0Oc/007Dl001C9`00b:m40>?GA`3VfTH0imE;0??JI03/_F40VTP>0<=G<`3BDC`0dTPn
0=I6A@3FA4L0f4=90=Y4C@3F@d/0eTM=0<m7B`30DE80Uda90:9bL02DN7L0J5YJ05UCE`1GD5L0CTM>
04M0A`14?D@0AT5704I1B018@dX0BTA>04e7D`1DD5h0FEES06EPKP1ZI700M75j07aiP023OXD0RhJ<
0::MX@2BS8h0=BX^03`/;`11:2`0<Q@F07QHF@1oH5d0GC/i07mMF`3<[Z`0jLW709E/JP3^_;/0_hj:
08]OG020GeX0nnST0?W`j`3Sg]X0=34/065LF03Ie=00kNST0?3]j03`jnP0kn[W0>_Vh`20NgP0^[Fa
0?Sck`3ak>P0n_Kc08Z6Q@27Ph@0m>k`0>cQi@3_gn80m^;Q0?SMe029IDd0/XeS0?OHU@3Sbg40`;0o
0=cCD03Ccch0gme<0=oOF`3Uj840GfHH07R0A02=UFh0moW/003o01[ooooo3000o`080?n000d0X23`
303oP0030:0Pl0/0oh002`2P8?060?n000030:0Pl03oP000oh0000D0oh002`2P8?040?n000d0X23`
1`3oP0040:0Pl080oh0000<0X23`0?n0003oP0002@3oP0020:0Pl1`0oh0000D0X23`0?n0003oP000
oh00003o000@ooooo`003_ooool?003o00240?3Uh@3=_;D0VH1k07EDC@1nDd`0REQA08=9A@35PH00
ZeIK09Te?@2d>TD0_c]60<@nA`3:@T`0c4A>0<i7CP3<Be00`TiA0:]7A`2/GU`0_hF109agL@2CO7H0
Th5m09F7Q02FRhL0V8f909V>RP2MTXh0X9FA09fBSP24NGD0ET]7048g<`1XGE/0THJ20:6FTP2OU900
WI:>0:>ETP2TT8l0[Hf@0;J3RP3>QY40e7J40<5:E`3CBeD0e4M?0=A5B`3AATT0cDe:0<=CB02fEd40
NcH?07]73P2[P380`Ye20<^XA037Y3`0_Idf0:nB;028L0h0[9dV0>SNB`3TfT@0h]I60>cIF03meVd0
ZfHQ0:i=8P3@Ec`0eTi00=E7@`3HATL0f4=90=U4BP3GA4X0ddA80=59C@2mDU40RD@o09mcL02JPX00
O71`07E_L`1lMG`0OGQn089kPP27PHD0RhJ:08f8SP2ARY40Ui:H09ZEW02OVJ<0W9JP09fGX@2NVJ00
XYfT09bGW@2MUYd0Ui6E0:^UZ@23OGl0<BP[03HZ;00f9bX0<R0P0<nk^P3G`[l0g/G00?cPg03oi^80
lLg:0<BDT03[^;D0i[Jb0:AoN@38[:P0nNOS0?3Uh@3nmnl0`knf05M@B00o>380Ee1:09NBS03Hd<d0
c<O309^FT`0j=C80ZZNR0P3Qg=H05`3Gd/h0/:fX0=KEd@3]k>X0jN?U0>_Pi03_gn80o>CT0<^XXP1Z
A340dZb50>g=T03:/Ed0i]M`0=SAEP3JeU00g]mO0>KYPP1VKQ/0Mgm308B<I@3hn^d00?l001[ooooo
3`00o`090?n000X0X23`3@3oP0030:0Pl0T0oh002@2P8?0@0?n000/0X23`603oP0040:0Pl0l0oh00
0`2P8?040?n000030:0Pl03oP000oh0001<0oh0000D0X23`0?n0003oP000oh00003o000@ooooo`00
3_oooolA003o000J0?Wdl03Kd//0/J:K08ijL@1TBD80aj:L0?c6aP2`IFT0^51G0;]3C02i?4@0_Sa4
0<4kA036?dH0bDI<0<M:CP2nCDl0XD=30;Y`K@2dOg/0VGIb09=jMP2@OWX0ThF209:7P`2ISXX209b>
R`1109bAS@2UVYH0WiBB07mdLP1HCD/0Ac`j06aQG@2@QH40X9FA0:BFT`2RSH`0/8fA0;Z2R`3IRiP0
dVaj0<A7E03BAU40eTI?0=95B`3>B4T0aTm90<9NC`1m<Q<0Sf0X0>?6MP3`gG@0jMiR0>WLF@3[geT0
k^5N0>kQH@3Zff@0gLmA0>OJCP3TedX0i]U?0>WFEP3ogW<0fImE09Q24@3<FC`0ddho0=Q:AP3C@d<0
f4=70=Y5B`3HAD/0edQ<0<m8C02jDE00RdY40:EnN@2[V9@0XYRG09fGV@2IU9X0WYVO09jHW02RW:00
WINK09bFVP2PVYh0W9FL0:6LXP2NVIl00P2LUid0?02KUY`0V9>I09F@U02GTID0Ui6C0:nYZ`1SGEl0
:B0Q03H/;@0W7Ah0CT920?CTi03njNH0onKR0?[KeP3P_KL0hKB_0=:OV`30SHT0VFaW08i]IP3ki=h0
m>GP0?7Xh`37`;P0bL:j0<o8`P2HTH/0GUMA065JE02IT8/0PGQc04U1?P21NGH0[:NQ03di<029QG`0
BTDo09ZGTP3[j^D0j>WT0>GSi03Xh^@0jn3T0?;Oh`3mh>@0YXF006M2;`2jV7<0d;9l0=S4O@2HSBl0
fMEJ0>7QI`3Tih00K7@O07Z4A@23Rf@0n?[]003o01[ooooo4@00o`040?n000040:0Pl03oP000oh00
0?n000X0X23`3P3oP0020:0Pl0L0oh002@2P8?0B0?n000X0X23`5`3oP0050:0Pl140oh000P2P8?02
0?n000060:0Pl03oP000oh000:0Pl03oP000X23`4@3oP0001@2P8?00oh000?n0003oP0000?l0013o
oooo000>oooooa@00?l001P0kNST0;^b[@2CPW/0/iJ@08iNFP2HBd/0]e1D0<9AE`34Be80_d170;Xg
?`34@DT0`d970<Q=D02dATL0ZD];0<5gM02dOg/0VWMc08mgL`2BP7`0SX5k0966P02HSHT209V>RP11
09^@S02QUY@0WiBB09jDTP1nM780GE9@04e2@01]HV00T8200:>:S@2bRi00_Gn:0=j:V@3:GVh0c4YH
0=96C`3DA4d0ddQ=0<a:BP35DT/0]5Q906LU0P3D/6H0l=ef0>KKF`3Rg4X0hM]50>GPB03TgDL0j=e?
0>SJE@3[f5/0jMEL0>[FG@3WdU/0k=9Q0?OEL@3lbgl0WUDR0;Y><@3BD4<0eDY70=I5B03H@dT0g4M=
0=M5B03CAdP0d4]<0;E@C028C4@0ZhR40:>AS`2NUIH0Wi^L09F@UP2IU9X0VIBH09fGV`2GTID0V9:F
09VBV@2IU9X0WIRN09JAU`2IU9X00P2IU9P0>`2DSi<0UY6E09F?T`2KUIL0[:JX04Q2@P0/8b@0=B//
024E5@22LW80nnOV0?SLf@3BZZP0[h9m0<^LUP3V/j`0VFIR0;B5O`2EK6H0JDa40?GQfP3djND0j>3M
04U4@012?CT0EU5=0559AP1IDT`0GeIA06eRG02FRH<0a;Na0=gBc03MeL/0RX5h08N0MP0j=Bl0`Kji
0?7`k03Vi^@0i>CT0>GSi03Xi>D0i]gN0>kNh@3ih><0Y8N307iQD`2DMU`0HDTS0594303Rfg40h=eZ
0=kSO01[Lah0MX9207Z5F`3innh00?l001[ooooo5000o`060?n000X0X23`3`3oP0020:0Pl0D0oh00
2@2P8?0B0?n000T0X23`00<0d51h0?n0003oP0005@3oP0040:0Pl0h0oh001P2P8?070?n000030:0P
l03oP000oh0000X0oh0000<0X23`0=1@N03oP0000P3oP0001@2P8?00oh000?n0003oP0000?l0013o
oooo000>oooooaH00?l003T0mO3/0=[=a`2`Ui80RUQG08e3A02QB4X0[de>0;]>D@32CE<0`DI;0<93
BP2n@4@0_DE70;55A@2^De80_gQf0:ikM`2IMW00TWUd08ikM@2=P7X0TXN309F:QP2GS8P0VXn;09bA
S@2JT8h0WiFC0::HUP2PUI<0Q7Ug05mDDP1EADD0MeeP0:5fO@2nO8P0hXZH0<EEI@3;AeD0dTE>0==3
C03?A4T0cde=0<=BBP2]E4@0MCD?0>c9N03[ffX0i=eA0>;OA03ShCl0hmln0>GL@@3Se4D0kmIH0?G?
IP3caVT00P3gbG40203hbW@0n/Mh0?oCU03;OU80XSDN0<i>A@3EBdT0dd970P3KB4h03@3C@TD0ddU9
0<];C02dE500RU5:0;2ASP2QTI40WiJG09bGV`2GTYH0VIBJ09^FVP2IU9P00P2HTYH01P2FTIL0V9>I
09ZEV`2GTYP0Ui:F09VDV0<0UY6E02H0UHnA0:NQX`2PVYX0>C0a02hT9@0f:RX08Q@D0;BRXP3okNd0
^iVH05XZ9P2kQ7l0j[6Z0<nFT03V/Jd0o<_708QQG02[T8T0n^WR0?cckP3<al<0;2PU0;Fa[P3Ac<T0
_[Jc059:A`0V7AP0HeI@05iAB`1FBD40L6=K0<W0]P38_kH0bL:j089mN@2MW9P0lO3^0>KVi080i>CT
0140i>CR0>CPh@3TfMd0m^?Y0?oWj`2YSHX0G40d03PN1`1FB1L0hm]h0=kLK@3Nhgd0LG/T0760?`1e
PUL0mo_]003o000JoooooaH00?l01P3oP0090:0Pl100oh000P2P8?030?n000T0X23`4P3oP0090:0P
l0030=1@N03oP000oh0001D0oh00102P8?030?n000030:0Pl03oP000oh0000P0oh0000@0X23`0?n0
003oP000oh001@2P8?0@0?n00080X23`00<0d51h0?n0003oP0001@3oP0000`00o`3oooooooooo`0>
ooooo`003_oooolH003o000G0?ofm@3JaLD0X7Yg08QEDP23@T00TT910:E7B02eBdl0`4U=0<I9C`37
BU00`4M<0:i1A02YCDh0_7Ec0;R3O@2IM6`0T7E^08alMP2=PWh0SXF00968P`2ES8L00P2HShX0<P2M
U8l0VI6>09jDTP2PUYD0W9:A08YjN`1hFf00Kd5;09UBH03SQiH0aE1R0<m8E`3DAe00dD5:0=15BP3?
BDX0b55;0;MGB@1d;`P0i;e`0>_IJ@3Ped`0hmi40>?O@03Tfch0i]Q30>oFE@3baV<0_g/f0;EO;02n
ISP0b6m30=V3E03QSf00o:f60?fTQP2]>BX0bdM30=E:C@3GB4h0eD9:0=U6CP3EA4T0cTI:0<Y<C`2^
DE40U5aK0;2@T@2QTI80WI:F0`2JU9P0202KUYX0VYFI09bGV`2HTiL0V9>I09ZEV`2GTYP0V9>I0P2E
T9@0?02IU9P0UY:C09FATP2GTi@0ZZBV08N1P`0c:2`0=RLZ03PX:@0d8B<0hlk=0?oYj03U`[h0`8n;
0=6FTP2mOWT0chn>0<F;RP2JI680Rf9N0?KMf03diml0m^oY0>OTg`1ZIF40GEQD09N?S02KTi00<RXW
02DK6@2PUI<0fm3<0=;7`@3BbL80[:BL028K5@1MF5@0P7ai0;^j^03]k>X0iNGS0>GUi@3Ti>@0hn?S
0>WUiP3/hND0kmoR0?kXj`2LPgl0E3X]04@/4P1OD1`0g]Qf0>7QL@3Mi7d0Kg`T06Ui>01dPeX0mo_/
003o01[ooooo6000o`060?n000P0X23`503oP0090:0Pl0`0oh003`2P8?000`3@D7P0oh000?n0000E
0?n000@0X23`3`3oP0000`2P8?00oh000?n000020:0Pl0D0oh000P2P8?0<0?n00080X23`00<0d51h
0?n0003oP0000P3oP000102P8?00oh000?n00000o`0@ooooo`003_oooolJ003o001m07kfM@1ai680
FlU80;jLV02SLg00UUME0:9@D02VATX0[3m70;50B@2jBE40]DiC0:eFE`2XHf00WfaX09efLP2DMg@0
S7Qd08mnN02=OgP0Rgmi08f3O02@Qh40Thb609RAR`2JTHh0VHn>09bBT@2STi<0Z8^>0:ioQP2iLGd0
fW^:0;m9G03ABUX0ddEA0=E5C`3BADd0d4M:0<Q:A`38Edd0SSDI0:AW;`3`bg<0j]IN0>GKCP3UgTP0
iMe50>GIA@3liVH0_YDg09I;502eCbh0]DH/0;M1;@2f?bd0]3l]0:hm;@2jA3T0^3Ha0<e4A03EBTd0
eTM=0=E5B`3FATd0ddI;0<e9CP32C4l0YDmA0:5^L@2`TY@0X92C09jCV02LU9X0W9FK09jHW@2KUIT0
Ui6E09bFV`2JU9T0VYFJ09^EVP2HTiP0V9>G09JAU@2ET9<0VI>F09FAT`2FTI@0V9FF0:ZWZ01HDU<0
;28S03`/;`0Y5QP0OFU[0?3Gf033XJ<0[HF40<nQWP3CX9l0g:JU0<N>S@3FX9h0cIVI08iVI@3[dm00
mn[V0>WQgP2ZYJ40[JJS0927P`1oMFl0QGYd0:ZPV@2bZ:80SX>006]QG`1aJ6<0a[jg0:6IT`2LUi@0
QX5n0;:^[@3YinL00P3Vi^D20>CTi00A0>GTh`3Xi>@0jn7R0?3Ph@3ji^H0Rg9^054g:016;Q80H5<O
0=oJN03LgW80g^F306Mc8`1AGRT0WJV90?[mlP00o`006_oooolJ003o00<0P<000`3oP0020=1@N0@0
X23`00<0d51h0?n0003oP0004@3oP0090:0Pl0030=1@N03oP000oh0000L0oh0000<0j6Pl0:0Pl02P
8?003P2P8?000`3@D7P0oh000?n0000D0?n000050=1@N02P8?00X23`0:0Pl03@D7P02@3oP0001@3@
D7P0oh000?n0003oP000d51h0080oh000P3@D7P20?n000<0d51h0P3oP0020=1@N0`0oh000P2P8?00
103@D7P0oh000?n0003oP0020:0Pl080oh0000<00?l0ooooooooool03_ooool000kooooo7P00o`00
N@3onO@0[IRC0:J1N`2bOGT0e8j@09e;C`2G?4<0TcPm09]6B@1k<C80^7eo0>Vi^@2LKg40X7Qh09Id
LP2?LVh0S7A`08ikM`2;O7L0RWmi08f4O`2AR8<0ThV709R=R`2NSh`0Yhf<0;B7RP3<QY00eWR60;a9
FP3=BEP0dTA@0=54C@3BADd0dDA:0<e5A`3>C4X0aUE708X_502JEb<0l/Eb0?;FJ@3YeeL0i]]>0>;G
B@3]geX0m]a^0:5]7`2EAA00/E4W0;iC<`37EC/0bU<o0<Y?@03=Cd<0dDi60=1;AP3DBTP0d4I60=96
B@3@ADP0cTM;0<M;C@2nDE@0Ve5B0:^3P`2[TYD0Wi2E09jCV@2LUI`0WIJM09bEW02JTiX0ViBK09ZC
VP2LUI`0W9JJ09RBUP2HTiL0UY6E09J@TP2HTI<0UHnA09RBUP2ETI80XInP09bKV@0e<C00<2PV03L[
:`0V5QL0a[Jg0=6k_P1_DE<0SF]/0;ZHU`2nViT0ikno0<VKV02FIF40VVeZ0=fg]P3khn40mNOV0>gS
h@1bJVP0=BdZ01X@3P0O5100<BHP04Pm=`1BAd<0J5iL07idLP2=QX00X9VC06INF@1kMW80OWYg09RG
U@3bl?40103Ti>@03`3Ui>80i^;Q0>cRh`3ahn<0l]gL07]RF`1:<1l0@b`=05mE7P3Rggh0gN1g0=SQ
R01=F1@0NXAO0?7hiP02003o01[ooooo7P00o`0L0?n000X0X23`2`3oP00?0:0Pl1L0oh00102P8?0?
0?n000L0X23`0`3oP0000`3@D7P0oh000?n0000<0?n00080X23`00D0d51h0?n0003oP000oh000:0P
l0020?n000800?l04?ooool000kooooo7`00o`00B@31^[80MfUN07QQD`3J]J`0d9nH0=:FU@2SHF80
V5AE06@T902GHF40omCE0;R5R@2=EEP0ZW=f0:1bLP2HL6h0TW=`08mfL@2?O7H0SWmj0923O@2AQX80
TXN309f>R`2URhX0/8J80<Z<T@3?NH80]d]H0<a;F@3?AU00dDA=0=E8D03AA4X0dTE;0<e5A`3>CdT0
`U1508DU302SFbT0l;ac0?_GMP3bfF<0imQG0>KJE03YfUT0j/mP0:Uk9@2@EP`0Qd4309Y:5`2RBAl0
/50Z0;eF=@32ECP0a50i0<e@?P3?CD00cdQ40=18B03?BTd0a4a>0;YFF02DE5@0[8j>0:>@U02OU9X0
VY>J09ZCV`2MUYh0WiRP09VBVP2HTIP00P2OUId0;`2MUYd0VI:I09VCU`2FT9@0UHnA09RBTP2EShl0
V8nB09F<S`2^Z:X0Qh>202hX:00a;2T0=2`Z02dU8P3MeM80lNOU0>WKfP3Zf=P0lmkM0?oUhP3E/Zh0
[hJ10;bCS@1B:bH0]iFC0?gXi@3gj>D0hMKD0=G;bP3CcLd0ShV903di>P0W8b@0DDQ909J=SP2NU9<0
MF]Y08^2O@2<Pg`0XIVD0:VTX01EDDh0S8^90?;ak`3Ti>80iNGS00<0i>CT00d0i^;S0>_QhP3`h^80
k=OD06mFC`18;a/0@BX:06MM903QggX0g^Aj0=3JQ01EGb<0alfc00<00?l06_oooolO003o00P0oh00
00<0X23`0?n0003oP000403oP00<0:0Pl0d0oh002`2P8?0G0?n000@0X23`2@3oP0000`2P8?00oh00
0?n000050?n000<0X23`1`3oP0000`2P8?00oh000?n0000:0?n00080X23`00H0d51h0?n0003oP000
oh000:0Pl03oP003003o013ooooo000>oooooal00?l00240gMkH075_HP1>AcL0MVIF0<RaX@3fdLP0
dJBN0<6>RP2aNgT0Pe5@0;Z8R@3W/;D0R4]@07i1AP2?EeP0VVQW09i`L02LM780TgAa099fLP2DOGL0
TGih0921NP2HQH40W8:10:V1PP32Qh/0bW^10;E?FP37CEP0cdMA0=55CP3BADd00P3BAD/0E@3DAdd0
cdM90<m=C@35D4L0US8K09A26P3KVe/0n/Yf0?ODL03/dV<0i]9I0>kJI03dfFh0k<YX0=B[D@2eQC<0
XFTN09ED402=APH0U4<;09Ll3@2_Ab80aU<h0<i@@@3>CTD0aTU70<9@D02cEeP0TUaM0:ZEU02KSi<0
W9FL09VDVP2IU9/0W9FM09fFWP2HTIT0ViBK09nEW@2KU9/0W9FL09VBV@2ITiL0WINK09B>T02GTI<0
U8j@09F<S`2IT940/jZ[06=MG@0`:bP0<bh[01hI5@1LEe<0l>gX0>_Xh`3]iN<0l>CT0?CTi03ihMl0
djf/0>>g/`2XOgT0VWE_0?GFd@3mi^00onoX0:JGU01<@T00FeEE075]KP18ATT09B<V02TT:01>B4X0
W9>D0=K<b`3cjNL0[JBO0;N^[03Xhml0QH5n0<c;b@3/jnT00P3UiN<20>GUi@0>0>CTi03Whn@0j=kO
0?GUi@3Tcl`0ITi204D/5P12;PT0L6XY0=oRM`3OiWh0`LUl09JNK@3fn^T3003o01[ooooo7`00o`02
0?n000030:0Pl03oP000oh0001L0oh00302P8?0@0?n000L0X23`5P3oP0050:0Pl0h0oh000P2P8?00
0`3oP000X23`0:0Pl0020:0Pl1<0oh000P2P8?000`3@D7P0oh000?n000030?n000<00?l04?ooool0
00kooooo7`00o`00B03fn?<0/K:Z06=TEP1=BSL0R7eY0<jiZ03=/:80/hf40=R]Y`2lSh`0YgMg0<FB
U@38TIH0/gZ00;EmP02XKG40SU=I09aTI`2RKfh0X7=^09agK`2EMfl0TWUb09IoN@2IO7P0Xg]k0;Z1
Q`33N7l0]5=N0<YCG@3;B500d4U@0=56C@3BAdh0e4M?0=95C@3AAT/0e4U>0=9=CP3>DDd0Z3LY098/
4`2eGCL0i9eW0?_2O@3jcGP0l=5[0>gFIP3[eV40m=mZ0?CMJ@3_f6H0iLUL0=VhD@3AZDX0gJIF0;AY
;`2O@QL0bELl0<]B@@36CdL0^U5>0:]JE`2AIF@0YYRH09R?TP2HTiT0VIBJ09^FW02IU9X0Ui:H09VB
V@<0VYBH03l0VI:I09B?U@2FTIL0VIBJ09JAU@2ET9@0THf>09B>T02PVYX0YijO03`d<P0c:bT0=2`Z
01PC402MV9D0moC_0>WVh@3[hn40l>;R0?GSh`3cemH0ZGen0=JRX@3IZJL0o]OB0?WKd`3PaK`0Yi28
0;NVW`37_;X0WiVI08b8R@1aK700CTU=03Xd>00X8R@06aDG04Ln?`1mMG<0FU9@071XIP3>bLH0JfMT
0>WXiP3XinD0i>CR0>CVh`3Ti>@0hn?S0>GSi03Vh>80j=kO0?WYj@3Ha;d0GDHh04Pb6P0m;040RXDg
0=WOL`3RjXL0a/n@0>7Wa@3mooD00`00o`0Joooooal00?l00P3oP0020:0Pl1P0oh00402P8?0=0?n0
00D0X23`5`3oP0040:0Pl1<0oh001@2P8?000`3oP000X23`0=1@N00=0?n000<0X23`00<0d51h0?n0
003oP0000`3oP003003o013ooooo000>ooooob400?l007H0eMK>07j0LP1LFDP0LFEE07UXF01MACT0
d;:X09E`JP3<Xil0`9BD0=NYZ`3LZjh0kK^l0<2<SP2/LGL0WF9V08MAD@1nCDT0SF9K09ekL@2HNW00
V7aa09QgL02PMg<0]W]m0;icN02YBU80`U5I0<U<DP3=C540d4]@0=5:D03@BDl0dDQ?0==8C`3EB4h0
eT]@0==;C`3ED5<0`dM50:4_902B;QL0[5Lb0=B;F03e_G<0n<mc0?CAJ`3beVP0kmIR0>gHH`3_g6H0
kmYW0?CHK@3og7l0kkI_09554@30FCH0aUHn0<=EB02eEdl0WeQD09UdLP2NU9D0ViFI09JAU`2IU9X0
VYFK09VDVP2MV9h0ViBK09^EV@2HTIP0W9FL09ZEV`2GTYP0UY6G09F@UP2ET9L0UY6G092;S`2:QXL0
WYZI08b6QP0[8b40=bl]030X9P0V8Ah0d/k;0?7]jP3Xi>40kN?T0>oOhP3ghN@0kloB0:5`M030QXT0
_hN60?W>b02eU8/0aJRP071ID@2hYj00o?;`0?3ZjP3]jn`0k>[[0>GQhP3EdM80al?40:>OX02<R8T0
R8:40:bVYP22O7`0J6AS06aXI@3^kN/0inOU0P3SiN803`3Ti>@0iN?T0>KRh`3Wg^40j]_N0?g[j@38
/ZL0DS/Y04@_4P0j;000ZJM?0=ONMP3TkI@0hNNg0?_nj@04003o01[ooooo8@00o`020?n000040:0P
l03oP000oh000:0Pl1@0oh00402P8?0>0?n000@0X23`5`3oP0040:0Pl1X0oh0000<0d51h0:0Pl03o
P0002`3oP0030:0Pl0D0oh001000o`0@ooooo`003_oooolR003o000R0>c]i`2l_;@0UY:7081hK@1@
A3P0R7I/0:N?Q@2hWI@0d;:Z09E`JP3E/:X0n]OC0<bVX`2AIF@0X7Ac0:5hMP2XPG`0QV5I071@A@22
HUD0V7Q[0:5kL02XMg00]gYg0<9dM02=;S80[T550<=?DP34C4h0aTU=0<M9C03:BDd0d4i@0==<D080
dDU=04<0dTU@0=5:D03@BDd0dDm?0<Q=B02^>Bl0UBXF0:Q::@3FQ5@0jj=X0?VjM@3la7L0o<ag0?S@
L@3ecf`0ll]Y0?W=M03odh/0YFH`0:=9902oFd40_5]:0:mKD02@Ddh0XH>109nEUP2OVId0WYRL09ZD
V02ITYT0Ui2H09bEW@2GT9P0TX^B08n:T@2>RI00Q7n608=nQ@20Nh80N7=j06QUKP1UHFP0GUUP04=1
A01eLG80K6IX03`f=P1JDE80:B0Q04m9B@3^j^T0jNGT0>[Ti03^h^@0lmkS0?cOi03:XZX0TV5W0<63
QP2UJ6L0]hJ108eXH02YSXD0]jJN0>SMe`3]j>@0inKT00<0i^KT0P3Xj>H02@3YinP0j^SY0>KTi@3X
i^L0`l7108j=R`3Kf]P0k>c/0>GUi@030>?Ui00>0>GSi03Yh><0k=gR0>kNh@3njnL0X8Ym04Tc7010
;@`0?S<00<W;J`3Lhh@0i^jU0??fe`3ko?@4003o01[ooooo8P00o`040?n000030:0Pl03oP000oh00
0180oh005P2P8?090?n00080X23`4P3oP0040:0Pl080oh00102P8?0X0?n000<0X23`1@3oP004003o
013ooooo000>ooooobD00?l004L0k^kV0=C@a`2XWiH0XIB;0;2RU`36]J/0EShd09f5N`3Qb/80hL[4
0;NKU`2eVIH0dKFb0??JeP3L`kh0YHb508A/HP1`EDX0OEeB091UG02_N7<0aX9o09E4@@2I>CT0[dE5
0;=5AP2iAdL0_TY;0<9:B`37Bdd0bTa=0<a;C`3?C540c4U?0=5;DP3>BDh0dT]A0=E@E@3BD580bdi<
0;Q0>@2N<Ad0VSDI0:94802dGC00bGU40=><C03XYEl0lk=[0?RiMP3oahh0k:Qk09Y18@2hF480]Ue=
0:MMDP29E500W8:208=hO01nN7`0N79f06eWJ`1XHFP0H5UQ05YCF`1:@d/0C4E<04m8D01:AD/0BdI<
05A?E@0205QCFP0S05MBF@1QG6<0If9X07YhN`2@S8d0@Sho03li>@1RG5`091hN096;R`3elO00i^;Q
0>[Ti03^gn80n>7W0?;Cf@34Vj40jKRl0<66QP2@EE40WVmY0<>NUP3H_KH0nNKO0?;Th@3/h^00jn?P
0>_TgP3/hmh0jnCN0>SSg@3XiN00in?P0>KUh`3WiNH00P3UiND01037alD0jNWW0>GUi@3Shn<20>?U
i00>0>GUi@3Whn@0j]kR0>cLg`3dh>40l=_F06iGA`15<1<0>2T007E^:P3GfgH0i>^K0>gd`03ko^/5
003o01[ooooo9@00o`060?n000030:0Pl03oP000oh0000h0oh0000<0d51h0:0Pl02P8?004`2P8?04
0?n000040:0Pl03oP000X23`0?n00080X23`1`3oP00>0:0Pl080oh00102P8?0Y0?n00080X23`1@3o
P005003o013ooooo000>ooooobP00?l000X0moC_0>COf@2m]Zl0QGac08j4NP2XWiH0^k:[0=;9a03_
iN<0ooKe0`00o`00LP3fkNP0fm3:0;ZYXP2GOWT0SFaU08mRG02:DDX0TDM109Y1?@2R@3d0Z40m0:Ln
>`2dATD0]TA40;m9B@35CU00`d]=0<A<CP3:Ce80bdiB0<U;CP3>CE40d4mC0=5ADP3?Cdl0c4m;0<97
?`2g?S<0/CT[09l/6@2M;AL0Wc<I0:4i702gE3L0`VA;0=enJ02S?Bh0]U550;IOEP2JEE00T6=P089]
K@1KEEL0GEMK05]FFP1LEUX0GUQL069HH01[HFT0JEmW07E/L@1lLWX0OgUm08N1Q@29PhL0RH:908f6
S@2ARhl0UI2C096=SP2/Z:L0RXJ502dY:00X9240:RHS02`X9@3EdLh0lNgZ0>OSh03Yi>40kn7Q0?[T
iP3_dM<0[8F60:UlN@2cPW`0Y7Q_0?WBb`3ge/l0hlBo0?7He03dhMd0mN;N0?OPfP3fg]@0n^3C0?_Q
e03fhmD0l>;G0>cSfP3Yi=h0jNKQ0>KUh@3Jf]P0WIfM0>c/k03UiNL0i>CV0>;Th`3Ti>@0i^CU0>WP
h`3/gN00k]cL0?_Vh`2kXY/0BS4M040/1`18?P40aL=`0=_TO`3[lkL0n?gM0?_mlPD00?l06_oooolX
003o00X0oh000`00o`090?n001h0X23`0`3oP0060:0Pl0h0oh00102P8?0X0?n000<0X23`1@3oP005
003o013ooooo000>ooooob/00?l000@0k^kV0=OGc`3Vi]h0n_Wd2@00o`00G@3om_80lN3I0=S1^@2k
VY<0Vf]T08Y=B027@3`0T44l09M2?`2M@Sl0WC/h0:Do?@2^A4@0/DE30;I6A@2lBTX0_DU:0<9;C@37
Ce00b4e?0<a@DP3<CE00cdaA0<i<CP3AC4l0dDa=0=1;C03=Bd/0a4A10;/n?02a=c@0Yc@_0:8b;P2f
BD@0^EQB0:iMFP29CD`0Ug5`09f<SP2BS8h0THb@09NBUP2HTYH0UHnC09R?U02NUIX0XIRM09^BU`2J
TIH0ViFG09bFV02FT980UHnC09ZDUP2ESi40Thj>09VEU02[Yj@0F5AA02@P7@0a;BX05Q8?06APG@3a
l>`0j^KS0>WTh@3[hN00l>3P0?SPh03hf=T0hKVi0=b/Z03FZ:00oMG=0=F`ZP35Y9l0IdE30;:CT@3o
h^80nmWG0?S;aP3W/ZX0dYb@0<nNS`3S_:d0mMW;0?KTf03`i]`0j^KK0>OTg@3Shmh0gMgK0>KVi002
0>CTi00?0>?Ui03Ti>@0in7S0>WOh03[fm/0ln3L0?OPf01kI5@0@b/A03TY002=QSP0h^>50=kWR`3a
m/d0nog_00H00?l06_ooool[003o00@0oh002@00o`0:0?n001T0X23`5`3oP0050:0Pl2P0oh000P2P
8?050?n000H00?l04?ooool000kooooo?000o`005@3bhMh0b[6]0:N6P@2BJF<0PDm808M;@`2=A3h0
TSlk09a1?P2Q?c`0Y3hj0:Hm>P2]@Cl0/TA30;a<B`2oCDd0_Ta<0<A>D039DE<0bTmA0<U=C`020<m>
D`0>0=5>E03@CE80cTeB0<mAE@3<Ce<0a4e?0<5DE`2iGEh0VU=A085?CP2UQhL0VH^<09>=S`2BS8h2
09B>T080Thf?0400UHnA09R?TP2DRhh0U8j@09F?T@2DSY00TXj=096;S@2DSY00TH^=092:RP2RWIX0
U8n<03Td<@0/9b@0<RdZ01PD4`2UXJ00mO7`0>SRhP3[hn40kn7Q0?KRh`3efmX0eK>b0:n3PP2gPGl0
WFUU0<FHU@2/Q880dZb[0:J0O`3Q^[/0on7R0>F_[`2PDU00VT4m094h<027=b`0Rde009maHP3:[Id0
jMS80>_Rd@3Vhm@0jNSM0>OXh03TiMl0iNKQ0>?Sh@3SiN@0i>;S0>SOh03[gM`0kmkG0?kZg`32[I`0
@bhC03XX001ICQ00clY/0=_LMP3WkJ80n_cT1`00o`0Joooooc`00?l02@3oP00F0:0Pl1L0oh00102P
8?0X0?n000<0X23`103oP007003o013ooooo000>oooooch00?l00280ooSc0?GVh@3Nal40aZFN0:Ul
M`2AFUL0QTE10916@`2;?SP0UT<m09]3?`2M@Sd0Y4E10:A2?`2Y@d40/TM60;U9B02nBT/0a4e?0<Y?
E03;CU@0bdaC0<]<E@3=CUL0cE1H0<Y>EP34DEP0_5MK0;5OH@22ATH0UFe]0:F=S@2DRHT0ShV;0`2@
RX`0@P2?RH/0Thf=09:<S02ES8l0THR;09B;SP2CSHl0TH^;092<R`2>R8X0S8J608j8R02@RhP0YZ6N
065LF@0[9R<0=Rh/02DM6`0k=CD0gmWI0>oYj@3[hN00kn7Q0?CRhP3hh^@0_:2O0<6NW03/`;l0ikBc
09UYJ01mDe@0[HJ70=>[[03M[k40omCF0?:f^02;@D80YdU90<=OG@33JF40/VEK091FB01W?R`0H4D`
065C>@1iLUP0_KbP0>c^f03VjmL0i>SI0>?Wf@3Si]/0hnCL0>OTg@3ZgmT0kMcB0??Rd03gi/`0PVm?
03XY000j;`00Y9m=0>GTNP3LgWT0l?Fn0?_mk`L00?l06_ooooln003o00`0oh00402P8?0G0?n000D0
X23`4P3oP0030:0Pl0<0oh000P2P8?0>0?n00080X23`1@3oP007003o013ooooo000>oooood800?l0
01h0oo?b0>oKfP3I_KX0]YF@09ieK`2;G5@0PD]108A5?02:A3`0UDI10:18A02TA3l0Z3ll0:`n?@2f
ATD0^DI90;Q3B@2kA4X0`4QA0<=;E@32CEH0`4iF0;iFG@2eGf80Ue=D081BDP2TQXH0V8R909>9R`2>
R8X2092:S01308n6R@2AR8/0THR;09B;SP2CRXd0T8N:09:7R`2DRHd0TXb>08b6R02<QXH0SHN7092:
RP2HTHl0SXJ303L_;@0a:BL0>c8c01`C501eK6l0m^g^0>kRi03ag^00m=kP0?[Ph`3ign80gl730<^Y
Z032W9/0Vg9`0:N3Q03Ybld0omoV0=ba^01e=c`0gXnB0<5XJP2L?Sh0c6mZ0;m/I02EEd`0R5i>09n6
LP2YWHD0X9]m08F5H@2b]8`0emjb0<G?Y@3Kil40gn[80>?/c`3Vjm@0i>OB0>OUd03[g//0k]k40?_[
a`36^8/0@c<0040f001iM1P0eMMZ0=SOK`3Uk8l0m_WF0?_lm007003o01[ooooo@P00o`0;0?n000`0
X23`603oP0040:0Pl100oh00102P8?0D0?n00080X23`1P3oP007003o013ooooo000>ooooodH00?l0
01X0o>gX0>SDc@3:[JD0ZhIn09Q[I@2:EDl0S4m:08Y1?02HAD40W4910:12@02P?3`0YSm00:Hl@02Y
?440Zci40:e2B02cC500Ze5C09]CE01lAT@0UW=_09f8P`2CQH80TXZ808j9QP80SXR80480ShJ70968
R`2?QXT0SXF80927RP2AR8/0ThR<08n4R02DRhh0RhF708f7Q`2<QXH0S8N409bFT`1FCT`0:b<Q03L^
;`0b:BX08QTL0;fg^@3gk?00l^?V0?7Mg`2XRhl0[XnD0>W:c`3mgN00kl_;0=>`[P2FM780m]gL0?[T
i`3oj>l0_Y>L07`c>P2bEU/0ZD950<=MF`37L6L0TTi309meI`3Xdl80[ZRB0820I01hNEL0NW]A08b<
FP2<SeH0HFP_06ikA@26U640]lBI0<7<Y03?d:h0hMfj0>kP_@3gi[X0i=FJ07a`:021Mb80Yj8n0=?B
G03MhfT0gNAj0>[cY03jo>P8003o01[oooooAP00o`0:0?n000T0X23`5`3oP0050:0Pl100oh00102P
8?090?n00080X23`403oP008003o013ooooo000>ooooodT00?l00240ooCc0?OUh`3Wd/l0eKVf0:b8
P`2GIf<0SEIC08Q7@`2=@Sd0TSlk09Y1?@2N@3h0Xd520:92@`2PB4H0TDI105lT8027G5D0X8El09Z:
O@2@QWX0SXEk08f6OP2<QGl0SXJ308b7Q02?RHT0SHN708^5Q@2<PhH0T8N:0966RP2>PhL00P2>QHH0
>02BRHX0RX62092;R02;Q880<2LX03<X;00e:Rh06Q4D05UCE`3Yi>P0kNO[0?CXk03`fn80U7In09Ed
N`3YaLT0j/?60;fFU`3B[jd0Of5O0<>/[03eh^@0onW_0=:W/02;@TT0bV]a0<IMH@37IF80]FQN08mJ
C03TbKP0QW]Y06]VD02ASG80SXIR07Q[?P1UFAl0HePF07Qd;01[MC00IgHe06Ih?P1IIS40Gf4_07E]
?02KREL0VHE809B4;`2/XCL0e<a@0=GBC@3MhEH0e=eP0>?/T@3/m;/0O_md2000o`0JooooodT00?l0
2`3oP0030:0Pl080oh0000<0X23`0?n0003oP000503oP0050:0Pl100oh000`2P8?080?n00080X23`
00<0oh000:0Pl02P8?000`2P8?0;0?n0000308300000o`000?l000H00?l04?ooool000koooooC@00
o`00E`20nWT0nNCQ0>oBcP3L]k40b9VC0:efL@2PHeh0UU9?099;A`2=B4<0O3df06Td;01hD4H0[i>7
09R7M@2CR780S8I/08b6K@2<QW00S8Md08Z4M02:QWX0SHUn08V4OP29Q800R8>008b4PP2=Ph@0SXB3
08f3P@2:P7h0SHAo09B;QP2TViH0F51<03L];00j<34091/N03T`<`3@b/`0k>[[0>KQi@3[h>H0l=oW
0?KOi`3eeml0]9BI081PH`36Z:P0iLW809EmO@2`WYl0ln3T0?WPiP3oeMl0ZemY0:m@F03;I6P0b6YX
0:=ME@2VN6/0/I^=05I??@3Of/H0em2f075Q?`1TCb00b[Ef0:JBB@2_Y5H0TiE:06af<@1]McP0J6h`
06eY:P1[H1h0JeTA06UG0@2aY3@0f]5>0<g;>03KgTL0e]e?0>7ZM`3VkJL0mogI07koN@08003o01[o
ooooC@00o`000`20`000oh000?n0000O0?n000030=1@N02P8?00X23`0080X23`4@3oP0030:0Pl0<0
oh0000D0X23`0?n0003oP000oh000:0Pl0040?n000<0X23`303oP0000`20`0000?l0003o0006003o
013ooooo000>oooooe800?l00580ooGc0?_Vh`3[d/h0f;Vf0;^LV@2:KfP0[iV>0>OGb03Yg/X0a;nQ
09fKM@2IUfh0T8mQ08^:GP27Q5/0R8IP08J7I@26QVX0QH9_08F2L`2:QWd0Pgmf08^2O@2;P7X0SX5h
08n1MP2HRWd0Z9b>089fJP0i;2@0?34]028J5`12?CX0_[Zi0?7`kP3ViN<0iN?T0>WSi`3]h^P0n^gd
0;2OY@22Kg<0^jRZ0;NWZ02[WId0^:b/0>cOhP3eh>L0f;W10>:^^P3m[kd0/59P0;aFH@30I6L0XE]I
0:MjM02JPg/0I5Y>08AmJ`26NV80ET8Q09AiBP3^di00g/Mk0:^KCP3UgYX0NgLh06IP901gKc00O6hU
07YZ5@2FQb80c<1:0=K>A@38ac40e]Xo0=[PC03MiVD0iNn?0>oea`3jo^d0OOik2000o`0Joooooe80
0?l07@3oP0040:0Pl140oh00102P8?030?n000040:0Pl03oP000oh000:0Pl0H0oh0000<0X23`0?n0
003oP0002`3oP0000`20`0000?l0003o0006003o013ooooo000>oooooeL00?l004/0ooWc0?Wek03g
lnL0l>oM0=SH_P31`Z00^;RB0:j_Q02SY7P0WYea09RIK`2?U6`0Q8QU08>6J`25Q6l0QHAb07miJ`2;
Og40UHEe09Z8LP2KQfh0[9Qm08QgF`0n;Q@0@C4J034R3`0h<1d0cLJd0?[di03[j=T0inGI0>WVg@3/
i>40jn?P0?3XiP3Hd<h0iM_J0?O]k03/in@0j^KU0?7[j`3^i^T0n^W_0=2b_01[?DP0Z65a0;APL02l
HVh0_V]c0:EYJ@2<IV<0[ibF05M>A@2o]jX0d/Nc05a9:`2QREd0k=:G0>cES`2_WUX0]j]a07AW<01o
KSH0PW4/079P302aX3P0gm5F0=C=@@3<b340c/lc0=_RA`3Hh5L0i>f20=oVX03ioN802P00o`0Joooo
oeL00?l05`3oP0040:0Pl1@0oh0000<0X23`0?n0003oP0000P3oP000102P8?00oh000?n0002P8?0C
0?n000X00?l04?ooool000koooooF`00o`00A`3in_80moW/0>c]g@3LglT0`<BY0;BgVP2/[i00YZf<
09VPO`2RZ8`0Yj^B07UiH@1cJeH0ZYZ30=BlX03</8/0[8mS08=X>@1>>0H0?bX004dh2`0l:P00ZIe]
0?kca@3djl80l>S40?3Yc03_im00knOD0>oVe@3]iMP0kNOK0>oXh03ZiMl0jNKQ0>GTh03Xi>40j>?R
0>kSi`3ii^`0Zh^F081<F@2OGfd0/6ai0:mbNP2<HV@0M5YI0>SMf`2IU900TXj508InL@1AABl0M6A3
0=C1UP3agjd0SGi>07=R=`2EPUL0SGQ306]D3P2cXCd0h=9G0=37>P38aB`0c<``0=cQA`3Gh540h^]f
0=OOU03/lLP0nog_00X00?l06_oooomK003o0180oh00102P8?0M0?n000030:0Pl03oP000oh000140
oh002P00o`0@ooooo`003_oooomN003o001303oo?P1mogP0O?af07GfK@1_lFH0I>ML05_OE03>dL<0
[JbN0;:]W`3Hc;/0^:RA09F2H`2XU6`0`k:00<NiP02n/G40[j=K09jB@`33^6<0dlMb0=;3L@3=_Fl0
d;ei0=S6Q`3Oc900iM>K0>cKZ03ah;<0ln:h0??R_P3bh/D0lN?90?;UbP3`i/d0knGA0?;Ue`3hi]`0
jLc70<BRWP2^SHX0Z8V70:RCSP3?a;h0lN_X0>[Wh`3Iem80clc30=K>`P3BbKP0_:nJ0;2RR038^IX0
iM>_0<>_O`2COCD0c;QG0=[<CP3@bCL0b<H[0<kB<`3FgD<0en5E0=cWL`3CgHT0hnW00?cnk`0;003o
01[oooooGP00o`000`10h000P<0008300004083003`0oh002`00o`0@ooooo`003_oooomY003o000g
0?omm03oo>d0mo;N0>gZb`3Ng;<0eMBN0=SHU03LfHX0f]B00=oFN`3Mcfh0dKmK0<F_C02jXSh0[IH^
0:F>9P2ORBH0X8TY09n6;02_UD40^9iD0<>/J039]G00hm6A0>oNYP3agjl0l^6e0?GV_`3hj<H0nN[9
0?W/c03gk=00lnW@0>gUd03]iM80kNCC0>oVe@3`j=D0o?7M0=S;^01lKEH0jMZi0:ZHJ024LB`0i]A`
0=G8B03:`c@0alH]0<_?=03Hh4`0dMeE0=k/NP2ga7D0bm>T0?cokP0<003o01[oooooJ@00o`0g0?n0
00`00?l04?ooool000koooooJ`00o`00=@3moOD0o_kd0?cmk`3mo>X0m?GI0>[ZaP3Pgk<0fMRP0=3;
Q`3CbgP0h=A`0>OJJ03XfUd0j]aI0>CFD@3Pcd/0e<=10<Zh?02kZSP0ZYPZ0:>A9@2PS2T0WhLa0:^B
@02lXUL0_jQT0<^fM@3JaH80im:A0>oKWP3cgZL0m=j]0?KO/`3fgkH0n>:i0?SS^03likX0m=nb0>?A
X@3^gJT0NF@Q0<^gH03HbEH0b/8k0<G2<`39bcT0f=mA0=?NF`3LkG/0`m=k09nYM`3bmn00nocd00`0
0?l06_oooom[003o03D0oh003000o`0@ooooo`003_oooom`003o000_0?gom03lonh0o?oT0?7_aP31
_h@0`KaZ0<k7G`3Ab540f=1;0=G<?`3Oe4@0hmM50>_OC`3[geD0k>1H0>cNF@3VeEX0f/IF0<nhD032
[4T0ZIHj09j==@2OSSH0WH/e09b7=P2bW500Zi==0;:IE`30YVT0aJ]^0<nfM03D_GX0g<N40>;?S@2b
Xf00UXHh0=g@L034_D/0_ki00<c?CP3BfeX0dMaR0=[ZO`3Ahhd0PY9D0<gF^@3loo@03@00o`0Joooo
og000?l0;`3oP00=003o013ooooo000>ooooog800?l002`0o?kc0?oolP3]kM40/k610;:_JP39aF`0
d/iS0<W3B@39`C`0b;ld0<_3=03CbcX0fM500=gBA03Me4X0gmIE0>7IG@3Sg6P0hmaa0=kIL`3MegL0
f=9d0=;9KP3?a6X0aKMO0;RXD`2cXU00ZYQ40:>A>`2HQS00UhLb09b=?02DRCd0fmB30<G4JP2c]eH0
a/iY0<gIL`3:fWP0`]Ek0:c1M01^PTL0UjF10?OnkPh00?l06_oooomb003o02T0oh0000<0X23`0?n0
003oP0003P00o`0@ooooo`003_oooome003o000X0>OVd@2OX7P0WIaS0;VgK@3<b6d0eM9[0=?@G@3<
bTl0c/]:0<c9AP3:adH0blI<0<2oB`35a5P0`<1L0;g1H`30`f`0a<Eg0<72MP38aGP0cLYm0=K>P`3I
dHH0g]F:0=oFR@3NdXH0gM650=O>P`3FcXH0e]2?0;nnO@24Qd80Nh8n08^FDP28Ue@0TJ5R082AFP1Y
NTd0NHQY0>;[f0l00?l06_oooome003o02D0oh0000<0X23`0?n0003oP0003`00o`0@ooooo`003_oo
oome003o000J0?gmm@3em^P0gmo70<o@[P31`YH0`L:90;k1O030aG<0aLY`0<K;K@34afh0blam0<c=
R@3AdYP0blnL0<W<W`3HgKD0h^?10=oP_P3Nh;/0i>K10>WV``3/j/@0l>c70?7]a`3`k<H20??_bP0;
0?;_c03^k<h0g]o00<[=[P38cJl0cM>g0=?I_`3IhLT0hNWD0>_bhP3eno404000o`0JooooogD00?l0
9`3oP00@003o013ooooo000>ooooogT00?l000d0n_g/0?7eg03Sil@0c=:V0:nfPP2e_H@0cm>P0>_]
``3bm]D0mo_R0?_nj@3jo^l0nokc00<00?l00P3moo800`3no_80oOk`0?gnl0040?gml@030?gml`00
o`000?l001L00?l06_oooomi003o00d0oh000`00o`0:0?n001T00?l04?ooool000koooooN`00o`00
1`3moo@0o?ka0?[mk03io>/0o?g]0?gnl@3moo@0:P00o`0Jooooog/00?l01`3oP00Z003o013ooooo
000>oooooj`00?l06_oooon/003o013ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {220.938, 0}} -> {-0.0523276, -0.0277532, \
0.00527483, 0.00527483}, {{9.875, 190.438}, {215.625, 115.438}} -> {-15.0024, \
-13.1403, 1.05837, 1.05837}, {{208.5, 389.062}, {215.625, 115.438}} -> \
{-225.221, -13.1403, 1.05837, 1.05837}, {{9.875, 190.438}, {105.438, 5.25}} -> \
{-15.0189, -124.786, 1.05854, 1.05854}, {{208.5, 389.062}, {105.438, 5.25}} -> \
{-225.271, -124.786, 1.05854, 1.05854}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error plot", "Subsection"],

Cell[BoxData[{
    \(\(cnt1 = CountPixels[class1];\)\), "\[IndentingNewLine]", 
    \(\(cnt2 = CountPixels[class2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bar\  = \ {cnt1, \ cnt2}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(BarChart[bar[\([1]\)], \ bar[\([2]\)], \ 
        BarStyle \[Rule] {pointStyle1[\([1]\)], 
            pointStyle2[\([1]\)]}, \ \[IndentingNewLine]Frame \[Rule] True, 
        BarLabels \[Rule] {"\<Kellogs\>", "\<Tide\>"}, \ 
        imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.00838773 [
[.27273 -0.0125 -23 -12 ]
[.27273 -0.0125 23 0 ]
[.72727 -0.0125 -14 -12 ]
[.72727 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09859 -12 -4.5 ]
[-0.0125 .09859 0 4.5 ]
[-0.0125 .18247 -12 -4.5 ]
[-0.0125 .18247 0 4.5 ]
[-0.0125 .26635 -12 -4.5 ]
[-0.0125 .26635 0 4.5 ]
[-0.0125 .35022 -12 -4.5 ]
[-0.0125 .35022 0 4.5 ]
[-0.0125 .4341 -12 -4.5 ]
[-0.0125 .4341 0 4.5 ]
[-0.0125 .51798 -12 -4.5 ]
[-0.0125 .51798 0 4.5 ]
[-0.0125 .60186 -12 -4.5 ]
[-0.0125 .60186 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -23 0 ]
[.27273 .63053 23 12 ]
[.72727 .63053 -14 0 ]
[.72727 .63053 14 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -84 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kellogs) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tide) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09859 m
.00625 .09859 L
s
[(10)] -0.0125 .09859 1 0 Mshowa
0 .18247 m
.00625 .18247 L
s
[(20)] -0.0125 .18247 1 0 Mshowa
0 .26635 m
.00625 .26635 L
s
[(30)] -0.0125 .26635 1 0 Mshowa
0 .35022 m
.00625 .35022 L
s
[(40)] -0.0125 .35022 1 0 Mshowa
0 .4341 m
.00625 .4341 L
s
[(50)] -0.0125 .4341 1 0 Mshowa
0 .51798 m
.00625 .51798 L
s
[(60)] -0.0125 .51798 1 0 Mshowa
0 .60186 m
.00625 .60186 L
s
[(70)] -0.0125 .60186 1 0 Mshowa
.125 Mabswid
0 .03149 m
.00375 .03149 L
s
0 .04827 m
.00375 .04827 L
s
0 .06504 m
.00375 .06504 L
s
0 .08182 m
.00375 .08182 L
s
0 .11537 m
.00375 .11537 L
s
0 .13214 m
.00375 .13214 L
s
0 .14892 m
.00375 .14892 L
s
0 .16569 m
.00375 .16569 L
s
0 .19925 m
.00375 .19925 L
s
0 .21602 m
.00375 .21602 L
s
0 .2328 m
.00375 .2328 L
s
0 .24957 m
.00375 .24957 L
s
0 .28312 m
.00375 .28312 L
s
0 .2999 m
.00375 .2999 L
s
0 .31667 m
.00375 .31667 L
s
0 .33345 m
.00375 .33345 L
s
0 .367 m
.00375 .367 L
s
0 .38378 m
.00375 .38378 L
s
0 .40055 m
.00375 .40055 L
s
0 .41733 m
.00375 .41733 L
s
0 .45088 m
.00375 .45088 L
s
0 .46765 m
.00375 .46765 L
s
0 .48443 m
.00375 .48443 L
s
0 .5012 m
.00375 .5012 L
s
0 .53475 m
.00375 .53475 L
s
0 .55153 m
.00375 .55153 L
s
0 .56831 m
.00375 .56831 L
s
0 .58508 m
.00375 .58508 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kellogs) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tide) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09859 m
1 .09859 L
s
.99375 .18247 m
1 .18247 L
s
.99375 .26635 m
1 .26635 L
s
.99375 .35022 m
1 .35022 L
s
.99375 .4341 m
1 .4341 L
s
.99375 .51798 m
1 .51798 L
s
.99375 .60186 m
1 .60186 L
s
.125 Mabswid
.99625 .03149 m
1 .03149 L
s
.99625 .04827 m
1 .04827 L
s
.99625 .06504 m
1 .06504 L
s
.99625 .08182 m
1 .08182 L
s
.99625 .11537 m
1 .11537 L
s
.99625 .13214 m
1 .13214 L
s
.99625 .14892 m
1 .14892 L
s
.99625 .16569 m
1 .16569 L
s
.99625 .19925 m
1 .19925 L
s
.99625 .21602 m
1 .21602 L
s
.99625 .2328 m
1 .2328 L
s
.99625 .24957 m
1 .24957 L
s
.99625 .28312 m
1 .28312 L
s
.99625 .2999 m
1 .2999 L
s
.99625 .31667 m
1 .31667 L
s
.99625 .33345 m
1 .33345 L
s
.99625 .367 m
1 .367 L
s
.99625 .38378 m
1 .38378 L
s
.99625 .40055 m
1 .40055 L
s
.99625 .41733 m
1 .41733 L
s
.99625 .45088 m
1 .45088 L
s
.99625 .46765 m
1 .46765 L
s
.99625 .48443 m
1 .48443 L
s
.99625 .5012 m
1 .5012 L
s
.99625 .53475 m
1 .53475 L
s
.99625 .55153 m
1 .55153 L
s
.99625 .56831 m
1 .56831 L
s
.99625 .58508 m
1 .58508 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .5 0 r
.09091 .01472 m
.09091 .60332 L
.27273 .60332 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .60332 L
.27273 .60332 L
.27273 .01472 L
.09091 .01472 L
s
1 .5 0 r
.54545 .01472 m
.54545 .36915 L
.72727 .36915 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .36915 L
.72727 .36915 L
.72727 .01472 L
.54545 .01472 L
s
.628 .126 .941 r
.27273 .01472 m
.27273 .26488 L
.45455 .26488 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .26488 L
.45455 .26488 L
.45455 .01472 L
.27273 .01472 L
s
.628 .126 .941 r
.72727 .01472 m
.72727 .49906 L
.90909 .49906 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .49906 L
.90909 .49906 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00Roooool3o`000?oooooo0oooool008kooooo00?o0000ooooooooool0
ooooool006cooooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol000000ooooooo0000
o`000003o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l0001oooooo`?o0000
0_ooool5o`0000;ooooo1?l00002ooooo`?o0000J?ooool006gooooo00Ko0000oooooooooooo0000
ooooool00007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0006_ooooo001]ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00ol00020ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00Go0000Ioooool006gooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000008?ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1Uooooo`00KOooool00ol0003oooooo`000003ooooo`?o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Go000000?oooooo`00
0?l000000_l0001mooooo`06o`000?oooooo0000ooooool0003ooooo0ol00004ooooo`?o00000ooo
ool3o`0006Sooooo001]ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2?ooooo`05o`000?oooooo0000ooooool000002_ooool00ol0003ooooo
ooooo`1/ooooo`00K?ooool3o`000003ooooool0003o000000Kooooo0ol00003ooooo`?o0000TOoo
ool5o`0000?ooooo00?o0000ooooooooool00oooool2o`0006kooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000Roooo
ool00000G000000Cooooo`008_ooool00`00003oooooooooo`1Looooo`0300000?oooooooooo09[o
oooo00<00000ooooooooool0Foooool00`00003oooooooooo`0Aooooo`006_ooool2o`0000Kooooo
00<00000ooooooooool0G?ooool00`00003oooooooooo`2Jooooo`0300000?oooooooooo05_ooooo
00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo00001Oooool00`00003ooooo
ooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co
0000oooooooooooo00001Ooooooo000005`000004oooool001Wooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Iooooo`04o`000?oo
ooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`006_oo
ool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol00000
0000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?oo
ool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0
003o000001gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Cooooo`?o00001?ooool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`005?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool06oooool3000001?ooooo000Dooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Cooooo`;o00001?ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01go
oooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool001Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo
00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<00000
0?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
0?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o0000
00000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<0
00000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
00000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`03
00000?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo
00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo
00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Boooo
o`Go00000oooool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`004oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`005Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool0
0`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Kooooo`<000004oooool001;ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Cooooo`?o00001?oo
ool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o0000
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?oo
ool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0
003o000001gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Cooooo`?o00001?ooool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Fooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl0?`00000Oooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Dooooo`;o
00000oooool01?l0003oooooooooool00005ooooo`0300000?l0003o000001gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`1Kooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Kooooo`<000004oooool001Kooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`1Kooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`1Kooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Cooooo`?o00001?ooool2o`0000Kooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_o
oooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl0
0?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<0
00000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooo
ooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
00000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00
?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oo
oooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`00
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo
05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo
00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<00000
0?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o0000
00000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
0?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03o
O`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooo
oooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`00
0000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_o
oooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl0
0?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001Cooooo0ol0
0003ooooo`;o00001_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<0
0000ooooooooool0Foooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`005Oooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<00000ooooooooool0Foooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool5
o`0000;ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<00000ooooooooool0Foooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00<00000o`000?l00000
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00
?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01_ooooo0`00000Cooooo`004ooo
ool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00
?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool001Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00
?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool001Gooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03o
O`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooo
oooo05_ooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`00
0000ogl00?mo000l0?mo000300000?oooooooooo05_ooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo05_o
oooo@000000m0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooooooo
o`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003o
O`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000
003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[o
oooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`00003ooooo
ooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol000000000
ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<0
0000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
0000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0
003o000001gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P
8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo
09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Cooooo`?o00001?ooool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`005_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Fooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00oooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000oooo
ooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01_ooooo0`00000Coooo
o`004_ooool4o`0000?ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool5o`0000?ooooo0_l00006ooooo`03
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oo
oooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000
003ooooo01;ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo
00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Roooo
o`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Joooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000oooooooo
ool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
0?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03o
O`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`00
0000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooooooo01go
oooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000R
ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2J
ooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000oooo
ooooool0V_oooolo000001oooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l0
00007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo0?Oooooo00?o000000000?oo
ool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
0?oooooooooo0?Sooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo0?Sooooo00<00000ooooooooool04Ooo
ool001?ooooo0ol00004ooooo`;o00001_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`004_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003ooooooooo
o`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
n?ooool00`00003oooooooooo`0Aooooo`004_ooool4o`0000?ooooo00Co0000oooooooooooo0000
1Oooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
m_ooool3000001?ooooo000Booooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
n?ooool00`00003oooooooooo`0Aooooo`004oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
0?oooooooooo0?Sooooo00<00000ooooooooool04Oooool001Cooooo0_l00004ooooo`;o00001_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?oo
ool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0moooool00ol0
00000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<0
0000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000oooo
ooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`03
0000003oO`00ogl003`0ogl000<00000ooooooooool0moooool00ol000000000ooooo`0Booooo`00
8_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl0
00<00000ooooooooool0moooool00ol000000000ooooo`0Booooo`008_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000oooooooo
ool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000
003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0mooo
ool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0n?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00
003oooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0n?ooool00`00003o
ooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo0?So
oooo00<00000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00?ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
00000?oooooooooo0?Sooooo00<00000ooooooooool04Oooool001Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00?ooooo00<00000o`000?l000007Ooooom000000?So
oooo0`00000Cooooo`005_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o
oooo00<00000ooooooooool0oooooomHooooo`0300000?oooooooooo017ooooo000Booooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo
0?ooooooF?ooool00`00003oooooooooo`0Aooooo`004_ooool5o`0000?ooooo0_l00006ooooo`03
00000?oooooooooo05cooooo00?o0000ooooooooool0V_ooool00`00003oooooooooo`1Kooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00?o0000ooooooooool0
V_ooool00`00003oooooooooo`1Kooooo`0300000?oooooooooo017ooooo000Rooooool00000G000
000Cooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00Roooool3o`000?oooooo0oooool008kooooo00?o0000ooooooooool0ooooool006co
oooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol000000ooooooo0000o`000003o`00
00;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l0001oooooo`?o00000_ooool5o`00
00;ooooo1?l00002ooooo`?o0000J?ooool006gooooo00Ko0000oooooooooooo0000ooooool00007
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0006_o
oooo001]ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00ol00020ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Go0000Ioooool006gooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooo000008?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`1Uooooo`00KOooool00ol0003oooooo`000003ooooo`?o00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Go000000?oooooo`000?l000000_l0
001mooooo`06o`000?oooooo0000ooooool0003ooooo0ol00004ooooo`?o00000oooool3o`0006So
oooo001]ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2?ooooo`05o`000?oooooo0000ooooool000002_ooool00ol0003oooooooooo`1/oooo
o`00K?ooool3o`000003ooooool0003o000000Kooooo0ol00003ooooo`?o0000TOooool5o`0000?o
oooo00?o0000ooooooooool00oooool2o`0006kooooo003ooooooi7ooooo003ooooooi7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.378218, -7.38552, \
0.00636706, 0.345042}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3d Gaussian classification (RGB)", "Section"],

Cell[CellGroupData[{

Cell["Visualize distributions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gobj1\  = \ 
        PlotRepresentativeSample3D[data1, \ 2000, pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample3D[data2, \ 2000, pointStyle2];\)\), "\n", 
    \(\(gdist1 = 
        Show[{gobj1, gobj2}, yS, \ ImageSize \[Rule] 288];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 288 312.623 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 .5 0 r
.01 w
.84334 .49598 Mdot
.71169 .37959 Mdot
.82923 .47225 Mdot
.85068 .50668 Mdot
.8322 .49341 Mdot
.86945 .50754 Mdot
.84231 .50093 Mdot
.75307 .42162 Mdot
.83227 .47188 Mdot
.84085 .50927 Mdot
.84856 .50845 Mdot
.85195 .51097 Mdot
.79117 .45953 Mdot
.85029 .51743 Mdot
.82268 .49257 Mdot
.8137 .46662 Mdot
.76401 .43304 Mdot
.81681 .5115 Mdot
.83677 .52283 Mdot
.85792 .53021 Mdot
.82318 .53544 Mdot
.78766 .45061 Mdot
.78687 .45838 Mdot
.8818 .54799 Mdot
.73151 .41753 Mdot
.78833 .46543 Mdot
.77317 .47093 Mdot
.83213 .51623 Mdot
.73229 .44878 Mdot
.8257 .51502 Mdot
.8034 .48988 Mdot
.75035 .46466 Mdot
.53724 .34147 Mdot
.82043 .50257 Mdot
.79484 .48403 Mdot
.85364 .51109 Mdot
.82811 .5536 Mdot
.84396 .51652 Mdot
.77054 .47067 Mdot
.82262 .54648 Mdot
.85632 .5215 Mdot
.8195 .49397 Mdot
.49024 .30453 Mdot
.84264 .53422 Mdot
.78108 .48211 Mdot
.80026 .49947 Mdot
.75021 .47476 Mdot
.82253 .50825 Mdot
.85473 .51352 Mdot
.81491 .50374 Mdot
.77946 .49055 Mdot
.5751 .37048 Mdot
.85113 .532 Mdot
.45033 .37804 Mdot
.81897 .57356 Mdot
.84335 .51825 Mdot
.87193 .56394 Mdot
.75594 .45652 Mdot
.85823 .53909 Mdot
.65251 .42476 Mdot
.83952 .53482 Mdot
.83935 .52556 Mdot
.81362 .56839 Mdot
.8552 .54046 Mdot
.82993 .54955 Mdot
.87282 .53416 Mdot
.46051 .34632 Mdot
.85971 .52245 Mdot
.79842 .49976 Mdot
.54136 .34898 Mdot
.85753 .57021 Mdot
.79647 .51172 Mdot
.82126 .58154 Mdot
.57002 .39668 Mdot
.85644 .55962 Mdot
.78144 .52857 Mdot
.57023 .29361 Mdot
.64815 .41361 Mdot
.53109 .3395 Mdot
.79894 .50561 Mdot
.74243 .51469 Mdot
.83636 .53542 Mdot
.70543 .49073 Mdot
.72952 .46896 Mdot
.79009 .49039 Mdot
.87433 .56194 Mdot
.39449 .38464 Mdot
.83125 .51744 Mdot
.86998 .55069 Mdot
.65485 .34005 Mdot
.57549 .3949 Mdot
.46121 .43783 Mdot
.60378 .413 Mdot
.62019 .39394 Mdot
.84703 .56115 Mdot
.39765 .27605 Mdot
.51565 .42397 Mdot
.63333 .43636 Mdot
.43541 .32461 Mdot
.60912 .39797 Mdot
.86142 .53746 Mdot
.74422 .48549 Mdot
.36694 .27725 Mdot
.86398 .64655 Mdot
.8487 .54638 Mdot
.67985 .45585 Mdot
.26768 .26541 Mdot
.84081 .53244 Mdot
.49373 .34875 Mdot
.49768 .37949 Mdot
.72615 .5226 Mdot
.87395 .5566 Mdot
.86137 .5441 Mdot
.701 .38217 Mdot
.81973 .59324 Mdot
.87596 .5371 Mdot
.50833 .46843 Mdot
.77055 .43107 Mdot
.22988 .26152 Mdot
.60529 .42612 Mdot
.23756 .26055 Mdot
.87152 .57144 Mdot
.83258 .59306 Mdot
.58306 .43987 Mdot
.81112 .52688 Mdot
.78576 .55496 Mdot
.70336 .48591 Mdot
.28661 .25781 Mdot
.4974 .37955 Mdot
.25505 .25775 Mdot
.59528 .48869 Mdot
.37856 .29502 Mdot
.57028 .41983 Mdot
.62592 .44163 Mdot
.7624 .44769 Mdot
.50661 .39143 Mdot
.628 .126 .941 r
.7914 .54744 Mdot
1 .5 0 r
.85414 .63716 Mdot
.84889 .54025 Mdot
.60532 .4244 Mdot
.24385 .28053 Mdot
.54049 .4553 Mdot
.19462 .25435 Mdot
.77654 .63875 Mdot
.7662 .45418 Mdot
.90807 .61055 Mdot
.2048 .26015 Mdot
.83176 .63228 Mdot
.40794 .3755 Mdot
.628 .126 .941 r
.13799 .2593 Mdot
1 .5 0 r
.33172 .29059 Mdot
.41406 .40564 Mdot
.86161 .64661 Mdot
.628 .126 .941 r
.53885 .37415 Mdot
1 .5 0 r
.85479 .64337 Mdot
.86814 .51485 Mdot
.60446 .43628 Mdot
.9069 .58296 Mdot
.86247 .62368 Mdot
.4697 .36659 Mdot
.57534 .39153 Mdot
.39415 .31941 Mdot
.88313 .57263 Mdot
.69678 .41274 Mdot
.85621 .64142 Mdot
.50821 .37181 Mdot
.54221 .43396 Mdot
.28504 .30509 Mdot
.78408 .53401 Mdot
.55834 .44916 Mdot
.57614 .43324 Mdot
.628 .126 .941 r
.162 .27289 Mdot
.54351 .38583 Mdot
1 .5 0 r
.74645 .4542 Mdot
.87484 .64861 Mdot
.20728 .28133 Mdot
.60567 .5544 Mdot
.84406 .57951 Mdot
.87444 .56673 Mdot
.47114 .39655 Mdot
.63236 .46854 Mdot
.77529 .59103 Mdot
.28809 .31138 Mdot
.64463 .3992 Mdot
.83614 .62845 Mdot
.86764 .55603 Mdot
.25346 .28554 Mdot
.48968 .42047 Mdot
.88778 .59291 Mdot
.79408 .49851 Mdot
.44766 .36291 Mdot
.89133 .59557 Mdot
.45202 .41297 Mdot
.28363 .27455 Mdot
.86333 .67071 Mdot
.77427 .58228 Mdot
.628 .126 .941 r
.19199 .29592 Mdot
1 .5 0 r
.51121 .36494 Mdot
.18403 .29874 Mdot
.628 .126 .941 r
.58253 .47137 Mdot
.15555 .30125 Mdot
.17356 .29476 Mdot
1 .5 0 r
.23615 .30099 Mdot
.76106 .5968 Mdot
.63762 .3827 Mdot
.628 .126 .941 r
.64227 .50547 Mdot
1 .5 0 r
.75437 .60305 Mdot
.86099 .59349 Mdot
.23431 .26906 Mdot
.88559 .57129 Mdot
.71049 .44845 Mdot
.23786 .28113 Mdot
.91218 .64616 Mdot
.88129 .57682 Mdot
.18483 .30587 Mdot
.36131 .26165 Mdot
.58455 .51674 Mdot
.628 .126 .941 r
.17101 .29932 Mdot
1 .5 0 r
.88449 .56045 Mdot
.628 .126 .941 r
.16743 .29861 Mdot
1 .5 0 r
.79973 .58522 Mdot
.86214 .63565 Mdot
.77986 .49657 Mdot
.19361 .31019 Mdot
.48144 .42352 Mdot
.87686 .56536 Mdot
.17958 .2941 Mdot
.38702 .30974 Mdot
.47314 .40733 Mdot
.628 .126 .941 r
.17746 .30633 Mdot
.15209 .29049 Mdot
1 .5 0 r
.76081 .56492 Mdot
.46512 .46392 Mdot
.628 .126 .941 r
.18292 .29667 Mdot
1 .5 0 r
.89137 .6025 Mdot
.628 .126 .941 r
.16822 .30575 Mdot
.18627 .29925 Mdot
.34946 .37498 Mdot
.12879 .27381 Mdot
.24237 .25796 Mdot
1 .5 0 r
.29207 .29577 Mdot
.628 .126 .941 r
.17156 .30833 Mdot
.15877 .29564 Mdot
1 .5 0 r
.24691 .31773 Mdot
.40351 .34595 Mdot
.15731 .28269 Mdot
.20722 .33004 Mdot
.628 .126 .941 r
.19443 .31735 Mdot
.20702 .32051 Mdot
.18164 .30466 Mdot
1 .5 0 r
.46432 .42778 Mdot
.628 .126 .941 r
.1875 .31406 Mdot
1 .5 0 r
.1875 .31406 Mdot
.21058 .33263 Mdot
.628 .126 .941 r
.21038 .32309 Mdot
1 .5 0 r
.18499 .30724 Mdot
.76277 .53765 Mdot
.628 .126 .941 r
.18834 .30982 Mdot
.19421 .31923 Mdot
.16754 .29995 Mdot
1 .5 0 r
.24344 .27461 Mdot
.2169 .31872 Mdot
.628 .126 .941 r
.18476 .30911 Mdot
1 .5 0 r
.18476 .30911 Mdot
.33422 .31498 Mdot
.87452 .52658 Mdot
.628 .126 .941 r
.19253 .30814 Mdot
.19253 .30814 Mdot
1 .5 0 r
.21122 .33028 Mdot
.628 .126 .941 r
.19841 .31757 Mdot
.19147 .31428 Mdot
.19695 .3046 Mdot
.51197 .36455 Mdot
.20177 .32015 Mdot
1 .5 0 r
.20177 .32015 Mdot
.37355 .23153 Mdot
.628 .126 .941 r
.18221 .3137 Mdot
.19483 .31686 Mdot
1 .5 0 r
.43504 .34216 Mdot
.628 .126 .941 r
.13154 .29149 Mdot
.34699 .27568 Mdot
1 .5 0 r
.6232 .44964 Mdot
.75406 .60462 Mdot
.50524 .25347 Mdot
.628 .126 .941 r
.20031 .30718 Mdot
.20513 .32274 Mdot
.19839 .329 Mdot
.19819 .31945 Mdot
.19819 .31945 Mdot
.43894 .30996 Mdot
.15298 .28755 Mdot
.18431 .31286 Mdot
.14016 .27483 Mdot
1 .5 0 r
.20261 .3159 Mdot
.628 .126 .941 r
.20849 .32533 Mdot
1 .5 0 r
.18979 .30318 Mdot
.628 .126 .941 r
.23374 .33166 Mdot
.40329 .41704 Mdot
1 .5 0 r
.67946 .58154 Mdot
.20162 .2681 Mdot
.48455 .42635 Mdot
.4419 .22993 Mdot
.26331 .27094 Mdot
.628 .126 .941 r
.21186 .32792 Mdot
1 .5 0 r
.21186 .32792 Mdot
.59025 .4577 Mdot
.35768 .24858 Mdot
.49436 .40358 Mdot
.16623 .27688 Mdot
.628 .126 .941 r
.57605 .43202 Mdot
.20934 .32108 Mdot
1 .5 0 r
.20934 .32108 Mdot
.20934 .32108 Mdot
.20895 .30195 Mdot
.628 .126 .941 r
.20828 .32722 Mdot
.24532 .35242 Mdot
.16959 .27946 Mdot
1 .5 0 r
.34086 .26996 Mdot
.56595 .50115 Mdot
.628 .126 .941 r
.21271 .32367 Mdot
.19988 .31093 Mdot
1 .5 0 r
.2186 .33311 Mdot
.88739 .57065 Mdot
.21232 .30453 Mdot
.21232 .30453 Mdot
.628 .126 .941 r
.262 .33291 Mdot
1 .5 0 r
.21125 .31068 Mdot
.5258 .4944 Mdot
.56961 .51335 Mdot
.22899 .28501 Mdot
.628 .126 .941 r
.20324 .31352 Mdot
1 .5 0 r
.61943 .48778 Mdot
.628 .126 .941 r
.19696 .28494 Mdot
.19629 .31023 Mdot
.21502 .33241 Mdot
.20238 .32924 Mdot
.26472 .3608 Mdot
1 .5 0 r
.75617 .57938 Mdot
.55511 .41454 Mdot
.628 .126 .941 r
.21945 .32885 Mdot
1 .5 0 r
.76921 .48414 Mdot
.628 .126 .941 r
.20661 .31611 Mdot
.20661 .31611 Mdot
.20661 .31611 Mdot
.76294 .45556 Mdot
1 .5 0 r
.21906 .30971 Mdot
.57263 .43331 Mdot
.628 .126 .941 r
.21839 .335 Mdot
1 .5 0 r
.40225 .31909 Mdot
.39597 .2905 Mdot
.19251 .29994 Mdot
.628 .126 .941 r
.22389 .3253 Mdot
.19184 .32524 Mdot
1 .5 0 r
.54547 .44886 Mdot
.78604 .46465 Mdot
.628 .126 .941 r
.22283 .33145 Mdot
.22283 .33145 Mdot
1 .5 0 r
.29309 .29658 Mdot
.49498 .38217 Mdot
.628 .126 .941 r
.19038 .31224 Mdot
1 .5 0 r
.4813 .38515 Mdot
.628 .126 .941 r
.72677 .53416 Mdot
1 .5 0 r
.31058 .31534 Mdot
.22137 .31845 Mdot
.88412 .56253 Mdot
.628 .126 .941 r
.19521 .32783 Mdot
1 .5 0 r
.20786 .331 Mdot
.628 .126 .941 r
.20766 .32143 Mdot
1 .5 0 r
.20766 .32143 Mdot
.628 .126 .941 r
.21336 .3213 Mdot
1 .5 0 r
.22475 .32104 Mdot
.628 .126 .941 r
.19971 .27023 Mdot
1 .5 0 r
.46544 .33684 Mdot
.70445 .50176 Mdot
.86848 .57788 Mdot
.628 .126 .941 r
.19858 .33043 Mdot
1 .5 0 r
.59694 .44778 Mdot
.628 .126 .941 r
.21103 .32402 Mdot
.21103 .32402 Mdot
.21103 .32402 Mdot
.22958 .33665 Mdot
.21673 .32389 Mdot
1 .5 0 r
.62732 .47932 Mdot
.89215 .61572 Mdot
.628 .126 .941 r
.22852 .3428 Mdot
.55646 .48549 Mdot
.21461 .3362 Mdot
.21461 .3362 Mdot
.18929 .32985 Mdot
.26438 .36463 Mdot
.29044 .29159 Mdot
1 .5 0 r
.49204 .41216 Mdot
.628 .126 .941 r
.21315 .32319 Mdot
.21315 .32319 Mdot
1 .5 0 r
.21315 .32319 Mdot
.628 .126 .941 r
.28168 .37384 Mdot
.26293 .35162 Mdot
.23111 .30706 Mdot
.21798 .3388 Mdot
.19903 .307 Mdot
1 .5 0 r
.21778 .32922 Mdot
.628 .126 .941 r
.23635 .34185 Mdot
1 .5 0 r
.26777 .36724 Mdot
.53978 .45293 Mdot
.51445 .44658 Mdot
.26194 .3037 Mdot
.628 .126 .941 r
.22309 .30992 Mdot
1 .5 0 r
.21652 .32579 Mdot
.23489 .32883 Mdot
.37354 .38908 Mdot
.628 .126 .941 r
.22136 .3414 Mdot
.22687 .33169 Mdot
1 .5 0 r
.24563 .35391 Mdot
.628 .126 .941 r
.2199 .32839 Mdot
.226 .34744 Mdot
1 .5 0 r
.24484 .31556 Mdot
.628 .126 .941 r
.23828 .33143 Mdot
.26971 .35684 Mdot
.21274 .31549 Mdot
1 .5 0 r
.65005 .40758 Mdot
.628 .126 .941 r
.19987 .30272 Mdot
1 .5 0 r
.91451 .56947 Mdot
.20577 .31219 Mdot
.20577 .31219 Mdot
.628 .126 .941 r
.19291 .29942 Mdot
.23025 .33429 Mdot
1 .5 0 r
.24902 .35652 Mdot
.628 .126 .941 r
.21061 .32781 Mdot
1 .5 0 r
.1661 .28004 Mdot
.27311 .35944 Mdot
.628 .126 .941 r
.22879 .32126 Mdot
1 .5 0 r
.22879 .32126 Mdot
.628 .126 .941 r
.24757 .3435 Mdot
1 .5 0 r
.22813 .34661 Mdot
.628 .126 .941 r
.20915 .31478 Mdot
.22793 .33702 Mdot
.22793 .33702 Mdot
1 .5 0 r
.45652 .35926 Mdot
.628 .126 .941 r
.18864 .32406 Mdot
.22667 .33359 Mdot
1 .5 0 r
.22667 .33359 Mdot
.27651 .36205 Mdot
.53472 .54951 Mdot
.67462 .54951 Mdot
.628 .126 .941 r
.23131 .33962 Mdot
1 .5 0 r
.23131 .33962 Mdot
.39695 .24727 Mdot
.628 .126 .941 r
.57144 .49191 Mdot
.82437 .58084 Mdot
1 .5 0 r
.24844 .33924 Mdot
.628 .126 .941 r
.32977 .39315 Mdot
.19055 .31362 Mdot
.21591 .31998 Mdot
1 .5 0 r
.18425 .28495 Mdot
.57549 .52335 Mdot
.24041 .3421 Mdot
.24041 .3421 Mdot
.628 .126 .941 r
.22076 .33562 Mdot
.24002 .3229 Mdot
.25223 .36105 Mdot
1 .5 0 r
.30981 .3133 Mdot
.628 .126 .941 r
.22627 .32589 Mdot
1 .5 0 r
.22627 .32589 Mdot
.23895 .32907 Mdot
.628 .126 .941 r
.21272 .33848 Mdot
.21272 .33848 Mdot
.21272 .33848 Mdot
1 .5 0 r
.2438 .34471 Mdot
.628 .126 .941 r
.28797 .37333 Mdot
1 .5 0 r
.36455 .35743 Mdot
.628 .126 .941 r
.23683 .3414 Mdot
.22414 .33822 Mdot
.23683 .3414 Mdot
.22414 .33822 Mdot
1 .5 0 r
.87068 .53538 Mdot
.44479 .47172 Mdot
.628 .126 .941 r
.25523 .34446 Mdot
1 .5 0 r
.25523 .34446 Mdot
.628 .126 .941 r
.22966 .32849 Mdot
1 .5 0 r
.22966 .32849 Mdot
.51067 .25853 Mdot
.36292 .33479 Mdot
.7727 .63056 Mdot
.24148 .34745 Mdot
.24148 .34745 Mdot
.628 .126 .941 r
.36273 .32518 Mdot
.31103 .38243 Mdot
1 .5 0 r
.83597 .63686 Mdot
.628 .126 .941 r
.29157 .38555 Mdot
1 .5 0 r
.27257 .35368 Mdot
.628 .126 .941 r
.21504 .34726 Mdot
.21464 .32804 Mdot
1 .5 0 r
.58202 .44568 Mdot
.628 .126 .941 r
.23305 .3311 Mdot
.23305 .3311 Mdot
1 .5 0 r
.23305 .3311 Mdot
.628 .126 .941 r
.24574 .33428 Mdot
1 .5 0 r
.60063 .45834 Mdot
.628 .126 .941 r
.22016 .31831 Mdot
.23285 .32149 Mdot
.21969 .3533 Mdot
1 .5 0 r
.21357 .33421 Mdot
.628 .126 .941 r
.22607 .32779 Mdot
1 .5 0 r
.22607 .32779 Mdot
.628 .126 .941 r
.20049 .31181 Mdot
.3387 .4518 Mdot
1 .5 0 r
.56811 .43907 Mdot
.628 .126 .941 r
.23092 .34344 Mdot
.19949 .26376 Mdot
1 .5 0 r
.26202 .34968 Mdot
.628 .126 .941 r
.23624 .32409 Mdot
.20407 .32403 Mdot
.24874 .31766 Mdot
.22946 .33039 Mdot
.22288 .3463 Mdot
1 .5 0 r
.26649 .34611 Mdot
.628 .126 .941 r
.19622 .3365 Mdot
.50802 .36196 Mdot
1 .5 0 r
.45629 .41925 Mdot
.28471 .33956 Mdot
.28424 .37457 Mdot
.83593 .56555 Mdot
.628 .126 .941 r
.25253 .33949 Mdot
.27134 .36177 Mdot
1 .5 0 r
.26503 .33306 Mdot
.35468 .2757 Mdot
.23285 .333 Mdot
.23285 .333 Mdot
.628 .126 .941 r
.25166 .35528 Mdot
1 .5 0 r
.21995 .3202 Mdot
.27028 .36795 Mdot
.27028 .36795 Mdot
.628 .126 .941 r
.2762 .37744 Mdot
.2248 .33586 Mdot
.2248 .33586 Mdot
1 .5 0 r
.20599 .31358 Mdot
.26883 .3549 Mdot
.27475 .36439 Mdot
.628 .126 .941 r
.22374 .34204 Mdot
.23032 .32612 Mdot
1 .5 0 r
.50839 .50125 Mdot
.628 .126 .941 r
.23624 .33561 Mdot
1 .5 0 r
.21064 .31962 Mdot
.45202 .38012 Mdot
.45719 .46929 Mdot
.26079 .35777 Mdot
.31772 .38961 Mdot
.628 .126 .941 r
.2411 .35127 Mdot
1 .5 0 r
.86979 .52643 Mdot
.628 .126 .941 r
.30941 .43714 Mdot
1 .5 0 r
.59601 .45625 Mdot
.24662 .34153 Mdot
.628 .126 .941 r
.20172 .33828 Mdot
1 .5 0 r
.23372 .32873 Mdot
.628 .126 .941 r
.29067 .36058 Mdot
1 .5 0 r
.21422 .33185 Mdot
.628 .126 .941 r
.23305 .35414 Mdot
.23964 .33822 Mdot
.25894 .32548 Mdot
1 .5 0 r
.23964 .33822 Mdot
.88491 .71089 Mdot
.628 .126 .941 r
.18814 .35089 Mdot
1 .5 0 r
.2771 .37319 Mdot
.2638 .34115 Mdot
.628 .126 .941 r
.26207 .37275 Mdot
.26207 .37275 Mdot
.24304 .34083 Mdot
1 .5 0 r
.24304 .34083 Mdot
.628 .126 .941 r
.2805 .37581 Mdot
.22247 .35013 Mdot
1 .5 0 r
.26061 .35969 Mdot
.21615 .32139 Mdot
.87632 .5572 Mdot
.20324 .30858 Mdot
.25342 .34676 Mdot
.628 .126 .941 r
.28498 .37225 Mdot
1 .5 0 r
.43755 .41049 Mdot
.22101 .33707 Mdot
.36135 .33707 Mdot
.271 .36563 Mdot
.628 .126 .941 r
.29643 .372 Mdot
1 .5 0 r
.4495 .37519 Mdot
.628 .126 .941 r
.20702 .33044 Mdot
.20682 .32081 Mdot
1 .5 0 r
.45439 .39088 Mdot
.628 .126 .941 r
.25683 .34937 Mdot
1 .5 0 r
.25683 .34937 Mdot
.628 .126 .941 r
.31383 .38125 Mdot
.25663 .33974 Mdot
.2242 .33005 Mdot
1 .5 0 r
.31889 .40657 Mdot
.628 .126 .941 r
.21041 .33305 Mdot
.21654 .35218 Mdot
1 .5 0 r
.26742 .36493 Mdot
.4719 .3458 Mdot
.28587 .368 Mdot
.26023 .35199 Mdot
.628 .126 .941 r
.2918 .3775 Mdot
1 .5 0 r
.444 .45084 Mdot
.628 .126 .941 r
.21527 .34874 Mdot
.24731 .33917 Mdot
1 .5 0 r
.2278 .34229 Mdot
.628 .126 .941 r
.25324 .34867 Mdot
1 .5 0 r
.25324 .34867 Mdot
.87573 .57509 Mdot
.628 .126 .941 r
.19555 .34223 Mdot
.33485 .40276 Mdot
1 .5 0 r
.47481 .43784 Mdot
.5389 .41871 Mdot
.628 .126 .941 r
.24605 .33572 Mdot
.21993 .3548 Mdot
1 .5 0 r
.22633 .32922 Mdot
.628 .126 .941 r
.28929 .37062 Mdot
.32067 .38651 Mdot
1 .5 0 r
.70292 .44711 Mdot
.628 .126 .941 r
.23119 .34491 Mdot
.24946 .33834 Mdot
1 .5 0 r
.79441 .65099 Mdot
.402 .36699 Mdot
.49892 .25845 Mdot
.628 .126 .941 r
.44707 .31588 Mdot
1 .5 0 r
.45178 .44031 Mdot
.628 .126 .941 r
.29271 .37324 Mdot
1 .5 0 r
.29271 .37324 Mdot
.628 .126 .941 r
.17114 .34121 Mdot
1 .5 0 r
.54551 .52309 Mdot
.628 .126 .941 r
.22234 .30924 Mdot
.2478 .31562 Mdot
.23459 .34753 Mdot
1 .5 0 r
.29758 .38895 Mdot
.28465 .37612 Mdot
.628 .126 .941 r
.23946 .36323 Mdot
1 .5 0 r
.27766 .3728 Mdot
.628 .126 .941 r
.29652 .39514 Mdot
.32839 .37593 Mdot
.29613 .37587 Mdot
.29613 .37587 Mdot
.2832 .36304 Mdot
.22074 .23211 Mdot
.25753 .34702 Mdot
.23167 .32136 Mdot
1 .5 0 r
.85474 .54799 Mdot
.628 .126 .941 r
.26967 .32129 Mdot
.28807 .37875 Mdot
1 .5 0 r
.689 .49686 Mdot
.628 .126 .941 r
.25061 .2893 Mdot
.2372 .31159 Mdot
.22427 .29875 Mdot
1 .5 0 r
.70648 .50614 Mdot
.628 .126 .941 r
.22367 .26982 Mdot
.25481 .33048 Mdot
.26094 .34964 Mdot
1 .5 0 r
.26094 .34964 Mdot
.628 .126 .941 r
.23507 .32397 Mdot
1 .5 0 r
.43983 .30481 Mdot
.50258 .39102 Mdot
.62856 .52832 Mdot
.29149 .38138 Mdot
.41322 .35903 Mdot
.628 .126 .941 r
.3951 .25678 Mdot
1 .5 0 r
.2911 .36209 Mdot
.24021 .2949 Mdot
.628 .126 .941 r
.18197 .32358 Mdot
.29051 .33316 Mdot
.27729 .3651 Mdot
1 .5 0 r
.84877 .64933 Mdot
.51966 .381 Mdot
.24461 .34575 Mdot
.30785 .39685 Mdot
.628 .126 .941 r
.65332 .37768 Mdot
1 .5 0 r
.88033 .61084 Mdot
.628 .126 .941 r
.29491 .38401 Mdot
1 .5 0 r
.30746 .37756 Mdot
.628 .126 .941 r
.5628 .40631 Mdot
.21718 .3614 Mdot
1 .5 0 r
.49993 .25598 Mdot
.628 .126 .941 r
.21699 .35175 Mdot
.31128 .39948 Mdot
.31041 .41534 Mdot
.20851 .33533 Mdot
.22814 .27775 Mdot
.30983 .38639 Mdot
1 .5 0 r
.89532 .60368 Mdot
.628 .126 .941 r
.22039 .35438 Mdot
.25985 .24885 Mdot
.25277 .29999 Mdot
1 .5 0 r
.23341 .31277 Mdot
.628 .126 .941 r
.17533 .35112 Mdot
.28393 .3607 Mdot
1 .5 0 r
.28393 .3607 Mdot
.628 .126 .941 r
.32832 .38946 Mdot
1 .5 0 r
.23935 .32229 Mdot
.23935 .32229 Mdot
.628 .126 .941 r
.34701 .40218 Mdot
.24576 .29666 Mdot
.20657 .35738 Mdot
1 .5 0 r
.61316 .56511 Mdot
.49963 .42124 Mdot
.25016 .34754 Mdot
.628 .126 .941 r
.19848 .36026 Mdot
1 .5 0 r
.33215 .4114 Mdot
.59948 .51369 Mdot
.628 .126 .941 r
.30031 .37618 Mdot
.28736 .36333 Mdot
.27393 .38564 Mdot
.34932 .4655 Mdot
1 .5 0 r
.62424 .48149 Mdot
.47147 .39831 Mdot
.628 .126 .941 r
.3048 .37261 Mdot
1 .5 0 r
.30432 .40777 Mdot
.628 .126 .941 r
.24838 .26064 Mdot
.24015 .37248 Mdot
1 .5 0 r
.29098 .37561 Mdot
.628 .126 .941 r
.21337 .36263 Mdot
.22612 .36583 Mdot
1 .5 0 r
.25806 .34658 Mdot
.46928 .34658 Mdot
.628 .126 .941 r
.24518 .27923 Mdot
.25746 .31761 Mdot
1 .5 0 r
.32012 .3943 Mdot
.55576 .46141 Mdot
.628 .126 .941 r
.28145 .36539 Mdot
1 .5 0 r
.24958 .33014 Mdot
.628 .126 .941 r
.43239 .4707 Mdot
1 .5 0 r
.24879 .2915 Mdot
.27932 .37781 Mdot
.628 .126 .941 r
.68019 .56656 Mdot
.34247 .41934 Mdot
1 .5 0 r
.89747 .5761 Mdot
.628 .126 .941 r
.3106 .38408 Mdot
1 .5 0 r
.35598 .34249 Mdot
.628 .126 .941 r
.20166 .36482 Mdot
1 .5 0 r
.29764 .37122 Mdot
.628 .126 .941 r
.28373 .42875 Mdot
.27786 .3647 Mdot
1 .5 0 r
.31548 .39983 Mdot
.53989 .35817 Mdot
.50073 .36444 Mdot
.59465 .50199 Mdot
.628 .126 .941 r
.31403 .38672 Mdot
1 .5 0 r
.33295 .40912 Mdot
.60155 .44113 Mdot
.2883 .37065 Mdot
.628 .126 .941 r
.30107 .37385 Mdot
.22405 .33532 Mdot
1 .5 0 r
.34541 .33846 Mdot
.40906 .34479 Mdot
.47954 .34479 Mdot
.628 .126 .941 r
.28684 .35753 Mdot
.29961 .36074 Mdot
.27359 .38954 Mdot
.31191 .39915 Mdot
.2538 .38302 Mdot
1 .5 0 r
.2361 .2453 Mdot
.628 .126 .941 r
.28558 .35408 Mdot
.29173 .37329 Mdot
.29173 .37329 Mdot
.25956 .38289 Mdot
.21469 .33474 Mdot
1 .5 0 r
.68684 .48842 Mdot
.895 .73495 Mdot
.86927 .71889 Mdot
.628 .126 .941 r
.29046 .36983 Mdot
1 .5 0 r
.27067 .3633 Mdot
.78736 .54582 Mdot
.23857 .31834 Mdot
.628 .126 .941 r
.24425 .37278 Mdot
.26298 .38553 Mdot
1 .5 0 r
.37351 .24456 Mdot
.628 .126 .941 r
.27536 .36939 Mdot
1 .5 0 r
.3525 .35338 Mdot
.43417 .4526 Mdot
.58666 .50693 Mdot
.53611 .40431 Mdot
.628 .126 .941 r
.31157 .39144 Mdot
.32435 .39464 Mdot
.26072 .33371 Mdot
.31137 .38176 Mdot
1 .5 0 r
.58638 .43302 Mdot
.30455 .38811 Mdot
.62322 .48409 Mdot
.74393 .56739 Mdot
.34191 .34935 Mdot
.25176 .35249 Mdot
.25176 .35249 Mdot
.31481 .3844 Mdot
.628 .126 .941 r
.3594 .35864 Mdot
.25076 .3041 Mdot
.35163 .43549 Mdot
1 .5 0 r
.51168 .45792 Mdot
.53062 .48036 Mdot
.42767 .4803 Mdot
.628 .126 .941 r
.26315 .28794 Mdot
.25017 .27506 Mdot
.2999 .39364 Mdot
.31845 .39672 Mdot
.2993 .36461 Mdot
1 .5 0 r
.57969 .50564 Mdot
.628 .126 .941 r
.22833 .34525 Mdot
.27996 .32281 Mdot
1 .5 0 r
.49671 .40289 Mdot
.51566 .42532 Mdot
.64773 .55338 Mdot
.25272 .29356 Mdot
.628 .126 .941 r
.32189 .39937 Mdot
1 .5 0 r
.22519 .30927 Mdot
.61403 .48558 Mdot
.63801 .58814 Mdot
.26203 .36039 Mdot
.32533 .40202 Mdot
.33813 .40522 Mdot
.628 .126 .941 r
.30571 .40516 Mdot
.8221 .64886 Mdot
.24749 .389 Mdot
1 .5 0 r
.61727 .53322 Mdot
.628 .126 .941 r
.80289 .55241 Mdot
1 .5 0 r
.73132 .62298 Mdot
.31021 .40158 Mdot
.628 .126 .941 r
.35552 .35019 Mdot
1 .5 0 r
.89829 .57475 Mdot
.628 .126 .941 r
.24108 .24105 Mdot
1 .5 0 r
.63596 .48166 Mdot
.628 .126 .941 r
.27881 .27627 Mdot
1 .5 0 r
.9169 .57785 Mdot
.628 .126 .941 r
.30875 .38844 Mdot
.37845 .45902 Mdot
1 .5 0 r
.68518 .57132 Mdot
.61436 .56164 Mdot
.628 .126 .941 r
.31452 .38831 Mdot
.23732 .34968 Mdot
.31366 .40423 Mdot
.41655 .3946 Mdot
1 .5 0 r
.70247 .62564 Mdot
.628 .126 .941 r
.35803 .42342 Mdot
.22317 .39769 Mdot
.31923 .39442 Mdot
1 .5 0 r
.35764 .40404 Mdot
.59408 .47138 Mdot
.628 .126 .941 r
.31208 .3267 Mdot
.36188 .44546 Mdot
1 .5 0 r
.73821 .55436 Mdot
.59714 .50936 Mdot
.78831 .62814 Mdot
.628 .126 .941 r
.31612 .35842 Mdot
.42978 .48356 Mdot
.22511 .38718 Mdot
.44808 .53166 Mdot
.29635 .29715 Mdot
.22641 .21682 Mdot
.2302 .41268 Mdot
1 .5 0 r
.83704 .68883 Mdot
.36618 .31308 Mdot
.628 .126 .941 r
.47483 .35803 Mdot
1 .5 0 r
.61433 .49932 Mdot
.74244 .53143 Mdot
.36456 .40935 Mdot
.84949 .67266 Mdot
.24317 .30646 Mdot
.628 .126 .941 r
.26167 .36427 Mdot
.1842 .3159 Mdot
.24711 .39292 Mdot
.40638 .47637 Mdot
1 .5 0 r
.90424 .74296 Mdot
.628 .126 .941 r
.43713 .50831 Mdot
.30972 .39582 Mdot
.4769 .3475 Mdot
1 .5 0 r
.32832 .39891 Mdot
.628 .126 .941 r
.32812 .3892 Mdot
1 .5 0 r
.83227 .67513 Mdot
.628 .126 .941 r
.28235 .42127 Mdot
.25034 .38587 Mdot
.37786 .44364 Mdot
.4672 .44673 Mdot
1 .5 0 r
.60774 .51742 Mdot
.71125 .47244 Mdot
.628 .126 .941 r
.37213 .2698 Mdot
1 .5 0 r
.49892 .40798 Mdot
.628 .126 .941 r
.65287 .39179 Mdot
1 .5 0 r
.23573 .29531 Mdot
.628 .126 .941 r
.31219 .34995 Mdot
.36185 .45916 Mdot
1 .5 0 r
.47897 .33696 Mdot
.628 .126 .941 r
.25915 .36898 Mdot
.2981 .34326 Mdot
1 .5 0 r
.8291 .56505 Mdot
.54679 .48463 Mdot
.67408 .5875 Mdot
.89304 .57142 Mdot
.628 .126 .941 r
.21553 .21455 Mdot
.45141 .35272 Mdot
.31013 .30765 Mdot
.30253 .39444 Mdot
.45169 .30765 Mdot
1 .5 0 r
.36694 .36545 Mdot
.35344 .38789 Mdot
.628 .126 .941 r
.3848 .44897 Mdot
1 .5 0 r
.49358 .49398 Mdot
.628 .126 .941 r
.21785 .39747 Mdot
.19784 .32642 Mdot
1 .5 0 r
.38229 .44206 Mdot
.628 .126 .941 r
.31937 .31014 Mdot
.21557 .34545 Mdot
1 .5 0 r
.3244 .39048 Mdot
.3244 .39048 Mdot
.40043 .48053 Mdot
.628 .126 .941 r
.28598 .32603 Mdot
1 .5 0 r
.75867 .57684 Mdot
.27303 .25828 Mdot
.49547 .47379 Mdot
.74547 .55421 Mdot
.628 .126 .941 r
.28975 .40291 Mdot
.38624 .40934 Mdot
1 .5 0 r
.60974 .49929 Mdot
.59025 .51216 Mdot
.628 .126 .941 r
.2188 .33838 Mdot
.29466 .41874 Mdot
.5528 .37692 Mdot
.4097 .48309 Mdot
.39667 .47016 Mdot
.28721 .39597 Mdot
1 .5 0 r
.53521 .48893 Mdot
.8039 .62732 Mdot
.628 .126 .941 r
.2081 .33432 Mdot
.2081 .33432 Mdot
1 .5 0 r
.46587 .32788 Mdot
.628 .126 .941 r
.74171 .41478 Mdot
.45664 .51128 Mdot
1 .5 0 r
.73772 .68831 Mdot
.628 .126 .941 r
.31091 .30522 Mdot
.3165 .29537 Mdot
.68828 .41441 Mdot
1 .5 0 r
.51447 .37894 Mdot
.628 .126 .941 r
.33922 .4497 Mdot
.21914 .25003 Mdot
.30172 .31435 Mdot
1 .5 0 r
.83199 .63304 Mdot
.628 .126 .941 r
.27353 .42042 Mdot
1 .5 0 r
.40446 .22064 Mdot
.628 .126 .941 r
.21495 .3396 Mdot
.23351 .39756 Mdot
.48553 .32665 Mdot
.27804 .41683 Mdot
.27785 .4071 Mdot
.26718 .21701 Mdot
.30846 .4294 Mdot
.42365 .49382 Mdot
1 .5 0 r
.42365 .49382 Mdot
.628 .126 .941 r
.28256 .41323 Mdot
.51437 .43578 Mdot
.25047 .37774 Mdot
.26285 .41639 Mdot
1 .5 0 r
.63556 .50981 Mdot
.4362 .42271 Mdot
.628 .126 .941 r
.28129 .40976 Mdot
.25662 .27754 Mdot
1 .5 0 r
.34517 .40642 Mdot
.37706 .43219 Mdot
.73079 .50308 Mdot
.628 .126 .941 r
.32069 .28392 Mdot
.32593 .37414 Mdot
.29363 .3289 Mdot
.30601 .36756 Mdot
1 .5 0 r
.39505 .46101 Mdot
.628 .126 .941 r
.36866 .48028 Mdot
1 .5 0 r
.7672 .58018 Mdot
.84386 .63496 Mdot
.628 .126 .941 r
.31208 .32226 Mdot
1 .5 0 r
.54265 .39625 Mdot
.70218 .52516 Mdot
.628 .126 .941 r
.32959 .38652 Mdot
1 .5 0 r
.40674 .40586 Mdot
.28423 .32831 Mdot
.628 .126 .941 r
.30232 .42179 Mdot
.36556 .44417 Mdot
1 .5 0 r
.56018 .34095 Mdot
.49645 .23443 Mdot
.4246 .25042 Mdot
.42413 .28588 Mdot
.628 .126 .941 r
.31884 .43741 Mdot
1 .5 0 r
.30054 .33418 Mdot
.628 .126 .941 r
.30578 .42445 Mdot
.27319 .42439 Mdot
1 .5 0 r
.47834 .50172 Mdot
.628 .126 .941 r
.29145 .40802 Mdot
.40057 .45317 Mdot
1 .5 0 r
.76014 .5692 Mdot
.86926 .61435 Mdot
.61824 .51426 Mdot
.628 .126 .941 r
.29113 .33359 Mdot
1 .5 0 r
.55353 .47867 Mdot
.628 .126 .941 r
.77323 .46254 Mdot
.48118 .53016 Mdot
.32207 .31069 Mdot
.33455 .29443 Mdot
1 .5 0 r
.6218 .51696 Mdot
.26265 .31043 Mdot
.628 .126 .941 r
.27532 .30391 Mdot
1 .5 0 r
.31831 .41993 Mdot
.628 .126 .941 r
.28569 .41987 Mdot
.27452 .26493 Mdot
.30599 .32623 Mdot
1 .5 0 r
.39448 .44556 Mdot
.628 .126 .941 r
.31179 .3261 Mdot
1 .5 0 r
.3565 .29041 Mdot
.42803 .25491 Mdot
.628 .126 .941 r
.56108 .44854 Mdot
1 .5 0 r
.20159 .23218 Mdot
.628 .126 .941 r
.30202 .42577 Mdot
.42411 .47418 Mdot
1 .5 0 r
.32901 .31596 Mdot
.628 .126 .941 r
.37965 .34488 Mdot
.38442 .47077 Mdot
.72699 .41255 Mdot
1 .5 0 r
.93049 .63201 Mdot
.54201 .54773 Mdot
.628 .126 .941 r
.75003 .45732 Mdot
1 .5 0 r
.66463 .56064 Mdot
.628 .126 .941 r
.76321 .41528 Mdot
1 .5 0 r
.3231 .43782 Mdot
.628 .126 .941 r
.27757 .43453 Mdot
.38159 .38932 Mdot
.43169 .5088 Mdot
.62428 .58302 Mdot
.34971 .30846 Mdot
.38645 .46024 Mdot
1 .5 0 r
.48981 .4408 Mdot
.628 .126 .941 r
.86347 .53446 Mdot
.26341 .42782 Mdot
.25033 .41484 Mdot
1 .5 0 r
.84115 .70552 Mdot
.42298 .48249 Mdot
.57075 .52765 Mdot
.41591 .47914 Mdot
.5257 .36899 Mdot
.628 .126 .941 r
.39489 .47884 Mdot
1 .5 0 r
.38896 .41416 Mdot
.33088 .30727 Mdot
.66255 .63036 Mdot
.628 .126 .941 r
.27032 .43318 Mdot
1 .5 0 r
.32858 .42995 Mdot
.85671 .59799 Mdot
.628 .126 .941 r
.37928 .45891 Mdot
1 .5 0 r
.53353 .53324 Mdot
.628 .126 .941 r
.32062 .44263 Mdot
.26454 .25833 Mdot
1 .5 0 r
.39779 .45226 Mdot
.56476 .52008 Mdot
.628 .126 .941 r
.50583 .54911 Mdot
.50583 .54911 Mdot
1 .5 0 r
.5598 .26432 Mdot
.4677 .32885 Mdot
.628 .126 .941 r
.50935 .55183 Mdot
.32378 .37069 Mdot
.63148 .59057 Mdot
.2801 .22512 Mdot
1 .5 0 r
.34986 .33183 Mdot
.628 .126 .941 r
.28994 .43201 Mdot
1 .5 0 r
.65576 .63891 Mdot
.628 .126 .941 r
.69075 .39625 Mdot
.39905 .40265 Mdot
.53286 .56113 Mdot
.25023 .37348 Mdot
.3721 .45757 Mdot
1 .5 0 r
.51451 .45757 Mdot
.41672 .41204 Mdot
.42245 .46703 Mdot
.9165 .77752 Mdot
.51709 .53144 Mdot
.628 .126 .941 r
.24611 .40837 Mdot
.43954 .44714 Mdot
.37002 .295 Mdot
.38054 .4762 Mdot
.51498 .54403 Mdot
.73493 .56345 Mdot
.34743 .4566 Mdot
.46917 .53097 Mdot
1 .5 0 r
.68962 .51479 Mdot
.56434 .55981 Mdot
.4151 .45593 Mdot
.628 .126 .941 r
.57774 .40737 Mdot
1 .5 0 r
.93554 .78289 Mdot
.628 .126 .941 r
.33769 .38135 Mdot
1 .5 0 r
.8599 .55611 Mdot
.628 .126 .941 r
.6056 .57855 Mdot
1 .5 0 r
.77401 .58503 Mdot
.628 .126 .941 r
.39229 .48777 Mdot
.45019 .52015 Mdot
.8459 .49424 Mdot
.27582 .44885 Mdot
1 .5 0 r
.43162 .40669 Mdot
.44434 .40015 Mdot
.628 .126 .941 r
.69701 .40986 Mdot
1 .5 0 r
.43649 .47781 Mdot
.628 .126 .941 r
.28925 .24112 Mdot
1 .5 0 r
.3843 .38033 Mdot
.57672 .53582 Mdot
.628 .126 .941 r
.47582 .27654 Mdot
1 .5 0 r
.46624 .50654 Mdot
.628 .126 .941 r
.31766 .44169 Mdot
.74325 .49971 Mdot
.45771 .48993 Mdot
1 .5 0 r
.71673 .51909 Mdot
.86372 .6811 Mdot
.36175 .36674 Mdot
.628 .126 .941 r
.33426 .45741 Mdot
1 .5 0 r
.43059 .47997 Mdot
.70766 .59333 Mdot
.50443 .24651 Mdot
.628 .126 .941 r
.30043 .46364 Mdot
.3144 .34036 Mdot
.29983 .43429 Mdot
1 .5 0 r
.39657 .47643 Mdot
.628 .126 .941 r
.29532 .26244 Mdot
1 .5 0 r
.78432 .56388 Mdot
.628 .126 .941 r
.39618 .45686 Mdot
.90101 .54762 Mdot
1 .5 0 r
.90658 .59294 Mdot
.628 .126 .941 r
.29185 .44701 Mdot
1 .5 0 r
.42261 .37245 Mdot
.628 .126 .941 r
.74586 .38847 Mdot
1 .5 0 r
.43285 .47919 Mdot
.38004 .47252 Mdot
.60043 .49198 Mdot
.628 .126 .941 r
.30806 .44315 Mdot
1 .5 0 r
.7278 .60205 Mdot
.33977 .44952 Mdot
.628 .126 .941 r
.29452 .41054 Mdot
.76043 .47204 Mdot
1 .5 0 r
.77012 .66977 Mdot
.42197 .46537 Mdot
.28757 .29663 Mdot
.44335 .29988 Mdot
.628 .126 .941 r
.44766 .46206 Mdot
.37078 .36144 Mdot
.27875 .44578 Mdot
1 .5 0 r
.44296 .28028 Mdot
.33251 .26075 Mdot
.628 .126 .941 r
.53633 .50718 Mdot
1 .5 0 r
.67728 .64993 Mdot
.628 .126 .941 r
.32145 .4778 Mdot
1 .5 0 r
.6072 .4778 Mdot
.83301 .58812 Mdot
.53778 .27975 Mdot
.628 .126 .941 r
.37445 .25352 Mdot
1 .5 0 r
.53346 .48062 Mdot
.628 .126 .941 r
.33809 .49355 Mdot
.35792 .36996 Mdot
.55648 .58095 Mdot
.4877 .35691 Mdot
1 .5 0 r
.59706 .43806 Mdot
.5113 .48664 Mdot
.46467 .49944 Mdot
.628 .126 .941 r
.32199 .45393 Mdot
.43166 .48958 Mdot
1 .5 0 r
.85241 .61296 Mdot
.628 .126 .941 r
.38588 .48628 Mdot
.87892 .52843 Mdot
.34807 .34977 Mdot
1 .5 0 r
.47108 .28781 Mdot
.628 .126 .941 r
.39842 .34945 Mdot
.30628 .43389 Mdot
1 .5 0 r
.46186 .41753 Mdot
.85666 .52465 Mdot
.628 .126 .941 r
.80254 .63498 Mdot
.31037 .46601 Mdot
1 .5 0 r
.25401 .28078 Mdot
.9121 .66085 Mdot
.628 .126 .941 r
.34261 .43665 Mdot
.29701 .44314 Mdot
.38926 .30332 Mdot
.48508 .40722 Mdot
.41171 .49482 Mdot
.56775 .49807 Mdot
.48277 .53056 Mdot
.43744 .49151 Mdot
1 .5 0 r
.48959 .45896 Mdot
.628 .126 .941 r
.52079 .55644 Mdot
.26276 .37441 Mdot
.34063 .33854 Mdot
1 .5 0 r
.41842 .35804 Mdot
.628 .126 .941 r
.8261 .51402 Mdot
1 .5 0 r
.67628 .53027 Mdot
.628 .126 .941 r
.53875 .57571 Mdot
.29497 .22445 Mdot
.31754 .48122 Mdot
.5644 .50723 Mdot
.29813 .44866 Mdot
.33644 .42897 Mdot
.57382 .6304 Mdot
1 .5 0 r
.41395 .37345 Mdot
.39454 .34088 Mdot
.628 .126 .941 r
.35475 .34725 Mdot
1 .5 0 r
.66944 .65939 Mdot
.83099 .6983 Mdot
.628 .126 .941 r
.34723 .32423 Mdot
1 .5 0 r
.54616 .5356 Mdot
.628 .126 .941 r
.40911 .4899 Mdot
.50743 .41503 Mdot
.56366 .59066 Mdot
.37795 .33691 Mdot
1 .5 0 r
.49907 .52881 Mdot
.628 .126 .941 r
.43447 .46695 Mdot
.4859 .51574 Mdot
.30066 .22619 Mdot
.81109 .51568 Mdot
1 .5 0 r
.50406 .54483 Mdot
.628 .126 .941 r
.37437 .45688 Mdot
.45801 .53171 Mdot
.45156 .50237 Mdot
1 .5 0 r
.38214 .31361 Mdot
.628 .126 .941 r
.36829 .3265 Mdot
.37935 .47291 Mdot
1 .5 0 r
.46973 .53147 Mdot
.76059 .69415 Mdot
.628 .126 .941 r
.27194 .20279 Mdot
.57896 .59318 Mdot
.34057 .35227 Mdot
1 .5 0 r
.51992 .57679 Mdot
.628 .126 .941 r
.80505 .68418 Mdot
.37259 .36847 Mdot
.50675 .56372 Mdot
.32094 .30983 Mdot
.71073 .36183 Mdot
.35084 .4594 Mdot
1 .5 0 r
.50569 .57006 Mdot
.628 .126 .941 r
.39055 .38774 Mdot
.48173 .3649 Mdot
1 .5 0 r
.44759 .48207 Mdot
.6111 .43324 Mdot
.42286 .35832 Mdot
.44989 .23776 Mdot
.44055 .42323 Mdot
.51078 .53065 Mdot
.39523 .32864 Mdot
.628 .126 .941 r
.89407 .5435 Mdot
.38638 .47833 Mdot
.46431 .49786 Mdot
.45064 .52059 Mdot
1 .5 0 r
.49933 .24372 Mdot
.628 .126 .941 r
.66002 .40977 Mdot
.9052 .56925 Mdot
1 .5 0 r
.59228 .55292 Mdot
.628 .126 .941 r
.4617 .54635 Mdot
.38316 .49732 Mdot
.5126 .56571 Mdot
1 .5 0 r
.35986 .26604 Mdot
.48883 .37025 Mdot
.628 .126 .941 r
.66891 .50366 Mdot
.4998 .45148 Mdot
1 .5 0 r
.66824 .52965 Mdot
.628 .126 .941 r
.49065 .5261 Mdot
1 .5 0 r
.48391 .54239 Mdot
.628 .126 .941 r
.49238 .37293 Mdot
.62187 .44134 Mdot
.53464 .55193 Mdot
.54716 .59103 Mdot
.41939 .36942 Mdot
.35524 .21607 Mdot
.37354 .31057 Mdot
.39694 .48647 Mdot
.51972 .57119 Mdot
1 .5 0 r
.61101 .54832 Mdot
.628 .126 .941 r
.57086 .60041 Mdot
.32283 .48931 Mdot
.40085 .50886 Mdot
1 .5 0 r
.43534 .34583 Mdot
.628 .126 .941 r
.51095 .54466 Mdot
.33881 .2219 Mdot
.3942 .46963 Mdot
1 .5 0 r
.52309 .5641 Mdot
.628 .126 .941 r
.31577 .43039 Mdot
1 .5 0 r
.52897 .56398 Mdot
.4016 .30638 Mdot
.5281 .58017 Mdot
.75451 .72688 Mdot
.628 .126 .941 r
.30341 .28017 Mdot
.45227 .37146 Mdot
1 .5 0 r
.88055 .55077 Mdot
.628 .126 .941 r
.37961 .38763 Mdot
1 .5 0 r
.26828 .29274 Mdot
.628 .126 .941 r
.48878 .3742 Mdot
.32377 .48502 Mdot
.73628 .39045 Mdot
1 .5 0 r
.35209 .24674 Mdot
.3839 .30871 Mdot
.628 .126 .941 r
.456 .26298 Mdot
.29916 .24987 Mdot
1 .5 0 r
.4934 .37056 Mdot
.64032 .54 Mdot
.89386 .62155 Mdot
.628 .126 .941 r
.38734 .36697 Mdot
1 .5 0 r
.41365 .32776 Mdot
.38666 .39301 Mdot
.628 .126 .941 r
.36043 .37663 Mdot
.47854 .33422 Mdot
.49686 .42883 Mdot
.50168 .55608 Mdot
.28964 .24925 Mdot
.41885 .35366 Mdot
1 .5 0 r
.58258 .29487 Mdot
.54719 .47427 Mdot
.628 .126 .941 r
.56503 .60479 Mdot
.31998 .29786 Mdot
1 .5 0 r
.53292 .4675 Mdot
.43348 .50322 Mdot
.628 .126 .941 r
.49945 .38226 Mdot
1 .5 0 r
.60797 .57159 Mdot
.628 .126 .941 r
.51276 .33976 Mdot
.50456 .46381 Mdot
.46405 .56174 Mdot
1 .5 0 r
.58733 .60085 Mdot
.56177 .55841 Mdot
.53215 .30699 Mdot
.628 .126 .941 r
.41184 .48321 Mdot
.5088 .56156 Mdot
.33977 .47336 Mdot
1 .5 0 r
.54093 .57783 Mdot
.54682 .57771 Mdot
.54036 .54827 Mdot
.55965 .57113 Mdot
.4813 .54168 Mdot
.628 .126 .941 r
.49413 .53509 Mdot
1 .5 0 r
.72139 .64611 Mdot
.628 .126 .941 r
.4703 .33911 Mdot
1 .5 0 r
.55985 .45987 Mdot
.628 .126 .941 r
.48631 .55778 Mdot
1 .5 0 r
.49316 .48581 Mdot
.5641 .55766 Mdot
.67732 .37797 Mdot
.714 .5674 Mdot
.628 .126 .941 r
.39143 .2244 Mdot
.66295 .42684 Mdot
1 .5 0 r
.50416 .56729 Mdot
.628 .126 .941 r
.43399 .41371 Mdot
.72212 .37778 Mdot
.48399 .56064 Mdot
.46593 .42012 Mdot
1 .5 0 r
.53592 .56385 Mdot
.91253 .71074 Mdot
.30275 .27605 Mdot
.628 .126 .941 r
.36531 .46222 Mdot
.47538 .5439 Mdot
1 .5 0 r
.51574 .43602 Mdot
.41947 .27585 Mdot
.54046 .49471 Mdot
.628 .126 .941 r
.5395 .56659 Mdot
.57909 .54045 Mdot
.41763 .36394 Mdot
1 .5 0 r
.55186 .59595 Mdot
.3986 .29525 Mdot
.35225 .33774 Mdot
.8386 .60231 Mdot
.55041 .58259 Mdot
.55717 .56625 Mdot
.628 .126 .941 r
.54288 .55948 Mdot
.39972 .4777 Mdot
1 .5 0 r
.60094 .57244 Mdot
.628 .126 .941 r
.76606 .38592 Mdot
.57332 .60823 Mdot
1 .5 0 r
.47052 .41849 Mdot
.628 .126 .941 r
.52231 .41182 Mdot
.52665 .57531 Mdot
1 .5 0 r
.65093 .53268 Mdot
.628 .126 .941 r
.39803 .33315 Mdot
1 .5 0 r
.53216 .55546 Mdot
.53216 .55546 Mdot
.53197 .54559 Mdot
.628 .126 .941 r
.69686 .40484 Mdot
.43377 .47346 Mdot
1 .5 0 r
.56329 .57812 Mdot
.537 .56171 Mdot
.76474 .6172 Mdot
.628 .126 .941 r
.61713 .37182 Mdot
.59007 .43724 Mdot
1 .5 0 r
.5166 .54518 Mdot
.56184 .56475 Mdot
.54812 .58759 Mdot
.628 .126 .941 r
.53487 .57445 Mdot
.72707 .3781 Mdot
.30293 .2439 Mdot
.46922 .53834 Mdot
.85596 .5089 Mdot
1 .5 0 r
.54058 .56446 Mdot
.5662 .60699 Mdot
.54715 .53823 Mdot
.53342 .56107 Mdot
.67683 .58719 Mdot
.628 .126 .941 r
.64975 .65263 Mdot
1 .5 0 r
.51515 .41044 Mdot
.628 .126 .941 r
.89325 .54132 Mdot
1 .5 0 r
.53913 .55108 Mdot
.55218 .55435 Mdot
.56476 .59362 Mdot
.60711 .34159 Mdot
.45992 .54769 Mdot
.628 .126 .941 r
.46263 .32183 Mdot
1 .5 0 r
.43555 .38728 Mdot
.628 .126 .941 r
.90461 .57709 Mdot
.46853 .32169 Mdot
.478 .5671 Mdot
1 .5 0 r
.537 .56382 Mdot
.537 .56382 Mdot
.628 .126 .941 r
.88424 .56055 Mdot
.49957 .40011 Mdot
.52375 .55067 Mdot
1 .5 0 r
.54291 .56371 Mdot
.40148 .33779 Mdot
.38871 .28863 Mdot
.49415 .2428 Mdot
.628 .126 .941 r
.5222 .59305 Mdot
.39867 .49806 Mdot
.41782 .5111 Mdot
.47635 .54383 Mdot
1 .5 0 r
.54213 .52419 Mdot
.54775 .56997 Mdot
.63869 .62889 Mdot
.628 .126 .941 r
.5043 .34067 Mdot
1 .5 0 r
.54059 .56658 Mdot
.54059 .56658 Mdot
.48137 .55997 Mdot
.5134 .5664 Mdot
.628 .126 .941 r
.57823 .61879 Mdot
1 .5 0 r
.49317 .55974 Mdot
.57765 .58915 Mdot
.53091 .55617 Mdot
.53091 .55617 Mdot
.53091 .55617 Mdot
.64125 .63805 Mdot
.55008 .56922 Mdot
.628 .126 .941 r
.77995 .53646 Mdot
1 .5 0 r
.54989 .55933 Mdot
.628 .126 .941 r
.57554 .60191 Mdot
1 .5 0 r
.57554 .60191 Mdot
.51243 .3955 Mdot
.47951 .40533 Mdot
.45928 .39865 Mdot
.56818 .58864 Mdot
.628 .126 .941 r
.83469 .73599 Mdot
1 .5 0 r
.5436 .41818 Mdot
.628 .126 .941 r
.48483 .37553 Mdot
1 .5 0 r
.54776 .57209 Mdot
.53411 .53915 Mdot
.628 .126 .941 r
.41821 .35561 Mdot
.516 .39821 Mdot
1 .5 0 r
.52811 .47357 Mdot
.628 .126 .941 r
.38945 .51938 Mdot
1 .5 0 r
.60489 .59146 Mdot
.59812 .60784 Mdot
.628 .126 .941 r
.55851 .57824 Mdot
.40822 .51264 Mdot
1 .5 0 r
.53314 .48971 Mdot
.5651 .55197 Mdot
.63095 .5323 Mdot
.56462 .58801 Mdot
.628 .126 .941 r
.6356 .65022 Mdot
1 .5 0 r
.53808 .56168 Mdot
.53808 .56168 Mdot
.628 .126 .941 r
.59842 .44037 Mdot
1 .5 0 r
.5377 .5419 Mdot
.40287 .29931 Mdot
.628 .126 .941 r
.53702 .56806 Mdot
1 .5 0 r
.46757 .34185 Mdot
.628 .126 .941 r
.65306 .69583 Mdot
.41177 .51538 Mdot
1 .5 0 r
.53673 .49244 Mdot
.55543 .54155 Mdot
.55494 .57761 Mdot
.628 .126 .941 r
.77775 .59727 Mdot
1 .5 0 r
.61966 .62016 Mdot
.60639 .607 Mdot
.61947 .61027 Mdot
.61947 .61027 Mdot
.628 .126 .941 r
.4662 .27255 Mdot
1 .5 0 r
.56066 .5676 Mdot
.59312 .59383 Mdot
.628 .126 .941 r
.75629 .5871 Mdot
1 .5 0 r
.45727 .30165 Mdot
.628 .126 .941 r
.78674 .69185 Mdot
.3403 .1901 Mdot
.57288 .46554 Mdot
1 .5 0 r
.54526 .56719 Mdot
.628 .126 .941 r
.88637 .58031 Mdot
.31277 .23587 Mdot
1 .5 0 r
.59672 .59659 Mdot
.88262 .81303 Mdot
.628 .126 .941 r
.37508 .4588 Mdot
1 .5 0 r
.54468 .53751 Mdot
.6886 .57358 Mdot
.51541 .24885 Mdot
.53092 .5604 Mdot
.5504 .52749 Mdot
.628 .126 .941 r
.70936 .42254 Mdot
.38959 .23217 Mdot
1 .5 0 r
.49864 .42241 Mdot
.54885 .56995 Mdot
.54885 .56995 Mdot
.628 .126 .941 r
.4333 .35012 Mdot
.57047 .4026 Mdot
1 .5 0 r
.61361 .61254 Mdot
.60033 .59936 Mdot
.628 .126 .941 r
.52404 .38936 Mdot
.56718 .59931 Mdot
1 .5 0 r
.56718 .59931 Mdot
.628 .126 .941 r
.34109 .29743 Mdot
1 .5 0 r
.53451 .56316 Mdot
.61255 .61893 Mdot
.78367 .58941 Mdot
.9194 .75016 Mdot
.38598 .35314 Mdot
.48341 .43188 Mdot
.56728 .54342 Mdot
.628 .126 .941 r
.56776 .50733 Mdot
.3213 .25465 Mdot
1 .5 0 r
.55351 .56633 Mdot
.628 .126 .941 r
.52132 .49409 Mdot
.3209 .23483 Mdot
1 .5 0 r
.55264 .58262 Mdot
.45015 .366 Mdot
.628 .126 .941 r
.61965 .43484 Mdot
1 .5 0 r
.61189 .52344 Mdot
.42988 .35931 Mdot
.628 .126 .941 r
.51453 .38878 Mdot
1 .5 0 r
.80643 .66114 Mdot
.628 .126 .941 r
.36838 .48716 Mdot
1 .5 0 r
.60288 .60853 Mdot
.628 .126 .941 r
.43491 .37546 Mdot
.53752 .53621 Mdot
.53732 .52631 Mdot
1 .5 0 r
.60794 .62471 Mdot
.62084 .61809 Mdot
.54644 .26354 Mdot
.628 .126 .941 r
.58767 .61803 Mdot
1 .5 0 r
.58767 .61803 Mdot
.58767 .61803 Mdot
.60756 .60491 Mdot
.628 .126 .941 r
.40753 .30942 Mdot
1 .5 0 r
.66635 .58181 Mdot
.45302 .27311 Mdot
.40694 .27968 Mdot
.47048 .44054 Mdot
.628 .126 .941 r
.72079 .39458 Mdot
1 .5 0 r
.56071 .57185 Mdot
.59321 .59811 Mdot
.628 .126 .941 r
.73 .68675 Mdot
1 .5 0 r
.58137 .47659 Mdot
.52801 .53568 Mdot
.628 .126 .941 r
.57361 .56523 Mdot
1 .5 0 r
.62446 .62087 Mdot
.62446 .62087 Mdot
.58643 .49276 Mdot
.57867 .58141 Mdot
.61117 .60768 Mdot
.61117 .60768 Mdot
.628 .126 .941 r
.40187 .50912 Mdot
1 .5 0 r
.6302 .61085 Mdot
.62389 .59115 Mdot
.6234 .62727 Mdot
.628 .126 .941 r
.45339 .53855 Mdot
1 .5 0 r
.41049 .28235 Mdot
.54539 .5155 Mdot
.87049 .77821 Mdot
.52627 .44648 Mdot
.36234 .36754 Mdot
.51132 .53175 Mdot
.628 .126 .941 r
.43445 .35762 Mdot
1 .5 0 r
.43396 .39375 Mdot
.64119 .62693 Mdot
.88869 .79772 Mdot
.42843 .29187 Mdot
.5816 .6104 Mdot
.5816 .6104 Mdot
.628 .126 .941 r
.31668 .21611 Mdot
1 .5 0 r
.61373 .61686 Mdot
.61373 .61686 Mdot
.61373 .61686 Mdot
.60063 .61357 Mdot
.628 .126 .941 r
.54364 .42628 Mdot
1 .5 0 r
.60043 .60366 Mdot
.60043 .60366 Mdot
.60043 .60366 Mdot
.60043 .60366 Mdot
.628 .126 .941 r
.43229 .37037 Mdot
.53403 .60355 Mdot
.4785 .30782 Mdot
1 .5 0 r
.87298 .77756 Mdot
.628 .126 .941 r
.41742 .39968 Mdot
1 .5 0 r
.56646 .56395 Mdot
.628 .126 .941 r
.59851 .62637 Mdot
1 .5 0 r
.61841 .61323 Mdot
.61841 .61323 Mdot
.61841 .61323 Mdot
.628 .126 .941 r
.41771 .35362 Mdot
1 .5 0 r
.56608 .54412 Mdot
.628 .126 .941 r
.53889 .60983 Mdot
1 .5 0 r
.61735 .61963 Mdot
.61735 .61963 Mdot
.628 .126 .941 r
.42295 .37971 Mdot
1 .5 0 r
.58414 .61958 Mdot
.63027 .61301 Mdot
.60405 .60644 Mdot
.60405 .60644 Mdot
.60405 .60644 Mdot
.628 .126 .941 r
.61648 .63595 Mdot
1 .5 0 r
.52549 .53074 Mdot
.57065 .59646 Mdot
.628 .126 .941 r
.7375 .39266 Mdot
.52432 .59312 Mdot
1 .5 0 r
.50568 .4879 Mdot
.63533 .62921 Mdot
.628 .126 .941 r
.58949 .58972 Mdot
1 .5 0 r
.62203 .61601 Mdot
.62203 .61601 Mdot
.62203 .61601 Mdot
.58882 .61596 Mdot
.628 .126 .941 r
.58833 .65211 Mdot
.60271 .53702 Mdot
1 .5 0 r
.63428 .63562 Mdot
.65419 .62247 Mdot
.50538 .41206 Mdot
.628 .126 .941 r
.53695 .51066 Mdot
.50422 .47445 Mdot
1 .5 0 r
.60767 .60921 Mdot
.60767 .60921 Mdot
.60767 .60921 Mdot
.628 .126 .941 r
.46322 .56314 Mdot
1 .5 0 r
.52326 .47761 Mdot
.628 .126 .941 r
.71317 .54336 Mdot
1 .5 0 r
.52306 .46769 Mdot
.628 .126 .941 r
.46263 .53338 Mdot
1 .5 0 r
.61953 .60899 Mdot
.61953 .60899 Mdot
.628 .126 .941 r
.44398 .42812 Mdot
1 .5 0 r
.57368 .56948 Mdot
.62566 .61879 Mdot
.62566 .61879 Mdot
.628 .126 .941 r
.79209 .45107 Mdot
1 .5 0 r
.73944 .42799 Mdot
.628 .126 .941 r
.67677 .68443 Mdot
.48954 .39176 Mdot
.49391 .55616 Mdot
.60662 .49369 Mdot
1 .5 0 r
.6246 .6252 Mdot
.46408 .30293 Mdot
.63752 .61857 Mdot
.61129 .61199 Mdot
.61129 .61199 Mdot
.61129 .61199 Mdot
.57806 .61194 Mdot
.628 .126 .941 r
.67553 .68093 Mdot
.73559 .59538 Mdot
1 .5 0 r
.92976 .81565 Mdot
.628 .126 .941 r
.5457 .47359 Mdot
1 .5 0 r
.62928 .62158 Mdot
.62928 .62158 Mdot
.49964 .42414 Mdot
.51227 .4636 Mdot
.628 .126 .941 r
.63668 .51293 Mdot
1 .5 0 r
.54337 .59844 Mdot
.6289 .60173 Mdot
.39447 .3879 Mdot
.628 .126 .941 r
.57185 .41421 Mdot
1 .5 0 r
.5634 .52926 Mdot
.628 .126 .941 r
.60908 .55886 Mdot
1 .5 0 r
.62172 .59833 Mdot
.61491 .61477 Mdot
.61491 .61477 Mdot
.61491 .61477 Mdot
.6084 .58511 Mdot
.6084 .58511 Mdot
.69394 .5884 Mdot
.39533 .24956 Mdot
.628 .126 .941 r
.53045 .48309 Mdot
.53511 .60145 Mdot
.65273 .66723 Mdot
.62708 .56844 Mdot
1 .5 0 r
.63291 .62436 Mdot
.60034 .59804 Mdot
.63291 .62436 Mdot
.63291 .62436 Mdot
.628 .126 .941 r
.64555 .66383 Mdot
1 .5 0 r
.6927 .58489 Mdot
.628 .126 .941 r
.68765 .44666 Mdot
.56758 .5618 Mdot
.4972 .361 Mdot
1 .5 0 r
.61854 .61756 Mdot
.61854 .61756 Mdot
.4691 .44312 Mdot
.628 .126 .941 r
.42826 .54183 Mdot
1 .5 0 r
.59987 .51222 Mdot
.61203 .58789 Mdot
.628 .126 .941 r
.54182 .397 Mdot
.53871 .60423 Mdot
.48747 .47255 Mdot
1 .5 0 r
.63041 .61733 Mdot
.60416 .61075 Mdot
.60416 .61075 Mdot
.60416 .61075 Mdot
.628 .126 .941 r
.42309 .33758 Mdot
1 .5 0 r
.48192 .37048 Mdot
.63654 .62715 Mdot
.84611 .71599 Mdot
.628 .126 .941 r
.60329 .62709 Mdot
1 .5 0 r
.60329 .62709 Mdot
.62216 .62034 Mdot
.62216 .62034 Mdot
.46149 .29775 Mdot
.5889 .62028 Mdot
.628 .126 .941 r
.60233 .57744 Mdot
1 .5 0 r
.58871 .61035 Mdot
.45312 .3568 Mdot
.60778 .61353 Mdot
.60778 .61353 Mdot
.60778 .61353 Mdot
.80573 .59049 Mdot
.64018 .62993 Mdot
.60759 .6036 Mdot
.57432 .60354 Mdot
.57432 .60354 Mdot
.38005 .32698 Mdot
.628 .126 .941 r
.73962 .48815 Mdot
1 .5 0 r
.60585 .63629 Mdot
.628 .126 .941 r
.48112 .57698 Mdot
1 .5 0 r
.57939 .61978 Mdot
.628 .126 .941 r
.75014 .66258 Mdot
1 .5 0 r
.67046 .65917 Mdot
.70306 .68551 Mdot
.628 .126 .941 r
.48881 .42206 Mdot
1 .5 0 r
.67027 .64924 Mdot
.55166 .59974 Mdot
.44248 .3626 Mdot
.628 .126 .941 r
.85508 .55688 Mdot
.40384 .27033 Mdot
1 .5 0 r
.52889 .2835 Mdot
.5396 .46791 Mdot
.55858 .52718 Mdot
.47469 .36906 Mdot
.49415 .39211 Mdot
.62942 .62591 Mdot
.62942 .62591 Mdot
.47984 .45132 Mdot
.628 .126 .941 r
.5397 .4118 Mdot
.5397 .4118 Mdot
1 .5 0 r
.59614 .62586 Mdot
.59614 .62586 Mdot
.628 .126 .941 r
.43176 .5467 Mdot
1 .5 0 r
.55732 .52365 Mdot
.56861 .61575 Mdot
.628 .126 .941 r
.57085 .42466 Mdot
1 .5 0 r
.44606 .36531 Mdot
.628 .126 .941 r
.81012 .74739 Mdot
1 .5 0 r
.60872 .47718 Mdot
.61359 .60564 Mdot
.61359 .60564 Mdot
.63257 .66494 Mdot
.628 .126 .941 r
.61924 .65171 Mdot
.58887 .43423 Mdot
.58059 .55941 Mdot
.69139 .63183 Mdot
1 .5 0 r
.64495 .62848 Mdot
.628 .126 .941 r
.76014 .37474 Mdot
1 .5 0 r
.61847 .61195 Mdot
.61847 .61195 Mdot
.63162 .61524 Mdot
.64427 .65478 Mdot
.628 .126 .941 r
.72996 .65808 Mdot
1 .5 0 r
.53406 .48999 Mdot
.5212 .4405 Mdot
.58498 .60195 Mdot
.628 .126 .941 r
.71498 .74363 Mdot
1 .5 0 r
.63689 .64144 Mdot
.628 .126 .941 r
.36501 .23608 Mdot
1 .5 0 r
.62355 .6282 Mdot
.61722 .60843 Mdot
.628 .126 .941 r
.50874 .28867 Mdot
1 .5 0 r
.53308 .44025 Mdot
.628 .126 .941 r
.57301 .41389 Mdot
1 .5 0 r
.61635 .62479 Mdot
.42917 .29519 Mdot
.628 .126 .941 r
.80996 .42701 Mdot
1 .5 0 r
.93024 .80269 Mdot
.51322 .39729 Mdot
.6223 .62468 Mdot
.6221 .61474 Mdot
.628 .126 .941 r
.50533 .42017 Mdot
.52968 .57178 Mdot
1 .5 0 r
.4988 .39044 Mdot
.83594 .78256 Mdot
.60683 .62429 Mdot
.628 .126 .941 r
.60664 .61434 Mdot
.62593 .62747 Mdot
1 .5 0 r
.62593 .62747 Mdot
.60674 .55818 Mdot
.628 .126 .941 r
.37349 .18881 Mdot
.5552 .4163 Mdot
.51331 .58774 Mdot
1 .5 0 r
.60587 .57455 Mdot
.628 .126 .941 r
.62449 .614 Mdot
.63033 .67005 Mdot
1 .5 0 r
.5975 .63373 Mdot
.63696 .64362 Mdot
.65694 .63043 Mdot
.61065 .63703 Mdot
.85913 .80848 Mdot
.628 .126 .941 r
.41391 .49512 Mdot
1 .5 0 r
.52042 .40273 Mdot
.628 .126 .941 r
.33778 .19154 Mdot
1 .5 0 r
.57753 .52462 Mdot
.56437 .52132 Mdot
.4404 .38935 Mdot
.628 .126 .941 r
.69722 .43552 Mdot
1 .5 0 r
.5827 .60701 Mdot
.63221 .33651 Mdot
.628 .126 .941 r
.70299 .42543 Mdot
1 .5 0 r
.94875 .75846 Mdot
.628 .126 .941 r
.48942 .5242 Mdot
1 .5 0 r
.56156 .56049 Mdot
.628 .126 .941 r
.52393 .33928 Mdot
1 .5 0 r
.53563 .45145 Mdot
.6186 .61628 Mdot
.67759 .64928 Mdot
.4312 .28629 Mdot
.60476 .63932 Mdot
.56634 .50063 Mdot
.628 .126 .941 r
.61228 .47411 Mdot
1 .5 0 r
.63666 .6259 Mdot
.63666 .6259 Mdot
.6035 .6358 Mdot
.6035 .6358 Mdot
.57942 .43775 Mdot
.628 .126 .941 r
.63598 .65224 Mdot
1 .5 0 r
.51973 .43109 Mdot
.628 .126 .941 r
.81036 .43109 Mdot
1 .5 0 r
.59726 .55979 Mdot
.62156 .64542 Mdot
.60839 .64212 Mdot
.60839 .64212 Mdot
.61551 .57936 Mdot
.628 .126 .941 r
.57777 .41427 Mdot
.50861 .59569 Mdot
1 .5 0 r
.59397 .6353 Mdot
.60713 .6386 Mdot
.60713 .6386 Mdot
.6403 .6287 Mdot
.628 .126 .941 r
.48452 .39757 Mdot
1 .5 0 r
.5806 .62204 Mdot
.628 .126 .941 r
.58705 .58561 Mdot
.51397 .56569 Mdot
1 .5 0 r
.61203 .64492 Mdot
.6252 .64822 Mdot
.628 .126 .941 r
.56256 .36754 Mdot
1 .5 0 r
.63818 .64157 Mdot
.73672 .68448 Mdot
.628 .126 .941 r
.43748 .30805 Mdot
1 .5 0 r
.54139 .44341 Mdot
.59262 .56557 Mdot
.69 .67117 Mdot
.628 .126 .941 r
.68951 .70749 Mdot
1 .5 0 r
.50197 .37725 Mdot
.628 .126 .941 r
.59272 .50932 Mdot
1 .5 0 r
.5976 .6381 Mdot
.65663 .67111 Mdot
.55984 .47294 Mdot
.58423 .62483 Mdot
.58423 .62483 Mdot
.62375 .63474 Mdot
.628 .126 .941 r
.7029 .5983 Mdot
1 .5 0 r
.50655 .42983 Mdot
.61049 .56522 Mdot
.628 .126 .941 r
.64221 .66429 Mdot
.68905 .62136 Mdot
1 .5 0 r
.62865 .64106 Mdot
.45424 .31405 Mdot
.628 .126 .941 r
.73972 .71367 Mdot
1 .5 0 r
.70684 .67728 Mdot
.57683 .48897 Mdot
.628 .126 .941 r
.78913 .43282 Mdot
1 .5 0 r
.61441 .6442 Mdot
.61441 .6442 Mdot
.628 .126 .941 r
.74892 .44927 Mdot
.55692 .4459 Mdot
.55702 .38962 Mdot
1 .5 0 r
.56141 .55479 Mdot
.6193 .65053 Mdot
.92927 .70999 Mdot
.628 .126 .941 r
.6977 .69672 Mdot
1 .5 0 r
.6977 .69672 Mdot
.56698 .53473 Mdot
.71051 .6801 Mdot
.63269 .54128 Mdot
.63172 .61396 Mdot
.60487 .6437 Mdot
.60487 .6437 Mdot
.61805 .647 Mdot
.628 .126 .941 r
.65057 .66347 Mdot
1 .5 0 r
.71024 .60388 Mdot
.628 .126 .941 r
.37734 .22706 Mdot
1 .5 0 r
.47549 .30637 Mdot
.628 .126 .941 r
.65029 .58725 Mdot
1 .5 0 r
.60342 .6302 Mdot
.62295 .65333 Mdot
.6625 .66325 Mdot
.40253 .29638 Mdot
.56494 .49129 Mdot
.55059 .55072 Mdot
.64923 .59368 Mdot
.6085 .6465 Mdot
.58389 .4845 Mdot
.59024 .50433 Mdot
.628 .126 .941 r
.42722 .27945 Mdot
.3943 .24302 Mdot
.51787 .40168 Mdot
1 .5 0 r
.68618 .65284 Mdot
.66615 .66606 Mdot
.79754 .73547 Mdot
.628 .126 .941 r
.49501 .57675 Mdot
1 .5 0 r
.69166 .68909 Mdot
.81164 .59978 Mdot
.628 .126 .941 r
.67467 .42781 Mdot
1 .5 0 r
.62533 .65262 Mdot
.62533 .65262 Mdot
.62533 .65262 Mdot
.62533 .65262 Mdot
.50301 .37485 Mdot
.58665 .50367 Mdot
.59174 .51996 Mdot
.628 .126 .941 r
.84876 .60263 Mdot
1 .5 0 r
.6109 .52314 Mdot
.62898 .65542 Mdot
.628 .126 .941 r
.63661 .55616 Mdot
1 .5 0 r
.46049 .33782 Mdot
.91741 .81737 Mdot
.57074 .48328 Mdot
.49235 .38068 Mdot
.49821 .43691 Mdot
.628 .126 .941 r
.55735 .46999 Mdot
.56859 .61882 Mdot
1 .5 0 r
.6287 .57913 Mdot
.72596 .73128 Mdot
.74513 .73448 Mdot
.72472 .72776 Mdot
.41218 .31089 Mdot
.46448 .36051 Mdot
.61943 .65493 Mdot
.61943 .65493 Mdot
.63263 .65824 Mdot
.93569 .77071 Mdot
.628 .126 .941 r
.88467 .60194 Mdot
1 .5 0 r
.61905 .63497 Mdot
.63225 .63828 Mdot
.61837 .66138 Mdot
.64536 .57524 Mdot
.65074 .66789 Mdot
.45694 .28071 Mdot
.4631 .29057 Mdot
.63628 .66105 Mdot
.63628 .66105 Mdot
.63628 .66105 Mdot
.62308 .65774 Mdot
.62308 .65774 Mdot
.62308 .65774 Mdot
.68224 .69083 Mdot
.60969 .64445 Mdot
.43541 .28037 Mdot
.46769 .34325 Mdot
.42083 .32988 Mdot
.44773 .30009 Mdot
.60305 .54824 Mdot
.60334 .50185 Mdot
.628 .126 .941 r
.63562 .56473 Mdot
1 .5 0 r
.64785 .64086 Mdot
.628 .126 .941 r
.62095 .67065 Mdot
.40165 .2039 Mdot
.38747 .27341 Mdot
.55131 .4058 Mdot
.5831 .5051 Mdot
1 .5 0 r
.63445 .62756 Mdot
.628 .126 .941 r
.72591 .72355 Mdot
.63456 .57118 Mdot
1 .5 0 r
.62673 .66055 Mdot
.628 .126 .941 r
.49252 .26989 Mdot
1 .5 0 r
.61333 .64726 Mdot
.439 .28306 Mdot
.628 .126 .941 r
.54642 .64714 Mdot
1 .5 0 r
.50367 .35245 Mdot
.63917 .62392 Mdot
.628 .126 .941 r
.48977 .37556 Mdot
.66588 .58413 Mdot
1 .5 0 r
.49642 .34901 Mdot
.628 .126 .941 r
.74427 .62043 Mdot
1 .5 0 r
.84994 .64692 Mdot
.628 .126 .941 r
.56257 .30914 Mdot
1 .5 0 r
.48869 .38199 Mdot
.628 .126 .941 r
.55474 .39854 Mdot
.35179 .16331 Mdot
1 .5 0 r
.61698 .65007 Mdot
.54564 .48438 Mdot
.628 .126 .941 r
.57207 .491 Mdot
1 .5 0 r
.62932 .66982 Mdot
.48771 .33199 Mdot
.55866 .4777 Mdot
.628 .126 .941 r
.5064 .3716 Mdot
1 .5 0 r
.5064 .3716 Mdot
.51178 .46433 Mdot
.628 .126 .941 r
.65027 .51732 Mdot
1 .5 0 r
.64244 .60674 Mdot
.628 .126 .941 r
.74668 .74252 Mdot
1 .5 0 r
.44111 .27217 Mdot
.628 .126 .941 r
.43231 .43446 Mdot
.56327 .53044 Mdot
1 .5 0 r
.63404 .66618 Mdot
.628 .126 .941 r
.63629 .47402 Mdot
1 .5 0 r
.62063 .65288 Mdot
.62063 .65288 Mdot
.75963 .66944 Mdot
.61339 .64946 Mdot
.628 .126 .941 r
.51824 .30489 Mdot
.53371 .60959 Mdot
.69182 .68578 Mdot
1 .5 0 r
.6185 .6658 Mdot
.628 .126 .941 r
.84252 .74857 Mdot
.55202 .62924 Mdot
1 .5 0 r
.63769 .669 Mdot
.63769 .669 Mdot
.65091 .67231 Mdot
.628 .126 .941 r
.57738 .64233 Mdot
1 .5 0 r
.69666 .6257 Mdot
.50061 .38374 Mdot
.628 .126 .941 r
.65926 .42351 Mdot
.53733 .61239 Mdot
.66366 .5892 Mdot
1 .5 0 r
.54644 .40356 Mdot
.628 .126 .941 r
.73448 .72501 Mdot
.55996 .36041 Mdot
1 .5 0 r
.56583 .41675 Mdot
.628 .126 .941 r
.73361 .74147 Mdot
1 .5 0 r
.61667 .50936 Mdot
.62794 .65851 Mdot
.44702 .27398 Mdot
.63411 .6684 Mdot
.63411 .6684 Mdot
.76077 .59874 Mdot
.628 .126 .941 r
.39422 .20423 Mdot
1 .5 0 r
.51725 .37978 Mdot
.62041 .57862 Mdot
.45122 .30672 Mdot
.628 .126 .941 r
.69939 .5785 Mdot
.67783 .70117 Mdot
.70429 .7078 Mdot
.5297 .34305 Mdot
1 .5 0 r
.63159 .66133 Mdot
.51578 .36619 Mdot
.628 .126 .941 r
.6412 .41592 Mdot
.56801 .40591 Mdot
1 .5 0 r
.61945 .52859 Mdot
.628 .126 .941 r
.6514 .57158 Mdot
1 .5 0 r
.70383 .62132 Mdot
.49442 .37588 Mdot
.628 .126 .941 r
.74804 .74058 Mdot
1 .5 0 r
.7549 .724 Mdot
.628 .126 .941 r
.83605 .58798 Mdot
1 .5 0 r
.8148 .6642 Mdot
.628 .126 .941 r
.80628 .78022 Mdot
1 .5 0 r
.92536 .81007 Mdot
.59027 .50484 Mdot
.68124 .6275 Mdot
.68007 .69046 Mdot
.64047 .62401 Mdot
.628 .126 .941 r
.66008 .64723 Mdot
1 .5 0 r
.63312 .67708 Mdot
.628 .126 .941 r
.55676 .38173 Mdot
.59989 .63053 Mdot
1 .5 0 r
.94302 .78977 Mdot
.5948 .49114 Mdot
.628 .126 .941 r
.64676 .5774 Mdot
.69823 .70014 Mdot
1 .5 0 r
.45783 .28207 Mdot
.628 .126 .941 r
.58088 .5143 Mdot
1 .5 0 r
.75098 .70341 Mdot
.47087 .27537 Mdot
.73069 .70667 Mdot
.628 .126 .941 r
.51558 .35818 Mdot
.69796 .62362 Mdot
.74955 .68987 Mdot
.6918 .49065 Mdot
1 .5 0 r
.60414 .54031 Mdot
.62326 .60005 Mdot
.628 .126 .941 r
.75204 .38427 Mdot
.50341 .59667 Mdot
1 .5 0 r
.62209 .66304 Mdot
.628 .126 .941 r
.85239 .80238 Mdot
1 .5 0 r
.62789 .65292 Mdot
.47908 .3309 Mdot
.628 .126 .941 r
.59709 .42378 Mdot
1 .5 0 r
.58924 .5134 Mdot
.61573 .52004 Mdot
.628 .126 .941 r
.57365 .6361 Mdot
1 .5 0 r
.65243 .68252 Mdot
.628 .126 .941 r
.73152 .68241 Mdot
.52185 .43668 Mdot
1 .5 0 r
.65921 .59936 Mdot
.628 .126 .941 r
.7959 .78855 Mdot
1 .5 0 r
.61988 .48629 Mdot
.628 .126 .941 r
.73597 .7253 Mdot
1 .5 0 r
.6296 .67871 Mdot
.64266 .67201 Mdot
.55316 .38304 Mdot
.628 .126 .941 r
.85378 .74164 Mdot
.57191 .42276 Mdot
.69754 .47258 Mdot
1 .5 0 r
.47896 .38948 Mdot
.56347 .48236 Mdot
.50487 .36604 Mdot
.628 .126 .941 r
.71592 .49226 Mdot
1 .5 0 r
.77856 .75462 Mdot
.628 .126 .941 r
.46962 .46556 Mdot
1 .5 0 r
.57545 .48211 Mdot
.628 .126 .941 r
.66116 .51195 Mdot
.64654 .56166 Mdot
1 .5 0 r
.77694 .73105 Mdot
.43014 .28577 Mdot
.56054 .45516 Mdot
.66345 .69102 Mdot
.93398 .85051 Mdot
.45605 .26231 Mdot
.628 .126 .941 r
.63969 .45503 Mdot
1 .5 0 r
.63674 .67435 Mdot
.63674 .67435 Mdot
.628 .126 .941 r
.74831 .73738 Mdot
1 .5 0 r
.51389 .33853 Mdot
.65041 .57448 Mdot
.628 .126 .941 r
.59767 .51461 Mdot
1 .5 0 r
.58422 .50125 Mdot
.74775 .70731 Mdot
.78065 .73389 Mdot
.628 .126 .941 r
.67193 .38486 Mdot
1 .5 0 r
.68224 .60755 Mdot
.4466 .27172 Mdot
.628 .126 .941 r
.61114 .40468 Mdot
1 .5 0 r
.4187 .31812 Mdot
.628 .126 .941 r
.43835 .34139 Mdot
.52578 .27159 Mdot
1 .5 0 r
.61075 .3846 Mdot
.628 .126 .941 r
.69572 .49762 Mdot
.51114 .32131 Mdot
1 .5 0 r
.64013 .6005 Mdot
.78388 .77331 Mdot
.628 .126 .941 r
.82102 .46075 Mdot
1 .5 0 r
.5354 .39751 Mdot
.628 .126 .941 r
.65312 .52712 Mdot
.67209 .57693 Mdot
1 .5 0 r
.63063 .66665 Mdot
.628 .126 .941 r
.5587 .54689 Mdot
1 .5 0 r
.50248 .24755 Mdot
.54769 .35064 Mdot
.53374 .37385 Mdot
.67034 .60996 Mdot
.90768 .77955 Mdot
.628 .126 .941 r
.44066 .34053 Mdot
1 .5 0 r
.59968 .37039 Mdot
.50661 .33707 Mdot
.49245 .35024 Mdot
.59173 .39348 Mdot
.5244 .45002 Mdot
.6225 .55639 Mdot
.628 .126 .941 r
.41981 .25697 Mdot
.68257 .4964 Mdot
1 .5 0 r
.64227 .52301 Mdot
.6288 .50965 Mdot
.628 .126 .941 r
.7051 .72909 Mdot
1 .5 0 r
.64739 .53941 Mdot
.6995 .6259 Mdot
.628 .126 .941 r
.51693 .31311 Mdot
1 .5 0 r
.65261 .62252 Mdot
.62666 .52259 Mdot
.628 .126 .941 r
.7068 .50595 Mdot
1 .5 0 r
.63797 .67231 Mdot
.56088 .41266 Mdot
.628 .126 .941 r
.44789 .34598 Mdot
1 .5 0 r
.77733 .6122 Mdot
.42851 .27603 Mdot
.55174 .49893 Mdot
.48073 .30585 Mdot
.63662 .60204 Mdot
.628 .126 .941 r
.68825 .72518 Mdot
1 .5 0 r
.53177 .39884 Mdot
.51171 .35544 Mdot
.628 .126 .941 r
.76384 .40863 Mdot
.56444 .34865 Mdot
.59395 .6316 Mdot
.76562 .74811 Mdot
.73886 .73141 Mdot
1 .5 0 r
.6216 .50831 Mdot
.47776 .27854 Mdot
.52991 .36509 Mdot
.628 .126 .941 r
.62928 .40837 Mdot
.75551 .41164 Mdot
1 .5 0 r
.54968 .33167 Mdot
.56248 .37162 Mdot
.628 .126 .941 r
.5792 .61467 Mdot
.77058 .7545 Mdot
1 .5 0 r
.53552 .34485 Mdot
.628 .126 .941 r
.60686 .49136 Mdot
1 .5 0 r
.52056 .44135 Mdot
.628 .126 .941 r
.74049 .44135 Mdot
1 .5 0 r
.5922 .54118 Mdot
.57891 .53785 Mdot
.628 .126 .941 r
.69337 .4279 Mdot
.61425 .31455 Mdot
1 .5 0 r
.53355 .36783 Mdot
.59162 .51103 Mdot
.628 .126 .941 r
.66592 .43777 Mdot
1 .5 0 r
.65805 .52768 Mdot
.55924 .39101 Mdot
.628 .126 .941 r
.63858 .39088 Mdot
.75866 .38422 Mdot
.80492 .4142 Mdot
1 .5 0 r
.61052 .49414 Mdot
.628 .126 .941 r
.7941 .72395 Mdot
.55304 .25752 Mdot
1 .5 0 r
.5175 .34725 Mdot
.628 .126 .941 r
.64992 .41721 Mdot
.64204 .50715 Mdot
.7782 .77027 Mdot
.6643 .29049 Mdot
1 .5 0 r
.60021 .52018 Mdot
.628 .126 .941 r
.65467 .41349 Mdot
1 .5 0 r
.51494 .34006 Mdot
.628 .126 .941 r
.84287 .75325 Mdot
1 .5 0 r
.50834 .31 Mdot
.628 .126 .941 r
.59924 .46989 Mdot
1 .5 0 r
.46117 .29653 Mdot
.628 .126 .941 r
.73545 .7331 Mdot
.68355 .59974 Mdot
1 .5 0 r
.51888 .41971 Mdot
.628 .126 .941 r
.67499 .71633 Mdot
.46599 .35965 Mdot
1 .5 0 r
.63983 .32966 Mdot
.6684 .68628 Mdot
.81417 .7596 Mdot
.628 .126 .941 r
.55936 .33626 Mdot
1 .5 0 r
.57118 .44958 Mdot
.7869 .77955 Mdot
.54488 .39619 Mdot
.64979 .53285 Mdot
.628 .126 .941 r
.73431 .67278 Mdot
1 .5 0 r
.83922 .80945 Mdot
.628 .126 .941 r
.51198 .31272 Mdot
.65728 .42272 Mdot
1 .5 0 r
.4842 .36932 Mdot
.628 .126 .941 r
.597 .41599 Mdot
.79994 .70601 Mdot
.66804 .54255 Mdot
1 .5 0 r
.53533 .46248 Mdot
.89839 .75585 Mdot
.628 .126 .941 r
.46419 .26904 Mdot
1 .5 0 r
.62135 .49242 Mdot
.628 .126 .941 r
.7849 .7358 Mdot
1 .5 0 r
.61425 .49903 Mdot
.628 .126 .941 r
.56332 .29224 Mdot
1 .5 0 r
.65191 .57881 Mdot
.92242 .81223 Mdot
.628 .126 .941 r
.57387 .40201 Mdot
.57268 .46531 Mdot
.71903 .50199 Mdot
.70751 .34186 Mdot
1 .5 0 r
.62699 .34846 Mdot
.628 .126 .941 r
.51168 .4852 Mdot
1 .5 0 r
.80729 .76852 Mdot
.628 .126 .941 r
.65135 .42491 Mdot
.61025 .47822 Mdot
.63717 .43813 Mdot
1 .5 0 r
.6421 .56822 Mdot
.628 .126 .941 r
.85188 .83169 Mdot
.76396 .39463 Mdot
1 .5 0 r
.47105 .25431 Mdot
.628 .126 .941 r
.47598 .38443 Mdot
1 .5 0 r
.49008 .30429 Mdot
.54234 .39104 Mdot
.52291 .3209 Mdot
.49629 .31423 Mdot
.71273 .60784 Mdot
.60259 .33085 Mdot
.628 .126 .941 r
.79684 .78463 Mdot
.71826 .64443 Mdot
1 .5 0 r
.77792 .6778 Mdot
.91561 .82118 Mdot
.628 .126 .941 r
.49481 .30054 Mdot
.73396 .39732 Mdot
.57361 .32704 Mdot
1 .5 0 r
.68358 .59404 Mdot
.628 .126 .941 r
.85471 .78427 Mdot
1 .5 0 r
.52656 .32363 Mdot
.69621 .62402 Mdot
.628 .126 .941 r
.78893 .68409 Mdot
.61267 .35361 Mdot
.71112 .46035 Mdot
1 .5 0 r
.72098 .7207 Mdot
.78165 .68064 Mdot
.8941 .76409 Mdot
.628 .126 .941 r
.69761 .44694 Mdot
1 .5 0 r
.77319 .74057 Mdot
.628 .126 .941 r
.65708 .40669 Mdot
.80556 .79393 Mdot
1 .5 0 r
.51048 .303 Mdot
.53613 .38312 Mdot
.628 .126 .941 r
.64842 .45651 Mdot
1 .5 0 r
.62178 .44983 Mdot
.6346 .4899 Mdot
.628 .126 .941 r
.76682 .59674 Mdot
.89293 .63675 Mdot
1 .5 0 r
.85741 .79367 Mdot
.628 .126 .941 r
.70132 .44971 Mdot
.8299 .80359 Mdot
1 .5 0 r
.51492 .34606 Mdot
.52133 .3661 Mdot
.53416 .40617 Mdot
.61371 .40604 Mdot
.628 .126 .941 r
.70006 .44611 Mdot
.69345 .416 Mdot
1 .5 0 r
.72336 .65305 Mdot
.51393 .29563 Mdot
.66494 .49936 Mdot
.46734 .25549 Mdot
.55233 .34887 Mdot
.628 .126 .941 r
.77522 .65277 Mdot
.82655 .8131 Mdot
1 .5 0 r
.81353 .76295 Mdot
.628 .126 .941 r
.66982 .43874 Mdot
1 .5 0 r
.6094 .43199 Mdot
.628 .126 .941 r
.70232 .43521 Mdot
.59509 .37821 Mdot
.66817 .41497 Mdot
1 .5 0 r
.60053 .47177 Mdot
.57416 .41825 Mdot
.628 .126 .941 r
.70155 .39485 Mdot
1 .5 0 r
.67933 .55525 Mdot
.628 .126 .941 r
.68013 .47165 Mdot
1 .5 0 r
.74432 .67215 Mdot
.628 .126 .941 r
.71648 .7289 Mdot
.61357 .398 Mdot
.78097 .38463 Mdot
1 .5 0 r
.78246 .77229 Mdot
.628 .126 .941 r
.81554 .79903 Mdot
1 .5 0 r
.81554 .79903 Mdot
.628 .126 .941 r
.73437 .34446 Mdot
.75362 .40462 Mdot
.74375 .6419 Mdot
1 .5 0 r
.5875 .29761 Mdot
.628 .126 .941 r
.71374 .33765 Mdot
.83208 .46793 Mdot
1 .5 0 r
.75534 .67845 Mdot
.54602 .27387 Mdot
.628 .126 .941 r
.67198 .36078 Mdot
1 .5 0 r
.49841 .30723 Mdot
.52508 .31391 Mdot
.63573 .54457 Mdot
.628 .126 .941 r
.66369 .43085 Mdot
.57754 .34386 Mdot
.58229 .46415 Mdot
1 .5 0 r
.76655 .69483 Mdot
.51668 .31692 Mdot
.628 .126 .941 r
.77655 .4005 Mdot
1 .5 0 r
.64118 .51418 Mdot
.81786 .78829 Mdot
.6067 .54081 Mdot
.72577 .64446 Mdot
.88418 .78484 Mdot
.628 .126 .941 r
.62094 .40352 Mdot
.66739 .43362 Mdot
.77511 .3868 Mdot
.66187 .2729 Mdot
.71376 .39664 Mdot
.65703 .58381 Mdot
.72634 .35959 Mdot
1 .5 0 r
.841 .79441 Mdot
.67029 .52008 Mdot
.62938 .52665 Mdot
.628 .126 .941 r
.74801 .66714 Mdot
.74386 .45299 Mdot
1 .5 0 r
.79329 .76076 Mdot
.628 .126 .941 r
.52894 .45286 Mdot
1 .5 0 r
.64857 .51977 Mdot
.66093 .59672 Mdot
.52913 .33885 Mdot
.64939 .31194 Mdot
.628 .126 .941 r
.61428 .43241 Mdot
1 .5 0 r
.59401 .44579 Mdot
.628 .126 .941 r
.62743 .42565 Mdot
.58175 .31181 Mdot
1 .5 0 r
.57384 .40216 Mdot
.628 .126 .941 r
.76372 .72677 Mdot
1 .5 0 r
.54081 .31836 Mdot
.91664 .76348 Mdot
.83554 .81702 Mdot
.628 .126 .941 r
.47374 .22437 Mdot
.7883 .74653 Mdot
.8343 .81348 Mdot
1 .5 0 r
.64962 .57242 Mdot
.628 .126 .941 r
.76338 .58246 Mdot
.75497 .70966 Mdot
1 .5 0 r
.83411 .80338 Mdot
.628 .126 .941 r
.67248 .31789 Mdot
1 .5 0 r
.61639 .47851 Mdot
.52884 .51199 Mdot
.5049 .27423 Mdot
.628 .126 .941 r
.67704 .42823 Mdot
1 .5 0 r
.45078 .28756 Mdot
.616 .4583 Mdot
.72088 .63239 Mdot
.83991 .72608 Mdot
.83942 .7629 Mdot
.89186 .84995 Mdot
.628 .126 .941 r
.69626 .42134 Mdot
1 .5 0 r
.84715 .66241 Mdot
.54269 .35431 Mdot
.628 .126 .941 r
.8247 .81302 Mdot
1 .5 0 r
.52914 .34085 Mdot
.65382 .53841 Mdot
.80521 .74266 Mdot
.83836 .76944 Mdot
.628 .126 .941 r
.89081 .8565 Mdot
1 .5 0 r
.47501 .35418 Mdot
.628 .126 .941 r
.87727 .84306 Mdot
1 .5 0 r
.84393 .80617 Mdot
.628 .126 .941 r
.80515 .67552 Mdot
.73785 .69562 Mdot
1 .5 0 r
.50657 .42431 Mdot
.628 .126 .941 r
.82327 .79937 Mdot
.84306 .82282 Mdot
1 .5 0 r
.51429 .32377 Mdot
.628 .126 .941 r
.76073 .44099 Mdot
1 .5 0 r
.7246 .63523 Mdot
.628 .126 .941 r
.85722 .74239 Mdot
1 .5 0 r
.909 .85621 Mdot
.628 .126 .941 r
.57229 .44756 Mdot
.72769 .35713 Mdot
.51914 .38721 Mdot
1 .5 0 r
.49291 .34367 Mdot
.79629 .71544 Mdot
.65208 .44743 Mdot
.67039 .58141 Mdot
.5722 .38038 Mdot
.5915 .44067 Mdot
.628 .126 .941 r
.72662 .36363 Mdot
1 .5 0 r
.72296 .61144 Mdot
.67624 .57118 Mdot
.61022 .47063 Mdot
.628 .126 .941 r
.68496 .39693 Mdot
1 .5 0 r
.60972 .50748 Mdot
.64566 .30306 Mdot
.84063 .6915 Mdot
.628 .126 .941 r
.79688 .43011 Mdot
.80678 .69145 Mdot
1 .5 0 r
.55587 .34956 Mdot
.59994 .56401 Mdot
.746 .67458 Mdot
.628 .126 .941 r
.83196 .74155 Mdot
.76938 .38294 Mdot
.85059 .82862 Mdot
.6043 .66436 Mdot
1 .5 0 r
.54122 .3426 Mdot
.628 .126 .941 r
.76207 .37946 Mdot
.78386 .75479 Mdot
1 .5 0 r
.55439 .33583 Mdot
.628 .126 .941 r
.70989 .74468 Mdot
1 .5 0 r
.66444 .58371 Mdot
.628 .126 .941 r
.90215 .86523 Mdot
1 .5 0 r
.57956 .3859 Mdot
.628 .126 .941 r
.70684 .39931 Mdot
.75388 .3926 Mdot
.89602 .79815 Mdot
.88859 .85178 Mdot
1 .5 0 r
.54548 .37571 Mdot
.88129 .84833 Mdot
.47208 .2716 Mdot
.71609 .56318 Mdot
.628 .126 .941 r
.74829 .66375 Mdot
1 .5 0 r
.66933 .52289 Mdot
.63545 .52283 Mdot
.78704 .72734 Mdot
.88711 .77092 Mdot
.628 .126 .941 r
.83311 .79439 Mdot
.75415 .65353 Mdot
1 .5 0 r
.45572 .36513 Mdot
.628 .126 .941 r
.60385 .32825 Mdot
.696 .46236 Mdot
.91845 .88817 Mdot
.87169 .84789 Mdot
1 .5 0 r
.95839 .88812 Mdot
.687 .55941 Mdot
.87113 .81756 Mdot
.53499 .33461 Mdot
.70644 .56265 Mdot
.628 .126 .941 r
.6889 .34461 Mdot
.84351 .82752 Mdot
1 .5 0 r
.87076 .79734 Mdot
.628 .126 .941 r
.83192 .66649 Mdot
1 .5 0 r
.75789 .65638 Mdot
.628 .126 .941 r
.80349 .76034 Mdot
.69042 .60925 Mdot
.8619 .83733 Mdot
1 .5 0 r
.65751 .5354 Mdot
.628 .126 .941 r
.6246 .46154 Mdot
1 .5 0 r
.61846 .39439 Mdot
.628 .126 .941 r
.70372 .54534 Mdot
1 .5 0 r
.86066 .83378 Mdot
.628 .126 .941 r
.9474 .87403 Mdot
1 .5 0 r
.6954 .61567 Mdot
.628 .126 .941 r
.73189 .37406 Mdot
1 .5 0 r
.662 .57871 Mdot
.628 .126 .941 r
.71713 .42426 Mdot
.70325 .45781 Mdot
.87974 .8168 Mdot
1 .5 0 r
.5102 .30676 Mdot
.628 .126 .941 r
.59013 .30663 Mdot
.86462 .8468 Mdot
.6889 .4038 Mdot
1 .5 0 r
.54194 .31984 Mdot
.50752 .35669 Mdot
.5943 .39696 Mdot
.628 .126 .941 r
.72125 .4473 Mdot
1 .5 0 r
.83084 .7896 Mdot
.628 .126 .941 r
.60135 .323 Mdot
.58845 .28272 Mdot
.56068 .34985 Mdot
.66513 .55115 Mdot
1 .5 0 r
.60423 .53425 Mdot
.81651 .73564 Mdot
.86957 .78599 Mdot
.4731 .26902 Mdot
.628 .126 .941 r
.8684 .84971 Mdot
.85482 .83624 Mdot
.86821 .83959 Mdot
1 .5 0 r
.52527 .33602 Mdot
.628 .126 .941 r
.67805 .46693 Mdot
1 .5 0 r
.98112 .9134 Mdot
.628 .126 .941 r
.73986 .34266 Mdot
1 .5 0 r
.88272 .71193 Mdot
.96754 .89992 Mdot
.96754 .89992 Mdot
.628 .126 .941 r
.761 .74545 Mdot
.89394 .85287 Mdot
1 .5 0 r
.85457 .75882 Mdot
.628 .126 .941 r
.87323 .84606 Mdot
1 .5 0 r
.64186 .53713 Mdot
.628 .126 .941 r
.87218 .85263 Mdot
.87218 .85263 Mdot
.87218 .85263 Mdot
.88588 .80893 Mdot
.87199 .84251 Mdot
.85859 .83915 Mdot
.83875 .81564 Mdot
1 .5 0 r
.97135 .90285 Mdot
.628 .126 .941 r
.7315 .72146 Mdot
.89773 .85579 Mdot
.68764 .45947 Mdot
1 .5 0 r
.5614 .32507 Mdot
.5346 .31835 Mdot
.628 .126 .941 r
.67504 .37208 Mdot
.69439 .43253 Mdot
1 .5 0 r
.81151 .72136 Mdot
.628 .126 .941 r
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
1 .5 0 r
.87056 .82882 Mdot
.79097 .72466 Mdot
.628 .126 .941 r
.70077 .38532 Mdot
.7906 .7044 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
1 .5 0 r
.64747 .3248 Mdot
.55217 .41213 Mdot
.628 .126 .941 r
.66682 .38526 Mdot
.66682 .38526 Mdot
.68668 .40877 Mdot
.84878 .82857 Mdot
1 .5 0 r
.60489 .44223 Mdot
.628 .126 .941 r
.6719 .45902 Mdot
.82279 .73783 Mdot
.91511 .87219 Mdot
1 .5 0 r
.97517 .90578 Mdot
.58583 .33467 Mdot
.58533 .37162 Mdot
.89439 .86538 Mdot
.628 .126 .941 r
.8942 .85525 Mdot
.8808 .85189 Mdot
.8808 .85189 Mdot
.8808 .85189 Mdot
.59845 .29744 Mdot
1 .5 0 r
.51803 .27729 Mdot
.628 .126 .941 r
.60391 .39151 Mdot
.87974 .85846 Mdot
1 .5 0 r
.59557 .46194 Mdot
.628 .126 .941 r
.7331 .73746 Mdot
1 .5 0 r
.83388 .74418 Mdot
.91332 .83825 Mdot
.91332 .83825 Mdot
.628 .126 .941 r
.78386 .41477 Mdot
.77721 .38447 Mdot
1 .5 0 r
.88545 .83811 Mdot
.628 .126 .941 r
.852 .80109 Mdot
1 .5 0 r
.89818 .8683 Mdot
.98507 .90862 Mdot
.56083 .4213 Mdot
.628 .126 .941 r
.81258 .70695 Mdot
1 .5 0 r
.81308 .66998 Mdot
.628 .126 .941 r
.88459 .85481 Mdot
1 .5 0 r
.66292 .30698 Mdot
.628 .126 .941 r
.85969 .63284 Mdot
.88353 .86138 Mdot
.67426 .39079 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
1 .5 0 r
.78433 .68651 Mdot
.78433 .68651 Mdot
.628 .126 .941 r
.62719 .34025 Mdot
1 .5 0 r
.5068 .26287 Mdot
.628 .126 .941 r
.62004 .3469 Mdot
1 .5 0 r
.75067 .63934 Mdot
.90911 .86455 Mdot
.59203 .40398 Mdot
.628 .126 .941 r
.85528 .84097 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
1 .5 0 r
.90179 .86109 Mdot
.51196 .2794 Mdot
.62274 .54834 Mdot
.7961 .66601 Mdot
.628 .126 .941 r
.67799 .39357 Mdot
.69786 .4171 Mdot
.87372 .85081 Mdot
.87372 .85081 Mdot
.645 .31953 Mdot
.70462 .39014 Mdot
.86012 .83731 Mdot
1 .5 0 r
.98662 .91459 Mdot
.51047 .2656 Mdot
.628 .126 .941 r
.74994 .47407 Mdot
1 .5 0 r
.73504 .58167 Mdot
.628 .126 .941 r
.80658 .7666 Mdot
.90179 .66903 Mdot
.89217 .86065 Mdot
1 .5 0 r
.83384 .66892 Mdot
.89161 .83024 Mdot
.628 .126 .941 r
.87751 .85373 Mdot
.87751 .85373 Mdot
.87751 .85373 Mdot
.87751 .85373 Mdot
.84701 .59471 Mdot
.89074 .84695 Mdot
1 .5 0 r
.66642 .48366 Mdot
.99045 .91753 Mdot
.628 .126 .941 r
.64783 .33897 Mdot
1 .5 0 r
.57985 .33883 Mdot
.628 .126 .941 r
.69367 .38592 Mdot
1 .5 0 r
.89646 .82657 Mdot
.89596 .86357 Mdot
.628 .126 .941 r
.84259 .80297 Mdot
.49197 .31515 Mdot
1 .5 0 r
.68483 .49344 Mdot
.628 .126 .941 r
.74398 .60109 Mdot
.78008 .39582 Mdot
1 .5 0 r
.89491 .87015 Mdot
.628 .126 .941 r
.89472 .86001 Mdot
.89472 .86001 Mdot
.8813 .85665 Mdot
.89472 .86001 Mdot
1 .5 0 r
.5381 .31494 Mdot
.628 .126 .941 r
.73198 .41924 Mdot
1 .5 0 r
.91423 .86328 Mdot
.628 .126 .941 r
.71817 .39556 Mdot
.65602 .50995 Mdot
.76689 .77912 Mdot
1 .5 0 r
.92747 .8565 Mdot
.628 .126 .941 r
.70406 .41904 Mdot
.86663 .84972 Mdot
.70635 .72518 Mdot
1 .5 0 r
.89976 .8665 Mdot
.628 .126 .941 r
.69174 .28432 Mdot
1 .5 0 r
.56992 .32806 Mdot
.628 .126 .941 r
.94762 .76545 Mdot
.88559 .82255 Mdot
.89852 .86294 Mdot
.8652 .83601 Mdot
.87167 .85621 Mdot
.88509 .85957 Mdot
.60007 .44209 Mdot
1 .5 0 r
.91767 .84591 Mdot
.90356 .86942 Mdot
.54009 .29372 Mdot
.5396 .33075 Mdot
.628 .126 .941 r
.65877 .46197 Mdot
1 .5 0 r
.903 .83898 Mdot
.628 .126 .941 r
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.90232 .86586 Mdot
1 .5 0 r
.90232 .86586 Mdot
.90213 .85571 Mdot
.83628 .71764 Mdot
.83578 .75467 Mdot
.9885 .923 Mdot
.7366 .58965 Mdot
.80226 .71758 Mdot
.628 .126 .941 r
.93509 .86235 Mdot
1 .5 0 r
.98832 .91285 Mdot
.57771 .35391 Mdot
.628 .126 .941 r
.87421 .85557 Mdot
.88746 .84878 Mdot
.88746 .84878 Mdot
.88746 .84878 Mdot
.90736 .87235 Mdot
.92079 .87572 Mdot
1 .5 0 r
.52388 .2729 Mdot
.628 .126 .941 r
.79305 .80491 Mdot
.80748 .7342 Mdot
.69713 .37041 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.87278 .84185 Mdot
1 .5 0 r
.89268 .86542 Mdot
.89318 .82838 Mdot
.628 .126 .941 r
.87906 .8519 Mdot
.95918 .90915 Mdot
.56787 .41069 Mdot
.78781 .59591 Mdot
1 .5 0 r
.853 .76093 Mdot
.628 .126 .941 r
.7294 .40389 Mdot
.72056 .51154 Mdot
1 .5 0 r
.90469 .85508 Mdot
.628 .126 .941 r
.69498 .38349 Mdot
.65417 .41043 Mdot
1 .5 0 r
.87216 .74388 Mdot
.9911 .92239 Mdot
.70524 .59899 Mdot
.92423 .85834 Mdot
.628 .126 .941 r
.61396 .34294 Mdot
.76726 .4743 Mdot
.89648 .86835 Mdot
.89648 .86835 Mdot
1 .5 0 r
.89648 .86835 Mdot
.61905 .41691 Mdot
.628 .126 .941 r
.88286 .85483 Mdot
.88286 .85483 Mdot
1 .5 0 r
.87122 .69308 Mdot
.53811 .31895 Mdot
.88211 .8142 Mdot
.628 .126 .941 r
.86817 .84789 Mdot
1 .5 0 r
.67034 .49071 Mdot
.53124 .27838 Mdot
.628 .126 .941 r
.78944 .61189 Mdot
.88155 .78373 Mdot
1 .5 0 r
.90097 .84438 Mdot
.63092 .33889 Mdot
.628 .126 .941 r
.88037 .8477 Mdot
1 .5 0 r
.90029 .87128 Mdot
.90029 .87128 Mdot
.55654 .32872 Mdot
.628 .126 .941 r
.88666 .85776 Mdot
.69427 .59486 Mdot
.86655 .82401 Mdot
1 .5 0 r
.50934 .27803 Mdot
.66102 .5105 Mdot
.628 .126 .941 r
.8856 .86435 Mdot
1 .5 0 r
.58214 .33182 Mdot
.9123 .86093 Mdot
.628 .126 .941 r
.73613 .36875 Mdot
1 .5 0 r
.97169 .91139 Mdot
.628 .126 .941 r
.75985 .58777 Mdot
.81214 .71248 Mdot
1 .5 0 r
.57488 .27087 Mdot
.628 .126 .941 r
.73575 .3484 Mdot
.71383 .47311 Mdot
1 .5 0 r
.90409 .87422 Mdot
.57368 .33485 Mdot
.628 .126 .941 r
.73456 .41238 Mdot
.70667 .47979 Mdot
.89843 .76967 Mdot
.89046 .86068 Mdot
.89046 .86068 Mdot
.67391 .35831 Mdot
1 .5 0 r
.56512 .39532 Mdot
.628 .126 .941 r
.8894 .86728 Mdot
.9696 .92459 Mdot
.53155 .35818 Mdot
1 .5 0 r
.6257 .38177 Mdot
.57887 .35143 Mdot
.628 .126 .941 r
.99631 .92117 Mdot
.66535 .41879 Mdot
1 .5 0 r
.63925 .3277 Mdot
.628 .126 .941 r
.69156 .45244 Mdot
1 .5 0 r
.61215 .31077 Mdot
.59751 .3714 Mdot
.94327 .75577 Mdot
.628 .126 .941 r
.88797 .85355 Mdot
.72486 .41179 Mdot
1 .5 0 r
.74379 .50957 Mdot
.89426 .86361 Mdot
.53035 .29708 Mdot
.628 .126 .941 r
.56882 .39811 Mdot
1 .5 0 r
.54919 .32722 Mdot
.71562 .49921 Mdot
.628 .126 .941 r
.86611 .8533 Mdot
1 .5 0 r
.9269 .84993 Mdot
.628 .126 .941 r
.8734 .78918 Mdot
1 .5 0 r
.52886 .28324 Mdot
.91239 .85315 Mdot
.91239 .85315 Mdot
.92585 .85653 Mdot
.628 .126 .941 r
.91171 .88009 Mdot
.71466 .44831 Mdot
.87265 .74849 Mdot
.89806 .86655 Mdot
1 .5 0 r
.89806 .86655 Mdot
.97831 .92388 Mdot
.628 .126 .941 r
.68138 .36385 Mdot
1 .5 0 r
.81196 .69442 Mdot
.93109 .87319 Mdot
.628 .126 .941 r
.76143 .41101 Mdot
.73402 .44137 Mdot
1 .5 0 r
.87738 .80226 Mdot
.94368 .89334 Mdot
.628 .126 .941 r
.59705 .5357 Mdot
1 .5 0 r
.67232 .46148 Mdot
.6783 .51883 Mdot
.50513 .31635 Mdot
.628 .126 .941 r
.77413 .37364 Mdot
.78441 .5895 Mdot
1 .5 0 r
.94294 .85266 Mdot
.628 .126 .941 r
.89558 .85941 Mdot
.91552 .88302 Mdot
.92898 .8864 Mdot
1 .5 0 r
.96288 .87628 Mdot
.72389 .54558 Mdot
.628 .126 .941 r
.90187 .86948 Mdot
1 .5 0 r
.90187 .86948 Mdot
.5507 .34307 Mdot
.628 .126 .941 r
.69079 .47129 Mdot
1 .5 0 r
.64343 .47804 Mdot
.58999 .35974 Mdot
.628 .126 .941 r
.58949 .39686 Mdot
.88218 .73093 Mdot
.91409 .86928 Mdot
.8737 .85916 Mdot
1 .5 0 r
.91409 .86928 Mdot
.628 .126 .941 r
.88717 .86254 Mdot
1 .5 0 r
.93454 .85579 Mdot
.58281 .36643 Mdot
.881 .795 Mdot
.96826 .83549 Mdot
.628 .126 .941 r
.61682 .2988 Mdot
1 .5 0 r
.79435 .6599 Mdot
.628 .126 .941 r
.79915 .78134 Mdot
.75826 .80834 Mdot
1 .5 0 r
.89939 .86234 Mdot
.628 .126 .941 r
.9328 .88934 Mdot
.69672 .33578 Mdot
1 .5 0 r
.57504 .34253 Mdot
.628 .126 .941 r
.90568 .87242 Mdot
.90568 .87242 Mdot
.64896 .32215 Mdot
.64926 .27482 Mdot
1 .5 0 r
.5529 .332 Mdot
.81777 .73372 Mdot
.628 .126 .941 r
.84552 .65602 Mdot
1 .5 0 r
.79744 .68972 Mdot
.628 .126 .941 r
.87626 .85852 Mdot
1 .5 0 r
.89072 .78763 Mdot
.628 .126 .941 r
.9032 .86527 Mdot
1 .5 0 r
.61217 .37231 Mdot
.61716 .50398 Mdot
.91648 .85847 Mdot
.628 .126 .941 r
.68631 .36212 Mdot
1 .5 0 r
.49803 .26751 Mdot
.628 .126 .941 r
.94255 .88201 Mdot
.75976 .37887 Mdot
1 .5 0 r
.54403 .31464 Mdot
.56997 .39568 Mdot
.628 .126 .941 r
.72514 .41594 Mdot
.71117 .44971 Mdot
1 .5 0 r
.93519 .87854 Mdot
.94218 .86165 Mdot
.58325 .38886 Mdot
.628 .126 .941 r
.90807 .8616 Mdot
1 .5 0 r
.90807 .8616 Mdot
.628 .126 .941 r
.63624 .41912 Mdot
1 .5 0 r
.65121 .31106 Mdot
.65121 .31106 Mdot
.628 .126 .941 r
.77197 .3786 Mdot
1 .5 0 r
.99452 .91891 Mdot
.628 .126 .941 r
.70222 .48992 Mdot
1 .5 0 r
.51349 .37489 Mdot
.56769 .34105 Mdot
.7264 .60451 Mdot
.628 .126 .941 r
.83152 .80712 Mdot
1 .5 0 r
.66213 .30713 Mdot
.628 .126 .941 r
.63368 .41185 Mdot
.98557 .89151 Mdot
.63448 .32733 Mdot
1 .5 0 r
.51299 .28673 Mdot
.628 .126 .941 r
.71465 .37456 Mdot
1 .5 0 r
.91713 .88123 Mdot
.628 .126 .941 r
.53805 .38456 Mdot
.58497 .41497 Mdot
1 .5 0 r
.878 .74943 Mdot
.61104 .43849 Mdot
.61104 .43849 Mdot
.628 .126 .941 r
.82771 .41822 Mdot
.90259 .88447 Mdot
1 .5 0 r
.60485 .37085 Mdot
.628 .126 .941 r
.75313 .40802 Mdot
1 .5 0 r
.74963 .66818 Mdot
.628 .126 .941 r
.94934 .90469 Mdot
1 .5 0 r
.92936 .88104 Mdot
.59766 .37754 Mdot
.5705 .36058 Mdot
.94878 .87414 Mdot
.628 .126 .941 r
.9421 .84367 Mdot
1 .5 0 r
.9421 .84367 Mdot
.92163 .85719 Mdot
.9481 .90112 Mdot
.628 .126 .941 r
.86852 .75914 Mdot
.92794 .86728 Mdot
1 .5 0 r
.52257 .27913 Mdot
.628 .126 .941 r
.981 .8976 Mdot
1 .5 0 r
.97401 .9145 Mdot
.628 .126 .941 r
.64114 .41744 Mdot
1 .5 0 r
.53456 .26865 Mdot
.628 .126 .941 r
.66822 .3666 Mdot
.98589 .89393 Mdot
1 .5 0 r
.92545 .86013 Mdot
.628 .126 .941 r
.62707 .38344 Mdot
1 .5 0 r
.61258 .45443 Mdot
.92477 .88712 Mdot
.628 .126 .941 r
.69381 .42732 Mdot
1 .5 0 r
.97785 .91745 Mdot
.9382 .82274 Mdot
.628 .126 .941 r
.7207 .36627 Mdot
1 .5 0 r
.63178 .43727 Mdot
.628 .126 .941 r
.76816 .35951 Mdot
1 .5 0 r
.63128 .47446 Mdot
.54515 .31211 Mdot
.6056 .34592 Mdot
.63099 .39644 Mdot
.94277 .86645 Mdot
.628 .126 .941 r
.87513 .83935 Mdot
.93559 .87316 Mdot
1 .5 0 r
.93622 .77838 Mdot
.62301 .36229 Mdot
.628 .126 .941 r
.96083 .91355 Mdot
1 .5 0 r
.54885 .31487 Mdot
.60932 .34869 Mdot
.70778 .57867 Mdot
.628 .126 .941 r
.79635 .48723 Mdot
.65622 .31128 Mdot
1 .5 0 r
.93311 .86601 Mdot
.628 .126 .941 r
.58704 .39578 Mdot
1 .5 0 r
.93942 .87611 Mdot
.58685 .38556 Mdot
.53366 .2874 Mdot
.58615 .41256 Mdot
.96554 .89969 Mdot
.628 .126 .941 r
.89769 .86238 Mdot
1 .5 0 r
.95817 .89621 Mdot
.57936 .31418 Mdot
.61885 .39877 Mdot
.628 .126 .941 r
.73834 .57808 Mdot
1 .5 0 r
.65865 .43592 Mdot
.628 .126 .941 r
.78664 .48667 Mdot
1 .5 0 r
.77764 .65246 Mdot
.95794 .8182 Mdot
.90325 .83168 Mdot
.628 .126 .941 r
.56307 .41881 Mdot
1 .5 0 r
.55657 .3985 Mdot
.628 .126 .941 r
.75249 .36108 Mdot
.73849 .39492 Mdot
1 .5 0 r
.74949 .58444 Mdot
.628 .126 .941 r
.71779 .39824 Mdot
.63678 .37794 Mdot
1 .5 0 r
.54957 .28988 Mdot
.628 .126 .941 r
.65109 .29664 Mdot
1 .5 0 r
.60308 .34064 Mdot
.628 .126 .941 r
.83512 .71631 Mdot
.78661 .79753 Mdot
.65039 .32365 Mdot
.56887 .34057 Mdot
1 .5 0 r
.90126 .78728 Mdot
.628 .126 .941 r
.76053 .64845 Mdot
1 .5 0 r
.84787 .67886 Mdot
.98691 .91918 Mdot
.628 .126 .941 r
.81417 .64157 Mdot
.65592 .29284 Mdot
.75646 .37409 Mdot
.98655 .89878 Mdot
.98655 .89878 Mdot
.91933 .83441 Mdot
1 .5 0 r
.57949 .38411 Mdot
.628 .126 .941 r
.73606 .32994 Mdot
1 .5 0 r
.60681 .34342 Mdot
.68034 .4179 Mdot
.84642 .66504 Mdot
.628 .126 .941 r
.72117 .38059 Mdot
1 .5 0 r
.93879 .82749 Mdot
.628 .126 .941 r
.63973 .33983 Mdot
.8902 .84088 Mdot
.99058 .91194 Mdot
1 .5 0 r
.61663 .47169 Mdot
.5774 .33956 Mdot
.62424 .35981 Mdot
.628 .126 .941 r
.64976 .47833 Mdot
1 .5 0 r
.64426 .38351 Mdot
.628 .126 .941 r
.73864 .39699 Mdot
.74965 .58664 Mdot
1 .5 0 r
.74915 .62389 Mdot
.628 .126 .941 r
.89527 .8474 Mdot
.98934 .90836 Mdot
.98934 .90836 Mdot
.6849 .33597 Mdot
.74526 .35961 Mdot
1 .5 0 r
.96145 .91843 Mdot
.628 .126 .941 r
.71104 .35954 Mdot
1 .5 0 r
.64948 .40018 Mdot
.55419 .4035 Mdot
.53547 .25779 Mdot
.628 .126 .941 r
.72967 .43731 Mdot
1 .5 0 r
.68763 .53892 Mdot
.64839 .40676 Mdot
.628 .126 .941 r
.7433 .38298 Mdot
1 .5 0 r
.62117 .38976 Mdot
.628 .126 .941 r
.91298 .87416 Mdot
.933 .89787 Mdot
.64249 .29145 Mdot
1 .5 0 r
.8128 .68768 Mdot
.93276 .81975 Mdot
.93226 .85702 Mdot
.61898 .40291 Mdot
.628 .126 .941 r
.72762 .39275 Mdot
1 .5 0 r
.92488 .85353 Mdot
.9454 .83998 Mdot
.53868 .29781 Mdot
.628 .126 .941 r
.6246 .44005 Mdot
1 .5 0 r
.6246 .44005 Mdot
.628 .126 .941 r
.61839 .37222 Mdot
.78963 .75173 Mdot
.90329 .87372 Mdot
.74738 .33827 Mdot
.91762 .79234 Mdot
1 .5 0 r
.66607 .3077 Mdot
.58445 .32465 Mdot
.628 .126 .941 r
.83281 .5178 Mdot
1 .5 0 r
.53698 .27367 Mdot
.94961 .86335 Mdot
.628 .126 .941 r
.7386 .38883 Mdot
1 .5 0 r
.92238 .84636 Mdot
.60319 .34471 Mdot
.60319 .34471 Mdot
.628 .126 .941 r
.65157 .25313 Mdot
.66459 .2938 Mdot
1 .5 0 r
.57595 .32769 Mdot
.628 .126 .941 r
.65658 .38531 Mdot
.98844 .90722 Mdot
1 .5 0 r
.98844 .90722 Mdot
.628 .126 .941 r
.76287 .50381 Mdot
1 .5 0 r
.74834 .57499 Mdot
.76788 .63601 Mdot
.96822 .87328 Mdot
.628 .126 .941 r
.70408 .31054 Mdot
1 .5 0 r
.92145 .79526 Mdot
.628 .126 .941 r
.70839 .46979 Mdot
.90674 .85623 Mdot
.75609 .40525 Mdot
.63336 .44932 Mdot
1 .5 0 r
.71301 .58154 Mdot
.628 .126 .941 r
.63517 .28992 Mdot
.95928 .91371 Mdot
.73497 .38811 Mdot
1 .5 0 r
.91883 .84581 Mdot
.80542 .67623 Mdot
.65392 .30999 Mdot
.61284 .33711 Mdot
.628 .126 .941 r
.92447 .88301 Mdot
.95854 .87284 Mdot
1 .5 0 r
.89172 .77106 Mdot
.89855 .74388 Mdot
.628 .126 .941 r
.98473 .89647 Mdot
1 .5 0 r
.91057 .85917 Mdot
.628 .126 .941 r
.72048 .33352 Mdot
1 .5 0 r
.85057 .73021 Mdot
.628 .126 .941 r
.77321 .40121 Mdot
1 .5 0 r
.77622 .68268 Mdot
.92354 .8319 Mdot
.92267 .84875 Mdot
.65787 .323 Mdot
.59653 .31615 Mdot
.88972 .72655 Mdot
.628 .126 .941 r
.94835 .9097 Mdot
.92812 .87574 Mdot
.98877 .90966 Mdot
1 .5 0 r
.71592 .47544 Mdot
.628 .126 .941 r
.89435 .83838 Mdot
1 .5 0 r
.9144 .86212 Mdot
.628 .126 .941 r
.66861 .43467 Mdot
1 .5 0 r
.65569 .33616 Mdot
.628 .126 .941 r
.98753 .90607 Mdot
.98101 .88572 Mdot
.98101 .88572 Mdot
.74322 .36663 Mdot
.72899 .39031 Mdot
.78294 .39363 Mdot
1 .5 0 r
.69972 .52256 Mdot
.628 .126 .941 r
.89505 .61749 Mdot
.9522 .91267 Mdot
.73423 .40701 Mdot
1 .5 0 r
.73173 .59363 Mdot
.92626 .77346 Mdot
.628 .126 .941 r
.91774 .90239 Mdot
.95133 .92954 Mdot
.74808 .36283 Mdot
.69443 .31193 Mdot
.71379 .36276 Mdot
.68621 .3933 Mdot
1 .5 0 r
.9655 .83783 Mdot
.628 .126 .941 r
.9314 .84801 Mdot
.68 .32537 Mdot
.79433 .4102 Mdot
.77778 .63078 Mdot
1 .5 0 r
.58453 .32869 Mdot
.74399 .59339 Mdot
.59787 .32184 Mdot
.628 .126 .941 r
.61793 .34559 Mdot
.73227 .43044 Mdot
.67942 .29462 Mdot
1 .5 0 r
.67089 .42358 Mdot
.628 .126 .941 r
.98381 .89532 Mdot
.98381 .89532 Mdot
1 .5 0 r
.99033 .91568 Mdot
.628 .126 .941 r
.7725 .42012 Mdot
.95605 .91563 Mdot
1 .5 0 r
.91555 .84766 Mdot
.628 .126 .941 r
.71174 .3181 Mdot
.98258 .89173 Mdot
.9891 .9121 Mdot
.9891 .9121 Mdot
.68998 .3961 Mdot
.77173 .37913 Mdot
1 .5 0 r
.97537 .89847 Mdot
.64143 .41973 Mdot
.628 .126 .941 r
.80094 .68451 Mdot
1 .5 0 r
.70845 .4638 Mdot
.628 .126 .941 r
.98786 .90851 Mdot
1 .5 0 r
.74731 .50768 Mdot
.91939 .8506 Mdot
.73187 .59584 Mdot
.83272 .67733 Mdot
.628 .126 .941 r
.80142 .45317 Mdot
1 .5 0 r
.91112 .86399 Mdot
.59832 .34437 Mdot
.628 .126 .941 r
.7604 .42248 Mdot
1 .5 0 r
.95773 .86384 Mdot
.67802 .4087 Mdot
.95754 .8536 Mdot
.5903 .31007 Mdot
.628 .126 .941 r
.73133 .43914 Mdot
1 .5 0 r
.92304 .84331 Mdot
.628 .126 .941 r
.65566 .45599 Mdot
.9829 .89416 Mdot
1 .5 0 r
.98943 .91454 Mdot
.60206 .34716 Mdot
.628 .126 .941 r
.72453 .34037 Mdot
.71098 .33697 Mdot
1 .5 0 r
.62916 .35395 Mdot
.628 .126 .941 r
.68839 .50002 Mdot
.91427 .89407 Mdot
1 .5 0 r
.92882 .82273 Mdot
.628 .126 .941 r
.98184 .90081 Mdot
.69603 .38779 Mdot
.71611 .41157 Mdot
.8406 .76148 Mdot
.67676 .27901 Mdot
1 .5 0 r
.81381 .70707 Mdot
.628 .126 .941 r
.72978 .35708 Mdot
.73581 .41484 Mdot
.72306 .32644 Mdot
.70831 .38753 Mdot
.78311 .38753 Mdot
1 .5 0 r
.70078 .44189 Mdot
.70078 .44189 Mdot
.86043 .70691 Mdot
.628 .126 .941 r
.74878 .38746 Mdot
1 .5 0 r
.64717 .33303 Mdot
.61955 .36361 Mdot
.94641 .83931 Mdot
.82603 .63872 Mdot
.628 .126 .941 r
.98571 .90378 Mdot
.6742 .27165 Mdot
.6742 .27165 Mdot
.68053 .28178 Mdot
.65291 .31236 Mdot
1 .5 0 r
.93161 .83232 Mdot
.628 .126 .941 r
.72553 .45163 Mdot
1 .5 0 r
.59778 .31562 Mdot
.628 .126 .941 r
.66608 .29523 Mdot
.74643 .39039 Mdot
.85339 .52974 Mdot
.87348 .55353 Mdot
.75257 .39026 Mdot
1 .5 0 r
.95698 .8729 Mdot
.628 .126 .941 r
.72978 .54315 Mdot
.73159 .38333 Mdot
.68399 .33221 Mdot
.78495 .41379 Mdot
.69504 .52257 Mdot
1 .5 0 r
.93665 .77072 Mdot
.628 .126 .941 r
.95523 .9067 Mdot
.96829 .94749 Mdot
1 .5 0 r
.96929 .8727 Mdot
.628 .126 .941 r
.75814 .35933 Mdot
1 .5 0 r
.90161 .79782 Mdot
.95586 .81141 Mdot
.628 .126 .941 r
.9413 .8828 Mdot
1 .5 0 r
.98852 .9134 Mdot
.628 .126 .941 r
.72792 .50873 Mdot
.66894 .31487 Mdot
.92096 .78061 Mdot
1 .5 0 r
.59319 .33173 Mdot
.7193 .56974 Mdot
.55209 .30099 Mdot
.628 .126 .941 r
.73248 .55262 Mdot
1 .5 0 r
.67852 .49135 Mdot
.9594 .86201 Mdot
.9795 .88582 Mdot
.628 .126 .941 r
.63913 .35866 Mdot
1 .5 0 r
.61802 .40967 Mdot
.64566 .37906 Mdot
.628 .126 .941 r
.78837 .39607 Mdot
1 .5 0 r
.92505 .86196 Mdot
.628 .126 .941 r
.70777 .29058 Mdot
1 .5 0 r
.59169 .31778 Mdot
.628 .126 .941 r
.6937 .32458 Mdot
.77461 .3824 Mdot
.89069 .86191 Mdot
.68698 .29391 Mdot
.74024 .38233 Mdot
1 .5 0 r
.87191 .71562 Mdot
.56366 .32785 Mdot
.628 .126 .941 r
.94409 .89242 Mdot
1 .5 0 r
.56929 .36513 Mdot
.628 .126 .941 r
.73966 .35152 Mdot
1 .5 0 r
.61703 .35832 Mdot
.628 .126 .941 r
.93718 .85151 Mdot
.6103 .32764 Mdot
.7445 .4739 Mdot
1 .5 0 r
.96395 .83781 Mdot
.67676 .39894 Mdot
.628 .126 .941 r
.65796 .2526 Mdot
1 .5 0 r
.60217 .35125 Mdot
.64288 .36146 Mdot
.628 .126 .941 r
.74473 .35799 Mdot
.702 .49746 Mdot
1 .5 0 r
.87524 .75596 Mdot
.628 .126 .941 r
.79109 .40548 Mdot
1 .5 0 r
.77984 .71162 Mdot
.628 .126 .941 r
.81906 .8341 Mdot
.71027 .28967 Mdot
1 .5 0 r
.62078 .36112 Mdot
.62078 .36112 Mdot
.628 .126 .941 r
.76306 .41556 Mdot
.89981 .88168 Mdot
1 .5 0 r
.61405 .33043 Mdot
.628 .126 .941 r
.74326 .34404 Mdot
.68796 .40528 Mdot
.66212 .27592 Mdot
.89943 .86117 Mdot
.74941 .3439 Mdot
.59183 .38807 Mdot
1 .5 0 r
.87995 .74197 Mdot
.5856 .31995 Mdot
.628 .126 .941 r
.7621 .36418 Mdot
.72841 .33696 Mdot
.7621 .36418 Mdot
.74852 .36078 Mdot
1 .5 0 r
.75908 .58878 Mdot
.628 .126 .941 r
.91898 .85422 Mdot
.66737 .29265 Mdot
.8851 .81673 Mdot
.66063 .26195 Mdot
.75328 .41497 Mdot
.75378 .37753 Mdot
1 .5 0 r
.65722 .46602 Mdot
.95897 .82339 Mdot
.628 .126 .941 r
.738 .51361 Mdot
.69908 .34336 Mdot
.69939 .29564 Mdot
.67927 .27181 Mdot
.7532 .34669 Mdot
.65694 .38747 Mdot
.72515 .35677 Mdot
.68452 .28855 Mdot
.92177 .86383 Mdot
.75708 .41778 Mdot
1 .5 0 r
.96887 .88421 Mdot
.628 .126 .941 r
.75084 .34962 Mdot
.71694 .3121 Mdot
.77078 .36318 Mdot
.82612 .80921 Mdot
.92706 .88066 Mdot
.92033 .84996 Mdot
1 .5 0 r
.94096 .83634 Mdot
.628 .126 .941 r
.92637 .90785 Mdot
.73598 .34254 Mdot
.72189 .37659 Mdot
.74957 .34595 Mdot
1 .5 0 r
.63999 .3356 Mdot
.628 .126 .941 r
.6883 .29132 Mdot
.68578 .47862 Mdot
1 .5 0 r
.94625 .85317 Mdot
.628 .126 .941 r
.74125 .3593 Mdot
.76138 .38314 Mdot
1 .5 0 r
.62531 .3388 Mdot
.628 .126 .941 r
.86385 .84967 Mdot
.72073 .31489 Mdot
1 .5 0 r
.74589 .47156 Mdot
.85259 .64867 Mdot
.628 .126 .941 r
.76029 .38975 Mdot
.95104 .90747 Mdot
1 .5 0 r
.95859 .85297 Mdot
.628 .126 .941 r
.67303 .26366 Mdot
1 .5 0 r
.64484 .33178 Mdot
.628 .126 .941 r
.92418 .85292 Mdot
.92418 .85292 Mdot
1 .5 0 r
.94431 .87676 Mdot
.94481 .8393 Mdot
.628 .126 .941 r
.7735 .37259 Mdot
.73223 .39984 Mdot
1 .5 0 r
.59663 .31802 Mdot
.66942 .45762 Mdot
.628 .126 .941 r
.65815 .25656 Mdot
1 .5 0 r
.62996 .32469 Mdot
.628 .126 .941 r
.77896 .39964 Mdot
.77877 .38935 Mdot
.75863 .3655 Mdot
.77877 .38935 Mdot
.91569 .85608 Mdot
1 .5 0 r
.58174 .31093 Mdot
.60893 .31774 Mdot
.628 .126 .941 r
.76448 .41313 Mdot
1 .5 0 r
.86315 .68228 Mdot
.628 .126 .941 r
.68928 .40285 Mdot
.71546 .48462 Mdot
.84182 .72311 Mdot
.69059 .28012 Mdot
.73067 .31753 Mdot
.75081 .34138 Mdot
.75585 .47427 Mdot
.73048 .30724 Mdot
.87045 .54917 Mdot
.68245 .30377 Mdot
.84338 .4843 Mdot
.68156 .32067 Mdot
.78277 .40245 Mdot
.78277 .40245 Mdot
.74884 .3649 Mdot
.78258 .39216 Mdot
.74078 .45691 Mdot
.70131 .32394 Mdot
.68097 .28979 Mdot
.78219 .37158 Mdot
.70111 .31364 Mdot
1 .5 0 r
.75903 .57266 Mdot
.628 .126 .941 r
.91917 .83849 Mdot
1 .5 0 r
.63897 .34425 Mdot
.65237 .33736 Mdot
.84476 .74296 Mdot
.59023 .36797 Mdot
.628 .126 .941 r
.75341 .40887 Mdot
.74737 .35093 Mdot
.90551 .76676 Mdot
1 .5 0 r
.9181 .84516 Mdot
.628 .126 .941 r
.74717 .34063 Mdot
1 .5 0 r
.75171 .51106 Mdot
.90375 .80064 Mdot
.628 .126 .941 r
.71819 .36763 Mdot
.85905 .52439 Mdot
.77151 .38789 Mdot
.969 .92658 Mdot
1 .5 0 r
.57433 .3094 Mdot
.628 .126 .941 r
.76477 .35714 Mdot
.76477 .35714 Mdot
.70381 .32304 Mdot
.75117 .35373 Mdot
.75117 .35373 Mdot
1 .5 0 r
.62099 .3673 Mdot
.628 .126 .941 r
.85527 .70827 Mdot
.77004 .37392 Mdot
.77004 .37392 Mdot
.77004 .37392 Mdot
.74264 .3568 Mdot
.72248 .33293 Mdot
.71442 .425 Mdot
.68853 .29535 Mdot
.68814 .27474 Mdot
.68763 .31226 Mdot
.76171 .38729 Mdot
.76222 .34977 Mdot
.77532 .3907 Mdot
1 .5 0 r
.61789 .39746 Mdot
.628 .126 .941 r
.77513 .3804 Mdot
.75497 .35653 Mdot
.94547 .91247 Mdot
1 .5 0 r
.61164 .32917 Mdot
.628 .126 .941 r
.75477 .34623 Mdot
.68704 .28135 Mdot
.72698 .3085 Mdot
.7804 .39719 Mdot
.77385 .37672 Mdot
.73989 .33913 Mdot
.83276 .49251 Mdot
1 .5 0 r
.64352 .32187 Mdot
.628 .126 .941 r
.69192 .27752 Mdot
.74586 .32869 Mdot
.77894 .38321 Mdot
.77238 .36274 Mdot
.74566 .31839 Mdot
.77188 .40027 Mdot
.75171 .37639 Mdot
.77188 .40027 Mdot
1 .5 0 r
.96396 .8438 Mdot
.628 .126 .941 r
.69738 .3046 Mdot
.6634 .267 Mdot
.76405 .37612 Mdot
1 .5 0 r
.78251 .50231 Mdot
.628 .126 .941 r
.72937 .36575 Mdot
.72968 .31791 Mdot
1 .5 0 r
.71456 .42711 Mdot
.628 .126 .941 r
.6957 .2803 Mdot
.6957 .2803 Mdot
1 .5 0 r
.64729 .32466 Mdot
.628 .126 .941 r
.76933 .39292 Mdot
.76258 .36213 Mdot
.76258 .36213 Mdot
.91992 .85359 Mdot
.70036 .39278 Mdot
1 .5 0 r
.91299 .81253 Mdot
.61876 .31415 Mdot
.63894 .33804 Mdot
.62512 .32432 Mdot
.628 .126 .941 r
.76786 .37893 Mdot
.91866 .84997 Mdot
1 .5 0 r
.74446 .57002 Mdot
.86602 .67584 Mdot
.628 .126 .941 r
.69938 .34125 Mdot
.93796 .89084 Mdot
1 .5 0 r
.79805 .60062 Mdot
.63674 .35128 Mdot
.66449 .32056 Mdot
.66449 .32056 Mdot
.628 .126 .941 r
.95707 .92142 Mdot
.86387 .68916 Mdot
.86337 .72671 Mdot
1 .5 0 r
.64271 .34084 Mdot
.67046 .31011 Mdot
.83644 .67203 Mdot
.64201 .36808 Mdot
.628 .126 .941 r
.77167 .38174 Mdot
1 .5 0 r
.63525 .33729 Mdot
.75483 .59338 Mdot
.83536 .67869 Mdot
.628 .126 .941 r
.9499 .80162 Mdot
1 .5 0 r
.6616 .36105 Mdot
.628 .126 .941 r
.71458 .4874 Mdot
.75677 .37465 Mdot
.72277 .33701 Mdot
.79038 .39165 Mdot
.75638 .35402 Mdot
.7695 .395 Mdot
.9219 .7536 Mdot
1 .5 0 r
.74761 .47349 Mdot
.62559 .34699 Mdot
.628 .126 .941 r
.92639 .8559 Mdot
.76166 .37083 Mdot
.76166 .37083 Mdot
.74147 .34692 Mdot
1 .5 0 r
.59138 .29903 Mdot
.628 .126 .941 r
.76046 .43566 Mdot
1 .5 0 r
.59118 .28871 Mdot
.628 .126 .941 r
.7944 .40479 Mdot
.95895 .87962 Mdot
.77401 .37056 Mdot
1 .5 0 r
.77906 .50379 Mdot
.628 .126 .941 r
.74 .33291 Mdot
.76019 .35683 Mdot
1 .5 0 r
.77079 .58572 Mdot
.65025 .34644 Mdot
.65025 .34644 Mdot
.65712 .31904 Mdot
.61623 .30879 Mdot
.64279 .34289 Mdot
.61553 .33605 Mdot
.61553 .33605 Mdot
.628 .126 .941 r
.9437 .85199 Mdot
.67743 .28473 Mdot
1 .5 0 r
.59443 .32908 Mdot
.628 .126 .941 r
.74489 .32908 Mdot
1 .5 0 r
.86203 .7733 Mdot
.628 .126 .941 r
.76439 .38027 Mdot
1 .5 0 r
.93708 .76299 Mdot
.628 .126 .941 r
.77783 .37337 Mdot
.77783 .37337 Mdot
.71654 .32888 Mdot
.764 .35963 Mdot
.764 .35963 Mdot
1 .5 0 r
.87541 .6979 Mdot
.628 .126 .941 r
.78312 .39019 Mdot
.80332 .41411 Mdot
1 .5 0 r
.60616 .29784 Mdot
.628 .126 .941 r
.9203 .84812 Mdot
1 .5 0 r
.94757 .85496 Mdot
.61253 .30802 Mdot
.628 .126 .941 r
.74233 .3217 Mdot
.7487 .33188 Mdot
.7682 .38309 Mdot
.82629 .64287 Mdot
.82559 .67016 Mdot
.76782 .36244 Mdot
.76731 .40004 Mdot
.71933 .40688 Mdot
.73327 .36237 Mdot
.78694 .39301 Mdot
1 .5 0 r
.65034 .34849 Mdot
.67106 .33482 Mdot
.628 .126 .941 r
.77311 .37927 Mdot
.76635 .34843 Mdot
.73906 .34159 Mdot
.7719 .44416 Mdot
.69017 .36539 Mdot
1 .5 0 r
.65632 .33803 Mdot
.64248 .32429 Mdot
.628 .126 .941 r
.75819 .37216 Mdot
1 .5 0 r
.64178 .35157 Mdot
.628 .126 .941 r
.95 .844 Mdot
.825 .44384 Mdot
.77055 .37189 Mdot
.75741 .33085 Mdot
1 .5 0 r
.70839 .41293 Mdot
.628 .126 .941 r
.77584 .38872 Mdot
1 .5 0 r
.64626 .32709 Mdot
.628 .126 .941 r
.762 .37497 Mdot
.78222 .39892 Mdot
.85298 .73756 Mdot
.77495 .40569 Mdot
.75403 .40905 Mdot
1 .5 0 r
.69874 .42267 Mdot
.628 .126 .941 r
.79459 .39865 Mdot
.76053 .36095 Mdot
.78075 .3849 Mdot
.74668 .3472 Mdot
1 .5 0 r
.94536 .85013 Mdot
.96521 .85345 Mdot
.65531 .34672 Mdot
.628 .126 .941 r
.77819 .37752 Mdot
1 .5 0 r
.61396 .31578 Mdot
.628 .126 .941 r
.75758 .3329 Mdot
.74373 .31914 Mdot
.76345 .38074 Mdot
.74322 .35678 Mdot
1 .5 0 r
.90961 .71957 Mdot
.96928 .86674 Mdot
.89526 .74348 Mdot
.628 .126 .941 r
.94868 .82215 Mdot
1 .5 0 r
.61923 .33262 Mdot
.628 .126 .941 r
.74851 .37363 Mdot
.93414 .83574 Mdot
1 .5 0 r
.65252 .32899 Mdot
.68571 .3837 Mdot
.95363 .81842 Mdot
.628 .126 .941 r
.73875 .4417 Mdot
.80755 .42116 Mdot
1 .5 0 r
.65103 .31495 Mdot
.628 .126 .941 r
.70415 .44163 Mdot
1 .5 0 r
.63666 .33885 Mdot
.628 .126 .941 r
.75233 .37645 Mdot
.75031 .52711 Mdot
1 .5 0 r
.80293 .69147 Mdot
.628 .126 .941 r
.68951 .38652 Mdot
.75833 .36597 Mdot
.75833 .36597 Mdot
.78211 .63651 Mdot
1 .5 0 r
.83018 .62966 Mdot
.71492 .4857 Mdot
.64115 .31433 Mdot
.628 .126 .941 r
.77729 .38625 Mdot
1 .5 0 r
.65461 .30741 Mdot
.64044 .34166 Mdot
.628 .126 .941 r
.75615 .37927 Mdot
.77581 .37221 Mdot
1 .5 0 r
.67306 .36536 Mdot
.628 .126 .941 r
.66426 .4852 Mdot
.77492 .38921 Mdot
.78111 .38907 Mdot
.79351 .38881 Mdot
1 .5 0 r
.68363 .39909 Mdot
.66369 .32706 Mdot
.628 .126 .941 r
.76597 .37161 Mdot
.76597 .37161 Mdot
1 .5 0 r
.62906 .32699 Mdot
.628 .126 .941 r
.75849 .36804 Mdot
1 .5 0 r
.64872 .31993 Mdot
.66239 .32336 Mdot
.628 .126 .941 r
.78494 .3919 Mdot
1 .5 0 r
.61408 .31986 Mdot
.63434 .34385 Mdot
.628 .126 .941 r
.77747 .38834 Mdot
.79773 .41233 Mdot
1 .5 0 r
.63931 .40877 Mdot
.61936 .33672 Mdot
.628 .126 .941 r
.7154 .31266 Mdot
1 .5 0 r
.61896 .31601 Mdot
.8136 .59014 Mdot
.628 .126 .941 r
.96083 .84379 Mdot
1 .5 0 r
.61766 .31231 Mdot
.66579 .30545 Mdot
.67167 .35338 Mdot
.83158 .68591 Mdot
.81213 .57613 Mdot
.6503 .33603 Mdot
.628 .126 .941 r
.76614 .37369 Mdot
1 .5 0 r
.75784 .45592 Mdot
.86577 .59652 Mdot
.6563 .32554 Mdot
.628 .126 .941 r
.75118 .36656 Mdot
.9354 .86366 Mdot
.73398 .5 Mdot
1 .5 0 r
.74798 .45534 Mdot
.628 .126 .941 r
.70676 .30741 Mdot
1 .5 0 r
.65149 .33143 Mdot
.628 .126 .941 r
.76081 .34852 Mdot
1 .5 0 r
.65738 .3794 Mdot
.628 .126 .941 r
.76062 .33816 Mdot
.7738 .37933 Mdot
.75992 .36554 Mdot
1 .5 0 r
.65 .31736 Mdot
.628 .126 .941 r
.77911 .39622 Mdot
1 .5 0 r
.92516 .77374 Mdot
.87781 .69475 Mdot
.66239 .31708 Mdot
.70144 .4784 Mdot
.628 .126 .941 r
.75095 .3479 Mdot
.76375 .36836 Mdot
.76375 .36836 Mdot
1 .5 0 r
.68138 .3374 Mdot
.63738 .36782 Mdot
.80735 .50517 Mdot
.62288 .32291 Mdot
.628 .126 .941 r
.75208 .40183 Mdot
1 .5 0 r
.65648 .32964 Mdot
.65648 .32964 Mdot
.628 .126 .941 r
.88485 .72803 Mdot
1 .5 0 r
.93255 .75894 Mdot
.628 .126 .941 r
.82325 .68332 Mdot
1 .5 0 r
.65609 .30889 Mdot
.628 .126 .941 r
.93065 .85156 Mdot
.77141 .37401 Mdot
1 .5 0 r
.65498 .31555 Mdot
.63296 .39449 Mdot
.628 .126 .941 r
.76322 .39786 Mdot
.94323 .79286 Mdot
1 .5 0 r
.66028 .33245 Mdot
.628 .126 .941 r
.89317 .765 Mdot
.74623 .41444 Mdot
1 .5 0 r
.79021 .6996 Mdot
.67049 .34551 Mdot
.65017 .32145 Mdot
.64797 .33478 Mdot
.64797 .33478 Mdot
.64646 .32068 Mdot
.70653 .40994 Mdot
.628 .126 .941 r
.75292 .36821 Mdot
1 .5 0 r
.81136 .62959 Mdot
.628 .126 .941 r
.75824 .38514 Mdot
.75824 .38514 Mdot
1 .5 0 r
.64094 .35404 Mdot
.628 .126 .941 r
.94332 .83548 Mdot
1 .5 0 r
.65957 .35363 Mdot
.67742 .31164 Mdot
.66238 .30448 Mdot
.628 .126 .941 r
.95792 .87248 Mdot
1 .5 0 r
.80392 .49024 Mdot
.6677 .32141 Mdot
.628 .126 .941 r
.94147 .85137 Mdot
.96183 .87548 Mdot
1 .5 0 r
.67261 .31755 Mdot
.628 .126 .941 r
.92755 .83755 Mdot
1 .5 0 r
.67151 .32423 Mdot
.65757 .31038 Mdot
.65615 .36535 Mdot
.628 .126 .941 r
.75728 .38562 Mdot
.96429 .86445 Mdot
.93534 .84352 Mdot
1 .5 0 r
.64923 .32594 Mdot
.628 .126 .941 r
.93276 .76712 Mdot
1 .5 0 r
.80412 .48419 Mdot
.92487 .74278 Mdot
.628 .126 .941 r
.72171 .40476 Mdot
1 .5 0 r
.65304 .32876 Mdot
.67282 .32165 Mdot
.628 .126 .941 r
.96745 .87664 Mdot
.91999 .73851 Mdot
.96492 .86935 Mdot
.95343 .84443 Mdot
1 .5 0 r
.88973 .63654 Mdot
.67666 .31816 Mdot
.628 .126 .941 r
.73293 .38625 Mdot
1 .5 0 r
.66922 .31662 Mdot
.628 .126 .941 r
.95259 .83523 Mdot
.95923 .85597 Mdot
.73587 .40626 Mdot
.95828 .85476 Mdot
1 .5 0 r
.8218 .57759 Mdot
.628 .126 .941 r
.94021 .80096 Mdot
.95352 .84254 Mdot
.95225 .83887 Mdot
.92209 .74701 Mdot
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 312.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001>2000`400?l00000o`00003o_oooool2
o`0005oooooo002looooo`?o000000?oooooo`000?ooool0G_ooool00;[ooooo0_l00004ooooo`;o
0000G_ooool00;Sooooo0_l00006ooooo`03o`000?oooooo000005gooooo002eooooo`?o00002?oo
ool00ol0003oooooo`00001Mooooo`00/oooool2o`0000_ooooo00Co0000oooooooooooo0000G?oo
ool00;3ooooo0ol0000=ooooo`04o`000?ooooooooooo`0005cooooo002^ooooo`;o00004?ooool0
1Ol0003ooooooooooooooooo000005_ooooo002/ooooo`;o00004_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Sooooo002Yooooo`?o00005Oooool01Ol0003ooooooooooooooooo
000005[ooooo002Wooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05Oooooo002Uooooo`;o00006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Ko
oooo002Rooooo`?o00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo
002Pooooo`;o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Gooooo002M
ooooo`?o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Gooooo002Koooo
o`;o00009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo002Iooooo`;o
00009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?ooooo002Fooooo`?o0000
:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?ooooo002Dooooo`;o0000:ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05;ooooo002Aooooo`?o0000;Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo057ooooo002?ooooo`;o0000<?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo057ooooo002=ooooo`;o0000<_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo053ooooo002:ooooo`?o0000=?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo053ooooo0028ooooo`;o0000=oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04oooooo0026ooooo`;o0000>Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo04kooooo0023ooooo`?o0000>oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo04kooooo0021ooooo`;o0000?oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04gooooo001nooooo`?o0000@Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo04gooooo001looooo`;o0000A?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo04cooooo001jooooo`;o0000A_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo04_ooooo001gooooo`?o0000B?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
04_ooooo001eooooo`;o0000Boooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[o
oooo001booooo`?o0000COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo
001`ooooo`;o0000D?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo001^
ooooo`;o0000D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Sooooo001[oooo
o`?o0000E?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Sooooo001Yooooo`;o
0000Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Oooooo001Wooooo`;o0000
FOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Kooooo001Tooooo`?o0000Fooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Kooooo001Rooooo`;o0000G_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Gooooo001Oooooo`?o0000H?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04Cooooo001Mooooo`;o0000Hoooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo04Cooooo001Kooooo`;o0000IOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo04?ooooo001Hooooo`?o0000J?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04?ooooo001Fooooo`;o0000Joooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04;ooooo001Cooooo`?o0000KOooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo047ooooo001Aooooo`;o0000L?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo047ooooo001?ooooo`;o00004oooool2oj0Pl5gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`10ooooo`00C?ooool3o`0001Gooooo0_nP8?1Mooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0?oooool004[ooooo0_l0001gooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0?oooool004Sooooo0_l0001iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0?_ooool004Gooooo0ol0001kooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0?_ooool004?ooooo0_l0001nooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0?Oooool0043ooooo0ol00020ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0??ooool003kooooo0_l0000Pooooo`;oX23`2?ooool2oj0Pl5Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0looooo`00??ooool2o`0002;ooooo0_nP8?08oooo
o`;oX23`Eoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03_ooooo000iooooo`?o
00009?ooool2oj0Pl67ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0jooooo`00
=oooool2o`0008[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0jooooo`00=?oo
ool3o`0001Kooooo0_nP8?0Qooooo`CoX23`Coooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo03Wooooo000booooo`;o00006Oooool2oj0Pl27ooooo1?nP8?1?ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0>Oooool0033ooooo0_l0002Booooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0>?ooool002gooooo0ol0000<ooooo`;oX23`Q_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Oooooo000[ooooo`;o00003oooool2oj0Pl0;ooooo
0_nP8?09ooooo`;oX23`3Oooool2oj0Pl0Wooooo0_nP8?1Mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0=oooool002Wooooo0_l0000Eooooo`;oX23`2Oooool2oj0Pl0gooooo0_nP
8?09ooooo`;oX23`3?ooool2oomo04oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0fooooo`009_ooool3o`0002Kooooo0_nP8?02ooooo`;oX23`2oooool2oj0Pl0gooooo0_nP8?02
ooooo`;oogl04_ooool2oj0Pl3_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0f
ooooo`009?ooool2o`0002Wooooo0_nP8?02ooooo`CoX23`2Oooool2oj0Pl0Wooooo0_nP8?02oooo
o`;oX23`5_ooool2oj0Pl3_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0eoooo
o`008Oooool3o`0001Cooooo0_ooO`04ooooo`;oX23`5Oooool2oj0Pl1?ooooo00Coogl0oj0Pl?nP
8?3ooooo0_nP8?0=ooooo`;oogl0AOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
03Cooooo000Oooooo`;o00005oooool2oomo00Cooooo0_nP8?0Kooooo`;oX23`3Oooool2oomo00;o
oooo0_nP8?0=ooooo`;oogl03_ooool2oomo03Gooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0dooooo`007Oooool2o`0003Wooooo0_nP8?000oooooooX23`oj0Pl00:ooooo`;oX23`
5oooool2oomo00_ooooo0_ooO`0eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
<oooool001[ooooo0ol0000Wooooo`;oX23`3?ooool2oj0Pl0Cooooo0_nP8?0=ooooo`;oX23`5ooo
ool2oomo04;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0booooo`006Oooool0
0ol0003oooooooooo`0Vooooo`;oogl00_nP8?0<ooooo`;oX23`0_ooool2oj0Pl1;ooooo0_ooO`04
ooooo`;oX23`6_ooool4oomo03Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0b
ooooo`006Oooool00ol0003oooooooooo`0Vooooo`;oogl01Oooool2oj0Pl0Oooooo0_nP8?02oooo
o`;oX23`3?ooool3oomo00?ooooo0_ooO`04ooooo`;oX23`00?oogl0ooooooooool05oooool5oomo
00;ooooo0_ooO`0_ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0<Oooool001Wo
oooo0_l0000Sooooo`;oX23`2Oooool2oj0Pl0Oooooo1?nP8?0>ooooo`?oogl02Oooool3oomo00Go
oooo0_ooO`0Eooooo`;oogl00_ooool2oomo02Gooooo0onP8?07ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0<Oooool001Wooooo00?o0000ooooool000006_ooool2oomo00Kooooo
0_nP8?0Dooooo`;oX23`1Oooool2oj0Pl0gooooo0_nP8?0<ooooo`?oogl02_ooool3oomo00Kooooo
1?ooO`0Xooooo`CoX23`1_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo033ooooo
000Hooooo`05o`000?ooooooooooooooool000002Oooool2oj0Pl0kooooo0_ooO`000oooooooogl0
oomo0009ooooo`;oX23`0_ooool2oomo0003oooooonP8?3oX23`00;oogl00_ooool2oomo00Sooooo
0_nP8?0=ooooo`;oX23`1?ooool2oj0Pl0Gooooo0_nP8?02oomo00[ooooo0oooO`06ooooo`Googl0
1Oooool2oomo00?ooooo0_nP8?0Mooooo`;oX23`1_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02oooooo000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool2oj0Pl17ooooo0_ooO`06ooooo`?oogl01?nP8?02oomo0003oooooonP8?3oX23`00;oogl00_oo
ool2oomo00;oX23`2Oooool2oomo00Kooooo0_ooO`08ooooo`;oX23`1Oooool2oj0Pl0Sooooo00?o
X23`oomo0?ooO`002_ooool5oomo00Gooooo0_ooO`000oooooooogl0oomo0002oj0Pl1gooooo0_nP
8?02ooooo`;oX23`0_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02oooooo000H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool2oj0Pl0Oooooo1?ooO`00
0oooooooX23`oj0Pl003ooooo`;oogl00_nP8?04ooooo`;oX23`2Oooool2oomo00Kooooo0_ooO`0I
ooooo`03oj0Pl?ooO`3oogl000cooooo0oooO`08ooooo`;oogl00_ooool2oomo01_ooooo0onP8?00
0oooooooX23`oj0Pl002ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;_ooool0
01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`;oX23`1Oooool2oj0P
l003ooooooooO`3oogl000Oooooo0_ooO`02oj0Pl17ooooo0_ooO`04ooooo`;oogl000?ooooooj0P
l?nP8?002?ooool2oj0Pl0oooooo0_nP8?02oomo00Cooooo0_nP8?02oomo0003ooooooooO`3oogl0
00Gooooo0_ooO`05ooooo`;oogl07?ooool2oj0Pl0Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;oX23`1oooool2oj0Pl0Wooooo0_nP8?05ooooo`;oX23`00?ooooooomo0?ooO`001_ooool2oomo
01Cooooo0_ooO`07ooooo`;oX23`0oooool2oj0Pl0?ooooo0_nP8?08ooooo`Koogl000?ooooooj0P
l?nP8?000_ooO`04ooooo`;oX23`0_ooO`05ooooo`;oogl000?oX23`oomo0?ooO`000oooO`07oooo
o`;oogl05oooool2oj0Pl003oooooonP8?3oX23`00;oX23`00?oooooo`000?ooool0:Oooool00ol0
003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
X23`00?ooooooj0Pl?nP8?001?ooool00onP8?3oogl0oomo000Dooooo`;oogl01?nP8?02oomo00?o
oooo0_nP8?000oooO`3oooooooooo`02ooooo`;oogl02_ooool2oj0Pl0;oogl00_ooool2oomo00Co
oooo0_nP8?000oooooooogl0oomo0004ooooo`;oogl000Cooooooomo0?ooO`3ooooo1_ooO`000ooo
ooooX23`oj0Pl002oomo0003oj0Pl?oooooooooo00Gooooo0_ooO`000oooooooogl0oomo0002oomo
0003oj0Pl?ooooooogl000?oogl01oooool2oomo01?ooooo0_nP8?02ooooo`;oX23`00?ooooooj0P
l?nP8?000onP8?000ol0003oX23`ooooo`0Yooooo`03o`000?oooooooooo02cooooo000Hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2oj0Pl0Gooooo0_ooO`000onP8?3o
ooooooooo`0=ooooo`;oX23`0_ooool01?ooO`3oX23`oj0Pl?nP8?02oomo00Gooooo0_nP8?000ooo
O`3oooooooooo`02ooooo`;oogl02_ooool2oj0Pl0;oogl00_ooool2oomo00Oooooo1?ooO`02oooo
o`;oogl000?oX23`oomo0?ooO`001?ooO`02ooooo`;oogl00_ooool4oomo00Kooooo2oooO`0Noooo
o`;oX23`0_ooool2oj0Pl0;ooooo0_nP8?000oooooooX23`o`000002oj0Pl2Wooooo00?o0000oooo
ooooool0;?ooool001Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`Co
ogl000?oX23`ooooooooool01oooool2oomo00Cooooo0_nP8?000oooooooogl0oomo0002oj0Pl003
ooooooooO`3oogl000cooooo0_nP8?03ooooo`;oX23`5_ooool3oomo00?ooooo0_nP8?000ooooooo
ogl0oomo0002oomo00;ooooo0_ooO`04ooooo`;oogl01oooool3oomo0003ooooooooO`3oogl000Co
ogl03Oooool2oj0Pl1Oooooo1?nP8?000ol0003oX23`oj0Pl00Zooooo`03o`000?oooooooooo02_o
oooo000Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool2oj0Pl003oomo
0?oooooooooo00Cooooo0_ooO`001?ooooooX23`oj0Pl?ooool2oomo00Cooooo0_ooO`000ooooooo
ogl0oomo0002ooooo`;oogl000?ooooooj0Pl?nP8?003oooool2oj0Pl1Oooooo0_ooO`02ooooo`Co
ogl000Cooooooomo0?ooO`3ooooo1?ooO`02ooooo`;oogl02_ooool2oomo00;ooooo1?ooO`0>oooo
o`;oX23`5oooool4oj0Pl003o`000?nP8?3ooooo02_ooooo00?o0000ooooooooool0:_ooool001Oo
oooo00?o0000ooooooooool02_ooool2oj0Pl0Cooooo0onP8?07ooooo`;oogl000?ooooooj0Pl?nP
8?001oooool2oomo00Cooooo0_ooO`001?nP8?3ooooooj0Pl?nP8?0Booooo`;oogl01Oooool2oomo
00Oooooo1?ooO`06ooooo`Coogl01?ooool2oomo00;ooooo1?ooO`09ooooo`03oj0Pl?ooO`3oogl0
00Cooooo0_ooO`02ooooo`;oogl02_ooool2oomo00_ooooo1?nP8?04ooooo`;oX23`0_ooool4oj0P
l003o`000?oooooooooo00;ooooo0_nP8?0Wooooo`03o`000?oooooooooo02[ooooo000Gooooo`03
o`000?oooooooooo00[ooooo0_nP8?001?l0003oooooooooooooool2oj0Pl0Cooooo0_nP8?02oomo
013ooooo1OooO`03ooooo`;oogl01?ooool2oj0Pl0[ooooo00?oogl0oj0Pl?nP8?001?ooool2oomo
00;ooooo0_nP8?02oomo0003ooooooooO`3oogl000;oogl02?ooool2oomo00Sooooo0_ooO`0;oooo
o`;oX23`1oooool4oomo00;ooooo0_nP8?02oomo00;ooooo1?ooO`0;ooooo`CoX23`0_ooool5oj0P
l0;ooooo0onP8?000ol0003oooooooooo`02ooooo`;oX23`:?ooool00ol0003oooooooooo`0Yoooo
o`005oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0_nP8?02ooooo`;o
X23`00Coogl0oj0Pl?nP8?3ooooo0_nP8?0:ooooo`?oogl00_nP8?02oomo00?ooooo0_ooO`03oooo
o`;oogl00onP8?03ooooo`?oX23`0oooool4oj0Pl0Kooooo0_nP8?02oomo00Cooooo0oooO`06oooo
o`;oogl01oooool2oomo00gooooo0_ooO`03ooooo`Googl01?ooool2oj0Pl0;oogl00_ooool3oomo
0004oooooonP8?3oX23`ooooo`;oogl02_ooool7oj0Pl0;ooooo0onP8?001?l0003ooooooj0Pl?nP
8?0/ooooo`03o`000?oooooooooo02Sooooo000Gooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00onP8?001OooooooX23`oj0Pl?nP8?3ooooo00GoX23`0oooool2oomo00;ooooo0_nP
8?001?ooooooogl0oomo0?ooool4oj0Pl0Sooooo0oooO`02oj0Pl0?ooooo0onP8?05ooooo`;oX23`
3_ooool3oomo00Kooooo0_ooO`02ooooo`?oogl000Cooooooomo0?ooO`3oogl02?ooool2oj0Pl0?o
oooo0_ooO`03ooooo`Coogl00_ooool2oomo00Sooooo0oooO`02oj0Pl004ooooooooO`3oogl0oooo
o`;oX23`1oooool2oj0Pl0?ooooo0_nP8?04ooooo`03oj0Pl?l0003ooooo00;oX23`;?ooool00ol0
003oooooooooo`0Xooooo`005_ooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooX23`oj0P
l0;ooooo0onP8?001?ooooooX23`oj0Pl?ooO`04oj0Pl005ooooooooO`3oogl0oomo0?ooool00_nP
8?000oooooooogl0oomo0003ooooo`;oX23`00?ooooooomo0?ooO`000_ooool2oj0Pl0;oogl01_oo
ool2oj0Pl1Cooooo0_nP8?02ooooo`;oogl02Oooool4oomo0003ooooooooO`3oogl000;oogl01Ooo
ool2oomo00;oX23`0_ooool2oomo00;oX23`2?ooool2oomo00Wooooo0_ooO`06ooooo`;oX23`1_oo
ool2oomo00?ooooo0oooO`02ooooo`;oX23`00?oooooo`000?ooool00_nP8?0]ooooo`03o`000?oo
oooooooo02Oooooo000Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool5
oj0Pl0?oogl00_nP8?02oomo0003ooooooooO`3oogl000?ooooo0_nP8?001?ooooooogl0oomo0?oo
ool2oj0Pl003ooooooooO`3oogl000;ooooo0_nP8?02oomo00Kooooo0_nP8?04ooooo`;oogl00ooo
ool2oj0Pl0Sooooo0_ooO`000onP8?3oooooooooo`02oomo00Sooooo0_nP8?001?ooO`3ooooooomo
0?ooO`02ooooo`;oogl000?ooooooomo0?ooO`001?ooO`001?ooooooogl0oomo0?ooool2oomo00;o
X23`0_ooool2oomo00oooooo0_nP8?04ooooo`?oogl01oooool8oomo00;ooooo0_nP8?000ooooooo
0000ooooo`04oj0Pl0Cooooo0onP8?0Tooooo`03o`000?oooooooooo02Oooooo000Fooooo`03o`00
0?oooooooooo01;ooooo00Co0000oooooooooooooooo1OnP8?000oooO`3oX23`oj0Pl002oj0Pl0Go
ogl000?oX23`oomo0?ooO`000onP8?02oomo00Cooooo0_ooO`05ooooo`;oogl01Oooool5oj0Pl003
ooooooooO`3oogl000?ooooo0_nP8?05ooooo`;oX23`00Cooooooomo0?ooO`3oogl00_ooool2oomo
0003oj0Pl?ooO`3oogl000Gooooo0onP8?000oooooooogl0oomo0005ooooo`Coogl00oooool2oomo
0003ooooooooO`3oogl000Cooooo0_ooO`02ooooo`;oogl00oooool2oj0Pl004ooooooooO`3oogl0
ooooo`Coogl01?ooool4oomo00Oooooo2_ooO`000oooooooX23`o`000002oj0Pl004oooooonP8?3o
X23`ooooo`;oX23`00Cooooooj0Pl?nP8?3oX23`9Oooool00ol0003oooooooooo`0Vooooo`005_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo1onP8?02oomo00?oX23`0_oo
O`001Oooooooogl0oomo0?nP8?3oogl000;oX23`0_ooool2oomo00Gooooo0_ooO`02ooooo`;oX23`
00?ooooooomo0?ooO`000onP8?02ooooo`;oogl01oooool2oomo00;oX23`1?ooO`04ooooo`03oj0P
l?ooO`3oogl000Kooooo1?nP8?02oomo00Wooooo0_nP8?001?ooO`3oooooooooooooO`03oj0Pl0;o
ogl00_ooool5oomo00;ooooo0_nP8?000oooooooogl0oomo0007oomo00;ooooo1?ooO`05ooooo`Ko
ogl00_ooool4oomo0003oooooonP8?3o000000GoX23`00Cooooooj0Pl?nP8?3oX23`:Oooool00ol0
003oooooooooo`0Uooooo`005_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo1onP8?02oomo00CoX23`0_ooool4oomo00;oX23`00?ooooooj0Pl?nP8?002_ooool2oj0Pl003
ooooooooO`3oogl000?ooooo1?ooO`07ooooo`;oogl00_ooool2oomo00;ooooo1?ooO`03ooooo`;o
ogl01_ooool2oj0Pl0;oogl02Oooool2oj0Pl005oomo0?ooooooogl0oomo0?nP8?001?ooO`000ooo
ooooogl0oomo0004oomo00Oooooo0_ooO`000oooooooogl0oomo0002oomo0003ooooooooO`3oogl0
00?oogl01Oooool<oomo00;ooooo00?o0000ooooooooool00_nP8?000oooooooX23`oj0Pl002oj0P
l003oooooonP8?3oX23`00;ooooo0onP8?0Qooooo`03o`000?oooooooooo02Gooooo000Fooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool6oj0Pl0Googl00_nP8?02oomo00?o
X23`00Cooooooj0Pl?nP8?3ooooo0_nP8?000oooooooX23`oj0Pl007ooooo`;oX23`0oooool2oomo
017ooooo1?ooO`03ooooo`;oogl02_ooool4oj0Pl0Wooooo0_ooO`000onP8?3oogl0oomo0002oomo
0003ooooooooO`3oogl000;oogl02oooool5oomo0003ooooooooO`3oogl000Coogl01?ooool<oomo
0003oj0Pl?oooooo000000Gooooo0_nP8?03ooooo`;oX23`0_ooool3oj0Pl2;ooooo00?o0000oooo
ooooool09?ooool001Kooooo00?o0000ooooooooool05_ooool01?l0003oooooooooooooool9oj0P
l0Googl00_nP8?02oomo0004oj0Pl?ooooooooooooooo`;oX23`00Cooooooj0Pl?nP8?3ooooo1?nP
8?03ooooo`CoX23`2?ooool2oj0Pl0?ooooo0_nP8?0Cooooo`;oogl01Oooool4oj0Pl0[ooooo00Co
X23`oomo0?ooO`3ooooo0oooO`02ooooo`;oogl01?ooool2oomo00Cooooo0oooO`001?ooooooogl0
oomo0?nP8?02ooooo`Koogl00_ooool;oomo00;oX23`0_ooool00ol0003oX23`oj0Pl002oj0Pl0Wo
oooo0_nP8?0Tooooo`03o`000?oooooooooo02?ooooo000Eooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool03OnP8?02oomo00;oX23`00?oogl0ooooooooool00_ooool2oj0Pl0Gooooo
0_ooO`03oj0Pl003oooooonP8?3oX23`00;oX23`2?ooool2oj0Pl0?ooooo0onP8?02ooooo`;oogl0
0_ooool2oomo00?ooooo1?ooO`03ooooo`;oogl01_ooool3oomo00?ooooo0_nP8?06ooooo`;oogl0
0_ooool2oomo00Cooooo3?ooO`000oooooooogl0oomo0003oj0Pl0;oogl00_ooool3oomo00;oX23`
2_ooO`000oooooooX23`oj0Pl002ooooo`03o`000?nP8?3oX23`00;oX23`00?ooooooj0Pl?nP8?00
0_nP8?04ooooo`?oX23`8oooool00ol0003oooooooooo`0Sooooo`005Oooool00ol0003ooooooooo
o`0Iooooo`04o`000?ooooooooooooooo`SoX23`00?oogl0oj0Pl?nP8?001OooO`000oooooooogl0
oomo0003oj0Pl0;oogl00oooool2oomo00?oX23`0oooool2oj0Pl0Wooooo0_ooO`03ooooo`;oX23`
0_ooool2oomo00;ooooo00?oogl0oj0Pl?nP8?000_ooool4oomo00_ooooo0oooO`001?ooooooogl0
oomo0?nP8?02oomo00cooooo0_ooO`000oooooooogl0oomo000:oomo0004ooooooooO`3oogl0oooo
o`;oX23`1?ooO`000oooooooogl0oomo0002oj0Pl0Soogl01?ooool2oj0Pl003ooooool0003ooooo
00Cooooo1?nP8?02ooooo`SoX23`8Oooool00ol0003oooooooooo`0Rooooo`005Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo2_nP8?000oooO`3oX23`oj0Pl002oj0Pl0;o
ogl00onP8?02oomo00Gooooo0_nP8?000oooooooogl0oomo000<ooooo`;oogl00_ooool2oomo00So
oooo0_nP8?0Aooooo`;oogl00_ooool2oomo0003ooooooooO`3oogl000Sooooo0_ooO`001Ooooooo
ogl0oomo0?ooO`3ooooo00Coogl000?oX23`ooooooooool00_ooO`000oooooooogl0oomo0003oomo
0004ooooooooO`3oogl0ooooo`?oogl00_ooool:oomo0003ooooooooO`3oogl000;ooooo0_nP8?00
1?oooooo0000oj0Pl?nP8?04ooooo`?oX23`0_ooool3oj0Pl003oooooonP8?3oX23`00;oX23`8Ooo
ool00ol0003oooooooooo`0Rooooo`005Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooooooo`[oX23`00Coogl0oj0Pl?ooO`3oogl01_nP8?05ooooo`;oogl00_nP8?000oooooooogl0
oomo0009ooooo`;oX23`1oooO`02ooooo`;oX23`1Oooool2oomo00Cooooo0_nP8?09ooooo`?oogl0
1?nP8?06ooooo`Coogl000?ooooooomo0?ooO`000oooO`04ooooo`;oogl000?oX23`ooooooooool0
1_ooO`06ooooo`Woogl000?ooooooomo0?ooO`000_ooO`02ooooo`;oogl000Kooooooomo0?ooO`3o
X23`ooooool00002oj0Pl0;ooooo1onP8?000oooooooX23`oj0Pl002oj0Pl0;ooooo0_nP8?0Qoooo
o`03o`000?oooooooooo027ooooo000Eooooo`03o`000?oooooooooo01Sooooo0_nP8?02ooooo`03
o`000?oooooooooo00CoX23`00Cooooooj0Pl?nP8?3oX23`0oooO`001?nP8?3oogl0oomo0?ooO`04
oj0Pl0;oogl01?ooool2oomo00;ooooo0_nP8?03ooooo`;oX23`1Oooool2oj0Pl0Koogl00oooool2
oj0Pl0?ooooo1?ooO`04ooooo`;oX23`00?ooooooomo0?nP8?000_nP8?04ooooo`Coogl000?oX23`
oomo0?ooO`000_ooool2oomo0003oooooonP8?3oogl000?oogl000Gooooooj0Pl?ooO`3oogl0oj0P
l003oomo0003ooooooooO`3oogl000;oogl000?ooooooj0Pl?nP8?000oooO`05ooooo`Googl000?o
oooooomo0?ooO`001OooO`001?nP8?3oogl0oomo0?ooO`05ooooo`;oogl00_ooool01?l0003oX23`
oj0Pl?ooool3oj0Pl003oooooonP8?3oX23`00SoX23`00?ooooooj0Pl?nP8?008_ooool00ol0003o
ooooooooo`0Pooooo`005Oooool00ol0003oooooooooo`0Hooooo`;oX23`0oooool01?l0003ooooo
oj0Pl?nP8?03ooooo`SoX23`2OooO`07ooooo`;oX23`0oooool2oj0Pl0Wooooo0_nP8?000oooO`3o
ooooooooo`03ooooo`;oX23`0_ooool6oomo00Gooooo00?oogl0oj0Pl?nP8?000onP8?02ooooo`Oo
ogl00_ooool2oomo0004oooooonP8?3oX23`ooooo`?oogl000?ooooooomo0?ooO`001?ooO`000ooo
ooooogl0oomo0002oomo0003oooooonP8?3oX23`00;oogl01?ooool5oomo00?oX23`0_ooO`000ooo
ooooogl0oomo0006oomo00;ooooo0_ooO`03ooooo`;oX23`00Co0000oj0Pl?nP8?3ooooo0_nP8?03
ooooo`[oX23`9?ooool00ol0003oooooooooo`0Pooooo`005?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00?ooooo2OnP8?08oomo00_ooooo0_nP8?07ooooo`;oogl01?nP8?05oooo
o`;oX23`0oooool2oj0Pl0?oogl01Oooool2oj0Pl004oomo0?ooooooX23`oj0Pl0;ooooo1?ooO`02
oj0Pl003oomo0?oooooooooo00?oogl00oooool3oomo00?ooooo2?ooO`03oj0Pl003oooooonP8?3o
X23`00Cooooo1_ooO`02oj0Pl0Koogl000?ooooooomo0?ooO`000_ooO`02ooooo`;oogl00oooool2
oj0Pl003o`000?oooooooooo00Sooooo3?nP8?0Qooooo`03o`000?oooooooooo01oooooo000Doooo
o`03o`000?oooooooooo01[ooooo0_nP8?02ooooo`;oX23`00?o0000ooooooooool00_ooool5oj0P
l003oooooonP8?3oX23`00;oX23`1_ooO`000oooooooogl0oomo0002ooooo`;oX23`1Oooool2oj0P
l0Kooooo0_nP8?000oooO`3oX23`oj0Pl002oj0Pl0Kooooo0_ooO`02ooooo`;oX23`1?ooool2oj0P
l0;ooooo0_nP8?03ooooo`;oX23`1Oooool2oomo00?ooooo1OooO`09ooooo`Koogl00onP8?001?oo
ooooogl0oomo0?ooO`04ooooo`;oogl000?ooooooomo0?ooO`000oooool8oomo0004ooooooooO`3o
ogl0ooooo`;oogl01Oooool00ol0003oooooooooo`09ooooo`_oX23`8Oooool00ol0003ooooooooo
o`0Oooooo`005?ooool00ol0003oooooooooo`0Jooooo`;oX23`0_ooool2oj0Pl003ooooool0003o
oooo00;oX23`00Cooooooj0Pl?nP8?3oX23`0_ooool4oj0Pl0Googl000CoX23`oomo0?ooO`3oogl0
0_ooool2oj0Pl0gooooo0_nP8?02ooooo`;oogl000?ooooooomo0?ooO`001?ooool2oomo00Sooooo
0_nP8?02ooooo`;oX23`0oooool00onP8?3oogl0oomo0004ooooo`;oogl00_ooool2oj0Pl0;ooooo
1?ooO`07ooooo`;oogl02?ooool3oomo00Cooooo0_ooO`000oooooooX23`oj0Pl003ooooo`Koogl0
0oooool2oomo0003ooooooooO`3oogl000Gooooo00?o0000ooooooooool01_ooool3oj0Pl003oooo
oonP8?3oX23`00OoX23`8oooool00ol0003oooooooooo`0Nooooo`005?ooool00ol0003ooooooooo
o`0Qooooo`CoX23`0_ooool2oj0Pl0Kooooo00?oogl0oj0Pl?nP8?001_ooO`000oooooooogl0oj0P
l002oj0Pl003oooooonP8?3oX23`00;ooooo0_nP8?0;ooooo`;oX23`00?oogl0ooooooooool02_oo
ool2oomo00;oX23`0_ooO`02oj0Pl0Cooooo0oooO`02oj0Pl003oooooonP8?3oX23`00;ooooo1?nP
8?001?ooooooogl0oomo0?ooO`02oj0Pl0;ooooo0_nP8?000oooooooogl0oomo0003ooooo`;oX23`
00?ooooooomo0?ooO`001?ooool2oomo00Kooooo1?ooO`02ooooo`;oX23`1Oooool2oomo00?oX23`
1?ooool00ol0003oooooooooo`02ooooo`;oX23`0_ooool3oj0Pl003oooooonP8?3oX23`00SoX23`
8oooool00ol0003oooooooooo`0Mooooo`005?ooool00ol0003oooooooooo`0Qooooo`;oX23`0_oo
ool3oj0Pl0Cooooo0_nP8?02ooooo`;oX23`00?oogl0oj0Pl?nP8?000_ooO`02oj0Pl005oomo0?nP
8?3oX23`oomo0?ooool00_nP8?02ooooo`;oX23`2oooool2oj0Pl003oooooonP8?3oX23`00[ooooo
00?oogl0oj0Pl?nP8?001?ooO`02ooooo`?oogl000?ooooooomo0?ooO`000_nP8?000oooooooX23`
oj0Pl004ooooo`;oX23`00?oogl0oj0Pl?nP8?000onP8?02ooooo`;oX23`00?ooooooomo0?ooO`00
0oooool2oj0Pl003ooooooooO`3oogl000Cooooo0_ooO`06ooooo`Coogl00_ooool00onP8?3oogl0
oomo0004ooooo`;oogl01onP8?000ol0003oooooooooo`02ooooo`;oX23`0_ooool?oj0Pl2;ooooo
00?o0000ooooooooool07Oooool001Cooooo00?o0000ooooooooool08_ooool2oj0Pl005oooooonP
8?3oX23`oj0Pl?ooool00_nP8?000oooooooX23`oj0Pl005ooooo`;oX23`0_ooO`05oj0Pl003oomo
0?ooooooX23`00;oX23`3_ooool3oomo00;oX23`0oooool2oj0Pl0;ooooo0_ooO`02ooooo`;oX23`
1_ooool5oomo00;ooooo0_ooO`02ooooo`;oX23`0oooool4oomo0005oj0Pl?ooO`3oogl0oomo0?oo
ool00oooO`06ooooo`;oX23`0_ooO`02ooooo`Coogl01_ooool3oomo00?ooooo0oooO`02ooooo`;o
ogl000?ooooooj0Pl?nP8?000_ooO`04oj0Pl003o`000?oooooooooo00;ooooo2?nP8?000ooooooo
X23`oj0Pl008oj0Pl2?ooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000ooooooooool0
8oooool2oj0Pl003o`000?oooooooooo00;ooooo0_nP8?07ooooo`;oX23`0oooO`03oj0Pl003oomo
0?nP8?3oX23`00;oogl00_nP8?04ooooo`;oX23`1oooool2oj0Pl0?oogl00_nP8?02ooooo`;oX23`
0_ooool2oomo00?ooooo0_nP8?02ooooo`;oX23`0_ooool4oomo00;ooooo2OooO`02ooooo`[oogl0
1_ooool>oomo00?ooooo0_ooO`03ooooo`?oogl00_ooool2oomo0003oooooonP8?3oX23`00;oogl0
0oooool01?nP8?3o0000oj0Pl?nP8?04ooooo`;oX23`00?ooooooj0Pl?nP8?002_nP8?000ooooooo
X23`oj0Pl002oj0Pl27ooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`05ooooo`CoX23`00Cooooooj0Pl?nP8?3oX23`0_ooool3oj0Pl004
oomo0?nP8?3oX23`oomo00?oX23`1?ooool2oj0Pl0Gooooo1?nP8?03ooooo`;oX23`2Oooool2oomo
00;oX23`00Coogl0oooooonP8?3oX23`0oooool2oj0Pl0Gooooo1oooO`000oooooooogl0oomo0003
oomo00;ooooo1?ooO`000onP8?3oooooooooo`03ooooo`;oogl00_ooool2oomo0004ooooooooO`3o
ogl0ooooo`Koogl00_nP8?0>ooooo`;oX23`1?ooool00ol0003oX23`oj0Pl003ooooo`;oX23`0ooo
ool3oj0Pl004oooooonP8?3oX23`ooooo`WoX23`8Oooool00ol0003oooooooooo`0Kooooo`004ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo1OnP8?000oooooooX23`oj0P
l002ooooo`Coogl01_nP8?001?ooO`3oooooooooooooool3oj0Pl0Cooooo0_nP8?000oooooooX23`
oj0Pl00<ooooo`?oogl000Cooooooomo0?ooO`3ooooo0_nP8?03ooooo`;oogl02?ooool3oj0Pl0Oo
ogl01?ooool2oomo0003oj0Pl?ooO`3oogl000;oX23`2_ooool00onP8?3oogl0oomo0002ooooo`;o
ogl00_nP8?03ooooo`;oX23`0oooool2oj0Pl0Cooooo0_nP8?001OooO`3ooooooooooooooooo0000
00Gooooo1onP8?02ooooo`_oX23`8oooool00ol0003oooooooooo`0Jooooo`004oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo0_nP8?05ooooo`04oj0Pl?ooO`3oogl0oj0P
l0;oogl00onP8?001?ooO`3oX23`oj0Pl?nP8?02ooooo`;oX23`00?ooooooj0Pl?nP8?001?ooool2
oj0Pl0Gooooo0_ooO`05ooooo`;oogl00_ooool2oj0Pl003oooooonP8?3oX23`00?ooooo0_ooO`08
ooooo`03oj0Pl?ooO`3oogl000Coogl000?ooooooomo0?ooO`000_ooO`05ooooo`;oogl00onP8?03
ooooo`;oogl01?ooool00onP8?3oogl0oomo0006ooooo`;oogl000Cooooooj0Pl?nP8?3ooooo0_oo
O`000onP8?3oogl0oomo0004ooooo`;oogl00oooool00ol0003oooooooooo`02ooooo`;oogl000Co
oooooj0Pl?nP8?3oX23`1Oooool:oj0Pl2?ooooo00?o0000ooooooooool06_ooool001?ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`GoX23`1Oooool01?nP8?3oogl0oj0P
l?nP8?03ooooo`03oj0Pl?ooO`3oogl000Gooooo0_nP8?0;ooooo`;oogl000?ooooooomo0?ooO`00
1_ooool2oj0Pl0Kooooo0_ooO`05ooooo`;oX23`1oooO`02ooooo`Coogl00_ooool00oooO`3oX23`
oj0Pl002ooooo`;oogl000CoX23`oooooooooooooooo1_ooO`05ooooo`;oogl00_ooool01?ooO`3o
X23`oj0Pl?ooool4oomo0004ooooooooO`3oogl0ooooo`?oX23`0_ooool2oomo0003oooooonP8?3o
000000;oX23`00Cooooooomo0?ooO`3ooooo0_nP8?000oooooooX23`oj0Pl00>oj0Pl2?ooooo00?o
0000ooooooooool06Oooool001?ooooo00?o0000ooooooooool0:Oooool2oj0Pl0Gooooo1_nP8?00
0oooooooX23`oj0Pl003ooooo`?oX23`0_ooO`08oj0Pl0Gooooo0_ooO`04ooooo`;oogl00_nP8?00
1?ooooooX23`oomo0?ooO`0:ooooo`;oogl02Oooool2oj0Pl0;oogl00_ooool3oomo00;ooooo1?nP
8?02ooooo`03oomo0?nP8?3oX23`00;oX23`0_ooO`06ooooo`?oogl00_nP8?04ooooo`;oogl00ooo
ool2oj0Pl003ooooooooO`3oogl000;oogl000Cooooooj0Pl?nP8?3ooooo0onP8?02ooooo`;oogl0
0_nP8?000ol0003oX23`oj0Pl002oj0Pl0Gooooo4?nP8?000oooooooX23`oj0Pl00Qooooo`03o`00
0?oooooooooo01Sooooo000Cooooo`03o`000?oooooooooo02Wooooo0_nP8?000ol0003ooooooooo
o`02ooooo`;oX23`1Oooool2oj0Pl0Gooooo0oooO`05oj0Pl003oomo0?nP8?3oX23`00Gooooo0_oo
O`04ooooo`;oogl00_nP8?001?ooooooX23`oomo0?ooO`0:ooooo`?oogl00_ooool2oomo00Gooooo
0_ooO`000oooooooX23`oomo0005oomo00GoX23`0oooool2oomo0003oj0Pl?ooooooX23`00;oogl0
0oooool4oomo00;oX23`0_ooool2oj0Pl0?ooooo0_ooO`03ooooo`;oX23`0_ooool3oj0Pl0?ooooo
0_nP8?03ooooo`;oX23`00?o0000oooooonP8?000_nP8?04oooooaCoX23`8Oooool00ol0003ooooo
ooooo`0Hooooo`004_ooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooooooo`;oX23`
1Oooool2oj0Pl0;ooooo0_nP8?001OooooooX23`oj0Pl?nP8?3ooooo00CoX23`0_ooO`000onP8?3o
ooooooooo`0;ooooo`;oX23`0_ooO`06ooooo`;oX23`0oooool4oomo00;ooooo0_ooO`05ooooo`;o
ogl000?ooooooj0Pl?ooO`001oooO`000oooooooX23`oj0Pl003ooooo`;oogl00_ooool00onP8?3o
ogl0oomo0005oomo0004oooooonP8?3oX23`oomo00;ooooo0_nP8?02ooooo`?oogl000?ooooooomo
0?ooO`000_nP8?02ooooo`;oX23`1?ooool3oj0Pl005oooooonP8?3oX23`ooooool000000onP8?02
oooooaKoX23`8oooool00ol0003oooooooooo`0Gooooo`004_ooool00ol0003oooooooooo`0Xoooo
o`CoX23`00?ooooooj0Pl?nP8?000_ooool2oj0Pl0Wooooo0_nP8?001OooooooX23`oj0Pl?nP8?3o
ogl000GoX23`0_ooO`0?ooooo`;oogl01_ooool2oj0Pl0?ooooo0_ooO`05ooooo`;oogl00_ooool2
oomo00;ooooo0_nP8?06ooooo`;oogl000?oX23`ooooooooool00oooO`001?nP8?3oogl0oomo0?oo
ool2oomo0003ooooooooO`3oogl000?oogl000Gooooooj0Pl?nP8?3oX23`oomo0002ooooo`;oogl0
00GoX23`oomo0?ooO`3oogl0ooooo`02oomo00;ooooo0_ooO`07ooooo`Coogl00_nP8?000ol0003o
X23`oj0Pl00;oj0Pl0Gooooo0onP8?000oooooooX23`oj0Pl005oj0Pl2;ooooo00?o0000oooooooo
ool05_ooool001;ooooo00?o0000ooooooooool0:?ooool4oj0Pl004oooooonP8?3oX23`o`0000go
oooo0_nP8?03ooooo`?oogl00_nP8?03oomo00;oX23`00?ooooooj0Pl?nP8?003Oooool2oj0Pl0?o
oooo0_nP8?06ooooo`;oogl00_ooool2oomo00;ooooo0_ooO`02ooooo`;oX23`00Cooooooomo0?nP
8?3oX23`0_ooool01OooO`3oX23`oj0Pl?ooO`3ooooo00?oogl000CoX23`oomo0?ooO`3ooooo0_oo
O`02ooooo`;oX23`00Coogl0oooooooooooooooo0_nP8?000oooO`3oooooooooo`02oomo0003oj0P
l?ooO`3oogl000;ooooo0_ooO`02ooooo`?oogl01_ooool4oomo00;oX23`00?o0000oooooonP8?00
1OnP8?02ooooo`CoX23`00?ooooooj0Pl?nP8?000_ooool7oj0Pl0;ooooo0_nP8?0Rooooo`03o`00
0?oooooooooo01Kooooo000Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02_oo
ool2oj0Pl0;ooooo0_nP8?001?ooO`3oX23`oj0Pl?ooool2oomo0003oooooonP8?3oogl000?oogl0
00?ooooooomo0?ooO`002_ooool2oj0Pl0?oogl00_nP8?06ooooo`;oogl02?ooool2oomo00?ooooo
00?oogl0oj0Pl?nP8?000oooool2oj0Pl003oomo0?oooooooooo00;oogl000Cooooooomo0?ooO`3o
X23`0_ooO`03oj0Pl0;oogl01?ooool2oomo00?ooooo00GoX23`oomo0?ooO`3oogl0oj0Pl006oooo
o`;oogl02Oooool2oj0Pl003ooooool0003oX23`00Gooooo1_nP8?02ooooo`CoX23`00?ooooooj0P
l?nP8?001?nP8?001?ooooooX23`oj0Pl?nP8?0Sooooo`03o`000?oooooooooo01Gooooo000Boooo
o`03o`000?oooooooooo033ooooo0_nP8?07ooooo`?oX23`00?ooooooj0Pl?nP8?000_ooool2oj0P
l004oooooonP8?3oX23`oomo00;ooooo1_ooO`000oooooooogl0oomo0002oomo00Cooooo0_nP8?04
ooooo`Coogl01?ooool2oomo00Wooooo1?ooO`02oj0Pl004ooooooooO`3oogl0oomo00Sooooo0_oo
O`001?ooooooogl0oomo0?nP8?02oomo00KoX23`0oooool2oomo00?ooooo00CoX23`oomo0?ooO`3o
ogl00onP8?001?ooooooogl0oomo0?ooool2oomo00?oX23`0oooool2oomo0006oooooonP8?3oX23`
ooooool0003oX23`0_ooO`02ooooo`OoX23`0oooool5oj0Pl003oooooonP8?3oX23`00?ooooo0onP
8?0Sooooo`03o`000?oooooooooo01Gooooo000Booooo`03o`000?oooooooooo02cooooo0_nP8?02
ooooo`;oX23`00?o0000ooooooooool01?ooool7oj0Pl003ooooooooO`3oogl000;ooooo0_ooO`02
ooooo`;oogl01oooool2oomo00Cooooo0_nP8?07ooooo`;oogl00oooool3oomo00;ooooo0_ooO`04
ooooo`;oogl00_ooool2oj0Pl0Soogl000?ooooooj0Pl?nP8?000oooool2oj0Pl004ooooooooO`3o
ogl0ooooo`;oogl01?nP8?000oooooooogl0oomo0003ooooo`;oogl00_ooool2oomo0004oooooonP
8?3oX23`oj0Pl0;oogl000?ooooooomo0?ooO`000onP8?03ooooo`;oogl000Kooooooj0Pl?nP8?3o
ooooo`000?nP8?03oomo00OoX23`1?ooool5oj0Pl0Oooooo0onP8?0Sooooo`03o`000?oooooooooo
01Cooooo000Aooooo`03o`000?oooooooooo02gooooo0_nP8?03ooooo`;oX23`00Co0000oooooonP
8?3oX23`0_ooool4oj0Pl003oooooonP8?3oX23`00?ooooo0_nP8?04ooooo`;oogl03_ooool2oomo
00Kooooo0_ooO`03ooooo`;oX23`00?oogl0ooooooooool00_ooO`0:ooooo`;oogl00_ooool4oomo
0003oooooonP8?3oX23`00?ooooo0_nP8?001?ooooooogl0oomo0?nP8?02oomo00CoX23`00Cooooo
oomo0?ooO`3ooooo0_nP8?02oomo00;ooooo0_ooO`02ooooo`;oX23`00Cooooooj0Pl?nP8?3oogl0
0onP8?000oooooooX23`oj0Pl004ooooo`?oX23`00?o0000oomo0?ooool00_ooO`02oj0Pl003oooo
oonP8?3oX23`00_oX23`1?ooool2oj0Pl003oooooonP8?3oX23`00?oX23`8?ooool3o`0001Gooooo
000Aooooo`03o`000?oooooooooo03;ooooo0_nP8?001Ooooooo0000oj0Pl?nP8?3ooooo00?oX23`
00?ooooooj0Pl?nP8?000_nP8?03ooooo`;oX23`0_ooO`05ooooo`;oX23`2oooool2oomo00;ooooo
0_nP8?07ooooo`;oX23`1Oooool2oomo00;oX23`0_ooO`03ooooo`;oogl00oooool2oj0Pl0;ooooo
0_ooO`03ooooo`Coogl000?ooooooj0Pl?nP8?000_nP8?03oomo0005oj0Pl?ooooooX23`oj0Pl?oo
ool00_nP8?04ooooo`;oogl00oooool2oj0Pl0;oogl00_nP8?03ooooo`;oX23`0_ooool2oomo00?o
X23`00Co0000oj0Pl?nP8?3oX23`1?ooool?oj0Pl0;ooooo0_nP8?03ooooo`?oX23`1?ooool2oj0P
l1Oooooo0ol00002ooooo`03o`000?oooooooooo01?ooooo000Aooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool00_nP8?000oooooooX23`oj0Pl005oj0Pl0?ooooo0_ooO`05ooooo`;o
X23`0_ooool2oj0Pl0_ooooo0_nP8?08ooooo`?oogl00oooool2oomo00;oX23`0_ooO`000ooooooo
ogl0oomo0002oj0Pl003ooooooooO`3oogl000;oX23`0_ooool2oomo00?ooooo1?ooO`03ooooo`;o
X23`0oooO`05ooooo`;oX23`2Oooool2oj0Pl0;oogl01_nP8?02oomo0003ooooooooO`3oogl000;o
oooo00?oX23`o`000?ooO`000onP8?05ooooo`;oX23`1?ooool01OooO`3oX23`oj0Pl?nP8?3ooooo
00;oX23`2?ooool2oj0Pl0Cooooo0_nP8?0Dooooo`?o00001Oooool00ol0003oooooooooo`0Coooo
o`004Oooool00ol0003oooooooooo`0gooooo`05o`000?ooooooX23`oj0Pl?ooool00_nP8?03oooo
o`?oX23`3Oooool2oj0Pl1Gooooo0oooO`0:ooooo`;oogl00_nP8?000oooooooogl0oomo0002oomo
0003ooooooooO`3oogl000Kooooo0_nP8?03ooooo`;oogl00onP8?05ooooo`;oX23`0_ooO`05oooo
o`;oX23`1Oooool5oj0Pl0;oogl01Oooool00onP8?3o0000oomo0003oj0Pl0;oogl02Oooool2oomo
00;oX23`2oooool3oj0Pl1Kooooo0ol00008ooooo`03o`000?oooooooooo01?ooooo000Aooooo`03
o`000?oooooooooo03Kooooo0_nP8?001?l0003oX23`oj0Pl?ooool2oj0Pl0?ooooo1_nP8?02oooo
o`;oogl00_nP8?0Mooooo`;oX23`1?ooool2oomo00Cooooo0_ooO`000oooooooX23`oomo0003oomo
0003ooooooooO`3oogl000Kooooo0_nP8?05ooooo`;oX23`2?ooool2oomo00Gooooo0_nP8?05oooo
o`;oX23`00Cooooooj0Pl?nP8?3ooooo0onP8?03ooooo`04oj0Pl?l0003oX23`oj0Pl0;ooooo0_oo
O`03ooooo`;oX23`0_ooO`0>ooooo`;oX23`0_ooool2oj0Pl1?ooooo0ol0000;ooooo`03o`000?oo
oooooooo01?ooooo000Aooooo`03o`000?oooooooooo03Kooooo1?nP8?02ooooo`CoX23`00?ooooo
oj0Pl?nP8?001?nP8?02ooooo`;oogl00_nP8?0:ooooo`;oogl04Oooool2oj0Pl0Cooooo0_ooO`03
ooooo`;oogl00_ooool2oj0Pl003ooooooooO`3oogl000;ooooo0_ooO`04ooooo`;oogl01oooool2
oomo0003oj0Pl?ooooooogl000;oX23`1?ooool00oooO`3oX23`oj0Pl00<ooooo`KoX23`0oooool0
0onP8?3o0000ooooo`08ooooo`;oX23`0_ooO`05ooooo`Coogl00oooool4oj0Pl0;ooooo0_nP8?0@
ooooo`?o00003oooool00ol0003oooooooooo`0Booooo`004Oooool00ol0003oooooooooo`0hoooo
o`CoX23`0_ooool2oj0Pl003oooooonP8?3oX23`00;oX23`00Cooooooj0Pl?ooO`3oogl01?ooool2
oj0Pl003oooooonP8?3oX23`00Gooooo0_ooO`0>ooooo`;oX23`1_ooool2oomo00;ooooo1?ooO`03
ooooo`;oogl00_ooool01?nP8?3oogl0oj0Pl?nP8?04ooooo`;oogl01oooool5oomo00;oX23`0_oo
ool3oomo00?oX23`0_ooool2oomo00Kooooo0_ooO`03oj0Pl0Gooooo00CoX23`o`000?nP8?3oX23`
1_ooool2oj0Pl0Oooooo0_nP8?03oomo00?ooooo0_nP8?04ooooo`;oX23`3Oooool3o`0001;ooooo
00?o0000ooooooooool04_ooool0013ooooo00?o0000ooooooooool0>oooool2oj0Pl0Oooooo0_nP
8?001?ooooooX23`oomo0?ooO`04ooooo`;oX23`00?ooooooj0Pl?nP8?005Oooool2oj0Pl0?ooooo
0_ooO`001?ooooooogl0oomo0?ooool3oomo00;ooooo0_ooO`000oooooooogl0oomo0002ooooo`04
oj0Pl?ooO`3oogl0oomo00;ooooo0_ooO`08ooooo`;oogl000?ooooooomo0?ooO`000oooO`02oj0P
l0Coogl00_nP8?04oomo0003oj0Pl?oooooooooo00?ooooo0_ooO`03oj0Pl0Kooooo00?o0000oj0P
l?nP8?001_ooool5oj0Pl0Cooooo0_nP8?0Hooooo`?o00005Oooool00ol0003oooooooooo`0Boooo
o`004?ooool00ol0003oooooooooo`0mooooo`04o`000?ooooooooooooooo`;oX23`00Cooooooj0P
l?nP8?3ooooo0onP8?0;ooooo`;oX23`00Cooooooj0Pl?ooO`3oogl04_ooool2oomo00?ooooo0ooo
O`03ooooo`;oogl01oooool2oomo00;ooooo1?ooO`06ooooo`;oogl00_ooool4oomo00?oX23`0ooo
O`001OooooooX23`oomo0?ooO`3ooooo00;oX23`2?ooool2oj0Pl0Oooooo00?o0000oj0Pl?nP8?00
1_ooool4oj0Pl0Cooooo0_nP8?000oooooooX23`oj0Pl00=ooooo`;oX23`0oooool3o`0001Sooooo
00?o0000ooooooooool04_ooool0013ooooo00?o0000ooooooooool0??ooool2oj0Pl003o`000?nP
8?3oX23`00;oX23`00Cooooooj0Pl?nP8?3ooooo0onP8?09ooooo`CoX23`00Cooooooj0Pl?ooO`3o
ogl00_ooool2oomo00_ooooo0_nP8?06ooooo`;oogl02oooool2oomo00;ooooo0_ooO`02ooooo`;o
ogl00_ooool2oj0Pl0?ooooo0_nP8?001?ooooooogl0oomo0?ooool2oomo00;oX23`00?oogl0oooo
ooooool00_ooool2oomo00Kooooo0_ooO`08ooooo`;oX23`00?ooooooj0Pl?l000000_nP8?000ooo
ooooX23`oj0Pl002oj0Pl0?ooooo0_nP8?04ooooo`;oogl000?ooooooj0Pl?nP8?003Oooool2oj0P
l0?o00006oooool00ol0003oooooooooo`0Booooo`004?ooool00ol0003oooooooooo`0kooooo`?o
X23`00?ooooooj0Pl?nP8?000_nP8?0:ooooo`;oogl01?ooool2oj0Pl0Gooooo0_nP8?000ooooooo
ogl0oomo000;ooooo`;oX23`00?oogl0ooooooooool00oooool2oj0Pl003ooooooooO`3oogl000Co
oooo0_nP8?02ooooo`;oogl000?ooooooomo0?ooO`000oooO`001?ooooooogl0oomo0?ooool4oj0P
l004oooooonP8?3oX23`ooooo`;oogl000Cooooooomo0?ooO`3oogl01Oooool2oomo0003oooooonP
8?3oX23`00Cooooo0_ooO`08ooooo`;oX23`00Gooooooj0Pl?l0003oX23`ooooo`06oj0Pl0;oogl0
0oooool2oj0Pl003ooooooooO`3oogl000Kooooo00?oogl0oj0Pl?nP8?001_ooool3o`0001kooooo
00?o0000ooooooooool04_ooool0013ooooo00?o0000ooooooooool0>oooool2oj0Pl0?ooooo00?o
0000oj0Pl?nP8?001Oooool2oj0Pl0?ooooo0_ooO`0;ooooo`;oX23`0_ooool2oomo0003oj0Pl?oo
oooooooo00Gooooo0_ooO`000oooooooogl0oomo0008ooooo`;oogl01?ooool2oj0Pl0Gooooo00?o
ogl0oj0Pl?nP8?001OooO`02ooooo`?oogl000?ooooooomo0?ooO`002Oooool2oomo0004oooooooo
O`3oogl0ooooo`CoX23`3Oooool2oj0Pl004ooooool0003oX23`ooooo`;oX23`0_ooool2oj0Pl0;o
ogl000?ooooooj0Pl?nP8?000_nP8?03ooooo`;oogl01?ooool01?ooO`3oX23`oj0Pl?ooool2oj0P
l0?o00008Oooool00ol0003oooooooooo`0Booooo`004?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo00Cooooo0_nP8?02ooooo`;oX23`00?ooooooj0Pl?nP8?001Oooool3oj0Pl0Co
oooo0_nP8?001?ooO`3oX23`ooooooooool2oomo00?ooooo0_ooO`0Dooooo`?oogl00_ooool2oj0P
l0;ooooo0_ooO`04ooooo`;oogl01_ooool5oomo0004ooooooooO`3oogl0oomo00Gooooo0_nP8?00
0oooooooX23`oj0Pl002oj0Pl0;ooooo0_ooO`001?ooooooogl0oomo0?ooool2oj0Pl003ooooool0
003oX23`00Wooooo0_nP8?02oomo0003oj0Pl?ooO`3oogl000;oX23`00Coogl0oooooooooooooooo
0_ooO`02ooooo`03o`000?nP8?3oX23`02Gooooo00?o0000ooooooooool04Oooool000oooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`07ooooo`;oX23`00Gooooooj0Pl?nP8?3oX23`
ooooo`07oj0Pl003oooooonP8?3oX23`00;oX23`1?ooool2oomo00Oooooo0_nP8?0:ooooo`;oogl0
1?ooool3oomo00[ooooo0oooO`07ooooo`Googl00_ooool2oomo0003oooooonP8?3oX23`00Gooooo
1OnP8?000oooooooogl0oomo0003oomo00;oX23`0_ooool00ol0003oX23`ooooo`02oj0Pl0Kooooo
0_nP8?02oomo0003oj0Pl?ooO`3oogl000;oX23`1?ooool4oomo00Kooooo0_nP8?0Pooooo`03o`00
0?oooooooooo017ooooo000?ooooo`03o`000?oooooooooo04?ooooo0_nP8?0<ooooo`;oX23`00Co
oooooj0Pl?nP8?3oX23`0_ooool2oj0Pl003oooooonP8?3oX23`00;oogl01_ooool2oomo00Gooooo
0_nP8?03ooooo`03oomo0?nP8?3oX23`00Cooooo0_ooO`02ooooo`;oX23`00?ooooooomo0?ooO`00
1?ooool2oomo00Cooooo0oooO`02ooooo`;oX23`00?ooooooj0Pl?nP8?000_ooool2oomo00Kooooo
0_nP8?08ooooo`;oX23`00Cooooooj0Pl?ooO`3oogl00_ooool4oj0Pl005o`000?ooooooogl0oomo
0?nP8?002Oooool2oomo00Gooooo0_nP8?000ol0003oogl0oomo0002oomo00Kooooo0_nP8?0Poooo
o`03o`000?oooooooooo017ooooo000?ooooo`03o`000?oooooooooo04?ooooo0_nP8?000ol0003o
X23`oj0Pl009ooooo`;oX23`4oooool2oomo0003oooooonP8?3oX23`00Oooooo00?oogl0oj0Pl?nP
8?002?ooool2oj0Pl0?oogl000Cooooooomo0?ooO`3ooooo0oooO`08ooooo`;oX23`00?ooooooj0P
l?nP8?003?ooool2oomo00Gooooo0_ooO`04ooooo`;oX23`0oooool2oj0Pl004o`000?ooooooogl0
oomo00Cooooo0_ooO`04ooooo`;oogl00oooool2o`0000;oX23`00Cooooooomo0?ooO`3oogl01Ooo
ool2oomo00?ooooo0_nP8?0Mooooo`03o`000?oooooooooo017ooooo000?ooooo`03o`000?oooooo
oooo04Kooooo0_nP8?0Booooo`;oogl000CoX23`oooooonP8?3oX23`1_ooool2oomo0004oooooonP
8?3oX23`ooooo`;oogl00_ooool2oomo00Oooooo0_nP8?04ooooo`;oogl00_ooool2oomo0004oooo
ooooO`3oogl0oomo00Cooooo0_nP8?05ooooo`;oX23`00?ooooooomo0?ooO`000_ooO`000ooooooo
ogl0oomo0002oomo00;ooooo0_ooO`05ooooo`;oogl01?ooool3oj0Pl006oooooonP8?3oX23`oj0P
l?l0003ooooo0_nP8?001?ooO`3oooooooooooooool2oomo00?ooooo0_ooO`02o`0000;oX23`00Co
oooooomo0?ooO`3oogl02Oooool2oomo00?ooooo0_nP8?0Mooooo`03o`000?oooooooooo017ooooo
000?ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01Oooool2oj0Pl0[ooooo0onP
8?000oooooooX23`oj0Pl006ooooo`;oX23`00Cooooooj0Pl?nP8?3ooooo0_ooO`02ooooo`;oogl0
1oooool2oj0Pl0;oogl00_nP8?05ooooo`;oogl00oooool2oj0Pl004oomo0?ooooooX23`oj0Pl0Go
oooo0_nP8?000oooooooogl0oomo0002oomo0003ooooooooO`3oogl000;oogl00_ooool2oomo0003
oj0Pl?oooooooooo00Wooooo0_nP8?001_ooooooX23`oj0Pl?nP8?3o0000ooooo`;oX23`0_ooO`06
ooooo`03oj0Pl?ooO`3oogl000KoX23`0_ooO`0>ooooo`;oogl07Oooool00ol0003oooooooooo`0A
ooooo`003oooool00ol0003oooooooooo`17ooooo`04o`000?ooooooX23`oj0Pl0?ooooo0_nP8?0:
ooooo`CoX23`00?oogl0oj0Pl?nP8?000_nP8?000oooooooogl0oomo0002oj0Pl004oooooonP8?3o
X23`oomo00oooooo0_ooO`02oj0Pl0Cooooo0oooO`03ooooo`;oX23`1?ooO`04ooooo`;oogl01_oo
ool00oooO`3oX23`oj0Pl002oomo0005ooooooooO`3oogl0oomo0?nP8?000_ooO`02oj0Pl0Sooooo
0_nP8?03ooooo`04o`000?ooO`3ooooooj0Pl0;oogl00oooool3o`000003oj0Pl?ooO`3oogl000?o
X23`00?ooooooj0Pl?nP8?00;oooool00ol0003oooooooooo`0Aooooo`003oooool00ol0003ooooo
ooooo`18ooooo`?oX23`2oooool2oj0Pl0Cooooo0_nP8?001?ooO`3oX23`oj0Pl?ooO`02oj0Pl0So
ogl000?ooooooomo0?ooO`005?ooool2oomo00;oX23`00Coogl0oooooooooooooooo1OooO`02oooo
o`?oogl01_ooool00oooO`3oX23`oj0Pl009oomo00;oX23`2?ooool2oj0Pl0?ooooo00?o0000oomo
0?nP8?000oooool3o`0000kooooo0_ooO`0/ooooo`03o`000?oooooooooo013ooooo000>ooooo`03
o`000?oooooooooo04Wooooo1?nP8?0:ooooo`;oX23`0oooool2oj0Pl0;ooooo0_nP8?001OooO`3o
X23`oj0Pl?nP8?3ooooo00Coogl00oooool2oomo00_ooooo0_ooO`03ooooo`;oX23`1?ooool2oj0P
l003oomo0?ooooooogl000;oogl00_nP8?08oomo00Oooooo1OooO`000oooooooogl0oomo0006oooo
o`;oX23`00?oogl0ooooooooool01_ooool01?l0003oX23`oj0Pl?l00002oomo00Kooooo0_ooO`05
ooooo`;oogl00_ooool01?ooO`3oX23`oj0Pl?ooool4oomo00[ooooo0_nP8?0Jooooo`03o`000?oo
oooooooo013ooooo000>ooooo`03o`000?oooooooooo04[ooooo0onP8?0:ooooo`;oX23`0oooool6
oj0Pl004oooooonP8?3oX23`oj0Pl0?ooooo0onP8?05ooooo`;oX23`2?ooool2oomo00;ooooo00?o
ogl0oj0Pl?nP8?001Oooool2oomo0004ooooooooO`3oogl0oomo00;oX23`0_ooool6oomo0003oooo
ooooO`3oogl000Cooooo1?ooO`02ooooo`;oogl01_ooool2oj0Pl003oomo0?oooooooooo00;ooooo
0_ooO`02ooooo`04o`000?nP8?3o0000ooooo`;oogl01Oooool2oj0Pl003oomo0?oooooooooo00?o
oooo0_ooO`03ooooo`;oX23`00?ooooooj0Pl?nP8?000_ooO`0:ooooo`;oX23`6_ooool00ol0003o
ooooooooo`0@ooooo`003_ooool00ol0003oooooooooo`1:ooooo`;oX23`00?o0000ooooooooool0
0_nP8?06ooooo`;oX23`1Oooool2oj0Pl0?ooooo0_nP8?05ooooo`?oX23`1?ooool2oj0Pl0cooooo
0_ooO`06ooooo`?oogl01_ooool2oomo00;oX23`00?oogl0ooooooooO`001OooO`02oj0Pl004oooo
ooooO`3oogl0oomo00;ooooo0_ooO`08ooooo`Koogl00_nP8?02o`000003oj0Pl?ooO`3ooooo00;o
X23`1Oooool2oj0Pl0Wooooo0_ooO`000oooooooogl0oomo0002oj0Pl0;oogl01?ooool3oomo00;o
X23`7Oooool00ol0003oooooooooo`0@ooooo`003_ooool00ol0003oooooooooo`1=ooooo`04o`00
0?ooooooX23`oj0Pl1?ooooo0_nP8?000oooooooogl0oomo0002ooooo`;oX23`3_ooool2oomo00Ko
oooo0_nP8?02oomo0004ooooooooO`3oogl0oomo00Gooooo0_ooO`02oj0Pl0;ooooo1_ooO`001?nP
8?3oogl0oomo0?ooool2oomo00cooooo1_ooO`02oj0Pl005ooooool0003oogl0oomo0?ooool00_nP
8?0@ooooo`;oogl000?ooooooomo0?ooO`000_ooool2oomo00?ooooo1?ooO`02oj0Pl003oooooonP
8?3oX23`01[ooooo00?o0000ooooooooool04?ooool000kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0;ooooo`;oX23`0_ooool2oj0Pl0;ooooo0_nP8?000oooooooogl0oomo000:
ooooo`;oX23`1_ooool2oomo00Kooooo0_nP8?02oomo00;ooooo0_ooO`000oooooooogl0oomo0003
ooooo`;oX23`2Oooool01?nP8?3oogl0oomo0?ooO`0<ooooo`;oogl00ol000000oooooooX23`oj0P
l003oj0Pl004o`000?nP8?3oooooooooo`;oogl00oooool2oj0Pl003oooooonP8?3oX23`00Sooooo
0_ooO`03ooooo`?oogl01?ooool2oomo00Gooooo0_nP8?0Jooooo`03o`000?oooooooooo013ooooo
000>ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool02_ooool2oj0Pl0;ooooo0_nP
8?08ooooo`;oogl00oooool2oj0Pl0;ooooo0_nP8?02ooooo`;oogl01oooool2oomo00[ooooo0_oo
O`02ooooo`;oogl000?oX23`ooooooooool01OooO`000oooooooogl0oomo0004oomo00[ooooo00?o
0000oomo0?ooO`000_nP8?03ooooo`GoX23`00?o0000oomo0?ooool00_ooO`000onP8?3ooooooomo
0002oj0Pl003oooooonP8?3oX23`00Cooooo0_nP8?02ooooo`?oogl00_ooool3oomo00?ooooo0ooo
O`04ooooo`;oogl06oooool00ol0003oooooooooo`0@ooooo`003Oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo01Oooooo0_ooO`03ooooo`;oX23`0_ooool2oomo00;ooooo0_ooO`07
ooooo`;oogl01_ooool2oj0Pl0Kooooo0_ooO`000onP8?3ooooooomo0005oomo0003ooooooooO`3o
ogl000Coogl01Oooool2oj0Pl0?o00000oooool2oj0Pl0Sooooo00Co0000oj0Pl?oooooooooo0_nP
8?000oooooooogl0oomo0008ooooo`;oX23`0_ooool3oomo00?ooooo1?ooO`001?ooooooogl0oomo
0?ooO`04ooooo`;oogl000?ooooooomo0?ooO`000oooool2oomo01Cooooo00?o0000ooooooooool0
3oooool000gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0=ooooo`;oX23`1ooo
ool3oj0Pl0Kooooo0_ooO`0Cooooo`;oX23`1_ooool3oj0Pl004ooooooooO`3oX23`oj0Pl0;oogl0
00CoX23`oomo0?oooooooooo2OooO`02oj0Pl0;ooooo00?oX23`oomo0?ooO`002oooool00ol0003o
X23`ooooo`04ooooo`;oX23`0_ooool4oomo00cooooo1?ooO`03ooooo`;oogl00oooool4oomo00;o
X23`0_ooool2oomo01Cooooo00?o0000ooooooooool03oooool000gooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`0<ooooo`CoX23`00?ooooooj0Pl?nP8?000_ooool3oj0Pl0Cooooo
0_nP8?0Booooo`;oogl000?ooooooj0Pl?nP8?001oooool2oomo0004oooooonP8?3oX23`ooooo`;o
ogl000?oX23`oomo0?ooO`000oooool5oomo00;oX23`0_ooO`02ooooo`03oj0Pl?ooO`3oogl000_o
oooo00Co0000oooooooooooooooo0_nP8?000oooooooX23`oj0Pl002oj0Pl0Coogl02oooool2oomo
00Cooooo0oooO`02oj0Pl0;ooooo1?ooO`02oj0Pl1Sooooo00?o0000ooooooooool03oooool000go
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`GoX23`2Oooool2oj0Pl0Ko
oooo0_nP8?0:ooooo`;oogl00oooool2oomo00Gooooo0_ooO`000oooooooX23`oj0Pl003oomo00;o
X23`0oooO`001?ooooooogl0oomo0?ooO`02ooooo`;oX23`0_ooO`02oj0Pl003oooooonP8?3oX23`
00Oooooo0_ooO`02ooooo`04o`000?ooooooooooooooo`;oX23`0oooool2oj0Pl0;oogl03Oooool2
oomo00;ooooo0_nP8?02oomo0003oooooonP8?3oX23`00;oX23`00?ooooooomo0?ooO`000oooO`02
ooooo`;oogl05?ooool00ol0003oooooooooo`0?ooooo`003Oooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo00Kooooo0_nP8?05ooooo`;oX23`2Oooool2oj0Pl0Sooooo0_nP8?0?oooo
o`;oogl01?ooool2oomo00?ooooo1?ooO`000onP8?3oogl0oomo0006oomo00Kooooo0_ooO`04oooo
o`Coogl00_ooool2oomo00;ooooo00?o0000ooooooooool00_ooO`06ooooo`;oogl04Oooool2oj0P
l0?ooooo0_ooO`02oj0Pl003ooooooooO`3oogl000?oogl00_ooool2oomo01Cooooo00?o0000oooo
ooooool03oooool000gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`05ooooo`;o
X23`4?ooool2oj0Pl0Wooooo0_nP8?0=ooooo`?oogl00_ooool4oomo0003ooooooooO`3oogl000;o
oooo0_ooO`001?l0003oogl0oomo0?ooool3oomo0004ooooooooO`3oogl0ooooo`Koogl01?ooool4
oomo00?ooooo0_nP8?001?ooO`3o0000ooooooooool2oomo0003ooooooooO`3oogl001kooooo1?oo
O`001?ooooooogl0oj0Pl?nP8?0Gooooo`03o`000?oooooooooo00oooooo000<ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool08Oooool2oj0Pl0cooooo0_nP8?06oomo0003oooooooo
O`3oogl000;oogl01?l00004ooooo`;oogl00_ooool7oomo0004oooooonP8?3oogl0oomo00;ooooo
0_ooO`05ooooo`;oX23`00?oogl0o`000?ooool01?ooool2oomo00Gooooo0_nP8?0?ooooo`;oogl0
1_ooool3oomo00;ooooo00Coogl0oj0Pl?nP8?3ooooo0oooO`02oj0Pl17ooooo00?o0000oooooooo
ool03oooool000cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Dooooo`;oX23`
00Cooooooj0Pl?nP8?3ooooo0_ooO`02ooooo`CoX23`00Cooooooomo0?ooO`3ooooo1_ooO`02oooo
o`;oX23`0_ooool3oomo00;oX23`0_ooO`02o`0000[ooooo0_ooO`000oooooooogl0oomo0005oooo
o`04oj0Pl?ooO`3oogl0ooooo`;oogl000?ooooooomo0?ooO`001Oooool00oooO`3o0000ooooo`09
ooooo`;oogl00_nP8?07ooooo`;oogl01_ooool2oomo00Oooooo0_ooO`02ooooo`;oX23`00?oogl0
ooooooooO`000_ooO`02oj0Pl17ooooo00?o0000ooooooooool03oooool000cooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0Cooooo`;oX23`00Cooooooj0Pl?nP8?3oX23`0_ooO`02
ooooo`;oX23`00?ooooooj0Pl?nP8?000_ooO`000oooooooogl0oomo0004oomo0003ooooooooO`3o
ogl000Kooooo0_nP8?000oooO`3oooooooooo`07ooooo`;oogl00_ooool2oomo00;ooooo0_ooO`03
ooooo`Coogl000Cooooooomo0?ooO`3ooooo0_ooO`06ooooo`03o`000?oooooooooo00?ooooo0_nP
8?03ooooo`;oogl02Oooool3oomo00Wooooo0_ooO`02ooooo`?oogl000?ooooooomo0?nP8?000onP
8?000oooooooogl0oomo000Dooooo`03o`000?oooooooooo00kooooo000<ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool05?ooool6oj0Pl0Gooooo0_nP8?08ooooo`?oogl00_nP8?03
oomo00;o000000Cooooooomo0?ooO`3ooooo0oooO`03ooooo`;oX23`0_ooO`02ooooo`;oogl00_oo
ool2oomo0003ooooooooO`3oogl000Coogl01oooool2oomo00?ooooo00?o0000ooooooooool00ooo
ool2oj0Pl0Wooooo0_ooO`02ooooo`;oX23`0_ooO`09ooooo`;oogl00_ooool3oomo0004oooooooo
O`3oogl0ooooo`;oX23`00Cooooooomo0?ooO`3oogl04oooool00ol0003oooooooooo`0>ooooo`00
3?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00cooooo0_nP8?05ooooo`;oX23`
0_ooool2oj0Pl0;ooooo0oooO`0:ooooo`?oogl00_nP8?05oomo00Cooooo0oooO`02ooooo`03oomo
0?nP8?3oX23`00?oogl01Oooool8oomo00Sooooo0_ooO`03ooooo`03o`000?oooooooooo00kooooo
0_ooO`02ooooo`;oX23`4_ooool6oomo00;ooooo0_ooO`03ooooo`;oX23`3_ooool00ol0003ooooo
ooooo`0>ooooo`003?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00_ooooo0_nP
8?0;ooooo`;oX23`0oooO`03ooooo`;oogl00_nP8?02oomo00;ooooo1?ooO`03ooooo`;oogl000?o
oooooomo0?ooO`000_ooool2oj0Pl0;ooooo0_ooO`001?ooooooogl0oomo0?ooO`05ooooo`Koogl0
1?ooool2oj0Pl0Wooooo00Go0000oj0Pl?nP8?3oX23`ooooo`02oomo00;oX23`3oooool2oomo00oo
oooo1_ooO`07ooooo`;oX23`3_ooool00ol0003oooooooooo`0>ooooo`003?ooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo00_ooooo0_nP8?06ooooo`;oogl00_ooool2oj0Pl0Kooooo
0_ooO`02oj0Pl0;oogl00_l00002oomo0003ooooooooO`3oogl000?ooooo0_nP8?02oomo00Wooooo
1?ooO`000oooooooogl0oomo0002ooooo`;oogl01oooool2oj0Pl0Wooooo00Go0000oj0Pl?nP8?3o
X23`ooooo`02oomo00;oX23`3oooool2oomo0003oj0Pl?oooooooooo00Gooooo0_ooO`05ooooo`Ko
ogl00_nP8?02ooooo`;oogl000?ooooooj0Pl?nP8?000_nP8?0<ooooo`03o`000?oooooooooo00ko
oooo000;ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool02_ooool2oj0Pl0Kooooo
0_ooO`0;ooooo`?oX23`00Ko0000oooooonP8?3oX23`oooooonP8?03oomo0003ooooooooO`3oogl0
00;oX23`0_ooO`09ooooo`Coogl000?ooooooomo0?ooO`002oooool2oj0Pl0;oogl01oooool00ol0
003oooooooooo`05ooooo`;oX23`3oooool2oj0Pl003oooooonP8?3oX23`00Cooooo1?ooO`03oooo
o`Coogl00_ooool2oj0Pl004ooooooooO`3oogl0oomo00?ooooo0_nP8?0<ooooo`03o`000?oooooo
oooo00kooooo000;ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool06_ooool2oj0P
l003o`000?nP8?3oX23`00;oX23`0_ooool2oj0Pl0Coogl00_ooool2oomo0004ooooooooO`3oogl0
oomo00Kooooo0_ooO`000oooooooogl0oomo0007ooooo`;oX23`0_ooool2oomo00?ooooo0_nP8?04
oomo00Gooooo00?o0000ooooooooool01Oooool2oj0Pl004oomo0?ooooooogl0oomo00Wooooo0_oo
O`03ooooo`;oX23`1Oooool3oomo00Kooooo0_ooO`001?ooooooogl0oj0Pl?nP8?02oomo01;ooooo
00?o0000ooooooooool03_ooool000_ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0Gooooo`CoX23`00?ooooooj0Pl?nP8?000oooool2oj0Pl004ooooooooO`3oogl0ooooo`;oX23`
0oooO`001?ooooooogl0oomo0?ooO`02ooooo`;oX23`0_ooool6oomo00;ooooo0_ooO`02ooooo`;o
X23`0_ooool2oomo00Oooooo1?ooO`03ooooo`03o`000?oooooooooo00Kooooo0_ooO`000ooooooo
ogl0oomo0009ooooo`;oogl02_ooool2oomo00Kooooo0_nP8?000oooO`3ooooooomo0002oj0Pl003
oomo0?oooooooooo01;ooooo00?o0000ooooooooool03Oooool000_ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0@ooooo`;oX23`0_ooool01?l0003oogl0oomo0?nP8?02oomo00?o
oooo0_nP8?001?ooooooX23`oj0Pl?ooool4oomo0003oj0Pl?ooO`3oogl000;ooooo0_ooO`02oj0P
l003oooooonP8?3oX23`00?ooooo0_ooO`000oooooooogl0oomo0004oomo00Gooooo0_nP8?03oooo
o`;oogl01Oooool2oomo00?ooooo00?oogl0o`000?ooool00_ooO`0Tooooo`;oogl00_nP8?03oooo
o`?oogl00_nP8?0Booooo`03o`000?oooooooooo00gooooo000;ooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool03oooool2oj0Pl0;o000000Cooooooomo0?ooO`3oX23`1?ooool4oj0P
l003ooooooooO`3oogl000Googl000?ooooooomo0?ooO`000oooO`03oj0Pl0Cooooo1?ooO`001?oo
ooooogl0oomo0?ooO`04ooooo`;oX23`00?ooooooj0Pl?nP8?000oooool2oomo00?ooooo0_nP8?05
ooooo`03oomo0?l0003ooooo00;oogl01?ooool2oj0Pl0Gooooo0_ooO`05ooooo`;oogl02oooool4
oomo0003ooooooooO`3oogl000Gooooo0oooO`02oj0Pl1;ooooo00?o0000ooooooooool03Oooool0
00_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0<ooooo`?o00000oooool2oj0P
l0Gooooo0oooO`02oj0Pl003ooooooooO`3oogl000;oogl00_nP8?0:oomo00Cooooo1?ooO`001?oo
ooooogl0oomo0?ooO`02ooooo`CoX23`0_ooO`09ooooo`;oX23`1_ooool00ol0003ooooooomo0002
oomo00?ooooo0_nP8?02oomo00?ooooo0_ooO`05ooooo`;oogl01_ooool2oomo00?ooooo1?ooO`04
ooooo`;oogl00_ooool3oomo00Kooooo0_nP8?000oooooooogl0oomo0009ooooo`03o`000?oooooo
oooo00gooooo000:ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02?ooool3o`00
00Kooooo0_nP8?05ooooo`?oogl00_ooool2oj0Pl003oooooonP8?3oX23`00;oX23`0oooO`001Ooo
ooooogl0oomo0?ooO`3ooooo00;oogl01_ooool4oomo00Cooooo1?nP8?04oomo0003oj0Pl?oooooo
oooo00?ooooo1OooO`04ooooo`03o`000?ooooooogl000;oogl01Oooool2oomo00;ooooo0oooO`0=
ooooo`Coogl02Oooool2oomo00;ooooo0_ooO`000oooooooogl0oomo0003oomo0004oooooonP8?3o
X23`ooooo`;oogl02Oooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`;oX23`0_ooool2oj0Pl0Gooooo1onP8?00
1?ooooooogl0oomo0?ooool3oomo00Wooooo1?ooO`06ooooo`;oX23`00Gooooooomo0?ooO`3oogl0
oj0Pl004ooooo`03oj0Pl?ooO`3oogl000?oogl01?ooool00ol0003oooooooooo`08ooooo`;oogl0
00?ooooooomo0?ooO`003_ooool4oomo00gooooo2OooO`02oj0Pl0cooooo00?o0000ooooooooool0
3Oooool000[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`03o`0000gooooo0_nP
8?02ooooo`;oX23`1Oooool2oomo00CoX23`1_ooO`000onP8?3oogl0ooooo`08ooooo`;oX23`2?oo
O`03ooooo`05oj0Pl?ooO`3oogl0oomo0?ooool00_ooO`000oooooooX23`oj0Pl005ooooo`;oX23`
00?oooooo`000?ooO`001oooool2oj0Pl0;oogl000Cooooooomo0?ooO`3ooooo0_ooO`0;ooooo`Co
ogl01Oooool2oomo00Gooooo1OooO`02oj0Pl003ooooooooO`3oogl000;oX23`0_ooool2oomo00So
oooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool0J_ooool2o`0001gooooo
0_ooO`02ooooo`Koogl000?oX23`oomo0?ooool00_ooool2oomo00Cooooo0onP8?000oooooooogl0
oomo0004oomo00?ooooo0_nP8?000oooO`3oX23`oj0Pl004oomo0003ooooooooO`3oogl000?ooooo
0_nP8?001?oooooo0000oomo0?ooO`05ooooo`03oomo0?nP8?3oX23`00?ooooo0_ooO`02oj0Pl0?o
ogl02oooool2oomo0003oj0Pl?oooooooooo00;ooooo0_ooO`05ooooo`;oogl00oooool2oj0Pl0Co
oooo0_ooO`000oooooooogl0oomo0009ooooo`03o`000?oooooooooo00cooooo000:ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool08_ooool3oomo0003oj0Pl?oooooooooo00?ooooo
0_ooO`02oj0Pl0Cooooo0_ooO`03ooooo`;oX23`1Oooool4oj0Pl0Ooogl000Cooooooomo0?ooO`3o
oooo0ol00002oomo00Gooooo0_ooO`02ooooo`KoX23`0oooO`05ooooo`;oogl01?ooool00oooO`3o
X23`oj0Pl00Fooooo`;oogl03?ooool00ol0003oooooooooo`0<ooooo`002_ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo01Sooooo0_nP8?08ooooo`;oogl00_ooool00onP8?3oogl0
oomo0003oomo0004oooooonP8?3oX23`oj0Pl0?ooooo0oooO`02ooooo`;oogl00_nP8?02oomo0003
oooooonP8?3oX23`00;ooooo0_nP8?001?ooooooogl0oomo0?ooO`02ooooo`?o00000_ooool00ol0
003oooooooooo`05ooooo`;oogl00_ooool2oj0Pl0;oogl000?oX23`ooooooooO`000_ooO`000ooo
ooooX23`oj0Pl002ooooo`Koogl01?ooool00oooO`3oX23`oj0Pl00Pooooo`03o`000?oooooooooo
00cooooo000:ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool06?ooool5oj0Pl0Go
oooo0_nP8?02ooooo`03oj0Pl?ooO`3oogl000?oogl000KoX23`oooooonP8?3oX23`oomo0?ooool4
oomo00;ooooo0_ooO`02oj0Pl0;oogl000?ooooooomo0?ooO`000_ooool2oj0Pl0?ooooo0ol00000
0oooooooogl0oomo0002ooooo`03oomo0?l0003ooooo00Cooooo1OooO`001Oooooooogl0oomo0?oo
O`3oX23`00;ooooo0_ooO`000oooooooX23`oj0Pl004ooooo`Koogl00_ooool00oooO`3oX23`oj0P
l005ooooo`;oogl01Oooool2oomo00Cooooo0_ooO`0<ooooo`03o`000?oooooooooo00cooooo0009
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool05Oooool4oj0Pl004oooooonP8?3o
X23`oj0Pl0Kooooo0_ooO`02ooooo`?oogl000?ooooooj0Pl?nP8?000_ooool5oomo00_ooooo0_oo
O`001?ooooooogl0oomo0?ooool3o`000004ooooooooO`3oogl0ooooo`;oX23`0_ooool2oomo0003
o`000?oooooooooo00;ooooo0_ooO`001?nP8?3oogl0oomo0?ooool4oomo00;oX23`00Cooooooj0P
l?nP8?3ooooo0_nP8?07ooooo`;oogl00_ooool2oomo00;ooooo0_nP8?000oooooooogl0oomo0002
oomo00Cooooo0oooO`03ooooo`;oogl03?ooool00ol0003oooooooooo`0<ooooo`002Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo01Gooooo1?nP8?05ooooo`;oX23`00?ooooooomo
0?ooO`000_ooO`02ooooo`?oogl00oooool6oomo00Cooooo0oooO`02ooooo`;oogl01?ooool3o`00
00Cooooo0_nP8?001?ooooooX23`oj0Pl?nP8?02oomo00;ooooo00Co0000oooooooooooooooo0_oo
O`03oj0Pl0?ooooo0_ooO`02oj0Pl004oooooonP8?3oX23`ooooo`;oX23`00?ooooooomo0?ooO`00
0_ooool2oomo00Sooooo0_nP8?000oooooooogl0oomo0002oomo00Gooooo0_ooO`0Aooooo`03o`00
0?oooooooooo00cooooo0009ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool07_oo
ool3oj0Pl0Coogl00_ooool5oomo0003ooooooooO`3oogl000;ooooo1?ooO`02ooooo`Ooogl01?l0
0002oomo00Gooooo0_nP8?03ooooo`04oj0Pl?ooO`3oogl0oomo00;ooooo00Co0000oomo0?ooO`3o
ogl00_ooool2oj0Pl003ooooooooO`3oogl000;oogl02Oooool2oomo00;ooooo0_ooO`05ooooo`;o
ogl000?ooooooj0Pl?nP8?002Oooool2oj0Pl0?oogl03oooool00ol0003oooooooooo`0<ooooo`00
2Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01kooooo0onP8?06ooooo`Soogl0
00?ooooooomo0?ooO`001_ooO`000oooooooogl0oomo0003o`000003oomo0?oooooooooo00Oooooo
0_ooO`06ooooo`?oogl000?oooooo`000?ooO`000_ooO`05ooooo`;oogl05_ooool2oomo0003oooo
oonP8?3oX23`00Wooooo0_nP8?03oomo00oooooo00?o0000ooooooooool03?ooool000Wooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`0Nooooo`?oX23`1_ooool2oomo00;oX23`3Ooo
O`03o`0000;ooooo0_ooO`06ooooo`;oogl000Cooooooomo0?ooO`3ooooo0_nP8?04ooooo`;oogl0
00?ooooooomo0?l000004Oooool2oj0Pl1Sooooo0_ooO`06ooooo`;oogl03Oooool00ol0003ooooo
ooooo`0;ooooo`002Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01kooooo0onP
8?0:ooooo`;oX23`0oooO`000oooooooogl0oomo0002oj0Pl0?o00000_nP8?02oomo00Wooooo0_oo
O`04ooooo`;oX23`1oooool2oomo0003o`000?oooooooooo00_ooooo0_ooO`000oooooooX23`oj0P
l00@ooooo`;oogl00oooool2oomo0003ooooooooO`3oogl000Kooooo0_ooO`0=ooooo`03o`000?oo
oooooooo00_ooooo0008ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool07oooool2
oj0Pl0Oooooo0_nP8?000oooooooX23`oj0Pl003oomo0003ooooooooO`3o000000;o00000oooO`02
oj0Pl0Coogl03_ooool2oomo00Wooooo00?o0000ooooooooool01_ooool2oomo00;ooooo0_ooO`0C
ooooo`;oogl00oooool2oomo00Gooooo00?oogl0oj0Pl?nP8?004?ooool00ol0003oooooooooo`0;
ooooo`002?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo02Sooooo0_nP8?001?oo
ooooogl0oomo0?ooO`04o`0000;ooooo2_ooO`02ooooo`;oogl02?ooool2oj0Pl0;oogl000?ooooo
oomo0?ooO`001oooool01?l0003ooooooj0Pl?nP8?04ooooo`;oogl08oooool00oooO`3oX23`oj0P
l00@ooooo`03o`000?oooooooooo00_ooooo0008ooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool0:oooool3o`0000Coogl000Cooooooomo0?ooO`3ooooo2?ooO`02ooooo`;oogl02?oo
ool2oj0Pl0Googl01_ooool2oomo0003o`000?nP8?3oX23`00;oogl07_ooool2oomo00Oooooo0_oo
O`0Aooooo`03o`000?oooooooooo00_ooooo0008ooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool08oooool2oj0Pl0?ooooo0ol000000oooooooogl0oomo0002ooooo`Googl000?ooooo
oomo0?ooO`002?ooO`08ooooo`;oogl00_ooool4oomo00Oooooo0_ooO`000ol0003oooooooooo`02
oomo00Wooooo0_ooO`02ooooo`;oogl02?ooool2oomo00Gooooo0_ooO`0Jooooo`03o`000?oooooo
oooo00_ooooo0008ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool08oooool2oj0P
l0?o000000?ooooooj0Pl?nP8?001?ooool4oj0Pl003oomo0?oooooooooo00;ooooo0_ooO`000ooo
ooooogl0oomo0003oomo0003ooooooooO`3oogl000;oogl00oooool2oomo0003oooooonP8?3oX23`
00Oooooo0_ooO`04ooooo`03o`000?oooooooooo00Gooooo0_ooO`02oj0Pl003ooooooooO`3oogl0
00;ooooo1?ooO`04ooooo`Coogl01?ooool2oj0Pl1?ooooo0_ooO`06ooooo`03o`000?oooooooooo
00_ooooo0008ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool08oooool3o`0000Co
oooo0_nP8?04ooooo`CoX23`0_ooO`000oooooooogl0oomo0002oomo0004ooooooooO`3oogl0oomo
00?ooooo1?ooO`06ooooo`;oX23`1oooool3oomo00Cooooo00?o0000ooooooooool00oooool3oomo
00;oX23`1Oooool2oj0Pl0;oogl01?ooool2oomo00;ooooo0_ooO`02ooooo`;oX23`00?oogl0oooo
ooooool04?ooool2oomo00Oooooo00?o0000ooooooooool02_ooool000Sooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`0Oooooo`Co00001oooool2oj0Pl0Cooooo4?ooO`02ooooo`;o
ogl04_ooool2oomo00Gooooo00?o0000oomo0?ooool00_ooool4oomo00;oX23`1?ooool2oj0Pl0Go
oooo1oooO`000oooooooogl0oomo0002oomo00Kooooo0_ooO`000onP8?3oooooooooo`0@ooooo`03
o`000?oooooooooo00[ooooo0007ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
7?ooool3o`0000cooooo0_nP8?04ooooo`Koogl00oooool:oomo01Oooooo0_nP8?000oooO`3o0000
ooooo`04ooooo`;oogl00_nP8?07ooooo`;oX23`0_ooool2oj0Pl003ooooooooO`3oogl000?ooooo
0_ooO`08ooooo`;oogl000?oX23`ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`001ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Wooooo0ol0000?ooooo`;oX23`1_oo
ool<oomo0003ooooooooO`3oogl001;ooooo0_nP8?02oomo00?ooooo0_nP8?000ooooooo0000oooo
o`0?ooooo`;oX23`0_ooool2oj0Pl0Gooooo1_ooO`0;ooooo`;oogl03Oooool00ol0003ooooooooo
o`0:ooooo`001oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Kooooo0ol00009
ooooo`;oX23`3oooool8oomo0003ooooooooO`3oogl000Gooooo0_nP8?000oooooooogl0oomo0002
oomo00[ooooo0_nP8?02oomo00Oooooo00?o0000oj0Pl?nP8?004?ooool2oj0Pl0Gooooo0oooO`00
1Oooooooogl0oomo0?ooO`3ooooo00;oogl02?ooool2oomo00gooooo00?o0000ooooooooool02_oo
ool000Oooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Booooo`Co00003?ooool2
oj0Pl0[ooooo0_nP8?06ooooo`Koogl00_nP8?02ooooo`;oX23`00Cooooooj0Pl?nP8?3ooooo1?oo
O`000oooooooogl0oomo0008ooooo`;oogl01oooool2oj0Pl005o`000?nP8?3ooooooooooonP8?00
0_ooO`03ooooo`;oogl01_ooool2oj0Pl0Gooooo0oooO`05ooooo`;oogl05oooool00ol0003ooooo
ooooo`0:ooooo`001oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00oooooo0ol0
000Looooo`;oX23`1oooool5oomo00;oX23`00Cooooooomo0?ooO`3oX23`2Oooool2oomo00Sooooo
0_ooO`07ooooo`04oj0Pl?ooO`3oogl0o`0000;ooooo00?oX23`oomo0?ooO`000oooool2oomo00co
oooo0_nP8?0Pooooo`03o`000?oooooooooo00[ooooo0007ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool03?ooool3o`0002Sooooo1_ooO`02ooooo`;oogl01Oooool2oomo00oooooo
0_nP8?06ooooo`;oogl000?oooooo`000?ooool01_ooool2oomo00cooooo0_nP8?0Aooooo`;oogl0
3_ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Wooooo0ol0000Wooooo`;oX23`0_ooool7oomo00CoX23`0_ooool4oomo00oooooo0_nP
8?03ooooo`?oX23`1?ooool00ol0003oooooooooo`04ooooo`;oogl000?ooooooomo0?ooO`000_oo
O`08ooooo`;oogl04?ooool2oomo00kooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`06ooooo`?o0000:_ooool2oj0Pl0;ooooo0oooO`00
1?ooooooogl0oomo0?ooO`05oj0Pl004ooooooooO`3oogl0oomo01Gooooo0onP8?04ooooo`03o`00
0?oooooooooo00Cooooo0_ooO`000oooooooogl0oomo0002oomo00?ooooo0_nP8?03ooooo`;oogl0
8?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00;ooooo1?l0000aooooo`;oogl000?oX23`oomo0?ooO`000oooO`000oooooooogl0oomo
0002oomo0003ooooooooO`3oogl000Gooooo0_ooO`0>ooooo`04oj0Pl?ooO`3oogl0ooooo`;oogl0
00?ooooooomo0?l000001Oooool2oomo00?ooooo0_ooO`02ooooo`;oX23`0_ooO`02ooooo`;oogl0
0_ooool2oomo00Wooooo0_nP8?0Aooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooool000000_l0000fooooo`;oX23`2_ooO`08ooooo`;oogl02_oo
ool2oj0Pl003ooooooooO`3oogl000;oogl000Cooooooomo0?ooO`3ooooo0_ooO`000ol0003ooooo
ooooo`07ooooo`;oogl00_ooool2oj0Pl0?oogl000?ooooooomo0?ooO`000_ooool2oomo00Wooooo
0_nP8?0Aooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo06cooooo0ol0
000looooo`Ooogl03_ooool2oomo00Kooooo0_nP8?001?ooooooogl0oomo0?ooO`07ooooo`03oomo
0?l0003ooooo00Gooooo0_ooO`05ooooo`Coogl000?ooooooomo0?ooO`000oooool2oomo01_ooooo
00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0JOooool3o`000003ooooool0
003ooooo03_ooooo0oooO`0;ooooo`;oX23`1_ooool4oomo00[ooooo0_ooO`05ooooo`;oogl000?o
0000ooooooooool00oooool2oomo00Gooooo0oooO`02ooooo`;oogl00oooool2oomo01_ooooo00?o
0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0I_ooool3o`0000Cooooo00?o0000
ooooooooool0>_ooool2oomo00Gooooo0_ooO`05ooooo`;oX23`2?ooool2oomo00Cooooo0_nP8?00
1?ooO`3oooooooooooooool2oomo00Cooooo0oooO`001?l0003oX23`oj0Pl?ooool4oj0Pl0?ooooo
0_nP8?000oooooooogl0oomo0002ooooo`;oogl00_ooool3oomo01cooooo00?o0000ooooooooool0
2?ooool000Gooooo00?o0000ooooooooool0Hoooool4o`0000Oooooo00?o0000ooooooooool0@Ooo
ool2oomo00;ooooo0_ooO`000oooooooX23`oj0Pl002ooooo`;oX23`00?ooooooomo0?ooO`001_oo
ool3oj0Pl003oomo0?oooooooooo00Oooooo0_ooO`001Oooooooogl0o`000?nP8?3ooooo00CoX23`
0_ooO`000oooooooX23`oj0Pl002oomo00Oooooo0_ooO`0Mooooo`03o`000?oooooooooo00Sooooo
0005ooooo`03o`000?oooooooooo063ooooo0ol0000;ooooo`03o`000?oooooooooo04Cooooo0ooo
O`02ooooo`;oogl000Cooooooj0Pl?nP8?3ooooo0_ooO`06ooooo`;oX23`0_ooO`02ooooo`;oX23`
2?ooool2oomo0003o`000?ooO`3oogl000;oogl000?oX23`oomo0?ooO`000oooool5oomo00Gooooo
0_nP8?0Looooo`03o`000?oooooooooo00Sooooo0005ooooo`03o`000?oooooooooo05gooooo0ol0
000>ooooo`03o`000?oooooooooo04Cooooo0_ooO`03ooooo`;oogl000?ooooooomo0?ooO`002ooo
ool2oj0Pl0;ooooo0_nP8?000oooooooogl0oomo0002oomo00?ooooo0_nP8?000ooooooo0000oomo
0002oomo0003oj0Pl?ooO`3oogl000Gooooo0oooO`05ooooo`;oX23`1?ooO`0Hooooo`03o`000?oo
oooooooo00Sooooo0005ooooo`03o`000?oooooooooo05[ooooo0ol0000Aooooo`03o`000?oooooo
oooo047ooooo0_nP8?0;ooooo`;oogl02Oooool2oj0Pl0Gooooo1?ooO`07ooooo`04o`000?oooooo
ooooooooo`;oogl00oooool2oomo00[ooooo1?ooO`0Hooooo`03o`000?oooooooooo00Sooooo0005
ooooo`03o`000?oooooooooo05Oooooo0ol0000Dooooo`03o`000?oooooooooo047ooooo0_nP8?05
ooooo`;oX23`1?ooool2oj0Pl1Sooooo0_ooO`02ooooo`03o`000?oooooooooo00Gooooo0_ooO`0;
ooooo`;oogl06Oooool00ol0003oooooooooo`08ooooo`001Oooool00ol0003oooooooooo`1Coooo
o`Co00005oooool00ol0003oooooooooo`18ooooo`;oX23`1?ooool2oj0Pl0gooooo0_ooO`09oooo
o`;oogl00_nP8?000ol0003oooooooooo`08ooooo`;oogl08oooool00ol0003oooooooooo`08oooo
o`001?ooool00ol0003oooooooooo`1Aooooo`?o00006oooool00ol0003oooooooooo`1<ooooo`;o
X23`0_ooool2oj0Pl0Gooooo0_ooO`03ooooo`;oogl00_nP8?09ooooo`CoX23`00Co0000oooooooo
O`3oogl01_ooool2oomo00;ooooo0_nP8?02oomo01gooooo00?o0000ooooooooool02?ooool000Co
oooo00?o0000ooooooooool0C_ooool3o`0001kooooo00?o0000ooooooooool0C?ooool2oj0Pl0;o
oooo0_nP8?05ooooo`;oogl00oooool2oomo00;oX23`1Oooool2oomo00Oooooo00?o0000oomo0?oo
O`002_ooool2oj0Pl0;oogl01?ooool3oomo00Kooooo0_ooO`02ooooo`;oogl02oooool00ol0003o
ooooooooo`07ooooo`001?ooool00ol0003oooooooooo`1;ooooo`?o00008Oooool00ol0003ooooo
ooooo`17ooooo`;oX23`4Oooool2oj0Pl0Wooooo0_ooO`03ooooo`;oogl00oooool00ol0003oX23`
ooooo`03ooooo`;oX23`00?ooooooomo0?ooO`001_ooool2oomo0004ooooooooO`3oogl0oomo00Ko
oooo0_ooO`02ooooo`;oogl02oooool00ol0003oooooooooo`07ooooo`001?ooool00ol0003ooooo
ooooo`18ooooo`?o00009?ooool00ol0003oooooooooo`17ooooo`;oX23`4Oooool2oj0Pl0kooooo
1?ooO`02ooooo`03o`000?oooooooooo00;ooooo0_nP8?03oomo00Gooooo0oooO`09ooooo`;oogl0
4?ooool00ol0003oooooooooo`07ooooo`001?ooool00ol0003oooooooooo`14ooooo`Co00009ooo
ool00ol0003oooooooooo`1Eooooo`;oogl00onP8?0Booooo`;oogl000?ooooooomo0?l000001Ooo
ool00oooO`3oX23`oj0Pl006ooooo`;oogl02_ooool2oomo013ooooo00?o0000ooooooooool01ooo
ool000Cooooo00?o0000ooooooooool0@Oooool3o`0002_ooooo00?o0000ooooooooool0Boooool2
oj0Pl0?ooooo0_nP8?03ooooo`;oogl01?nP8?03ooooo`;oogl000?ooooooj0Pl?nP8?001_ooool2
oomo0004oj0Pl?ooooooooooooooo`;oogl000?o0000ooooooooool00oooool2oj0Pl0Cooooo0_nP
8?06ooooo`;oogl05_ooool00ol0003oooooooooo`07ooooo`000oooool00ol0003oooooooooo`0o
ooooo`?o0000;_ooool00ol0003oooooooooo`1;ooooo`;oX23`0oooool2oj0Pl004oooooonP8?3o
X23`ooooo`;oogl00onP8?03ooooo`;oogl000?ooooooj0Pl?nP8?001Oooool3oomo0003oj0Pl?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool2oomo0004ooooooooO`3oogl0ooooo`;oX23`
1Oooool2oj0Pl003oomo0?oooooooooo01Cooooo00?o0000ooooooooool01oooool000?ooooo00?o
0000ooooooooool0??ooool3o`00037ooooo00?o0000ooooooooool0D?ooool2oj0Pl004oooooonP
8?3oX23`ooooo`;oogl000Cooooooj0Pl?nP8?3oX23`2Oooool5oomo00Kooooo0_ooO`000ooooooo
0000ooooo`05ooooo`;oogl01oooool3oj0Pl1Oooooo00?o0000ooooooooool01oooool000?ooooo
00?o0000ooooooooool0>Oooool3o`0003?ooooo00?o0000ooooooooool0Eoooool2oomo00KoX23`
1oooool2oomo00;oX23`0_ooool2oomo00;oX23`00?ooooooomo0?ooO`000_ooool00ol0003oX23`
oj0Pl00<ooooo`;oX23`00?ooooooomo0?ooO`005_ooool00ol0003oooooooooo`06ooooo`000ooo
ool00ol0003oooooooooo`0eooooo`Co0000=_ooool00ol0003oooooooooo`1Iooooo`;oX23`00Co
oooooomo0?nP8?3oX23`1_ooool2oomo0003oooooonP8?3oX23`00;ooooo0_ooO`02oj0Pl003oooo
ooooO`3oogl000;oX23`00?oooooo`000?nP8?000oooool2oj0Pl0[ooooo0_ooO`06ooooo`;oX23`
3_ooool00ol0003oooooooooo`06ooooo`000oooool00ol0003oooooooooo`0booooo`?o0000>_oo
ool00ol0003oooooooooo`1Dooooo`;oX23`0oooool2oj0Pl0;ooooo0_nP8?06ooooo`;oogl01ooo
ool2oomo00?ooooo0onP8?000ol0003oogl0ooooo`02oomo00CoX23`0_ooool4oomo00?ooooo1?oo
O`03ooooo`;oX23`00?oogl0ooooooooool02oooool00ol0003oooooooooo`06ooooo`000oooool0
0ol0003oooooooooo`0_ooooo`?o0000?Oooool00ol0003oooooooooo`1Booooo`CoX23`0oooool2
oj0Pl0;ooooo0_nP8?02ooooo`;oX23`1_ooool2oj0Pl0?ooooo0_ooO`000onP8?3oooooooooo`02
ooooo`04oj0Pl?ooO`3o0000ooooo`;oogl000Cooooooj0Pl?nP8?3oX23`0_ooool4oomo00?ooooo
1?ooO`03ooooo`;oX23`00?oogl0ooooooooool02oooool00ol0003oooooooooo`06ooooo`000ooo
ool00ol0003oooooooooo`0/ooooo`?o0000@?ooool00ol0003oooooooooo`1Booooo`;oX23`3Ooo
ool3oj0Pl0Gooooo0_nP8?04ooooo`;oX23`1oooool00ol0003oX23`ooooo`06ooooo`;oX23`0_oo
O`09ooooo`03oomo0?nP8?3oX23`00kooooo00?o0000ooooooooool01_ooool000;ooooo00?o0000
ooooooooool0:Oooool4o`0004?ooooo00?o0000ooooooooool0H_ooool4oj0Pl0;oogl00onP8?0;
ooooo`;oogl000?oX23`o`000?nP8?001_ooool2oj0Pl0;oogl02Oooool00oooO`3oX23`oj0Pl00>
ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03o`000?oooooooooo02Kooooo0ol00017oooo
o`03o`000?oooooooooo06Cooooo0_nP8?02oomo00?oX23`2oooool2oomo0003oooooonP8?3o0000
00Oooooo0_ooO`04ooooo`;oogl01Oooool2oj0Pl0Cooooo1?ooO`06ooooo`03o`000?oooooooooo
00Kooooo0002ooooo`03o`000?oooooooooo02?ooooo0ol0001:ooooo`03o`000?oooooooooo06[o
oooo0_ooO`001?ooooooX23`oj0Pl?ooool2oomo00Kooooo0_nP8?001?l0003oogl0oomo0?ooO`02
ooooo`;oX23`0_ooO`04ooooo`;oogl02?ooool2oomo0003ooooooooO`3oogl000;oogl01oooool0
0ol0003oooooooooo`05ooooo`000_ooool00ol0003oooooooooo`0Pooooo`?o0000COooool00ol0
003oooooooooo`1Zooooo`;oogl000Cooooooj0Pl?nP8?3ooooo0_ooO`06ooooo`;oX23`00Cooooo
o`000?ooO`3oogl00_ooool2oj0Pl0Gooooo0_nP8?05ooooo`;oogl00_ooool4oomo00[ooooo00?o
0000ooooooooool01Oooool000;ooooo00?o0000ooooooooool07Oooool3o`00053ooooo00?o0000
ooooooooool0K_ooool2oj0Pl0;oogl01_ooool2oomo00;ooooo00?o0000ooooooooool02?ooool2
oj0Pl0;ooooo0_nP8?000oooooooogl0oomo0002ooooo`;oX23`0_ooO`000oooooooX23`oj0Pl007
ooooo`03o`000?oooooooooo00Gooooo0002ooooo`03o`000?oooooooooo01Wooooo1?l0001Coooo
o`03o`000?oooooooooo06Kooooo00?oX23`oomo0?ooO`001Oooool2oj0Pl0Oooooo0_ooO`04oooo
o`03o`000?oooooooooo00Gooooo1?ooO`001?nP8?3ooooooj0Pl?nP8?05ooooo`;oX23`00?oogl0
ooooooooool00_nP8?07ooooo`03o`000?oooooooooo00Gooooo00000ooooooo0000ooooo`0Hoooo
o`?o0000Eoooool00ol0003oooooooooo`1Vooooo`04oj0Pl?ooO`3oogl0oomo00gooooo0_ooO`05
ooooo`03o`000?ooO`3ooooo00Cooooo1?ooO`000onP8?3oooooooooo`04ooooo`;oogl000?ooooo
oomo0?ooO`002oooool00ol0003oooooooooo`05ooooo`0000?oooooo`000?ooool05Oooool3o`00
05[ooooo00?o0000ooooooooool0Hoooool2oj0Pl0?ooooo0_ooO`0Dooooo`03oomo0?l0003oogl0
00;oogl02oooool4oomo0003ooooooooO`3oogl000_ooooo00?o0000ooooooooool01Oooool00003
ooooool0003ooooo01;ooooo0ol0001Mooooo`03o`000?oooooooooo06?ooooo0_nP8?03ooooo`;o
ogl00_ooool4oj0Pl0Oooooo0_ooO`06ooooo`04o`000?ooO`3oogl0oomo00Sooooo0_ooO`001?oo
ooooogl0oj0Pl?nP8?02ooooo`;oogl02oooool00ol0003oooooooooo`05ooooo`0000?oooooo`00
0?ooool03oooool3o`00063ooooo00?o0000ooooooooool0J?ooool2oomo0003oooooonP8?3oX23`
00?oX23`1oooool2oomo00?ooooo0_nP8?02ooooo`04o`000?ooO`3oooooooooo`;oX23`1Oooool2
oomo00;ooooo0_nP8?02ooooo`;oogl02oooool00ol0003oooooooooo`05ooooo`0000?oooooo`00
0?ooool02oooool4o`0006?ooooo00?o0000ooooooooool0Joooool2oj0Pl0Cooooo0_ooO`02oooo
o`;oogl01Oooool2oj0Pl0;ooooo00Coogl0o`000?nP8?3ooooo0_nP8?02oomo0003ooooooooO`3o
ogl000Sooooo1?ooO`0:ooooo`03o`000?oooooooooo00Cooooo00000ooooooo0000ooooo`08oooo
o`?o0000Ioooool00ol0003oooooooooo`1[ooooo`;oX23`1?ooool2oomo00;ooooo0_ooO`0:oooo
o`03oj0Pl?l0003ooooo00;ooooo0_ooO`000oooooooogl0oomo0003ooooo`;oX23`1Oooool2oj0P
l0[ooooo00?o0000ooooooooool01?ooool00003ooooool0003ooooo00Gooooo0ol0001Zooooo`03
o`000?oooooooooo06kooooo0_nP8?06ooooo`;oX23`0_ooO`03ooooo`;oogl01?ooool00ol0003o
ogl0ooooo`08ooooo`03oj0Pl?ooO`3oogl000Cooooo0_nP8?0:ooooo`03o`000?oooooooooo00Co
oooo00000ol0003oooooooooo`02ooooo`?o0000KOooool00ol0003oooooooooo`1Xooooo`;oX23`
1?ooool2oj0Pl003ooooooooO`3oogl000;oX23`00?ooooooj0Pl?nP8?000_ooO`03ooooo`;oogl0
0_ooool2oomo0003o`000?ooO`3ooooo00;oogl000?oX23`oomo0?ooO`001?ooool2oomo013ooooo
00?o0000ooooooooool01?ooool00003o`000?oooooo000000;o0000L?ooool00ol0003ooooooooo
o`1Xooooo`;oX23`1oooool2oomo00?oX23`0_ooO`02oj0Pl003oooooonP8?3oX23`00Cooooo0ooo
O`001Ol0003ooooooomo0?ooO`3oX23`00?oogl01_ooool2oomo00;oX23`00?ooooooj0Pl?nP8?00
2?ooool00ol0003oooooooooo`04ooooo`000_l0001cooooo`03o`000?oooooooooo06[ooooo0_nP
8?09ooooo`;oX23`00Coogl0oj0Pl?nP8?3oogl00_nP8?05ooooo`;oogl000?oooooo`000?ooool0
0oooool2oomo00Kooooo0_ooO`02oj0Pl003oooooonP8?3oX23`00Sooooo00?o0000ooooooooool0
1?ooool000;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1Pooooo`;oX23`2?oo
ool2oj0Pl0Sooooo0onP8?04oomo00;ooooo0_ooO`06ooooo`03oj0Pl?l0003ooooo00Sooooo0_oo
O`0?ooooo`03o`000?oooooooooo00Cooooo0003ooooo`;o0000L?ooool00ol0003oooooooooo`1P
ooooo`;oX23`4Oooool5oj0Pl003oomo0?oooooooooo00;ooooo0_ooO`05ooooo`;oogl000?oX23`
o`000?ooool01?ooool5oomo00Oooooo0_ooO`07ooooo`03o`000?oooooooooo00?ooooo0005oooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Loooool6oj0Pl0Sooooo0_ooO`001_nP
8?3oogl0oj0Pl?nP8?3oooooo`0000Cooooo1_ooO`06ooooo`;oogl01oooool00ol0003ooooooooo
o`03ooooo`001_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo07Kooooo00?oogl0
oj0Pl?nP8?002?ooool2oomo00CoX23`00?oooooo`000?ooool01?ooool2oomo0004ooooooooO`3o
ogl0oomo00Cooooo1?ooO`06ooooo`03o`000?oooooooooo00?ooooo0007ooooo`;o0000K?ooool0
0ol0003oooooooooo`1iooooo`;oX23`1?ooool2oj0Pl0Cooooo0_nP8?02ooooo`04o`000?oooooo
ooooooooo`;oogl00_ooool5oomo0003oooooonP8?3oogl000?oogl01_ooool00ol0003ooooooooo
o`03ooooo`002Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo07Wooooo0_nP8?04
ooooo`;oX23`1?ooool2oj0Pl004ooooooooO`3oogl0o`0000;ooooo0_ooO`02ooooo`;oogl000Co
oooooomo0?ooO`3ooooo0_nP8?000oooooooogl0oomo0006ooooo`03o`000?oooooooooo00?ooooo
000:ooooo`;o0000JOooool00ol0003oooooooooo`1iooooo`CoX23`0oooool2oomo00Gooooo0ooo
O`000ooooooo0000ooooo`07ooooo`;oogl03?ooool00ol0003oooooooooo`03ooooo`003?ooool0
0ol0003oooooooooo`1Vooooo`03o`000?oooooooooo07;ooooo0_nP8?06ooooo`?oX23`00?ooooo
oomo0?ooO`000_ooO`05ooooo`;oogl000Gooooooomo0?ooO`3o0000ooooo`02oj0Pl0Coogl03_oo
ool00ol0003oooooooooo`03ooooo`003Oooool2o`0006Gooooo00?o0000ooooooooool0Loooool2
oj0Pl0Oooooo1_nP8?04ooooo`;oogl00_nP8?001Oooooooogl0oomo0?l0003oogl000;oX23`00?o
ogl0oj0Pl?nP8?001?nP8?001?ooooooX23`oj0Pl?ooool4oomo00Cooooo00?o0000ooooooooool0
0_ooool000oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1mooooo`SoX23`00?o
oooooomo0?nP8?000_nP8?001Oooooooogl0oomo0?oooooo000000;oX23`00?ooooooj0Pl?nP8?00
1?nP8?001?ooO`3oX23`oj0Pl?ooool4oomo00Cooooo00?o0000ooooooooool00_ooool0013ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`1mooooo`?oX23`00?ooooooj0Pl?nP8?00
0_nP8?02ooooo`;oX23`00Cooooooomo0?ooO`3oogl00_ooool01Ol0003oogl0oomo0?ooO`3ooooo
00;oX23`0_ooO`05oj0Pl003oomo0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0017o
oooo0_l0001Qooooo`03o`000?oooooooooo083ooooo2onP8?000oooO`3oooooooooo`02oomo0003
o`000?nP8?3oogl000?oX23`0_ooO`05oj0Pl003oomo0?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool001?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`20ooooo`_oX23`
0oooool01OooO`3oX23`oj0Pl?l0003oogl000GoX23`00?oogl0ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`005?ooool2o`0005kooooo00?o0000ooooooooool0P?ooool;oj0Pl0Coogl0
0onP8?000ol0003oX23`oj0Pl003oj0Pl0?oogl00_nP8?02oomo00Gooooo00?o0000ooooooooool0
0_ooool001Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`20ooooo`_oX23`00?o
ogl0oj0Pl?ooO`001?nP8?000ol0003oogl0oomo0006oomo00;oX23`0_ooO`05ooooo`03o`000?oo
oooooooo00;ooooo000Gooooo`;o0000Foooool00ol0003oooooooooo`22ooooo`_oX23`00?oogl0
oj0Pl?nP8?000oooO`000ol0003oogl0oj0Pl002oomo00?ooooo0_ooO`08ooooo`03o`000?oooooo
oooo007ooooo000Iooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0QOooool7oj0P
l0Coogl00_nP8?02oomo0003o`000?nP8?3oogl000Googl00_nP8?07ooooo`03o`000?oooooooooo
007ooooo000Jooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0Q_ooool2oj0Pl0?o
ogl00_nP8?03oomo00?oX23`00?oogl0oj0Pl?l000001_ooO`03oj0Pl003oomo0?oooooooooo00?o
oooo00?o0000ooooooooool00Oooool001_ooooo0_l0001Gooooo`03o`000?oooooooooo08Oooooo
0_nP8?03oomo00;oX23`0_ooO`02ooooo`CoX23`00Go0000oooooooooooooooooomo0004oj0Pl003
oomo0?oooooooooo00?ooooo00?o0000ooooooooool00Oooool001gooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`28ooooo`?oogl02_nP8?000oooO`3o0000oomo0003oomo00CoX23`
00?oogl0ooooooooool00oooool00ol0003oooooooooo`01ooooo`007_ooool2o`0005Cooooo00?o
0000ooooooooool0Roooool9oj0Pl0?oogl000Co0000oomo0?ooO`3ooooo1?nP8?06ooooo`03o`00
0?oooooooooo007ooooo000Pooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0R_oo
ool2oj0Pl003oooooonP8?3oX23`00;oogl00onP8?02oomo00;oX23`00?o0000ooooooooool00_nP
8?08ooooo`03o`000?oooooooooo007ooooo000Qooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0R_ooool3oj0Pl004oooooonP8?3oogl0oomo00?oX23`0_ooool2oj0Pl003ooooool0
003ooooo00?ooooo0_ooO`000oooooooogl0oomo0002ooooo`03o`000?oooooooooo007ooooo000R
ooooo`;o0000D?ooool00ol0003oooooooooo`2;ooooo`;oX23`0_ooool2oj0Pl0;oogl01?nP8?03
ooooo`04o`000?ooO`3oogl0ooooo`;oogl000?ooooooomo0?ooO`000oooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2>ooooo`?oX23`0_ooool6
oj0Pl0;ooooo00?o0000oomo0?ooool01?ooool3oj0Pl003ooooool0003ooooo007ooooo000Uoooo
o`;o0000COooool00ol0003oooooooooo`2>ooooo`;oX23`1_ooool00oooO`3oX23`oj0Pl002oooo
o`03o`000?ooO`3ooooo00?ooooo1?nP8?000ooooooo0000ooooo`01ooooo`009oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo09?ooooo0_nP8?03ooooo`;oogl000?ooooooomo0?l0
00000_ooO`000oooooooogl0oj0Pl003oj0Pl003ooooool0003ooooo007ooooo000Xooooo`;o0000
B_ooool00ol0003oooooooooo`2?ooooo`;oX23`0_ooool2oj0Pl0?ooooo0_ooO`03ooooo`04o`00
0?ooO`3oogl0oomo00CoX23`00?oooooo`000?ooool00Oooool002[ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`2?ooooo`CoX23`1Oooool4oj0Pl0;ooooo00?o0000oomo0?ooO`00
0_ooool2oj0Pl003ooooool0003ooooo007ooooo000[ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0TOooool2oj0Pl0Gooooo1OnP8?02ooooo`04o`000?ooO`3ooooooomo00?oX23`
0Ol00001ooooo`7ooooo000/ooooo`;o0000A_ooool00ol0003oooooooooo`2Gooooo`KoX23`0_oo
ool00ol0003oogl0oomo0004oomo007ooooo0Ol00001ooooo`00;_ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo09Oooooo1_nP8?001?ooO`3ooooooomo0?l00005oomo007ooooo0Ol0
0001ooooo`00;oooool2o`0004?ooooo00?o0000ooooooooool0V_ooool2oj0Pl0;oogl00_ooool0
0oooO`3o0000ooooo`04oomo007o00000Oooool0037ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`2Jooooo`;oX23`0_ooool2oj0Pl0;oogl000?o0000oomo0?ooO`000_ooO`01o`00
007ooooo000booooo`;o0000@?ooool00ol0003oooooooooo`2Nooooo`;oX23`0_ooO`001_oooooo
0000oomo0?ooO`3oooooo`00007ooooo000dooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0VOooool2oj0Pl0?ooooo0_nP8?04ooooo`04o`000?ooooooooooo`00007ooooo000eoooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0VOooool2oj0Pl0Wooooo00Co0000oooo
oooooooo00000Oooool003Kooooo0_l0000kooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool00Ol0000003Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2Wooooo`7o
00000Oooool1o`000000>Oooool2o`0003Sooooo00?o0000ooooooooool0Z?ooool2o`000000>ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo09oooooo0_nP8?06ooooo`?o0000000l
ooooo`;o0000=Oooool00ol0003oooooooooo`2Oooooo`;oX23`00?oooooo`000?l000000ol00003
ooooo`00?_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09kooooo1?l00008oooo
o`00?oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Wooooo1Ol0000<ooooo`00
@?ooool2o`00037ooooo00?o0000ooooooooool0UOooool4o`00017ooooo0012ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0TOooool4o`0001Gooooo0013ooooo`;o0000;_ooool0
0ol0003oooooooooo`2<ooooo`Go00006Oooool004Gooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`28ooooo`Co00007_ooool004Kooooo0_l0000[ooooo`03o`000?oooooooooo08?o
oooo1Ol0000Rooooo`00B?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07oooooo
1?l0000Wooooo`00BOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo1Ol0
000[ooooo`00B_ooool2o`0002Oooooo00?o0000ooooooooool0M_ooool4o`00033ooooo001<oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L_ooool4o`0003Cooooo001=ooooo`;o
00009?ooool00ol0003oooooooooo`1]ooooo`Go0000>?ooool004oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1Yooooo`Co0000?Oooool0053ooooo0_l0000Qooooo`03o`000?oo
oooooooo06Cooooo1Ol00011ooooo`00D_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo063ooooo1?l00016ooooo`00Doooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
05_ooooo1Ol0001:ooooo`00E?ooool2o`0001gooooo00?o0000ooooooooool0Eoooool4o`0004oo
oooo001Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool5o`0005?ooooo
001Gooooo`;o00006_ooool00ol0003oooooooooo`1>ooooo`Co0000F?ooool005Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1:ooooo`Co0000G?ooool005[ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`15ooooo`Go0000H?ooool005_ooooo0_l0000Fooooo`03
o`000?oooooooooo047ooooo1?l0001Uooooo`00GOooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03cooooo1Ol0001Yooooo`00G_ooool2o`0001?ooooo00?o0000ooooooooool0>?oo
ool4o`0006kooooo001Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool5
o`0007;ooooo001Qooooo`;o00003oooool00ol0003oooooooooo`0`ooooo`Co0000Moooool006?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0/ooooo`Co0000Noooool006Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`Go0000Ooooool006Gooooo0_l0
000;ooooo`03o`000?oooooooooo02?ooooo1?l00024ooooo`00Ioooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01kooooo1Ol00028ooooo`00J?ooool2o`0000Sooooo00?o0000oooo
ooooool06_ooool4o`0008gooooo001Zooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool5o`00097ooooo001[ooooo`;o00001Oooool00ol0003oooooooooo`0Aooooo`Co0000
U_ooool006gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`Co0000V_oo
ool006kooooo00Go0000ooooooooooooooooo`00000:ooooo`Go0000W_ooool006oooooo0_l00000
0ooooooo0000ooooo`05ooooo`Co0000Xoooool0077ooooo0_l000000ooooooo0000o`000003o`00
0:Oooooo001booooo`;o0000[?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {311.562, 0}} -> {0.0486402, -4.05116*^-5, \
0.00298809, 0.00298809}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gaussian pdfs", "Subsection"],

Cell[BoxData[{
    \(\(\[Mu]1\  = Mean[data1];\)\), "\n", 
    \(\(\(\[CapitalSigma]1\  = 
        CovarianceMatrix[data1];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(\[Mu]2\  = \ Mean[data2];\)\), "\n", 
    \(\(\(\[CapitalSigma]2\  = \ 
        CovarianceMatrix[data2];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(lpdf1\  = \ \(logpdf3D[\[Mu]1, \[CapitalSigma]1]\  // \ 
            ExpandAll\)\  // \ N;\)\), "\n", 
    \(\(lpdf2\  = \ \(logpdf3D[\[Mu]2, \[CapitalSigma]2]\  // \ 
            ExpandAll\)\  // \ N;\)\)}], "Input",
  CellFrame->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Image classification", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = ClassifyImage3DAugmented[obj1, lpdf1, lpdf2];\)\), "\n", 
    \(\(class2 = ClassifyImage3DAugmented[obj2, lpdf1, lpdf2];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1, class1}, {obj2, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55495 
%%ImageSize: 400 221.978 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.013213 0.47619 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.013213 0.477324 0.264889 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7E7E5CBCCC7D1D2CDECECEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F8F7F3DCDBD7B2B1AF7E7D7B4C4B472E2D2935343053524E
777672A5A6A1CCCCCAE9E9E700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00DCD8D59C999466635C3F3C3527241F2D2A25282421302C29322F2A2F2C27
2926212827222E2F274748428B8C86EDEEE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F6F7F2AEADA943403B221D17211E15302D243C3731433E3A443F3B4C4441524B45554E48
544F494D4A4137342B2222181B1B135E5F59D0D1CC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E0E1DC
7D7C7734312A1D181228241B353128413D3440393339312E3D3532423836473E3949403B
4D443D50493F494238433F363532291D1D153E3D39ADACAA00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3E3E15F5E59
28251E2521181F1B1237332A403C333B372E37302A342C293F3533403634433834443933
3F342E3F362D483F364A43394B473C3C39302825202A2925A5A5A300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F4F4F27B7A7525251D
2C2920242017322B21463F353B342A4740363D342D342B26362F29352E283C332E393029
3B322B4A41384F473C423A2F433F334A483C37342D1F1E193C3D38D6D6D400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3A09B28251E26231C
2F2A24261F17342B244A4138372E253F362D494039393029302722382F2A3D342F362D26
433A31534A414F453B40362C403A2E4A463B46433A2827221E1D196E6E6CF4F4F400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFF5F4FFF6F3FFF4F0FFF4F0FFF5F2FFF5F2FFF6F2FFF8F3CBBEB83C332C2017122A231D
312A242A231D2D221E463B37392E2A2E231D4237333F34303227213B302A443933382D27
3E342B4F453C493C343A30273A3128453E34514D442B2A2523221E21211FABA9AA00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFEEE8E8D1CBE1C9C5D8C3C0D4C2C0D5C3C1DBC9C7D2BDBCD5BBBCDEBEBFD1AAABC09495
CC9A99CB9894C48F89B9847EB7857EAF7E77A0756E92706760453C27150B251812312823
2E24222A201E291E1C382D2B4136322F2420372C283A2F2B3A2F29423731514640433832
3F362D4A4037362C2330261D372E25474038443F392B282326221F1B1716484242E7DEDF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDEDEDAFAFAF6A6A68
6565636566616565636667626768636A6B668E8E8CBBBBB9D3D3D1E8E8E600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FCD5CE
BF897F894D42A47065A97C76825D5783625DA4817FA27A78A47474B37978A55D5E8F3E3D
A34A46A64741A6453C9F3F33A34539953D3186382B7A3C2F5F332633150B28150E352724
3329272E24222A201E2C2220342A28372D2B382D293D322E393029443B34534A414F463D
4740363E372D302720281F1841383148413B372F2C2D2523251C1D271B1B251214887473
DCCAC6E0D1CAE6D9D1E9DFD6F1E7DDF8EFE6FFF6EFFFFDF500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEECACAEAB5959572525231A1917
1716121918131B1A161E1D181718120F100A1A1B1623241F2C2E29474944646663878986
AEB0ADE2E4E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFEAE7E5AEA9B26960
9C493B903D2DD08B7CBD83789867608E635D9467629A6764A96C6BC37978C86E6DA9413E
BB4A44BE473FC84D45C54B40C54D3FBD4C3EA33F2FAB584881433442180C2C0F0934211D
3729263328263126242E24222B211F2F2523382D293A2F2B3A312C3F362F423932403931
3F3B3239352C37302A3F383238302D362E2B312927281E1D2D1F1F3420222B0E1040211E
513329593C2E6D5241644E396D5941745F4A7B6955806D5C897665917E6DA18C7BAE988A
BAA496C8B2A5D5BDB3DBC4BCE0CBC6E6D3CFECDAD6F1E2DFF4E9E5FAF0EE00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00F2F2F0AFAFAD5757551E201B1516111F1E1A201F1B
1C1B161C1B162926212828201D1D151D1E161D1E18181913161711161912151712161815
1719164E504DD6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F5FFCECAD0837DB64F46BA4A3E
B045359C3D2BE29585C6887BB48075976860A3736FB27C7AAD6D6BCA7C7ADC7E7CB44845
C34E47C24740D3544DCE4E45CF5145CA5043AE3E30BE5D4D964A3C50160A360E06391D19
3723223424243A2C2B2F24222F2420302521342623332824372E29372E2938312B3A332D
3E393336312B362E2B372F2C2B23212B23212B2122302222352123381B1D320A0B552521
6A392B6B3B257A4D305E36125F391258350B5B350E5B3510552F0A59330E5C3410693E1C
5C2D1168341E672E1B632A19672F226E3A2F73473E734C4576554E7A5D578265618D6F6D
957673A58683AF908DB99A95C4A7A3CFB3AFD9C0BCDDC8C5E2CFCBE7D5D1EDDEDBF3E4E1
F9EBEAFEF3F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00C6C6C465666123241F171813151611191A15201F1B21201B
2F2C27302D26342F2937342D37342D39392F33332B26271F1C1D15181911151811131510
1217131015114A4C4BD2D4D300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F4DBAFACB4615BB6463BCB473BD04B3C
BF4635A83F2CE89583CB8878B97F73AB756BAF766FAA6D689D5652B6615EDB7873BF4E48
C94E47CC4B45D24D46D55047D14C43D04D43BC4034C25143BB5B4D6D1F124307003F120D
3F1D1B3A201F3723223523213A2B283A2B283D2E2B3B2D2A3328263026242E24222F2724
332B282C24212A222029211F2920212B21222D1F1F331F213E2123381112390605652A24
7D3F307C4026915B37794A1E794D1E754B197E5221805423764A197446157545177F4A1E
6F330E77351585391F873B247E35247A362970372C5A2A20542C244B261E4A231E4A2220
502723542B27542B25572E28532C254F2A224C2B24563732593C3660453E684C496F5652
745C587D6561866E6A937B779C8782A9948FB5A09DC1ACA9C9B4B1D7C2BFDEC9C6E5D0CD
EAD7D3F0DDD9F6E7E2FBEEE8FEF5EEFFFDF2FFFFF4FFFFF3FFFEF500FF0000FF0000FF00
00FF0000FF00E2E2E08888863435301C1D181A1B161C1D18191A151617122A2924393631
403B3538332D322D27322D2734312A38352C33302731312734342A2E2F2722231D13160F
171914161815181A19505251D6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FCD3CFA15650BC4A40D24A3ED44537D24635
C64736AC3D2AE68E7AC77C69B97465A76356904A40A65B559D4843C0615BE87B74C14840
CE4D47D14A44D64D47DB5049D84D46D54B41CB4136C94539D55D4FAE4436731910540B04
49120D451C183C1D1A381F1B3A25203C292542302E40312E3A2F2D3E33313429272D2321
342A2933292831272833292A302426312323341E203A1C1E441C1D3E0B0A480806753128
8A46338D4D32AB775294673D855C2E845E2D8A653198703D926A37956C389567369C693A
975C309B57308D3E1D8F3F249247308C4A3A6731275A2F288A685E85645B7C5953835D5A
8259555C302D643933653D35522C23542F2657352C59382F502F26502F264D2A264C2925
4F2C2848251F4E29234E2923502922532C25502922522923562924602D29682E2A6F342E
773E377D493E805044825B4A7F634E7F6B508D8262948E6C9D987AA7A58CADAC9ABBBBAF
C2C3BBA8A9A34D4E491D1E191C1D1721221C1D1C181E1D191F1E1A26252143403B312E29
2C2723302B2728231F2B26202F2A24312C2628231D28231D302D2633332B31302B23241E
1718131516111C1C1A191917505050E0E0E000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF6F3DCA098A7453AD04C40D64234D74132D54433
C74231B13928E27B68EB907DCC7466B75F53B55B52C5645DD16A63F0817ADF645DCA473F
D54C44D84B44D74840DD4E46DE4F47DD4D44D7443ACC3C31DD5346D25245BA453B8C271D
5F0F0653130A4B1610461914411C16401F1A3B1D1B3B212039211F3C2726372322362221
3A2828362424301C1D372123391F223C1C1F3E16174715164D0F104E040365120C903C31
9746339E563DAE76538F5F3782572D7852256B4518724C1D744C1B895F2D865A2B8E5B2C
884F229E5D33A45834974A2C954D358A4B3A55231A835D54AD8C83A1837BA88581B8928F
976E6C59302E633A36502922805B5298766C97756B916F658D685F8C655E8A615B875C56
865D577D544E774F47734B436C443C663B326539305B2A23692F2B6B27247C2E2A802D27
7D2A227B2D20722B19682E165227055C3F1567562260551F5A52235B562E5D5A3B5F5E49
3D3E301011091516101E1F1920211B1F201A201F1B1F1E1A1A19153A39353A3732292621
29262127241F25201C322D292F2A242B26202C24212B26222C272326231C2B282335342F
23241F191A151C1C1A1D1D1B16161689898900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFE7E3B76861BE4C41D3493CD64031D73F31D03D2D
D44736C23D2CDD6453FD8A78F38176E8736AE66D65DD605AD85952D8534CCD443CD3463D
D84A40D7473EDC4941DD4841E14C45DD493FDA433AD74035D94539DF5042DE5447CF5143
B1413389271A6B140A570D0453120C511713481512491917441B194921213A13143C181A
3E1A1A3C181841191A4115164715184B1012530D0F5807066607057A110D9F322BAD4336
AA4B379E4C34B26F5299614083512E885A387448255E340E6F451B7D52276D40177A4920
743E12995B32A86240944D3195533D7B41336C3D35B08B83B19089AE9088B59290BE9798
724A4B5B3435512E2C674641B3928BAC8E84AE8D84AA887FB68D87B58883A77672A77671
AB7E78A98179A38178A080759A7C7199796E96746A976C65A7726E7B37347B2725963934
97342E94342689341F8039196C380988642A856C29786721766B2B79723B817C528E8D6F
65645208080016160E23221D24231E21201B27241F201D181A171243403B2B2A25201F1A
2625201E1D18231E184B443E35302A25201A2D28242B26222A2521231E1A2A252135322D
3C3B361B1C171616141D1D1B181A1740423FE4E4E400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECC3BFAC4F47C84A3ED94B3DD64031D94133D43E2F
DE4B3BD84B3ACC4434DE594AD85247D95048DA4F48D4473ED4453DD24239D6433BD8443A
D64238D9453BD94239DC453CDF463EDA4237DA4139D84035DC4236E0483AE95345E45746
D85344CB5040AF3D328F291D72140C610C075B0C08570D0A5912105612114E0C0D501011
4D0D0E521011520E0F52080959090C5F06086C080A8212119F2522B4352EC5453CBE4638
B04734A54A35B86C54AE6C52A1654BA56D549761478350338B5A3A885736804E2D8C5634
7F4422B57655B372549151388E5341632F228F645DC8A39DBD9A94C09D99CDA6A7AB8286
62393D663F424D2B2A997A77B79893B1938BB4918BBE958FC796928D5653854A46864C48
8150497B50497D5B52A5897EA58A7FA4897EA4867CAC857EBD8785702C2B7D27269E3C39
9A332C9D392A943A22883C18793F0D9B72328D71278170227E712B8B8247948D5F9E9B7A
7978640E0E0217170F26252025241F221F1A27241F23201B201D18403D3835342F1E1D18
20211B191813231E1859544E35302A241F192A252126211D241F1B26211D25201C2C2924
41403B23241E191A151B1B191F211E20221FAFAFAF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF4F2C68F8CAE4740CE4940D64739DC4638DA4235DB4335
DE4839D84436DA483BDD4B3EDE4C3FDF4C42D9453BDA463CD9453BDC453AD94136D94136
D84035D94136DB4338D84035DA4036D83E32D93F35DC4236D93F33E2483CEB5346E55143
E05141DE5243DE584CD8584DCC5046B53E36A3322C8E211C8317147B120F78100F740C0B
700A08740C0B7D13138115158D1A1D9E2627AE2E2DC8413ED24440D84B42CF463CC84A3C
B74837AC4B3AC57260AC6352A05B4BA461519B59499F5E4CA46651B1735E9F5E4AA96854
A3614BB1705CAC6D5B995E4E774336603129966D67AF8A84AF8986B6908FCAA0A4895C63
673C4360373B664242C19F9DC1A09BC09D97C29995DDABAAB2757477312F944A4797524D
8D544D6839316B443DB0928AAC8F87AB8E86AE8D86C39A949F69676622218E3A389C3F3A
9C3B329D402F98442A863E1886511DA1793B8E732C8A7830807533968D549B9468A8A383
89867316140817140D29262125221D25221D26221F24211C21201B33322D3E3D3921201C
1C1B1712110C27241D57524C433F361F1A14211E1724211C26231E221F1A1E1B142D2A23
45453D22231D22231E1D1D1B1B1D1A17191668686600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FEDBD7A45F58BA4941D2483ED9473ADC4638DF4539DE4438
DB4335E0483BE1493CE1493EE2483CDE4639DE463BDE463BDF473ADD4538DD4337D93F33
DB4135DF4539DB4137DA4036DB4135D93F33DD4337D93F33DC4335E1483AE85042E95143
E85243EE5B4BE85649E9594EE95D50EE6459EA6459E46157E15E56D34F4ACF4E48CC4B46
C2423FBE3E3BC44443D95757D75253DA5050E15150E34F4BE74F4ADE4942D7493FC94739
B74636AC4B3AC87565B86F60A15C4D9B594B854335884638935143A56355955345975547
955647985A4D885043B17F745A2E257E5750B8938DAD8A86B28C8BB99192AD8085693C43
70464A50292C866262AB8987A88782B08B85BB8B8BD096958E46478333329E4D4A9D524D
91544F5F2E27916A63C2A19AB99C94BA9D95BF9E97CEA7A2794645713433934747994844
9A483D9548368F472F804422916234A8854D977D408F7D3F8C7F489C9463A19972ACA789
9996831F1D1113100928252027241F26231E27232021201C25241F23221D33322E393836
1918140B0A05312E274C494249453C1F1B121D1A13211E17221F1A1E1B161D1A133A3A32
3E3F3721221C21221D1B1B1919191713131130302EBABAB800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF7F5DFAAA49F483FC44B40D64A3DD84637DD4738DF4539E3493D
E95144E85043E3493DDC4236E2463ADE4438E0463AE2483CDE4438E3493DE4483CE2483C
E04739DF4739E2483CDE4438E1473BDF4539DF4638DE4537E04737E14838E64D3DE64F3E
EB5544ED5746F15E4EED5B4CED5B4CEE5C4DEB5C4EEE6052ED5F51ED6154EE6157F3665D
EC615ADE554FE55E5BF66E6EF16767E55658EB5757EB5350E54D48E04B44D44439CA4639
B74636AB4C3AAE614FA36250995E4C9C65519A634F9F6756955D4E9961549860539B6559
9561548E5E527F534AA67E7663403AA98883C19F9DBB9997C6A09FD8B0B18D636763393D
623B3C563433B49592B69794B79691B8908ECD9797BB76797E2D2C9B43429F4A479B504B
7E433D62332BAB867EB08F86B0928AB4968EBE9D98A8827F6D3F3F875453905654915650
965C51925A4B8F5C4983573C9672509D8058947D51917E538F82589C936CAAA18298927A
B6B3A2413F330C0B0623221E28272324231F24231F22211D2524201F201B22222033342F
34332E24241C2F2C2535322B3C3930221F161E1B1217140B19191120201832312C3B3C36
2728221F201A201F1B21201C1C1B171A19151716122C2D28858583A4A6A3D1D3D0EBEDEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF0ECB9766EAA453BCE5044D44638DC483ADA4435E85043F0584B
EA5245E44C3FDB4336DE4639E0483BE1493CE24C3EDE483AE34B40E1493CE0483DE34B3E
DF493BE14B3DE0483DE34B40E1493EE1493CE1493BDF4837E34C39E14C38E24F3BDE4E36
DE5136E85C41EE6249EE6249EC6047EA5E45EE624BE95E47EE624BEB5E4AEB5E4CEC5F4E
EB5C4EE95B4FEB5E55F96B67FA6B67EB5A57ED5854EB534EE74E48DD463FD44137CB4539
BD4A38AF4E3B8A3C268F4E38894F378B553D834F378A583F8E5C458757418556428A5D4A
8F66548B665484635487675C6C4F47B29591BFA09DC09E9CCDA6A7C9A1A2683F456D4649
4E2C2B896A67C6A9A5BC9D9ABD9B99CB9F9EE5A9AB974C50832B2AA64B4AA14B4A9B514E
5D2621865B54BD9890B19089B89790B89591CCA4A27C525367373782504F65322F703D39
68382E75473A693F2F623C297250375B3D21684D2F58412279664887785B7F7359948C77
BAB5A299978A1C1C1416151022211D25242027262221201C22211D1D1C1822211F282723
28272233332B3A37323C393239362F312E25312E2527271D33332B3837323A3B35262721
22231E1F201B22211D2625231D1C1A201F1B1716141313115F5F5D6163606C6E69858681
A3A49FC9CAC5E7E7E500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00EECDC8A05248BF5045D14D41D94A3CDB4739E44E40EB5547ED5749
E54F41DD493BDE4A3CE14F40DB4C3EDA4B3DDD4E40DC4D3FE14E44E35144DE4B41DE4C3F
E04E41E04E41E14D43DF4B41E14A41DD463BE04A3CE04A39DF4E39E0543BD44D2FCD4D2A
CF512BD1562DDC6138E1653FE86C46E46844DF6341E06442E16241E56444E76446EE664C
EC614AEC5F4BEE5F4FF26355FA675DE9564CE8514AE75049E14A41DD463DD6433BCD4539
C74D3EAC45328A341DAC6247AF6C4FA96C4D8C543395603E8C5A3981533181563485613F
7F5E3D674D2C6F5638725A42593F309E8277C3A29DC4A19FD9B2B39F7778633C41633F43
4E2E2FB69896C2A4A2BE9F9CC29C9BD8A6A7D08E907C2C2F95393AAB4D4DA25150823E3B
5B2824AF8682BE9B97B69590BC9995C9A09EC191915C282A763B3DAA706E8C524E97605B
9E6C659869618E6257865C508D66577F5A4894715D664631846853A2897375634DA89C86
B7B09DCDCAB98583771C1C141516101F201B29282425242025211E25221D211D1A1D1C17
1F1E1A2625202C2B272F2E2931302B32322A32322A34342C34332E2B2C2626272221221D
1F1F1D1A1A182624252624251B1B1B20201E1515151313116E6E6C6F706B6B6C6677776F
77776F75776C7E7F77999C93BCBDB7E1E2DCF5F6F100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FFF7F5C1948F9B4339C84F44D1493DD7483AE24E40EC5647EF594AE85244
E24E40E65445E05141DC5041D54C3CE1594BEB6154E85C4FEB5D51ED5F53E85A4EE4564A
E6584CE5574BE5554CE5554CE45449E35046E65447DF503FE45944D85539DE6342E7734C
D56639D96D3ED5693AD86C3EE27648E4774CE07348D86B40EC7D50D7633AE16B43E76D48
E76646E86245DF573DE45942E25541DE4F3EE14F40DF4B3FE34C41DD463DDC483ED2453B
CC4C3FC04C3DAD4834CC7258C06C50BC7050AE6544AB69469B5F3BA16B45986842906942
8D6D477F6540836C4C806B5069503C94766BCAA7A3CCA5A6D7AFB0734A4E6F484D502D31
7A5C5CCCAEACBFA19FC5A3A2CAA2A2E0AEAFA66468752629A54C4EA650519F5554612524
805350CBA5A2B99795BE9B99C29997D9A9A99C61656624268E4848C27B79B26F69BB7A74
AB706AA56C65A26B64B58078BD8880B17F74AF7D729C6E5FA98271A3826F937A66B2A18D
B6AE99D1CEBBE2E0D366665E1415101515131D1C1A2625232C28252D2A2526231E1F1C17
1D1C1822211D26252122211D26252024251F25251D23231B1F201A21221D25252321211F
1D1D1B1919171F1D20211F221D1D1F2626281212141F1F218787877A7A7871706B808076
84847876766A74766977796E727469777870909189B4B5AFD7D8D3EEEEEC00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FCE0DD9C635CA44237CD4F41D2483BDA4839E6503FF15A49EB5544E65041
E95646E65747E25645E96453FA786AFC7D6EFC786BF0685AEE6457F26657F4685BF3675A
F56B60F2685DF3665CF2655BF1645AEE6157EE6255E96050E5604DD2563EE17052F98E6A
DA754BF49265F39164ED8C5FF19264EC905FF59968F39562F69864DC7C49E5814FDE7546
E5764BE5714AD55D38D85C3AD25332D65337D74C35E25140E14B3DE34C41E04C42D8483F
D54B41D65447DA5F50D5624FCC5F4ACC664DCA684DC76C51CB7A5DC37C5EAB6E4FAD7A5B
A9826387684B9E8368987E678366569F7F74CDA7A4DEB6B7BB919562373E6F484D522E32
AF8F90CCAEACC5A7A5C7A8A5D6AFB0D4A3A67B3E438A4347A15559A0585B894D4D562624
AD8784CBA9A7BF9D9BC49E9DD1A0A3D89DA17B3239873539A34D4CC8706CB05D55BD6F65
A55B529A514A9C564EB8726AC68078A25E55A25E55995B50905B4B8D6251A3826FBEA996
B9AE9ACBC6B3F3F1E4AEAEA631312F454547282629171518201F1D322E2B332F2C2D2926
27232027232024201D231F1C22211C1F1E1924251D23241C1B1C161D1E19222220222220
1E1E1C1E1E1C1F1D202220231F1F211F20240D0E135B5C61A2A1A67C7C7C7A797486867C
8A8A7E8182748384768082757E80737A7C6F75776A7173686B6D6286877FA2A39BC7C8C2
E5E6E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00E4C1BD8A473FB1493ECF4D40D84A3CDA4737EE5847F05946E95342E54F3E
EA5747E65746E15544F26D5CFB7969F07162F97568EC6758EE6656EB6252F3675AF3675A
EE6459F46A5FF3665CF66A5DF46A5FF46A5DF2685BF36B5DF36E5DEF715BEA765DF68769
E87D59F48C65FA926BF79169FC9B71F49569FC9D71F99A6CEA8E5DED8F5CEA8A58EB8756
F98E62ED7E53E7734CF9835DEA724FFD8060E9634AD64834E24E40E34C41E04C42DF4C42
DC4C43E3564CDD5348DF5A4BE05E4ED45A45D45D47CE6049CE6A52C97159C0765DAF735B
87574198725DC8A592C0A091B39187B48F89D6AEAFE8BBC093646C71444B663D436E4A4C
D2B0B1CEB0AEC8ABA7CCAFABD9B7B6BD9395562427743C3F884D4F854F4F603232613B38
CAABA8C6A9A5C2A09FCBA1A3E7B0B5BD777F772229A14246AF4D4AA7463F993F369E473E
A7544CA4544BA75750A95A53A859529D4E47AC5D56A25950A2635493604FA6816FC4AA99
BAAD9AC3BDADE6E2D7E4E3DE3C3A3B3F3E435B585F58555C3C3A3D1A1917181715272322
302C2B403C3B29232328242127262223221D23241E23241F1A1A181C1C1A222222242424
2121212121232422272221261213180C0C140F0F1783838BABAAB0838383807F7A8C8C82
8C8C808B8C7E88887C898B7E888A7D8A8C7F888A7D83857877796C797B7075776C6F7166
7B7C74989993BABBB6DEDFDAF5F5F300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00DAB1AB8F463DBC4D42D44E42D94A3CE65041EF5948EF5948E74F41E54F40
F15B4CE85545EA5B4AED604FED6454E75F4FE96151EA6252E86050EC6353F06455F16558
F1645AF5675DF6665BF06153F36559F26456EF6354EF6354EE6253F16A57EC6754EE6D57
EB6D54E66A4EEE7256EB7255EE7759EB7859ED7A5BF0825FF0865FFF9870FF956EED8059
F4825DED7753EA7250EF7455EA6E52FF8468F46D57D94C3AE35142DE4A3EDF4B41E24E44
DC493FDE4E43E15146DC4D3FE35645DE5241DB5441D95A47CF5C49CB6654BC6957A66152
72392EBB8C84D6ADA7D0A9A4C8A0A0CBA1A3E4B7BEDCAAB378445083515C5F343BA57E81
DCBCBDD2B4B2CCB3AFCDB4B0D5B7B5C8A9A7866262734F4F734D4C674442674845AB8F8B
CCB3AFC7ABA8CDA9ABDAABB1ECADB69747528E2F35B54E51AF4945A6433DB3564EB45B53
B56059A4514BAE5D59994844B86861AF5F58AA5A539F524A995548793F31946958CBAE9C
BEAD9BC2BBABD8D1C7F4F1EC7F7D801E1B223D3A4559565F615F64838184575558262425
2725262422231511122521202D2C2A2928262323212426252021231E1F2128292D292A2E
1B1C2018191E21202815131E30303C4D4F5B23232F666670B1B0B68B8B8B8988838A8A80
8E8E8291938690928781847964675E7E7F7783837B85857D7A7A728B8B818C8C82838377
8183787A7C716E6F67707169878882A8A9A4D2D2D0F0F0EE00FF0000FF0000FF0000FF00
00FF0000FF00
00FF00FFF9F3D1A59C96483CC05044D24C40DB4C3EE75143F25C4DEA5443E54D3FEB5345
EB5546ED5748EC5949F36152E85B4AEC604FEE6555E75F4FE25A4ADA5244E1594BE1574A
E1574CE95D50EA5C50EE6052EF6153EE6253F06455EE6253F16556F06455F16556F36756
EE6552F06955EF6653EF6854EC6853E96751E76650E46850E16A4CE26D4CEC7555EB7253
EA6F50EF7256EF6F54EB6B52E86A53EC6B55ED6653E45B49E95B4DE15146E5554AE25247
DF4F44E15146DF4D40E14F42E24E40E14F40E25345D95040D65748CD5C4CC964589F483F
904540E6A5A3EAAEAEE5AAAEE8ADB3EEB3B9FEBFC8C5838D7F3B468F4D576D343BDAA7AC
EDC1C2E1B9B9E2BCBBDEBABADCB8B8D9B5B5CEAAAACEACABC8A6A5C1A2A0C9ABA9D2B4B2
D3B5B3D4B2B3D9AFB3F3BAC3E294A1862934B4474DBE4C4CBF524DC45C53C5625CCB6C66
C26762AA514BBD6561B35E59BE6964B9645DD27E74B06154AC6354834633A57861CFB199
C4B29CC4BCA9CAC4B8E6E3DECAC8C92B282F36333E413E493E3B44B0ADB4D3D2D76C6C6E
7472754D4B4E5856574442433636361C1D1F23262B24292F1F232C1D212A1E212A191C25
2D2D3712121C201F2D21202E373946555764595B6873737DA9A8AD908F8D928F888F8D81
9192849193869B9D927B7E7540433C5B5C565B5A554E4D484F4E4957574F606056727268
83857A797B708183787C7E7372736B696A6261605C7776728D8C88CECDC900FF0000FF00
00FF0000FF00
00FF00FFF7F2C9998FA04E42C05042D24D3EDB4C3EEF5B4DEE5849EB5546E54D3FEF5749
EC5648EE584AF55F51EE5A4CE75848ED604FF56C5CFE7668F87465F77366F57164F26E61
EE6A5DE56152E76253E96153E25A4CE25A4EE45C50E75F53E95F52ED6152ED6152EE6251
EE6553ED6452F26655F16554F26655F26957EF6654F36C58EC6851EC6851EA664FEB6750
E96550E8644FF06C57F06C57EE6956EE6958F0685AF76F61F46C5EF3695CF06457EC6053
E65A4DE25649E6584CE15146E04D43E24F45E04D43E05246D85042D85649D25950B3433F
A94140B65658B75B60B85D64BC626BC76D76D27780AA4D57A0434BAE535A87353BD2858B
EBA4AAE7A6ACE7AAAFE9AEB4EBB2B8ECB5BAEAB6BAF0BEC1EABCBEEBBFC0EBC1C2E8BEC0
E9BCC1EBBAC0F0B7C0FFB9C4BC5F6A9B2C35CA4F52CC4F4DC94F4AC44F48D96965DA716D
CD6763B1504AC66763CD7069BF655DC1695FEE9688B1604BB3694E925634B78B66CFB18D
CDBD9CCBC4A8C3BDADD3D0C7EAEAE85A595E2E2D353E3C4733313C78777FEDECF25E5D62
383639484649BBB9BABBBBBD5D5E63565A63555B69484F61464E61424A5D21283A2C2F40
A6A8B72D2F3C2C2D3F3031433235442125313133405656609D9D9FA1A09C97948D979589
9495879395889EA0957C7D75555650767570706F6B4C4B474E4F4A4F504A2526205D5E56
484941393B307E807584867B7D7F747F7F777F7C757974704C4741524F4AE4E3E100FF00
00FF0000FF00
00FF00FFF5F1C18B81A75144C55144D24D3EE35446EF5B4DF05A4BE65041EA5445EE5849
ED5749F15B4DF35C51F15A4FEE5C4DEF6050EB5F50ED6356EF6A5BEB6758EF6B5EF36F62
F27060F57461F47360F67562F57260F16D5EF47061F16C5DEC6454E86050ED6452EA614F
E85F4DE75E4CE95D4EE95D4EE75B4CEA5E4DED6150F36756F26754F26754F16653F26655
F26655F36A58F36A58F76E5CF26959F16959F2685BF46C60F56D61F1695DF2685BF46A5D
EF6558F46A5DEE6457F4685BED5F55E85A50E6584EE15349E2544ADB5146D9534ACD4C47
C94D4BC24B4DBD4A4FBE4F55BA4D52B3464CAF4047AD3E44BF5154C85B5EB24B4EAA4A4C
AA4E53AA5359B25D64B05F65AF6066B3666CBA6F74BE767AC47F82CC8A8CD39193D69599
DD9AA1EAA3ABF1A1ACD1767F9F3037C24549D24D4ED24B47D8554DC3443DCF544FD25C58
D3605BCC5D56E27570DA7269D67165D17260D17A5FB56540C37F50925B25A98048CAAF7A
D6C89BD4CEAACFCDB6CCCCC0E7E8E38E8F9124232B4947523C3A4746444FDCDBE1B0AEB3
5C5A5D4F4D509F9D9EEBEBED6D6E73262A3321273720283B253044343F553A4058373C52
BFC2D33D405125263A292C3F9FA5B56A6D7C191B28292933706E71B3AFACA6A39CA19F93
9E9E92A2A296ABADA272736B61605B878681807F7B8485808A8B868C8D8876777182837D
55544F4F50488989818C8C8484847C807D76827974857A767C716B3D342FC3BEBB00FF00
00FF0000FF00
00FF00FFF5EFB97D73AC4E42CC5446D74D40E75548F25C4EE85243E75142ED5748E95646
EE5A4CF35D4FF35C51ED564BF35D4FF35F51ED5E4EEF6251EE6251EF6654E96151E96453
E76450E3624DE86751E4664FEB6A54E86751EE6D57EE6D57EF6D57F2705AF16D58F36F5A
F26D5AF26D5AF06858ED6454E96050E55C4CE55C4CE55C4AE45847EA5D4CE95B4DEA5C4E
EF6153EC6051F16554F26655F46857F36A5AF5695CF06659EF6558F3675AF26659F4685B
F1675AF66C5FF46B5BF1695BF06A5EEC665AEC6359E75F53E05349E6584EE15349E1544B
DD5650D95853DA5E5CDB6362D86464D46060D35D5DD25C5CD1595AD25C5ACF5B5BC95756
C45655C25656C3595BBA5052B44C4DB74F50B44D4EAC4848AD494BAF4D4EAD4A4DAC494E
AE494FAD454CB2434AAF383EC13F41D64E4ED84D48D84B44D94F45D64D45D24B45D5504B
D7544CDA5A51E2665CE26A5CDB6B57D16A4BC26A3CBF7538A66C23805506B39442C0AD61
DAD093DDD9ACD7D6BAD0D2C4E0E2DDBFC3C427272F54525F4B495735313FABA8AFF0EBF1
E3DEE2D6D2D3CCC7CBEBE9ECDAD9DE888B9060646D444A562831421E263D3D425F4E526D
A7ACBF70768615182B262B3E8B91A1787B8A1A1C2925252F38363B928E8DB0ADA8A6A39A
A5A59BA4A69BA9ABA072736B77787262635D6465606A6A686667627475708988849B9A96
9A969383827D8A8782999691999490988E8C988888927E7D998481614E4A988D8B00FF00
00FF0000FF00
00FF00FFEEEAB26F67B55046CD4F43DE5245EE5A4EEF594BE85244E54F40F05D4DEA5747
EF5B4DF66254ED564BF35D4FF05C4EF26150F16251EE614FEC644EEB644EE8664EE7674E
E76B4FE0694BE06B4ADD6B49E06E4CDD6B49E16E4FDE6B4CE16B4FE1694EE66D52E5694F
E66A52E96B55EE6D5AF26D5CF36B5DF66E5EFA7161F46B5BF46756F36655F06254EA5C4E
E95B4DEA5C4EE55847EB5F4EE35746E75B4CEA5E51E85C4FEB5F52EB5F52EC6053EF6356
EE6459EE665AED6859EE6A5DE66659E9695CFB796CF77166ED6056EB5B50E9564CE35348
DC5248DA574FDB625AE1706ADD706BDD716EDF726FDB6E6BDD6D6BDA6867D96663DB6865
D96864D96965D76765D56362D36160D2605FD56561D0605ED0605ECF5F5ED05D60CB585B
C95558C85153C94C50D45254D95350D64D47DA4F48D64C42DB5147D3493FDD5049DF5249
DC4F45DD5348DA5246DB5949D25A42C85E37B55C24CF8B40D5A448BF9D3BC7AF4BC2B356
D8D087E2DFAADEDDBED9DACADCDDD8E8E9EB515159363441555361484452807D86F2F0F5
F3EEF29994986D686CB2ADB1EEECEFE5E6EADFE2E7D5D9E2CFD5E3596073313550545571
84879ACCCFDE434655181B2A23273325273319192521202819171C64605FB9B5B2ACA9A2
AAAAA2A8AA9FA9AAA283847C74736E6667618F8E8A72736E50514C51504C5756526B6764
74706D5C5855696562A098969A8E8EAB9798B99B9DBF9B9DCEA8A7A684827B635FF9EBE8
00FF0000FF00
00FF00FEE5E0AF665FB84D43D24F45E5554AF15D51EF574AE24C3EEF594BEC584AED594B
F36251F05F4EEF5B4DF15F50ED5E4DEF624EEA624CEA664DE7674AE16849E26D4ADF724B
E0764CDA7549DD7D4DDA7B4BD67A49D37748D97C51DA7A52DA7853DC7854DE7555DE7353
E17256DF6D52E46C54E56751E86553ED6555EE6555F46857EF6251F36454F56857F7695B
F66A5BF36758F36756F16554F26657F26959EC6255EC6255EA6053E55B4EE55B50E75F53
E55F54DF5B4FE36358E36559DE6459E1675CFA7A71F26D64F0665BED5D52EC5A4DE25446
D65245CF594BB95146AD5048B35E59B4635FB5615FBD6766C56B6ACA6C6CCD6B6AD67270
DE7874DB7571E07A76DE7673E07974DC7570DD7470DA716DD86C69DA6D6ADB6B6ADB6968
DC6868DC6664DE6463DC605EDC5D57D95852DC5C53D9564CD8534ADD574EDD524BE05349
E05045DF5143E05447DB5643D3573DCA5E37AF591ECC8A3CE9BD5ADABE50D4C252D1C65D
D9D37FE8E4A7E8E5C2E1E0CEE0DFDAF4F4F69A99A1201E2B454351555361595762DDDCE2
D8D6DB57555A656368838186EBEBEDEDEDEFE6E7EBE3E6EBF5F9FF979AA9232439484860
69687AE7E6F4C8C6D18281895A595F4443482A292E1A181D29272892918FBEBAB7B3B0AB
B0B0A8AEAEA6ABABA3A8A8A0A29F989E9E96ABA8A1A0A09896968E8F8E89807F7B61605C
4E4D484D4C475E59569D91919E8588AB878BDBA6ACEFB3B5F6B9B8C38C89714842E7CEC9
00FF0000FF00
00FF00F8DCD8AE635DC05148D65148E5554AF25E54E85146E65042EF594BEA5648EF5B4D
F36251EC5D4CEB5C4CF06351EC644EE6644AE56A4BE16C49DE724CD8754CD2754CD27B50
CF7E51CC7F51C87E4FD18959CA8355C27E51C67E56C67D5AC77C5CC67758C87458C77156
CB7159CB6C56CF6855DE6F5CE56D5CE86958E96453EB6451F06552ED604EF16453F16453
EF6153EE6253EF6352F26655F06455F26657F4685BF5695CF86C5FF46A5DF46A5FF36D61
EC6A5DE4685EE06B61DD6D62C4584EB7483FD7605AEA6B64ED675EE95C52EC5D4FE55C4C
D95A4BCF604F8F33247226197131286C312D6A2E2D7032337A38397A34348A403F924442
9B4C489F504CA04F4CA95854B05D57B4615BBE6964C46C68CA716DCF746FD27371D16F6C
DA7772DF7975DC7370DE726FDA6F69DD7069E3746DDD6C64DF6862E46761E96560E75E56
E05349E25649DB5144DA5848D35C44CE6842BD6C37BA7B34EEC367E3C85FD7C559D8CC68
E0D988D1CD90D7D3B0E0DDCEE1E0DCF0EFF4DEDCE7403E4B3330414744554D4957B7B4BD
D8D5DC3F3D4238333A8E898FF2F0F3EAE8EBE6E6E8E2E3E5EEF1F6C5C8D127283A403E54
454255BFBDCBE9E6EFD5D3D6C8C6C7BBB9BAAAA8AB989697A8A7A5C2C1BFBFBBB8BBB7B4
B4B3AEB7B6B1B6B3AEB3B0ABB1AEA7AEABA4AAA7A0A8A59EA9A9A1A6A69EA8A7A29C9B97
91908B8887827D7573978486AA878DB68189CC838AD88388CE7879AB5D598A4F49CEA9A1
00FF0000FF00
00FF00F1D4D0AA5D55C25348D75249E7574CF25E54E85448E85446EB5749EF5B4DF15D4F
F46253E65948ED6451E46049E66A4EDC6A46DD7349D8794BCC7A4AC88251C18458BE8760
C18F6CC08F6FC29473C49577CD9E82DAAC92E4B49EE3B39FDBAA99E7B3A5EAB1A6ECB0A6
EDADA4EFABA2E79E97D58176CD6959DF705DEA715CE96B54E7634CED654FF06351F06352
F16453EC5F4EF16355EF6052F26355F16254F16355F16355EF6153EF6354EE6255EA6458
E4695ADD6D61D57368CB7169A24B447C211E9B3332C75353E76862ED645CE95C52E86054
E16354CC6151822F1F5A1B0C56261C4C251E4A27254A26264F2829542A2C5A2C2E5E2E2E
5A2A285F2F2B61302C612E2B6B383464312D743F39733C37763B377D403B82413F823E3B
8E4745944A47984D4A994B47994B47A2534FAF5B59B05655B65755C75E5BD35D5BDB5B58
D6514CD6514AD05148CA5446C55C49C66C51BF754EB07440E1B671E7C876DDC771D9CA77
F0E7A2B1AB797E7A5F88867A969696ACACB4BFBFCB5655653D3C4E423F52453E508B8593
F5EFF9BBB6BDA69FA6E2DBE2F1EBEFEBE6EAE6E4E5E1E1E3E7E8ECE5E8EF41435228293D
2B293E797687E9E6EFD9D4D8D1CFD0D3D2D0CBC9CACCCACBCCCBC9CAC9C7C8C4C3C9C5C2
C3BFBCC2BEBBC0BCB9BDB9B6BAB7B2B8B5B0B3B0ABB4B1AAB1AEA7ADAAA3ACA9A4A3A29D
ADACA7B5B2ADB8AEADB89FA2B58A91CA8991AB5059B74E55C35757BE5D57A75D54B08179
FFF2ED00FF00
00FF00E7C8C5A3544DC35348DB574BEA5A4FEE5C4FE85446EE5A4CEB5749F05E4FEF604F
EA5F4CE7604AE7674EE06949DC7147D47442D17F47D08A4FC99158BF915FD3AD86E7C5A9
E8C9B4E6C9B7EACDBFEFD2C4EFD1C6D2B4A9C5A79FC2A39EF2D3D0BFA09EAF8B8DB1888C
B2888CAD7F82CE9A9CFDC0BBDC8F7FCA6E57E1785BE67354EA7152E8684BEC654FED624F
F26655F06352EF6153F26355F16254F16254F26355EE5F51F26456ED6152EF6558E76557
E06C5DDF7A6EA35146D18D8494534F5D17156716158F2D2EC65453E66965E8615BE55F56
E16355D9695B9D4434611E0E48180C411F163A211C372221351F213B25273A2222402627
4026254229254A2C2A452725503230492C2850312C4B2A254F2C284F2926552C2A592D2C
5D302D5F2F2D62312D67363263302D67312F662C2B723232772B2D893032932B2CC14D4D
CB4F4DC94E49BF4C45BF594DB55D4F934A377A3E246F411D886434846A317D692C807136
8B835279755058554255544F56555A5C5C665756643D3C4C3F3E503E3C51413E515D596A
A8A4B2ACA9B4C3BDC9D4CED8DFD7E2E6DFE7E7E2E8E4E2E7E1E2E6F1F4F9848692111320
14132142404DD7D4DBE1DFE2D8D6D7D7D6D4D5D3D4D4D2D3D3D2D0D4D3D1D5D1D0D2CECD
D0CCCBCFCBC8CDC9C8CAC6C5C6C2BFC5C1BEC4C0BDBFBCB7BDBAB5BAB7B2B6B3AEAEABA6
B1B0ACBBB6B3C5B9B9CDB4B7C99AA2D48D95B34F59B23F46C85052C15451B05C52915B4F
EED9D400FF00
00FF00E3C2BDA3534AC35146DC564AED5E50EA5849E55242EB5A49F46352EE5F4EE9614B
E56349DE6546DE6E48D57140D68045D28945CE9249CE9E56C9A567DABF90F0DBBEDFCCBD
BEADA6B3A19FF0DDDFDBC7C9907C7E6F595C5843486D585FD5C1CA6B576268525F6A5262
6C505F6747545E3940C49895FAC2B1C27D5ED07B52DB7A4DE0764CE7764EEA6F4EE7654B
EC6551EB624FF16453F16453F16453F16453F06352F06352ED604FF26657EC6758E36859
E2786AC66E6279362D89574EA47973A67974703634631C1A842928C35554E46866E76660
E46157E1675ACE6353933A2A5F1D0F4315083A1C14301D172E1E1E2D21212D1F1F2E2020
2B1D1D2E201F39272733211F463432392723402F283A27214B36313924213A25223B2623
402826422A28402723482C29402423482A2A442221512728511A1D611B1D691012B34B4C
CA5A58C95955CB6560BB645B9B584F5F2E20441F0F452A154731194435163F35123A3414
3433172A2B193C3C3440404044454A45454F3A39472F2E3E3130423132463A3C5146495C
5455674D4E60535166615F7474718284808F9B95A1DBD8E1E1E0E5E7E8ECC8C9CE7E7F84
65646A545358B8B8BAE5E5E5DBDBDBDBDBDBDADADADADADAD9D9D9D6D6D6D7D5D6D7D6D4
D6D5D3D4D3D1D4D2D3D2D1CFCECDCBCDCCCACBCAC8C9C8C6C5C4C2C5C4C0C2C1BDBCBBB7
ABAAA8A8A4A3B8AEAFC1ABAEC499A2DD9AA3B2535BA33238C24A4CC65652B75D5483473C
CAB1AA00FF00
00FF00E1BEBAA7544CC45247DF594DED5E4EEA5849E04F3EE65746EA5D49E65F49DF5F42
DB6442DB7046CF6F3CD27E40D18941D19646D7A858DBB76DCDB579E7D8AFD8CBB8E3D8D4
C6BBBFBCB2BAE8DCE68175816759665D4F5C392C36B3A5B2988C9A574A5B56495B4E3F54
564359675062452A33957270FFDAC5DCA47FD48E5BD28149DA7F48DE7A48E7784DEC7451
E9694CEB644EED624FF16453F06352F06352F36655EF6251F26554EE6555EA6858E26E5F
D9796BA2584B6430254F2A2272554FB59892B6918B6C393657110F862E2CC35B5ADF6967
E36660E0645ADB6559CB6153913E2E5B1C0D3F130832170E2C1A16271D1B271F1D261D1E
241B1C261D1E312726291F1E3A302F2E2422352C273229243A2F2B3025212E2422342A28
332927372D2B3628272F21202E201F423232352122472A2C4117195C1E21640F12AD4949
CA5A58CC5C58C8655FB161588E554C48231A30180E30221731271B362E21322C1E2C2A1D
2D2D231F201A2929272B2C2E32313735343C36343F2C2A372C2B392A2C392124331A1D2C
2326353235443437483C3D51474658484556464250BCB9C2E6E5EADADADCDDDDDFDBDBDB
DADADAD1D1D1D5D5D5DEDEDEDDDDDDDEDEDEDEDEDEDDDDDDDEDEDEDBDBDBDCDADBDDDBDC
DDDCDADCDBD9DCDADBDBD9DAD8D8D6D6D6D4D7D5D6D4D2D3CFCFCDCFCFCDCFCECCCBCAC8
B7B6B4A09C9BA69DA0AD9A9EC5A0A7E5A8B0BA5F689A2B32C54D4FC65551B85C5188483C
A0857CFFF8EF
00FF00E1BAB5AA574FC7554AE25C50F16252E75546E45544E65B46E35F48DE6143D3613C
E77E4FD77A41D48341CD8539D1933EE2AE58EDC06FD7B470D5BF8DE0D1B2CDC1B5E1D8D9
BCB6BAE8E1E9C0B8C5645C6B5C5461423745706671D4CAD56E6373453C4D5F5667706478
4739506350633B212CB18E8AFFD3BCECB58CF7BA81E7A261D18440D37E3DE08046E67A4B
ED7751E76848ED654FEF6250EF6251F06151F26355F16355ED6150EA6554E26958E37969
C473626F342653281F4A2D2544302959443F9F8681BF9E996E3E3A521512823432B45656
D76A67DD6763E36861DB655BCB6153984032601E103D110630150E291A15271D1B241C1A
292323241E1E29232325201D3C34322A221F352D2A2D26202B241E2A231D362E2B2F2725
322D2928231F271D1B2E2422251B19352A283123223D2427370D1158171B6A1012B54947
D55B56CB5249C05649B4615390584B3F1D132A1710261D1626211B27241F24231E1F1E19
2626241F1F1D1C1C1A1E1E1E211F222321262C272D2621282522291411183F3E43636267
4A4B4F363A3D1E23271F222B2424301D1B281D1A2584818AE9E8EDDBDBDDDAD8D9DBD9DA
DDDBDCE0DFDDE2E0E1E1DFE0E1E1E1E1E1E1E1E1E1DEDEDEDEDEDCE0E0DEE0E0E0E0E0E0
E2E2E2E3E3E3DFDFDFE0E0E0DFDFDFDFDFDFDEDEDEDDDDDDDCDCDCDBDBDBDCDCDCD9D9D9
D3D3D3C9C7C8C5BFC1D2C2C5E2C5CAF6C3CABE6B7391282DC34C4EC4534DBC5E548D4B3F
8C7065FFF6EC
00FF00DDB4B0AC584ECC574DE35D51ED604FE45545E15442E4604BDF634BDA6B4DD26F46
E18755DE8E4FD68E44D99846E5AC55F2C06BE2B86EA8884DDBC59EDBCFB9E3DAD5C1BBBF
CBC6CCEBE5EF777382524E5F413D4EA7A0B0F3EBFA958D9C453C4F3E3749D4CCE1D1C9DE
50445A4C3D50422B35E1BEBCCE9B88BC7D5AF2B07CFFBC7BF1AB63D98C44D6813EE08044
E27645EF7850E96849ED654DEF6250F26353F26355EE6052EF6654E56653DF6E5CD87B69
9E59495C2C1E45271C3D2922402E2A3E2F2A4C3935A9918DC4A5A0683F3B521A19772F30
AD5554CF6766E16B67DF665EDF695DCE64569F493A5F20113C11083017102D1B17261C1A
27221F262221221E1D272322332E2B26211E322D2925201C2A252126211D312C282A2521
2A2722282520221D1A352D2B2A221F342C29312525361D203B11155715196F1014C24E4E
D4554ED15347C65849BB64539157493D1D1026150D211C181D1C181F1F1D1D1D1B1F1F1F
2020201A1A1A1B1A181F1B1A1D1918211D1C251F2121181B140E103E3838B0ACABDCD8D7
C7C7C5B8BAB7A2A6A59094957E7F8466656D4B484F646168DCDBE0DFDFE1E0DEE3DFDDE2
E2E0E3E6E4E7E5E3E6E3E1E2E1E1E1E1E1E1DFDFDFDDDDDDDFDFDDE2E2E0E2E2E2E1E1E1
E5E5E5E6E6E6E0E0E0E2E2E2E4E4E4E1E1E1E0E0E0E2E2E2E2E2E2DFDFDFDFDFE1DFDFE1
DFDFDFE0DEDFE1DBDDE6D7DAF0D7DDFFD7DEC87B83852227BC4849C04F4BBD5F55914F41
8D6F64FFF5EC
FFF7F4DAAFA9AD564CCC584BE76253EA5D4CE25544E45B49DE614DD96B52D07155C87450
D28857DA9659DC9C54EAAD5DF5BA6AE9B5699E7537BD9E70E6D5B9DDD3C7DFD6D7A7A0A7
EAE5ECBFBCC7595669504D62403D52948FA3AAA5B95850654840584F475FA39AB57C748C
50445A352738816B77F6D2D6AD7169B56854CE7A55E3905CFFB672F9B469DF9347D9873D
E28343E67B45ED734CEB684AEF674FEF6250EE6150F06455EB6353E46957DD7461C57461
79402F4C281A3C261B382922382A273527243D2E294E3B35937B77BEA29E8E686550201E
692929A35251CD6765DE6D69E26960DC685BD0695AA34D3E5D1F103C1206331811291A15
251B19231E1B272320282421302C29221E1B312D2A25221D2E2B262C2924322D292D2824
27241F2C292225201C312C2827221F372F2D25191B3A1F244114195A1319761316C54D4E
D8544FD25245CA5B4ABC63518C53423C1C0D23120A221D191D1D1B1618171A1A1A202020
1E1C1D1D1918211C191C17131F1A16241C191C1210251A18746A68CFC7C4DAD5D1D7D3D0
DBDAD6D8D8D6DBDBD9DCDCDCDDDDDFDEDCDFD3D1D4CBC9CCDEDDE2E1E0E6E5E2EDE7E3F1
D9D7E4BDBBC6B7B6BCD9D9DBE0E0E0DEDEDCDCDCDCDDDDDDDFDFDDDEDEDCDFDFDDDEDEDC
DEDEDEE0E0E0DFDFDDDFDFDDDFDFDDDEDEDCE0E0E0E0E0E0E0E0E0E0E0E0E1E1E1E0E0E0
DEDEE0DFDDDEE1DBDDE6DADCF2DBE1FDD4DAC17A82B25359B24143BE4E4ABC5B52975346
937368FFF4E9
FFF7F2D5AAA3A65247CD5C4CE56152E95D4CE25645DB5A47D86854CB6B55CB7B64DD987B
E1A37CE0A470E5A869F5B973F2B771B38041A07847E3C9A8DDCCBAE3DAD3C9C0C3CCC5CC
F9F4FB88828E4E495D504D624D485E5A55695C5469574F64544C64534B635D536C574D65
4237482F2130D1BDC8FFE0E7E9B1B2BE756EBC6A55BD6945D88F58FDB873FBB669DC9346
D58139E58344E77747F1754FE76448EB634DEF6352EE6555E86553DF6A58DB7A67AB6251
5E2F1F40231536251B31262031262231262440322F3D2E2942302C83706AC1A9A5987674
5427246D302F954441C5645EE06F67E16C62DE6D5FCC6657A14E3E62231445160C381710
2A120E2C1A163224212B201E332927271D1B362E2B2C24213029232D26203029232E2721
241F192E2923241F1B2D282429242130282627181B3E212543121860171E7A1317CC5251
D9544DD45245C85745BF67538A513E3D1D0E25140C211C181C1C1A1717171D1B1C201C1B
201B18231B18251A161D130A1D13071910014B3F33A99C93DCD2C9C5BEB88C8783B0ACA9
E2E1DDDDDCDADDDCDAE0DFDDE2E0E1E4E2E3E8E6E9E8E7ECE9E9F1E5E4F2D1CFE4A7A5BB
6E6C814F4E5E514F5AB1B0B5EFEFEFE2E2E2DEDEDEDDDDDDDEDEDCDFDFDDDFDFDDDFDFDD
DFDDDEDFDFDFDEDEDEDCDCDADBDBD9DBDBD9DDDDDDDADADADCDCDCDBDBDBDBDBDBDCDCDC
DCDCDEDDDBDCDFD9DBE3D7D9EED9DEF5CDD5CD878FDC7F87A33538BD4D4BBB5A519D574B
99776DFFF5EA
FFF8F2CFA79FA65448CA5A4CE56355E35B4BDD5847DD6453CC6657CA7769C17F73AF7567
D09881ECB491F8BB8CF8BC86D89C68A87546C7A582EFD9C4EBDAD2DCD1CFC4BABBE0D5D9
EEE5EA918790362D3E40374A443D4F484151463D4E443B4C443B4C43374B3F324436293A
3426338D7D87F8E3ECFDDFE7FFDCE4FDCBCED59691A35B4CB26845D38C58FCB877FBB76E
E1954ADC8540E67F45EC794CF07150EF6950ED6452ED6857E06351DE715DD47B69914E3D
5126163E241738271F2C211B2E25202F2523372E293D322C42352F473831705D57A68F89
8667646F43406B302C8F443EBE6058DC7167E37166DA685DCD6558A84C3F6F2115511108
3C09053B120E43211F361A173D25212E1B1533221B35261F32251F2D201A32251F362B27
281F1A332C2628201D362E2B261E1B3227252E1B1D4324294510185F12187D1418CE5250
DA544BD25042C75844BC6551874E3B3E1E11291810211C181D19181B1718231A1B231918
2A1C192B1C1528160C1F0E002B1D02706343CCC1A3C9BFA67973638F8B82AAA7A2D0CCCB
DFDEDCDEDDDBE1E0DEE3E2E0E7E5E6EAE8EBEAE9EFE1E1EDBEBFD38C8EA7606180565678
6667855E5E76343341747379F0F0F2E6E6E6E1E1E1DFDFDFE0E0DEE1E1DFE3E1E2E4E2E3
E9E4E8E8E6E7E4E2E3E3E1E2E2E2E2E2E2E2E1E3E2DEE0DFDFDFDFDDDDDDDEDEDEDDDDDD
DBDDDCDDDDDDE0DCDDE4D9DDEDDADEFCD4DCD8929ACB6E76A03235C0504EBB5A519B5549
9C7A70FFF3EB
FFF8F2CDA59DA6574ACD5F50E36556DE5B49DA5D4BD46554C26A5ECA847C9F686562312C
8C584DE3AC97F9BD9BDBA078B67F58B28663F2D3BEE6D4C8F1E3E0CABEC0E0D4D8B5A9AD
BFB2BBDED2DC817485605566514958534B5A5E5363625765675C6A655A686C5E6D817380
C3B3BDF5E4ECF9E4EDF9DFEAFBDDE9FFDBE6FFD0D6E2A8A6D69382B56C4BD6905CFFBC79
F9B469DE9046DF8342E87E4AED764EEB6C4CEA6651E76653E36B5ADD7663C1705F773C2C
4C2619422A1E3829222D241F2C24212D2522332C26362D28352A244237314435305A4942
6E59549A7D79A37A747E47408B4138B95F56D87067E5756ADD6B60D16356B853478F352A
6717105E1711662521511612541F1947160F4F231A471F17421D153A180F43201A43241F
371A143F231F3418154024213118143E22213B191A491C2154161B630E138B1A1CD65653
D94F45D65142C95643C469548745353F13082E110B2A15122812142C1316301413331612
381A123114042E1400523C159E8C5AB3A6719086558179529A967DDEDACEE4E1DCE3DFE0
E2DEDFE2E0E3E9E5E6EEEAEBE5E3E6CBCAD0A1A1AD696A7C464861464968595C7F6D7093
5B5C7A3E3C542C293A4E4B54E3E1E6E9E7EAE1E1E3E0E0E0E0E0E0DFDDDEDFDBDCE3DEE2
EAE4E8E7E2E6E6E2E3E1DFE0E1E1E1E2E2E2E1E3E2E0E2E1E2E2E2DFDFDFDFDFDFE0E0E0
DEE0DFDEDEDEDFDDDEE5DCDFEBDBDEFFDBE2C9868FC3666EAD3E44BC4A4ABD5A549D544B
9E7C73FFF3EB
FFF6EFC59D95A8594CCA5F4DE36856DD5E4BD35B4ACF695AB96D60B77E77C6989AB98F91
814F4ED29990F0B29DC08367946345CAA68CE3CDBFDFD2CCE7DBDBC4B7BEF2E2ECDCCCD6
DCCCD9F0E2F1E4D7E8D6CBDCC9C0D1C7BFCEC9BECEC8BDCBC1B6C4BFB5C0D2C4D1CEC1CB
C9B9C3C5B4BEC6B2BDB8A0ADBBA1AEB496A294737EEEC5CBEFB8B5AC6956BA6F48E3985F
FFBF78F2AD60E9974EE18144EA7C4BEC744FE8684DE66955DE6E5ADB7C68A75E4D622E20
4E2C203E2A213528203229243028252D28242C272129241E302923332C263E332F473A34
4C3D3865524C9E827EC7A29AA8736DA55E58B75E58D7726AE7786FDF6A60DA6659CF5E50
BC4C41A73B319B30288D261F88261D7B1D13721A0E6D190E6012065E140B5D140D5F1A13
55120C61221B50110C591C195217135B1F1E5416195E191C610F156E0B0E991E21DB5451
DC4D45D84E41D35848C861508F3D2F4E0B02450B09420F0E3F080B480D0F490C0B4B0F07
4B1302582A08926E34C6AB64B19E52887A31938A49CEC793E9E4C4E9E3D3E9E4E0E8E4E5
EAE5EBE7E2E8D6D1D8ACA9B077767E50505A4042513C3F5243485E4B4F6A656986686985
3F3D552E293D261F2F342C39C9C4CBF0EBEFE2E0E3E1E1E3E0DEE1DFDADEE6E0E4F0E9F0
AAA0A88D878BE9E5E6E5E3E4E0E0DEE0E0DEE1E1E1E1E1E1E1E1E1E0E0E0DFDFDFDFDFDF
DDDFDCDDDFDCDFDDDEE5DCDFEADBE0FFDFE6B87680BA5F68BB4951B94649BC5954A15851
9A786FFFF5EC
FFF6EFC19991AB5C4DCE6351E16654DA5D49D46450C46756C17D7292615DDDB4B89E767E
68353AD49A98DD9D93AB7060A17663EBD0BFCABBB4D5CBCAC4BBBED6CBD3EDDFEC9F91A0
9A8D9E988D9E8E8296898093847D8F867F917C75877E7787716B79716B7779717E7A707B
7A6E7A887A878C7C8987737F8C7683745E6A7D6773F6D8E0FFD8DAC88D85BB6F55C57749
F1AD6EFEBC72EEA459E58E49E68149EA794FEA7152E06850DD725ED47B69995A4B4C2013
452A1F3B2A22372C262F2822332B282E292527221C25201A2A251F2A251F342D2739302B
4439354A3C3955443D806762BC9590CE9794C57C76C86D68C9605AED7B71E47063D76153
D15B4DD15B4DD1584DCD5449C34A3FC14B3FB14032A6382B9E3427912B1F8F2A2089281F
7E20187E211A791F17741B156E17106D18136C14136F13146F0B0D770608A02021DC5250
DB4C44DD5144D25344CF5B4C9A34286A0D065E09065E0A08630B0A660C0B6D1009792012
7C2F15A06233E8BC73EED07AAB953F645502A49C54EEE7B0F3EDC9F1ECD9EDE8E4DFDADE
B7B2B98380895C566047444D46464E454851474B573F425344495C52576A5A5B6F3F3D52
322E3F2B24342D22322B202EA79DA6F4EFF5E3E1E4E0E0E2E2E0E3E3DEE2F5EFF3D4CBD0
261F262B2529D7D1D3F0ECEDE3E2E0E1E0DEE2E0E1E1DFE0E1E1E1E0E0E0E0E0E0DFE1E0
DEE0DFDDDFDEE0DEDFE2DCDEE9DADFFFDEE5BA7B84AF555FBE4F58B54247C05D58A25952
99776EFFF5EC
FFF4EFBB938BA65446D06553E16654D85E49D36652C06958BE7F76906360D8B1B68F666E
A67177CC9092C687829C665CD8B3AAE2CEC7DCD0D0CEC8CCB0ABB1F2ECF6B7AFBE635C6C
6B667A615E735C596E57556B5A586E5C5A705D5B71615F746263776364766B6A7C6F6C7D
6E6A797872807D72827B6F7D736670544750BDADB7FCE7EEFFDFE4EDBDBBBF7A6AC77B59
D89560FFC17FFCB86FF2A55FF19356F48859ED7857DC6A52D7725ED382719C64574E2920
39251C352A242E27212E2623332C262F28222E26232A25212C27232C27232D2522352D2A
3C3431413833463B37523F3B6B4C499F726FC88888ED9E9ACC6D67C05950E68072EF8B7B
E3826FD77461D06555CA5A4CCF5B4CD35D4FCF594BD35D4FD25C4ED35D4FD05A4ECB554B
C44F45BF4D43BC4A40B34338B14237A93A31A33631A1312D9F2C299C2221B63230D54E4A
D64D45D74F43D34F42D05043BE4439A32C249E2721A02923A12A24AC332AB0372CBF4F39
BD5B38B16430F2C175F7D782A9903E8E7E31D7CE8BECE6B2DFDABAC4C1B094908F67646B
4B485145444C4A47504B4A5247474F3F42493C3F463B3E47393C45393C4533313C2C2934
322C382D25322F23312719288F858EF6EFF6E5E0E4E2E2E4E2E2E2EBE9EAE3DFE06A6466
6560643D393AB7B1B3F4EEF0EBE5E5E9E3E3E6E2E1E5E1E0E3E1E2DFDFDFDFDFDFDDDFDE
DFE1E0DEE0DFDFDDDEE2DCDEEADBE2FFDEE7BE808BA9535CBC5159B8474BBD5C56A35A51
9A786FFFF3EB
FFF3EFB78C85A75547D26755E26956D85F4CD26755C06A5BC0847AAB7E7BC29B9EBD9299
C69197C3888AAA706EAA7A76F0D3CFDCCDCAD3CACFBAB5BCD3D0D7ECE9F47D7988636073
615E734D4B603E3C51323045312F452F2D4337354B43445952536855586B424355373948
343341403C4A4B45514C444F3F353D685F64EADFE3F4E5E8F8DFE5FFD8D8CF9186C47D61
C78352FABA7AFFC277F3AE63E78D4EF18956EC7C57D5694FD67765C175679F6B607F5E55
5948403E352E312A242A251F2F2822312A242F2724352D2A2A25212C27232E2623312926
302B27322D294036344738355238375E34357E4242BA6C6CB85955BB544BE88274FD9C8B
FFAF9DFFA894FC9584ED7F6EED7E6DE87765DB6A5AD56454DC6957DA6554E1695BE1695B
E46C5EE86F64E16B5FE26E61DD6C5ED56557D56559CE5E53D05E54CF5A51D35650DB5C55
DF5C52E36154DD594DE05A4FD9534AD9534AE25951E45B53E1584EE05A4EDA5647D65E46
D06946B36332E5B271EDCC85C8B16DBAAA6EAFA57089865D6C6A5158564A4745464B484F
4A49514241494241473C3B4137363B2F303433323726252A27282A2727292B2A2F2C2A2F
2F2A312F252E2C1E2D2315248B7F89F8EEF6E5E0E4E3E1E4E2E2E2F5F5F5A19D9E706A6C
E8E4E57A7677ADA7A9BAB4B6B6ADB0DFD6D7E9E3E3EBE5E7E8E4E5E3E1E2DFDFDFDCDEDD
DDDEE0DDDEE0DDDDDDE2DCDEE9DAE1FFDEE7C38A939A4952CA6168AE4043BD5C55A0584C
9A786FFFF4EC
FFF1ECB1867FAB594DD26757E36A57D9604DD06553C56F60B77B70B98C87C69C9EE2B8BC
C79397B683829D6D6BE1BBB8E4CFCEDED2D4CEC4CCB7B1BBF2EFF8B3AFBD5653645C596C
4440517C78879F9BAA94909E8F8B99908C9BA5A2B35F5C6F535065403D504A4856A9A7B2
A19EA5A6A1A7AFA9ADB5AFB1B8B2B4D2C9CAF1E9E7F0E4E4F4E1E3FFE2E0E3AFA4B27257
BA7846EAAB68FFC778F9BA6ADA8542DA7740E0744DD97156CE7662AD65576F3D347A5952
86756E7E756E5E574F3F3832342F292D2822292420302B272D2522322A273028262B2321
312C28302B27382E2C3D2D2D482E2F5A30326725297D2426A43B38E37069F48277F9897B
FE9484FF9787FF9281FB8D7CFF9583FF9C89FF9E8BFF9E8BF5927FE88371E47A6ADF7565
DD7363DC7264DC7566DA7666DC7D6BDE816FE68978E98979E78676E98575E67A6DF18175
F47C6EF5796DF9796EF57067E75E56EF645DFD7069F1675DE95F55E66255DC6151D66753
CA7153B5714CB3875A977B4C6E5B315D502D4E492C44422D4E4E424B4A46464646424146
37353A3432373634372823272823272B262A2A28292321222929272727252929292A2A2C
2E292F2A232B3024322A1C2B827680F4EAF2E7E1E5E4DFE3E8E6E7E9E7E8928E8DA39D9D
877E7F867D7EC7BEC182797C433D3F585254857F81ABA5A9C6C0C4D8D3D7E1DFE0DEDEDE
DDDFDEDCDEDDDDDDDDE2DCDEE9D8DEFEDDE6CC949F8A3D47D46C75AC3F42B857509D5549
9B7970FFF5EC
FFF1ECAA7F78A8564BD46959E36A59D65D4AD36554C26957C68476E0AEA3AB7E79C39794
B88B86A97E78AA8781EFD3D0E0CECED6CACEBEB3BBE1D7E0EEE6F17E78865B5768524D61
3B3748C2BBCBF1E9F8E7DFECE6E0ECF0EAF8D7D3E26763744B465A242031A8A5B0F8F3FA
EBE6EAECE8E9ECE6E6EDE7E7EFE9E9F0E8E6EFE7E5F2E6E6F7E7E8FFE3E2F7CBC2B27A61
B37343D59653FEC775FCBF6EDC8C45CC6C32DE774ED77254CD7662AB655965352B52312A
594640776C66918881857C756A635D453E38342C2929211E28201D332B282F27252F2A27
2D2824312C28352B2A3E2C2C44272957262A63181D7C1C1EC75554E86D66E96D63EC7265
E87264EB7567E97161EE7968EB7A68F08573F48D7AF5927FFF9A88FF9887FE9484FF9484
FB9181FD9383FB9684FC9986F99A86FDA18CFFA694FFA694FFA290FF9B8BFD9687F98B7C
F37D6FF07468E9695EEF6960EC635BEC6258F2655CE95F55E86257DF6455D76759BF6250
A159438A573C6C482E513C2142361E463F2C433F333A3A323E3E3C383A39323234333237
28272C27252A2C2A2F262125292428292428292526292524262521282924252523232321
262427251E262E22302C1E2D796D77F5EBF3E6E0E4E4DFE3EEECEDDBD9DA9791917D7777
89817F83797ACDC4C7D3CACDD2CCCEBBB5B78882842C26283E383A9B9597E8E4E5E2E2E2
DEE0DFDEE0DFDEDEDEE2DCDEE8D7DDFEDDE6D29DA7853842D9717AAC3F42BB5C56995349
9F7E75FFF5EC
FFF2EEB28780A65449D5675AE66B5BDD604ED86552CF6F59D08570BD84718455457C5544
A88474AD9080D3BBAFDBC8C2EAD8D8CEBEC1CCBBC1F8E9F0CCC1C95E566160596B524D61
49445A736E82827B8D7D7688857E908B84967770825B5466393242453F4DE4DFE6EDE7EB
E9E3E5EAE4E4ECE3E4ECE3E4EDE4E5F1E6EAF3E8ECF6E7ECFAE7EBFCE2E3FFDAD3BC8A73
B6774BC48444FBC474FBC16FE1934BCD7033DD784CD77455CE7763A6615265342D54332E
4D38354D3E3B5B4D4A786D699186829085816E65604F4842362F292A251F27221E2B2622
2C27232F2724352A283E282A462226551C2265101793292DDD6362EE6A65ED685FF26E62
EF6D60EC6A5DEE6A5DED695CED6B5DED6F60EA7160EC7463EE7666ED7364F07669F47A6D
F47C6EEE786AF27F6DF38270F48675F88D7BF88A79F78978F98B7AF9897BFA8679F67D72
F2766AF37368F57165F56C62F3695FF2685EEE645AEC665BE36557DD6D5FBE6255873F31
6231224F2F204734263D3327332F242F2C2531302C2F2F2F2B2C2E25292C26272B2A2B30
26262E26263027242F28252E27242B2A282D2D282C2C2827272622242520242520252523
2725282A232A291D292A1C2B827680F5EBF3E6E1E5E3E1E4F0EEEFCFCECCA09A9A4D4747
6F67657F7775C8BFC0918889B0A7A8B0A8A6C7BFBDB1A9A7C3BABBDBD5D5E4E0E1E0E0E0
DDDFDEDDDFDEDFDFDFE2DCDEE9D8DEFDDEE6D39EA8833640DA727BAF4245BB5C5697534A
A6857CFFF6EE
FFF7F3C59E97A25249D4685BE66859DE5D4ADB624DD46C53DD896FC17F6588553A795439
BD9F85DAC5B0DCCCBDDCCDC6E4D4D5CBB8BCE9D4D9D1BEC4D6C5CD594D574A4251514A5C
4F475C5850675D556A5D5668625B6D645B6E5C53664E4556261E2BA9A1ACF4EDF4EAE4E8
EBE5E7ECE6E6EDE4E5EFE6E7F0E7ECECE1E9EFE4ECF1E1EBECD8E1F5DCDFFFE0DAC89A83
B97C50BA7A3CF6BE71FFC473E5974DC96F31DB794CD17050D07B669E5A4D63342C50312E
4B36334D3E3B4537344C3E3B594B4872676391868291888379726C55504A3B33302E2925
2A25212D25223628273E2626461C205413196A0E13AE3D3FE96966ED6660F1675DF46A5F
F3695EF2685DF2655BF5685EF1675AF0685AF16C5DF26E5FF36F62ED695CEE6A5DED695C
EC6A5DEF7061E96A5BF07263EB7061EB7162ED7263ED7263EC7064EB6F63F17367F27267
EF6C62F56F64F36A60F46A60F3665DF2655BEF6258E76155E16657D76D5FB9655A6E3227
4520173A261D2E231D2C29242B2A2826262627262B292A2F22252C20242D20242F242833
242736292B3A2726362C2A382D2D392C2B332A282D2A2829292728262523272725272727
2A25292E272E2A1E2A2D1F2C8F838DF7EDF5E5E0E4E4E2E3F2F1EFC1BDBC959190464040
655D5B958D8BD0C7C8675E5F534B49342C2A7C7472ADA5A3C3BBB9DED8D8E4E0DFDFDFDF
DEDEDEDEE0DFE0DEDFE1DBDDE9D8DEFDDEE6D4A0AC823640DA757DA83B3EB0534E98554C
B0928AFFF5EF
00FF00D9B8B39E544BCE6457E7695BE05D4BDC5F49DC6D52DB7E5FC77C5CAA724FBC9672
D1B698E5D5BCDCD0C2E5DAD6CBBBBCD9C4CBD3BAC0886F75E0C9D1B8A7AF504450382D3D
312839382F423F3649403748413948423747403543443A458C828BF0E6EEF3EAEFF1E8ED
EFE6E9EEE5E8EDE7E9F6F0F4C8C1C98E8693A497A897899883717DEBD4DAFFE4DFCC9F8A
BB7E51B57434F3BA6BFFC473E7994FD07638D8774ACE7150C97B65925447562B244C302C
483632483D37483D39453A36473C3A4136345449476C6260887F7A948D87847B76655E58
463E3B372D2B3020203B2122481B1E56111478181ACB5456EA6662EE635CF3665DF1645A
F2685DEF655AF26659F4685BF4685BF06659F36A5AF46A5DEF675BF26A5EF0665BEE6457
EF655AF1695DEE665AF0685CEF695DEC665AEB6559EE685CEB655AEA6459EF665CEF655B
EC6258EF6259F06159EE6056EE5E55EB5B50EB5D51E86054DF6153DA6F5FC06A5D6A2E23
3D181034211B2F2724292826262628292A2E26262E21232F2127331D243421283B2B3348
292F4532374D393B52373A4D36384725273323232B26252A2B2A2F26262827272929292B
2B262C29222A30232D2C1F29988C96F6EFF6E5E0E4E4E2E3F5F1F0ABA7A68884835A5454
706866A39B99E7E1E1D9D3D3DBD6D3BCB7B475706D332D2D5F5959C3BFBEE7E6E4E0E0DE
DFDFDFDCDEDDDEDCDFE2DCE0E9DAE1FBDDE5D8A6B1863E49D4737A9E3637AD524D97574E
B89B95FFF7F3
00FF00E6C9C59F5951CD675BE66A5EE25D4EE05F4ADF694FDD7959CB7B58BC825CC9A27B
E0C7A8DBCBB2EADED0DED1CBC6B6B7EBD6DDD8BDC6CBAFBBE2CBD5F8E4EFDDCDDAB5A8B9
A59AABA299ACA097AAA398A9A095A5ABA0AEBCB0BCCEC2CCEFE4ECF3E8F0E0D5DDE1D6DE
F0E7ECF3EAEFF2EBF2F6F1F89C96A4736C7C7E72865F5063948393FBE4ECFFE0DCCA9A84
BC7D51B67535F3B86AFFC171E89A50D1783CDA7B4FCA7151C67E68834B3E4B261E48302C
483934443B364B423D4138333F3533403634433937483E3C4B423D675E59817873958C87
8C8280786D6B5B49474F3131522021550D0E882122D95F5EEF6A65F0635AF06258F16359
F1645AF1675CEF6258F4675DF2655BF06359F3665CF2655BF4675EF1645BF3655BF3655B
F1645AF4675DF2655BF1645AF1645AF4675DF4675DF06359F4675EEF6259F2635BF06159
EF5F57F16159EE5E55F25F57EF5C52EF5C52ED5D52E95F52E26255D7695AC56F626D3126
3D1B123624202F272529292B27282D2F2F37292B37292D39272D3D293043373F563D445E
3B425C3C425C3B3F583E435732354625273424242E22212929282E25242A21202529272C
211C23241A23281B2530232DA0949EF4EDF4E4DFE3E5E3E4F3EFEE9D9998938F8E585252
8D8787B0A7A8CEC8C8B9B3B3D2CAC8C9C1BFC1B8B9BCB6B6DAD4D4E3DFDEE4E0DFE2E1DF
E0E0E0DDDDDDDDDBDEE2DCE0E9DAE1FBDDE5D6A7B1823C46D6777D9A3636A9544D91554B
C1A5A100FF00
00FF00F1D9D5AA6963C6655CE2675FE05C4FDF5B4CE16853DA7257D27F5FB17752CDA783
D7BE9FD3C3AAE5D5C6C9BAB3E1CFCFEAD5DCCFB7C4A890A0AB94A6A893A6A18FA5A092A9
998DA5998DA593879D988AA1978A9E9D90A27F7381988C98F2E6F0B0A4AE837582847884
B2A8B1F0E9F1FAF4FEC9C6D1716D7E726D81675E73504357D7C4D7FEE3ECFFD7D6C88F7B
C27E51BF7A39FABF71FDBE6EE19148DA8044D3764BCA7558BC796677453A4D2C2548352F
3F3430433B3849413E443C393F37343C3431413936453D3A3E3731433C36443A38594F4D
6E605D8C7A78977F7D926F6D8C54537F312FA33B38E56A65EB655CF1645AEE6056F26458
F3675AED6056F3655BF2635BF3645CF1625CF1625EF36460F1625EF46561EF605AF1625A
F5665EF06159F4655DF1625AF2635BF2635BF1625AF2635BF1625AF2635BF16159F06058
F15E56EF5C54F25F57EF5A53EF5B51F05C52EF5C52E85E51DF5F52D86A5BC9736673372D
3D1A143826242D27292E2D332D2D352C2C362F313E3134433A3F5241465A454962434760
4347603F445A3D42584042572E2F412224311C1A271C1A251E1C2723222A1F1C232C272E
3E373E5349526D606A60535D9F939DF3E9F1E3E1E6E2E2E4F2F0F17E7A79BBB5B7C5BFC1
837D7FCFC9C9A49E9EA79E9FD4CACBD7CBCDD9CACDDFD3D5CCC2C1D6CECCE6E2E1E1DFE0
DFDFDFDEDEDEDFDDE0E3DDE1E8D9DEFADFE6D3A1AC7E3840D2787A983B36A6584C8B5549
C4ADA700FF00
00FF00FEEBE7B17670BC6259DD685FE16156DE5F50E26B57D87259CB7C5EB87F61E4BD9E
E7CDB2E0CEB8E5D4C4E6D5CDDCCAC8EFDCE07D69755C47585C495C5443565041564C3E55
4C3E55473B5146384F493C504D40524F42532B1F2DACA0ACF6EAF47D717B6153606A5E6A
594F5ADCD4DFF3F0FB908C9B63607366617740364E8F8095F8E3F4FDDEE6F6C3C0C4836D
BE7749CC8746FFC277FBB96BD98640E2854CCF734AC57457B778666B3F344C2F29493733
3C32303D38343F3A36403B37433E3A3E39353934303A35313C37314039333D3532433836
4436334C3935674B48885C5BAA6A68AD5855C75C56E46860EC665BED6154F16357F06256
EF6356EF655AED6359EE655FEA6560E76563E76768E56468E86869E96769EC6667EA6262
EB615FEE6360EC615EEE6360EE6261EC6260ED6361EB615EEE6360EA5F5CF06260EC5E5C
EB5D5BEB5D5BEB5B5AEE5F5BED5C59EA5954ED5E58E75D53E16156D6665ACA7369783C32
3D1A163E2C2C322C302D2C3230303830303A3434403032413A3D4E373A4D303146323348
34374A282B3E2526381E1F31201F2D24222F2E2B36423F485A57606B686F716C73756E75
777077746A72645761382B35A296A0F3ECF3E3E1E6E3E3E5F6F4F57C7B795A5657544E50
8B8788F6F2F386808062595A5F53555F5053605053635356443838BAB2B0EDE7E7E1DFE0
DEDEDEDEDEDEE0DEE1E2DCDEE8D9DEFADFE4D09FA5813C41CB7274933C35A560517F5142
CDBAB400FF00
00FF00FFF4F2BB8680B46257D76B5FE66C5FD75D4EDF705DDC7E65BF755CBD876FD4AE97
D9BDA8DFC8B8F2DFD1CFBEB4C7B8B3E5D7D782737A7A6D77766875746675726674756879
7467786F62736E6071695B6A695B6A4F414E71656FF1E6EEFBF1F9C1B7BF6D626A544852
746D75ECE6F0C4C0CE696677676278574F663D3147D6C5D7F9E1EFFFDBE0E6A7A0C67E65
B87241E4A061FFC37AF9B36BD37B3CDE7E4BCE724DC7775CAF7561643C30482F28443530
4036343E3634403836423A37473F3C443D373D35323B33303C34313B333039312E403634
42333047322F52302F5B2928691F1E8A2C2AD4615CEA6A61EA6458F26657F16355EF6153
F16558ED6559E8655DE56A65DB6B69BD5556B24F54B15059B2515ABC545DD25E6BDC606B
E4626CE6636BE6636BE15F67E3616BE3616BE3616BE36169E36066E66067E66069E45E67
E45E67E45E67E7616AE65F66E85F67E75C63E75C5FE8615EDF5E58D7675CCB746A80443A
3D1A163F2F2F322C3026252B2A2A3228283026263024242E272733232230201F2D2B2A38
3434403C3C484A48555A586367646D6F6A717D767E827B827A737A6C676B5751554D474B
3B3539362C342E242D291F28B6AFB7F1ECF2E3E1E4E3E3E3F2F2F2B8B8B82826275B595A
D0CFCDEEEDEBD3CFCEDBD5D5857B7AB0A4A6D1C2C5CEBFC2A89C9CD6CECCE8E4E3E1DFE0
DEDEDEDDDFDEDFDFDFE2DCDEE8D9DEFDE0E4CB989D843F42C16D6B924239995E4E795444
D6C7C000FF00
00FF00FFF7F4CB9E98AD6358CE685CE06F5FE37463D26D5BD27F6DA1604EE3B5A6DFBFB4
DFC4BDDDC9C2E5D4CDE0D2CFE4D8D8E7DCE0DFD5DDE0D6E1DED4DFDCD1DFDFD4E4DCD1E1
DED3E3DED3E3DDD0E1DCD0DED8CBDCCABECCD0C6D1E5DBE6DFD8E0E6DFE7DBD1DCCFC7D2
E9E3EDEEEBF6888495635E72665E7534283E857487FFE7F7FFDEE7FBC9C8CE8979C97D5B
BD7743FAB977FFBF78F0A561D97A42D67445D17452C4785EA66F5B5F392C4B342E443532
4238374038363E36343F3734453D3A453E38453C373F36313D35323D35323A322F3C3230
40312E472F2D522B2C5B2324691719993331DE6761ED6A60EF6759F06455F06453EF6354
ED6557E9695EDE675FE27975A44C4AA5595BD8929AC37F8AB56E7CB26472C5687BB34C5F
D36776D76B78B74F5AAC4651A94551A3424DAA4652A94551AD4752AC444FAF4752B9505E
B64D5BB74E5CB54C5ABC505FBE4E5CC04C59C95059D75A5EDF6361D4655ECF786F82463C
3D1A162F1F1F27212523222826262E33333B36343F403E494E4C595D5B68615F6D6F6D7B
7775827D7B8673707B6B6871615C62524D514741453C3638322C2E312B2D2C26282E282A
2E282C2C262A2E242C362F36CBC6CCEEECEFE2E2E2E2E2E2E5E5E5E5E5E5B0B0B0C2C2C2
E5E5E3E4E3E1ECE8E7FDF5F3786E6D685C5C7F7073786C6E6E6465DCD3D4E9E5E6DEDEDE
DEE0DFDCDEDDDEDEDEE1DDDEE8D9DCFFE0E5C59195894544B8676392483D915C4C856556
ECE2D900FF00
00FF0000FF00DAB3ACA76559C86B5CD86F5CEC8775D17868A35F54BC8B84E8C8C97E696E
83727A8578818D818B877D86978F9A958D9A827C8A817D8C7C78897F788A7D758A786F84
7A71867D74897B72877A7184766E83766F817F788A8B8496867F918780928F88989891A1
A5A1B29893A76E667D6B61795749603C293DD7BED3FFDFEDFFD0D5DD9D93CF8467BF7244
D8985AFFC178FAB46CE18E4CDB7743DC774DD07556C97E679863515B392D4E3632463837
3E3232473D3E3C3231403634413936463F39453E38433C34413A343E37313B312F3B302E
40312E492F3051282C5F212672191BAA3E3CE56864EF6960EE6457EF6354F06455EB6355
EA685ADF695FD9736EC77371713433CD9FA1FFDEE4FCD4DDFAD0DEFFD4E5E8A5B7964B5F
C175828B434F9E626AD6A1A9DFAEB4CFA0A6C997A0C3919ABF8C93B27F86A9747CAA757F
A06B759B636E9A606C965865A25B6BA95867B45664AE444ED05E5ED66A67C570698A4E46
5C39355C4A4A5E585A605F6566666E6D707971717D6F6E7C6E6D7D6E6D7F5C5B6D525163
434051403E4C34303E302D362E292F2F2B2C2B27282A2625322E2D2D29282E2A292B2726
2C28292924282620243E383CD9D7DAECECECE1E1E1E3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
E4E3E1E6E2E1E1D9D7EFE3E3CCBEBDB4A4A4B1A3A3AB9FA192898AE3DDDDE4E2E3DFDFDF
DEE0DFDEE0DFE0E0E0E3DDDFE9DADDFFE1E3B98184964F4DA85851A0584C8757499C8275
FEF5F000FF00
00FF0000FF00E9C8C1A1675CC7705FCF6A58EA8B79BA6B5CA97067F7D1CEB1989E685863
6A5C6B685D6D6D6272675F6E6E66756C66745E5A68605C6B615D6E615D6E5E566B60576C
60576C61586D635A6D5F586A5C55675D5668615A6C665F716A6677666273635F70656275
68657A676279675D766A5A74402A3F937486FFD8E8FBC6CCDD9A92CD836ACA7D53C47C42
F9BA73FFC076EFA159D4773ADF7646E07853D67B5EC77F6795645355352A4B3631453736
413535453B3C403635423837413936403933453E384A433B40393137302A3F36313E332F
40312E462C2B53262B5F1E22791D20BE4E4CEC6D67EB625AF16558EF6354F06757EA6659
E46A5DD76F66CD7875995959885E5FF9DCDEF5DCE0F2D8E1F9DAE9FFD9EB99647892596A
885260956771FAD9E0FADFE6F8DFE5F7DEE4F8DDE4FBDDE5FFDEE7FEDDE6FBDCE4F7D9E1
F2D7DEF1D6DFF0D2DCF5D1DFF7CBDCFFC8DAFFBDCDA74753C25457D06764C8736C8E4F48
623F3B6C5A5A5F595D53535B4C4F584345514042514142563D3E5238394D3A3B4F3C3B4D
3A374838364434313C302D34332E322B27262F2B2A2F2B2A2D29262C28252F2B2A2C2827
2925262B2527211B1F544F53E5E3E4E8E8E8E1E1DFE3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
EDECEAD9D3D36F6566C1B3B37E6E6E8A7A7A8C7C7D8377778E8586EDE9E8E2E0E1E1E1E1
DEE0DFDFDFDFE0DEDFE5DCDFEBDBDEFFE0E3A96E70A55B5AAA5D559E5E527D5647C5B1A6
00FF0000FF00
00FF0000FF00F6DAD6A47269C06D5FCC6B5ADD806EA05444CB9B8FD1B2AD52373C66515A
5C4C575F525C5C505A5B515A5A50595C555D58515958505B59515C5A525D5B505E5B505E
594F5A594F5A5E545F5B535E574F5C564E5B5A525F5B53605B5561595661585664585566
5D59706058706757715A425A513043E7B9C4EFAEB2DA9087D6866BCE7F54C88247F3B06A
FAB86CF6AC63EC9253DB7640E17449DF7452D4795CCD856D956654513328493630473938
463A3A403635453B3A443A39423A373F37343F3A36423D37443F393C37313C352F39302B
3E2F2C4529285325285A15187C1E1FD05E5DEA6964EF665EEE6255F16858ED6557E7695B
DE6F64CF756DBC7877724144CCAFB3FCE7ECF1DAE0F3D9E2FEDFEEE2BCCB8350619C6978
6D4550DFC0C8FEE7EDF2DDE4F4DDE7F5D9E5FDD7E6FACEDDF2C2CEF4C6D1F3CBD6F3D4DC
F6DFE7F1DDE6F0DBE4F5D9E7F8D6E6FFD4E5F6ACBB963642C95B5ED56967CB736F81423D
4C292740303338333A31313D333542383B4C3B3D5242445B494B6245475C414256414050
3C3A473130382E2B322E2C2F2E2A292925222F2A272E29262B27242A26232925242E2828
2A24242C2626211B1D615D5EECEAEBE4E4E4E2E2E2E2E2E2E2E4E3E0E2E1E1E1E1E2E2E2
E8E6E7DDD9DAB3AAADD6CACCAA9A9BAA9A9BA898998C80809A9494F2EEEDE1DFE0DFDFDF
E0E0E0E0DEDFE1DDDEE5DADEEDDAE0FEDBE193585CAA6462A46055965E4F856558E8DACF
00FF0000FF00
00FF0000FF00FEEBE7A1766FB1675ACD7260C76A58AB5846FEC2B7CD9E989E72738E676C
664349614247583B3F51373A4A31344F36394C37364935343E2B27412F2B46332F49342F
4B332F4E36324E36324C3432483030452C2F442E3148343647373A44393D48424C4D4B59
544F655E526A67546A4125349F777FEDB7B5C37A6BD28163CF7E4FC87E41FAB771FFBE74
F6AC63F5A05DED8850F38456EC7A55DA6F4FCF7459CB846EA97C69573B2D3C292240322F
433836403634473D3C3D33314238363F37343D3834413C38433E3A3F3A343B342E39302B
3F302D4529285726295A1416862725D86560EC6B65ED645AEF6558ED6557EB695BE36D61
D27067CF827C925C5C815E62F7E2E7F1E0E6F0DBE4F6DAE6FFDDED9E75858C5D6D7C505D
8C6E76FAE5EAF3E0E6F1DCE5F5DBE8FFDAEBF2BBCEB57586A46270AB6D78A16F7A94707A
E8D1D9F1E0E8EEDAE5F0D8E5F7D7E6FFD4E3BF6E7D9A343FDA676AD36663CE76727F403B
5531314130363F39433635433638473A3D503B3D523D3F564A4C63424459444557373743
2D2C342E2D322624272725262C28272A26232C28252D29262A2623282421251F1F2B2525
2B2223342B2C201A1C6E6A6BF2F0F1E4E4E4E2E2E2E2E2E2E2E4E3E1E3E2E1E1E1E1E1E1
E2E0E1E5E1E2F6F0F2CEC3C77C6D7095878794888A7B7172B1ABABEEEDEBE0E0E0E0E0E0
E0E0E0DEDCDDE3DDDFE6DADEF1DCE3F4D1D791595AB2716D9C6055895B4C968073FCF3EC
00FF0000FF00
00FF0000FF00FFF7F5C1A29D9D5F54C87263CB6757BB5546EC9486FDADA2F4A7A1F2A8A5
EFAEAAE8ABA8E2A7A3DDA49DD9A29BDAA69BD7A799D2A794CAA58BC6A387CBA689CAA384
CC9F80D0A183D29E86D29E89D49F8FD19D8FD1A092D4A89DD2B0A6CCB5AFD7CBCD8E8691
5044586051665A42524F2F34ECC2B6D19B81BE7950C27942D09049F7B86BFEBA6FF3A960
F49F5EF18E55F28355F27C56E66F4FDD6F54CF735AC67F69AE816E896D5F67554B42352F
3328243D322E433836403533413634433937423A38453D3A433B38473F3C3D33313E332F
43312F462A29552427601A1A8E2F2BDB6861E96960F1695DEC6456EC6859E4685CDB6F65
CF7871BB7B796F4748CAB1B5F9E6ECEEDDE5F1DBE7FDE1EFEBC4D6865B6C976D7B613D49
D0B9C1F6E5EBF0DBE4F3D9E6F9D8E9FFD0E5B3667AA95062CB717DC97982AC70786C434B
DCC2CBF6E2EBEFD9E5F1D5E3FED8E7F8BBCA963944C35258DD6765D66964CA756E7B3E3B
532F314231393C3441383745393B4A393C4D36394C40415545465A3F3E4E3838442C2B33
28272C2C2A2B252422252422282723282723282725282725282725282423251F1F292021
3026273128291D1719817D7EF5F3F4E5E3E4E2E2E2E1E1E1E2E2E2E2E2E2E2E2E2E2E2E2
E4E3E1E8E7E5F7F3F4D8D2D45E53576A60617D74775D5757B3B2B0EAEAE8DFDFDFE0E0E0
DEE0DFE0DEDFE6DDE0E8D9DEF5DEE4E6C3C7824C4CB479738C5B4D825E50B8A79F00FF00
00FF0000FF00
00FF0000FF0000FF00FAE7E3B1827AB46C60CF6F61C5594CD96F61E57B6ED26A5FD87369
DF7E75E0837BDC8279DF877BDE8879E59481E29780E4A184EAAE89F7C195FBC797EFBA88
D99F6DCC8E5DCA875CD38E67D28C68D79271D89578D49A82BE917EB4968BF3E1E17B6F79
53465863506343293297746EE2B69B9A6438C68649E7A45DFFC172FFBE6EF1A75EEC9756
F18E57F18254F17954EE7153E56951E0705AD57964C5816C885B48674D3E88766C8D807A
6459553D322E362B273C312D403533483D3B443A38443C39443C3948403D413735413634
412F2D4729295220216019179F3E38E16F64E9695CEB6657EC6758EA685AE26C60D47269
CE837E8C59587B5D5FF5E2E6EFDEE4F0DCE5F5DDEAFBDCEBA77C8D90647377515E8B6D77
F9E6ECEFDEE4F1DCE5F6D7E6FFD7EAE0A1B6A14457D66D7CDA7680D48288A0636A885F67
F6DCE5F1DDE6EFD5E2F6D4E4FFD6E6C17987A33840DE6366DC655FD46961C6736B723834
502E2F402F373B333E3A38453A3C4B3436453334463D3C4C403F4D3A38452D2C34262429
2624252827232726222524202726222827232928262625232322202A2625282222281F20
2D23242F2428271E21A29C9EF3F1F2E3E1E2E3E3E3E1E1E1E2E2E2E3E3E3E3E3E3E2E2E2
E4E3E1DFDBDAF7F1F19E9596867C7DF8EEEFF4EBECE1DBDBDEDDDBE2E2E0E0E0E0E0E0E0
DEE0DFE0DEDFE6DBDFE9D9DCFAE1E5D1ADAF73403DB38178855E4F7D6656DDD2CC00FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E7CEC7A37369BA6A5FC66054DD685EF2766CEA6C60E86A5E
EB7166E76E63E87062E77163DF6E5CE37661DB755CDB7E5DDB865DE39766EEA970F8B679
F7B676E5A462D48E50C98146C47940C47844C57D4DBD7F588B5D43D6B6A9C5B1B2574A54
5F51624A3844503B38F0D1BDD0A47DCF9B62FCBF7CFFC076FBB367F0A059EC9253ED8852
F38457F07855F17156EB6953E86956E3705DD27563C985728557484E3427513E376B5E58
877C788C817D70655F4A3D37372C283C312D433834443B36433A35463D38463C3A413332
412D2E49292A552221671D1AAB4940E57164E66758EF6A59EB6657E96B5CDE7063D2786F
BB7C776D4442D2B9BCF8E7EDEDDCE2F0DBE4FCE0EEE0BECC8051619C707D63424BD7C0C6
F7E6ECEEDDE5F4DAE7FBD5E4FFC9DBAE5D6EBC5161DE6E7AD47478C77B7F7E4C4FCCACB1
FCE5EDF0DAE6F1D5E4FFD4E7FCBBCF9C4150C55056E46765DC655DD56F63BC6F6567322A
4C2D2B3B2B2E362F3635343C3C3A473939453838443D3B483D3C443431382E2C31262223
26221F2A27222F2C2724211C26231E26231E2A262326221F231F1C2A25222D24252B2223
2D22262A1F252D2228C0BABEEEECEDE2E2E2E2E2E2E2E2E2E2E2E0E2E2E2E3E3E3E7E7E7
E8E7E5746F6C887E7D564A4A736564998B8A8B807E827876DFDAD7E6E5E1DFDFDDE0E0DE
DEE0DFE0DEDFE6DBDFEBD8DCFCE2E5AF8B8B72433DAE8476775C498D806FF4F0E700FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF8F4C7A9A1995B50B85E53D9675DEF6C62F2695FEE6459
F76D62F56D5FF36B5DF57061F3705EF1725FE76F57E47557E37B56E28355E48F59E9995C
F4A968FDB470FFB571FFB874F9AC68EDA261E49E63BD8353B88D6DF5D8C88A7574634F58
6A56613520259E8378FEDBBFEEBB8CF9BD81F6B36FEA9F5BEA9554E6884BEA824FF28157
EF7453F17156EE6A55F16C5BE76555E06D5BD57866C6826F855A4A51372A493830493E38
4D443F6B625D887D799186827B706C5348443E332F392E2A3E35304239344238363C2E2D
412D2E4F2D2E561E1F702220B14C44E56F63EA6B5AEC6957EB695BE16B5FD9746AD0817A
8A55518D6B6AFAE6E8F1E2E7F1DEE4F3DCE6FFDFECA6808F9264717B515D8F747BFBE8EE
F2E1E7F2DDE6F4D8E6FFD7E7E69DAE923442D86972D96A71D87E809E5A5B895F61F8DDE2
F3DEE5F0D8E5F4D5E5FFD5E8CF7E91982F3DE3666AE2615CDB665CD06F5FB87062633128
4628263A2A2B3329312D2A31322F383B39443A38433E3D453D3A413432352F2B2C282423
26221F2926212B282324211C2A27222A27222A252227221F25201D28222230272831262A
2D2027291C23382D33D7CED3EEECEDE2E2E2E2E2E2E2E2E2E3E3E1E2E2E0E3E3E3E6E6E6
E8E7E59D9895968C8B948685A0918E9687848C7E7B908583EBE6E3E7E3E0E1E0DEDFDFDD
DDDFDEE1DFE0E8DCE0EED9DEFEDFE4926C6B9469629E786B6B5945A7A28FFFFCF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F9E6E0A57970A1584FCA6259E66A60F06A61ED6056
F4675DF96D60F86C5FF46B5BF56D5FF67263EF6E5BEC725BE67356E47756E78159E58658
E78D5BE58E58F09C60F3A263F6AB6AF9B473F6BA7EDFAF7EF8D8B2AF9680472E29533A3D
462E2E553832EFC9B6E9B796E29E71EA9A65E8915BE88A54E6804FEF8355EE7854F27557
EF6D55F06C57F26A5AED6859E96757DE6B59D47765CB877483584750392B46382F49423C
4C4441473F3D4B43405F5651827773988D89847975655A56463D3838312B362C2A3B2D2C
3F2B2C4E2A2C581D1F762625BB544DE86F64EA685BEB695BDF6558DB6F65D27975B97876
683C3DCCB2B3F9E5E7EFDEE4F0DDE3FCE2EDE1BBCA7F54659E727F603A45CEB7BFF6E5EB
F0DDE3F4DAE5F9D9E8FFD0E0BA6373B54B55DF6E74DB7276C77778794142CAA7ABFBE4EA
EFDAE3F2D8E5FCD7E9FFC4D8A34756C34E57E76567E4635DD56456D27564AB68585E2F25
432724392B2B372C34342D3537313B39363F3B3843403D463B383F2B292C2824252D2928
2B272429262128232027221F2C27242C27242C2324281F20251C1D2E252632272B30252B
2B1E27271A234B4048E1D8DDEDE9EAE0E0E0E2E2E2E2E4E3E0E0DEE2E2E0E3E3E3E2E2E2
E1E1DFEAE9E5E4DFDC8C8280998E8A9688859B908EA39997A49C9A7F7B7AE1DFE0E3E3E3
DFDFDDE3DFDEE7DBDDF1DBDEF5D5D886605FB0857E846256665647CECABE00FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E5C8C298635BB8645AD16559E86C62EA665A
EA6256F2685BF3675AF56C5CF56B5EF46C5EF46C5EF06D5BEE705AE66C54EA775AE77958
E67C55E68155E58352E68854E18A54E1925AD7925BDAA273FFDDB7D1AC92B88E82B1867F
AB8079DDAD9FFAC0A8D58E6EE58D67EB8A5FED8359EB7E55EF7B56EF7657EF6F54F16D58
F16A57F46C5CF1675AF0685AEB6758DF6A59D57662CC85718E614E543A2B473930443D37
47423F45403D48403E473F3C453B39584E4C796F6D9389879088857068654E44423A2C2B
301A1C4521235B1F217A2928C05753E66F67E86A5EE3695EDE6F66D0736EC88081824E50
927275F9E5E7F1DEE2F1DEE4F3DEE7FDDFEBA97E8F93677681596496777FFAE7EDF1E0E8
F1DCE3F7D9E3FFD9E7E2A4B3983844D6676EDB6E71D67878A25E5D835557F4D9DEF2DEE7
F1DAE4F5D5E2FFD6E7D18A9C9A303CE2636AE86261E16158D66658D178689A5B4A4F271B
41292535292B372D35352D383A343E3B35413D3A453B3841302D3429272A232122272624
2925222622212824252C28292D27292C26282920232920232E25282E252831282D31262E
2C202A1E121C5B5159EAE4E8EAE5E9E1E1E1E2E2E2E1E3E2E3E3E1E4E4E2E3E3E3E2E2E2
E1E1DFEEEDEBCDC9C8696461877D7B796E6C817674635958847E7E6F6B6AE8E6E7E4E4E4
E0DFDDE1DDDCE8DCDEF5E1E3DEC0C264413FBF9A916F53477D7367ECE9E000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF7F4C5A6A1995F54B96759D26C5DE06A5C
E7695BE45E52E96153E95F52EC6255F06457F4685BF3695CF36B5BF3705CF1705BEB6D56
EC7358EC7557EA7854E87852E97D56E88359DB7B53DA855EF1A686F1AA8EF0A892F3A797
F2A998F8AA96E18971E07E63EB7F62EE7B5CE97254EF7357EB6D54EF6D57ED6855F16A57
F16858F16858F76B5EF1675AED675BE16959D97865CE8572916250573A2A49382E463D36
49413E443F3C443F3C46413E453D3B463E3C4139374E46446B6361867E7B958B898A7C7B
6B565550292A531719701F1EC05656E6706CE16A62DE6F66D67972AF65628F5B5D5C3A3B
D3BDC0F6E7ECEEDDE3F1DCE5FCE2EFD8B6C675495AA074835E3D46D4BBC1FAE7EDF1DEE4
F5DBE6FBD7E3FFD1DEB56B78AF4954DB6E74D57173C87776794343C8A6A7FCE5EBEEDAE3
F2D8E5FAD4E3FFC7D6A85161C04B54E86165E7605CE4665AD36858D17E6C89503F472519
37261F3128293932393B353F37343F3A3742413B47322C362D2A312C2A2F282629252525
26242527252828262B28252C2A252C2D262E2B212A2A20282A2126251F23251F232B2129
3329322D262E736E74F0EBEFE6E4E7E2E2E2E0E0E0E3E3E3E4E4E4E2E2E2E1E3E0E1E3E0
E3E3E3F2F0F1B6B2B3736D6DD9CFD0D9CFCE9F9594A69D9EEDE9E8DBDAD8E2E2E2E1DFE0
E2DEDDE3DDDDE8DCDEFAE7E9B89E9D5A3E3AB59D91635346A8A19900FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F8E9E499786F8D594CB0685AC56D5F
D26D61DA6C5FDC665AE56B5CE06053E26052EB6559EF6759EF6759EE6656F16959EE6958
F16E5AF2715BED6F58EF7359EF7357EB7456EA775AE5785BE37E62DF7D62E07C64DD7962
DA7762E07A64E4765FE8745DEC725BEE705AF06F5AEF6C58F16C59F06858F16858F66D5D
F16858F2685BF4685BF2685BEE685CDF6556DA7563D1836FAB73645E382B4D342D4A3B36
483E3C423D3A433E3B443F3C423D3A453F3F423C3C413B3B473E3F48403E58504E7B6D6C
9F8689A87F83A264678D3B3DBF5756E2726EDB6E67D7766FBC716C753D3CC8A4A6D2B9BD
F1E1E4EFE0E5F0DCE5F8DEEBFFDFEEA982948F60727B515F95777FFAE5EAF3E2E8F0DDE3
F5DBE6FFD8E6E0A3B28C3C49C8646ED87077D57C7EA05A5C835659F6D9DDF6DFE7F1D9E6
F5D6E5FFD5E5E096A5932F3BE16367E95F5DE66057DF6558D46D5EC97A6B7A4638402217
31221D2B25252E2B32322F3A3632403834423C3642302A3429262D26242928272C28282A
28272C26252A1F1E24201D261E1B241F1923251D28302931302A2E3832364D464D5F585F
726B735550568A888DF3F1F4E4E4E4E3E3E3E2E2E2E3E3E3E3E3E3E2E2E2E1E3E0E0E2DF
E3E3E3EAEAEADDD9DA7872725B5253574E4F746B6CD3CDCDEDE9E8E4E3E1E0E0E0E2E0E1
E1DDDCE5DCDDE8DCDEFCEAEA8B7371776058A69687655B4FDEDBD600FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3D6D0C0A9A1B29087AD7E74
AF756AB97367BF6D61C96D5ED36D5EDC6E5DE16C5BEA6F5FEB695BE86455EC6758EB6655
EA6552E96451ED6857EF6A57F06C57EF6D57F06F59F47660F17762EF7661EE7763EF7864
E8705FEC7362F17462F1705DEF6C5AF06B5AF06B5AF36B5BF06858F2685BEF6558F66A5D
F1675AF2685DF4675DF1645AF26A5EE46658DF7162DA7E6FB672676E3C335635304E3938
493B3A443C3A413B3B423C3C423E3D413D3E423E3F423E3D453F3F45403D433E3B463A3A
533A3E774E54A86A6FB9676BC76363DA716DD3706AD7847E7B3F3E9D7575FFE7EAF2DFE3
F0DDE3F2DDE4F3DCE6FFE1F0DBB2C48152669C6D7F633D4AD6BFC7F5E6EBEFE0E7F0DCE5
F5DDEAFCD3E1A1616FA04E5CD0757ECE757BC4797D743C3FBF9CA0FDE4EAF1DAE4F3D7E5
F8D6E6FFCFDDB65C68B9464DEA6465EB605BE35E55E0685ACF6D60C2786B6A3A30351A13
2B201E2B262A29262D29273232303D3634413733412A27322E2B3428252C252229262429
1A171E1F1C232A273035323B413E475C575E6E69706E696F726D716F6B6C696367565054
443F452C272DA09EA3F3F1F4E3E3E3E2E2E2E2E2E2E3E3E3E3E5E4E2E4E3E2E4E3E1E3E2
E2E2E4E9E9E9F2EEEDA49F9C473F3D534B49C4BCBAF1ECE9E3DFDEE1E0DEE0E0E0E1DFE0
E1DBDBE4DADBEFE1E1F0DEDC614A44AB998D84786A8B877BF9F8F300FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF4F0F6E5DE
ECD1CADAB5ACCC9D93C0867ABA7669BF7164C46C5EC96959D66F60DB6B5DE36F60E66E5E
E56A58E66957E46254E76354E86352E45F4EEE6656EB6353F26D5CF16C5BF36E5DF4715F
F36E5DF67160F46C5EF66E5EF16959F06858F56B5EEE6457F3695CF1675AF4685BF3675A
F1675AF1675CF5685EF3665CF1695DE8695AE26C5EDE786CC8766B793A335D312E543837
4E3C3C473D3C483F40423C3C403A3A3F3B3A433D3F453F3F433D3D403A3A464040473B3B
4F363A5A313762232B823036C76363DB7370D97872B665618A4E4DF4CACBFFE2E5F8DBE0
F8DAE2F8D9E1FEDAE6FFD7E5A66F82975E6F81515F9B7580FDE6EEEEDFE4EFDEE6F0DCE5
F9E2ECF0CFDA743C498A46519F58609D5A617541458D6468F5DADFF2DDE4F3D9E4F5D5E4
FFD7E8DB99A799313ADF6164EA605DEB6258E46457D56557CF7668AD6B5F582D27311917
2B21202523262B282F2A2931302D382E2B362A27322F2C35302D342D2A313533384B464C
5A555B6F6A70807D84838087807E837573786560644843473C3839363233302A2E2D262D
27202739343AD3D1D4EDEBEEE2E2E2E2E2E2E2E2E2E2E2E2E2E4E3E1E3E2E3E5E4E2E4E3
E5E5E7EEECEDB2AEAD888481A39E9B918C898B8683E2DEDDE6E5E3E1E0DEE0E0E0E0DEDF
E3DDDDE6DADAF4E4E5C9B7B35E4C42B1A1946B6557D1CEC500FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF5F0FBE6E1EED3CCD8B6ADC79C93B9877CB5776AB87061BE6F60C76E5C
D06F5CD66D5AE06F5FE46C5CE86D5DEB695BE96455EA6252EA6151EB6250EE6553EC6351
F26655F06453F46859F86C5DF66A5BF36A58F66A5BF66A5BF26657F46859F26959F16858
F36A5AF1675AF5695CF4685BF0685AEA6657E6685AE47468DC7B728C4239531E1A4F2C2A
432E2B413332463C3B3E3838443E3E3F3A37453C3D443B3C443B3C433A3D413B3D413537
493336593237602129752329C35F61DE7572DA726FAB4E49B56969FFC3C4FEC6C9FECBD2
FFCDD6FFCDD9FFD3E1E4A7B6914957B06A75804B55E9C1C9FEE3EAF3DEE3F1DEE4F2DDE4
F4DFE6F6DDE3C6A3AAB28A92AC858A967377A08689E0CCCEF7E4E8F0DBE2F3D9E4FDD7E6
FFCBDCA55361BC4851EB6566E9605AE76357DF6757D26C5DC97B6E91584F44211B321E1D
281F202321222E2C2F363437413C424D484E534E546560646E696D7A76777D797A807C7D
777374676364585357474246383637302E2F29282624232122211F2824252922292E242C
2319216B646BF1EFF2E4E4E4E1E1E1E4E4E4E2E2E2E2E2E2E4E4E4E3E3E3E3E3E3E4E4E4
E9E7E8E6E4E58A8687D0CCCBD7D1D1C8C2C28B8786D6D5D3E6E5E3E1E1DFDFDFDDE1E0DE
E6DDDEE8DCDCF9E9EA93817D8072678D8377827E75F7F6F100FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F0FAE6DFEFD1C7D9B3A8C6988BB77F72
AF6D5DB96D5DBD6A5AC96D5ED0695ADC6B5DE66B5CEE6A5BF36B5BF46B59F56A57F46956
F26752EC614CEC5F4DF06351EF6352ED6150EF6354F36758F36758F66A5BF5695AF36A5A
F16858F36A5AF26659F66A5DF06757EF6759EE6A5DEA7063EB7F72AF574B5D1A11501F18
401F18321A16372825382D2B3B313038302E403635433938443A3B433A3D42393C433739
4C383A542F365D212974252BC15F60E17573DE6E6ACD615EC46561CA7270C97779D28388
D78A90E1949CED9DA8B05D67B45761BE676DA55E64FFCACDFFD1D4FCD3D9FCD5DAFED6DE
FDD9DDFDD9DDFFDCE1FFDEE2FFDDE1FCDDE2FBE1E4FDE2E7FBDEE3FBDAE3FFD7E2FFD4E2
DF93A09B3743DE6064EE6261EC6258E46254D96858CB705EBD796C825349654A43695B58
6A6464706E6F7975767E7A7B807C7D7C78797571726A66675B57564C484744403F3C3837
2A26252E2A292E2A292B2726322E2D2C2B272A29252A2925252422262223261F262C222B
2319219F999DF4F2F5E4E4E4E3E3E3E5E5E5E2E2E2E3E3E3E3E3E3E3E3E3E3E3E3E3E3E3
E5E3E4F0ECEDCECACB938D8F544E4E6D6767AEAAABE9E7E8E1E1DFE2E2E0E1E1DFE3DFDE
E5DCDDEBDFDFF4E4E462534E9C90847F796BBDBCB700FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FFF1EDF5E1DA
E6C9C1D1AFA5BB9389B48073B16C5DBF6759D06658E06858E36451EC6A54EB6750EC684F
F06D51EF694EF56B51F46952F16450EE614FEE6150ED5F51EE6150F06352EC5F4EEA5E4D
EB5F4EED6152F16558F06457F26659F2685BEE6457F16F5FEA7564D66F5E863021611D10
532214431F133A1F182C19132A1C192D22202F25242E2423352C2D3B32333A3132403436
4B37395330365D262C74292EBF5F60DF726DE36E67E46B63E9726AE9766FE3746DDF7370
DC6E6DD86A69CF6162C85759DE6C6CDB6F6DBF5D5EDB8181DC8A8CDF9093E0959AE39B9F
E29BA1E8A3A8EFADB1F1B0B6F6B9BEF7BEC4FDC6CCFDC8D0FFC7D0FFC8D1FFC3CFEF9FAC
A43F47C54E52EB6564ED6059EC6458E26455D46B58C87563AB73627854466E5A516D645F
635E5B585453575153464243403C3B3433312F2D2E2725262A29272625232D2C2A2C2827
2C2825312D2A2F2B282A26232F2B282A272226231E2B27242C28272521222822262A2028
332C33CDC8CCEEECEFE3E3E3E3E3E1E3E3E1E4E4E2E1E1DFE2E2E2E3E3E3E3E3E3E3E3E3
E6E4E5F1EDEEC5BCBF70676A685F60A49E9EE8E4E5E5E3E4E1E1DFE0E0DEE1E0DEE3DFDE
E5DDDBF2E6E6D1C1C1463835B9B1A69E9C8FEBEAE600FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF4EEF9E2DACCA49AA2685AB86B5BC86957D66C56E47059E87057F07458
EF7455EC6D4DE46143F06A4FEE664EEF6751F46956F36A58F46B58F26B57F16C59F16C5B
ED6A58F16E5CE96556E66253E35E4FE56051E76253E36151DF6653E87965BD5A47913A29
6E26175F24165323174721183C1B162F1612331B19301C1B2C1C1C2A1C1B302021332022
3C23264824285922286E2327B15250E3746DE66B63EB6B60F16F62EF6D60F17367F2736A
F07168F17168EB6A64EE6D67E96A64E86D66E9736FE2726EDE726FD66E6DD46D6EC96567
C26263BF6162C06263C06668BA6467C06B6EC9747BC6747AC6747ACC757DC76A74B64E55
CB5355EA6664E95E59ED6057EB6559DF6556CF6B5BC67D6C9D6E5E52382B40312A3A3531
34302D2B2726302C2D2A26272C28272F2E2C2726242827252B2A282B2A282726242C2B27
2B27242E2A27292522282421342F2B2C272328231F2723202F2B2A2C28292A24281F181F
615A61EFEAEEE6E4E5E4E4E2E3E3E1E3E3E1E3E3E1E3E3E1E2E2E2E3E3E3E4E4E4E3E1E2
F0ECEDCFC6C77A70719E9495C2B8B9A39D9DAEAAA9EBEAE8DFDFDDE1E0DEE2DEDDE4DFDC
E6DEDCF7EDEB998E8A574E47BCB8ADD0D0C600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFF0E9B3988D89604EA96F5BBB7059CD735BD06A53E6785D
E17052F07A5CF37A5BF57A5BF06F52EF6D53EC6851E9674FE86A53E76D56E56E58E6715D
E67360E5725FEA7764E97462E76F5EEA7261E86F5EE16A56DA6551DB6B57DB6E5AD36A57
AA49368E35237C2A1C722A1C6E3025511D124B1C16441D183A1B1634181533191835181A
3414173F15194F1219621318A74544E5746EE76B61ED6B5DEC6859F06C5DEF6B5EF16D60
EF6B5EEE685CEF695EEF6B5FED685FEE6B61EF7067EC7066ED726AEF766DEA7169EA736D
EB746EE6706CE7716DE16E6BE16E6BDF6C69E36F70E16D6EDC6869DF6969DC6163E26563
EB6562EF645FEF6259EA6055E96559DD6759CD7162C684767E564A432F263C332E373330
373634312F302B292A2E2A2B2925242B272426221F29242126211E2D2825292522282520
292621292621262520272621332F2C2D28252924212C26262A26252D292A2A2529221D21
989699F5F3F4E2E2E2E3E3E1E5E5E3E4E4E2E2E2E0E3E3E3E4E4E4E3E3E3E4E2E3E7E3E4
F7EEEFB4AAA9A09292D0C2C2CBC1C095908DB8B4B1EBEAE8E0E0DEE2E1DFE4E0DDE4DFDC
EAE2DFEDE6E07F7B709492869A9A90E9EAE400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00EEE7DFA391838A6D5B946754A76D59B56D57C16F57
BE674BD07256DE7C5FDC7759DE7558D76B4FD86E54CF674ECF6D54C0644DC26A56C6715D
C26F5DC3705EC56F5EC6705FCB7260D17663D07361CD715CD0745FCC7059D2735DD37762
C56954C16953B15C48A65544944B3A7E3B2B692B1E581F144C1A1144150D3E110C3E0E0C
400D0C480C0C52070B5D0305A23936E8716BEB6D61EB695BE86553ED6857EF6759EF6759
F26A5AF06858EF6759EE695AEE685CED695DF26E62EF6B5FEE6C5FF27063EF6D60F06D63
F06D63F26F65F06D63F26F67EF6C64F26F67F5706BF26D68F26D68EE6763F16862EF645F
ED6059F3665DEE6157EA6256E66659DB6B5DD07A6DB97D725F3D343D2C253B3330343331
3433312C2A2B2927282A26252824212925222B262327221F2D25232E29262E292528231F
28252026231E27241F27241F2723202824212822222F29292822222E2A2B2F2A2E2E292D
C6C4C5EFEFEFE3E3E1E2E2E0E4E4E2E5E5E3E3E3E3E3E3E3E3E3E3E4E2E3E7E3E4E5DFDF
F4EBECE6DADAA59796726463675D5B8F8A87E6E5E1E5E4E0DFDFDDE1E0DEE2DEDBE3DEDB
F2EDE9CBC8BF8587797B7F719EA19800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F2EEE2D9D2C3B2A89F887A92715E946B55
9E6F55AA745AB1735AB07055B67359AE6D51AE6E53B1755DB27F6ABD8F7FBE9486B89084
B28C7FAE887BA98175A47A6CA37868A67868A0715FA1715DA27059A6745BA47058A77157
A86E56AA6E54B2745DB3725CB26F5CB06C599A51408940317D3425772D206D201667190F
67170E69120B6D0E0A72060397201AE0645CEE6E63FB796BF4715FF4715DEF6A59EF6A59
F06B5CEB6657EE695AEB6657ED695AEB695BEA685AED6B5DEE6A5DEF6B5EED695CED695C
ED695CEE6A5DEF6B5EED695CEE685DF16B60F36A62F56C64F0655EF0665CF2655EF0635A
F2655CEF6258F06359EB6559E26859D66F60CD7F72A36D614D2F2741322F3E3634353130
302C2B332F2E2D29282B27242A26232925222C26262A252227221F2B26222C24222D2523
2C27232A252128232026221F1F1B1825211E2723222925242721232B25292620244C474B
E5E3E4E8E8E8E3E3E3E3E3E3E2E4E3E3E5E4E2E2E2E3E3E3E4E2E3E7E5E6EFEBEC908A8A
968D8E998F8E9F9492978C889A938D97948FDAD9D5E7E8E3E1E1DFE1E0DEE1DDDCE4E0DD
EFEEE9B1B3A88E94866B7366D7DCD500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F5ECE4DACEC4B4A4
AD9887B39A86BA9B89BC9B8AC3A08DBE9E89C0A18DD8BDACF1DED0FFF2E8FFF6EDFDF3EA
F8EEE5F2E9E0F2E5DDEDE0D8EBDDD2EADACDDDCBBDCFBCADC3AE9DB8A390AA947FA28772
95796391715C8E68559166539665549B6654A36858A76857AB6858A86353A155479C4E41
9C4A3EA24A3EAB4D43AC453CB6463BD86457DF6759E56B5CE96E5CEE715DED6E5DEF705F
F07160F17261F47262F57363F27060EF705FF27062F16F61F36F60EE6A5BED6859F06B5C
EE6A5BED695AEC6756ED6859EF6759EE665AF2695FEA6056EF655AF06359F06359F16359
EF6157F26659EE6255EC6859E06657D77061CB7D708F564B4F2A22472F2B40312E3B302E
342A28352D2A2F2A272E29262D2926302C292C28272925242E2A272D28252C23242B2223
27221F2D28252C27242B26232824232622212624252725262722262B242B1C151C928D93
F3F1F4E5E5E5E3E3E3E4E4E4E4E4E4E5E5E5E3E3E3E4E4E4E4E2E3E9E7E8EAE8E9979392
817B7B7D75737E767381797679767163625DDCDDD8E5E5E3E2E2E0E1E0DEE2DEDDE9E5E2
EBEBE3A0A398626A5D8E968BF6FBF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFBF5FFFBF5FFFBF5FFFAF5FFFBF4FFFAF300FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDF6EEF5EEE6
EDE4DBE7DDD3DDD0C7D0BFB5C1AFA3B4A193AB9387A4887C9F7F729E786B9A6F5F9D6C5D
AB7364AA6D5BB57061BC6E61C06A5BC76A59CC6858D06958D36854D76855D86755DE6B59
E36B5AE16857E46959E56758E96C5AEA6D5BEE6F60F37463F3725FF47360F26F5DF87563
F67361F77462F77364F67263F67162F67162F16B5FF36B5FF0685CF66E62F4675DF4665A
F36559EF6153F16556E96455E06556DC7063CC76697E3A2F521D154B231B3F21173A2218
3320192F221A2E272128242124231F2726242523242422232625232A26252C26282C2628
2E282A2B25272C23262B25252C2829201E1F211F2228262B2621282520273E3940D9D4DA
EEECEFE5E3E6E4E2E3E5E3E4E4E3E1E4E3E1E4E3E1E4E3E1E2E2E0E3E3E1E1E1DFE3E3E1
E5E4E2E5E4E2E7E3E2E7E3E2E4E3DFDADAD8E3E3E1E2E2E0E2E1DFE1E0DEE4DFDCF2EDE9
C1BEB5787A6F646A60CFD4CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFFAF4FBF2EBF5E8E0EFDED4EAD6CBE3C9BC
DDBDB0D0AC9ECCA093C79688C68E81C38576C27F6FBE7566BF7363C07160C16E5EC46C5E
C76B5CC76A59CC6B5BD06C5DCD6758CF6857D46959D46657D76855D56452DB6A58DB6856
DA6554E16C5BE06858E36B5BE26859E56A5BE56A5BE76C5DEB6D5FED6D60EC6A5CEB675A
E76253E56051E66152E46252DD6354DC6E5FC165567325185E1C0C511C0A461C063E1E07
361D07291806190F03100C030B0A050B0C070C0A0B0D0B0C110F10100C0D100B0F171216
1B1519161014120C0E140E101D1B1C2A282B2F2E342F2E36302F373E3D4598979FDEDDE3
D7D6DBE0E0E2E4E2E5E7E5E6E7E5E6E6E5E3E5E4E2E2E1DFE0E0DEE1E2DDE0E0DEE2E2E0
E3E3E1E3E3E1E2E2E0E3E3E1E1E1DFE2E2E0DFDFDDDFDFDDE0DFDDE1DDDAE9E1DEF3ECE6
6E6A5F64645894978EF6F8F300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFAF5
FFF9F5FFF9F5FFF7F2FFF3EFFFEEE8FAE3DDF6DDD6F2D5CDEBCDC3E3C1B7D9B3A8D0A59C
C79890C09086BF8B7EBB8678B67B6DB47566B87467B76F61BA6E5EBB6E5CBC6B5ABF6C5C
C26B5AC16654C26554C1604FC66252C86152CB6455CD6355CA5F4FD16153CE5D4DD25E4F
D25D4CD5604FD76250D76251D2614FCE6351BE5D4AA551399C5537894D2977471F6E4B21
61451D4F3D19797053837E6A7D7B6F75746F807C7B7975767975767874757772766D6B6E
7672737F7B7C858182908C8DA6A4A7A1A0A672727C4B4D59474B564A4E576D717A74797F
787D838F94989DA0A5B0B1B5C0C1C3CACACADAD9D7E9E8E4E4E3DFE4E3DEE5E4E0E4E3DF
E5E4E0E4E5E0E3E4DEE2E3DDE3E4DEDFE1DCE1E3DEE0E1DCE1E0DCE3E0DBF1EAE2DED8CC
423F30807E71D2D3CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3FFF9F3
FFF6F2FFF0EAFDE9E2F9E1D7F5D8D0F2D1C8F0CBC2EEC6BCE8BEB2E6B8ABDEAEA2DBAA9C
D9A397D49A8ED59A8CD29286D18D80CD877BCD8579C77D72C87C6FC5776ABE6F62C16F61
BD6A5CC46E5FBD6758C0685ABA6455B66353B26553AE684FA76A4BB3825AD0AA7BC5A775
C0AC7AC7BA8EE9E0BFEBE7CEE7E3D7E9E6E1EAE6E5E6E1E5E5E0E4E7E5E8E6E4E9E2E0E3
E4E2E5E7E5E6C2C0C19B999A757678393D4022272D2F363C3740453A4446424C4E485254
4C56584D5758535B5D51565952585850545370726FE3E4DFEEEDE8E6E5E0E5E4DFE3E3DB
E4E3DEE4E5DDE3E4DCE0E3DAE3E6DFE2E5DEE1E4DDE0E3DCE0E1DBE7E4DDE4E0D7A39F93
484536A2A094F6F5F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F5
FFF8F4FFF8F4FFF8F4FFF2EFFFEEEAFFE9E4FFE6E1FDE1DDFCDFDBF9DAD5F4D5D0F3D2CB
EECCC3ECC7BEE3BDB4E0BAB1D5AFA6D1ABA0C9A599C09F8EA98D75B09979A8966EC6B98D
D1C89DA09B75A6A285D7D4C1CCC9C0A6A5A1B4B2B3DFDDE2D1CFD4B0AEB3B8B5BCBEBBC2
E7E5E8E7E5E89A98997577767379777F88854C5753333F3B45524B45524946534A48554E
48554E4A56524F5A564C575349545047524C495049ACAEA9D2D3CDC8C9C1C6C7BFCCCEC3
C9CAC2C8CBC0CACDC2C9CFC3C7CDC3C9CFC5C8CDC6C4C9C2C5C8BFC1C4BB9B9C947A7A70
8B8B81D3D2CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFBF500FF00FFFAF4FFFAF4FFFBF1FCF3E4DBD5BF9F9A7D9A9778
908F70616145373923A4A698BDC0B7414340404143A0A1A5C0C1C53034374142475B5C60
9C9D9F9698977C7E7D646867737975B8C1BCABB4AF89948C909C92939F959FABA19FABA1
A0ABA3ACB7B1B0BBB5AFBAB4B7C2BCBCC7C1BFC5C1D1D6D0DFE2DBDFE0DADEDFD7E3E4DC
E0E3DAE0E3DAE4E7DEE4EAE0E5E8E1E7ECE5EAECE7E7ECE6EDF0E9F0F3ECEEF1EAF4F7F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8F8F0DDDFD4
ACB0A1838A7A5860515A6459657167303B35333C39505B57C2CDC939444035413F3D4945
47524C4C5550464C48797E7AC9CBCAF5F7F600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00E8EFE8CED5CEBAC4BCA5B0A895A09A87928E76817D9FAAA458655E4B575348554E
5D6A639EA9A3D5DBD700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00ECF0EFE3E9E7DAE0DCD2D8D4
DAE0DC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.013213 0.97619 0.264889 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.290056 0.477324 0.541732 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F5F5DCDCDABEBEBC959593767674
898B86B6B8B3D7D9D6F0F0EE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEECD3D2D0AEADAB8786845D5C5A3E3F3A2425201E1F1A1C1D18
23261F23261F3A3C375355507C7D77A9AAA4E0E1DC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00D4D3D15D5C5834332F1F1E1A24201D1D1C181D1C171B1A15201F1A20211B
22231D1C1D151B1E17181B1421221C22231D54554FC6C7C200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00F3F2F0726E6B211E1923221D25241F27262125241F22211C221F1826231C292621
23201B23221D201F1B22211C26272123241E22251E3D3F3AA7A9A6F6F8F500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A5A4A02F2C2725221D29262126252024231E2926212D2A2535302C3A3531393430
35302C37322E36312E2C282529282323221D2627211E211A2527227D7F7CE8EAE900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D0D0CE41403C23221D27241F25221D23201B2A272238332F3B3632423A38433B3939312F
3C3431433B38423A374139363C37332F2A262926211E1D181E201B1A1C19797B7AF5F7F6
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E8DAD9D1BFBDD8C6C4DDCBC9E5D3D1EAD8D6
EEDFDCF6E7E4FBEBEBFFF1F0FFF7F5FFF6F4FFF7F500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F0F0EE
6C6D681D1E1922211C25241F211E19211E193B36323D383435302D39312F393031332B29
372D2B3B312F3F35333E3432443C39423D393D383425241F1D1E191B1D18323431CDCFCE
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECD7D47C5751582B2561302C6534306D3C376E3F39
784B467F544E865D598D6661916B6892716C987974A68985AB8D8BB59996BB9F9CC5ACA8
CCB3AFD7BFBBDBC3BFE1C9C5E4CFCCE8D6D2ECDDDAF2E4E3F4EAE8F7EFEDFAF6F5A6A5A3
2F2E2A25241F24231F22211D1C1B162B2A25413D3A2F2B28312D2A2F2A272F2A27312C29
37302A342D273C332E3B322D3B342E3D383245403A35352D24251F23241F232321878785
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F7DFDD8D64606B302A75302973292670262370292369241D
6A272164251E6A2D287E433D733C376C3A336A3934683B366236336438355B322E5C332D
5B342D5A332C5530285D3832623F3963423D6B4E4A6C534F6D5A565E504D554D4B37322F
26221F272621262521231F1C19161137342F423D3A27221F2C28252B2724282320302B27
332C262F2822382F2A3B322D362F2939352C38332D43403938373221221C23241F40403E
DCDCDA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAE6E59D706D75312E873633872D2C862D29832A26812927812C29
7F2C287A2B267729257D33307A372F7B3C357136306B322B68312C713C3667322C6D3830
6D3B327242386F3E376C3B3471403974453F673A34562D2753352D2F1812130502211916
2E292625211E26221F221D1A221A173A322F463C3B261E1C36312D312C2827241F292621
2A25212D2522332927372D2B362F2938332D2D28243F3C3740403828292323221D21201C
91918F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFEFEDA88281702F2D87322F8829278C282896302E8925238E2C2B8F312F
882D2A882E2D832E2B81302D7A2F297C362E77342C692A237539317A3F376F342C70372E
69332969352A6E373070393278413A8F564F7C433C622D276F443D47261F1F0A05271C18
2E262326211E28232025201D221816352B29493E3C2F252338312B39342E29241E27221E
26211D2B23202E2624352D2A342D2739342E26211D34312C44443C30302823221D1F1E1A
424240D8D8D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5BC9693692E2A8938359B3C3AB34B4AC65C5C9D3534932D2B9836359E3E3F
993B3B9C4241933B3989363280312C7F362F8C474073332A7C40388449417F463F763F38
7C473F744239713C366C37316F3531753833793A356D302B7D48406237302E110B2D1B17
2F24202E26232A252227221F271D1B2F262144393540352F382F2838312930292329211E
2B2320261E1C2A221F2E2623342D27453E382A252138332F4B48432F2E29252420272622
26262480807E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00C6AAA7662F2A732521A14341B74F4EBC5252B94F4FA03837A94543A64445943435
943636903534943A398F3A378637327C312B742F2875362F6A2F297039327A453F7A453F
84524B814F48723D37753E39743734712D2A762F2B752E2A8946407C433C4C1F1A3A1914
361E1A3526232E23212B23202D23212B221D3027223C332C443B343E352E312A242F2822
322A27271F1C231B18302923413A34423D372F2A26423F3A413E392A292424231F292824
2A29272F2E2C706C6DA6A0A0CFC9C9F0EBE800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D2B9B4693C3669201A89302CAB4541AA413EA8403DA33D399634318E2F2B8A2C2C882A2A
892B298A2F2C8D32318A32308736326D241E8A49439A5F59753E3979464285544F895853
8A5753925D5987504D8B4F4E904F4D843A3981302D83302C8C3935984944813E38561F1A
3B120C3A1D1735221E2E231F2B211F2A231D2A231D2B241E4138334A413C49403B3D342F
3D3630332C26322D2739342E3D38323D3A33423F3A3E3B3634302D2A29252524222A2927
242321201A1A1E14151D0D10422E2F715B5D877173B6A4A4D9C9C9F4E9E700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7D5D1
7249435F20197D28239B3735A63E3BA23A379C363293302B8A2B27842624882A2A8B2B2C
8C2D2B8B2C2A89292A872C2B822D286C211B92514BC58B87AB767094635E92615D93625E
A3706CA5706C9A6261935757945253863C3D8A3636862C2B8E302EA04240A149478B3D39
5E221A4819133D1A16361E1A2F201D2E252029221C2B241E2D241F382F2A453C3747403A
47403A47403A47423C46413B423F3843403943403B2F2E292A29252A29252B2A28262221
261D1E271B1D230E1326090E3F1F225E3C3D5737384A2C2C4C332F65504B897871B8ABA3
DBD0CAF5ECE700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B19591
622B2671241E9132309F3937A33D3B9F3937932F2D8F2D2A8F2D2C8E2C2B8C2A2B8D292B
922A2B8C242591292A8D2B2A8E332E8030296D28218A4D48BB867EBC8A8394615D895653
B07D799C6763AA72719A5E5E7F41426F2B2C7526297C26278F2F30A23E3EAB4543AA4B47
9B433F762D27551B174519163C1E1C3724203325222E23212C22203228262C2421322D29
312C283B3632403B373C373339363136332E2C2B262A29242928242726222B2623291F1E
2A1A1B341B1F2D0C133910184C1F245F32358E6465916B687D5B5265453A5639294D3221
5B41306F5848957F72C1AFA5E3D2CAFCEFE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FBE9E5835E58
65221C842B279F3937A2383898302F9D3735993331952F2D902A288C2425942A2C972A2D
962829962527962829992F2F922F2A8A312B7C312B81403A8D564FBC8A83C79491875451
A26F6CC18E8BB67E7F9A5F61A66A6CAA6A6BA75F629242458933348E32339D3D3E973939
933B39984A4882413F5C29263B15143D211E4028283A26273323233325242D2220312725
352B292F25232F2523362C2A2F2724332B282A25212D28252E26242A201F2D1D1E2C1618
38191E38101834050D4D1A215A252D5C282C7141419A6F69AB83799A756397745E907155
8265476E51335A3F2450361F573E2A6E5948938175BFB1A8E2D5CDFAEFEB00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DBC2BD653630
70221E90312DA13835A537369C3030992F2F9C302E982A299729289A2A29A02C2DA32C2E
A22B2D9E2729A52E30A43031A133328B282395403BEDA6A0C88D87915F58D29F9CAB7978
703E3FDBA7A9D49DA26E353BB77F82DB9FA1C8878BB16F71AB696A894546B97375D99395
BE7C7D8E5051793F3E734140653D3D4927264E2C2D48282B45282A43292C3D27293B2729
3523233422223323233626263424253222232E1E1F311E22311C21361B2039141B390E15
410E15430C12561A226B2E36682C34652E33643032764642A27A6EA27F6B937457937752
9880529A7F509D805495784E80623C6F512F5D3E2253351D593C2A725849978176C3B1A7
E3D4CDFAEFE9FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE8D88602622
7D2A269C3836A33735A13130992B2C99282A9D2A2DA12D2EA83435A42D2FA62E30A92E30
A92E30AA2F31AE3336AB3335A733349F3130842221B86561F2ADA8CD928EA06966D7A4A3
926063D6A3A8F1BCC26B363C935A60DFA4A8B07378BB8082905A5AAF787BF0B9BCF8C1C4
F0BCBEDDABAC916161CCA09FF0CAC9BC98985D3639553133502D3140202548282D523237
4525284022243E2123381E213C21263B1E233A1B2334131C3B152043152048101B4C0D18
53101964212A7330396D2E36894D5570393E6935375727237B5349A98672A5876B8E744F
8D7545917A44957C449D824BA1834FA384559D7C5193714B8463426A4B2E593D254A311B
543F2C716050948477C2B5ACE3D8D2FAF2EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8EAE7825B5663241F
883231A23B3CA336399D2C2E99262BA02C2FB94246B94045BD4449BE4648B73F41B1393B
A93133AB3335BA3F44AF3437B2373AAE3739A431348C2624A44C4AEBA29CCC8C8AC08887
D5A3A6BC8B8FEBB9C2925F685E272DCB9298AB7076CC9497AD797B875556F0BEC1EAB9BC
956769BE9495EBC3C3F9D6D4F8D9D7E8CAC8856566D0B0B3D8B8BDA8858B5C333B5C2D35
602F3557292C471E223D161B4118204B202A481826440F1F511628591627681B2B792636
7E2E397D313B78353C70353BA77278916064774649693B3B5D342E7E5A4CB1917CA68B6D
90794F8B7543917B42968044947E42957D41997E47A28752A78D5AA38958A2875A927950
8167426E5433583E234D351D5A4331705D4FA18F85C9BAB3E8DAD7FEF4F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D9C6C26B3C36722B27
9439389D34389D2F32AA393D9B2A2EAC3B41B7484EA9383EBB484DC45156DA6669E67273
E36C70D2595ED55A5FCA4F54CC4F55C3464ABD4245B541429F39379E4541D58783E7A6A4
FBC5C5C49397A27379EDBBC4AC79807B444AB57C83E3AAB0EDB5B8804C4EDAA9ACEEC2C3
D4AAAB855F5EC09E9CFFE3E1E9CDCA9D817E856968F2D4D6F8DBDFFDDCE3E2B9C1976870
79464D6F3E429B7175C79EA69A6F79623441834E60C1869CA36278BD74888F3A4F9C4153
98404E86353E833C42A96C71A87174A37174966666956767986C697A544B967264B99A85
A58B6A8C754B8069378A743B927940967C419B7E449B7E469E844B997F469E834CA58A55
AA8E5CAB8F60A78A609476507D6040654B305B422C4D36245946386F5D539E9087C9BFB6
E8DDD7FEF5F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE918D6B302C85312F
9B37399E31349D2E34A6373D9D3438B55255BC6166B85D62AF4C51AB4447AE4144BE5051
D66368D96268DF666DEC7176E3666CD95A61D6595DD2575AC65253B64D4AA54644BF6E6B
F1B1B1FFCBCD98676A96696CF7C8CED29FA4935A61A4656DCA878E7C3E43C79598EAC0C1
C39D9CCAA9A4977873ECD0CCFEE5E1DFC7C5A98C8EE7CACEFADFE4B6999EDDBEC4E4C1C7
654145AE8A8ED0B0B5DDBEC6F4D3DEBC98A6906377EEBAD1DCA2BAD38FA6C16F86A0475B
A74C5D822C37B0636BCE8C8EA46868AE7675A06A6A996766A3736F996C66986D66A98376
B99984B193777D613C583B11714F22815D2D8C6335976F3E9E7A489F7E4B9F804A9E8149
9E844B9F864D9F864DA58C54A58E5AA58D5DA0875E957B587B604362462E4C311C472D1C
573D2E735D50A08C83CCBBB3EADDD7FDF4EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAE8E6845C5A77302E943636
9A2D30AE3B40B64147BE4F55A43D41AA4E51EE9FA4FFBABFEB9296DB7C80CD6A6DBB595A
A94448AA4146AD4046BA494FC45158CD5860D96268DA6166DA6365D56363D16563BB5C5A
BE6E6DF7B3B2FBBFBF8C5656B17D7FFFD1D5F4BDC3995C638A474E88464A8C5457F6C8C8
BB9592B1928DBA9B96B39793F9E1DDF2DAD8E1C4C6D4B7BBFFE2E6CFB2B6A88B8FF3D4D9
997B7DE2C5C7FFE5EADFC4CBECCED8FFDEECC79DB1B2859AD8A4BBEAAFC5E69EB49E4C62
A750618E3845A3525BC87D829D595AB87878B07372AE7271AB716FA26B6897625C7E4E44
A97F71CCA794AF8B717B583869411D7C50297F52298051277F5429875E30936D3C9B7743
A3844DA4874D9D8346A38B4DA28A4CA28C52AA915BAB9160A88D62A48861977A5A826448
694B31563A24452C163D26145441327563579F9089C9BEB8E9E0DBFDF5F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E1C5C2753F3D832E319E3438
A42F35B93E43BA3F44B84349B0464A95393ED98C92F6ABB0C0696FC56A6FD98384DB8B8C
E3979BD08186C56E74B55860A2454D9E3D44AB4249BC4D54C55458C75457D05E5ED26463
D36B6AD77977FAA6A4DE9292AD6664D39695FFD9DCFCCBCFB77C82A26467884849BA807F
F3C8C2A3807ACBACA7BCA09CE2CAC8D2BABAD9BBBDE6C6C9E4C4C7FFDFE3DEBBBFF0CDD1
D5B7B7CFB2B4FFE7EAC4A7ACC2A3A9FFDCE6D1ABBAAD8496BA8FA2D5A4B7FCC1D5B36E81
88394C8C384886323F903F4686373A8D3E41AC6062AF6566B3696ABF7876B6716CA3625C
7A4136BE8F7FC99F89A880667D553270462083532B87562E84532B87562E84502B86552D
885B31976E40AC8854AC8D54A58B4EA58D4FA48F50A28E51A08D559B8A56A08B5EA18B62
A38B659E8660957D5979613F664D2E4E34193D220D3E2413533D2F78665AAA9C93D0C6BD
EDE4DDFFFAF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E9E8E4D4D3CFC3C2BEA7A6A28B8A886C6B67
65616063625E69686465645F62635D767771B7B8B3E9E9E700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BA94917232328F3034A43138
B63A42C24048B43338B93E43B14449983C3FE19A9EE1A0A48F474AA65C5D914B4B935655
FFCACACE9697C18182D79295D79096E99CA4CE737CCA656DBB4E54B54448BD4B4BB84645
C14F4EC55957CC6868C96B6BC66E6CAE605EDEA3A5FFD9DBFFC9CCBD7D7EAC6263A15A58
D99F9BE6B7B1DAB5AFE8C9C6C0A2A0EBCDCDB99798E4C0C4D4ADB2D0A6AAF4C1C6F1BDC1
FDCCCFEDBFC1FFD8D9E0B8B981585CDFB6BEE0B6C0A37985F6CCDAE2B4C1DCA7B7DC9FAF
9952647E31417B2D3A7E2E37792A2F7B2C2F9141448331359D4B4DA55053AA5656A25450
6F2A238C5246C39482C79D84A47D5C7E583173491F774A20794A207E4D25854F2B854F2D
844F2D784621805028906538A27D49A98A51AA9053A49053A39459A69B63A195639D9063
998A5F9E8D629E8B619E885FA28A649A805D8B7150785D40664C33472E1835200D362513
5040307A6C5FA89B92D3C9C0EFE6E100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00EAEAE874757048474232312C2625212F2B28322E2B302C29
312C2939353239363137342F32322A2C2C242F2E294D4C4890908ED4D4D200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F9E7E58F625F782E2D983337B13A40
BF4047C03A43BC363FC14249B7494C893130EFB3B2F1C4C1AB7A767D4A4661322CC79C95
FFDDD7ECC9C37C504D704242DEB1B4FFD3D9D58892E48791F28A91EF8285E27676D26463
C65857BC4E4DBD5053BF5557C86061AD4D4E934143E8A0A3FFD0D4FCB8B9D37F7FC66E6C
B2635ED7948CFECBC7FFD9D3C39C97D2AAA8E5BDBEB48A8EEABDC4C28B91D98E95E48F96
EA959AD98789CF8584EEADABDFA5A4C08C8EFBCAD0B4858DC6949FF6C2CEBE8895D9A1AC
E6AAB6A7697472333CA3626AAB696D934C527B2E348332388D363C92373C8F3034903636
883734702C23925D4DD0A68EBB9878A181588E6F408665327C58267C542376471D75411C
824A29854A2C82462A8247297E48248C5D339E7847AA8F5AA3925CAFA570A39D6D959267
9A96709C96729C946F9A916A9C8E679C8D649D8B63A08D659F8C64947E57806947664F2F
50391A452D11381F093B241258423478665AA99A93D2C7C1EEE7E1FCF9F400FF0000FF00
00FF0000FF0000FF0000FF00898A85191A141D1C1723201B2825203B36323E39363A3532
3F3734473F3C473F3C453D3A403B353C37313B3831312E291D1C1731302B8E8F8AF4F5F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DCC4C277403D843330A1373BB73E45
C1444CBB3C45BF4049BD464CB44D50742521D2A099FBD7CBFED9C9BC9785A7826FF3D3BC
BDA18BF4D8C2C0A18DBB9B8CF7D6CFFFD9D8C27B83AA4F58CB6068D8656CE57275EF7C7F
F58182F27E7FE67275D86467C75457BB4F4FA23E409C4443D6878AEE9E9FCD6D6ED16D6B
D77874D07D77DD9A94FFC7C3DAA5A1925F5CE2B2B2DDAFB1F8C7CDEBAEB6BB646DC65E67
C55A60BE5559A24444CA7473F6AAAAE39FA0E5A7AAE8ABB09C5D65E6A7AFC1848C8A4F55
E7AAB1C68990A96B70DB9DA2DD9FA2D29195C47F848F424A852E3690333B902C34903034
8F35357B2C276F2F25C79783DEB99CB99C74A68A5A957A457B5C26906A3997683C905A34
85482B803C2589402F8E4534813D287C3F2378441F90693EA28A5AAA9C6B9D996A68693F
6365407A7B598A8A689895729B95719C946DA1956D9E9167998A5F9D8C619E885F927B52
93775087694574533461422654361E3B200B2C15053A2719544437766A5EA9A097D0CCC3
EFECE500FF0000FF00B6B7B22A2B251B1A152E2B2627241F39343045403C3C343239312E
3C34313B33304E44424D443F3B322D3D342D433C36433C343431281C1C12212119979892
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B59693793937913736A93C3FB84147
B94248B23F46A3363C9532379945455B1812C5998CD0AD97BC997BEFCCA6FBD9ACD0B081
AE8E5DD2B281FCDDB1ECCEA8B8987FFBCDC0E39D9DAD5058CB5561D04E5ACC4951D55258
D45358E16367EE7175F2777AF37C7EEB7979E17372C25A59AE4C4BC15D5DB64C4EC45858
BA5050B65451B25D5ACA7C7ACE8785B87775AF7372EBB5B5FFD5D8FFC6CCC77079C95F69
D36268D05F63C65C5EDF7B7DDD7F80C86E70B76164E28D92A65156AD5B61EBA0A5B87074
BE7679EEA6A9A75C60DD9598D391927D3F40D09297CD878F8A3942AF545DB14D57922D33
8E2B2E892F2F6F241F854A3CD0A38CCDAA8AAF8F66AB8C5D7B59295E330679451D8D512F
A35D439548347D2B1F8B372D8B392E873A2A7C3823763F21805A339C8657A69B6D8F8E60
50552D4B532E555A3A5E61446C6B4F817C5F938A6B998E6E9D9370A3967394855E947E57
9A7E5686663F7C5A3484613B83613E81603F7152355E4026492F1638220A311F093B2E1B
544D3D7B776CA29F984948431F1F1725251D2A27222C272345403A403B35362E2B372F2C
3A302E332A255449454E433F382D273B312845383242382F4841373D392E27241B32322A
B0B1AC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9EAE78C64627B3432983637B64549B43D43
AD3C40A73E42B85E60A85A5AA8635E854D40D7AD95D7B391C7A172D6AF76D5AF6EC6A059
EBC57CCCA760D5B771C8AB6FA98A5BE5BC9EF9BBB0A85454C1535CCE525DD1525DD04E58
D14D58CE4B53D24F57D45358D5575BDF6466E97172EE7A7AEE7E7DF18382EA7E7EDC7272
CB6765C16361AE5A58A35956A35F5CAD706DB07473A3686AE1AAADFFC8CCDE838CCA5C65
CE5961D05B61C95B5ECB6364C9696ABB5F60BB6264BA6467B65D61A44B4FA65458D18184
DA888AE69496BF6D6F954747DB9796A26564A1666AF4B5BDA0505B9A404AA23C4790272E
972E35912C30872D2D691E18925948CDA188BF9B79AC8B62A58258693E1466300A7C3B1B
893D258A37277F251D8D302B8D322D8D342E86372A803C276D3A1B68451D907B50A8A173
83845A484E28424727676A4F7D79606B634C6B5F4770604676674A8677568474509A875F
947B5281643A7F603477562B73522785643B75532D71512B785832745833614A28534224
372B13231C0A1912081C1912201D1625221D26211D27221E4A453F39342E3028252F2724
2C251F332A254C433E473C382F241E372C2641342E3D332A433A314541363E3A2F24241A
3B3C36C0C0BE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00DAC5C27747457E2E2DA63D41B84147B53C43
A6353999393AEDA3A0FFCCC4F4BFB1ECBCA5F4C8A5C49A68D4A869EDBF74E4B460DEAC53
E1B457F2CA6BBD9C3FDDBE6BCBAE68C9A873FFD6BAA466598C38369F3E45A9414CB44452
C54B58D04D5BD54D59D54C54D64D54D24B51CB484DD05255CE5858CF6160CF6B69C86F6B
BA6B64BD7A72B67D76B1827CAF8682BA8E8BC89697B2777BA56367D7868CC25D65C45359
C64F55C14C52AE4446BA5C5CCC7B78B9726EB57170B06C6DB3686CB7686DB35E63A85157
BD6267B15759AF595A803031894343BD7F80D4999FFFC1C9A85C68872F3BA139449D2E37
9F2D37982930942B2F852A276A2118A56C5BDAAE95B4906EAC89639E744C6C3813773618
893B258A32248E2F298F2D2C9331309132308E342C88392C7B392366331464421C8D7A4F
ACA5777F805440401A535031A1977E93816B7A5F4C866A54775C41705738604A25746137
7C673C7D683B826C3D7D6537816639937748795A2C70512378592B7E6233604A1B655228
746544574D3421190C1B140C27221E27221E27221E221A17433E3839342E201B17211C18
241F19362F293B33303B312F3128232E2520332824382F283B342C3A362D454138282820
1C1F165B5D58F2F2F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00B19391703837872E30AC3F44BB3F47B6393F
B5424592302F904943FAC4B8D5A692BC9171DBAF80CB9D61E7B76FDEAC57DCAA4BCA9932
BC9025DCB347CBA93DDBBB56E3C56DB5974FFFDAA9EEC09FD59A88CB867FBB6C71BA5E6B
C65767C84A58D34B57D54851D44950D44D53CF4E52C85153C85C5CB55755A554509A574F
A97369C09489B9978EBB9E96B39A95AA8D89AE8887BD8B8EBC7B7FAD5B61C25D63C15056
C24B51C04C4FAF45479C4140B46963B67A72AD7874A87773AB7374AF7174BD767ABB7074
B9686EAE5E61A95D5F7933359E6262A87073B0757BFEBDC5DB8F99A349559F3541A93540
A32B35A42C359D2A2F9830317A221E732D23C18978DBAF96B7906FAF8763A573506F3213
782D168C392990332B8F302C8E2F2D8E302E913830873529823B27753D2258300D61481F
9C8E5DABA573706D403C38126E6347A8937E77584665422E815D457C5B3C7456326F562D
664F236D5829725D2E76602F7E68378A73419379468E733E876C37866D37614A165F4A1B
8071486E6345271E0D1910072E27212B2622261E1B271F1C362F2945403A2F2A26211C16
25201A2F2A243D36303B342E342C29241D172C231E2D241F39322A39352C49463F33332B
1E211843463FE5E5E300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F7ECEA8F6968763636933438B23F46B3343BB8373C
BE4346B14747802D29AC6E61F2C4ACCAA37CE6BB86EEBE7CEFC072BC8D35B58926C59C30
D2AC3DC5A22EB3901CB69524EDCC65C9A74ED6B46AE4C084F0C69CF2C6ADFECCC5FFCBD2
F08E9BC04756D34C5AD44851D44B52CE4D51C85558BB5958A6575395564FA4736CBA948B
BB9D93AF978DAC988FB3A099A5948C9D8A84A18884A78383C28E92C37C82B95E65C1565C
BD484EC14A4EC251539C3A37944741AA6E66A1746E97746E9876749B77779F7778A67A7B
AF7D80AC7A7BA47275956467F1C7C9F4C7CC93575FB8727AF3A3ACD47982A3353EB03841
A93037A92E33A72E339F2E30932D2B7A221E874338DFA796D4A88FB28969B18560A06C47
6A2B0C7E331C8936268B3329893229822E247D2F2277301C76361B754021653C1E422400
8B7A46A69C61ABA8715D5B2B3D3413827259B0958266432F774E388C6045825A3775522A
6243175B4011674F1F523C0B564210634F1C705B2677622B786229836D347C672E776330
8173466F624021190621190E2F281E2F28202D241F261F192A231D3B342E453E38332C26
27201A2E271F403931463F37372E29261D16281F18292019362F273A362D48453E33332B
24251F3C3D38D9D9D700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00DBC9C77345457D3536A23F44B03B43B4353CB93B3F
BB4748AC464480312A6E3323EBBFA2E7C194C29659E6B86DB0822DB78B2CEBC259F1CB5C
F1CE5AF3D058F0CC54D1AC37BC982ADBB955D0B157DDC074CCAF75A5855EF7D2C2FFC5C7
BE616CC44E5ECC4957CD4A52CB4E52C55456B25454974E4897605BB08A81BEA199A9958C
9E8D859B8D84A1948CA59890AB9E96AEA199AB9995A58B8AB08889CC9195C27379BC5B62
C6575EC14C52BD494CB64C4C933E399A5A51A4756F95776F8C756F8D7A768C7474907677
957978997B7B967677957779CFB2B6F7D3D7BD8890A36069B86871BB6067B74C54B34047
AF3A40AC373DA9363BA436399D353695373571221DA9695FE8B8A4CDA488AF8763BA8E67
97633C6C2D0C82381F8A39268736257425147A2F1C8B473079391D70391A5D30114E2B05
997E479F8D4FADA567AFAA73534E24483D1F947E67AF8E7B6136238858429F6D52956746
7F552F724D238562385C3D115034055D43125D4310634A145D440C5A410870581C89733A
76643261532C221800231C0A2A2414312B1F332A212E251E271E172C231E3A312C49403B
40393130292139322A342D252F261F2B221B2A211A2B241C38342B3F3C353E3E362D2C27
1F1E19343530CFCECC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00BFA7A76C3636883839A63D42B13A40B1363BB74344
A33F3F81312AA3675CDAAB97E8BD9AC9A16ED8AD69E2B564A37619EBBE57F3C95DF3C959
E5BE47D0A930F5D157F8D35ED3AD40A7841ED9BB5BF2D683AF9451D2B385FFD6C3C28081
B95561CF5667C94B59C54C55BA5052AF5554924F49A06F68C8A7A0BCA59DA291899A8B84
988B83998F869B908A9A8F899D928CA49993AFA19EB3A09CAA8C8CBB8E91D19096C06A73
C45C65C8545DBE474DBC4B4DAA4847863732A46B64A37C759178718A79728977758A7A7A
897A77897A778B7977897576877374A4878BAC8188B97D87CA7E88C06971B34F57B0474C
AE474BB14C50B04D52A64348A24244A145468935336F2A23D7A195EBC2ACC09E7BB49167
BC9262925F326A2B0880391B8B3E227E2E13792B14994F36A560439D5E3D935B38996A40
A9824BA185449F8D4DB6AC6F8C895648431B53452AA98F7E956E5F8A594B98604F8F5541
9A61469D6647A671518D5D397F522B7F552B6C471A6947175C3B086E4D17866727866828
674E15635121312402221B01251E0B302A1A332B20372E25342B222D241D2A211A2D261E
433A3349403941383339302B322B25332C2638312B3C3731413C363E3B36302F2A282722
1D1C172C2B26C7C3C000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A88C8B7137368F393CAB3E43B43B40B63B3EAF3B3C
A13F3CE2938CFFD6CAE2B49DB38865DDB381F6CA8BCEA052B18427E7BA53D9AD44B28717
D6AC36E1B93FDFB73EECC550F8D265B59028D5B352DDBF69AB9147FEE0ACF3CBB1965954
AC4F59C75868C3505DBF545CA74F4E96514CA6756EBB9A91C8B4ABA79A919B8E86988D87
978C869A8F899B928D99908B998E889B908A9B908CA69794B19C99B59394C9969BD18A92
C36772C15660BD4952B9464BBD535599403C914C47A3726B977971907C758B7C778A7F7B
877D7B837977827775867A7A8373748D74789C747CA7727AC37A83B15B64A3484D9B4143
9C474AB96A6DB4686CAC6064A4555A9F50539B51526829249A6A60F9D4C2E0C3A5B89B73
BD9C67C59E677D4D1D652A007C390F8139137E33147F3518843A1D8039198442208E532B
96612FA1773D9C7E42A18E53B0A7707F784A3D3212594731AE8E81A67C70915D50814739
8B503E7C3F2A824832A0684FA76F549462418D5D3990643D8B62368B66319B78388A6C24
6348018C7937796C37271E00241D0028210E312A1A3D33293F352B42382F362D262F261F
281F183027203C332E463C3A4038353E39353E39353F3A363733302C282526221F24201D
201B172E26239F9892F2EBE5FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF5F3937472793C3B973E40AD3E44B3363CBA393EBE4244
A0302EBA5D56EBA299FDC5B4E7BA9DD6AC84DDAE7AD3A25FB2842FF9CD6EDAAF499C7003
E8BB46E0B43BB58811CFA433F5CC62CDA742AE8728E9C56FC9A95ED7B87FFCDBBAE4B4A8
A35B5FA24A56B65661AD545A96504EAA7871B08E85AE968CBCABA1B4A79EA89B93A1948E
9D928C9C918D9A8F8B9B908C9A8F8B988D89998C869D8E89A59391B59B9AC29B9ECF989E
CB7F89BE616BB84D57BD4B53C05356B2504F9445419A5D589E756F977C75907F788C817B
877E79897F7D867C7B84787887777A8F767C987079A46F77B86F789F4E549C4A4C8A3E3E
9C5F5CAA7774A77777A37577A67477A16F709E6C6D855855714C46E7CABCFFE5CED6BE9A
BCA06ECCAE72B49253764E116B3A02672F006628016D2B097730107E33147C2F117D3212
7B360F76390D71421491713EB19D68B1A573695D374436196C5A46927668906C5E8C6053
8C5C4E774335764133824A3B8E564589503D8A533E925F44865834926A39A27F3F987B2D
967E24B7A448BFAF5A70631F281C00251B022E2311332A1B392F234B41374E443B443B34
3B322B2B221D2B211F291F1E2B232127221F2923232B2726251F1F221C1C241E1E2C2422
2C222032251F37261F6B594FB5A399DBCAC2F7EAE400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00F4E5E286605D7F3B3A9E3F43AE3B42B13239BF3940C13C3F
B83E3DA338328B372DB67768E9B9A3F5CCACCEA275E0AF75B4843ADBAD57FDD170D2A63D
EBBD4DCFA02CB68715E9BB4CF8CF65C69F3AB68F32EFC974ECCC83AE8F58C3A281FFDBCE
F7B9BCA65D68A5555E91494DA16C68BA958DA48980A08E84A89A8FBDB0A7CDC0B8BEB1A9
ABA09AA0958F9E938D9E938D9D928C9D928C9F928CA0938D9E8F8CA4908FAF9392C2999D
CB8F97CD818BBA5F68B64E57C4595FC35C5FA74D4C8D4340A16F68A07E75957E768E7F78
877C78897F7D877D7C877B7B8676798F747B986F77AE757EAC636A98494E954B4C854543
A3736F97747093757394787796787A9779799878799576747F6662B69F97ECD7C6EBD6BB
CDB78ECAB37FCAB276C5A96AB79558A67D459464347843176F3408702F05702C0776300C
77330C7A3C13602F06633D109A804DB6A672A89C6C5F562D3E33155141287158427B5C47
8B685498725D986D5A8D604D895A488B5A498956437F4F385E3112906A3DAB8949A08431
A68F29BAA636C6B446C4B6557A6D272F2300281E002E24092E26133B3223463C3252483F
564C434D443D3E332F342A282E26242A22202620202C2626281F202920212D2322352B29
3628252B1C1528160C5E483B8D76688972649A8479B5A29BDACBC4F1E6E000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E4CFCC764A478B3D3DA63F43AD353EB5323AC1383FC23A3E
C24040BC4642A8473E863C2F6B3825E0BBA0C9A27BDDB27FC59555B07F32F2C36BE6B856
D5A63CD4A637C39526E2B649F6CB62B18A25DAB356D2AF5DBE9F5CD5B584E1BCA2FFD2CA
FFCACFE29EA99552598D5254B58D8BA58A839C8A809E90879A8D84A39990BBAEA6CABDB5
CFC2BAC0B3ABAEA199A4978F9E948BA297919E918B9F918E9F918E9F908DA18D8CAF9294
B89194C38E94C47D85B35E65C05C64C15A5EB5555697444092534CA77B729C7E76948079
8C7F798B807E8A7E7E8A7C7C8C777C94757BA1727AB778819C51569B4C518741438B5352
A079748F736F8C77748B77768C7A7A8C7A788D79788E7A798876748876729D8C84A79587
A6947EB29F7FBFAC82CAB684CEB87FD3B97ED0B276C6A669BA9658A67E408F652B754811
6537035E32015E35074E2C005D43129F8E56B0A468877E435F5927514A1E60522B614F29
59431A745B337A5D3B8164448D6E4F96775A916F54936F558461419B7A4DAA8C4CA38932
A99123BBA72ACAB935D8C948D2C7539B91324B42002B2300302708322A15372B1B3A2E20
44382C4E443A54473F4E433D4136323F34303E3432403634372D2B332927332824352724
352822271910301E127B6859987E6F8C71608E71619474678E7065997D71AE938AD2BEB5
F2E0DCFFF6F200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00D7BBB774413E933F3FA83B40AC3038BB353EC53C43C4393E
C64041BC403EB64B45A04E43622D1FDEB8A3C09B7EE5BB93DFAF7FC08E51C39349DAAC56
E0B254F3C661F2C761E4B953C09634BB9437E4C06CD0AE66C4A56EFFE0BAEFC6B4B58480
B3767DA86972894E54AA797CAF908D9A87809B8D849B8E86998F869C9289A3968EAC9F97
BEB1A9D1C4BBD3C6BDBDB0A7ABA198A59B92A0938DA0928F9E938F9E938F9D8E8B9E8C8A
A58D8DAF8C90C59096C27C84B55E66B6565ABA5559B459589244409C6159A67B74A0837D
98857F90827F8D7F7E907D7F92797D99747BAB737CB06D76914549994F507E4041966664
9B79778C77728D7B798A7C7B857A78887D7B857A78847977867877817372887A77887974
8A7C718E7E6E9080679C8C6BAD9B73BCAA7AC7B380D1BC85D4BE84D1B97BCDB378C2A56B
B798619F804A8767346A4C18412B00665416ADA35BB5AE66A2A063706F396C663684794C
67562A6C572A70592F533C12644D236750266D542C7D643C8B6F48907442A58A45A38A2E
A9931CBEAA23D2C22FD7C934DBD13EDFD653C3BC546A6514322C00251E002C220031260A
352A143B301E3E32224234273F31263B2D243D30273A2D2435281F2E211833261D36281D
25180824140442311D7A68529F8974937865917260916D5D9974649B76668E6A5C866659
8E7368A18D84CDBCB4EDE3DAFFF7F200FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00C3A29D8045419D4142AD3C40AB2E36C03A43C23940C93E43
C43E3FBF4240BF4F4D903932834A41EEC6BAAA8372D9AF97D6A98CDEAE86D2A36FCC9C5C
C6964AB88B38C89F47B08831C09A47E8C277D8B573E6C38DA4845DDBB9A0F6CEC48D5B5C
8E5055A160689B646AAE8486A188849C8D869C8F87998E889A8F899B908A9B908A9F948E
A29791ACA299BCB2A9C8BEB5CCC2B9BDB3AAA99F969E938DA19690A196909B908C9F918E
9F8F8FA48E90B69296C28F94C37E83B25D64B45458B95659A94E4D984A46A16763AD847E
A387839A8783928080917B7E98777EA1747BB4757EA1585F9045498E4A4986504E9E7674
9379788977758A7C7B8A7E7E867A7A887C7C857979857B7A877B7B817575897E7C8B7D7C
8779768578728779708A7C6F8C7C6C8E7F6A93836A9F9073AD9D7BB9A77FC7B48ACEB98A
D6C08ED2BB85CDB77DC5B071A28F4A83752AA39B48BDBA69D2D38D8F93585E5C2C817952
80714A6D57307D62377C61327F6630776127614B116D591E69521C5941038E7525AB942E
AD981BB8A616D5C62BDAD030D4CC2BDBD63ADED949D3CF51A39F346E68123E37002B2100
231A00261D002F240835270D34251032231038271535241232231031220D30210C281A00
1F110037280770623F76674675654C8A756293796A9B7E6EA18071926E5E95705E96715F
94715E8766538367528B705DA08B7AC8B6A8ECDFD6FFF9F400FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF6F5AF89868645419F3F41AB363CB2333AC23C45C13840C94047
C33B3FC44244BC4445922C2AC67874FFCAC3F2B6AEF7BDB1F5BCABF7BFA8E0AE8BD3A478
E2B57EC99D60D9B26FDEB877E8C486B6915CCDA67BE7BE9ECA9D86D9A99DFFDFDBE8B1B4
9654588E5055B07D828B6767604B468B7E769E938D9B908A9A8F89988D87988D879B908A
9D928CA29992A2988FA99F96B5ABA2C5BBB2CEC4BBBAB0A7ADA29CA297919E95909E9590
9D9391A19191A58D8DB18D8FC99297BA7379BB616ABA575CB95659A34948974D4AAE7772
A7807BA48783977F7F997C7EA0777DAA757DB67078974A50984E4F7F3F3D9366619D7E7B
8E79768C7C7C8A7C7C897D7D857979867A7A857B7A877D7C887E7D837978857979867A7A
887C7C837777897B7B887A79867875887B7585787084766B897C6B8B7C679183699B8C6D
AE9E7AB7A67BC7B585D4C38BD4C486CCC078C5BC6DB9B667D1D58BC3C98B5E603158542E
918464B39F7E8A6E4984653792753B8B702B7D671C8673267D6A1E604B00897212AC9724
B09C15AF9E08C9BB1CDBD22BDFD82FD8D42ADFDC37DEDE42DEDD51D8D65BBCB75397913D
6C651D524D0D3B3200372C002F23002B1D002E20002D1F002D1F00322400382B004A3D06
6B5F239A8E527C6F3A75673A6C5B3D705E4A725B4B81675A886B5D9B7A6BA480709F7C69
9070598C6C538F70549D7F6390775976614672604C867667BCB2A8E9E2DAFDFAF500FF00
00FF0000FF00
00FF0000FF0000FF00FEEEEE9C706F853F3DA43F43AF383EAF3037C23C45C0373FCC434B
C63D44C53C43C74046B4363AC55255D56D6CD77371DA7D78D8847AD38B7DF4BDA9D4A88D
E4B999D2AA86B6936DCEAC87DBB898AC876DFCD1C1F5C0B8EFABA8F5AEACFCB8B9FFC6C7
BB797A884E4DB9908EA789876C5953554842716660968D869D938A998F869C8F879B908A
9C918B9C918B9E938D9F948EA49993ABA09AB9ACA4CEC4BBD2C8BFB7AEA5A9A099A19891
9D948F9E938FA2938EA8908EB79091C99297BD7078BB6069BC575DB654559B43419F5650
AE7770AB827CA17E7CA17A7BA9767BB97B80AB606796474C904849854A46A07773957975
8D7B77897B7A877B7B897D7D847A79857B7A897E7C877C7A867C7B857B7A857979857979
877B7D82767885797B857979867A7A857979857A78877976887B7582756D86797085776C
897C6C8C7C6C93846D9D8E71AD9E77C2B483C9BE80C5BE7AC6C781E6ECAC9CA37043451E
6D684BDBCBB2AA8C726E4A26B9945DBD9B51957A219D87248B7714705D00A28F19B5A21F
B6A414B1A106BDAF0ED0C51EDDD52CE0DC32E6E43AE4E541E3E546E4E44EE6E559E2E260
D9D95FCECD59B6B244A7A33897922C8B862289811F8B812090862499902BA89B35B5A840
BEB14BC4B759A494476C5C21624E2968523B816758866A5F7F635787695E7D6153987E6D
87715A8C785D8C7959937F5AA08D63A9936A9E88637C674858442B625340867C70C4C0B7
00FF0000FF00
00FF0000FF0000FF00F0DEDE906060883C3CA63F43AC353BB8363EC13B42C43E47C64049
C03A43C33B45CA3E47CC4049BA3339B02D32B23638AF3B3BA33A367D241EBC7E73EEBEB0
AB8070CBA191F2CDBBF3CEBEA27C71C19892FFD5D7BF7C839A4147A8484CAB5254C17371
A15D5A9B6662B5908AA68F899D8E897F746E584D47574E477D726C9C9289A1948E9E918B
9E938D9B908A9F948E9E938D9F948EA0958FA2958DA99F96C2B8AFCBC2B9BEB5AEB0A7A0
A59C95A09790A19690A69490A88E8DBC9397CE8F97BC6C75BE5F67BB565AB4545599413F
A66058B47971AF7C78AF7979B77778C27A7DA351579B4B4E853F3F915C58A4817D937B77
8B7C79887D7B897D7D897D7D867C7B857B7A887C7C877D7C867C7B867C7B877B7B877B7B
84787A85797B877B7D84787A867A7C867A7C85797B85797B867A7A867A7A837876857A78
877978897B7885766F8676678B7B6196875E9F9059A39A55BDBE72DCE29AE1EAB36C7148
3D3C1EB4A892EBD0BD65422498703CE3BD72CBAE4AC3AE3BB9A930AB9C1DB8A821C3B322
BFB019C1B314BBAE0ABFB40CD3CB20DDDA2DE6E439E7E63CE2E43BE2E53EE7E946EAEC4D
EAEB51F0F05AEEEE5CE9E85ADDDE54DADA54DAD756D6D151D6D151D6CD4CD7CD49D5C845
CEC043C4B745B09F47927D3C5E471D5A3E266E51417A5C518362598A6C6281675A836D5F
705F4B897D63978C6E9D906D9C8F6599885CA18F61AF9970A5916E7362443B301C746E60
FAF9F500FF00
00FF0000FF0000FF00E2CDCC8451508B3D3DA73E43AC333AB7393DBF3E43BC3D44BB3E46
B73D48B23641C53F4AC73E48C93D46C93E45CD4549C94749C54D4CAC4441843731EFB4AE
D8A9A3FDD2CBF5C6C0ECBDB7DBAFAEE9B8BBFFC7D0B4616BB84952C54E54B44848B05250
954E48B27D77AE8D869E8A839B8E889D928E988D89726763514642574C468274719D8F8C
A39894A0958F9F948E9F958C9F958C9D938A9E938D9E938DA49A91ACA299B7ACA6BEB3AD
C1B7AEB6ACA3A89B95A2938EA38F8EAB8F8EC3949ACD8E96BA6970B5595EB75457B65453
A04743A3534CBD6F6BC47674CA7978C77172A74E50A05051834240A1706CA0817C907D77
8C7E7B867C7A8A807F897F7E8C817F877B7B877D7C8B81808A807F867C7B887C7C8B7F7F
857B7A867C7B887C7C887C7C867A7A877B7B897D7D857979857979877B7B867A7A867A7A
8579798C7E7D8C7D788B7B6E907F659584588B7B3D94893AC4C369CDD27EEAF3B0B4BA8A
53523379715CF4E2CEB7997D744F1BD9B569E0C85ED4C244C9BD35C9C130C7BB27CABF25
CBC124C8BE1EC6BD18C6BE15C9C317D6D324E2E033E8E83AE0E236DDDF34E3E53CE2E43B
E2E33DE1E23CE5E640E5E843DBE03EDCE045DBDD4BE7E658DEDB4ED8D246D8CD40D3C73D
D0C340C1B23DAF9C4098813D71542860412584614E7A564A643E357A584E7E60567D6559
77675868604D736D57A09A80AEA888A59D769B9063998C5FA89B6FB9AD856760436E6C57
F9F8F300FF00
00FF0000FF0000FF00D0B8B87C4644903E40A93E44B0373EB93B3FBD3F43B63B40B13942
F68790E77481BB3D49C9414DC93D48CA3D45CB3E46C73F43C54345BE4A4B852624C77977
FFD1D1F9BCBBA66060874143E8ACAEFFCED4FAAAB5AD4955CB4F59CA494EC14B4BAE4C49
9A534DB98881A688809D8A849C8F89968D889A8F8B9C918D958A866A5F5B4E403D5A4F4B
8075719A8F8BA297919D938A9D938A9E948B9C918B9D928CA39990A39990A79C96A99E98
B8AEA5C7BDB4D1C4BEC1B4AEAE9F9CAD9897AF8B8DCD989EE39AA1B55E66BD5D61BE5A5A
C96A66C56863AD524FB25756CA6A6BC06061B557579D4746964F4DAD7673A37C77997D79
927D7A8F7D7B9384818E807F8F81808D7F7E8C80808D8382897F7E877D7C8A7E7E8C8080
8B7F7F897F7E867A7A897D7D877B7B8A7E7E8B7F7F877B7B8A7E7E887D7B8B7D7C8B7D7A
8C7F798E807790807190806796845C9281498D7D32ADA14BCDCA6DC3C571DCE19FE1E4B7
7473576F6856D6C6B7EED6BE7E5D32B79651F5DD7BE3D35ADDD14BDBD344DAD03DDBD13C
D3CC35D2CC30D1CB2DD2CC2CD2CD29CDCA23DAD730E2E139E3E43EE2E33DE0E239E1E338
E1E337DFE233DEE132DFE334DEE236DBE139DDE142E6E74DE3E24ADAD440D1C732D6CA3A
CEC137BEAE34B5A13E7E671B6B4D196D4C29947056754F3C7D564775514367473A5C4235
6150405F5241675F486A644A827D5DAFAA84B6AF83A59D6E9B9364ACA5799B997386866E
F9F9F100FF00
00FF0000FF0000FF00B89C9B814745903C3CAC3F44B0373EB73A3EBE4145B43B40AD3A41
F78D97EC828EB23A46C4414FC8414FC83F49C43B45CA4149C94248C7464AAB373AA73D3F
F79497BA575AB44A4E9D3438973B3EFFA6ABE9848CB9474FCD4F53C7494ABE4C4BA24742
9F5F56BA8F88A286829C8A869E908D9A8F8B9B908E9A8F8DA09591A196928D8280695E5C
4A3F3D59504B867D78978E87A0958F9D928C9D928C9E938D9B908A9D928C9F948E9F948E
A59A94ACA19BC5BAB6D9CBC8D4C5C2CEB9B8BD9B9CC69599E39EA3BF6D73D77B7EC56566
C76967D27772C96B69AF504EB85454B75051BF5859A64846AA5654BA736FB07571A97975
A47D789A7B769A7E7B99817F927F7B917F7D91827F9082818F81808C817F8F81808A7F7D
8E83818C817F877D7C897F7E897F7E897F7E8A7F7D8B807E8D7F7E8B7D7A8E7F7A8F8178
92817195846A97855F94834F948240928234AB9D44C3BA5DCCC86FC9C77CDBDBA7E0E0BE
918C798B8279B3A29AE8D1C1876A4AAA8A57FAE093F2DB7BEFDD6DEEDE65EBDE5EEAE05C
E4DC55E1DB51E0DA4ED6D443D8D645DAD943D7D63EDAD940DBDC42E6E74BE1E344DEE13C
E2E63ADFE334DCE031DFE334DEE235E1E539DCDF3AE3E441EBE748E0DA3CD7CE33D2C72F
CCC02EBDAF2ABAA83A78630A573E008163317C5C33603D1D8A664C6A473193725F7F634E
6047315540255D4A2A6F613E695D3770693D9E9769B7B384B2AE7F949367AAAA84A9AC91
F8F9F100FF00
00FF0000FF00FFF6F49C7E7C844744953F3EA93C41AD3439B83D40BB4045BB444AAF4248
D5717BDD7985A93B48B74252BB4251C04351BE404CC3444FC2404AC2434AC2474CAB3239
BC474DBC434ACC4D54CC4F559D282EC55259D45B62C94C52CF4E52C44A49BE524F99443D
AE736BB590889D8581998A879A8C89998E8A9A8F8D9A8F8D9A8F8B9D928E9F9492A19795
897F7D5E545248413B58514B847B769F948EA196909D928C9B908A9C918B9A8F899F948E
A39892A29791A89D99B1A3A0C3B1AFE3CBCBEBC4C7E3AFB3CD868CB25D62CE7275CF6F70
DB807DE58A87F09290DA7B79C86464C35C5DC0595AB85454A94B49A85350AA5C5AA96361
AF726FAF7875A97874A87C79A37D7A9E7C7AA18480997D7A99807C977F7B95807D927F7B
93817F9283808D7F7E9385858C817F8E83818E807D8F827A95847A90807197867494846A
98866294825490804492843DA59547B0A450C7BD68D2CB7BDDD894D7D49DC5C29FABA994
9C958DA29897A39594C3B0AA6D5342694F2EA58957BFA260DEC171F0D57AF4DA79F3DE75
F0DE70EFE36DEDE36AEBE366E9E162E7E05EE3DF59DFDB53D7D449EBEA5AE7E753E0E147
E1E340E2E53CE1E539DFE337DEE235DDE135DFE138E0DF39E6E33EDFDA36D5CD2CD3C92A
CCBF25C9BA2BBEAF30A99729806B107D6618836A27785E239F8353775A308266419A805D
745A37765F36816B3C6A562362521E6A5E2A766C3B847E4EABA778A6A579A8AA83B3B69B
F8F9F100FF00
00FF0000FF00F7ECEA8A6B688144419B4341A53B3DAA3337B63E40BA4347BA494FAA4249
9A3B43B0545FA44654A84758AF4A5CAD4657B04555B14554B2424EB7454FB94550B8434C
BE454EC4454ECD4750CA444DC9434CC23C45CF4751D04950CB484DC04A4AAE4A48974843
B9847EAC8B849E8984978A84978C889A8F8B988D899A8F8B9C8E8B9A8F8B9A8F8B99908B
9D948F9D96908C8481574F4C483E3C665B578C817DA39592A49791A396909E948B9D938A
9E938DA29791A49693A79895B09B9ABC9C9DDEADB1F4B3B9C17077B2555DAB4B4FB55255
DE8080FA9F9CF79C99F29794F69B9AE58787D17270D37170BF5B5BB35150AA4A4BA24746
9D45449F4B49A65554A95D5DB16B69B0706EB57B79AD7A77AD7C78A77B78A27C79A0817C
9D807C9B818097828199858693817F907E7A93827A9C8C7C9A896F9886629A875C94834D
8F7D3D94833BA09344B1A656C0B76AD5CC87E0D79CD8D0A1C1BB97AAA68D9F9B8F9D9A95
9F999BA09A9EA399A1B3A7AB8D7B795138316546346B462B875B34B18352DAAC71E8BB77
EFCA7AF4D57BF4DA79F9E37DF4E178F4E475F2E573F3E872EEE66AEDE868E8E65FE5E456
E0E34CDCE043E4E643E2E540DEE13AE2E53CDDDF36DCDE35DBDA32D6D32CD4CD27D5CC29
D0C325D3C62CCFC331CBBE34B9AC2CAA9B26A08F259C8C2D9C8A368E7C34715D1E7A672D
77642A766225B09E56B8A65A8B792F5E4D0866551D756736797142C3C095B0B28DADAF97
F8F9F100FF00
00FF0000FF00E5D7D47B5A55864742953D3BA53B3DAB3438B84042B84447B04348A03B41
AE535CB15B66B46471B66876A65969A254649342517F2D3B8F3B488B333F983B46A13D49
B3434FBB434FC64450CE4650CD414ACC3F48CD3D47CF434CC8454ABE4A4BA849479D5650
BD8E88A2857F9E8B859B8E889B908C9A8F8B978C88998E8A9E908D9B908C9A8F8B99908B
99908B9B948EA099939E9791897F7D5E55504A3F3B685A578B7D7AA2958FA398929E938D
9C918BA29791A49693AA9695AF9294B98F93D4959DD5858EC86770C75E65AE41479C3236
9B3435BD5B5AD47573D97B79E08282E48686E68785EA8684E7817FE47C7BD87071CA6364
B85152B65252A541439F3F40A14343A24848A85452AB5B5AB26867B26E6BB67976B27B78
AD7C78AB7D7DA88081A17D7D9E817D9980799A84769E8A719A886092814D917E439D8C46
A69649B6A95AC5BC6FD8D189DAD496D2CC9AB8B290A8A28CA19B8FA09B97A09C9DA09BA1
A19CA39F9AA1A199A4A89EA7B7AAB36F5C6046292B65423E71473B71422EA7785AB0835C
A37947BB975DC9A767DABC74E9CE81EED583F1D983EFDA7FF0DC7BF0DF77ECDF6FEFE56C
EAE160E4DE54E3DC4DE4E049E3E047E2DF42E1DE41DFDD3DDAD838D9D536D7D133D8CF34
D3CA31D5CA32D2C832D5CB35D0C633C7BF30C8BE38BAB034A99E2B9E932A8E832782771E
7A6B166E6008A49635E1D26DE8D974C0B1547B6B1E635516786F38BBB788B2B28CADB095
F8F9F100FF00
00FF0000FF00DBCDCA73524D844540973F3DA73A3DAE373BB94045B94248AD3E44A23D43
B35C64B66973AC6873965D66935F6BAF7D89B5838EB2808BCC9AA5AC7884B87E8ABD7986
903C4B9E3947BD4753C6444ECC454CCD4048CD3D46CE434AC7464ABE4C4C9E4443A96864
B38A849F867F9D8C85968B859B908A9A8F899B8E889A8D879B908C998E8A9A8F8B99908B
9B928B9B928B9E958E9D948DA198939F96918279745C514D4638356557549183809F9490
A0958FA0958FA3948FA8908EB58E91C38A90DD8D96C2616ACA565FDB5F67CD5056C74A50
B0393DA63336A03434A93F3FB95351D46E6CDD7775E07A78E47E7CE8827EE98381E27C7A
E47E7CE47C7BDF7778C55D5EBA4D50BF5154B24548B14749B24B4EA64445A74B4CAE5655
B26160B76B6DBA7677B67A79B2817CA781769C7D69977F5D927E4CA09052A99B54BBAF65
D1C57DDAD190DAD39DC6C197B2AD8DA09E899D998DA19E99A09C9DA09BA19F9CA39E9BA2
9C99A29A97A09F99A39F97A2B7ABB597879139262C402A2D4026253A1E1A957A6FEFD5C6
CBB09DBA9E88A98970A07F60AE8E68B6956AC7A373D4AF78E2BC7EEAC57FF2CE80F2D27B
F2D673F0D86CEDD863ECDA5EEADC59EADE58E4DB52E4DD51E3DD51DFD94FE0D851D8D049
DAD24BD4CC43D4CD3ED5CF3BD4CF37D5CE35D5CE37D2CC38CAC335C5BE39B6AE31A59C25
A097228B820D9E9419D3CA49EAE15EEAE065E3D86E8E842B605915BBB883B1B288ADB093
F8F9F100FF00
00FF0000FF00E9DBD87B5C577F444096403FA73D3FAC3539BA4146B63F45B5444AA13C42
AD565EB96E759A5D6498676DE3BBC4EDCAD1E0BFC8E6C5CEF1D2DACDADB8E6C2CEAF7F8D
7C3A48842D3DB24854C44A55CA444DCF434CCC3F47CB4249C6484BB7494A9E4A48B27570
AE8983A18A849D8E879A8F899A8F899C918B9E918B9D8F8C988D899B908C9E938F9A8F8B
988F889C938C9A918A9B928B9E958E9D948FA097929C938E857A765D524E4B403E645955
897E7AA0958FA99795AC908FB7898CD39097D57984B84854CA4D55D44E55D64D54D75056
D04D52C84A4DBC4144B13A3CA63233AB3B3AAB3B3ABE504FD06462D96D6BE07676DB7171
D96F6FE47A7AE87E7EEB7D7EE37073E16A6ED2595EC75054C75457BF4E50B34649B04849
A94547A54748A04847A3555394554EB08072D3B09ABDA583B39E6FBDAE75CEC385DDD396
D6CC97C0B78CAAA4849F9A86A19D929D9A959D999A9D9BA09C99A09F9CA5A09AA4A09AA4
A09BA29D989F9F9AA19F98A0AAA0A9B3A8B04B3E472E1F262A1B1E2F21214B3D3CF1E3E0
F8E9E4FAE7E1F7DFDBEDD4CDDFC3B7C8AB99B79780AF8C70A67F5EA88359BB9566C3A068
D5B272DBBB70E3C471E9CC70ECD06FEED56EF2DA70F0DA6DEFDB6BEFDB6BEFDD6FF2E072
F4E473E5D65FDBD054DCD24ED9D043D8D03DDDD640D8D13BD6D03CD5D040C5BF33BFB931
C8C13CBBB52DBCB529B6AF20CCC634E5DE52EFE76BE2DB73726B1DABA96EB1B384A9AC8F
F8F9F100FF00
00FF0000FF00EEE3E17E625E79423D934440A03C3EA73439B63D42BA4148B7444BA83F44
A1464DB96C729D5F6488575BF3CBD3F0D0D58F6E758A6B71C3A5ADBFA4ADCAAAB7A27987
A76D7C984B5BA34150BC4855C74853C8404AC94048CA444BC2474AB34B4A964844B78079
AA87819C88819D8E899E938F9A8F8B9A8F8B9C8E8B9B8D8A988D899A918C9A8F8BA09591
958C879B928D9A8F8B9B908C9C918D9C918D9B928D9E9590A39A959B928D857C775E534F
4C413D685A57917B7DB08E8FC18A90DC8F97C5616BC14C55CD4B53D44B52D5484EDA4E51
D74C51D54D51D44B52CE494ED14E53CB4A4EBC3E41B5393BAE3637AE3838B33F40C15150
CF6361D86C6AD66A68DA6C6BD76766DA6868D56164CD5A5DCF5F5ED66867D86E6ED36B6A
C96162C0595AC35F5FB25955934A41A97464FDDAC6F2DAC0D6C6A4D1C3A0CCBF9DBAAF93
A89D879F9685A49B92A29A97A19B9BA49EA0A09A9EA29DA3A09BA2A39EA59E979FA29BA3
A29BA29E979EA19AA1A099A09E979EB8AFB45C5358291E222D23242E24232B2622D8D3CF
F1ECE6ECE4E1EEE4E2F0E6E4F1E8E3F2E7E1F3E4DDEDDCD2E3CFC4D6C0B2C3AD98B29A82
AD9072A48360A38056AC8453B48952C99D60CEA15EE4B56FEEBF77F1C57AFBD283FFDA89
FFE089FFE286F9E17FF3DE75EBDA68E4D45AE1D452DBD14BD8D047D3CD43D8D049CEC63F
D0C83FC7C032CEC836C4BE2ACBC330E5DE50E2DB59F4EE808C8534A09E61B2B483A5A889
F9FBF000FF00
00FF0000FF0000FF00B8A39E73484281403A933A3CA0373BB34045B74046BA454BB4474C
A14145B16164A66569804E51E1B8BCF9D9DCA38386371A1E80656AD7BCC59F818DBC96A3
E1ACBC924E5D953D4DAD4453BF4753C44550C7434EC3444BBF4B4CAC4846944B45B7857E
A688809D8A849A8B869A8F8B9B928D9A908E9B908E998E8C9A8F8B99908B9B908C9B908C
99908B9C938E9C918D9A8F8B9C918D9C918D9A918A9990899F98929C958F9E95909D948F
8E83816F5F5F684E51795054B1727AD57F88B84E58C95057CA4C4FCE4A48D24C49D34E49
D34C49D54B49D44A4AD74D4DD4494CD64E50D54D51D14C4FCC4A4CBF4142BD3F42B3383A
AF3939AC3839B03C3DC24E4FD56162D15F5FD25E61D05E5ED06261D06462DC7370E8807F
EC8483DF7774CC6461B85953B2645A995E50EFCAB8ECD6C1C5B4A0AA9D8CA09486A59B92
A69D98A19997A79EA1A2999EA29CA0A39DA1A19B9FA49EA2A19CA2A19AA19F98A0A1979F
9E989C9D979B9E989C9C969A999397AFA9AD736D712C2628362D2E2A2522201D18C5C4BF
F2F1ECE6E5E1EAE6E5EAE6E5EAE6E5ECE7E4EDE5E3EEE4E2F1E6E4F2E7E3F5E6E1F7E6DE
F1DDD2EAD3C5E1C4B4D0AD99BD987EB48B6BA0745195653FA7764DA6754AB18352C79C67
D5AB71E4BC7EEDC786F6D18AF8D584F4D57BF6D876EFD76BE8D360E9D65EEBDB61E1D452
DBD249CCC336DDD546D0C839D2C63CE1D754DAD057F2EB819992418D8C4BB3B583A4A887
F8FAEF00FF00
00FF0000FF0000FF00E7DCD879625A7E534A904C4B913739B04349BD4850BC454BBC494E
A84144A85253B26E6F8D5757A17778F6D4D3E7C9C9674D4EA68D91F9DEE5A88792B68C98
A773807A3A4ABA6C7CA84C5BAC4351BB4754C44853C1484FBE4D4FA8494598534CBA8B85
A586819D8A869A8B88998E8C9A908E9B918F9C918F9A8F8B9B908C9B908C9C918F9B908E
9A8F8B9A8F8B9E938F988D899D928C9F948E9B928B9C938C9E95909B928D9D95929E9693
A59B99A49494A285878C5D63B16A70C1666DB84950C85153C04B42B94536B2412FBF4C39
CC5342D05243D25043D14B42D44A47D64A49D5494AD74D4DD44C4CD64E4ED64E50CE4849
C84648BF3E42BF3E43AE3034B73C3FB33B3DB84143C14F4FCB5E5BCE6561D46C69D6706C
D56F6BDC7672D06A66BA5B55CA7A71AE6E64C59B8FBA9E93A6938CA598929E9492A2999A
A09A9A9F999BA59FA39F999D9F999DA09A9E9D989C9F9A9EA09A9E9D979B9C959C9C969A
9B95999C969A9E999F9C979D99949AABA6AA847F833531322E2828282421161510B3B2AD
F5F1EEE8E4E1EAE5E2ECE4E2EEE3E1F0E2DFF2E3E0F3E4DFF2E5DFF0E5DFF1E6E0F1E6E0
F1E8E1F1E6E0F3E8E2F5E8E0F6E5DDF0DED2EAD7C9DDC6B8D0B3A3BE9D8CA4816E8E6853
8B5F469061459E694AAB7350C48B60CE9462DBA368E5B06CE8B768ECC369EBCB64E3CC58
E3D453CBBD38DACC45E0CE4EDDC7579A87209D902AFAF194AAA353848340B7BA85A2A685
F9FBF000FF00
00FF0000FF0000FF0000FF009C928963483F9A6964A258599E3E42B8464EC0494FBA454B
B24A4BA34748AD6364A26666835150C89E9FD2AFADC6A6A7BEA0A2E1C1C6A07B83C398A2
A7737F894C5B8C4555DD8A9A9A3A48AA3E4BB33D49BC454BBE5051A04540A15E56AE817B
9477739B8884988A87988D8B988E8D988E8C9B908C988D899B908C9D928E9C918F9B908C
998E8A9A8F8B9C918D978C889F948E9C918B9B928B9D948D9C938E9C938E9E94929C9290
9E9391A59192B08D91C28B91D88891B7535BC14E53C7514FB7493CAC4830B55B39984018
9A3D14B04D26B94E2CC65439CB523FCF5142CF4D40D24D44D55047D34C46D54C46D84D4A
D34949D34B4DD44C50D24B51CB484DC24146BF4145B4393BB23C3CAB3938C75756CF6160
CF6160D86C6AD56966C3605BB560599C584F906159AD8E89A59190A39797A09599A0979C
A09A9E9B969A9993979E989C9C96989B95979B969A9E999D9E989C9C969A9F989F9F999D
9E979E9B969C9A959B9D989F98969BA5A3A89893993C373B2A262726222114100DA4A09D
F6F1EEEDE3E2EFE3E3F1E1E1F4E1DDF8E0DCEBD2CDECD3CEF6E2DBF6E3DCF7E6DEF4E7DF
EEE7E1EBE8E3ECE8E7EBE9EAEEEAE9F0EBE8F2EAE8F5EAE6F6E7E4FAE7E3F9E1DDF2D5D1
EBC8C2D7AFA7BF9088B07F71A16C5A89513A84482C763C168149168B5A17BD9840DEC358
E3CF56CFBD3DDAC64BE6D060AE9435594100948327FBF096B7B05F7E7E38B3B67FA2A683
F8FAED00FF00
00FF0000FF0000FF0000FF00D3CEC8594B4274534CD39C999C474AB0484FBB484FB9464B
B54B4DA9494BA35155AF696B7E40415820218C5958EDBFBFEBC1C2D7AFB07A4D52B28389
D7A5AE9C6771874853E69AA7AF5360B94F5BA02B34B33C40BB4F4DA54B43A15E56B98D84
6E514B705F58948582998E8C9A8F8D988D8B9B908C9B8E889C8F899E918B9D8F8CA19390
988D899B908A9D928C9B908A9B928B9990899D928E9E938F9D928E9C918D9F94929D9290
9D8F8EAA9194B1868DCD8E97D57B87BC4E59C84F54C9524EAF48399F4A2BF8B682E7B270
C59044A1651C8D490893460EA0491CB1512BBB5232C65439CB533ACC4F39D34F40D24A3E
D44942D64B48D5494AD5494CD84B51D54A51D3484FCF464DD14A50C74247C23F45BD3C41
B93D3FAA2F31AC3636AF43419B403B89403A8D5A56B2908EA28E8FA19597A0959BA0969E
9C969AA09A9E9A94969D97999C979B9893979B969C9D989E9691979B969C9B969D9B969C
9E99A09B969D9D97A19E9BA49A979EABA9AE9792982E282C2C26282A2426161010A19899
FCF0F0F1E1E2F4DEE0F9DFE0FFDDDCC8A29F744B47B8918AFFDBD3E9C8BFB7998FBCA39C
F2E3DCEEE6E3EDE9E8ECEAEBE7E6E4E8E4E1EAE5E2EFE8E2F4EBE6F4E9E3F1E6E0F2E5DF
F2E5DFF4E5E0F9E6E2F8E3DEF2D9D4EDCEC9E0BAB1C89D8CCDA1847C5423B8944AEDD16E
E5CE5AD5C148E2CB5BA48B277C620E5B4200AC9C3DF8EE8DBEB95E7C7D31B0B57B9EA480
F9FBEE00FF00
00FF0000FF0000FF0000FF00F5F6F17F787055423BD1AAA39753529D4448B34A4FB8494F
B3494BB34F51A1484C9342489145496D25298D494AC88888E5A9A9C08587692B2E8D5055
E7ACB2E8ABB2D6959DA85B658F333EA13741A22A33B53E42BE514EA34941A36058BE9289
A0837D725F595A4B487769689486859C918F9B8D8A9C8F899C8F89A0938D9F918E9F918E
9D928C9E938D9E938D9F948E9A918A9D948D9D928E9C918D9D928E9C918D9E93919F9190
A59393A98B8DB9888ED78F9AC86371BF4955CE4D52CA4D4BC3574A7C2708CE955EFBD185
F0CD71F1CF6DE3BA5ECB9B47B1792E93520E954B0C9B4911AA4E1BB55024C35731C55233
CC523BD14F3FCF4B3FD34A44D74948DC4B50D9484FD7464DDA4A53D6464FD94952D2454D
D1484FCC474AC24447BA4646AE4C49924440915A57B69391A59192A095999E959A9E979E
9A94989C969A9B95999A95999E999D9B969C9C979D9893999C979E9E99A09C979E9D989F
9F9AA19F99A399969F9C99A2A09DA4B6B1B7918A912923272C26282E2528180F129F9395
FCECEDF3DADDFBDDDDFDD7D6B98D8C7B4B47B2817CEDBEB8BD908A704840542F26856860
F6E5DEF3EAE5F0EAEAD3CFCE8F8B8A716D6A625D5A76716D9B948ED3CCC6EFEAE6ECE7E3
EAE5E2ECE8E5ECE7E4ECE7E4F0E8E6F4E4E5F8DEDFFFDED9FFE2D286623EBD9C59F3D678
E6CF5BE5D059BDA83F715A00796109846F14E1D36AEBE378CBC766797B28ABB1759CA27C
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF00BEBDB84D453A9E887D895A54843E3E9C4244AC4548
AC4445B14A4DA44448983B43963C459C424B8B32387B22267C26297A2427852A2F792326
A15154DA8B90B8696E8732398E2A34BA4B54C1484FC3484DBE4C4CA849459E5751BE8D86
A68782A48F8C8775736052515143427668679687849F908D9D8F8C9C8E8B9E908D9F918E
A398949E938F9C918D9A8F8B9B928D9A918C9C918D9A8F8B9D928E9C918D9E908FA19191
A5908FAD898DC1888FDA8A95BE525FC84A56D14A51CD4849CE574F94341CA15D2EFFCF8C
EFCC70EACF64EFD868F3DC6AF1D769DDBE54D8B551BE9335A2701B925709924C0799490E
AB4F20B34B24C55233D0523CD54D41DA4C48D74649DB484ED9464ED94650DA444FDA474F
DA474FD6474BD44C50C84E4DBF5754A4534F97605DB59191A69294A095999B95999F989F
9C959C9C959C9C979D9C979D9F9AA09B989F99969D99969D9F99A39D97A19A979E9B989F
9D9AA3A09DA69C99A29C99A0A7A2A9B5AEB5857F81292023342B2E32272B1C1012A19194
FAE6E8F8DBDDF8CFCDA97874905D59F3BEB8E1AEAAA3746E784D46A17A73CFB1A7F2DBD3
FBECE7E5DBD97A72706F676598938F9A959189848177726F46413E56514EA8A09EEBE6E3
E8E3E0CDC8C4D8D5D0E5E2DDE8E3E0EDE3E2F5E1E2FADEDBFFE1D6795837B99A59EDD374
E5D059EDDD63A0912A625400938518D3C751E6DE61E4DF67D7D26A7F7F29AAAF6F969A75
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF00F0F1EC89867D655B516A4F467A4B45914D4C974645
9B403F9838399F3C3F98353A98333BBE565FA83F46A4393F972A3094272DA6373EA83B41
9D363AA0404286272DD26E76A33840B13C44C64951C6474EBD494CAC48489F5451BD8884
A5827E9F8A85A3918F9A8C8B7668674F41405446457F716E998B88A19390A193909F918E
9F9490A196929E938F9B928D9B928D988F8A9E938F9B908C9D928E9C918D9E908FA89696
AB9192B38A8EC88992D57F8AB54551CC4A56D2474ED3484BCF504AB34433923718E29A68
F5BD73F6CA71F3D06AF5D769EED465ECD563F3DC6CF3D96AEFD368E5C45DD4A94AC49138
B172259F510FAA4C18C0522DD1533CD54B40D54544D84649DC464FD9434ED63F48DE4750
DD464DD8454BD24649CA4C4DBB524FA4534F955E5BB39190A69294A2979B9D979BA39EA4
A099A0A19AA19F9AA19E99A09D9AA19C99A09D9AA199969DA09AA49C96A09C99A29F9CA3
A19EA79F9CA39D9AA1A6A1A7A59EA5B5AFB3746B6E261D1E342A2B332729231314B7A4A6
FFEAECE3C5C58357545D2A26AA756FD09B95C28D89DBA8A4F2C3BDF5CCC6F7D9D1FBE4DC
FEF1EBB6ACAA1B110F887E7CF7F0EAF3ECE6F4ECE9EFEAE7DFDAD7938A8B3F3637B0A8A6
C1B9B78A858187827E8E8B8686827FB8B0AEFAE7E9F6DEDEFEE2D77C5D40B7975AF1D67B
E4D15BEBE062877B0B887E0BDBD251DCD64CDCD94EE7E463DAD86B81812BA6AB6B91966E
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF00EEEDE9C6C3BC958B8277635A744F497E4943
914E489E4D4A9D42419C35389D3035AE3B42B13A40BC434ABD4149BD4048C2434EC2444F
C0474EC24D53B13D46C14D569C242DB2353DC94550CA4852C1484FB34A4E9D4C4BC08483
A9817F9E86829E8F8A9B908C9E938F9388866C615F4B3D3C594B4A857776988D899F9490
9E938D9F948E9D948D9B928B9D948D99928A9D948F9B928D9C938E9E938F9E908FA59393
AF9294B18489D28F98C86E78BA4852D04D55D1464DD6474BD44A48D04C47B3392EA33420
AC4A27C87241E89E61FABC73FDC975FCD173F7D46EF2D466EDD460EBD55DEED85EF0D65D
F0CF5EF3C361E19F53A04611CA5836D44F3ED54642DC474BDA474FD9464ED64049DA444D
DA454BD54449D4494EC94D4DBD55529F504B96635FB29391A59393A4999DA09A9EA29BA2
9E979E9F989F9E999F9D9BA09D9AA19C99A09D9AA39A97A09F9CA79E9BA4A09AA4A39DA7
A49FA6A49FA6A39EA5A19CA2A59EA5B1ABAF645B5E2B21203125252C1E1D301E1EDCC8C7
FFEDEAC5A9A6AD8784DAAEABE9BCB9C99894AE7473B478778E57547948438B6960AF968F
FAEBE4E6DDD8BAAFABDFD4D0D4C9C3BFB6AFC8BFB8E0D9D3FFF7F4D0C8C62016158F8584
A39998CCC2C1877F7DA49F9CCAC4C4CDC3C4F7E4E8F5DDDDFFE3DB917357AD8E57F2D883
E1CF5FDFD552A69E19CEC73BD6D03AD8D53CDCDA47E2E25CDEDE707D7F2B9FA5678A906A
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F8F3E3DCD4B6A59E8D706A
815650905652944A47A14B4AAD4B4CAB4145AB383DB43B40BD4046BF3D45C8444FC9434E
CA4651CD4B55C4454EBE3F48B6343EC33F4ACB434FCB4752C64951B94B4E9F4545B67271
B285829E827EA08F88978C869A8F8B9C918DA095938D81816759584C413F5F5450847975
9D928E9F948EA196909D948D9C938C9A938B9D948F9B928D9C938EA196929D8F8E978281
AF8F92B6858BD68E99BE616BC04C55CF4C52D4474DD44348D44547D04443D54B49C94540
B73F2FA63A209A39169D491AB46D2FD2944BE7B35FF4C96BF3D36CEAD35FE3D550E4D74B
EBD953F1D45CFFD175AC6621B94F27D1533DD84B42D94748DA474DD7444CD7414AD7414A
D9444AD7464BCF4449CA4E50BD5755984A469C6B67B39593A39394A39A9DA19AA1A49DA4
A099A0A19AA1A09BA1A09EA39E9BA29D9AA39C99A29C99A49D9AA59A97A29B95A198929C
948E988D888F8681887873796D676B7C767A4C43462D21213626262C1817503836F2D8D7
FBE2DEFADDD9EECCCABA9795A27A7AE5B7B7E2AAABCB8F8FCD9391C49490C1A0997B6760
F0E5DFD6CFC9968B87887D796C635C685F585049434E4741857D7AA59D9A857B7AC7BDBC
948A89A89E9DA9A19FD3CDCDE8E2E4F0E5E9F0DFE5F2DCDEFFE5DEB3947F937344F4D88E
E0CD66DCD153C0B92DE1DB45D0CC2DD5D333DEDD45E0E05AE2E1776D711D8E94568C926C
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6EBE7
D2C0BCA88C8887605B834E4A96524FA45551AC5150AE4647B24143B83F44BB3C43C03C47
C6404BC9434EC8404CCF4753CF4753CD454FD04751CD4750CA4850C24E51A54143AC5E5C
BC8783A07F7A98847D9A8D87998E8A9B908C9A8F8D9D9290A196948D82805F545249403B
665B578B807C9E938DA0958F9C938C9E958E9E958E9D948D9D948DA0958FA3918FA3898A
B28B90BF868DD88B95B7565FC34E56CD4A50D3484DD44549D64548D64749CF4543D04C47
C94F44C45542B74F36A14321983F138C3A0892470EA06324B08139E2C164EBD75CE3D649
E8D94CE9D250FFDF74C98E40A54714D25A3FD34E3FD44642D54344D9464CD8424BD9434C
DA474FD8474ED1464BCA4E50BD5755994B499D6C68B294929F8F909F9699989198958E96
928B928C858C878289817C837C768077717B6E6B766864725F5B6A5D59685A54624F4955
47444D423F464B464D4A454B4F4A4E5C565A382D313626293B2225321414826361E8C6C4
C2A09E916F6D694A488A6A6BEBC7C7F1C7C8EBB9B8D9A3A1AD7C78C29B96FFE8E4F1E4DE
E8E0DD44413C3E36339D9592B0ABA5BCB7B1AFAAA68D8884615C5967625FBCB4B1F6EEEB
A199967F7A77847F7C6B6766747071F3EAEDF0E1E6F2DEE0FDE5E1D9BCAC795531E8C689
EED47DDECE5DC2B834DFD947C6C326D5D235DCDB43E0E05AE4E57F5C61117D85498E966F
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF5F3E7D5D1BDA19D966F6A824F4B8E4F4A954A45A44E4DA94B4BAB4447992C31
A53039B93D48BD3946CB434FCB434DCB434DD04751CC444ECC464DC74C51B94C4F9F4746
BD7D7BAB807A957A7397867F978A849B908C9A8F8D988D8B9C918FA398969F9492857A78
594E4A473C38655754897E789F9490A39A93A198919D948D9C938C9F928CA69291A98B8D
B5888DC5868ED7818CB74F5AC54C55CF4950D3484FD3444AD5464AD14747C94843C85248
C05744A5472B8C37108939088E41098841037F3B00753C005327009E7F25F1DF63E3D747
E6DA46E7D54BF3DA64ECBD619A480EC35733D2513CD2483ED64645D64447D84349DA444D
D6434BD6474DCF474BC84D4FB85454974C49A27270947877685A5A5953575750574E474E
474047443D4446414746414848434A4A444E4D475354505E595563635F6D66606E6A6470
74717A7C7980837E858B868CA29DA1928C8E352A2E3C2C2F41282C3214167858597F605D
5D3B397F5D5BCCAEACFFE2E0D2AFAD956C6AEEBCBBBF8E8A8B5F5C805F5AFBE8E4F9F0EB
E3DEDA34312C615C58D9D4D0EDE8E4F0EDE8F0EBE8EFEAE7EBE6E3807B787E7975F6F1ED
F8F3EFF1ECE8FAF6F38A8685878384F4EEF0ECE1E5EFDFE2F6E2E1F8DDD489654DB28D63
F7D895E3CB71C0B03FDCD350CFCA3BD6D441DFDD4CDFDF5BE5E8815F66187880448D956E
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F0E5E1CDBCB599807B75544D7E534C895851834945C58180
AB565B99353DAF3945B93A45BF3B46C43E47CA424CCC444ECE474ECC4B50C24E51AB4747
AC5E5CBF85819C7771937C7693817D958784968B87988D89998E8A998E8A9D928EA09591
9D928E847975564B47423733685D5B918682A196929F94909D928EA39592A4908FAD8D90
B6838ACE8691D47684B84856CA4C57D34B55D4474FD4454BD14649CD4D4AC35348B65741
7B360F7B470EAB8032C29D42CBA844C7A43CBD9D36AF922C88700E7B6900DDD14BE8DE4B
E4DA44E2D646ECD958FDD66DAB6621AE4D22D0573CD64E40D54743D84647D84349D9444A
D7444AD34448D1494DC1494AB95A5889443F9F73709A82807C7070756F737C757C7D787E
827B828781858B868A8D888E918A919792989A959C9F99A39C96A09C96A09D97A19E99A0
A29DA49C979D9D969D979195ABA5A9837D7F31282B362A2C36272A322020CFBBBAD7C2BF
DEC5C0FCE0DCFFE6E2FFE3DFE3B7B4C49490EBB8B5E6B6B2A47F79C8ACA8F9E7E3F0E5E1
FEF7EFC3BFB65750483F383257504A97928CD8D0CDCCC7C39B96933A35326A6762E9E6E1
E1DCD6E1DCD6D7D2CEB0ADA8D6D5D1EDECEAE9E3E5EBE0E4EFDFE2FCE4E4CBA8A26A4431
D2AC85EDCD90CAB15DE6D770DCD35ED3CE4EDAD650DEDF5FE6E982666E1B777F43848C65
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9F4F0DBD2CBB1A29B8E7A71644942C7A29C
FCC6C6B06569B15057BE4F56BB434CB93C44BE3C44C13B44C63F46C9464CC74A4EBE4D4F
A14343BA706DB47F7B997672937A76907E7A938582928783988D89998E8A9C8E8B9C8E8B
9C918DA59A969F94927F7472584D4B473C3A6C615D908581A09591A49693A28D8CB08D91
BA828BD98B98D26C7ABD4755CA4653D24651D6464FD2454BCE4849C64F49C25E4F7D3213
8F6028E3C676F0DD74E9DE62E9DC59EBDF59EEE15EEEE161EADB64D7C94FE2D552E7DA4E
E4D74AE6D94FE9D656FFDE73D99F55984211CC593CD34E3FD84A46D34343D84347DA454B
D8454BD7484CCF484CC34D4DB055528B4A44A57E79AB9894A298979D979999949A9E999F
9E989CA29CA09D979B9C969AA09A9E9C959CA19CA29E999F9C979D9B969C9C979D9B969C
989399959094979195979193AFA9AB635D5F292021362C2D271D1E4E4242F4E4E4FEE9E6
FFE6E2FADBD6E0BDB7D8AFA9EAB9B4D29F9BC08D89996C678E6D66FBE4DEF4E5E0F1E8E3
C7C0B8C9C2BACFC8C298918B5E5751615A5499908B81787349413E817976E1DCD677726C
3D393089857C4A453F9A9792EBEAE5E8E9E4E5E3E4E8E2E4EBE0E4F2DFE3FDE0E4A68580
67422FBA9873D0B27CD8C47D998A35979028D9D55AE1E167E4E7806C741F7A8445838B64
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDE8E4BBB2AD93827B
B396908E5E5A8A4645A65051B75054C25157C44B52BF4047BA373FC44149C34247C84D50
B44647A94B4BC17774B47F7B9A77738F777392807C8E817B8E837D938882988D89998E8A
998E8A9B908CA196949F94929E94927E74725D52504D42406D6260908080A38A8DB28B90
BD7F8ADE8A99CA5E6EC54858D24C57D2464FD4444DD3484DCC4A4AC5524BB45849672502
D4B066F0DD76E6DB5BE2DC4AE1DB45E5E048E4DD47E8DD4FE8DA55ECDA5CE9D55AE9D55C
EAD65DE7D25BECD261F7D571FCCB7F9E5522BA4E31D25043D54A47D64548D84349DC474D
D74548D34748D04B4CC14F4EA8514A884C44AB8884A3918F9E95969F9B9C95909699949A
9994989D979B97919598929699929999949A9D989E96919799949A989397999498999498
948F93969195958F939B9597ACA6A84842422C2324352B2C211515827272FBE7E6F8DCD9
D2AAA8AF827DCB9C96E2B1AAE9B4AE996662B4857F956C66694C44F5E1DAF4E9E5E8E0DD
494440423D3956514D51494659524C5F56516D625C968983C4B7B1DDD2CCF9F0E7C1B9AE
8A81788780763A352FC1BEB9F1F0ECE6E6E4E4E4E4E5E3E4E8E4E5E6DDDEEEDEE1F9E0E3
A487837E615394765C6149233625006E6218E2DB71E0DD6ADEE37C6B731E7682427A855B
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F0EC
DACDC7B097928A615F894F4E8D4344A1484AAF4D4EBB4E51C24D53C1464BC2434ABE4044
BD4547B14545AE5352BF7876AE7B779976709279748E7B758C7D788D827C928783958A86
978C889A8F8B9C918D9A908E9F9593A29896A095938479775F5452554545775D60A1767D
BE7C88E28A98C55565C64655D04854D2454ED3434CCF4449CF4D4DC3524AAD544475350F
ECC978EBDB6AE4DD51E2DF44E3E13FE3DF3EE5DC41E3D445EFD658F6D466F3C965F3C669
F7C971F7C971F8CA74FAC778FFD394CB7E52A2351ECE4E45D54B49D34247DB484EDB484E
D34245D34949CB4B4CC45655A4514B8A514AB0918EA191919F96979C979B97929699949A
9B969A9994989892969892969691979893999A959B9792989792969A9599979296969195
969195969195958F91A7A1A3A09A9A3930312E2425362A2A221414B4A2A2FFEDEDBB9998
5A2A26BB847FEAB1AAD09790CE9490E6B1ADFCCBC788615CAB9089FAE9E2FCF3EECCC7C3
2C2825B5B1AED1CCC9BEB6B3524A47261D186356505E514B56494170635BD7CDC3BBB3A8
C8BFB6C9C2BA827D799D9C98F1F0EEE6E6E4E4E4E4E4E4E4E4E4E2E4E0E1E4D9DDF6E3E9
FFE7EBA98D8A5C4034381E07352300776C2EE3DB78DEDC6DDEE37D717B2471803F758257
F7FBED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5EBDBDBC9AFAEA07A77885552834240924241A54748B54B4FC0494DC6494F
C74A50C0474CAE4144A94D4EBC7573B8837D99746C90756E8C79738C7F798D827E8E8580
918883958C87988F8A988F8A9D948F99918E9E9492A096959C92918A7A7B785B606F414B
995260E38796C55062CB4858D24855D44750D1414AD0454ACF494AC8514BB75749742F08
E4BD70EBD969E0D74CE3DE44E3DF40E4DB3EE6D843EFD655F2C663CA8F43B36729B55F2C
BE6638C86F43D98354E18F60FCAD86FDA486AD392ACB4743D54A4DD7484ED5424AD9464E
D54449CE464ACA4C4FBD53539F4F4E945C5BB09091A191929D92969A94989A94989A9498
9B969A9A95999C979B9893979893999A959B979298989399959094948F93959094999498
969293959192979394AAA4A687818333282C36272A382829342123E3CECDFFE9E8E5C2BE
C08F8BD19692BD7E79CC8C8AD19191C58B8A9A64628B625EF6DDD8F4E7DFF6EFE9E7E4DF
6A65615D5854978F8C9B9390322A27251B19A09593DBD0CCD2C7C1D2C9C2E4DBD4736C64
221B155D5854807C79BBBAB8EDECEAE5E5E3E5E5E5E4E4E4E3E3E3E9E5E6ECE1E5EFDFE2
FEE8EB9C837F543A2D442C123A2800837838DED876E1E171DDE47D6F7C2469793874835A
F7FBEC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBECE9E1C8C4B6938F8E5D5981403E91403F9D3A3DAC3F44
C14952C74F58C35057B64F52A65252B4736FA7787295726C9175718C77728B7C778E817B
8C817B8D827C8E857E938A8398918B9A938D9B918F988E8D9E9493A59596A78A8EA6777F
AA626ED87A8ABE495BD14C5DD24857D34551D64650D0434BD1494BC64B46C55B4E792908
BD8A48F6DA77E3D453E7DF4CE6DF46E5DC43E8DA46FCE365BB8C32833F00AA4F22AA4121
A6361EA6331EA0301A9E311AA03A24BA4F3FA52921C74140D64B4ED5464CD6454CD8474E
D4454BD0494FC24A4CBA5356964A4C9C686AAF91939F8F929D92969B95999D979BA09A9E
999498948F939C979B9893979A959B9B969C969197999498989397938E92969195989397
959192979394979394ADA9AA6A64662A20213D2D302B181A624E50F6DEDEF6D6D7DBB3B1
CD9D99D19A97E4A8A7DFA2A1844647AC7271B37D7D633A38E4CCC8F6E9E3EDE5E2EFEAE6
DFDAD688807D5C534E4C433E7C736E7B726D453A384A403E978E89E4DBD4958E88716A64
514C49696461D3CFCEE7E6E4E5E5E3E5E5E3E4E4E4E4E4E4E4E4E4E8E4E5EBE1E2EFDFE0
FCE8E98F7773503627472F13382700887D3BDFD977DBDD6FDEE4806D79255261267D8B67
F8FCEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEDBD7C4A5A29A6D6AA665639F4D4F
96353C9A303AB0424BB44C53B3595B9C5251975F5EA579789B75749778758D74708F7A75
8D7C75897C768B807A8C837E8E8781968F8998908D9A908E9A908EA09090A98C8EB5868C
C8808BDC7C8AC0495CCE495AD14756D24450D4444ED3464ECF4449CA4848CA534BA34029
8A4315EABC6FF1D769E2D650E4DC49E5DE47E2D843FCE966C19D3C783F00AF5D2DC05C3A
C4553AC74E3BCC4E3FCA4C40BC4036BA3933CA4340D24647D4484BD6474DD3444AD4454B
D1464BCA494DC14E51B355568E484AA57477B19395A090939E93999D939B9A939A9C959C
9C969A9993979B949B9B949B9A94989A9498999498969195948E92948E90969092999395
959094948F93989697A7A5A6453F3F2D23243B2B2E271416978385E9CFD28F6B6F7E5657
D0A4A3D4A6A6D3A3A3D2A09FE3ADABFFCDCBE7B5B4B99191F2DAD8F8EAE9E5DDDA645F5B
7A726F978E89A19690BEB1A9D7CDC4E8DDD7D6CBC78C82804A413CA7A09AA29994D8D1CB
E7E2DFA39E9B918D8CEAE8E9E7E7E7E6E6E6E3E3E3E4E4E4E5E4E2E7E3E2EBE1E2F0E0E1
F7E3E2866D68523829452D113425008C8340DEDA79DCDF74DEE586606C204F5B2BBCC6AB
FBFEF500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F4AD9893A6817BB27D79
D48E909D4B4F973C4393383D9B46497B3132B87D7FE9B9B9A6787A926667A07878967472
8F726E8C74708E7B778B7C778A7F798D847F918883938987988D8B9E8F8CA78D8CB4878A
CC8690D67886BC495ACB4B5ACF4755D24450D1444DD2454DD1444ACD4547CE4C4AC65547
8A2F149A5723F2C572F2D669E9D757E6DB4EE2D749EDDF5AF6DC6EB68D358C4D08954510
B15127BE5333C7553BCA533FCA4F40CD4F43D14E46D04B46D44A48D04646D24649D04548
CE474BC74B4DBE5154AC56578A4C4DAB8383AB92959F90959E93999C959C9D969D9C959C
9A939A9B949B9A939A9C959C9C969A9892969893979691959690929690929A9194958F91
989296959192A19FA09C9B99353130302826372B2B261617C6B6B7D1BBBE6F51538D6B6C
BA9897BE9B99E7BFBFDCB0AFB585819665619A6D6ADDB7B6FBE3E1F5E7E6EDE3E1726A68
352D2A1A100E1F1410312620483D37524743685E5C7E74728D8680A099936D645F5F5852
7B76727E7A77989795F2F0F1E4E4E4E4E4E4E4E4E4E4E4E4E5E4E2E6E2E1ECE2E3F1E3E3
F2DDDC7B625B4A301F432C0D35270089823CE2DF7EDDE077D8E1884D58147A845FF1F8E6
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C1BAB277695E786153
DAB5ACD09F98D29695A36162985455642424976161FFD4D5E6B4B78A565A8D5558AA7376
A0727298706E9273708F76718F7C768E7F7A90837D9186829287839D8E8BA58B8AB08688
CA8C91CF7982B74B58C94C5ACE4A57CF4650D1444DD54850D1444AD2454BCD4547CE4F49
C2504585250CA35B29F0BC73FBD776F2D963E7D857E6DA54E9DA59F6E16ADDBC55A97B25
90560C8741039A4A17A2491FB0502ABD5635C25538C45039CD503ECF4D40CF4844D04848
CF4A4DC44C4EBA5658A05252885655AC8E8EA390949F949A9A939A9A939B9D969E9F98A0
99929A9891989F959D9F959D9D969D999299999397969094958F91979191989292958F8F
988F92958C8FAEA8AA8783822E2828312C29342C2A2D2522DDD5D2F1E7E5E9DBDAEAD8D8
F3DEDDFFE5E2D5B2AE99706CC59C96BC938D522B26B79593FDE8E5F7E8E5E1D6D4D5CBCA
D3CDCD8F89893D393A272324514849968D8E9E9493756B698B827D8C837CC3BAB57F7872
A9A4A055514E8C8B89F2F1EFE4E4E2E5E5E3E4E4E4E4E4E4E4E4E4E6E2E3EBE1E2F0E2E2
ECD7D46F564F482F1B412A0A362900979147E1DF7ADEE47AD0DA84555F23C7CDB300FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DDDED8716F624E4737
766656C8B1A1F6D1C8D1A49EC18E8AB17B79835150BA8889F3BFC3DAA1A7884B507E4146
8F57589A68679E70709C7472937471927672947D77917E7890817A9885819C8281A98182
C2878BCA7B81B54F5AC6505CC84954CF4751D1454ED2454DD2454BD2454BD4474DCF4749
CF4D4DC5504796321B94421ADB9B5BFACA76F7D470ECD263E6D259EBD85FF0DB68F4D96E
ECCA68D4AB51B58533A1691E9554108D460694430B973C0DAF4722C65338CE5041CE4E45
C64947C25050B35758914D4E936B6BAA95949B8F939C959C99949A99949B9C959D9D969E
9891999B949B9F959D9B949B9C959C9992999993979D979B948E90979193979193948E90
958C8F999091B3AAAB635D5D302B28332E2B1E19155C5753F0EDE8EBE8E3EDE5E3F0E4E4
F4E4E4F9E1DFD3ADACE2B6B3E3B8B2A87F799A756FF5D6D1FDE6E0FFEFE8A697944C4240
5B5555716D6E4846492523262924284E484A9C9394D6CCCBF3E9E7ADA49FA09694CEC6C3
E8E3DF85817ECCCBC9ECEBE9E5E5E3E5E5E3E5E5E5E5E5E5E4E4E4E7E3E4E8DEDFF5E5E5
E4CFCC664E42452C16422E093B3100A5A251DFE277DFE67EC1C97C969E6DF6FAE900FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F8F3B1B2AA636456
4D4A37887D69CEB9A8CDB0A2B38D84D8ADA7BC8F8CA77777AE7C7FDBA7ABC89196B37A80
B57D80A86D718E53599C6467A26F6EA0736E9C776F95776F927972967F79997C78A37B7B
BA8187C3787FB4535EC2505AD25660CB4850D04950D1464DD2474ED4474FD2454DD1464B
D4494ED24D4ECE514DA83729922C13B55D37E49D67FBC27DFACD78F1CF6DEED368EDD666
EBD661F4DF6AF4DD69EFD866E5C95CD9B851D1A94ADDA656B4692F9F4217C9573CCB5241
C64F47BA514EAB5A57814948A0817FA69898988F9298939999949A9B969C99949A979298
9992999A94989A94989A9498999299948F9596919799949A969195969195948F93918D8E
948E90A09A9AA79E9F3C3432332B29342C2A1813109D9895F7F4EFE9E6E1EBE3E1F0E2E2
F5E3E3F3D7D6A97D7EDBA8A7D19B9BD9A9A7FED7D2F9DBD3E0C5BCA79088B7A69FC7BCBA
9F99998C8889716C704E494D3A34382822241B1517473E3F7D75735A5250534B498D8583
CEC9C66B6764E9E8E6E8E7E5E4E4E2E4E6E3E4E4E4E3E3E3E5E3E4E6E0E2E8DEDFF9E9E9
D8C4BD5D463848321A3D2C014B4200C8C86ED9DF73E2EA87C6CF90E1E7C5FDFFF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D5D6CE
7E80725C59487165557968585D4539D0B2A895706ACCA39FC19594BE9293D7A9ABDCABAE
EDBBBCC08C8EAC71779D62668751517E4D498D625B9D7B71987A70987C71987770A07773
B67B7DBE7378A94A52C0525BC44F57C94C52CD4C51D04B50D14A50D0494FD1484FD3484F
D5484ED64B50D34B4FD55053C34745A12F24922E17AC5732D48B58EFB26FFAC776F8CF73
F4D16BF2D668EFD662EDD863EFDC66EFDA67F4D86DFFDC7FEFB66F914511C05936C6563E
C35548B5574F9F5854885856A98F8E9E94959B959996919799949A9A959B99949A9D989E
9B949B9B95999891989C959C9A959B979298969197959096959097989399938E94908B8F
8A86879E9A998C86862B2321372F2D30282626211ED2CECBF1EDEAE8E4E1EDE3E4EFDFE2
F7E1E4EFCFD2A17074D1999CAF7375BF8786F9CEC8B5948BC5A8A0705951B8A7A0FCF2F0
F0EAEAEDEBECECEAEBE5E1E2D5D1D2C7C3C4A39FA08C8889888284ACA6A6C0BABA443E3E
6864636C6865EEEDEBE7E7E5E3E5E2E3E5E2E4E4E4E5E3E4E6E2E3E7DEE1EADBDEFDEBE9
C8B2A7523B29442F123A2C00787224D9DB7AD7DE76E4ED94E1E7B7FBFEE900FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
ECEDE7BCBCB496928780786D50443888766CA78F85B89D94F2D5CDAD8F8795706AD5B0AA
FAD7D3CCA6A3916564A07473A17876A8817C86615970504582625598786BA17B70A87770
B77A77C274748D2E32A0373BBB4A4EC34F52C44C4EC6494DC7494CCA494DD04E50D34C50
D1494DD1494DD24950D14A50D0494DD14F4FC84D48AE392F952A169D3A1DB35934D68454
EBA368F9BA75FCC477FCCC77F8D071F5CF6CF3CB69F9CD74FFD38BA56630A34924BF5B41
BC5B4AAF5B5090534E946C6AAE99989F95969F999D9E989C9A94989992999790989C959D
979098928B928F8A918E8990847F86837E85807B8278737A68656E67646B625D645E5960
4341447571726C66683C36365A51522920214F4949EEEAE9E9E5E4EAE4E4EEE2E4F3DEE3
FCDFE4CAA2AA926167DBA0A4A76567A56867B786818D6860A98E85B7A69EE8DDD7EDE8E4
E7E6E4E6E6E4E6E6E4E6E6E4E8E8E6E8E8E6E9E7E8EAE8E9E6E4E5E8E6E7E9E7E89C9B99
8E8D8BDBDAD8ECECECE5E5E5E3E5E4E3E5E4E3E5E4E5E3E4E9E0E3ECDDE2EEDEE1FEEBE7
A08A7D49331C402D0C3E3300B9B85ED9DE77DCE384E6EEA5F3F6D7FBFCF400FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEE6D4D0C7A89F96A1948BB0A297D2C1B7BAA89E563E349D857B
E1CAC2E1CAC4B79B97B59996D1B5B2F3DAD6DCC3BEA58C85846C6270554A7D5D5290655C
AF7873C6827F954441913635A03C3CAF4545B34546B94747BE4A4BC24A4BC74B4DCA4C4D
CC4B4FCF4C51CC494FD14B52CE494ED24B51D55055D25052CB4E4CC04641AF3A309E311D
9A3519A24420B45D30C97944D38C4CE8A55FF3B36BF8B976FFC78EECA87B9A4121B85842
B65D4DA75D52895450A2807F96848483787C7E787C7872766D676B6861686059615A535B
4A434B4C454C4F48504A454B4B464C544F5558535A58535A5752595F5A61635E65676268
7A787B908C8D423E3F3F3939625C5C241E1E918B8BF5F1F0E6E2E1EAE4E4EEDFE2F8E1E7
F2D3D9C49BA1E9B8BCDEA6A7A366659055519E6F69C39E96D8BDB6F9E6DFF2E4E1ECE2E0
EBE3E0EBE4DEECE3DEEBE4DEE8E3DDE8E5E0E7E3E0E6E5E3E7E5E6E5E5E5ECECECDDDDDD
C7C7C5E9E9E7E5E5E5E3E3E3E3E5E4E3E5E4E5E5E5E7E3E4EADEE2ECDCDFF4E0E1F0DBD6
6E5747453013382900756E2ADDDF7CD0D770E4EB9BEDF4C0FBFEEB00FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F4EFE4DFD9D0C9C3AAA39B857C738E847A
A89F96BBB2ABD2C9C4EFE5E3FFF6F500FF0000FF0000FF00F6EDE8DBD0CABAA9A2977E79
8D6C658F625C8A514A8B463F9647429A413DA2403DA8403DA73E3BB44645B64444BF4949
C54E50C34B4DC44C4ECA4F52CB4E52C94B4ECE4D51D04F53D15152D05051CD4D4CCC4F4B
C2473FB73E33B1392B9F2C199D2D179F3319A1391CB75437C2644BDD7E68A33D2EB65145
B65F569A5550906360987C7B6C5E5E5B55575D575B5B565A5C565A5E585C6258606B6169
695F67756C717C727A7F797D8781858983878982898D868D918B8F948F93959192918D8E
ACA8A78A86852D29282824212A26232C2825D5D1CEF1EDEAE7E3E0E9E4E1EFE1E1FAE4E6
EFD1D3AC8586A97C79C1908BA5746DA4786FF9D2CBF7D6CFE3C4BFF1D8D4F4E1DDF5E2DE
F7E0DAF6DED4FAE0D3FBE1D4F6E3D5F0E2D7ECE3DAE9E4DEE9E6E1E6E5E1F1F1EFC2C2C0
9D9D9DECECECE5E5E7E4E4E6E2E4E3E4E4E4E6E4E5E9E0E3ECDDE0EEDCDCFBE6E3BBA29B
4A311D402C07483E01C5C370D9E078DDE786EBF3B7F8FDDDFBFDF200FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEE6D7D7CF
E6E6DEFAF9F400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F2
F1E0D9D8C1B9BB9A93A1766F945F598A4D4887403C90413C97423F9D423F9D3B38A53F3D
AE4444B14543B64645BC4A4ABD494AC24B4DC74F50C84D4FCC5052CA4C4FCE4D51CF4C51
CE4C4ED14C4FD14C4DD04B4CCD4B4BC44441BB3E3CB13734A7342FA2322EB64944B95852
AE5D5A894D4C977170A58F9194888A928C8E918C90979296989296958F93988F949E959A
A1989D9B92979A91969B95979C9698969092958F939A9496958F91948E8E928E8D999594
ABA7A458545124201D312D2A16120F64605DF1F0ECEAE6E3E9E4E1EBE1E0F0E0E0F8E0E0
F8D8D9E1B9B9DCACA8CF9E97DDB1A8FDD5CDD5B0AAC5A49F674543B29391FFE2E2FBD9D7
F8CBC6E7B2AAD29C90CF9E8FE3BCADF5D9CBF6E4D8F0E6DCEAE6DBE7E4DDE8E7E2DEDFDA
DDDDDBE6E6E4E4E4E4E4E4E4E3E5E4E4E4E4E7E1E3E9DFE0EBDBDBF3E0DCF7E0D87B6454
432B113929008D8638E2E385D6DE79E6EF9CF1F6CDFBFDEF00FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAECE9E9D6D2CAB1ADA78681926963814F48874B438D443E923F3B
9C413EA13F3CA43E3AA63D3AAD413FB24443BC4C4BBF4D4DBE4C4CC45051C34C4EC95153
CA4F51C94D4FCF4E53CF4E53D14E54D04D52CE4D52CF5155CC4F53C44D4FC15457B95D5E
9A5351814F4EA587879D8B8B958B8C938D8F928C8E948E90948E90938D8F938D8F958F91
988F92948B8E948E90958F91948E90928E8D918B8D948E90918B8D918B8B8F8989A29D9A
948F8C3934312C2724322D2A181413A5A1A0F5F1F0E8E2E2EBE3E1EFE1E1F6E2E3F5DBDA
D5B3B2AF8382B7817F743D3AC59490C59895AC8482D2ACABA6807FE1BABBFFE1E2E5AFAF
A052509A413D91383087372C8B4D409F7162CAAD9DE9D8C8EBE2D1E6E3D4E9E7DBE8E8DE
E7E8E0E4E5DFE5E6E1E3E3E1E3E5E4E4E2E3E8DFE0EBDDDCEFDED7FEEADFC2AD9C432E13
3A2800594E10CFCA6CDBDC76DDE38BF1F7B9FAFCE400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF8F3F5E6E1DEC7C1C6A59EA97C77915A57
8645419046438B3E3896433D9B433F9D423DA44541A4423FA94341B04646B44846B94948
BE4A4BC44D4FCA4F54CB4E54CB4C53CB4C55CD4E57CD5058CA4E56C45158BC575BB15F61
824646956D6DA58D8D948686948B8C8F898B908A8C908A8C908A8C8F898B938D8D928C8C
958C8F91888B948B8E938D8F918B8B908C8B8E888A8C86868E8888908B888F8A87A6A19E
615C592B2623362E2C251D1B3B3535DFD9D9EFE9E9EBE1E0EFE1E1F4E2E2F8E2E4BCA09F
C19E9CECC0BFE7B4B3915E5DA173737D5354AD8687D3ABACDDAFB1FFD4D6F2B6B88B4142
A74949C35F5DC36961B2655B905648673E2C604530615339797258BDBCA0EFF1D9E8EBD6
E6EBD7E4E8D9E3E7D9E3E6DBE3E4DCE7E4DDEADFD9EDDCD2F3E2D0F7E6CC826F4F3A2900
3A2F00A49F4DE5E47ADCDE79E9EFA9F6FBD2FBFDEF00FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF3F2EFDBDA
D9BDBAB695909E756F8B5C54814B4184453C8A443C954641A04844A24540A6433EA83F3C
AC3E3DB64645B94649B84349BB444AC04851C34B55C24D56C04E56BE565DB55F62975354
805252A4868698888993898A92898C8E888A908A8C908A8C8F868991888B91888B948B8E
938A8D90878A92878B94898D928C8E8C86888C86868D8787908A8A8E8986A199978E8683
372F2D3129273B32331C1314756C6FF6EDEEEEE2E4F1DEE0F4DEE0FAE0E3F9DFE2DFC1C3
CBA9A8C29C9B9B7270865E5EC8A8A9E9CBCDFFDFE6DCB1B875373CDE8F92C1686A9C3E3E
CC6F6ABF6C6495574C885E4E9F8672A99D85A09B7D858561B2B48CD7DEB2C4CDA2C6D1A7
DBE7C1DFEAC8E3ECCFE6EBD4E4E7D2E7E5D0EBDECBEEDEC4FBEBC7C6B88B433300403600
797418D5D76AD8DF6FE5EC8FF1F5C3FAFDE8FBFCF400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FCEDE8E8D4CDCAADA5AB867E986B658A554F8C4F4A86413C8E403C984541
9C4241A04240A03C3CA63F40A63C40A93C41AB3E44AD4248B34C50AB51539B53547C4644
96736F9D8883938582938B899088868E89868E88888E88888F868791888B8F86898E8588
90878A91888B93888C8F8488948B8E8B85878D87878C86868C878496918EA29A98564E4C
2B2321372E2F32292A22191CBDB7B9F7ECF0F2E3E6F1DDDFA88B8FAE8F94E9CACFFDDDE0
EFCBCBD3B0AE967472EDCFCDFFEAEAFAE4E7FFE8EFBE939C7C333AB2565BA94245C35D5B
C77067924E439F7567E8D3C2AEA8928080647879577A7B518C8C5A8C8F5663682E5F682F
6E7B45869461B7C499C1CCA4CFD0AEE1DDBAEEE0BDF7E6BAE4D59A7C7028817722A7A23E
D3D25CDDE369DDE47AEAF3A4F8FCDBFBFCF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF4F3F7E5E3E7D2CFD5B9B6B79691A07974976763
8D56538847438D423D923F3B9A413D9E403EA34142A24243A048469146415F2420875C55
A0857C9A8A7D90867A8E867B8D847B8D867E8C857F8E86838C87848F89898D87878B8585
8C838690878A91868A8E83878E85868E858692898A8A8182908B88A5A09D706866302728
33282C352A2E1A1114595357E9E4E8EDE7EBF4E8ECF0DBE294767E95747BE9C5C9EAC3C6
BD9697D2AFAD7F615F927877F3DFE0F5E2E4FFE9EFD2A7B08B4249CA6B71C65D61C76562
B5685E8F5A4CE4C9B8867B696B6650918D728E8662786B3E65591F635816766F27797931
6B753067763566783E5966315F612F756D3C9B895799854894842FACA137D4CC50D5D24D
DDE156D4DD60E3EC91ECF4BBFBFFE800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF5F2F9E4E1
EFD2CEDCB7B1C89993AD7671A0635E96524F924B478D48437C3D3669342C785046AF9387
9887759388728C866C8B856B8D876F8C86708C87748A84748A867A8D897E89847E898480
8883808C84828D83848E84838D83818A807E8D847F948B86A49B967A736D362C2A372D2C
3A3031241B1E393033D0CACCECEAEBE6E1E5EBE0E6F0DFE7F6DFE7F5D7DFB49499806063
C6A8A8E5C9C8957D7D705C5DF0E0E1F3E0E4F9E0E6FFD5DFAB5F69AF5058CB6468C86A68
A35D55A6786BB19B8D564F3DDFDAC6D7D0B671613F644F20CAB576A692499C8C3FC2BB6D
93954A6C76316D7738686E306D692A6B601E6B5911695701B1A434DAD14ECDCB38DBDE47
D6DD4FE1EA77E6EDA7F7FDD9FCFEF100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFF5F3FBE6E3EBD2CED8B9B6BB9C998A6F68AF998EE7D7C8E9DECA
C4BFA19D9B7599976E9291638E8D5F8B8A5E87845B88866086876586866A85826F858273
8A867D837F768B827D8B807A8E81788F8176988A7DA89C8E82766A392C23392C243C312D
221A17423D3ABEBAB9F1F0EEE6E5E3E5E3E4E9E3E7EDE2E8FAEDF4B09FA5826F73BBA8AA
B7A7A8AB9D9DB8ACACE3D7D9F5E6EBF5E0E7D8B9C1E2AEBAFDAFBDB05260BC5661C06467
A15B59A77A749A837B645A4E847D6B867A6256422194794AEED390DEC77B9D8A3BB8AC60
E5DE9A7B7738666024776F307C6E257A6A15968722CCC04AD6CE45C8C731D6DA3FDAE04C
DDE665E5EF8FEFF5C7FAFEEDF9FCF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3F9F5ECF7F3E7F0EFDD
D8D8BEC1C2A0B8B892AFB086ACAD81A3A4789E9D7198996F8F946C84886583866B85846F
8584727F796B8B7F719585759A88729B876EAC987D88775B3E2E143D2D1445342031220F
38301DCDC6B4FAF4E4EBE8D9E7E5D9E9E6DDECE4E1EBE3E0F0E8E6D8D0CEE5DBDAF7EDEC
ECE7E4EAE6E5F1EBEBEEE8EAEEE3E7FAE9EFD0B2BC6B3D48A86171B46070BC626EBE6B73
A569698C6663AF9C96574E45BFB7AAD2C7B35C492BA1895DECD297ECD58FA5924DB8A966
B7AB717467307F6E3682712C72600CB1A038DFD156D4CD41CCC831CECF33DBE247D8E057
E4ED82DFE6A0F9FDE200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F9FAF2F7F9ECECEDDDE3E5D0D4D8C1C0C4A9B4B79AACAF90A6AD8C99A07FA2A88CA7AB92
797961736B56AA9A83D4BCA0CCB08BAC8F638368394E38063F2A004B36094E390C3C2A00
A99D6DFEF3C5F4EBC2F0E8C4F0E9CCEFE7D0EFE7D4EFE6D5EDE5D8EDE7DBEFE8E0EAE5DF
E9E6E1E5E4E0E8E4E1E7E3E0E9E3E3EEE3E7F9E6ECAB8B96804C599F5F6DB06C79AF727A
8C6264745A59E8DDDB999490928E85867E7151452F746443D4C196F1DFAD897948918354
7362379582578D78436B540EB3A13DE0D257D0C73AC8C52CCCCC30DCE147D7E051E2EB76
D7DF94ECF1C8FBFDEF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBFEF5FAFEF0F7F9EBEAEDDADDE2CCC7CFB8B6BEA7A6AB95
71705C827B68D3C3ACBCA78A967C57A28758B7A06AB39F649D8A4F8E7C3E82702E7D6C27
C9BD73E7DB93EADD99EFE1A4F3E3AFF2E4B5F4E5BAF5E7C0F6E9C6F3E8CAF2E6CCF0E5CF
EDE4D3ECE5D5ECE5D5EAE4D4ECE6DAECE3DAF3E5E2FBE6E5D2AEB295686D8053587E5559
715554AD9E9BF7EFEDECE8E5C9C6C1B2AEA3B8AFA0AEA38DBAAC8FCBBC9BA0926FDECEAC
E6D4B0ECD7AC887034B19B46E5D460CFC63BC9C62DC9CB2CD5DB3DD9E14ED8E363DEE888
D6DDAAFBFEE900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F7F1
E8E8E0E1DED5DDD5CAB4A89894886EAEA17FCEC396DBD29BDED793DCD68AD0CA76BFB85E
BCB253BEB250B9A949AB983AAD9742BEA759C9B266D5BF76E1CC89EED89CF3DDA4F5DEAC
F6E0B7F5E1BCF7E5BFF4E6C1F3E6C4F1E6C8F0E4CCF5E6D3FFE9DBF2DCCFDCC6BBD1BDB4
DED1C8F0E9E1EAE7E2E7E6E1E9E8E3ECE9E2F3ECE4F6EEE3BEB2A4948774D4C6ACCCBD9E
E3D1AD9A86519E8936E7D567CFC33BD0CB33C6C628D2D83AD6DF48D5E15BDFEA82C7D18A
EFF4D6FCFDF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFDF4FFFCEDF7F2DEEDEACBDEDCB3D5D49ED8D898D7D78FDCD98A
DAD480DFD67BDDCF6ED1BF5BC5AF4CBAA23EAD962EA58E269F8926A089299F862CAF9541
B89E54C3AC68C9B570DDCA88E8D89AEFDEA6F1DFAFF2E1B5F5E6BFF8E8C6F9EAC9F9ECCC
F7ECD0F3E9D0EDE5D0EDE5D2EDE4D3EFE6D5F0E8D5FCF1DDD8CBB87C6D56EEDFC2E4D4B0
AA986884712CE6D470D5C848CAC334C7C62DCBCF34D8E04CD1DD55DEEC7AB7C475CBD3A4
FCFFEE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FDFDF5FEFEF4FCFDEFFDFCEAF9F9E1EFF0D1EAEAC6
E0DFB3D9D8A0D0CB87D3CB78E0D470E7DA68E8DA5DEADC59E4D651E0CF4BD4C341CAB83C
BBAA38AA982AA39125A4912A9B87289F8731AB9240BCA257BFA864CBB675DAC582E7D291
EFDB9EF3DEA7F4DEADF6DFB3F6DFB6F8E2B9F8E3B8FCE7BAF4DFB2E3D1A1FCECBBDFCE96
796421CBB760D8C956CAC23BC5C233C9CB39D8DF51D3DE5BDCED7BC3D37B9FA977F2F7E0
FBFCF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4
FCFFEEFCFFE4F1EFC6C1BF84C1BC6ACEC75FD1C851D8D04BD5CC3FDFD444E3D745EBDF4F
EBDF55ECE058ECDE59E8D95AE4D159DAC656CFB850C2AC49A9963A9E8D359F8E369D8B35
9C8736B29C50AB934DB29957C0A669C5AB6ECFB674D4BD7ADCC784E2CF8DE4D5947F702B
968638DDD070C4BD4BBFBE40CCCF4ED2DB5AD1DC62DAEA7FD1E38D829254CDD6B9FCFFF4
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FCFEF3FFFFF2EDEDD1B3B181B2AF6AC9C56CD2CE63C9C349C9C13CC8BF34CBC334
D3CB3AD9D140DDD244DED548DCD24CDFD655E1D95DE3DC68E3DC71DED973DDD777D8D274
D2C96ECFC46AC5B75FB8A853B3A250AA9844A3913B9886309787329C8D3C988C408F8639
DBD483C5C46AB3B756C6CE69CDD973CADA78C2D57BACC1746E824797A581F7FEEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00E7E6D19FA0789D9C63B9B76DCCC86DD5D26BD3D05DCCCA4F
CECB4ACCC946CAC746CDC94CC8C34BC0BF4BC5C458C0C05CBDC163C0C36CC4C577C1C276
C8C578CDCA7DD6CE83D9D186DED58ADFD689DED286DDD185D7CE83D6CE86D3CB8AD8D494
BFBE7D8487427B823E8B965288975491A16280915A697A4D798869E2EBD800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FDFDF5F5F6E8DFDFC7CFD0AEC1C296C1C289BEC17CC0C573
C5CA70C6CB6DC4C76EC9CB78CCCD81CCCD89D1D298CBCF9CC9CC9FD8DDB5E2E3C1DFE0BE
DEE0BBE4E6C1E9E6C3ECEAC4F0ECC7F1EDC7F0ECC6F3EFCAF3EFCAF2EFCCF0EDCEECEBCD
DEDFC0CACDAEC8CDAFCDD3B7D3D9BFD9E1C9E1E9D4EBF2E2F5FBF100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAFDECF1F5DCE3E7C4CCD2A6
AFB682B5BD84CFD3A0E6E9BCEFF1CAF2F6D5F7FBE2FBFEE9FAFEEFFBFEF300FF0000FF00
00FF00FDFFF2FDFFF2FEFEF2FDFEF0FDFEF0FDFDF1FDFDF1FDFDF1FDFDF1FDFDF3FDFDF3
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4FCFEF1
FAFDECF9FCEBFCFDEDFDFEF0FCFEF1FDFFF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.290056 0.97619 0.541732 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 221.938},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000gB000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`003_oooon/003o01[ooooo[000o`0@ooooo`003_oo
oolZ003o00030=WJeP3Ad/d0k>cZ07l00?l06_oooolZ003o00<0X23`O`00o`0@ooooo`003_oooolV
003o000;0?Sgl`3LfmL0/[6_07imN`0m?3P0=C@`05=BCP1gMW80YJJQ0<c<bP3YjNL0N`00o`0Joooo
obH00?l02`2P8?1k003o013ooooo000>ooooob@00?l000l0g=SE09bIU01VHe`0?c`e02LT7`0]:RD0
;2PU038_:P0_;2L0:BHQ02PW8P0^;bL0AdQ208^<QP3]k^T0N@00o`0Jooooob@00?l03`2P8?1i003o
013ooooo000>ooooob800?l00180m_Ob0:j]Z@13@3/08QdG024N5@0`;B@0?3La04<n>P18@Sh0DT]5
05E>B01DCdT0CDY103Ld:`0R8QP06a/C05iOF@3@dLah003o01[ooooo8P00o`0B0:0Pl7P00?l04?oo
ool000kooooo8@00o`00503PhM`0OGag03@a:P0M6180:2@K03Da:011?C@0@3Tc03Ta;P10=c@0Achi
04U0>`1=A3d0D4To04U2>013?cH0=C8Y01dM5@0n?CT0[JbZM`00o`0Jooooob400?l0502P8?1g003o
013ooooo000>ooooob000?l001H0hn?Q05mNF@0X9Ah09B4H01lK4P0g<bX0@3`c03/g;P0g<2X0=2`Y
040f=013>3@0A3Tc03ld;P0o=Rd0B3lf04Y3>@1;Ac`0?3T`02PU800Z:BD0YJFSMP00o`0Jooooob00
0?l05P2P8?1f003o013ooooo000>oooooal00?l001P0m?Cb07]jM@0U9Ad0;2TP02@P5`0b:b40ASle
03/d:P17@3H0?C@]03@[9P0f;bT0?3<^03T`:@0k<R/0BT4h04m7?012>Rl0@clc04Y8?00g=2d07ahI
03`m>03Fe]Ae003o01[ooooo7`00o`0H0:0Pl7D00?l04?ooool000kooooo5`00o`000`20nWX0P?]j
083jN002083jN@0L083kN@20o7X0I]mL071ZI00T7QP0:2<M030Z900X8AX0<BLQ04Pn>00h;RP0=bdU
04Hl=P0l<Rd0=R`V044g<@0g;BL0@CL^0558?`1<@CP0?C<Z03df:`18@SP0C4Po02XY900Q81`0B4Q6
0=3?cg@00?l06_oooolG003o00P0D91h6@2P8?1d003o013ooooo000>ooooo`/00?l002h0onkX0>SA
b`3QbLD0f<?00=C2`03E`l40flW70=:m_03E^k`0g[jo0=6ZZ`30U9D0c9ZI0<^HU02oRX@0]hEn0:mn
M`2PMFh0TW1W0615?00W5@/09APB034X8`0^9280:R0N02TN700h;B/0@CHb02lT800g;2P0>Rl[03hc
;@1AAT00@cPb03lf;@1:@3L0=R`S030V7@0g;RD0Ad0h04@o>@0[:2<09R8O01/G5P18@T80imkO@@00
o`00303]kNd0[jn_06YZJ01UIF<0IFIQ06EUH`1WJ6<0JV]V08j>S02k^kT0dm?A0>SXiRH00?l06_oo
ool;003o02h0X23`@@00o`0<0:0Pl2H00?l04?ooool000kooooo2@00o`00=`3on?D0o=G>0;n9O`29
CD80Y71U0:UlMP22GEL0Pf9M0:B1O`2RNWP0Y7Ad0;=iN02UGEh0Schm0:=:AP2VAd40Xd8h0:=5>@2E
?C40QSP[07Xl;`1O<bH0<aD;02PE3P0e9b@0<bTW02hT8P0Z81h0;28P03@Z:00g;B/0>2dY03db;P0o
=Rl0DdY104m6?@17@3H0?SL]030W800X7aP0@CPa04Q1>`0g;b`0;BDS02DL7@0W6a/09A8D08QdL`3L
b/H0h=7:0>KId@3]hmX0n>oV0?ofk`3ooOD0>000o`004P3^k^`0[:j[05UIE`0U9B<06QTG01LF4P0I
61<06aXF01/K5@0?40X06Q/F02<T7`0/;RT0AdU406AVH`27RHH0[[2]0>;ThB800?l06_ooool9003o
03L0X23`>000o`0B0:0Pl2800?l04?ooool000kooooo2000o`00AP20mG@0iJjY0;9YH02LBC/0T3d]
0=2;O02mPgP0V6MP08iSG@2DIf80VVMT0:U/J`33NGP0b6i]0:U1?P2kBT@0_TLo0<M<@`35CCl0_D`n
0:<o;`2[F4P0PD<d048H300/3`T0=24M03LY9P0c:2H0<BHT02hT8P0[8Al0;bDS03P]:@0j;b/0?C@^
048i<P10>C40?c/b03Te;00g<2X0?cPb03P`;@0f;R/0<BTW02PN7@0]7al0=20R02/>40108Ah0DC<Y
05Tl;P1]DT40JE@m07AOBP1kJED0P6eL08UfI@2AOVd0XHak0:jHRP2jY9H0b;:U0=Fm/`3Ka;`0h<_6
0>KCc`3/f]H0lN;O0?CYi@1mn7LX003o00070?;bl02_[jd0EeME01hP6`0E5Q407ahJ020O6`0201`K
5P0<02TV8@0S8a/07AhF01dN600H6A<05QLA01HI4P0E5a805QPE01LI5P1>D4d0e]KF8@00o`0Joooo
o`P00?l000<0D91h0:0Pl02P8?00<@2P8?000`3@D7P0oh000?n000030:0Pl0030?n0002P8?00X23`
00P0X23`00<0D91h003o0000o`009P00o`0E0:0Pl2400?l04?ooool000kooooo1`00o`00:P3om_D0
j:VT0;I?AP2jBSh0/4De09`m:`3RUHD0aXQk0;B0M@2GJ600Xg=_0;9lNP2]KF/0bWaj0=anO02dB4D0
`di70<97@03ADDT0ce550<Y@@`2^?S00_Ue=09I:?01@5PX0=Ph603TM6@0g8b80=2@T03X/:`0_9280
;b@P030U8@0d9R<0<bPT03L^:@0h<B/0>S<]03hi<`0f<B/0=Rh[03L_;080:b<Q02X0:b4R030R8P0e
8B<0>1/M038:2`1E9B40JST[06/k9@1jCC00GcPB05Pe2`1K=@h0FcD@05D_2P1I<`h0G3@@06Tn701L
;A40J3@N06L^6`1S:QT0IblR06hj;`1cAch0Lda507IECP1nHE`0SFm]09EfL`2UQX<0[i2=0;VJU@34
Yj<0ck>_0=W0_03Mb<D0h/o;0>OEd@3]g]/0lnCQ0?W[jP3nlo4H003o000G0<K6a01UIV408b@O01LH
4`0E5Q406AXE020O6`0Q81/0;b`W030]9P0d;bT0=c@]03Ti;`0c<b/09RLO01`M5@0H6A405APA01<E
400B5a<041DA04Y<B`3Be=<08000o`0Jooooo`L00?l0=02P8?0:0?n001P0X23`6000o`0G0:0Pl200
0?l04?ooool000kooooo1P00o`00803omO@0fjn/0;EDB`3;Ac/0d4/l0;m6=@2X?b`0j9F30<^8N02i
Og<0ZgE[0:mfK`2ZKFP0WEIB0;IQGP3KN7<0_di80<U>A`3<BdD0e4m70=5<@`3@CD<0_40d0<9A@`2k
Fdd0KAlB04<7000o4Pd0?adK03XP7`0g8b80=B<Q0P0j:bP0A`0m;R/0>bdZ038W9@0^9280;bLT03<[
:00/9240:R8P02TQ7`0Y8240:b4R02dO7`0c7b40?R4S03PA4P0i1PD0IBXT07do<01l@2H0TE/g07U<
7P1eBaT0OU8Q081D8`1fBQT0M4HE07E55`1oBQh0Kc<>07Le5@25>Al0Qc/T07he901j=RT0L3L/05XZ
801D;2@0BbDN04XR801@9b<0E2/W05@[9@1G;RP0Db`U04lZ8P1<:b@0ESLb05Tl=P1PACh0J4a906mF
DP1dG5P0OFEQ08I^JP2HPGd0ZIB?0;FPW@31[:T0bKBa0=O2_`3NbLH0iM3=0>[Gd`3`gMT0m^OR0?_^
j03nmNh0oogb0?oom03ooo<0ooke00@00?l001X0h^;P08R8QP0d=C0071dH01XK5P0L7AP06AXE01HG
4P0Z:B@0>CHa040k=@0h<bd0<RdW03<_:@0h=B`0<c0W034a9`0d=2X0;RlW028S7@0C5Pl05aTD01HH
5@0H6QT0D59A0=KFeQl00?l06_ooool6003o03D0X23`2`3oP00Y0:0Pl0@00?l06P2P8?0O003o013o
oooo000>ooooo`H00?l00540o=??0:5FD037BSl0e4Dg0=96=@36AcH0[3dZ0>J>NP37O6T0^GAU0:MS
EP2@BT00YU]E09e8@`30HE/0j7]d0<58@03>CDL0dDY40=U?B03HCDH0eD]10<]1=P39ACT0eEe?0:i4
=P1c6A00E0/404TB3@1571P0?1dJ03PO6`0j9B00?2TU048`;P10<Bh0?34_03@Y9`0]8b40=2XY03<Y
:00a9bP0<bTZ030T9P0a8b<0=1hP03XL7P1471d0?P/:04P81P1e<BP0RTHc08e=<P2[Me80SF8f08AN
;@2:IC40V70m099Z=`2EK3P0UFLf09aY>P2GG300VeL`08dn7@2??b@0TTL`08a:>P1W<BL0FRlX08YX
GP21GeL0PeeJ089IE@1L<2d0I3Tc06Dm=@1B;2<0E2lV05Le;01I>2l00P1@;bH0:@1=:RH0C2TU04l/
:0189Al0CRTS04lY8`1C;2D0D2TR058Y8`1F:B@0H2dY06P^:P1_=2h0Mchg07e9?P20D4@0PU]:07mS
CP1oJe00SH9R09B>K02MV7X0ZZVC0;^k[`32`k/0Z:VS04e>B@0M7QT071dG024R700M71P07QdI01lN
6P0V9B40@d0k034^:@0/9b<0<2/W02PS7`0]:280<B`V0080:2<M00X0<2dV03<c:`0a<2/08b@N01LH
4`0E5Q4071`J01TI5`1@D500h>3P7P00o`0Jooooo`H00?l0=02P8?0=0?n002<0X23`1P3oP00N0:0P
l1h00?l04?ooool000kooooo1@00o`00M`3om_<0g:2H0:M5>P3CAcX0ed4b0=E4<`37@S40/CTX0>9k
J03[T7d0c7AV0;MOD`2eFe80aFAM0=5ZH`3`PGX0gfAM0<Y7?`3EC4@0f4]40=Y;@`3NCdL0gDe40=M4
>P3<?340gE=60=9BA@2jAC/0S2LM05l?1P1C4`X0BaH@04HI501171H0@1lJ03/M6`0k8B00>b@S03LS
8P0f8R40>RPX03HT900`71d0=b4S03TO8P0l71l0?QHG04LE5P1=3a00CP@306DB302@?340UdHc09iF
?@2^MU<0RE/b07QB9@1[AAP0LT`M07A<6`29Gbd0QUX[08iK;028Cb80WUdc0:AH=02GBR`0UDde08Y;
>P1E8aX0PeeD0:f<P`2UQ7h0^9:?09M^K01I<2h0HcXf050Y8P20Fe80V7I/09MeJ`2AKfD0SFQO08aU
GP2:HE/0QeaF08IME`1mE4h0Mdm70718@01V>c80ICT`05/Z8`1Y;b/0JbLT07`^:P20;BL0OBXR07/]
801b:aT0J2hF058W1@1L?aD0IeHR061E7`1JDR<0G5Pe05mNB@0m?S00414901DF400N7aT0824K01lP
6P0P7a/07ahJ01XI5@0j>CD0>SLb0080:BHQ01009b@O02DP700a;2L0:bHP02`T8@0[9R80;2LS02HS
700[:2<0=C@_02<T7`0I6QD071`J01dM6`0F5QH0RHV97P00o`0Jooooo`D00?l0=P2P8?0=0?n00280
X23`1P3oP00N0:0Pl1h00?l04?ooool000kooooo1@00o`00RP3oin<0]fQQ0;i<@@3EACL0ecla0=0m
;@3DAcH0`Sd/0=eTD`3mRWP0lh5f0>QcJP3VKFD0gF1J0=QIDP3HDd`0cD@l0==6?@3HBT00edLn0=e9
@@3QC4D0gDTo0=Y3>P3G@3D0fDDi0=m@@P3NE4L0ce530;51<`299aX0Ja@:05L=101C4P`0DALC04PE
4P196AL0AahM03XC500l61X0?QXJ03`H60116AX0@ADF04LE601;4180D`d?05P71P1V1`D0NQ4=09lb
:`2]@cH0ZT/g09i<=02bKe80SUTg08QJ>01dB2D0GS@>06m56`1mDRL0KD0G07Y9801d?Q80VE/b0:QR
@02DCC40UE<m07]1<`1/?CD0/8^30;6@R@2bTH`0_YNH079:B`1K=3D0DBh/06M6@@2cTX/0[8j40:j=
Q02ZR7l0]Xf70;F8P`2WMW80YgIa0:]nN02YPGT0Xh5h09enL`2INFh0UWAZ09M/I@2WLVh0NcLd07/W
9@2F>C@0Uc@^09@d9P29=1l0P3TI06`h2@28I2X0QF`Y07QW8@1fJb/0OGM708j=K`1UI58020P001HF
3P0S8Qd092<N024P6`0W91l081dH01XG4P13@3/0:bXU020O6P0V9B007QdH02<N6010>S@09B0J02dX
900[9R80:RDQ02<N6P0Z9B40=C8]03`k=P0K71L05QHD01dM6`0H6QL0@48o0>CTi1d00?l06_ooool5
003o03H0X23`303oP00R0:0Pl0P0oh007P2P8?0M003o013ooooo000>ooooo`D00?l008X0k<>o0:a?
A`38BSh0f4Hg0=U1<`3D?Rl0gT/k0=Q;>P3<A3@0gUU:0=QBA`3ID4P0fTm80=A7?P3DACd0dT8i0=I3
>`3HA3X0eT8h0=U5>`3KA3/0gdHn0=Y2=`3J@CT0f40e0=a2=P3PB3X0jE=50>AGAP3HDd@0be100:lm
<P2?:Ad0LQ@<064<1`1K30P0E`d:05PB4@1>30d0D10A04d=3P1B4140DPh?05882@1I2@`0G`H806`8
2P224Q40WbDR0;@e;P35AC`0_THh0;17=02UBSD0^6aD0:QYC`2UKE@0Uf5708=@<`2;FSX0R5Lf081>
;@2<ES@0Od@R0;EfE@2cLU@0TE4h08iC@@1S;b80SfAM0<RSW@2mVY@0aj:P0:^2QP1R>Cd0ISm204d[
:P2INWL0]iRC0;6CR`2dTH/0_YF?0<NFTP2=EU<0QDY608I<B021D4T0Ne1907eKDP2URWl0Y8Un0:B6
O02/QGh0_HN5070/:`1m9bH0WS`i09Xc;02M>BX0U3XR08Pl601i?`d0Vg8b08ea9`21L280OW4[0928
D`2NVgX0NGQT00h>0P0G5`l09RDP02DT7`0R7aX09b@O02<P6`0P7AP0@3dh03Dd;`0N7AP0824K01TH
4`0S7QP0Ad8l02@O6@0Z9B409R4M02@O6`0V8Ad09B0L02`Y9011@3/08b@N01TJ5@0K6aT07b4N020R
7`2_[jlM003o01[ooooo1@00o`0g0:0Pl0/0oh008P2P8?090?n001d0X23`7@00o`0@ooooo`003_oo
ool4003o000A0?odlP36Sh`0[TM00<i9@03IAcT0fT8e0=]3=@3NB3T0f4@f0=Y8>`3MBch0gT`o0=m<
@P3IAC/0fTHl0=U5>`3LACX00P3I@CH0GP3H@3D0fD4f0=Y2=`3J@3H0f3hb0=To=@3L@SH0fClc0>98
?03[DdH0iE530>1A@@3NDT<0gUQ<0=QHC@3<D4H0]Chf0:<b;02>8A`0OaDB07P@3`1d30/0L0X807@<
2`1m4a<0PADE08dJ7@2N9RL0[Rh]0<Q1?P3BA400f4]20<m6?038BS`0]dPg0:a;>P35LV00YUm?0:AQ
D@2KFDT0Wei<0:AVD@2aLeh0Wei:0:UXE02SHD/0/G1L0:a]F`2IGTh0Md<f060a:@2FKFL0[hZ40:n9
QP30V9X0REaS06Ll@`1P=c/0IT920<6OW@31X9/0`9fG0<:IU@3MZjX0/WEd07La;`2DBTL0Ue9=08eD
C@1X>C40Jd@m0:jAR@2[SXH0[Xf60<>JU02OJFL0IR8Q08hj>02L?cX0W3/b09e0;`2HA2X0QShH08IA
7@2QNC/0SW</08Yh<020MC<0VI5N0:RSP`29QW<05Q@801LD3@0Y9R4202DR7@0H02HR7`0T8A`08B0K
03<b;@0n?CT08B0L01`K5`0B4@`09b@M04e9@@0O6Q@08AhG02@Q700V8ah08QlJ01hK500]:R<0ADDm
028S7@0R8ah07AdK01/M6P0G6AH0J6QV7@00o`0Jooooo`@00?l0I@2P8?090?n001d0X23`7@00o`0@
ooooo`003_ooool4003o000=0?kKe`2TGeP0^TU10=98?P3KAcT0gdDi0=i4>03K@cD0h4Pk0>59?03Q
BCh0hTPl0=i6>@020=i6>`1m0=m7>P3MACP0gD<g0=To<`3K@CD0gdDi0=]1=`3K@CD0fClc0=e3=`3I
?c<0g4<e0>58>P3XD480jE530>QB@`3^Fd/0j5I90>UICP3YGE00kVAI0>YTF@3THEL0fUM@0<m>B03<
BdH0`T8o0;hn>`34A4<0fEMG0=MBD`3JD500hE5@0>=?B`3WCdX0gTU20=M9?`39AcT0]dHf0:a;>P38
MFD0[FIG09]IB`25@cD0R4Hh09=A@`2UHeD0UE=509MEA`2EETL0V5Y=08Q@@`2aOg@0FRhU07iGD02h
Thd0[HZ60;:<R`2cRH`0JCa30716BP1@:B`0QV9R0:^9Q`2XQh80/8^50;^;R`3@UYD0STI708<c<P2N
CDX0WE9=095DC`1O;RL0TFYS0;jOU`2jWID0_ijG0<jWXP1iATD0LC@c09=7A`2IB4@0VTPm09E8=P2?
Abl0P4@R095R=02XQDd0Uge008mm?`2<OdP0WiM[0:bWR@2IUX<07adA01<@2@0X9B009b@O02HS7P0W
8b008B0L02DT7`0S8Qd0<c8^03Th=P0I61@02`X5034^9`1;Acl07a/B01dJ4`0Q7QL08QlJ01hK5P0M
6Q<0>SXb03ho=`0Q8Q`08B8M01/K6@0I6AL04a<A030`;P2j^[P07000o`0Jooooo`@00?l0I@2P8?09
0?n001h0X23`7000o`0@ooooo`003_ooool3003o000R0?ogm@3OZZ@0WdPo0<A;@03FBSd0fdLh0=m5
>@3SBCd0jE540>Q@@`3SBCd0g48f0>96>P3NA3P0h4Hj0>98?03NA3P0hdTm0>A8?03RB3`0h4Li0=m7
>@3PASX0hDLk0=m5>@3OASP0gTDg0>17=`3QB3P0iTdm0>I??P3[ED@0kEM60?5NCP80kE]<04l0kUa=
0>]LCP3^H580kF1C0>iQE`3cIUd0k65J0=iEC`3UGU/0mVi^0?5WI`3UEUP0jeMG0>]CD03UCDP0h4]4
0=A4>@3:AST0]dHf0:]<>P2^HDl0WV1>09aUD@2JHdl0WfMF09EMCP2IHE@0V61C09]UF@2EHE@0SUiB
07mCBP2VOWH0Hd0j0:V8P`31Wid0^iVG0<JPW`2cRX`0HcTm068k?01F=3<0]9FB0;JGU02gUY40^92>
0<fGU`2kMWT0ORd/09]3@P2OBTL0Ve1;07i3?@1R<b/0ZhIn0;2AR02dUXh0_YfH0:R2O`1]?cl0QeAC
091FE02AEU00UUaA099JB`2?G4T0PeLl09IbD02MP5P0U7eA095nD`2?PUP0XiYg09RBNP2f/j80@Clc
00`;1P0S8Qh0:2LS008092<O01/08R4M02DT800O81/08R8P03<d;`0d<bh092@L02l/9@0i=Rh08QlF
01hK4P0G50/06ATA020P600b<B`0>c`f02LX8P0O81X081lK024P700L6aL06QTE01LF4P0/;BP0QHF3
0:BVX`3Nh=d06@00o`0Jooooo`<00?l0IP2P8?090?n00240X23`6@00o`0@ooooo`003_ooool3003o
000Q0?o`k02iMVh0ZTDk0<i@A03DASP0fdHh0>Q@@`3`F4/0jU950>A<?`3K@cH0gTHi0>18>`3QBC`0
hT`n0=i8>P3SBd00hDTl0>18?@3SBch0gdTk0>5;?@3RBSl0hDTn0>59?03QBC/0gdPg0>=<>@3QC3P0
hTlk0=i>=P3NDCH0j5a10080kV9905/0k6170>YNA@3^HT/0jEi70>ePB`3[GT`0k5m>0>]LCP3YFdl0
jeiE0?U[I`3jJfL0jeYG0>eHE03[Ddh0idi80=e6?`3D@CL0bdDi0;e:>02_CS/0RS`V08a?>02;ECd0
Pdlg08YH?`2>G4D0QeM108EF@P2:GDX0SfID08]VE024He@0QfML06a?A`2bUI40_j2M0<2NW03=YZL0
VG1d06e6B@1>;2/0RFYW0<JYY@2lWIX0_I^I0<^OWP3UZJ/0Uda@08<[:P2VBdX0XD]:09]ACP1M9R40
QU]D0;fHT02eU8d0^9FA0<bTXP1lDU<0IcLg089@C`1U<Rl0L3di06Ph;P1eAcX0JCl_068l:@1bD3L0
FcdQ06Q=;`1H@B80NFI808=fFP2DS7L0^[FR09VGRP0L71@05QD@028Q7@0U92009bHR024P700R8Ad0
7A`H028Q7`0X9b<0:2LR03<c:`0j=c80>cPa0080<BhU01<09bLM03<c:`0h=c80>S/e02HW8@0R8ah0
7b0K028Q7@0V9B<07A`J020O6`0G5Q@04a<A05mOG@1QHf00NGYe0:>TW`39b/D0inOU01H00?l06_oo
ool3003o03X0X23`103oP00Y0:0Pl0P0oh00902P8?0F003o013ooooo000>ooooo`<00?l001@0k/g8
0:1BB02oD4D0dDe10=U:?03PBcd0jeE70>eGB@3UCd40gDTk0=i:?03QCd00fd`n0=Y;?@3MCT00g4do
0>5>A03SDD@0gT]10=i<?`80h4i106P0h4a20>5:@@3MAS/0h4Xl0>1:>@3OCST0h5@k0=A=;`3=CBX0
ce4[0=5F;@3LHCP0hFDo0>Q/AP3TJ4@0gf=10>1T@P3SHd<0ifA60>iVC03/HDX0k5m;0>iOC`3bHeD0
nVMM0>UFC03XDDX0ie190>5:@@3MASd0eT<k0<e5>@37CCh0[4Db08Xd7@2^Id/0ZFa=08aD<`2EH3h0
S5Xi085C<@21ES@0QF4o07mN?@1WCB`0KeHh079J@P1I?c00WX9g0<>RW@34XIl0fK:c085JG@1S?d<0
CRh_0;JHUP32Y:80_YnL0<:LV`3HYZL0d8j@07`/;`2E>CX0Zde=0:9AD022?S/0FbPT0:n6PP2nViL0
^INC0<VPWP31TI40G2PZ07Hk?@2ZL6h0S59>09MPF`2NK6D0V6UQ08iRE`26G500SFIG07mJB02DLEd0
ITHa08AXD`2<MV00Z9b60;N`W@3=b[T0QH=g01`L500E5Q007b0K02TX900U92009B4N02DR7@0Q7AX0
7A`G01lN6P0V9B00;2/W030_:P80<S8Z00L0=3@/03@c;P0[;2H09RLR024R7@0O7ad06QXH00809R@U
00h06a/K020P7P0E5AD04a<A06i^K01_L6/0LG9[07MgK`1eMf`0OWmg09VLT`2l_KL0hN;L0?GflA80
0?l06_ooool3003o03T0X23`00<0d51h0?n0003oP0002@3oP00T0:0Pl0030?n0002P8?00oh0000@0
oh009`2P8?0B003o013ooooo000>ooooo`800?l009/0ooOe0<6DS`2K@cT0b4m40=59?@3GB3X0ie94
0>mIBP3XDT@0hTi00>IDA@3PDD40g5110=E<?03QFD/0jf5D0>QLC`3[GE40kEmC0>QJCP3TETX0iUQ<
0>EGB`3UED`0i5A90>=@AP3VE4L0ge0o0>AIA03HECT0gV=20>McC03EIST0fFdn0=EY>P3HK3h0hWI8
0>AgC03PLdP0f6]00>9`A@3QJd<0ife80>MVAP3XHTD0geLm0>AI@P3RED40gTln0>5?@03OBcl0hda1
0=e6?@3LB3h0dTDk0<a<?`30C3d0[DPd0<I_E02lL500[VE40:]YAP2KGc/0XF]509QX@P2@JD80SFe7
07mU@023K4`0P6]@06U@?02DMV/0bZNS0<bUYP3G[k00LDU>050]<@1jG5`0c:j/0;nQW`35Xj80bZ:R
0>2^[`2VI6P0MBHY0:E<CP2VD540WeED064U9020De00bjFR0;VGU@30VYP0fJVY09aQI@1V92H0STQ8
0<9kN@2bKfT0^gYd0:]`JP2UK6D0XV]T0;F0N02mR800/Gmd0:mmLP2LKUl0ZH9a09]nJ`2bXHd0]ZjI
0=7>^`3Rh=<0IVIN01@E400E5A<07A`J02HU8`0/:2D0;BXU02HS7P0O71L07A`H028Q7@0V9B4092<O
02@U7`0U9Ad08b<K01lP6P0Q8Qd09BDS024Q7`0M7A/06ATG01lM800Q7b807AdO02HV:00B4Q@07alQ
08N7Q`1jNWP0NGQa08B4N01fMVX0M7IY07MiKP1bM6T0MgQ`092AR@2d]Jl0emSC0>k^k00?003o01[o
oooo0P00o`0P0:0Pl0D0oh000P2P8?000`3oP000X23`0:0Pl00A0:0Pl0/0oh009`2P8?040?n002X0
X23`3`00o`0@ooooo`003_ooool2003o001Y0?cPg@2LHe`0Y48g0<e?@@3BB3/0fTPi0>aEA03[ED@0
iU110>UFAP3VEdL0hUI50>UTD`3jN6X0o7e^0?ahJ`3`J5X0kVAG0?9VE`3dJ5/0lfMJ0?E[H03bJ5d0
lfIL0?5TFP3^HEL0kV9E0>UPD03UH4d0dUHn0>5`DP3iSVX0fWE;0?BBI@3cTF@0kHaO0?6BI03/T5l0
mIUX0?>EHP3YRUL0iH5?0=ieAP3UMT/0iG5:0=EM>03HG3X0dU<b0=IC=`3GC3D0hU500>5;?@3SC440
h4a20=Q8?`3EBd40eUA70=YOD03AHDd0c6I=0<YXC@37K540bgYM0<=lGP2[KTl0[GYK0:V2H`27J4/0
WX=X09QnI`23IUH0Wgmd0<fWY03N][L0^i6E06U0AP1B;S80[hn@0<b^[035YjD0ajRU0=J_/03DXjH0
Nci308Y3A`2QEET0X5QK08U=C@1F9R@0[HN40<^YY`2oWI/0binP0=RMX@1k<ST0QcDi0:==C038L6`0
/5eE0;e_I@2UFe80VU5:09aFCP2hLVX0aX1h0080XUiE0100VE]@091KB`2HLV00_ZVF0;V^VP3;a[<0
lo7T0:j^YP0a<Bl0ADE702PV:@0G5AP081lM038^:`0c;b`0;BTV0P0W8b001`0T81d08b0L01lN6@0T
9Ad08b@L01/L5P0M7QT00P0R8R0201hN700F01lM800R82<07alQ01lP900=3Q<0FeaQ0::QYP1lO7`0
P81h08Z:OP21PW@0PhAf0822M@1nP7<0NWa_07EgJP1aLfP0JfeR08J7O`2RXi/0alS20>GVh@`00?l0
6_ooool2003o0200X23`2`3oP00D0:0Pl0L0oh009`2P8?00103@D7P0oh000?n0003oP00]0:0Pl0`0
0?l04?ooool000kooooo0P00o`00PP3O^K@0SDLn0;M;@03BCT40fDXl0>1<?03`FDP0j5520>E??`3^
FDX0ieI60>IHA`3`IeH0m6mO0>aXF@3aJed0jfEE0>]SD`3/He<0lVIH0?9VF@3`I5X0mFUN0?AVFP3d
J5`0lfMJ0?5VF03aIeT0lFQH0?1^F@3[KeT0lWYP0>YeE`3]NeX0m89Q0?62G`3eRFD0l8MQ0?F<IP3e
SVH0lXmR0?F@H`3/Q5P0mhQP0>ekD`3YLdh0m7aI0>Y`D@3nPV@0kfQA0=Q:=`3SD440hD]00>1<@P3Q
CD<0g4]10>5BB03ODTL0h5M80=UF@`3HFD@0e5e80<mSCP3:K5L0_W1J0:]ZE`1mB3P0ZWma0<nYW@38
YI/0_YVD0<2HUP3M/kL0h[>j08IDGP1_@TX0RVAW0=Nf]`3@/[00bZn[0<fb[P3G]kH0`ijN06i3A@1d
ATL0OTe>07I:B@1T?C`0QVER0<^_[037ZZL0b:FU0=n[/02ZGfT0PbT_0:]8C02_BdP0YdDn0:I;@P2Y
DDT0[UYC0:ACB`2[FUD0XE5<0;1QFP2VEe00ZeaE0:5FC@2NG4h0TV=B0<R/V`2l[I/0`kb/0=oJc`3/
j^D0GUaN02l]<`1<BE80FEIN04m=D@1?CDh0>3Hg02LT900/:BT0<Rl_01lJ6`0Y9R@09RDR02<T800T
9B8201dN7P0P02DV:00W9bT07QlQ01dM8@0S8BP071XR024R:P0];SP06ATS07EeOP2^[K<0QhN708R8
P02=SH40SY2208b=PP25R7`0MWU^08B6N`26Qg`0Q8Ek07UjK`22PgT0PH9g07UjK`1nP7H0RH^209BE
S`2WZ:80RLZ706WYJ01hn7L6003o01[ooooo0P00o`0T0:0Pl0L0d51h602P8?020=1@N1P0X23`00<0
d51h0:0Pl02P8?003`2P8?020?n00300X23`00<0N5Rd052@N01@T7P01P00o`0@ooooo`003_ooool0
Z000o`00ooWc0=6UW02FB3`0`5140=9<@03KC3h0ie530>iHB03UCCl0je=50>]EAP3]EdP0k5U90?=Q
DP3XFdX0k61?0>iUE@3WGdl0hUY:0=YBA03QFD/0hEM:0>5GC03YGE00k5iA0>mQD`3^HU<0l6AE0>iR
D`3aIEH0l6AE0?5UEP3cIeH0kVEB0?1YE@3_IU<0kfQD0>aXD`3YIe40ifI@0>AXD03RK4`0k7EE0>]b
D`3ZKe00kg9F0>m_E03[Je80j6YC0>a[E@3]IU<0i5]90>UKC@3QDDH0iEE:0>9BA`3OCd@0hE560=m=
@03RCd40hDm00>9CA@3ID400eUM80<eLC039I5P0WdPo0915@03VYJ<0jZj^0>FZ[P3X[K<0k[>i0?jo
b035Phd0Oc]607i1B@3JYj`0kL720>6i^@3R_;/0g[Zj0=bh^03I]KD0cZZZ0<j/Z`38YZD0`J:P0<V[
Z@3B];80dkFc0=Bb/`3I[k<0jjNb08HY=02dAdd0_Ta<0;mBC@34G5<0aF9L0<]/IP32If80ZU5;0;eU
H@2cGUT0_VUT0;UTG@3BOW@0/65D0:aSE02DGdX0ck6I0<BbW034_:T0b/Bh0>KSgP3:b<T0:bP_03Hc
?P11?TT0?S]40;2]]03Cd]L0K6a^07AbM@1=Bdh0F5IG03dl?@0L7Al08bH[02@Y;`0O8b`07B4Z01hQ
:P0I72D0;Bdg018B700P7bd08B0^03LiAP1EEf@0FE]X07=cO@2YZ:d0T8n=096>Q@2ATX@0TI>609^M
TP1kOWD0@4<l05]LEP1KFUD0CTe804m>B@1GEdl0H61F079bJ023QGX0NG]`0863N01lOW<0KVmW065P
G01gMW80SHb80<k=b@@00?l06_ooool00`00o`00X23`0:0Pl0190:0Pl0030?n0002P8?00X23`00l0
X23`00<0d51h0?n0002P8?003P2P8?00103@D7P0oh000?n0003oP00e0:0Pl0@00?l04?ooool000ko
oooo01l00?l00?oglP39VHl0X4i20<1@@P3BCCh0fd`n0>mKC@3]EdP0iDdo0>mGB@3/ETP0kUQ:0?EO
D@3^FT`0ieQ80>ePC`3eK5`0oWIX0?QdI@3gLfH0mG5T0?9^H@3^JUd0iF5B0>QRD`3RFT`0hUY>0>AL
D03WGe<0jEmB0080kF5B00h0kV9A0>iUD`3]I580lVIE0?5UE03bIUD0lVUG0>mVE03cK5P0k6QA0>YV
C`3[Ie00jFE@0>QTC`80l6aG07P0kVUF0>iYF03`J5X0mfmQ0?A/GP3cJE`0l6AG0>aPD`3VFTd0hUI9
0>IHC03QCdD0hTm50>1=@`3PDTH0f5120=QFB@3BFE00/d<o0:U1@02fEUP0]e]P0;QMI02lHV/0afef
0=9gP02ZCEL0X4=;09]4B`3BQH/0jjBZ0>NV[03WZZl0jJjd0>^b^03/]KX0j[Jj0?2n`@3Z_;h0jko0
0>_1`P3X_/00jKc10>^j`03`]l00gXbG09//=@3:Ce80c4m=0<U?BP34CdP0fFUU0=YaK@3=If<0/E1:
0<IWH`3=L6T0_fEM0<5YG`3^UXP0/F1;0;=YCP2ULDd0ck6=0<fmW03;a:P0`kf]0=?@a`3Zj^P0FUUN
02h]=@0n?4L0<c4l07QgO`3]k?80GUeR03Pf>@18ATT0^kVj08b=T01FFV<0EE]Y04Q?H@16CV40@TYM
024X>P0/;d00YZRg02d_?00/;Cl0<353038eA00Q9C40<C=005IFH02MWIl0XJ2L09NER`2DUHL0TiF8
09jPU@1lOGD0EEI@07IeL01`Kf/0C4]704i?BP1?D4X09BHP05eNEP18BD40>C/`07j0M@24QW/0OWmf
07mlM@1iM700C4M1059?BP3Thn43003o01[ooooo00<00?l00:0Pl02P8?00B02P8?000`3oP000X23`
0:0Pl00@0:0Pl0030=1@N03oP000X23`00h0X23`1@3oP00e0:0Pl0<00?l04?ooool000kooooo01P0
0?l00?oel@31Rh40Ye540<EAA03BCCh0heA60>mKC@3[EDH0jUA50>iHB@3]EdT0lE]=0?=LD@3aFTl0
kUa=0>mPD03[Ge00kF=F0>mZF`3[IeP0kf]N0?=_HP3bL6020?EdH@0:0?EbH03aKEh0m71Q0?5/G@3/
I5@0j61@0>eTDP3ZHDl0j5m=0>MNC080jEe>00H0ie]<0>YNC@3]HE00lfMF0?9WE03aIU<20?9VE@80
lfYH07T0mfiL0?9YF@3aJET0lVQK0?A/H03eKF40lFUM0?9XF`3dJUd0kfEH0?AZG@3^I5L0lFAH0>QJ
D03VF4h0hE=90>9DBP3KDDH0fE=:0<e<A`39CD/0`T]=0;e:C`2nCeD0^TeB0;=6C02_@4L0[Ci40;mA
E02mDeH0ZTY<0:Y>D`2ZDeT0/UeT0;1OI@2_H6H0/fI/0;Y_M02nMWX0a7n20<b:S03CTI<0eYFI0=fJ
X@3ZXj/0lJ6/0;QCF`32ADT0dTe>0=9;A`3HEDd0`d@m0<mDC`3BG5P0df1K0<aMEP3RMG00fW9Y0=Ia
I@3ALV00dGYO0;EU@033Oe00WVhg0<Z_NP3Fb9/0e<jZ0<o=]P3<c<00inSS08j?T@0T8b/0BDMB03`j
A`16A4l0g=_Q0;2^/`1LFUd0Cde@09nMWP2/[K009RXc024W=`0P:3/09C1403@oE@0j@5P0=caB0;o2
d`0m@5409BHj02T/?`2OYKD0JVel01TK:00Y:C<0L6ia0;>_[02TXIP0WYjB0::RUP2[[J80LW=[065P
F`27QX40P7mk08B5P02:RhH0S8f807IgL@22Pgd0EEA?04m@B029RH40S8b408:1N@22NG@0QGYf07aa
J`0m=2l0`kjk00<00?l06_ooool00`00o`00X23`0:0Pl01Z0:0Pl0L0oh00=@2P8?03003o013ooooo
000>ooooo`0L003o003omNl0^Gec0:a>@P3<E4H0ede00>MEB03bG4h0j5930>eGB03YETH0kUY<0?=M
C`3cG540kEI;0?=MC`3cGe40kEi>0>mRD@3^HU40kfID0>UQD@3YI5<0ifA@0>=RC@3VIe00jfYD0>QW
D@80kVeG00@0kfeG0?9`FP3aKEP0lfmJ0P3bKEX00`3`J5P0kFAD0>UPD0020>ELC0200>ELBP3WFdX0
jE]=0>YLCP3_HE<0k61A0?5UE03bIUD0m6QG0?=ZFP3eJE`0l6II0>mUF03cIeX0lVII0?AXF`3aIeX0
mVaO0?A[F`3aJUd0k6IJ0>aSF@3WGe<0h5=90>IHCP3QDdT0hEA;0=eFD03IF5<0fUiL0=]SHP3HI6@0
e61P0==MG@3BG5`0dEUJ0=5LF`39EeH0a5IE0<9FEP33FE/0^U1B0;A<C@2gCe00]4e>0:a8B02]BD/0
[de>0:e:C@2/BDh0[TU?0:e5C02b@dX0^3a00=I>CP3HCDP0f4]40=U?A@3FCDD0dT]50=E@B`3GE4`0
fUYA0>9VG03RJU`0ff]G0=5ZB`32JS`0_gDh0:I/8`2JMB@0`:eQ0=[@T`3MfJ`0emJj0=3Ba03Ph]d0
_l?402LW;`1DDUl0BdUG03Da?`2[Z:l0l>_a0>?NhP3Fd]<0c<O;0>?Qi@28Ri00H6A]04A:EP0X<D80
7RHm03e2G`1>DVd0Yjbo071fQP0E62/09R/n08^AX@1hNhX06Q`Y02DU;`0h=S/0TXj=0:^XX@2UYI/0
Y:JK0:V[X01bLf/0MgQb069SG@1TIF00JVYX06IWHP1dMG00RHR409^JUP2JUY<0Ph9m08Z7PP2IUY40
VI6>09R8R02BOWd0VHB1065>BP2HSH/3003o01[ooooo00<00?l00:0Pl02P8?00J@2P8?080?n003D0
X23`0`00o`0@ooooo`003_ooool0=@00o`00onkZ0;9_I`2eD4H0cDm30=iBA@3^FTh0keU;0>MA@P3`
GDd0jUM70>mKC@3fHU@0kEI;0?=MC`3`G4h0lV5@0?5RD@3^HDl0k6A>0>]TCP3XITh0ifM>0>M[C`3P
JD/0gf]:0>1^C03MJdT0hFi?0=i[C03QJdl0hFU>0>I]DP3UJDl0iVYB0>U[E@3^KEX0lVeL0?=[G@3f
KUh0nW5Q0?A[F`3dIeH0l69D0>YLCP3YFdd0jUa>0>EHA`3[Gdh0heM60>MKC03ZGU40j5a?0080jemB
01l0k61C0>mSEP3^I5T0kVIJ0>eXF@3ZJ5/0jFUL0?]iK03gLFH0kF1F0>]KD03YET`0he=80=aBB03J
Edl0ff9J0>5`JP3ML6/0gG5^0=mbK`3KKV/0gFe[0=YWI@3KJ6D0fFQT0=UYI@3GIfD0eF=R0==QH03B
H5l0eFEQ0080d61N0580cemN0=1MH03;F5/0bEEH0<QAD`39C500ee=B0=I=A`3JCdP0eTa20=]AA`3C
BCl0gE190=mBB@3LCdD0gE=80=YBAP3KFDT0dUY20<QN=`2eG2@0ch]00=FTB033YT<0`[=F0=S@Q`3R
gjX0g]fn0=WJbP3LgMP0j>W[055AF@0f=440EE=Q04Q4DP20OHH0l_3e0??^lP2IU9P0KFQ/0=3=d03U
i^X0gn;W0=GIhP3?eN<0FF1c034eD01DEG40Q8NJ0<c?gP13AUD061/Z02<W<`0U9c<06ATU024P:00I
5a`0I61O0;>_ZP2ZZZ80Z:ZO0:VZXP23Q7`0M7=^06IWH@2?SXX0LW=^051AC01AD4`0EeIB06]WI01d
L6d0G5QE06UUHP2PV9H0Xi>C0;VKW@2oVid0cZRW0:J4PP1kHel0nN_X0P00o`0Jooooo`03003o002P
8?00X23`06T0X23`2@3oP00e0:0Pl0800?l04?ooool000kooooo03<00?l00?kUh02_IUl0^4e30=9?
A@3UEDX0lEeA0>mGBP3YDdD0k5Q:0>eIB`3cHU40l5m>0>mKC@3aGe00kEi=0>mRCP3ZHT`0jVI=0>MW
BP3QJ4T0hVe:0=mbB`3PMT`0fWE90=alC03FNTT0dgM80=UlD@3JNU80fWQC0=ahE03NMED0gW=C0>5b
EP3OKE80i6aD0>EWD@3XIE<0kFEE0>iUE@3dJ5L0lF=C0?EXE`3gJE/0mVYK0?=WF03cIeH0lFED0?9V
E`3bJET00P3/HUD0M@3ZH5<0iE]>0>EKD03WGe<0iEmD0=mKC`3SHeP0hFEI0>5WG03jNW40lVeT0?1V
F`3]GE80k5Y=0>9DAP3FDTD0ceU;0;UAAP2]D4P0/eiI0;ASG`2eHEl0_FMV0<E[JP3<K6/0eW9`0=ih
M03KMG40h7Yf0=ifL`3PNG@0g7E`0=edL03JLFd0f6aY0=Y]JP3KJfX0ffUX0=aXJ03LIV@0gVAS0=aO
F`3IF580g5aC0=UFC03HDdX0gEM>0=eBB`3PDdT0h5150=mA@`3PE4L0feI30==G?@3:GSL0[eTN0<b:
?03Y_EX0el1A0=76G@3Idgl0j>BW0>SU`P3Qh<h0h=oJ0?CdmP2JVJ4081h[04E3D@1EDf40FEMR0=gL
hP3He]/0EeEJ06ESJ02g][X0kNg_0>KWj`3Si^/0mOWo09NJZ@0S93T0B4QP06UXNP3Wi_@0b<KA08:1
R@1JFEl0A4=802XY;P0J61d0:BLX09:AS`2i]K40/;2X0:j^YP2[Zj<0Z:RP0::OV02NWYH0ZjRQ0:2P
V02FUXh0Shj9081oN`1QH5`0CTe804e<A`1NFEH0WI6A0:F6RP3KYZ`0kk>e0?Ji^033S8T0LDQ20>O>
b@02003o01[ooooo00<00?l00:0Pl02P8?005@2P8?060?n004h0X23`2@3oP00e0:0Pl0800?l04?oo
ool000kooooo02/00?l00?SLf02^Hed0`5580=IAB03UEDX0lUiD0>QAAP3[EDL0jUI80>mKC@3cHU40
k5e<0>]LC03`He40k6A>0>ITBP3UJT/0hFa90=ibC03HMD`0dWE<0=9kD03?OU40c7mA0<f4E03:PeD0
`WiA0<InEP36OEX0agaL0<IgF038M5P0ag5F0<]aF@3;K5H0cfQE0=i_G03UKE`0j6UH0>UTD`3[I540
kf=@0080lFAC07d0kf5C0>iRD`3_He80lVIE0?1TE@3bIUL0m6QK0?EYG03hK5l0m6YM0?AZG`3cKF40
k6YM0>AXGP3PJf40dF=H0;M8?`3GH5X0jV]T0>eWGP3YG580k5e?0>ELC03IFT/0cf1?08lc901b9QT0
LC4X06`a;@1Z;Rd0L38c07Xh>@22>SX0TTA209]<B02OD4`0X4m<0:UHE02`GEL0]65K0;iYI034K6P0
bW5]0<mdK`3BLg40dFm/0=YgLP3ONGD0g7=`0=aaK03ML6T0hgA]0=e/I03OJ680i6MQ0>UUH03WGUH0
h5=90>9FB@3KDD@0fUQ80==LA03>J480_F`g0;Yk=03^`fL0gLML0=S<J03PfHP0dLf@0=OC/03PgLh0
hN3L0?3_m03Ng>L0@3i;03<`@@17A5D0CDUG0;Nd_@3HeM`0?ce203Pc>P30_L40j^S[0>KVj03RhnD0
k_7f0<G8d@0W:3X0@3iD04E2E@2o_L/0jNK_0=GCeP38a/L0^kVj0:ZXZ`2HUYL0Z:NU0<;1_`2m^KH0
];>^0;Nf/@2f/jh0/k2[0;6^Y`2^Zj@0ZZNP0:RUWP2YZJ40YZJN0:RWXP2LViL0TI2;08R7PP1mMG<0
UhB60;24R`3<PhX0f8>80<ihN@2[GET0RTm90<jYX@02003o01[ooooo00<00?l00:0Pl02P8?004@2P
8?0<0?n004`0X23`203oP00f0:0Pl0800?l04?ooool000kooooo03<00?l00?7Dd02ZGED0`U=80=MB
B@3WEd`0lUiD0>QDB03ZETP0ke]=0?5MC`3dHU<0iUU80>eTD@3TH4T0iVY>0=aZAP3MLdT0f7U;0<aj
BP38PU40`HAH0;j7H031Sf`0`8m_0<>EM@3=WX80fZbB0>BdWP3S/il0fjZI0>NcY@3Z/JH0k;2V0>f]
Y03_Zj80iijG0=F1MP3=JET0gg1M0>YaG03YJe@0jVA>0?1SD@3`He80lFAC0>aOCP3aHeD0kf1B0?9S
E@3aHU@00P3aHeD0M`3_HE<0kf=D0>iRE@3ZI5P0i6UJ0=e]H@3ELfP0]eiG07`Q7P2K<c80ae=C0>MX
HP3]I5`0jEaB0>QPE03QHe@0c65A088_7`1J6``0ERHL04`U7P1:9bD0BRHV04lX:@1G:bd0GRh^05XZ
:01O;b/0HC0/064^:`1[>3@0I34]07@o>@1c?3L0MS/g07e0>`22@Cl0PShk08i7A@2DBTL0V4e:09U;
A`2RDdl0[e]I0;1FE@2fEeD0aeiK0==MF`3KFeP0eU5<0=IABP3@DDP0bUA60<ELB@36K540_gE>0;1d
@03Q]W40h/Qd0=W:M`3`ij80/J]i07ijG`28QWX0UYJF0:b/]02o_l/0EUEU03dlCP12?e80ACi@08^5
T`3ekoT0^kJm0:JOYP3ZhnT0jnKZ0>KTi@3QhN<0inS/0>GXk`11@e80:2Tm02/Y?P1iMXL0jNK_0=WD
f03Acm00dm;@0<_9bP3<b//0c<_90<[9a`39aL<0`knl0<:n^`30_;T0_KVf0;Zg/P2h]K00/k2[0;Ba
ZP2a[ZL0[JZS0:bYY02SXYd0[JbW0;Fb[@2h[Zd0^9nR0<2:T@2[D5T0]diE0<=GE`2nGEL0YeeD0;21
N@3ol^d00?l001[ooooo00<00?l00:0Pl02P8?003`2P8?0:0?n00500X23`203oP00`0:0Pl0030?n0
002P8?00X23`00@0X23`00<00?l0ooooooooool03_ooool000kooooo03400?l00>O8a@2SE4d0`e=8
0=]GB`3ZFTl0kUa?0>QDAP3]FD/0l5i?0>mPC`3ZGd`0if1:0>MWCP3PJDT0g7570=Ad@P3AOdL0d8Y?
0<VAF02oTEl0djf60>O5Z@3XbK@0i/Vg0>g@`P3_dLH0d[BY0<FWW`32Xih0l]?@0;nPWP2_Rhd0/HR<
0;:8S02]Oh80cYZL0?g0^`3LSgl0bViG0>5hF`3VLe@0jFe?0>aUC`3]HTl0lVIE0?1SDP3_HE<0lV=E
0080lF9D07T0lV=E0>iOD@3bI5H0kF5B0>mUF03WIEL0h6aM0=mjKP2SDDH0/g1Z05dG5@1W5QD0Sbd^
0<IDD`3VJFD0j65K0>EOEP3QHeD0fFUK09e4=01Q7Ph0B1P<044O5P0j8A`0=b8Q03DO8@0k92D0@2HW
040V9@12:BD0BR`Z04DW9@1@<S00BB`X050a;01;:RD0Cb`X04lY9P1E;2X0FBd/05d`;@1O;bd0HS4]
06Dc<01W<Bl0IR`[078b<P1g:bd0RC0b09<[;031CDd0bdm=0<U>B@2oC4D0_eU=0;EMC`2CBSL0NShT
06m17@28I3@0PFX_081a=P2;Pe80NGE@05QE@P1EE4l0EUEJ05aLIP1GEV@0?Ca<03lnD00n?540@CiA
05eIJP2XY;80[:Vd0<>mb@3Jdmd0i]oW0>ORj03Th^L0hN;V0?7dn@24QY804A<P01@C8@12@4d0emCK
0>7OhP3He]L0emKD0=GCe03Dd]<0dm;@0=CCd@3Dd<l0d<c;0<o;b03=bLP0b/K50<K2_`35`Kh0a<2m
0;nl]`2m^[D0^[Nb0;Jc[P2^ZjH0/K2/0;^f/`35^KT0cKBg0<nDW02cCeT0/Sm60<Q@DP31E540/5aB
095KC`3^fM@00?l001[ooooo00<00?l00:0Pl02P8?003@2P8?080?n005D0X23`1P3oP00a0:0Pl003
0?n0002P8?00X23`00@0X23`00<00?l0ooooooooool03_ooool000kooooo02l00?l00>?2_@2SDdX0
`e560=aFBP3]GU00jUQ90>EB@P3`Gdh0kUm>0>UQB`3UHdT0gVE60=i^B03ELD00eX150=:9A@3>TTT0
cYiF0<VUI`3J_i00l=^n0=o<_@2n[JH0/j6O0>KBe02@O7h0KeUL05Q3B01]F5l0eL7:06]GHP1XDUl0
JU9R06a@G`1WAe@0GSU00<BHU@3j`[40`WeN0=1kDP3KNTd0i7I=0>Y_CP3WID/0k6EA0>]RC`040?5T
D`80l6=B05L0kF1?0?9VE`3/IeP0hfQI0>9hJP36KV80NCH]09MXH@2VNG@0L3Hd06<L6P24:BP0`eED
0>AXIP3WIV00i65G0>5WFP3>He<0TcXZ05lM3`135@P0>Q`D030M5`0^7Qh0;B0P02hP800[7Ad0;R0O
03TW9`0c8Al0AS@b03TW8`10;bP0>RLQ04/f<@0i9240>RDR03/V8`10:2H0@RXX040W8`14:2H0B2XZ
04@R8@1A9bP0DAXM064K7@1Y4180/d]<0<YJF039FED0bfEP0;]TF`2KF4l0GbhP04@O3`15:QD0Ac4I
048e500j=1@0=3<G02X[6@0l?3@0@41004A5BP15ADl0>SU702l^?P0a<480<C9603XlD@16BE`0E5EW
04e>H01CDFH0JfQk08B0S`2KUJ40fmSQ0>7Pi@3Wj>`0b<W>07ioQ01UI6X0E5=H0;Rh^P3UiND00P3K
fm/20=[JfP0L0=WIf@3Fe]H0emKE0=KEd`3Ddm40e=;C0=;Ac`3>cL/0cLc:0<_:b039b<H0aLC20<G4
`032`Kd0_;^g0:^ZZ02XY:<0^:j_0<6[[P3AVZ<0/U=K0:<b>032BT`0aUIB0;MME023Ac`0b[6Z003o
01[ooooo00<00?l00:0Pl02P8?002`2P8?080?n00140X23`0`3oP0150:0Pl0<0oh00>@2P8?000`00
o`3oooooooooo`0>ooooo`003_ooool0<@00o`00hKjj0:MDC034DTL0geU=0>eNCP3ZF4T0h4ln0>QJ
B03VGdT0gem20=]T@P3KL4H0cfll0=9n@03ARD40dII60=NXF03K]fd0cKEi0>OH[`3HbkP0hmSD0<Jk
_`2l/[X0]JVd06MIIP1MCe`0>B`f0;>U/P2HS9X0EdYK05I9F`1>?e@0ET=I06M@HP15:S<0UG9`0?oJ
a@3LY7l0e8iK0=:1B@3LODP0igQ=0>adD@3YJD`0jfA>0>eRC`3aI5<00P3`He80FP3cIUD0kf9A0?9U
E03^IED0jVQH0>9^G`3INF/0XUQ;06@`9@1Q@3T0]IRB0;JAR`1/>CH0Ea4?08H^;033FeX0gfUW0>=V
H03PI5X0ffEI0<]QD`2A?Rh0Fa`=03lC200b5`h0;1XF02LN700V7Ah091/L02HM7P0a9bH0:AlN03X`
;`0^9280=B`W038Y900j;b/0<2DQ02hT8P0d:RP0<bTW03L]:`0f:2L0;b4P048b<P0e8B80AbX/044G
6@1L7R40I0lB0:e9B@3:FUP0c5aH0<QUG`2aHEP0SUE<04PS6P0`60h0<28G034W6`0d;B00;2XM02d]
8`0O81X0:BTW02//;P0b<CL0=C@l03Hd?`0/:SL0;2/i02X/>@0Q93<06Qd/02<V=@0b=D@0=3M80492
E@18AEH0AT9@0;bi`P3ViNX0f][L0=gMg`3Kfm/0f][J0=7Ad@3EeMD0g]kN0=gMg@80g]kN00`0gMgM
0=kNgP3Kfm/0gM_L0=gLfP3LfmT0g=[K0=_IfP3Hf=H0e]KD0=OEeP3Dd]<20<o?c@0?0<o>c03;b/P0
]kJd0:2LV`2VWJ00[IZN0=FT[02jGfP0VR/b0<E=C`36EE40^5aA08Q8?02PQG`0ooS_01[ooooo00<0
0?l00:0Pl02P8?002P2P8?090?n00140X23`103oP0210:0Pl13ooooo000>ooooo`2<003o003Q^[D0
ZUM?0<MEBP3RG500lF9B0>MEAP3TED@0iEe70=iQ@`3CHC`0igi?0=Mj@@3DPd40cHDi0=6C?P3R[UP0
kL1_0=NdL03E_hd0h=6b0<g1]@3Qf=T0_;Jj0>SQj@2BRYP0G5AQ048gA@1`IW40e<[E06iSL`15?4d0
GeIW071TN017>E00He1S03/Q;02aSXX0om>l0>beS03g^X40ij9Q0=:1?`3PP4H0iWY;0>egD@3WJ4P0
kFE?0>mRD03_HU40l65A0?9SE@3aHeD0kF5@0>YUE03RJEP0hgUY0<AcHP1_=2H0DbPO04L_9`1IA3l0
WhJ10;nNV@1^?SX0DQDB088d<P2dEUH0efYW0=eWH`3SJ640ffEK0<]QD`2H@380H1h@03dA1P0`5@h0
:1`H02@L6P0Y8b<091hN02TS8`0U81d0?3@b02XR7`0e;BX0;BHP02/T7P0Z8ad0=Rh[02lW9@0b;BT0
:2<O02LM6`0Z81h0=BXX034S8P0m92L0=`dA05PG6`1Z4180]DU70=EKEP3;DTT0`5I90;AQD`2@F4/0
?adC02XG400V7AH09R4K02HT7`0O7QT09RHT01lO7@0L71X07QhN024O8P0S8BH0;2L]02HQ:00U8RT0
514H03ln@`1SHVL0BT]?03Hj?@0N8bL08R<^01dK:00M6RD0Q86:0>WXk@3Kfmd0f]SI0=_IfP3Mfm`0
h=oM0>;Ph@3Qgn030>7Qh@080=kNgP3Ng]`0h>3N0>3Ph03Rh^80hn?S0=oOg`3Ph>020=oOg`0C0=kN
gP3MgMd0g=cL0=_Kf`3Lg=`0fMWI0=?Cd`39alP0aKo10=;2a@3/a<X0_V]c094X;@33C4h0a5==0;aN
E02=Bcl0S71U0?ofk00Jooooo`03003o002P8?00X23`00P0X23`2P3oP00B0:0Pl0H0oh00O`2P8?0@
ooooo`003_ooool0S000o`00gKB`0:aHCP3<Edd0heeA0>ePC`3TEDD0hEA20>9RB`3JJdd0dVm60>67
E@3NSTl0eXi40=VHAP3U[5D0l/1[0>:hKP2XR4d0flFN0=_?^@3Sf]D0`K^o0<_6c03[iNl0IF5a044m
CP2WX;00ln_j09F=W015?4l0?SM90=C<h@3AbMh0D4AJ04`mD012:cD0hKjl0<jKR02lOEX0l[1l0?nl
N`3UW5@0eX4n0>20A03RMTD0kgQ@0>UXB@3]IDd0kf9@0?9SD`3bHeD0kV1B0>mVE03UIU<0gfiL0=Qk
J@2NFDT0G2`N04DW700o;2H0?RlZ04`i=@2YTHd0a:FP06Po>`1B6QT0Mbl`0:eEE03?IfH0hF]W0=mV
GP3OJEd0cVAF09m9>P1O8140?14802lI500V71X09b8O02HR8@0R7Qd09b<R03<^:`0V8Ah0<RdY02DP
700Z9B409R4M034/:00Z9B40:RLR02PU800R7AX0<2PU03@/:@0a9BD0=QdP03/A5@1G5AT0Ka0D0<9>
CP3DEDh0dE=70<IHB@2kI5<0TEM903dM400V5@d08A`H01dL600N7Q`07alO020P800J6QX06aXH01lK
6P0M6AP08AdL02DO8@0Q61/050h@03hh>02`[:/0g=SG0<O7a@2h^[L0XZJU08N:S@1VIFd0BdQ?06AQ
J03Lfn00gmoQ0>3Nh`3OgN80h^3S0>KTi`3UhnH0hn7R0P3QhN40303Ogml0gMgM0=oOg@3Rh^00h^;R
0>GUi@3Vi^H0h>3P0>;RhP3Ti>@0hN7Q0>3Ph080h^;R0100gmoO0=oOh@3Ogn40gmoO0>3Ng`3Qfmd0
i]OJ0?SGgP38Nh<0QB8W0;a8B@30Cd/0_EmE095?@@2=Kf@0ooG/6_ooool00`00o`00X23`0:0Pl007
0:0Pl0/0oh004P2P8?070?n007h0X23`4?ooool000kooooo09D0ooOd0=Z_Z@2]ET`0c5Q;0>MRD`3Z
GD`0hUE40>AKB@3LIU00d75E0<QdD03BR5L0fYII0=bLE03Z[Ed0mKYZ0>VeJ@2NMCL0_Ii`0>KE^@3M
dlL0gmKG0:NPY`3ZiN`0_kc705EBIP10?E80U8nS0:ZU^@1HD6D0B41H04m7G`2SV[D0O7B<0514FP0e
9cP0PF]g0?KBeP2]LFT0]FQD0<ijE@3ST5`0o;E^0=nCA`3IQcd0hX=30>IkA@3]Ld`0jfQ:0>mWC`3_
HU00kV5@0?1TE@3[He<0i6UG0=edH@35M640ND0_04`X6P0l9Q/0>2XU03DW900m;RT0CS/e09=kM`2n
XYh0SVQU050P7P1Y:BT0Xe9A0<eWI@3NKFT0hVUP0=aXF`3@JEX0Xddn05dO400h5@`0:AXE02DK6@0S
7Q/09b<P02PT8@0`;2T08QhK034]:P0U8Qd0;R/V02`Y900b;BT0;BPT02LT7`0/:B809B0L02`W900g
;bd09ATK03XO901151T0FQ<I07HC5P35CDh0f5A?0=9BA@3:FdX0_6=A08aC@P0l70d08a8:028M6@0M
7A/061TI020P800N71d07ATH024L6@0L5a<07aXF02@L6@0L4Q009AXH07AZJ03?al@0f]GA0=OCd03K
f]H0f=SF0=_Kf@3MgMh0g]cO0=?Ae03;bL`0g]gR0>7PiP3Uh^d0in?a0=WGi02m^lH0]kJl0=WIf`3P
h>00g]kL0=cLg03MgMd0gmoM0=kNg03Ogmd0g]kN0>3Ph0030=oOg@030=kNg03Ph>00h>3P0080h>3P
00l0hN7Q0>3Ph03Ng^00gmgN0>7Kg@3Vf]`0n=SN0<5jPP2bDeT0/T530;i>BP2lFe80Ue=609=cJ03o
m>T06_ooool:0:0Pl0X0oh00302P8?020?n000H0X23`1`3oP01m0:0Pl13ooooo000>ooooo`1n0?og
lP3EZZ<0YU970<eLC03UHE80jEe<0>9FA@3KFTL0dVYE0<]kI03MV7/0hJ=l0>2TL03UZ6T0mKUc0?:g
L@2cP440X7Q70>?9Z03Mc;X0hm[C0<W0``3<aL`0nOCk08R2SP1?Bf00CDQN05YEJ@1LE6T0EdmT05A<
I01CBf<0GE=/05M=I@12=dP0;b4`0=6mb03oh>L0jK6b0;ieKP2lJUD0_FU50>^TIP3k]VT0g9=60=F1
>@3UPd@0igM70?5eC`3WI4P0jf==0>mSDP3^IED0j6EC0=mZF03KNVL0Zf9A05h_7`108aD0=RDK034V
8@0a9R@0@38_03d^:@12<2`0Pg1Z0<6YY@2HMW@0E2LT06d`;`2EA440aFAN0>1_I`3QK680gVeO0<aV
E`2QCSh0E1d@03PG400Z4Ph0;1XF038T8@0[81h0<bTW02LM6`0f;R/0;2@Q030Y8`0]9R00<2TS02hW
8@0T7aT0;RTS02@O6`0[9R<0<2PV02LH6`0n8BD0@a8H060G7P1j4aL0c59A0=UDC@3DDTD0b5M50;mW
D`2:DCh0?Ad>02DD300Q71P071`J01XI6P0P71/081/H02<K600U6QH07A<:01dC1`0I4040Bclc0:VL
T`3Ld/T0aKjh08b7P`2`[:T0h^7M0P3Mg=X04@3Qh=l0i>;S0>SVj@3Xin`0jNWa0>GTlP3Acn@0YjFk
06i/P@1?CUh0DDmJ0;6`]@3_knl0h^;R0=kNgP3MgMd0g]kL0080gmoM00@0gmgN0=oOg`3Ng]h0g=cJ
0P3KfmT00`3MgMd0f][J0=cLg0020=_Kf`0>0=cLg03Lg=h0gM_L0=oIf`3SemT0l]?J0<f7S`3LOhL0
XcDh0;e=B`2kFU40WEM;09UgK@3omNXJooooo`X0X23`2P3oP00E0:0Pl0L0oh00O02P8?0@ooooo`00
3_ooool07@3on?80cjNO0:IDB03:FT`0iF=E0>=KB`3MF4L0gFAC0<]_H031Og<0[gEW0=2HP@3/]940
n;^<0?RlQP3HW6P0Z7E60<NUPP3_fL@0jm[B0=cAc`34^[/0h=GI0>kUjP2AQi00>c9404@mC`18@E40
ASe>0080A3]<07P0@cM;03lbA00f:CX0=2Hc08emQ`3hhn`0oMoW0?oLi03mblh0eIJA0:=KC033NTl0
o;Qg0?^gKP3QUDX0g8E00>IoA@3/ND`0l75@0>mYD03]I580kFQG0>1SD@3NLEd0e7]Y095>?@1A9QH0
?R@G03PW7`0]8ah0;bDS03L^:@0m<R`0@SD_04Lh<@1`GEL0YXn908IWI01_@d00Jc0/08m4?P2nH5P0
g75W0>=aIP3JJ5d0cFEH08`g:P1A4@P0?0T503/B3P138Al0=QXG03dU8@0^6aD0<b8K03DV7`0b9Al0
;B0J038U7`0f:bL0:1lJ03</9P0X81d0;RHS038W9@0^6ad0@b@Y04D@601O4QP0OA@H0<iBD03JE4/0
dU120<MHA02lIE40Qdhk03hN4@0Y61008A`H01dI600O6AX08aTH02XL6@0[71D0:1H<01l>000[7@80
L6=30<c1X`39_jH0NG=S08n;PP2ZYj80d<c;0=oNg03NgM/0hN3N0>GTh`3Zj>/0j^W_0>7Qk@2n_m<0
S8jW061QP01FEWP0IVN505iNMP0d<d40M7=i0?3`lP3Vi^H0hN7Q0=oOg`3Ph=h0hN7O0>CRh`3Yi>P0
j>KW0>CRh`3ShN820>;RhP0C0>7ShP3Nh=l0gmoO0=gMg@3Ng]h0gMgM0=_Mg03MgMd0h=cM0>CIg@3e
emd0f9:J0<]^MP2P<SD0`51>0;]JD@2KEDT0W7Y`0?ocj`0Jooooo``0X23`1`3oP00G0:0Pl0H0oh00
AP2P8?030?n000d0X23`0`3oP00S0:0Pl13ooooo000>ooooo`2?0?ohlP3=YId0YUM:0<eOD03SIEH0
gU]90=YMB`3DIE@0aWM]09mXI@1R<B`0S5Q=0>>/U`3i_I/0fj1h0;IoF02bQV<0l]>n0>KDb03ahn00
b[k00>3Df02eZJd0_k:k0=kBg01aIGH0DDUH05=;FP1NDf<0HUMU06MLJP1UFVP0K5i]085cP033/kd0
mNC/0?WTk@3ignX0nmgY0?oKiP3od=H0hZRV0<J0I`3FT5`0okai0?VdJ@3NT4H0gh=20>QnBP3]MTh0
jfa<0>YVD@3WIU<0hf]J0=efH`31L5l0Mc`/04`V6@12:Qh0>2TR02dT800]9B80<b`V03H]:00e:R@0
@SLa04@e<01JBD80KUUD09YmN@2SNW@0OTM008]1>02iGeH0f71W0>EeJP3MJf00aE]?08le:P1W5a00
GQLA06HU8@1A5Q80E1lI04LF3`1?8aX0AalG048M5@0j60l0@b0J04<T7`0g6Q@0?b<O03@H5@0i7Q/0
?R8Q03/I6P197240E1HK06<>4`2;6Q`0eUIC0=U?A@3FDD80bEI30<AYE027ACD0?a<802hA2`0Z5A80
:18D02hD5@0c5Q80>1XB034D100^5000DS`E09j<FP2cYW40T8IE085iDP2JUWd0g][>0>CQg03Sgn00
h]kO0>;Ph`3YiNH0j^OY0<_:d02QXJd0JFYl04I8H@16BFP0FEao06e`T`1KG7X0?SaD02`Y>P1>Be@0
hn7V0>WWjP3QhN<00P3Ph>002`3OgMh0hMgO0>[Tj03Wh^H0i^;S0>7Oh03QhN40h^;R0>7ShP3Ph^40
h^;R0080gmoO00h0h>3P0=kPg`3Ng]h0gmgN0>GLg`3efn00bHJ?0<=VKP2]?T@0_4Y:0;eJE02ME4/0
WWac0?ocja[ooooo3@2P8?040?n001T0X23`00<0d51h0?n0003oP000103oP0130:0Pl0H0oh00302P
8?030?n002<0X23`4?ooool000kooooo01X0ooK_0<>KT`2ZFdd0c65?0>9WE@3LGTX0e61=0<YXF02a
LfX0dZJY0:b3R01e@T@0diZD0>NXV02fNV@0VfeD0=^kYP3Ga;X0f/o;0=K;c@3=`LT0l>7/0;j_^`2k
[K`0a;S80;FZ_080Yin`0800XiZ[0:>JZ@2ITIl0V92L0:JKZ02TVJ<0XYBO0:NGX`2YUj<0X8ZF0:B<
V@2DNXH0RFei0?;?eP3IXY/0^fm?0=B8E03h]W<0n;EY0>bNE03SR4L0j7m:0>]gC`3YKE00hfUC0=i`
G03HO6T0X5a<05LW6P1::b00?BXR03HZ8`0b:RD0;RTU02XU7`0W8Q`0;BLQ02lY8`0i<2/0@3D`04Pk
=`1HAd<0NV=N0:B5OP2bQ7l0^W]f0;i]I`3@L6T0f6aU0>=_I03CH580aeA70;a;?`2fA3/0[Cdd0:Hh
;P2N=2T0TRdP08XY7@1o8aL0N20E07HO5`1d8AT0JQTB070R6`1U6180I1XE06@L6@1P5AH0IaHH06P=
4@1c2@/0WAlQ0=aCD@3LCDD0fe130==FAP3<GTh0UCT/05`<101B2PP0D0d;054:2`1I3P`0HQP=06@Q
301lAQh0_IED0=ZnK`2^VTT0MVPJ09bCC`3Nej80k^W70>gXeP3[i^80i=oR0=7<dP2e/KT0VIBL06e[
L`1;C5H0A4MD03i1D`14BEd0Ce=Z061RN`1DDf`0>CI:02dW>@0Z8C40<2Hd0;Ra^@3bkO80hn7T0>7Q
h`3Qgn80hMcP0>SQiP1XH6L0G5IJ0>3Kg@3[j>T0h^7O0>7PgP3RhN40hN3Q0>7Qh@80h>3P00h0gn3P
0=kPgP3Mgmd0h=kO0>CLg`3egN<0^GV20;EJI02mC5D0]dA80;iKEP2RFE80VWQ_0?oek1[ooooo3P2P
8?030=1@N1X0X23`00<0d51h0?n0003oP000103oP0100:0Pl0P0oh0000<0d51h0:0Pl02P8?002@2P
8?020=1@N1d0X23`00<0d51h0:0Pl02P8?00102P8?0@ooooo`003_ooool0@03om>l0^i>;0:IDAP3@
IE<0hFID0=QNB@3CIU80`6UH0:MaJ`3H/KH0SfI^0:IaM`3<T980aXN209aVG03H/jX0h/k70=c@d03>
b<`0/:^a0?;/mP2g[kh0Hea/06]VNP1QGW<0FUM]05YHKP1LFW00GE]a065OM01RHgL0HfAf06]ZO01_
K7d0KVYi07QbP01mLX80Nfmm07=VL01DAe00_Jfg0?cWkP3fc]00_gYZ0<MkF@3HUF00ol5o0?bhK`3b
YEl0lI=F0?B8F@3]N5L0g6YB0=MbGP3CPW40W6AG04hY800i9A`0=BXT02hW8@0a:BD0;bPR02hV8`0Z
9B4202`W8`1202dU8P0e;BX0?3@a044h<`16>cL0DSlk06]<B@2OLVl0b8R80>fNVP3<KFL0dfeQ0>n;
N`3SPVl0egAQ0=1UE@3:FT`0ce]<0==MC`3?FD/0dee?0=9LCP3CGDl0d5Y>0<]EB`34CdD0_de30;a:
@02b@cP0ZCXa0:<f<@2Q<Bd0Wb`Y09`R8@2f<S00eDi:0=I=A@3GCd<0ddm20=1@@`2nA3T0Xb`T09hW
8@2P:B<0XBXT0:he:`2oCcT0_E/h0;5T<03b`GD0mmN20:V@?P2>OS40elj;0>cV/P3Of[X0a<6`09B@
S`1WI6/0BdQA04E4C01:Ae00BDUA03m2B@0l?dH0>ci70P0i?4D05P0c<C`0;2Td038/>00]9C80;b<a
02LI:02?QHh0m^of0>GPi03Rh^@0h^;R0>_YjP2WXZ<0IF1T03di>P2g/K<0m>k`0>_Ui@3Yhn<0i^;Q
0>GQh03ShN820=oOg`0>0=gOgP3OhN00g^3O0=oMgP3Rg=h0mMgU0;j0R`2YDe`0_55I0;Q7B`2mG5H0
XeYA09YhK`3oln/Jooooob`0X23`1`3oP00o0:0Pl0T0oh00:@2P8?020?n000H0X23`4?ooool000ko
oooo05T0oo?_0;N<Q@2WEDL0dVME0>9YEP3HGd`0dVME0<1ZF`2fPG/0`Y^N0;fBV@36TIL0`hR:0:Y`
KP2ZNWH0l=??0=c=bP3Cb/l0^[Fl0=?@e`3/jO@0OGV806=PL`1QGW<0CD]P03PfB`0a;dD0;be303Le
B`13A5T0DU=X05EHJ`12@eD0=cU803@c@@10?4X0BdEA04a4C`0o=Cd0J5mT0>[Oh`3diNP0o=cO0<nA
QP34OF40ah=B0?ZjNP3o`WL0ljiS0>N=CP3aREH0k7aG0=EYC`3FMfD0`GEW09m[H01oGUD0FDQ003he
;P0a:R@0;BLQ034Z900_9b@0=BdZ02XU8@0/9b<0;RHS034Y9P0`:bL0<RdY040f=017>3D0DSPg05hd
=@1n@T80^Va/0;QIE@3BJf00oIb;0?n_W@3oZ9@0o9F40>eoKP3]OVd0j7MU0=]ZFP3EI5@0g6UG0=YU
E0020>5YF`0?0>A/GP3XKf@0hF]O0>1]H03EIEL0eFEI0<iND`3@GU@0ceYA0==FD03KG5D0geaB0>=Q
E03MFDd0h5Y?0080fE=:03<0hUUA0>AKD`3QF4h0gEQ;0=INAP3@JDH0/f<b0>FbL@3]c8D0b;5]0;ZZ
KP2_YG00RHIM06aZD@1HETX0AdE604]8C`1:BE40@T590491A`0j>Ch0;c0d03<b=`0V9BX09bPZ02LW
:@0[:Rl0;2X_02lZ<@0_9Bh0;1h]02<E902;OhT0n>kf0>GPi03ShN@0h^;R0?Gem@29Q8D0j>CU07Yf
M`2]YjT0^[Bf0;J]/03Oe]L0jN?S0>_Ui`3Xi>D0hn7R0=oOg`3Lg]d00P3Mg^002`3MgMd0h]cN0?CL
i033RY<0VTUB0<YQJ02^@4<0_EaE0:1HC02JN6l0ooC/01[ooooo;@2P8?060?n003l0X23`203oP00[
0:0Pl0030?n0002P8?00X23`00@0X23`4?ooool000kooooo05D0oo7/0;66O`2[FDd0dVMG0>=ZE`3I
H4d0d6EC0<E_H02hQ7`0aYbN0>:h_037TiL0]X>209e]J`3Q^kP0i<o>0=kBe03>a<`0]k6k0?;_n02c
[kd0EU=T05aIK014@540O7R709ZFY02?RiT0T8bK0:FR/`1OG6l0De1U040mD01:B5H0ZJNb0:6NY@2V
XJL0[jV]0;F_/@2h/[@0d/W:0?7Yi`3`i>@0n^;R0>>_Y02bLUL0^WQ60>Z[J03oagP0nKYZ0=Z5@P3J
Md00h7A=0=UaEP3>MV80[FEG06lm=01jFE80QWE^07ieKP1NEdl0>S@^02dX8P0Y9200<2/W02dU8P0b
:RL0<2PV02/S8@0a;2P0<2/W03P^;00m;Bd0B2h_05X`<P1W9BT0OB@V0:@k>03/NG00nHUk0?jDQ03o
UhL0oi:10?^=O03oUH<0oib90080oij;05D0mI9o0>R3L@3TNVX0ggEU0=ecH`3LLV@0g7EV0=]jJ@3N
PFl0iXUh0>V9N@3WQWH0jHEe0>IjK@3aPGD0m7a^0?EiK@3iNFh0mG1W0>MNEP3_I5d0oG1Y0?5WG@3Y
GeD0hF9C0=IWD`3:LE<0]G5<0;>7FP2GNd`0KU/a05e@;@1>BB`0A48]04i>@P1;BTH0ATI60491AP0g
=CX0=38g03Hd=`0X8bL0:bHZ02XX:@0S8B80:BTW02LW9@0Y:BT0:RX/02hY;`0Z8b/0<2@b02XL:`22
MX00m>[b0>OQi@3Tgn<0j>KW0>WWj02KUYD0Qgio08ImOP37_/40PWUl04<m?`1HDU@0QGn10:^UZ@36
`<@0f=?G0>7Oh03Ng]h0gMoN0=cNg@3MgMd0h]cN0?CKhP3<U9l0RSe70=A/M@2/?d80^5M@09eEB@2K
NG00ooG/01[ooooo;02P8?070?n003l0X23`1P3oP00]0:0Pl0030?n0002P8?00X23`00@0X23`4?oo
ool000kooooo0600oo7/0:YoN02XET/0e6UI0>=ZF@3FGDX0dfED0<9YE`3CVHd0Zgii0<>GU02hRhH0
ZGih0:Z7P@3_dm00h<k>0=K:cP2n/k/0hMOP0>kVl@1nN8H0FeMX059=H@0k=dP0`[_;0>cTlP3Vh>`0
l>[h0=OChP1WHg@0BdIJ02@P<@2XYK00n??j0>_VjP3/j>T0k>KV0>gWi`3_jNT0l>SV0>oWi@3bi^H0
nnGU0?O;`P2bNV40/g=30=FFD`3nagD0o;m^0=b<A@3<K380gWM>0=MbE03=MV80ZfEI06De:`1B<BX0
FDI007M/IP2AR840N71Y04Dn>00d;2T0:B4N02PP7@0c:bP0;bLU02lZ9`0]:2@0<B`X03D[:P0n;2`0
A2LY05LV:P1S61d0O1`N0<MEE03YKFD0k79U0>QbI03[MFL0jG5Q0>iiJ03[NVP0l8Ec0?B=NP3eTWl0
oiZ80?nHQ`3nU8@0oiB40?^AP@3mTh<0niJ40?^JQP3mXH`20?nVU00m0?nRT03oVh/0oIJ70?V;O03c
OFl0l7AX0>UYGP3_JF00k6=K0>aRF03bIE`0jEmE0>QRE`3KIUL0_f9@0:5I@`2:Ec`0K4P^054l8@12
=Qh0ASl/04<o<`0j>S80?Shl03Pj>@0b<S@0<c8g02PW;00W9BX0;2X_02PS9`0Y92P0:BDV02TU900V
9B40:2TT02DU8`0S8b409R@W02DN9P0^8S00;1h]07U]M`3ejo<0i^3T0>COh`3^k>d0fmWJ08Z4Q029
PGl0PgUj0<g4a`3Cb/d0d/c>0;^e]`28PX@0;2HX03hh>P2KUIL0j>CU0>;RhP020=kPg`0;0=kNgP3R
g=h0lm[R0=:MY`25>480fG5j0:`o@P2kG5H0VE=909mnM@3omN`06_ooool/0:0Pl0P0oh00?P2P8?03
0?n00300X23`00<0oh000:0Pl02P8?00102P8?0@ooooo`003_ooool0903ol^h0/XN00:IDB@3EIeX0
iV]K0=ePCP3HIE80cfmI0<N5L@24EDD0O5E40:R4M02]T800dk^_0=_8`P3Zf=P0c[k10<bk`@3hjO00
c<7905iFH@1PFF/0DTeQ04U4FP1cKX80P7V;08EnT02;Q9H0Mg2205]DIP0i<T80ACm=0>COiP3]in/0
jN?U0>[Ti080k>?T05l0kNCU0?7VjP3cj>`0m^O/0?_Ui`3of]<0_8Yc0;IgB`34Q4@0nlAd0?_1K`3Q
Td/0cG0c0=ehC03GM5D0cWMS0:IQDP1U=2d0E3<^04dh=@1=?S/0Fde:08EjMP2@QH40KVEP04m8@P0f
;bT0:RDO02LR7P0[9R80;2LS02lW900e:RP0?RPZ04HR9P1E7280IA0G09<Y;@3MHf80kVUR0?9^HP3_
KF00k6YM0>iZG@3]JE`0kF]M0>e_H03ZLF00k7AS0>ifIP3]Lf@0l7IY0?AjK@3dO6h0kWQZ0?9oK@3d
Q7<0n8ek0?R:N@3gRGP0nH]j0?V9N`3jQWT0mWeb0?9fJP3cLfP0mG5U0?E/HP3cJEl0lVQN0>iTFP3/
IU/0hfEG0<iXFP27?c40HS4R04l_8017=2H0?C<W03<_900_;2D0<C0/02l_;`0[;2h09BT/02HW:`0Z
:c009RH^02HV<00W92l0:2D]02XX;@0]:2`0;2PW02LV8P0202@U800H02DU8`0W9BP0:R<Z02TM:@0Z
72/0PWJ00?G[l`3VhND0hn7T0?3^k`3?c/`0Mg5a06mWI@1oMgD0b;o00968R@2`YjP0/:RV0<No_@2a
ZJL0`kZk0=_Ee@3Th>40h>3P0P3Mgmh02`3Ogml0h]cN0??KhP3CWZP0PcI00=YbN`2_@TD0^eaF09MC
BP2VQG`0ooK^01[ooooo;02P8?080?n00740X23`00<0oh000:0Pl02P8?00102P8?0@ooooo`003_oo
ool0H03omo<0aIjG0:9BB@3DJ5/0iVQI0=iMBP3KHTd0e6aC0<n4JP28ECX0NE@i0;fOQ@3JaK00g<bm
0=c=aP3Te=D0bkRl0>WDf@3A_/@0e/G=05U=E`1:@U40DDYL04m7G01HD6L0GEIY069KK@1TFfh0G5=V
04i5EP0V7R/0ZJ6/0?C]m03Zi>P0jnGW0>cViP3]i>D0knKW0?3Wk03/hNT0knC/0?7Qj`3af^00on3J
0<RJP`2iO500^WXl0?JnL@3oa7<0iIM=0<U_<@3KND`0dG1@0=1kIP2NFTd0Hc@/050a;P1;=S<0CChk
04Dg=01CAD80LVMS0966PP2AR8<0NG9/05E@BP0k<c00;RTU02XU8@0]9B80=RPW03hV9P167200E1<I
06X>4`2^?Cl0jFUV0>mWG`3dJUl0lfUN0?9XG@3bIE/0mFQN0?5WFP3`J5X0lFaM0?9^G`3cKf80kFUL
0>iZG@3]JE`0k6YM0>m`H@3YJU/0kW5R0>]aHP80kG9S04X0k71T0>]_H`3aLfL0lW9W0>m/HP3eKf@0
lfYP0?AZH03cIUd0lVEK0>mRF03WHED0hFIG0<QYG@1^<RL0AB0G03XV7@0^8ad0;2TT02/Z:00V9RH0
9bH[02TZ;`0R9B`082@]020T;`0T:3<092Lf02T[>P0W9SH0;B`i02`[<`0Z:2d0:RPY02TW:00V9B<0
9bLU02LW9`0Z9BT0;RL^02XN:P0]7b`0Sh>=0?O]m@3Uh>@0i>;S0?;ak`31_K`0KVUX06EMF`2ESH/0
d<O806MNG`1CBdT0=2`Z07adLP2]YJ<0`k^i0=kHf03Th=l0gmoO0=kNgP3Nh=l0h=kO0>7Kg@3cfn80
e:2/088f@03JMGd0Z3/n0;1CCP2HED`0/9::0?oeka[ooooo2@2P8?040?n001l0X23`203oP01a0:0P
l0030?n0002P8?00X23`00@0X23`4?ooool000kooooo05800?l00=Vh/`2NE4/0cVAG0>MYF`3PGD/0
g5m90=a]DP3AOEh0ZW9?0;bFLP3A]YP0iMFl0=c@`P3Uf]H0bk^l0=W4b`3C^/00R6me0>39d@2hYjl0
D4A@03P]?@0a:3T0>2m2040gB@11>DP0@SM7040e@`14>TD0S8:;0?3VkP3cj^l0lNS]0>oVj@3^iNP0
kNOY0?K`m038`LT0SXJC0:BGZ02GRIP0]j>/0?oTg`3<WhX0^giA0;Ed=03c^V/0olAc0>NIC`3@MSP0
f7M:0<iaD039NfD0TUA705H[901<<2`0B3Hb04Pm=`18?CT0AS/h044f=01DBDL0K69P08QoNP2DSHL0
Q7]f06ENF016?S/0=bd[030P800k8B80B1/N05HA501h61X0beAF0>YVHP3aIEd0lFAJ0?9XG@3_IEX0
lVII0P3dJ5/0F03`IUT0lfYJ0?AZG@3_Ie/0lVYN0?1VF`3^I5L0kfEJ0?5YG@3^IUX0l6UM0>aVFP3[
IET0kVQL0>]UFP3ZI5T0kfIL0>mUF`3/HUP0kf9I0?1QF@3^H5H0kUiE0>]KD03[GE40j61D0=mQD`3=
KEh0JRhS03dH400d8A/0;bLT02TX9P0V9RP0:BX^02HV;P0Q8bl08BLc01dT=00Q:3/0:c=802T_A@0b
=dd0>C]B03LiBP0U9c<08b<[02HU:P0[:Rl09RHX02LW:@0Y:B/0:bH/02TR:P0`8bd0;1lY09R<UP3f
koH0iN3T0>CRh`3elO00ZjNV075/K01`J6H0Xi^I0>OQh@3Idm<0fmKC0;bg]01eL6d0<bd]05mIF@33
_kh0inKT0>3PgP3Ogml0g=kM0=kLg`3Rg>00l]cS0=RV/@26?TT0e7=j09hf=`2]DTd0UeM>0;RKU@3o
mo<Jooooo`03003o002P8?00X23`00D0X23`00<0d51h0?n0003oP0000P3oP00P0:0Pl0L0oh00L@2P
8?000`3oP000X23`0:0Pl0040:0Pl13ooooo000>ooooo`1I003o003VbLD0WeUA0<eWF`3VJUh0hUe>
0>1OBP3OJDl0e7YI0;b2G039XW/0h<NX0=_;/P3Zg]00g]7;0<Jf]`3[e]d0f;g60<^_^`3RbmD0n>C_
0=g=fP2eZ;T0YIZ[0::I[02RV:X0X9FU0:^P[P2l/;`0c/;<0>oTk03cj?00h=GM0>7FgP3`in`0ln[_
0?;[lP3flOP0W9JT07=/O01nLXH0Ge1S0<Rd`03oh=`0bYZ40;amD@2fMCD0lkQZ0?o1L@3XVU00dGPl
0=YkC`3:LE40aWiX08=;?P1;9Qh0B30/04Pi=014>cH0Bd8m040g<`10=S@0@cTg04Pn?01;@Sd0IeiI
085hL`2ES8L0S8:007Q]J`1KBDL0Cc4a058P8@1E3@h0R24R0=UOGP3_JVD0l6=I0?5SF@3aI5X0lFML
0>mRF03dIed0lVEK0?1SF@3cIU`0lVEK0?AWGP3aI5/00P3cIE/0103aI5X0m6MM0?9UF`3aI5X20?AW
G@090?1SF@3dIeh0kf9I0?9SF`3`HET0kemG0?5QF@3^GUD0lUmG0080keaB0400kEeB0>UODP3RHUD0
cVaN06da9P0m6a80=R@P02lW9@0Y:B/09bP]02l_=`0Y:cL0:Bdi02L]?@0Y<4<0=cmF03e4GP0k@U`0
?49L03/oF00h?4l09BLd02@T;P0R8BT0:BP^02DT:P0Q82D0:BL/024L8`0T6R<0:1/U030S;@2PU9h0
m>gd0>COh`3Uhn@0lno^09fIV01fLG00SHN70;2WZ03>b<P0^K>c0=;:b039`Kl0`KRi0;bf]P3Je=@0
hmoN0>CPg`3RhMl0h>3P0=gMg@3Mfmh0h]cP0?;Lh`3FYk40PSa60=IgO@2J=SH0ZEA=095EB`31YJ40
0?l06_ooool00`00o`00X23`0:0Pl0050:0Pl0030=1@N03oP000oh000080oh007`2P8?080?n007L0
X23`00<00?l0ooooooooool03_ooool000kooooo01L00?l00?7Ie@2ZJF<0aVEL0>9WG`3PG4l0ge]<
0>5XD`3FNE/0/GMB0<fWP`3G_Yl0dl>Z0>GEaP39^[<0hLo?0>[Eg03?]l@0Z92P0:^DYP2XTjH0XHnU
0:2BZ@0209V=Y@1509J9W`2GRYh0WI2R07mcP@2HS9P0l^K`0;2T[P23MH80Q7R40;:X/@3`jO40n_Cn
0<W6d@1aKGh0LVf106MNL`1@@eL0jmCR0?oGeP38Sg/0`WiA0;mj>@3j_g40oKi^0>6AB03JP4@0dgI;
0<YeF02lNFH0MdDj04d/9@18=Bl0?c@`04<k>019@Ch0@SXg03`d<@11>CH0ACdj03hg<@13?3H0A3Xh
05U?C@1^H5d0S7Yh09MoO@2BKfd0S5AC07la;`2S>cP0iFYU0>]UG03`HUP0lVAH0?=WFP3]H5H0lfEK
0?9SF`3cI5`0lF9L0?5RGP3cI600lF9N0?AUH@3_H5X0lF9J0?EVGP3`HET0m6EM0080lV=K01`0lF9J
0?9SF`3aHUX0lV=K0?5QF@3`H5P0lEiF0>mLE03bGeL0keYC0>mKD@3`G580keaB0>QND@3OGe80dFmQ
07<g;@0m6Q@0>2HT02dW:@0^;C<0;Bde02`/=P0_<Ch0<CA303XoDP11AUX0ADUR0P13Af00;P0oA5X0
?D9H03LiC00R934071XW01`J9@0N72L08b8Z01lL8`0/9bh0?SLn05=9DP1]H6X0H5=M09nCW@3cjO40
hn7V0>;Ri03bl?40OWYi0<2j_023OGl0clW90:BNWP2WWYl0e<[;0=O;c@3Ib/d0gm?E0<c2`@3Fc/`0
i^;Q0>7Oh03Ogml0g]kN0=oMh03SgN40lMcR0=>Q[01n>400dWQj09Pk=P2VF4`0ReE90<B]Y`00o`0J
ooooo`03003o002P8?00X23`00H0X23`103oP0060:0Pl0P0oh004P2P8?070?n007L0X23`00<00?l0
ooooooooool03_ooool000kooooo01H00?l00?k[i`2aMW00_69I0=eXG`3QHEH0gUm@0>9[E`3BMe`0
^7mQ0>BmWP3WcK80h<jh0>GDa03VeLd0g<[80>oLh01mJGD0G4MH05a9G01D@eH0D45F0P1<?UD0CP17
>e40B3Y@04e0DP1?@U<0:al]0:bP[03fj_@0OG5k065CH01ZGVX0FDmJ0=cDg`3cl?/0T8bK06=PL`1V
HGL0@3I>08n0U@3khNd0m/?00<B3K@2nMdT0c8M60?o2M`3k^F/0fHI00>:5C03?LdX0aGAG0;MhIP1[
?c@0C2lY04Tg<`0l<S00?CPd03lj=P12?CT0?STe03Td<00j=C40?3La040i<`0m=C80@cPf04@f<`1<
>CD0Id]808QLF`2ZJVP0[EQE0<MLEP3TJ600k6IK0>mREP3`HUH0kf=F0>mUFP3]HeT0kVEO0>YUH03W
IF<0ifMX0>ETJ03XJ6T0jFMY0>aVI`3ZHV80jf5O0>iSH03/HEh0kV=Q0>aRH03]Hf40jf5N0>iSH03Z
Ge`0l69P0>aNG080jeeK03L0je]J0>iOF`3]G5T0jUUD0>eNF03WGE<0hF5F0=1]HP1h?380?AXF03h/
;00b;300;B`b030`>00`<3X0=3A0030b@@0j?Dh0=cY=030aAP0b<dP0=3M:02P[?P0U9SP07al_02@R
;`0^:cH0@Sm805YGH01[J6l0LFac07E^M@1gL7L0M6Yb06AGH@0h:cD0XYJP0??/l`3ShNH0hn?U0?Kd
m@1lNgT0Ee9D08^7R03fl_<0QX20069IFP1ODeD0Ge1C061@D`1SDeH0A3Ph0;Zb/03]inL0hMoP0080
g]kN00/0h=kQ0>;LgP3ag>40d9nU084l@@3;LW@0Tc`e0:EPD@1oDD80cKZd003o000Jooooo`03003o
002P8?00X23`00H0X23`103oP00L0:0Pl0040?n0002P8?00X23`0:0Pl0L0oh00M`2P8?000`00o`3o
ooooooooo`0>ooooo`003_ooool0G000o`00ooCb0;^6P02dHUL0ef]O0>I/G`3GGDh0gg1M0<ijH@2m
Qfl0e:jG0=VmZ03Ob;P0l]oA0<nn]037^;<0iMOG089cNP1jKGL0MVQe07AVM@1bIW@0MFQi07AWN01_
HW<0K5i^06UKJP1?@Dh0LFE_0?7VkP3klOT0`KNo06eRJP1DB580M6ee0>cVl034`<h0JFIg06MRN01G
CfH0?C570=K5e`3lg^P0iZNP0<InI@2hLT40i:1Q0?o3NP3i/f/0dg/l0=inB`3>LTd0agML0:meH@1T
?300B2lX04@e<010=S@0?SHd040h=P15?CX0A3dg03de<P0k<c00?3@a03/c<00i<Bh0@3Hd048c<017
<Rl0DS0_05/Y:01Y7ah0RR`Z0=AQG03ZJV40jVAH0?9UEP3_HE<0lFEH0>eUF@3XIEd0iFYU0=][J@2m
EEH0/TmD0;5@F@2bDEX0_5AM0=9NJ`3LH6/0i69/0P3VHf/01`3RH6T0hf5[0>=QJ`3SHFT0hf1V0>IP
I`3VH6T00`3TGVL0A03WHFX0iUmV0>QOI`3WG6<0ieaO0>QQGP3OGUP0dFiS0814>P0m6QH0?bl_038/
<00V9B/0:RXb02PX<00V9S0092@^02LW<`0S8S0081l]02/Z>00d=400?3a804Y8E@1QGVP0KfYa07ef
OP22Nh80NW=j06aWJ`1GDED0CDM;03/e>@0f;3@0;R@]02TO:02f[kL0lNcb0>?Qi03Shn<0l_;b0;Rh
^012@440d<o=0>k]j`3Cclh0fmGE08EkNP2`Y:H0dL;50<jo`P2XW9`0e/k<0>STh`3Qgn00g]kN0=gO
gP3Ogml0h]cN0??Mh@3;V9d0Q3m20<5]J`2B@ST0VEi>07UDA03Fal000?l06_ooool00`00o`00X23`
0:0Pl0060:0Pl0<0oh008@2P8?070?n00280X23`0P3oP0000`2P8?00oh000:0Pl01@0:0Pl003003o
0?oooooooooo00kooooo000>ooooo`0G003o003omo@0bijH0:eSF03>J5`0h6mO0>=dH`3BKE/0^W1N
0>>eYP3O_k@0glBm0=g9`P3Ue<d0h=;?0>CHf03Wg>00gmGM0>3Fh@3Ne=l0g=7O0=oDi03LdN400P3N
dn<09`3Md>00f<_L0<Znc03@a]40iM_V0=oHh03VgnL0fm7L0<o7dP3Yhnd0k^_f08R4U@1SGW80IUie
03@X?P25M8L0onOg0?gDf03>RGT0bGeK0;eg@`3j^GL0okmh0?2UH@3INT80eWA50=5dDP34N5h0YVmK
05li;01;=2h0A3Db048h=`10>3H0?SHd048j=`15?SP0AC`g03lf<@0203de<P1<03Xb;`0l<S00@34^
04L_;@1B:b`0Fb<T06TG6@2I<c40gVMQ0>eZH03_IeT0l6AD0>mSE03]IEL0jFUN0=iWG`3RNGD0Y4a:
0:EIF`3HTYX0`gn:0;E^O02bI780aFQk0;=<G`3CIgH0ef]h0;M?FP2[AU40Xd9=0:Y6DP2YAE40[DMB
0:a4C`2_Ae80^E1N0;I=F`2gCU`0]DaJ0;a@G`2nCU`0`4aI0<U@F@3GFUh0gf=Q0=9_I`22AS`0?AXF
02lO7`0W8BD08b8X02HV;P0c<c/0=S@o040nB@1>C5T0GE]X065OK@1_KG/0MgF207ekQP1cL7/0IV9Z
059=D@17@DD0?3Hh038/;P0a:bd0;2HX02hX:P0^:2`0;2HZ02hT;00f;cH0blK<0>k/k`80h^;R0P3U
iND06P2i^KT0iNGS0>CSh@3/j>L0oOGc07Q^K@1XG5`0Og1c07Q/KP1^I6D0g=?D0>WUiP3Ng]h0g^3O
0=cNg@3Ng]h0hMgN0?CMh@35TID0RDE40;QWH`2BB3d0TEa<08EUEP3/h]T00?l06_ooool00`00o`00
X23`0:0Pl00Y0:0Pl0L0oh008`2P8?0F0?n003l0X23`00<00?l0ooooooooool03_ooool000kooooo
0P00o`00SP3J/j`0YfEI0<Q[G03HKe`0k8Me0=5hJ02`MF`0j<S907iYKP23LWX0QGR108f1R`27OHH0
UhnJ09F=VP22O8X0PGf<07ahR@1oN8X0OGF:07Q_Q01jLHH0OGB907]bQP1fKX<0MVn107mhRP2;Q9H0
QWnA08N0TP2?R9P0V96Q0:FQ/P2HTjL0KVIm06]QN@1GBF00?2Tm0=Nnd`3ognd0k[Nd0<n4I`2oLT@0
f9QJ0?o1N03j]6`0hHi<0=]g@`3LMdd0d7EF0<UnI`2HHe40FcT]04hf<P16>3L0?S8b04Lm?P0l<S40
@CPe04Ho>@15?SP0@c`d044j=00n=c40>c4_03/`;P10<Bh0BBl`054X;01O8BH0LQTK0:Xn?03UJ6@0
kfUP0>iTE`3`I5D0jf=E0>YXFP3OJEl0fG=^0<McL@1a=3<0cInQ0?oNi03le=d0n]3N0?oDi@3XYKL0
UT]O0<5ePP2;@dl0WV9Z0=^X[`3?X:H0bINP0<>AVP2oS9<0/Wn60:UdO02ZMGl0X6]e09]SKP2JH6`0
UUQU0:9KJ`2YF6L0]5IT0:i4CP3@GUh0cVeX08Y>AP1L>CD0G4Y:05iHFP1PGfD0IVI^06e`N@1aLGd0
Kfil06i]O@1^KGl0G5]]059AH`13@540@3i<03@`?P0_:c<0;b//02/W:00Z9RD0<Rh]02dY:00^:RT0
:bLV02`X:@0Y92P09R0T03hh?03IemX0k>c/0>7Qh@3Shn420>7Qg`0=0>7Qh@3Thn40i^;Q0>7Ie`3_
hn<0c;jm0;BTY02aXj<0ZinQ09:9RP3SgMd0i>;S0=oOg`020=kPg`0;0>3Ph03SgMl0m=kP0;V1Q02F
Cdd0Z5QA0:1HC027EdT0W89e0?kel000o`006_ooool2003o02<0X23`00@0oh000:0Pl02P8?00oh00
0`2P8?070?n002H0X23`103oP00:0:0Pl0L0oh00?@2P8?000`00o`3oooooooooo`0>ooooo`003_oo
ool2003o000A0>W8`@2QIe`0ag1O0<mZF03ZRgT0^V]L0=2QV`2aV9h0J5QS06YLJ`1XGFd0KF9b06MO
KP1^IWD0K6Id05iJJ01PG6/00P1QGFh0K@1NEV/0H5M/061GK01QF6d0HEU/05aEI`1MEVP0HEY/06IO
L@1ZIWL0IV9c06=OL01UHWD0J6Ej06MRN@1WGGH0JUYd040Z?`2CM8H0omSX0?_6c03ESgh0bWeC0<Al
@P3i^W<0ol1f0>nQF@3DMcX0ggI60>1hD`3FNeh0agmW09ETD`1E=BX0BcHa04Dg=P11=CD0AC/l040f
=@12>CL0@3Tc04Dn>01:@c/0@3Ta03L`:P0o=S40?S<_040a;P16;2/0DbH[05lN8P1i7B00_Ti<0>a]
I`3[HUX0lFEH0?1UEP3ZIUT0i6YM0=M_IP3=N7D0VEUI08QNG`3ig=h0mMcP0?;Hh@3if^T0omW[09UT
N02BFFX0R59P09EWL@3jfN00nMoV0?ONi03hgN@0nmgU0?oNi`3ngNH0nmcT0?OIh@3bemh0lMKO0?3B
g03edMl0ml_L0?o8fP3o_Ld0YdMC0<9DE`3<KFP0STm8068o>`1/FUX0GeUM05=CF`1<CeP0@dEA0412
D@11@UH0?CiB03PiC@0j>dl0?3]=03XgB00h=T@0=34l038^<`0[9bH00P0_:bX0300]:BH0;2PU02l[
:P0/:2L0:BDV02/U9`0Q6al0E4mC0>GSi03Xj>P0hN7O0>?Sh@80hN7O01P0hN7Q0>g/jP3Idm<0KfEV
0<6c/`1nKVh0RWYj08alO@23MgL0SXF60>gYj03Rh>40hN7Q0=kPg`3Ogml0h=kO0>GLg`3eg^40ZFi`
0:EKFP2ZGED0WUiB07eFA`35/JH2003o01[ooooo0P00o`0R0:0Pl080oh0000<0X23`0?n0002P8?00
0P2P8?070?n002L0X23`0`3oP00?0:0Pl0030?n0002P8?00oh0003`0X23`0P00o`0@ooooo`003_oo
ool2003o000C0?KJeP2TLVT0`6eO0<a[FP3MP6h0X5A40<jWWP1B=c`0IU5J05a<E`1ODU`0G51J05]A
FP1JD5T0G5EM05QAF@1HD5/0FE5L05YBG@0205]@GP80FDmJ07D0GEAO05M?G01FCU/0FU9O05]CH01K
EF40FEIQ05QFI01HEFH0GEU`061HL01WEg40FT9J054`@`3W^L@0kjjb0=Z@Q`3BPf00b8970?>`JP3j
^6`0mZaS0>bBD`3KMT00hGA90=mdDP3DNE`0cHE]09EVE01A<bP0BCH`04Li>016>SX0@3He04Dk>P13
>SP0?cLd03lj=P12?CL0A3li03`g<@0l=Bl0>C0[03h_;015:BP0DbDX05XE601l7Ql0d5iM0>YYI03_
IUh0kV9E0>mWF03WJE/0gVmT0<meK@2lN7L0LT540<b_/`3lin`0lM[P0??IhP3ngnh0h[c;08=@H@2L
JGP0KDE@0=o0b03nind0lmgV0?GIi@3menH0n/kM0?;2cP3da]40ll_F0??Dg03fgnL0lMgV0?3Ki03e
fNL0n=KV0?oDi@3f[;/0USI20<UKGP3@KV/0PD8m04`Y9`10<3<0>3<j034a?@0c=D80>3]<03/mDP12
A5/0BD]R04E7G011@UH0@D1@03`jA`0a<3P0;R/b02h[;00Y9B80;bXW02hY9P0[9b@0:RHS02TU900^
:2P0:R@T02`V9P0Q6ad0HEeN0>cZj`3Ti>@00P3Rh^801`3Ri><0h>;Q0>;RhP3Xi^L0gMWJ0;>Z[@3F
b/`00P2ZVY/04@2XV9T0S82009ZDU03bk^d0hMoP0=oOg`3Ph>00h=kO0>7MgP3Uf]h0m]_Q09=HG02Z
I680Y61E09INC`25IEP0j=[?00800?l06_ooool2003o0280X23`0P3oP0040:0Pl0030=1@N03oP000
oh0000@0oh00:02P8?020?n00180X23`00<0oh000:0Pl02P8?00>P2P8?02003o013ooooo000>oooo
o`800?l008`0o^_W0:5fK`2aIeX0cG9P0<MZF02[F4H0i[2X09ibL`2>If`0IT=90652A`1H>cl0DCLj
04Xa=01?=ST0C3Lf04Te=00n:bL0@Bl[04Hc;`19=2l0Bc<_04hf<P1==C80B30`04D/;`14;S40B3@f
04Lg>P14>Cd0B49<04e;F@1DCfD0GU9Z06MDJP119C@0WgMo0>fg]@33NV/0dX5S0<anB03j]g40okid
0?J/H`3eX5d0kHQ@0?>4EP3/NUD0fVm?0<mdF@3;Q6h0ZGaY05Lk;@0l:B80@38_04<h=P10=S@0Acdl
040f=00o=c@0?CPd044l>013?SX0?cXd03/d;P0i<2/0?c0]04DY:01G9RT0FQ@F08HW9@3HIF00k6]U
0>eTFP3_IEP0k6MI0>=]H@3BL6L0ch9l099LG021GV80mn;W0?7PiP3`fn@0m][V0?oMk@2NMHD0S5e]
07a@G@2<KWH0n^GZ0??PiP3cg>L0om[[0?:kcP2eMHH0Y69`0:]]N02QKgX0U71j0>SAf@3ah>P0k][U
0?3Hi@3genH0omCS0;m^O@2J=3l0fVMZ0=5^J`1o@3/0EC4a044`=P0o>D<0=SE303HhA`0j?E00>ceB
03doEP1:C6<0@TAI04A5E`0g=d<0;B`d02h]<P0V92L0:RLW02XV8`0/:2D0;BTV02XV8`0X92409AlO
02/U9@0[8R<0=2//020J701^JV/0l_3a0>CTi080h^;R00d0h^CS0>7ShP3QhN40h^3Q0>GQhP3fl?80
c/?707a]L02EQhL0U8R:07]aLP2aZj/0k^g[00<0h>3P00X0g]cM0>?Mg`3Vf]h0lmOM095IFP2bLFd0
W61E08UKC02FP7<0o??/0P00o`0Jooooo`800?l08P2P8?000`3oP000X23`0:0Pl0030:0Pl0L0oh00
9`2P8?020?n000H0X23`103oP0080:0Pl080oh00?02P8?02003o013ooooo000>ooooo`800?l008l0
P?]k0=k5`02WLFL0_VmR0<e[G030EdT0jX]n0>>9P03USXL0iiJ@0>BGTP3OUHh0gYJ<0=bERP3PWHh0
gIn=0=^TS03JZXX0gk:>0>>gT03M[hH0dimg0<jHL03AUGD0diIl0=BHP03EVhD0e:6@0<RQTP30YYd0
iMKG08EkQ@1BAEP0HU5U04lf@P1cDU40ikbY0;J0G@32P4d0eHm@0?:bIP3h/FL0l:1K0?>GF`3aR5D0
lWiE0?1gE@3VK500gg1G0=9fG`36P6/0VfiK07QMC`1hIU`0J5]E04a1?@0m<Rh0?C8_040e<P16>cT0
@cXh04Dm>P14?3T0B40m03le<`10=C80@S0^04LZ:@1D8R@0H1XI09Lg<P3NK6<0jFUN0>iXFP3/IUL0
ifUL0=QaI`3?OWP0Y6YY07EBE03Pb/h0m>;X0>oMi@3cg>T0o=o]0<VP/P2;H700Qem]07IEH03Ud=L0
ln;X0?7Li@3if>P0l;W>0:YEJ@30Gfl0dgAo0<mnQ@2VJW40NU5I0>W?f03dh>T0kmOT0?CEi03oenL0
gIZY09di@P3AFel0gFIR0<m_J01g>cP0DRl`044`>00l=400>CQ503XlB`0g>DT0=CM903loD@13@e@0
?C]:03<b?00Y:2h09bHY02XY9`0V9B809bHR02PW8`0Y:2H09bHT02HU8`0Y9B@09b4Q02TP8@0_9BH0
<2HY028K7@2BSHh0m?;c0>CRh`3Shn<0hN7Q0>;RhP020>?Sh`0:0>CSh@3ThN00mo;c0;^d]@1bJ6X0
/JNX0;V`/P2OVIT0bLS60>KVi080h>3P00X0g^3O0>3Ng`3Vg>00jMWM0>[<d01kATD0]7ef08UMCP20
HU<0bkff0`00o`0Jooooo`800?l000<0D91h0:0Pl02P8?003@2P8?000`3@D7P0oh000?n000040?n0
00040>QX?03@D7P0d51h0=1@N0T0X23`00<0d51h0?n0003oP0001P3oP0000`3@D7P0X23`0:0Pl00U
0:0Pl080oh0000<0d51h0:0Pl02P8?000`2P8?030?n000030=1@N02P8?00X23`00H0X23`0P3@D7Pl
0:0Pl0<00?l04?ooool000kooooo1000o`00R@3Wc/L0Xg=Y0;YZG`36H5@0j6mU0>Y/H03XJUh0jg5V
0>M^H`3XL680ig5S0=m^G03SMV40fgEL0=]nG@3KQUd0hiMV0>jYL03h]WT0mkIf0>FTHP3?R4/0a7U0
0<AhA035ODd0_GmH08]M@`3F]ZT0aK6b05M:E01ODF80BSQ4050k>03`dKd0d:Am0<nKHP3l_g`0ol1f
0?JZH03/TU<0kHQB0?>4E`3`N5D0lG5F0>]YD`3XJEH0hg1M0=9eH`39QG80QEM804hd9`1A?SL0JeiH
08MlN02<PGd0L6EO044e<00l<Bd0@cPd04@k=P13>SD0ASdh04Hl>P11<c80@Bd^04TY:P1E8R40IadJ
0:]9@03ULF@0iVMH0>mZF@3[IUL0i6iP0=9hK`2kO7L0KDA20=:i_03hind0kMcR0?3Ki03lh>h0h;k<
081AH@2LL7d0Hd9;0=O0aP3gi^`0k]gU0?CJi`3mcn00[Ue^0;aAH@3NKWX0e7Ah0<MkO`1nC4l0c:ba
0?cUk@3`f^H0lMGT0?oDi`3l^ll0W45@0<E@EP3TIfD0g6EM0<U_I01W<RX0C2d[03/[;P0f;cH0=C@l
03`jA`0i>DD0>3Q403dkB00m?4@0=34h02h/<@0V8R<09R8O02XW8P0_;2L09B8M02HS7P0Z9R<09R8O
02<O700Z9B80;B@U02/R8`0]8RH0:QlU02dR:030^[h0k^c]00<0h^;R01T0h^;P0>;RhP3UiND0j>OU
07A_K028OWd0ETY:07=UI02IRhX0Rh1n089hMP3Of]L0i^GQ0=oOg@3Ph=h0g^3O0>3Ng`3Vfml0jmSL
0=Jg^01b@cd0[XAf07MLB@2=P6l0m?3W00<00?l06_ooool4003o00l0X23`303oP0070:0Pl0L0oh00
:P2P8?020?n000D0X23`00@0d51h0?n0003oP000oh00202P8?020?n003d0X23`0`00o`0@ooooo`00
3_ooool4003o00290?ohm037ZJ40VE]@0;QND`3TJV00lVUO0>iTF@3gKF80mFeO0?=[G@3eL640lg1N
0?5bG`3WKeL0i7EG0>=kEP3RPeD0i8mI0>VIG03dZFP0oKA`0?ngL`3i[6P0kJ9Q0>BNH`2mPe<0^8e]
0?GHb02:MG@0HdmH06YFH@0e82D0WX=h0?kK_`3^^h`0nKf10?JcK`3ZWe/0j8m@0>Z2C`3bPEL0kgAC
0?5aEP3^JUD0lFaK0>MUE@3PKE/0eGQV0<J2K`25FTX0DCLZ04Th<019?SP0CD@o06]RG@28OGT0QW]g
05=8A00n<bl0>BhZ03he<012>C@0@SPf03`^;@11;Bh0Cbd^05HN7`1`8R00/Da40>E_H`3ZJeX0k6UG
0>]YF`3ML6D0d85j08YED@2=JfX0n^KX0?7Ri`3ag^@0lmcV0?oOk02VP8l0TVAa07]AG@2?M7/0nnS^
0?;Qi`3bgNH0m=SV0?>jb`2B=480f6Ub0=UZL@3HOX00WUYK08UOH@3hgN80lmkU0?3Hi@3deND0omGX
0<mnT@2H;cd0hfIZ0>9QG03KIU`0a71Q06<a:016:2H0>RX[03<Y<@0]:S40<Rlh03/iA00j>4<0?Se5
03dj@@0d<SD0;b//02PT8`0V8Ql0:BHQ02/X8`0W91l0:RLR02XU8P0W8Ql09B0M02PR8P0`9bP0<BHZ
02dP9`0Y72<0>2dc0=O>d`3^k>d00`3Rh^806@3Shn40h^;P0>GUi@3XinD0WIRE09J<R`2DQXD0X96>
09J7Q02<OW/0T8F30>_Vh`3Whn00hN3N0=oOg@3Mgmh0hMoP0>SLh03^fMh0b:JX09AYHP2NN6/0JeU5
0:NRS`3oo?D00`00o`0Jooooo`@00?l0402P8?0;0?n000H0X23`1`3oP00Z0:0Pl080oh001P2P8?00
0`3@D7P0oh000:0Pl0090:0Pl080oh00>`2P8?000`3oP000X23`003o0002003o013ooooo000>oooo
o`D00?l00:<0nNKP0:EiL02QF4l0f6IM0?1ZH@3]H5H0m6MM0?U]H03hK5l0m6]K0?E]G`3fLV<0kfiK
0>abF`3VLeH0i7MF0>N1F@3UQUP0iheK0>F>F03bWf80mZ]Z0?VdL`3f^Wh0gjmn0?SH/P2_UX00AbhY
05<j?@16;Rh0ECPb0>o9]P3Y]iH0hYia0>ZJI@3XTE/0j8YD0>^2DP3^N5@0lWEG0>m]E@3`K5L0lVYJ
0>eXF@3YIeL0gV]I0=AgI@3;Qg@0PeQ7050i:`16>2l0BD8l04a4@@17?cd0Bd=0075WHP2HSHT0Q7Ue
06EJEP16?CP0>34[03H/:P0k;B`0?b//04hZ;01H7Al0MRHU0;]DC@3XKf@0jVQK0>]YF`3OIEP0egA]
0;UhMP1X?3d0c;:c0?WUi`3_g^@0l=gS0?cRk@3Q^lX0OeAU09ibO`1P>TD0c[No0?KUj`3`gN<0m=[U
0?WIj03MVZX0]D]E0=m^M03KLWH0agMh07U1@P3:Yj/0nnCZ0>oJh`3bf>D0o=OY0?o4f02SAeH0`diG
0>MUI`3THed0eFAF0;m_GP1N;bD0@bLT03T[:`0g;3@0=2de03La>`0i=Sl0>cQ3040mAP0k>3l0:bT/
02PT9@0]:BP0:bLT02TV8@0X8b00:RDR02`W900/8b@0:1lP02DL7@0^9BH0<RL[030U:`0[7RL09aXS
04]0B03Qf=d0kNWZ0>3Ph03Rh^80h^CS0>3PgP3Rh^00hn?S0>7Qg`3ZjND0i=oL08b2P02ISXX0UXR5
09^@SP2SVIL0Y9bJ07mkNP3Qgn00hn?S0=oOg@3Sgmh0im_M0?7KgP2nVi`0/8En08AREP1VETL0c/Zn
00@00?l06_ooool5003o0140X23`2P3oP0050:0Pl0H0oh00:`2P8?020?n000H0X23`00<0d51h0?n0
002P8?00202P8?020?n003d0X23`1000o`0@ooooo`003_ooool6003o000:0>G8`P2HHe/0aFEJ0>Q/
HP3ZIUX0jV9F0?9XF`3cIeX0mFaL0?E[GP80m6aN0700l6eK0>i`FP3VK5@0jWMJ0>MiF03VO5D0iX5E
0>J6D`3QRU@0hI9J0=NBF`3JXW<0omfg0=6/TP2hSX80/HIo0:^0N@3M[Il0n/2X0=F>KP3USFL0jhYO
0>f3F@3[OUD0kgUG0>m_E03aKEP0lFYG0?A/G03aIeX0l6QJ0>]WF03OJUT0eGIR0<b5L@2>HDh0E3X[
04Li<014?CL0Ad8o04E0?@18@3h0ASdk05Q>C01iKfd0ThV70928Q@1`J6D0CTA203X/:`0`6Q`0AB4S
05/O8@1j:BP0`5MC0>I_I`3XJUh0hfUN0=i_IP3<NWP0PTi@099bM@3iiNL0lMkR0?7Ni03cg^L0oMo[
0:UnS`2CIgH0PEUT09IgO`3jind0lN3X0?7Lh`3gfN<0omWW0;e^O03FIfh0ffia0=IhN02RGUd0PeEG
0?CIgP3bg^L0lM[T0?GEhP3oe^L0dHZL09X`?03RHfX0j69Q0>5QF03FIUP0]VYI04lW6`11:BD0=BT[
03L]=@0e;CP0>S@n03/e@@0m>TD0>cQ1030]=00Y9bX08b4R02LV900Y9B809R8Q02PT9@0]:2T0;2HX
0P0Y82<202hU:00R034X;@0a9Rh0;20Z01hB701KDET0j^CX0>[Uj@3QhN40h^;R0>7ShP3Shn40i>CR
0>?Sh`3QhMl0k^g[0<g9b01YI640Qgek07U^K021MW@0HeUH08AnOP1_JfX0j>KW0>CTi03Pgmd0hMgL
0>SLgP3ehN<0XH610;nJT@1_DdL0OG=W0>cYh0@00?l06_ooool6003o0180X23`203oP0050:0Pl0<0
oh00;@2P8?020?n000L0X23`00<0oh000:0Pl02P8?00202P8?020?n003d0X23`1000o`0@ooooo`00
3_ooool6003o000W0?ogm035YZ40ZF=G0=9/G@3PJU`0ifUK0>ANDP3YHE<0jEmB0>aRE@3`I5L0m6QK
0?=YG03cJe/0lg1L0?5`F`3[KEH0k7=H0>aeE`3YN5<0jGeF0>R3F@3KNe<0fXEN0?6VQP3aZXh0l:RB
0?>WU`3bZIP0n:ZF0>69L@3POV<0jgmR0>ikG03YLU@0kg=G0>e]EP3]J5D0lFYG0080lFQH00/0mf]N
0?5WFP3]Ie/0hFUI0=UhI@3>QG80TF9@05Lj:P19>2h0ASdf04U1?P0204@o?01904Ho?@16?S`0@CTg
04i6A01[Hf40QWik09F;R@2:O7/0JeIE050Y:P1C5aT0L1lN0<1FEP3VL6`0hFYR0=i_IP3FNG80Wf1P
05`j>`3C_L00m^O/0>kMh`3ag>D0o>;_0=RfaP1eBEX0X7B305hmAP3D^l40n^O]0?7Ni03efnH0nmOS
0?oAgP2bFVH0ffid0=EaL`38MgH0ND=30<RVY`3liN/0k][S0?;Hi@3je><0olOF0:QAH@30Be@0j65U
0>MPG03TIUX0dfQH0:eWEP179AT0=bHO034X:@0i<ST0>cDo03Ld?`0j=d80@C]7038/=P0]:S40;2X_
02PV:@0U9BD09R@U02LU:00X9R/0:BD/02dV;P0[8BX0:R0X02XQ9P0202DO8`0P02/Q:@0c:C80;BH^
07=^M03`jnl0i^CW0>;RhP3Ph>00hn?S0>CTi03Rh^80hN?P0>?Sh`3bl?40][:c07=]K@3Icm00fLo>
09nEU02VWIh0kNWX0=_Jf03Rh^80hMoP0>;Ng@3SgMd0j=cN0?[Wj@29KV`0]IfA06=CAP2XXIT5003o
01[ooooo1P00o`0E0:0Pl0<0oh00=`2P8?020?n000L0X23`00<0oh000:0Pl02P8?00202P8?000`3o
P000X23`0:0Pl00k0:0Pl0D00?l04?ooool000kooooo1`00o`002`3hjN@0TfUN0;1XFP35KEl0dVeQ
0=Y/G`3LIUX0iF]L0>1PD`3RH580jfEI0080kfMI02L0kVIF0?5YF@3^JEP0lFiJ0?9aF`3^LET0kg=G
0>]dEP3ZMeX0iGQK0>=nHP3OOF80h7aT0=eiHP3JMf80h7YT0>AfG`3XM5d0k79K0>i`FP3`KeX0kfaH
0?5ZF@3aJ5P0mVeM0?5XF03bJ5/0m6QK0?9XF`3^J5`0gfEF0=YeH`3APfl0Zg=T05hh:`1==2d0BS/f
04Pn?012?CX00P13?S/0DP15?cl0@S`l044k>`17?Sl0B40n05Q@CP1kKF`0WhJ90:QoP`2RI6L0SC/m
0;mGEP3RLVh0ffiW0=MfK`2lLF`0Wg5a0=:i_@3ahN@0kn3U0?3Li@3hg^/0omo^0:V2U02?H780Ne5O
09EgO`3jiNX0ln;X0?3Mh`3efnH0omSV0>2S/P2ZD5`0f71g0=ElOP2PFU`0PeII0?KIg@3fgnL0lMWV
0?GFi@3oeND0h9JU09<_>`3QHfL0jEmM0>IPE`3OIEP0e6eN0:9PDP108QL0<B8M02/U9@0^:c80<Rlj
03Hb@00h=480?3I2030Z=00Y9Rd09R@Y02PW;00X:2X0:2L/02HU:P0O7R@07a`U01lI8`0U7BP0<2Ta
030Z;P0h<SH0CDI=05mHG`1bJg<0EE1F08Z8S@3clO@0i>CT0>?Sh`3Rh^820>?Sh`0F0>;RhP3Qhn00
hn?S0>[ZjP3MfMX0N79b05]BD`1GCTl0M6]/0=?=c@3]jNP0i>?Q0>3Ph03Rh>40hMgL0>GLg@3Xg=h0
o>[Z085ZI@2VUXL0IE]?0=kKePD00?l06_ooool7003o04d0X23`0P3oP0070:0Pl0030?n0003@D7P0
X23`00P0X23`0P3oP00m0:0Pl0D00?l04?ooool000kooooo2000o`007`3B`;T0/Y270:enM02_MFX0
^G=W0;m]H@39KEh0dfeN0=a^G@3QK5/0jVmO0>]YF`3XI5D0k6MH0>]VE@3ZIE80jFAA0>iYE`3`K5L0
kfeG0?1_F@3dMV00lGMR0>mfH@3^Mf<0kgQT0>Q`G`3/Lf80lGAR0?5`G@3_K5X00P3`JeX0I03cJe/0
lFQJ0>mUF03fJUd0lFMJ0?9XG@3dIed0lFAJ0?9ZGP3TIUP0gg5R0=YnK`2fLVL0KS`c05He<01>>CP0
BC/j04@l>P11>c/0@Sdm044m?P12?Sl0@Shm04Do?`15@3d0@chk04Hj>P1C>Sh0MdiD0:QZK`2iIf/0
af=S0=YaK@3CL6X0ehAn07/o?P3>[[00l]oS0?3Mh`3bgN@0lmcV0?oQl03K//@0PE9V09a]O`1S?DX0
e[o70?GVj`3_h>L0l=cU0?GMjP3ldn40XF5_0;QRK@3>MG/0a7Um07@l?`2oW:00oNCZ0?7Ji03cenD0
n=KV0?o?g@2fG6P0^DI=0>YTI@3[H5/0heiE0>1XFP3?KF00UUU>03DJ4`0[81h0:bHZ02TV;@0Y9c80
<S0m03Hd@@0g<d40:RLb02h[=00X9B`09B8Y02HT:@0J5ah07a`S02XW<00k>440G5MN06iYL01^JFl0
LVea06m[K01YHfL0EU1D04@oA@0/9bd0X9jS0??am03Shn<20>;RhP0H0>?Sh`3SiN@0h^CS0>;Th`3R
h^@0jNWY0?;^k@2TWi`0Aclm05=;B@34_;X0lNcY0>?OgP3Qh=h0h>3P0>7Oh03Qfm/0i=[K0>oQh@3`
g]`0QW9Y08AhJP2;Qg/0nOSc1@00o`0Jooooo`P00?l0B`2P8?030?n000L0X23`00<0oh000=1@N02P
8?00202P8?000`3oP000X23`0:0Pl00l0:0Pl0D00?l04?ooool000kooooo2@00o`00P`3om?00m^GN
0>cAbP3J]J`0c9fC0<26NP2jMVT0_g5T0<A/GP39JET0eVmP0=][G@3SKf00iViN0>EZF03VJEL0iV=D
0>QSDP3TGdh0kVIF0>]SD`3bKE`0lFaK0?=^G@3dLEl0lfiM0?IaH03dK5h0mViN0?5YF@3`J5P0mF]N
0>iTE`3bJ5/0m6QK0?=WFP3aIeX0lFML0?EXGP3cIU`0lFUM0>QYFP3RK5h0gWQ/0<QfJ`1i>S<0GC4^
05@h=`1>?3`0Acdl04Po@011>c/0?c/j04<m?`15?cl0@cdm040j>P16@400Ac/k04lf>P1J<CL0HR<[
088`=P37Hf<0fg=`0=UhLP2fIF40RTi=0?[Ff03hfn00n=[R0?SIh@3nf^H0omOU0:I_PP2GGVl0PE5O
09]eP03mi^h0k]oT0>oNiP3`g>D0nN;/0?3?fP1d?4T0UDmI09eJH@1e@DD0SFAX0?GJg`3bgN@0lmWT
0?GEi03oenP0fiVW09Ta>P3OHF@0jV1M0>]RF03TI5L0eFEG0<mfJ023C4<0<ATG02/Q800U8bH0:bP_
02XY<@0`;CP0;R/f02XW<P0_;3D0<2dd02dZ<@0e<cP0BdI<05YEF`1_JW00P7f4089oQ@1eLgP0IF1T
04Q3A`0l>3T0=S8c030Z;P0]9Rd09b0W03Td>P3CdM@0kN_^00@0h^;R01H0h^CS0>7ShP3SiN@0iNGW
0>k/k@2b[Zd0R8B10:>NV`2AS8T0RhJ30>;Ng@3ViN<0hN3N0>3Ph03Pg]l0hmgM0>KJfP3di>D0bKNc
08QgJ`1[IEL0dLk51P00o`0Jooooo`T00?l0BP2P8?030?n000L0X23`00<0oh000=1@N02P8?001`2P
8?020?n003d0X23`1P00o`0@ooooo`003_ooool=003o000K0?oel03ki^40k]?<0=Rf[@37W9<0^HMl
0;EgJP2hL640_VmP0<M^G03@Ke`0eVeJ0>9^GP3XKEd0jfUK0>UTE@3ZHU80jV5A0>]RD03^IE<0k6=A
0?9VE@3`I5<0m6QI0?Q/G@3fJU/0lfYH0080mVYK01D0lfMH0?9YF@3aJ5P0lfYJ0?5WFP3eJE`0m6QK
0?1XFP3ZIUL0iVQJ0>AdJ03LNg80S48i05<N6P1?;2X0@bh[044c<P16?3/0@C/k03lj=`15?3d00P14
>c`0C@13>Sd0@C/m044e=`19<cH0FC8g060Q:@1e8bT0`emQ0=ieLP3JLVl0Zdi90;EYJ@3oaLL0o/_B
0?o=eP3ocMT0om?Q0>BW]P2ABEL0/6Ye081;E@3Y`LT0o^?Z0??Nh`3ag^@0l]gT0?COiP3fgN<0aZ>Z
0:n8SP2FLgL0X8J90>3<cP3gi>P0l=_R0??Ii03menH0ol_L0:ECH@2lB540jfEV0>UPFP3WHeL0gfMG
0=9/G@39Nfh0Jcde038N7@0X7b008b4R02h/;`0f=3L0@Ca204e8CP1CCU@0IF1T06iYK@1jMWL0OGUj
081lO@1gLg@0If=T05QCE`10?3l0<2h_02TX9P0T8b408R4O02PT9@0Y8RT0;R@/02<I8@1[I6/0lNob
0>CTi03QhN40i>CT0080h^;R01H0i>CT0>?Sh`3Ti>@0jNOX0>KTi@2:QXL0d<c;0=OAd@38`/80RhN6
0=KEd`3ViN<0hN7O0=oOg@3Qh=h0i]gN0>SLg03ijNX0Th5m08MkK`22OWD0moKa1P00o`0Jooooo`d0
0?l0A@2P8?030?n00180X23`00<0oh000:0Pl02P8?00?02P8?06003o013ooooo000>oooooa400?l0
01T0ooG`0?[Vg`3_dLL0fK>X0<JHR`2gOg80[feM0;U]G@33K5`0d6UJ0=a[G@3VJe`0kVYK0?=[F`3d
JeT0mFYG0?AYEP3bIe80k65<0>aOC@3`He40kf=B0>eQD03_He@0lfMH0080mFUJ02l0lfYJ0?5XF03c
JUX0lVII0?IZG@3`IeL0kfMI0>iZG@3ZL6<0jgmb0:mGB`1M6Q40D1lH040O600b6QH0=bPU03X_;P0h
<2h0@3He04<i>014>S/0@cXm048i?013=cT0C3Pj05@_=P1M8BT0M2D[0<5OH03QMG<0gViZ0<eQGP34
IF40bWEe0=:3R03GRY00hIBL0>fMZ02`GFL0]5MQ0;iWK@2UGV@0ol[=0?oAe03ldmT0o=GJ0?kFgP02
0?gIg@0Q0?oLh@3og^80o=gR0?_Qi03mh^L0nmkS0?_Jh`3oen80omCR0=nCX02K=d<0gV1T0>iRH@3/
HUP0i69D0=UXF03;L5h0_GU/07A?AP1YFeP0JVAT071^K`1iMGH0OWYk081lO@1lN7T0MG5b06YVI`1K
EeH0C4Q704A0?`0l>3L0:RHU0080;RXY00l0;b/Z02`[9`0Z:BD0:RTU02DT8P0V8R<09QlV02`R:`0S
6B40WiVM0?Cbm@3Ti>@0hn?S0>GUi@3Rh^80103Shn<04P3Uhn@0l>c]0<k:b`2CSHl0E4i>06eWI`2^
ZZ/0jNOX0>7Qg`3Rh^00hN7O0>?OgP3Ug=d0jmoO0?CTi01RDdh0SXEh0;fl]`L00?l06_oooolA003o
0440X23`0P3oP00B0:0Pl080oh00?@2P8?07003o013ooooo000>oooooa@00?l007P0ooSe0?oak@3e
hMX0i/W10=6_Y@2hRWh0/FaM0;mWF@3@IUP0h6QH0>=TD@3/JU@0jfM@0>aXC`3`KE40kfU>0?E[D@3d
JE80lFA@0>iQC`3^HE00kEmA0>mRD@3/Gdh0jUi=0>]OCP3]HE80lFEH0?1TE`3bIUT0lVQK0>iTE`3a
Kel0jWET0=I_GP26<240HAd@05<R50137a<0>QlH02/K5P0]8R00;bDT02hT8`0e;2d0>c8c03Xa<P10
=3H0BcLi05<`=P1M9R`0M2T^0;mOH03OLVd0hfiW0>A[H`3YLVX0iWE^0=mcL03LKVd0f6YY0<mQHP38
EeT0gVa/0=]_K@2oGEh0fh610=b:S03OT9<0h9FJ0>>KW`3RVj40j:>X0>n]/@3d]KX0mkk40?g6c03m
b=00olO@0?o8d@3o`ll0kin/0:@oA`35CU80jfET0>ePF@3/I5P0hVAE0=A[F038MF<0Zg=R07=GC01]
I5l0HeiK05QDD`1GDE<0AT93040l>`0d<c40;bd^02LU9P0Z:BL09RDS02d/:P0/:2L0;2PU034]:P0_
:bP0;BTV02XW8P0V8ah0:bLT02`X9`0U8B80:28V02XP:00c;3<0cLS<0>k/k`3Shn<20>?Sh@030>CT
hP3QhMl0h^;R0080hn?S0180i^CU0?7]kP35_;l0L6MZ06QOH02TWYh0j>CU0>GSi03QhMl0h>3N0>7P
gP3Sgmh0iMgK0?;ViP3A`L40ASPe0:bWV`3[j^H7003o01[ooooo5000o`2A0:0Pl0L00?l04?ooool0
00kooooo6@00o`00B03ljn@0c:BJ0:9XFP2hJe/0b6UG0=I/EP3TL5T0j71G0?1dF03_M5D0k6e=0>AQ
@`3`JTl0kVI>0>mWD@3dJEH0lfYH0?=[F03aK5T0lFaK0>eZF03aKU`0jFEF0>IRD`3SGTl0iF1A0>MR
D`3SHE40gfIC0>QiI@2mFTL0TCXY06hV5`1O91H0Db<G048N5`0_5Q80<a/I030L6`0/71`0:Q`K030P
8@0c8280?2<V04PT:01I8RP0KR<W0;5BD03SM6d0iV]S0>][H03aKf80l71T0?9cJP3`LFP0lG5X0>]Z
I03^KFL0jFYT0>Q]IP3YLfl0hW9^0=ibK`3FKVd0e6e^0<UUI`32HV<0_f5R0<1RH`2mIFP0`6]^0<Ud
N`80aWAj01H0c7Em0<MZM02fCUD0be=E0>YVI03YGUT0kF1G0>]UF@3OIEH0cf]K0<ImK02MKUh0BCD[
03Xe<@0d<2d0:bLV030/;@0Z9RL0;2PW02l^;00W9R@0:2LU0P0[:RP04@0W9R@0;2/W02/W900^:RL0
:BDR02hZ9P0/9b<0:2<O02LS800_:bX0;2PY02XT:00O61l0HEYQ0>oZkP3Vi>D0i>CR00@0hn?Q01@0
h^;R0>?Sh`3Thn<0l>c]0<o6a`1jL740WYBE0<:h^@2SWId0[ZZY0>_Zj03Ogmd0hN3N0>;Ng@3Tgm`0
i]kL0?O]j`2ISXX0Edi70<K4^PP00?l06_oooolI003o08/0X23`2000o`0@ooooo`003_oooolJ003o
001S0?o`j@2cV8d0RF1>0:U_F`2kL5T0cG=K0=1ZD`3VN5d0hG1B0?1jG03cNU/0mGYK0?1_DP3_KE<0
k6QA0>UWC`3XK5D0iFiH0>IaG@3VLf00iG9O0>YgI03YM680ifmN0>YbH@3XKeh0hFYF0=YUD@3KJeL0
ffiJ0==ZE`2ZBCH0SSDS07`Z701`;B40DAdB04/L5P147AP0>Q/F03@H5@0c6AP0=APJ03@D5`0o5AT0
Ca8I068C602WAD@0iGA^0>M[H@3]Jed0k6QI0?1/GP3aKF00kf]N0>iXG03_JEh0kf]O0>eXG`3^Jf40
kg1W0>a`IP3]LVX0kgI]0>YaJ@3ZLfd0jgA^0>I`K03WLFd0hFi[0=m/J@3SKg00hFe^0=aXJ@3OJFT0
g65S0>9UH`3[IF80kfAO0>mRF@3ZH5D0jFEI0=eWF@3=LF80aXAf07iFBP10<BX0=c<`03Lf=00a;c00
:bTZ02hZ:`0Y9B@0:bLT02HR7`0Y92409R4N02dX9@0Y9B80:2DP0080:BHQ02D09RDP02d[9`0]:2D0
:B@Q02`V9P0Z9RD0;BTZ02XU:@0R7B40V9JI0?Gcm03Rh^80hn?Q0>GUh`3Ti>80h^;P0>?Sh`3Ti>@0
hn?S0>KSi03gk^l0]:ZY0:2BTP3@`/80bl7009F@S@2h];40jn[X0>3PgP3RhMl0i>3M0>COg03Zh]l0
kNKP07mkL02DTXH0`/:j00P00?l06_oooolJ003o08X0X23`2000o`0@ooooo`003_oooolK003o000o
0>kWg`2STH<0RVeK09AWE02WKET0]FeG0<5_E`2nId/0d79F0=ilG`3LMeT0gWEH0=M[C`3HKU@0cfM>
0<QYD@32JUH0aW5M0<9_G@33L5h0aFmN0<I`G`3;LV00dGIS0=1cH@3=LE`0d7AO0<a`F@3BLed0dgMR
0<EYE031JE<0/Ea809e@?`1n>b/0JB/N05PO501<6Q40A1D=03hA300n3P`0@0d<04P<301B1`/0G@<5
0:8i=P3XLF/0jfeQ0>]YF`3XIE<0kVQH0>mWF@3bJUX0l6QH0>mWF@3^JEX0kVQL0>eYG@3bKV80kf]O
0>i/G`3bL6<0kfeP0080l6eS00D0lVmU0?1]H`3aKVH0lVmW0?E`J`020?9]J00=0>iWH`3aJ680kfAO
0>ePF@3cIUd0kV5G0>YREP3VIUT0ff]M0=1jK@2iOG80Gcdd03``:`0203@c<@0L02`Z:`0Y9bP0:RHU
02PT8@0Y9B80:bHS02LR7`0]9B<0;RTV02hY9@0X8al0:2DP02HS7P0W91l09b@P02PT8@0X8R80;bTY
02PR8P0^:R/0;bX^02hY;@36a<D0kno_0>?Sh@3Rh^00i>CR0>GUh`<0hn?S01<0i>;S0>KQhP3djn`0
i][J0:FGUP1bI6<0IeeK08n:Q`3ViN40iNCP0=oOg@3Qh=h0h]kK0>?Nf`3bkNT0blRo08F7N@1kOg40
Cm1<00P00?l06_oooolK003o08P0X23`00<0D91h003o0000o`001P00o`0@ooooo`003_oooolL003o
000m0?ObkP3RfM80`k:X09n8NP2BLEh0U6]E09i_E@2ZM5X0/G=J0;1`E@2fLeT0[VeA0:i^D`2aMEd0
^8Me0;jDQP2hT8@0/Xao0:j8N`2YPGD0Y7Y/0:=hJ02VN6P0X75O0:5aG@2RL5T0YWAK0:A`F02WLEL0
Z6iF0:Y^E02bM5d0/g5L0;1/F@2JDD00RD0a07dd9@1g;B00KB0F06LI3`1W5`h0JA8;06d>2P1b1P<0
Ub0J0>1TG03^KV<0ngU[0?AaG`3bKU/0kfYI0?1[G03[IUL0kVUJ0>]VE`3]JEX0jfUK0>YXFP3]Jed0
kVYM0>m[GP030>eYG00^0>iZG@3_Jeh0kVUM0?5[H03cJV80mFaT0?1UGP3`IU`0lVEN0?1SFP3bIE`0
kf9H0?1SF@3[IET0hVQI0=I_H03=Og80XfeQ04d_9`10=380=C4`030/:`0c;bh0;BTX02/W900Z9R<0
:BDR02`V9P0Z9B809b8O02/V8P0/9280;BDS02`W8`0Z9B40:2<P02<O700U8Ah09b<R02TU900W8B<0
:bDY02HP901<Ad/0iN?T0>SXj080hn?S01P0h^CS0>?Ui03Rh^80hn?S0>CRh`3WiNH0`;^k09J=SP2I
Shh0WiBB09N<R02JThd0UiB?0=[Ie@3Wj><0hN7O0>7PgP3QgM`0i>3M0>o^j@2a/jP0SYB606]cIP1/
kV/8003o01[ooooo7000o`050:0Pl0D0oh0000<0X23`0?n0003oP000302P8?060?n006P0X23`00<0
D91h003o0000o`001P00o`0@ooooo`003_oooolO003o00140?Wek03Tf/h0a;BT0:fHQ`2cVXH0^Y^9
0;bKRP33X8d0_Yj90<2QS@3H_J`0n>SL0?ofk@3mlnX0n>kU0?;Yh03biMd0kN3H0>_MdP3Zf/d0gL^m
0<nl[@33[Yd0^:>@0:ZDO`2RQg80UGUS095aG02>J5D0U6ID09]VE02SJ5P0YfQG0:]XF02XHe<0XEE7
09a>@@2LBSh0XTXn0:]=@`2/AC`0]THk0=QTE`3OIeT0iF]L0>U^G03^L5d0kg1O0?1aH03aLV40m79R
0?EcH`3bL600kg1O0?9`HP3aKf40lfmP0>iZF`3]J5T0l6]L0>iZF`3]JEX0k6MF0>iXF@3^IUX0lVUO
0>YPEP3_IEX20?1SF@0V0?5SF@3_HEL0lVII0>iRE@3/J5T0h6IG0=M`H@3;OG00SeI;04lZ8P14<2d0
>c0^03@Z:00e;BX0;bXW02hY9P0]:BH0<2`Y02`X9`0Y9B@0;RXW02dX9@0/8b@0:b8S02LR7`0]:2D0
;2LT02XU8`0V8R409R@U02LU9P0W8RH0:b@[01`E702BSI<0lo7d0>GUi@3Shn<20>CTi00G0>GUi@3S
hn<0i>CT0>CRh`3YinP0`Kjn085kN`1mMG<0OWIc085iMP1iMW40Hf9M0=cMf03UiN<0h^;P0>7PgP3R
g]d0jNGR0>_[h`2PXiP0HVYM08jFR`1koG/02000o`0Joooooal00?l00`2P8?030?n000040:0Pl03o
P000oh000?n000`0X23`1P3oP01X0:0Pl003052@N000o`000?l000H00?l04?ooool000kooooo8P00
o`04083mN`80P?ej3`00o`00@01ongL0NoMc07ObKP1dkVX0KnQT06GKE`1Jd4X0eLNn0=2m]03:]:T0
aj^P0<:SU@30Vhd0a9R:0;f=O@31R7X0`X9e0<=lKP35N6P0agAT0<M_G`39KU`0cFaK0=5/G03EJe/0
e6UH0=QZFP3KJU/0ffYI0=e[F@3QK5d0i6eM0>E]FP3UK5T0ifeK0>Y_G@3XK5/0k71O0>a^GP3]KUl0
kViO0>][G@3]K5h0kV]N0?9^H@3`JEd0l6MJ0>eTEP3ZHE80k6=D0>MSE03OI5D0g6mQ0<M^H01i<2@0
F1dA04TP4@0l8100=Al@02`M400T6a8071PB01PG4P0I6AH201TG600D01`J6P0M6AT07QTL028L7`0U
7b808A/N01lH6P0S7Ql09B<U02PW:`0/:S40:bP`038_=P1[J700g=WO0>?Qi@3Sh^@0i>;T0>KTi@3V
i>@20>GThP040>?Rh03QhMl0h^?O0>;Rh080i>CR00@0iN?Q0>GShP3Sh]l0g]kL0P3QhMl0203Qh=h0
hMoL0>OPg@3ckNP0V9B:06i_I01lPGL0hnKP2@00o`0Jooooob800?l01P1@T7P?003o00L0D91hI@2P
8?09003o013ooooo000>oooood<00?l003D0oo[e0?oim@3onOD0ooOb0?ock`3ok^P0n^?M0?KMeP3b
eLd0jlg30=jj/03@YI`0aiR@0<2@QP2oRgh0^hIh0;IkK@2dMFH0^7AW0;M_H@2jKUh0^fiL0;a[FP2o
K5`0`V]J0<5VE032IE@0a65A0<QQDP3;I5D0cF=E0<YOC`3AHE<0cUe=0=9NC`3BGD`0eF1?0=MRD03G
HU40dV5?0<iSD@2nGDX0YE4i09aE=`20BR@0KT/Q06557@1??AT0NG1C08=nJP1mNfl0MGA_081lN`02
07UeMP0H07QdM@1gLWH0KF]^07IbL`1oNg`0QH6209^HVP2QX:H0LW9l04]=F@17BeH0BTiG06eaNP1d
NGl0N7f308nDV02MX:D0/;6e0<31``3:b/X0f]WG0>WXi03Thml0i>?N0P3Ui>003P3TiN00hnCN0>;S
g@3Si=h0gn7L0>7SgP3PhM`0hN3L0>?Pf`3aj^80g]S<048o<020OW40d]?=2P00o`0Joooood<00?l0
:`2P8?070?n002d0X23`2P00o`0@ooooo`003_oooom=003o001E083lNP3onO<0ooKb0?o`jP3mjN80
nN7G0?GHd03bdLP0l<_20>k6_03X_[80i[R[0=j^XP3KZY`0fJ>G0=BJSP3EVX`0dY230<f7N`3=QGT0
ageb0<QlK`35MfX0_VmR0<5_H@2mJU`0a6iO0;eWF030J5X0^VAE0;ISD`2bIE<0[VQ?0:MZB`32UV/0
aJMe0<2/NP37^Xh0jN2o0>_WcP3WhmL0jNKQ0>[Vi@3VhND0iN3T0>OUj03Vi>T0h^3S0>CRi@3WiNH0
`/3108R8R@0i?D008RL]02lf?00g@4D0>TA6049<CP18DU@0C5IH04eGF01CFed0DEII059HF01@E5<0
L79_0>?Tg`3^kNP0i^GP0>CTg@3Thmh0i>GM0>?Tg03PhmX0hnKO0>;UgP3Qi=d0h>?L0>3Qf`3Wi=d0
i>3G0:>OT`18ACH0XZ2D0?Kel@0:003o01[oooooC@00o`000`1@T7P0X23`0:0Pl00N0:0Pl0L0oh00
;@2P8?0:003o013ooooo000>oooooeX00?l002<0ooWe0?ohm03on?@0ooSd0?o`k@3ojN@0onKQ0?gQ
g@3lgm/0nM[E0?CEd03cd//0k/c30>c7_P3S_K@0h;Za0=F_YP3AZj00bJFI0<2OSP2YSGD0[9Qd0<Ji
S@3Ab9d0X9]e0:JRQ@3Ge<40c<W00:JUX@2d/[<0gmgR0=7?e02`[[<0^;Fl0;jk`P020>OUj00809ZH
V@1dN7L0OhR504aGD`0c?c/0AE9;04EBB@16DdX204QECP0H04YFDP1?FUH0C5MC04UDD017DT`0BE19
0:b^Z@3Bdld0b<W10<W;`@39b/80b<_00<[=`P39cl<0alg30<W?a@38cLH0a<W20<G8_`31a;/0VibD
07YjL02;Rh40dm;=2`00o`0JoooooeX00?l0502P8?070?n002`0X23`2`00o`0@ooooo`003_oooomY
003o000M0?okm@00o`00oo[d0?ojm03ono40o??T0;fhWP2JUgP0T8m`065QA@0g>B<0Y:JH0;g0]`11
@d00@4530:2QY@30`LD0<3@g0452A`1KG600W9fO09JHU`1lOWd0K75^0;S1_02[]:l0RIB<092LTP2C
WiD00P2OZj402`2PZj<0[;Na0;2k]@2_^[@0]l:l0;c7`@2oaL40dMK@0=oRf`3Oh=X0hN;J0080h>?J
00X0i>ON0>CZh03Uj>40incU0>[/i`3Wk>H0kO3Y0?3ck03^lNX0m?O`3@00o`0JooooofT00?l000<0
X23`003o002P8?000`2P8?040?n002`0X23`3@00o`0@ooooo`003_oooom_003o000C07clN03Mgm@0
[;2Q08>:NP1HH540FVAI06EaI`0`>cD0<c`i051KE`32cLT0>DA003E1?`0mBDD0Ae9<04aED016C4P0
XJFR0?GgmP0Z003o01[oooooK`00o`000`1@T7P0X23`0?n0000@0:0Pl2X00?l04?ooool000kooooo
LP00o`003P3XknP0c]G>0;[4_02U/:P0UJ2J08NBSP1fPGd0WjZT05QUGP1;Ee<0B5E>05eZH`2NZJ<0
eM_G;000o`0Jooooog800?l03P2P8?0/003o013ooooo000>ooooogT00?l000D0k?3_0>?Yi`3Jh=`0
d]SD0=[Pg00^003o01[oooooN@00o`050:0Pl2h00?l04?ooool000kooooo[000o`0Joooooj`00?l0
4?ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool000kooooo
[000o`0Joooooj`00?l04?ooool000kooooo[000o`0Joooooj`00?l04?ooool000kooooo=000o`00
2@3emOD0g=cJ0;jn_02EUI<0MWId08V;QP2f^;<0emWF07ShM`1_003o01[ooooo=000o`080:0Pl003
052@N000o`000?l006d00?l04?ooool000kooooo<000o`002@3^k^`0dm;@0:j]Z`27QX@0GEaJ03ho
>P0T9B007QlJ01`M600202<V7`0403Xl=`1XJF@0ZJZT0>3Qg6d00?l06_ooool`003o00l0X23`K@00
o`0@ooooo`003_ooool_003o000A0=CCd@1MG5P0=3<_01lN6P0T81d07A`H01dL5`0K6QD081lJ020Q
6`0R8ad071dE01/N5`0M7aP08R<M05AEC`36al80K000o`0Jooooobl00?l04@2P8?1/003o013ooooo
000>ooooobh00?l001@0lo;`079^J`0Q7QT08b8M02DT7`0W9R409B@O028Q700R7aP09R<L02TV8@0S
81/08b8M020O6`0T91l08b@N028U7P0m?cX0YjVV0?KhmFX00?l06_ooool^003o01@0X23`JP00o`0@
ooooo`003_ooool^003o000E0:FTX00_;2L09B8M02TV8@0V9B0092<N02TV8@0]:RD0=C0/03Xe<@0i
=300=C0/03Lb;P0f<Bh0:bPT02<R7@0V9b407R4J02DW8P1mOg`0j>[Y06T00?l06_ooool^003o01D0
X23`J@00o`0@ooooo`003_ooool]003o000G0=3@cP11@3`08b8M02LT7`0U8Qd08b0K02XW8P0h<bl0
>cHb048j>013>cT0>C4_03`d<@13>cP0@SXg03lh=@0_:RH0:BHQ01hM600N81/06Q`I07UkNP3emoH0
J000o`0Jooooobd00?l05`2P8?1X003o013ooooo000>oooooa400?l000`0j=[I0=6o_@3Ha/@0gL_9
0>GCd@3Zf=H0k]oL0?KWi03mk^h0ooOe0?ofm03omoD?003o00050?3`kP1/KFP07AhI028Q700U91l0
0P0Q7QT04@0k=S80?CPd03D`;@0i<Bl0>C0a03<[:@0g;B/0>c4_03le<`11>3H0@Sdi03dh=00U91l0
7AhI01/M600b=340cLo>06P00?l06_oooolA003o00`0X23`3`00o`0H0:0Pl6P00?l04?ooool000ko
oooo3`00o`00=P1lkfl0_IjJ07A4?P1W;RL0JRdY06/]:P1_<bd0K38[074i=01b?CH0Ode8089DD01o
EU00PEUD08MRGP27HUl0SFUV08]YI@2AL6/0U7A^09UiM02HNW@0Wh5l0:>7P`2VS8P0[9JB0:nLV@2^
XIh0Z::P06m/J@0[:2D09RDP02DT800S81d06aTD034_:P12?CX0:bLT02l[:00]:BH0;2LT034/:00e
;RP0<R/U03Xa;00j<Rd0>cL_03lj=00l>c<0;RhY028S7P0S9200I6AR06k^KFL00?l06_ooool?003o
0003052@N02P8?00X23`0380X23`00<0D91h003o0000o`00I@00o`0@ooooo`003_ooool>003o000g
0?[Vi@2ML6d0MC4^08Lf<`27;B`0QRdY08<Z9P21:BL0PB`Y07l/:01j:bH0NRh[07Xg;`1k?3D0LCH`
06/b:`1X<B`0LC`f06Lb;01]>300KC/b0792>01_?SL0K3/d0750>@1dACl0IcXd05H]9`119b004`D2
024I5P0^:BH09B4N02HR7`0R7AX08QXG03Xb;`16?3/09QhL03Ha;@0a;2P09b@O02TV8@0Z9B40;BDR
03<Y9`0g;RX0>3<]02dX900o?3L0@40h02PY8`0S8Qd08B0L096AS`1W003o01[ooooo3P00o`0g0:0P
l6L00?l04?ooool000kooooo3@00o`00>@3oknd0Z8:1070_;@27<Rl0R2TW08`X:02F<2h0RBDS08h/
:`2?<Bl0R2dZ08P^;@22;b`0NRlY07`f;P1g=2`0JBXS07Di<@1j?cL0Kc@/070g;P1Y<bT0JCDZ06hg
<01`>C80N44j08mFC`1l@c`0HRdW05/e;P0O2PD09a`H02hV8`0V8Ah0:2<P02DP7@0R61H0=B/Y04Tn
?00_9B<0>34[03Td;P0Y91h09b8N02HQ7@0[8b00;RHT03D]:@0i=2h09R4M03@a;014A3`0<30X02<R
7@0O7QX0@T900=SHeP1V003o01[ooooo3@00o`0i0:0Pl6H00?l04?ooool000kooooo3000o`00>P3o
m_D0_9JC06T^:P29>3D0Vc`j0;=;BP36G5`0WCDd09<]:`2H=SD0WSho09Tk>`2L@T40SSTf080a;01o
=Rl0S4M007<c:P1l@3P0Q4U107m6?`1f?cP0O4Lo07A2>@1a?3H0K3La06le<@1e>3<0NCXe06d`:`1`
@3P0;Q4;02dK5`0_9200;RHS02XU8P0W8Ql09adK02lV8@14>CD0@3D_03P_:00h<BT0<2TS02TQ7P0[
8b009QhL02XR7`0a:RD0AChh02XU8@0h<bl0BdQ302l^:@0U92009bHR02HV9020P7iV003o01[ooooo
3000o`0j0:0Pl6H00?l04?ooool000kooooo3000o`005036ZZL0IRlZ07<U8@2Q@d40]dm>0;aBDP2i
Cdl0X3Pg0:U5@`2VA4D0U3@e09@f=P2@=C@0TSXh08Hg<P1l<B/0M2lX07Df;`1Z;bT0L3Tb0P1jACl0
:024DT/0PDm8078m=`1e?ST0M3Ld074]:P1f;b/0MBhZ08=5?P1<7aX0>QTD03HN6P0e9R<0;R<Q02/S
800]8b40:b8M030W8P0l<b`0A3/d03he;P0a:R@0;bPR038Z9`0W7a`08a/H03Tb;012?CL0;bXV048o
>P11?ST0:RTT02@S7`0Y:2@0:RTW02l^;01`K6d0YZ2P0<o9b@3`jnQR003o01[ooooo3000o`0n0:0P
l6800?l04?ooool000kooooo2`00o`009`3B^K@0JC`f06TP6P29<2`0ZdE10:Y1?P2X@3d0Xcdi09Hd
<@2>;b/0RR`/08PZ:P29:bT0RRl/08`b<@27=S80KB@N08Y9@`2JGeT0MChi07U6@P25E4l0REQC08YG
D`2BGET0Qe1=08]?CP2@Cdd0Q3Xi084`;@23<2`0TT4m084n>01F7aX0>a8<03XM5`0e8Qh0;R<O02/Q
7`0202XS7@0J02/T7P11>3<0BT4l04U0>`0m=2l0?CH`03</9P0b;BL0>cH`03dj<`12?cX0?S/f03@`
;@0Z:BD09B@R02XY9`0T8b4081XJ01hD5@0M3A00@Rh_075KG@27LG<0]ZBT0=W9b@1jm7AN003o01[o
oooo2`00o`120:0Pl003052@N000o`000?l005`00?l04?ooool000kooooo2P00o`00;P3WeM40LTU3
05lP6@1m:2<0VcLe0:Hn>`2R>SL0W3Hb09<`:`2::bL0Q2HT08PZ:P2;:b`0S2d[08//:P28:b/0PRdX
06`Q6`2BDD/0aH^70:]fL02DHeh0TV5M09=RGP2SL6`0YG1/09YRH@2CEeL0U59C08Hl?@2:=SH0QR`[
09Li=`2QBDL0Rcdi05hR6P186A<0?AXF03HN6P0_81d0;RDP02TR700[91h0;B@O03P_:P15?3L304M0
>P0504M2?014@3X0@d0i04=0>`0_;RT00P0Z:BD03`0[:RP09R8Q02HM7P0W6ad08`hC02H93P0o7b80
GS`m05Lg>01:;2`0C3<_07MTGP2hZj<0fm3:0?G/i`1K003o01[ooooo2P00o`170:0Pl5/00?l04?oo
ool000kooooo2P00o`00B`2aUI40HR/V074T7P2A<S00WcTg0:<m>`2O>CL0Tbl]08l]:P2?;B`0SR`[
08`Z:`2=:B/0TRX[08`T9@2?:RX0SS<^080`:@1]:240RTe80;^6OP2lRX<0U65M08UFD`2`OGT0W6MS
0:YbL@2JGUh0Od5206l[;01e9RT0O2HW09Tg=`2[AD<0ZT]709]3?`1f;BL0EA/G04DI5P0l7Q`0=b@P
03<U8P0^8b40;28P038X9P0/9240<RdY034/:00k=S80@3/g03/g<P0f<bh0;2/V02XY900Y:2@09bHR
02/V8`0Y7ah0:QXK03@K7`0]31<0>A0H04`O901O<SD0SVAU095[J01mFe80GSlb04db8@1K@C00KeQ8
09EoLP31[jD0hm;:0?c_j@1G003o01[ooooo2P00o`1;0:0Pl5L00?l04?ooool000kooooo2@00o`00
<@3kjND0PeiH06DR7024:bL0WcTg0:8h>02H<2l0WCLe09Tc<@2E;bd0T2XX08`T9@2D:R`0UbX]09HX
:@2F9BL0V2`/098_:P2:<B/0O34[0850>P2=ETl0_8Z30<NDT@27E540XVm/0<6>R`2fOWl0VUmQ0:IZ
K02ZJV/0YemR0992A@2<<c@0WCdn09Li>@2C>cT0V4Y80891?`1L:BH0>aDD03dQ7P10:2P0>RHW03<S
8`0c9B@0;B8P034W9@0e:bT00P0_9B<07@0c:RL0<b/X02XU8@0]:2D0;RHT02XP7`0]7Ah0;1HH03PI
7P0h41P0=0D=04dJ8@1J9Bd0G2P/0751@@2JKfT0Zh=i09UeH@2@LED0PVE706iA<`1J?b@0D3HO05Ln
:P1^FDP0Th5e0;naZ03ReLd0n^o[05<00?l06_ooool9003o04@0X23`00<0d51h0?n0003oP0000P3o
P0070:0Pl5<00?l04?ooool000kooooo2@00o`00E@3K`[d0ICH`070R7P2@<Bd0XCPe0:Dg=P2L<300
VBl_09``;P2H:RT0UbTX09XZ:@2P;2d0Xb`^0:8[;@2N9bT0YBla0:4c<P2;:2<0UD0k0>fVX038SHL0
TEmH0=:OW02[NGP0L3ho0=^WZ@3DWJ80KSDk0;MoPP3KWj40b8N;0;5_L@2JEeP0^G=e0=VCU@2nO7d0
SU1A07To?P1c@D00ICdm04TW9P1>;2d0B2P[04DX:P13:B`0?BLY03/W:@0e8b<0=28R03<S8`0e9BH0
<R8S02hN7`0a7R80<A`Q03HK800i51/0>@hE044>5@133180EQXR06/^=P1X;3@0IBhc06@`<P1fAT80
XWY^09]jH@2CMe80V81B09YoD02MP5@0UGQ>081R?01_DBl0GChR05<e7@1I?2X0LUQ909N1MP33/JL0
hmC=0?[_j@3on?D0CP00o`0Jooooo`T00?l0A02P8?090?n000P0X23`CP00o`0@ooooo`003_ooool9
003o000=0:j=R01P9R80OBXV09`h=P2S=cD0XC4`09T[;02I:2X0WBX]0:4];P2X=3D0Y2d_0:H^<002
0:T^<0180:X_<@2]<cH0Yc<d09la<0248R40^6EQ0?:]Z03=TXh0X6UV0=NTX`2BH6<0eZ>X0?6l`P1[
=S`0TeYP0=nTZ02`LgP0^h220:1YJ`3`^K`0n<740?2l_P3MZj`0TF5Q0<bPW`3`b/T0_9RH05df>@1E
<C<0D2da040P9@18:2d0DS8g04DU:0108R@0?R4S03XP900k7R<0>Q/S03@C700k5B00@aDP04P@6`1<
3AP0Da0I06@Q:P1c<3T0KBhf08U=E@1`>Ch0JCDg05LW8`1kDdT0YhM_08idC`2=MDD0TGY409ElA02M
PT/0XH=?0:>4E@2MO540Tg5;08AS@P1ZBbh0FCdU04Xa6`1D?b`0LF1@09B4M`3Cakl0n_;_C000o`0J
ooooo`T00?l0A02P8?0<0?n000L0X23`C000o`0@ooooo`003_ooool8003o001L07ceM022FeH0Hb@O
08Pb<@2R>c`0XcHi09d/;P2I9R/0X2`_0;U2AP2i@4D0_DA90;i6B02g?d40/CTk0:Ta<`2[<cD0]CXn
0;8g>P2^=cT0Y34d08`V902TC4X0jj:L0<b<RP30R8L0eJ>V0;b;S`3[^L80TUmX05hW;@3;TYP0Zg1f
0<bDU`2JIfT0l;k10>Zi_02EIfT0_YBE0>_3``3ie]@0n=WG0>S:b025IFH0d;2c0=Rh_@2XQH/0G3<k
05`]=@1P;cD0EbT/04LN8P0o5ah0Bb0Z04PH9P143al0DAHX05TF9`1X6b/0NBHf07h^>@1m<C/0N3Dl
070e>`2WLWP0TF1T07M6B@1Y>c/0GC@^09QfI02VRfd0T7U?08]e@`2ANd80UX1409An@P2EOD40VGi7
0::7DP2WSEX0XhUH0::7FP2BNE00PFM206iD<`1H?R<0E3`W071MC`2QShD0bKZc0>SJe`3nm?98003o
01[ooooo2000o`000`1@T7P0X23`0:0Pl00e0:0Pl0D0oh00202P8?000`3@D7P0oh000?n0000>0?n0
00H0X23`B000o`0@ooooo`003_ooool8003o001P06gSH@1[?3H0LR/W09@i>02M=3P0WBlb0:Xi?@2K
:Rh0[3]10;M8CP2Y>3h0^dQ=0<AAEP3JIVT0iW9c0>=/L03BFEh0d5EJ0<a?E@33ATX0_D950;E1@P2O
>CL0WTE10=F7P`3WYZ@0nlG50<BCU`2RLgT0kK_40:aiP01kA4X0]Gb30>>Z/02gPH<0fZV/0>k2``3D
ZZ/0QEmN0<2NW03ohn40jLg:09f1OP25JFP0l]CF0?SKg`3mg><0h[W109MXL01iATd0Kci209]aM@2a
Qi00HSA108=>H031QY`0Xf9h0;edR02?>Tl0W45C09Q0CP26=Ch0Pca20:U/L@2XLG@0Xg5d09IVIP2E
IfL0V6aY08QSF02iVXD0YH]Z08aeB`20JCL0RW@k099i@02FO440Vgi409]nAP2NQ4/0VGm609j3C02U
RUD0ZXiL0:^?H02WRV00RF]806E;<01K@R`0CCHT05U6>01_GE<0WY270<Vo]P3XgML0o_G`A000o`0J
ooooo`P00?l000<0D91h0:0Pl02P8?00<`2P8?070?n000T0X23`4P3oP0080:0Pl4@00?l04?ooool0
00kooooo2000o`00E01Gb4L0Jc0/08Da;`2K=cT0WS4d09d^=02V=cd0WC@h0;EBE@2lHFH0^5eR0:m<
D@2[A4L0[T540;i@D@3FHfP0fF9X0>I/LP3SIV`0fEYQ0=IIG@3BEeX0aU9C0;I=BP2UAT@0_fi[0?6a
/@3obld0V6MZ09IYK03gb<h0dYnT09=JH@2TIFd0Xf=Y0<NEV03Z`<40`ifL0<ZYY02GN7<0k=3<0?kU
h@3OalD0ZHb>0>O:cP3jgn@0]YVN0=fna03T`LL0ID550:j:SP3@/;D0jLWB0;bHYP2@HgL0k[[A0=bR
^P3CSjH0`Fn60:17F`2WC5d0PR`g0;1SJ`3>S8h0Y6QX0:ifM@2PJVX0VFMV0:=cK`2IKFH0ZH=f0;VI
Q02aTgL0OF4l05Pk4@1aCb80PEd]08aS=@2GKch0WWY809mnB`2OP4X0WX5909j4B`80WhI=00h0YHeG
0:F=G@2PQeh0UG]H07]P@`1RARh0C34L04L]701G?Bh0Lee@0:2<P`3<^k<0j]gG0?gdkd000?l06_oo
ool8003o0003052@N02P8?00X23`03<0X23`203oP0090:0Pl1D0oh00202P8?10003o013ooooo000>
ooooo`P00?l006P0_j:P07L`;P2D=SH0VRd`0:hk@02f@DL0_TmE0:@m@@2ZCU40kYnT0?nj_`3[TYH0
fgb00<eZK@2kFEX0ZDA80:Y1AP2dAD/0a55H0<eHH03IHVP0fV5V0=YSI@3EHf<0dFES0;]LFP2nKVd0
mk>b0?^o_`2<EUH0/Geo0?oAe@3d_L<0VEaS08U7C02<E5L0m/S80;^ETP2aTXd0^Y^F0;>GT`3ihMd0
l][H0>74aP3D]k/0on;V0<nb]P2XRhl0lmCI09UkO@3RaLL0onGZ0>K9dP3og^`0aifa0;:5VP3HY;/0
jZo50>JN]02NC680Ye1Q08hhA@2SDU/0b7f209eIFP2hN7P0/7=b0:ibL@2[LFl0WFMR07i>A02YOg40
c:ND0:n;L@1kF3P0JD4M07a@:@1oDRT0P54W07mD:@27GS00Tfdl09]g@`2SQ4d0Y8M=09f3AP2SRdd0
XXaB0:ZAF`2[TF00Z8eR0:B8H@2GNUX0PVA806U;<@1F>R@0AB`F03dV501D@C80MF=G09n@R@39_[P0
jN3K07ojNC`00?l06_ooool8003o03H0X23`2@3oP00:0:0Pl1H0oh00202P8?000`1@T7P00?l0003o
000j003o013ooooo000>ooooo`P00?l006/0Zh:008<^<@2N=3P0Y2le0;Tn@`2j?d@0^4=90;16BP2E
>Ch0fHbB0?J[/030JFl0aFY_0=V3Q03KRh`0hiNK0=21QP2mHfX0XTE=09hmA02[@TT0_4eD0<EDF037
E5L0d5iN0=9TH`3CJfX0egUg0?ZVY03NTY80[FIT0=>FU@3ofM`0o<_?0:e`M@28B4T0^X1o0??8`P2S
P7X0bjbW0;bPW03Rb/P0d[Zj0=Vk_@3Va/T0i<C70?oOh`3N^kl0l<gA0=Fg]`3?/[@0onOZ0<>UZ`3o
g>H0dJ^j0:f4UP2jSj80eJBg0?c1e@2cKX40R3U<08`hB026<Sl0T3m608Hg>P2=?T40[61R0:mUIP2c
JFX0^gEa0:=RG01j@CH0_Xmo0<VOR@2XP6H0OEDb07168023Db/0QeH^08AC:`27ERh0Q50[08IE;@28
Fc40Ufi00:b8E02YS540YHe?0:B?D02RSU40X8eE09^:EP2PReh0XH]R0:>;I@2NQV00UGeI07UQ?`1V
CBh0CS@I03dR3@0n91<0Dcd_0961M`3@a[d0kNCM0?ojm00?003o000>0>WXi03Ddll0`l:n0:NVXP2;
RXP0K6]W06EQH01SHUh0JFQT06ETG`1RHed0MWMa0;Nh/`3YjNLL003o01[ooooo2000o`0g0:0Pl0P0
oh002P2P8?0K0?n000L0X23`3`00o`0>0:0Pl1`00?l04?ooool000kooooo2000o`00KP2FHf80Sc0d
0:@a>02f>T80`T180;@c>02i?T<0/DA909Pl?`3QVYh0hJ2T08m7BP2VG5d0TD];09=FE@3ob/X0cYJG
0<b:S03GT9H0jIbT0<icO03:IFd0^diD0;E4B02mBd/0^4I50<5?CP35FEL0c6QX0<U[J`36KV`0[V1N
0=jSY@3ofM/0gZ>U0:aRH`2QFUP0fInK0>Jg/@3J]Jl0j<W60<2RX03[cLd0^INH0>C0a03D[K80d:JZ
0?C1aP3a_L40oLc?0>fo`@3of=T0/HR;0=nf_P3P]/00XgV50?K<fP3R]<40g:Ng0=bO[`2IDV@0OS51
07/]>P1n;SL0NBX_07//;`2A@D@0Pc4e09e;C@2XDeD0XUA@06lZ8`2<DTH0`iB20<NMQ02TOE`0OUPa
07=97`1gBR00NDXP07i=9@25Cb/0QDl]08A?;@1hAR40P50X09Ua@@2YRU40ZY1C0:B@D`2SU5T0YY]S
0:6EH`2MT6<0VHYO09j=HP2NRf40WXQO0:::I02JP5d0Rg5@07QM@01VC3<0?RLC03HU4`1@@300NVaO
0:RKTP3CbL00knKQ2P00o`004P1emG@0M7E`04Q7@P0b<B`09RDQ02l[:00b;R/0<2`Y034/:@0i=C80
>CHa03Ld;`0b<RX0;2`T02l^:@1=C4P0T92>0=CDdQX00?l06_ooool8003o03X0X23`1@3oP00;0:0P
l1d0oh001`2P8?0:003o0003052@N02P8?00X23`00l0X23`6P00o`0@ooooo`003_ooool7003o001d
0?WWi@24B4H0V3<g0;4j@02o@4L0`3Y30;`f?`31@TT0]dU<08Ta<03_/k80lLC10:]jMP1mBTH0HC8/
0<NLU@3ogML0k<W307I9B03N/K@0om?I0=F8TP3TQi40lXZA0>n2Q@3RMWH0dVAS0<IHE`2lCTd0_E1C
0;mEE`38H640[De>09=1@`3XX:<0o/C70==oO`36KV`0/V=N0=NDS03nblL0omWC0<>LU`3BZZP0iKfn
0;B:SP3Z_L@0`X^A0=V>U@3TSiH0jYFJ0=V7R@3?QH@0ijVX0<2<SP3kb]00]8F=0<JDW`3f`/h0_XRE
0=VQ[03VZ[H0YfUd078c?02SHVX0ZfU]09=<DP1k;S@0Pc8h08df?02A=3P0T3Hf08Pg=01`;2<0TUe=
0=2VSP2kV7P0XH5H08i_@026IC80O5PV07aD8`1fAad0MD4L089::@25BR`0PTHZ08189`2<GC<0WWQ7
0:Z?FP2STU`0[jE`0:>MK@2ETVL0VYI`09bFLP2LU6l0VY5Z09b>I`2LSF@0WH]S0:2=I@2OS6@0RWA?
06I?;`1@>AX0ABdA03PO2@0k9180F48d07QVFP2YVY<0d/O10>kWh@3lnO@5003o000904G5@`0I6Q@0
7A`G02<P6`0X9B00>cHb03hi=P0j=C80?cLd0080Acll00P0ACdj040k=@0l=c40>cPa034^:@0M71L0
<C0[0<72_AT00?l06_ooool7003o03/0X23`00@0oh000:0Pl02P8?00oh00302P8?0Q0?n000P0X23`
1@00o`000`1@T7P0X23`0:0Pl00@0:0Pl1T00?l04?ooool000kooooo1`00o`00M`3La<80OSXg0:4g
>`2g?TD0`DA<0;/lA@2o@4T0_DI<0;A=D01d9B40dZ2I0?_Gb`3nfLT0_9N50:N2K`3cdk`0_J6;0?CH
`P2nWXd0mmK?0?oIf032Nh<0ZTmH0<]PJ03HIF`0iG9e0>mlO`3ePH80lWio0>IbM@3HI6L0aeAG0;]?
C`2R?T00W4A30>:CU@3=KFh0dFe[0=MhM03@OGL0gIZD0?o7``3JYJ40TUmL0>:b/P3M[k40n<O=0>^^
]P2kI6d0aUiW0<EJH02nEET0XTA40>2?S`3SWj00iJNZ0>R[/02LGFD0iZN_0<64S02:CeD0ijZa0<J9
T02YJg00fifR0=fOXP3BTID0a7n408m2BP25;SH0T30h090`=02?=CD0Nb`W06l_9@37Uh<0g[VL0;VL
M02VRUX0UGY507]L9P2@JST0UfPl091J=025B2/0P3`U08U0;`28@Bh0O3lS07Q47`2@JCh0XXYJ0:ZL
J`2MVFX0J6To06=U@01jNeT0RXYX09RELP2KUG40W9A]0:6EK@2NTFL0VHYO09j:H02BNe80TgM@08MY
A@1dDc@0HD8V05@f7P0k80/0;1D503XW6@1DA3L0MVYN0:VPU`3@c<<0kncU00800?l001<0L75/01/J
5@0^:bH09b@O03Td<015@3`0?3@b03Ta;P0l=340>c<`04i4@P1=A3l0>c8]03dd;@13?3H0@c`d03@a
:00L7180G5eF01T00?l06_ooool7003o00h0X23`103oP0001@3@D7P0X23`0:0Pl02P8?00oh0003D0
X23`2@3oP0030:0Pl1H0oh002@2P8?02003o01<0X23`6@00o`0@ooooo`003_ooool6003o000K07ge
M02QOG/0R3Lf0;11A02f?dD0/cm40:doA02^BTh0WdI90:5DDP1`<bT0cZ>A0=B`U032WGL0hkj>0>S4
S@3;Z6d0cJY]0<n]L@3Ra8l0/I5]0?35[`3^[:L0Ze9F0<IDG`3?D5`0cdiG0080de1H06<0f5MM0>1P
IP3SIFT0i6Y]0>E_L03ULW80f6YZ0=A[JP3@IFH0d6EU0<=LF`2lG5T0/5aI0;M[J02iLg40/gAa0;1d
L`37Si00l<330?o7c03CNX<0bUiW0=5NI@3@GF80b5aN0=AbL`32IfP0^F9T0<iiO@2^Ee`0ZE=H0<Uj
O`35NG`0c7n20>ZMX02cIFP0^Fi`0=NDU02@DU80^Gb10>6NYP2EADl0Z4QB094Z<@2C;C80SBh`07/Y
9P1g=2X0/GiZ0<fVR@2gUG00[8aP091^@@1T>@d0L3/D08E69@2FCC@0T40^07hX7P2<=Bd0RSL/084h
9`1k?R@0MdXW089V>P2KRel0W9QZ06Y]A01:DB/0C54a06=VBP1eLUP0MW1F07meF@25MeX0RWeM0962
GP2GPe/0UgeD08AU?@1nGC@0OU`c07]J<`23HSd0Le<a06Q9:@1QA2@0ESdO04Te6@17>200AS`X04m:
>`1NFE00:RPQ02DT7@0X9200:RDQ04Q3?@0m>3800P0c:bP03@0c:bL0<bXU0516@P1;@3`0=2TS03T_
9`13=S00@3H]04Hn=011?C80;bdT07IgL@1Ph5l05`00o`0Jooooo`H00?l000<0D91h0:0Pl02P8?00
202P8?000`3@D7P0oh000?n000070?n000050=1@N02P8?00X23`0=1@N03oP000;02P8?000`3@D7P0
oh000:0Pl0040:0Pl0030=1@N03oP000oh0000D0oh001P2P8?000`3@D7P0oh000?n0000E0?n000@0
d51h5`2P8?000`1@T7P00?l0003o000E003o013ooooo000>ooooo`H00?l007/0f/G207M7A@2B=SL0
^4570;Dl@`2V=CT0VCTj0>fSX03oc<@0m;na0>blY@3db:D0a9YX0=BXJ@3]_g@0i;AP0=j/D`3Q]5L0
l/Y[0<f]E@3;[VP0bJQc0?oF^P2TIUT0S3Pf09lnA@2Y@D`0]4AB0<E;F03@CE/0eDeI0=E<E03FCE@0
dT]A0<]8C@3@DUD0ceeL0<m[J@38Kf/0^V]T0;ejLP2fOGH0/H9l0:n6PP2jSX/0b9JG0;9gN`2UHfL0
ehJ<0<9MI@34DeT0aTmE0<5<DP2^A4H0`faZ0;UbKP2eLG00/6a]0;=XK02gJ6d0/eiS0:QAE`2mHVL0
/EMI0:mIFP20<340RD=30;eoP03DVIl0ol790:QLJ02D=400WBhg09l]=`2H:C00U2/_08DZ9`1Z8AP0
YFaK0=Z^U@2dT6h0[8US09idC01/>1<0McHH08Tk9@2:<R@0SRlY094_;P2A<S00SS@/08Pi;01k>B<0
IS<D06A2702=NTl0[:Eg07n0E010@1X0De0a0:6GOP2CPF/0NUm<08IZE01gG440J54_07AQ=`1lIc`0
OFPk089/?@1mICL0PFHi09=gB01iFR`0L54S07QI:`1nHS<0H4XK06EB:01dID@0Eddd024I300Q6aD0
0P0W8Qh04`0R6QL0@chh03Td;P0P6aL08A`H02@O6@0f;bT0>c<`03/a;`0a:2<0;RDP03<X900h;bP0
>c@/03Xf;@0g=B`071lF05]MF03bl_005P00o`0Jooooo`H00?l02`2P8?0<0?n000<0X23`1@3oP00W
0:0Pl0@0oh001@2P8?060?n000P0X23`2@3oP0000`2P8?00oh000?n0000@0?n001L0X23`5P00o`0@
ooooo`003_ooool6003o002@0;6CT@1`>3L0VSLj0;/oA`2f>Cl0]D95098`;`2@BD<0n/Bh0=FVTP2l
TG40fjn00<^MH@3W]fl0gZaG0=bZB`3:VC80_90U0=bcA`3C/TX0hlE]0;FGC`3ofZT0k/2O0=FJR03;
QWl0^faa0;YNJ`36EfL0b4YH0==;E`3EB540e4U@0=A=D`3?CU80b55C0;mJF@2UE500VUM?0:UcJ@30
U8T0^IN>0;^NUP2cVYD0ZXf90:j8Q`2mRhh0_7]o0:eKH@32GF<0`E1F0<9;D@30C4l0[dE70:QEDP2f
NW80[GQd0:QgL`2[Lg@0[g5d0;efNP2kL7@0^FQ^0:iNH@2YGEl0NC<e09iRHP2XL7<0/7Ek0?jma@3K
SiT0XCm;0:Te@02S:cD0Y2`e09dZ;`2H<340NR8N07<]8`31RGP0fjnF0;N@K`2_Qf<0YG=@06lb4`1h
;AH0S3TY090c:`2?<2d0SS0^094h<027=BT0PS/W07Dm8P1H<0d0HDPO09b>G@2[YG<0L6e003`h4P1^
HdL0Z9=n07MHAP1U@Rh0PEe507QI=`1_ERd0ITlS06eH:@1bGBh0MV0_07iX=`2:Ld40TgU608ic?P27
K3L0QVdg065:5P1OBQ/0P75806iSA@0W7Pd091`D02/V8P0V7Q/09alL03H_:@15@3X0;bXV024L5P0U
81X0;bXT03df<00k=2h0=2`Y02@M5`0/8ah0;B@O03Tb:P0i=B`0?Sde01hQ6013ASl0iNGS5P00o`0J
ooooo`H00?l02P2P8?0>0?n000<0X23`103oP00X0:0Pl0<0oh001P2P8?050?n000P0X23`2@3oP002
0:0Pl140oh005`2P8?0F003o013ooooo000>ooooo`D00?l00940mncZ08mYJ01f=SH0XcXo0;<d>`2h
=c`0_T=60;57A`20;BT0[6iQ0?;4[03:Xg`0i[^60>jnO03_`780_8de0;F99P35W300dZ`m0<FR;P2e
Tb00kLaU0<VWCP3F]6X0i<240?36W03baZd0o/c50?o;dP3`SY/0`4MF0==<FP3DB540e4]B0<i=D@38
EEP0^eUH09iGD@2TLf`0^YB;0;^MT`2_Uhd0[9R?0;>PV@2UU8`0WHZ40:68Q02WPh<0`XjB0<=lPP2i
GVD0`EIL0;e8CP31BTh0`U5C09Q1?02ZKVH0XGA^09MdKP2HMW@0VgMg09mgN02VNW/0[gf00:ajN`2T
LWD0UFAW0?77b@3dal`0TeMO0;QbNP3cXj`0_5MP0;0h@@2Y<3L0ZBhc0:L^<`2O;S00Tbd[07XR7P27
@cP0gjNF0=BXS`2bRFT0/HEP0:1/A`1Z:``0OS<L08Tf9P2:<bT0PRhT07d_8P1g<1`0MSHK07E08@1U
?1h0@R@008]jAP2VW640ZjQa05eK:`0m=1<0PW9I0;2EPP1V@bl0Mdhh08MM?P1eDRX0HT<G05]04@1W
Cal0DS`;05I2401SCa`0L5/V07MR:`1hHRT0Pfdd07aW;P1gHc00PG=606mR@00Q6@H0:24F02lX800]
91l09QlI02XS7@0k=2h0AChh03</9P0W81X0;RLO040i<@16?cL0=bhY02HM5P0X7aP0:B0I03H_9`0j
=Rd0?S`e02@U7`0l?CP0fMWG01H00?l06_ooool5003o00/0X23`403oP0030:0Pl080oh00:02P8?00
0`3@D7P0X23`0:0Pl0070:0Pl0D0oh001`2P8?0:0?n00080X23`403oP00G0:0Pl1H00?l04?ooool0
00kooooo1@00o`00T@3KbLL0LdE507de=P2Y?D@0]3Dl0;Tk?`2kAdP0[4I4080a:P1^<b<0jknR0>O1
U032UUT0i[Q]0;22;@2gRb`0jl9I0?7;G03acUX0lm1H0>6lAP2lV2X0fkUE0=2aE`3M`7@0c:me0:F5
GP3gd/80olG70;iQK034CUh0c4UG0<e:DP3;CU80aEAF0;9DE02GCTP0Y7E^0;jQV@2YUH`0WXf509^=
Q02QU8`0YIR@0:^NUP2^XIT0ZiVE0:F;RP2`R8T0c96E0<9cN@2lFf80aUMN0<5<DP2mBD`0YDE309YJ
D@2TMFl0UGM_08aeK`2=NWH0S7Ad091fM`2ENGP0VG]k09IfM`2EMgT0ck:f0?OCe`2mR900Xf1Y0;QX
L@2iEUh0/d170:lj@02/=cd0ZCHk0:@f>@2M=CH0UCLe074R7@2YJEl0j;RT0<fTR02_Qf<0^XiW09MS
?01/;@`0PSPO08Th9P1d9A@0NRlL08]7<01i>Ad0L3TJ05d`4@1>:`D0VGi709n=C`2]YFL0[jYc05=>
9018?Al0U7iW0:n>N`1Q=R<0U6=:09EWAP1oEBl0LTdS08ER>01L?A40D3@505e34P1M@a00HdXD05e4
301J@@P0L5PL08Uc>P1fI380HE</028H000W80l0<B/O03<Z8@0^9Ah09ahG02`S7P0j<B`0BD0k040i
<@0`:B40>C8Z03@]9@0_9Ql0:b8K02XQ6P0[91`0>3@[03ll=@0f=Bl07ahI03@e<03?c/`05P00o`0J
ooooo`D00?l02P2P8?0A0?n00080X23`0`3oP00c0:0Pl0D0oh001@2P8?0<0?n000030:0Pl03@D7P0
oh0000h0oh005`2P8?0F003o013ooooo000>ooooo`D00?l003l0_jNW06`f=P28>3T0[3a10;4f>`2g
@d@0Xclo084a:P2SIe`0fZ^G0>RmVP39XFh0f:eY0>:eI02SMQT0jkiG0??9G@3cbET0iKi70=2Y<03g
dU/0dje00:N47P3I^e/0l]J30:nDD@3B/hD0omK30<:0P@2iEF40ceIW0<U;F@35C5D0^U1B0:mEE02B
CdT0X6mX0<:VW`2RTHT0VX^409R;P`2IShH0Vi2:09Z?R@2MTX`0Y9VC0:nQWP2cX9`0ZXb<0;^>T@3A
T9H0`6Yc0<ALI@38E5d0_TM=0;=:BP26=c80Y6]T0:=lM@2AN740RWUb08UgM@2:NWX00P29NWL0D02;
NGL0RGEf08McM02TQh/0[8680;UmQ`3:OXP0^UaT0;17C02^Ad/0/Da@0;1=DP2V@dP0XT940:55AP29
=C<0KbXS0=NQU@3[`Z`0`9ik0;BAI`2lTV80TUlb06X[2026?1l0ORhC07T[502ICcH0YF1309eN?@2C
FcP0VFY00:V2B`2QQD@0Whe=0;J/K`2<REH0B4<K05=5:P2YSgh0UFiO095MC@2?ED40VV5609eVA`2V
LE40SEdi07mB:`1oEB/0K4LJ06U75`1L>`P0KTdG08IW9`26J2P0IdhE06=A8@0a908091d6030Z6P0c
:b00=bhU03@[8P0]91d0:R4J02dV7P13>S<0BD0i044h<`0i<2/0<R/U03</9P0h<B/0?3La044l=P0n
>cH0;2/V01dL5`0/:bH0al?05P00o`0Jooooo`D00?l02P2P8?0A0?n00080X23`0`3oP00d0:0Pl0D0
oh0000@0d51h0:0Pl02P8?00X23`2`3oP0040:0Pl0l0oh005P2P8?0F003o013ooooo000>ooooo`D0
0?l008P0Z8b;074g=P2?>C`0/3e20;Hk?P2_>c`0XCll0>:CS03oe/X0h[BM0;>8I@3M/h40m/Z;0<jP
DP2aQ2L0ikYC0=V]A02bQaL0eZ`f0>6i?`3V_TL0n=9U0;F@:03E/e80gKmY0:^AA`3nh:`0ll^a09II
E02/CeT0aeQX0<=@G@2oE5`0Ydm>09IAC02VMFh0^iZA0;RWWP2KSXH0V8f709N<QP2JShT0Vi:=09V@
R`2ISXP0Vi2:09^@S02VUi@0/IbI0;FCU039UY/0dHZB0<=WLP31EV00_DUB0;]=D02I@3`0TDa70:=b
J`2GNG40T7ae08]lM`2:Og/0Qgek08=iM`22MgD0QWYj08=cM02=M7P0W7Al0:MbNP33NX<0ZU9I09]1
@`2LAdX0^FY]0;AXK02/H6@0Y5EJ09m@D`2KDE80J2TT09YZH03ie<80h<>U0;RKL`2mW6L0aIiW07e=
7@1a<PP0PCTC07hc501o=AP0Q3XM080i6@24@R00SU<[09IQ;`2QMcd0W7i20:6>D`2`Yg00OgQ:03db
4P1IAc40[Xj109a]H021AcT0Re0n07`o:P22B380X6Q?0:M_E02DHT40SEdi091T?@2;HSH0RfHa09]h
>02:K2@0HdP108ai=`1iK3L09Qh002PQ3P0a:QX0?C<Y03le:`12>2l0=RdV02lV7`0X7aP0<2LP03`c
;P16?3X0@3Pe0P0n>CD02@0o>SH0=c<`02`X9@0U8Ah081/G02hV8`2OV980l^_U0?ohm@0D003o01[o
oooo1@00o`0:0:0Pl180oh0000@0X23`0?n0003oP000oh00502P8?020?n001h0X23`203oP0020:0P
l0X0oh001`2P8?0<0?n000030=1@N02P8?00X23`01D0X23`5000o`0@ooooo`003_ooool4003o002F
0?oel`2CM780NC`k09Ln@02`>T00^STn0;i2A02P<2h0^UeF0>^RV@3maK@0ikZM0=J/Q03M[WX0dj9O
0;:4;`3icFh0fZm909a`0`3X^dH0h;@k0<:F8P3ec680cJM20:j7:03YaFl0bJUN0=NhO`3lfkX0i;BX
0:=KG`2RBUH0]UIQ0:eDFP2FD4h0ZWQa0;2>Q@2^UX`0^:VP0:RKT`2QU8h0WI:<09bAS@2JSh/0Vi2<
09Z?R`2HSHT0VHb609f>R@2UTi40]I^J0<:KWP3?V9h0bgn90;iQJ`2hCEL0_dmE0;9@C`2DAD40VUeH
09ieK`2GO7D0T7mh08b1N`27OWT0RGmm08IlN`24N7P0QgMj08mfO02HL7T0Y6mg0;Q_N02NC500RShn
09aOG02ZMg@0YgMg0:=eM`2VM7L0XFm`09i/K@25F5D0LDa60>O:_03oiLh0e[jJ0;bPKP3<[W80]99C
07542P1W;`00IRP106d[2@1g<100OS<D07`_4@1m<Q80NcH?07Hi3@1a@Q@0TG4n0;6MJ02aYG<0JEdg
04@f6@1/FTH0TG5S08aPD`2<G4h0Md<e07I1<`22BS/0SUI508U@?@2:Dch0TUm408IH=02BJST0XWlo
09Qk;@2FOR@0]jA80;n_FP1<@1009A/202hS4@0c:Q/0>BlS04]1=`1>A3/0A3/d03/b:`0[8Qd0:b4O
02TO7P0[8b409b8O02TS8`0[9bH09AlO028L700X8B00;28P038U7`0g9Ql0JeU?0;FSV@3Kb/80mn[T
4P00o`0Jooooo`@00?l02`2P8?0B0?n00080X23`0P3oP00E0:0Pl080oh007@2P8?0;0?n000030:0P
l03oP000oh0000L0oh002P2P8?080?n000030=1@N02P8?00X23`01L0X23`4P00o`0@ooooo`003_oo
ool4003o000[0?CUhP26H5d0Oc/j09ho@`2`=ch0_cU00<4l?`2h?Sd0XcPb08/g;@2fMfP0jKVS0?G<
[03>XWD0h:me0;B4>P3K[EL0oM5`0=:V?@3[_Dd0cj0/0=2Q<@3hcfD0aYlj0;J?<P3_bG@0k<b30:j?
F033XX40om_>0?Ni_02VGFP0YEEN0959C@2QK6P0^YF=0:B9P02PSX@0/jFK0<g0^02n/JT0Zj2J0:2E
S`0209jCS@80WI:<06X0Wi:<0:2CS@2NSh`0Y92?0:nCTP32VId0bhnG0<f1R`2jGfP0_EAK0<=LG`2W
CD`0SD=00:5_J02POWD0UGif08ioN027O7P0RGmm08MmO027Ng/0QWIi08mdN`2HKgL0[WEn0:aSJP2G
BTd0QDE30:=cK`2GM700TgEc09AhM`2FN7X0UgUi09QhN@2EMW@0OfIR0;JOU`3/elH0jmJk0<fgSP3:
/gl0b[9f0;jOH@2VODD0U6@d07Q35`1_=0P0L2l5070/1`1f<0`0Mc<<07Xl4`1P;`H0Hcd@09Z0C@2f
YW80Z9a/05mF;@0n<aD0HDde07]LA`2;J5@0V79M09Q]FP2=H4d0REY808]JB@29ET<0Odlh05ha4P2@
JSd0ZhU90:24<@2VSbT0^ZHf0<JdAP2OTSh0;b<002PN000^90T0;RHC03/b8`16?380DTPo05I<@`1=
A3d0?S<_03@Z:00^9R@0:R8P02HP800/9RH0:1lP02TP8@0a9bH0=RPU02/L5@0X5P`0GTPk08efJ029
LV@0VXAi0;FRV`3Jbl@0lNKP3`00o`0Jooooo`@00?l0302P8?0A0?n00080X23`0P3oP00e0:0Pl1T0
oh001P2P8?0:0?n001X0X23`3`00o`0@ooooo`003_ooool4003o000`0>C?c01fBTL0Rcdm0:Ho@`2a
=3`0`CPo0<8j?P32@400_4I20:Q7?P26?2l0JcPU0>2kX039XW/0gK9o0<FEE@2`Oc80l/=[0>JhEP3E
YS`0e:Hg0=>V>03fbf80/HXU0=ZcEP3B[ed0_YmL0=FeQ03Q_:80om;:0?o:c`3RWZT0UE9I08eBE02e
SH/0YHZ309b:P02NT8L0Wi>:0;^^YP3:_KD0cl:j0<2cZ`2^XIT0Y9N?09jDR`2RUi40WY6;0P2OTHh0
J`2OT8d0XHf<0:nBU02hTI@0`hjD0<AmQ@2jGFD0`EYN0;EEEP2GA400TU=<0:MkLP2LOWH0U81i08ao
N@2;P7h0RWin08YlO02<Mg`0U7Ek0:5bNP2gN840W55F0957BP2;De80X7Ud08mcK`2<Mg@0RgMf08aj
NP2<NWP0SGUh08ijN@28MW@0R7Ib09f<Q02WUHL0YYAn0;:OO`2o[880c;N20=>iOP3@/WH0aZIY0;ZF
F02VOT00SfD[07E84@1U=`<0GS8105he1`1>;000GD<B09n>EP2`Y6P0Qgi305mI9`1ICRD0HDlY05U3
6P1dFc<0NUdk085TA02=KTl0UWMJ095_E02CKeD0Q65109]jC@2ZS4`0XhTb0:VA8`2kYbX0b[Te0=G8
CP2KTC80Bd8002/S000`9`P0<RXE03L[6`0j;R00A3P/04i4>P1DAcl0CT<m044f<P0o=300?S@b040f
=00g;B/0<bTW03@X900e:2809aT@030N4P1kJ5T0V7i_08aaH02>LF40U7AW08i`I@2IOG40[Y>:0=:n
]@3bh=`0ooKb00/00?l06_ooool4003o00`0X23`4@3oP00j0:0Pl2X0oh00702P8?0;003o013ooooo
000>ooooo`@00?l00340ek^g07A1?P2C?cl0Z3]00;@c>`35?4<0a3Tn0<I0@@2l@3h0]T]50:1>@`1R
;Al0g[RS0<2KOP3U^i<0gjmo0<2>D@33TdT0fZaF0>2bE03caV40jl1J0<2F=02kU3L0i<1/0=2^IP34
YFh0on2j0>o6]02eQ800/gIm0:QYLP29CU@0ZWUl0:n@S@2JQh00Vhf409^>QP2KTHP0XiJ>0:bOU`2n
/JT0dLBk0=?6_@2m/:L0Zj6H0:FKTP2PThd0X9:?0080WY>?06d0WHj;09j<RP2USHd0[hb@0<F@UP2l
KGD0]UIJ0;YEF@2dFEP0TTA009aQF@2VNg@0X8=m09R5O`2@PWl0SGmn091mO`2BNGd0VGAk0:]cO02`
KGH0TDE908a8B@2FIV@0VgUg08agLP2=NgT0RWak08EjN028OG/0QGYh08AiM`26N7L0PG=b08QjM`28
NG@0RWaa08inKP2@P6L0YIA_0;bZNP37/h00dKb50=BnQ03A^G/0cK=h0<:UJ`2gV640Wh1:08MW=01Z
C1P0@B/006ID5P2]Xe/0]JiV0::PH`1^JcP0Q7U<06MF:P1/EbX0L5T_05<l4P1TCB<0Ie0V06eD;01m
I3`0Rfm8091d@P2URTD0XhX^0:VC702nZR<0d/8_0=W=>@3OeU<0`kaD06YU500b;0009Ah002`R000a
9PX0=BXD03/`7P0n<R80@S@W03la9P0k;B@0?C0W03X]900e:1l0;R4H03DW7@0U60P091@4048a7@1j
J580WhUd09=hI@2ALV00TFeM09UdI02KMVH0SVYL08IVF@2>LfP0XHf40<fl]03]hmX0P?]i00P00?l0
6_ooool4003o00`0X23`403oP00m0:0Pl2X0oh003`2P8?030?n000X0X23`00<0D91h003o0000o`00
1P00o`0@ooooo`003_ooool4003o000V0<>RW@20AD40WD520:dl@02f=3d0`SU00<Tn@`34?Sl0_d90
0;m?C@2@>C80PdY10>k6^P2ZPg80fJnG0=JYS03N[XH0dZ=_0<bLG036UTX0^8/h0;bD?030VTL0j<9g
0=ReL`3V`hd0Y8AM0=^iX03fc/@0SE]L08i@E@2QH6P0VfAZ0:j4QP2QR8@0W8f609b?Q`2ISXP209^@
RP0909nDSP2RUi40[::I0;bbZ@38_[D0c<:i0;fcZP2YWiH0WY>=0080XIJ@06l0Vi2<09nASP2OShl0
Y8j@0;JBUP33Qh`0/UeT0;ADF02iEUT0ZDi=09Q:AP2QIf<0[HAn0:>7P`2JQh<0TX20095kOP2HMgh0
XGAk0;AeOP2QF5l0T4E908Y=C02NMW@0TgUh08UgM@2:O7/0RWin08IjNP28O7`0QGUi08EkNP27Ng/0
PGEe08UnO02;OG`0QgUf08EhLP27NG00Rga^08ioJP2CPfX0Wi1c0:fMN`2iYgl0akB:0<jiRP3F`8h0
d[^50<fgO@35/740XXm:08=e:P2SVdP0_KYY0=;CS@1gN480PGUB081aBP1]Ec00OF8g07aQ<P1oIS00
Mf4W065;4@1]FAh0JE8L05U10`2>MBD0Zi@^0:fH6`2hYQH0eLH[0=O>;P3KeSX0g]U90=??D@2SWc@0
KVPB03hg000[8@008aX002HM000_90P0=BL=03@U400b8a00>2LE03DT4P0b8a00<B8=02`N1P0O4@00
=bP7071R?`1fIdH0MFE<08YeHP2CNFX0Vgi^0:60L@2BKUh0UG1N09IaG`2DLEh0QfIC08=WDP2;L5d0
]:6A0>cOeP3onO@01P00o`0Jooooo`@00?l03P2P8?0>0?n003l0X23`:@3oP00<0:0Pl0D0oh00202P
8?020?n000030=1@N02P8?00X23`00H00?l04?ooool000kooooo0`00o`00=03om_D0[hV608I5@@2O
?d40ZcHl0;Xh@031>400bD170<<k?`34@T@0_4A5098/:P36N7@0ol[30?:f[P3g_K40mKb[0?NoZ03P
[X/0djAh0>:eOP39WF00g;Ec0>S4QP2fTE`0cJIk0>NnWP3:WHH0fJVM0?oOf`3X/K@0UUAH08i@E@2`
OH80RfMW061;AP2;OWH0WY>=09^@RP2ISXP0V8f709^@RP2MTX`0XYVB0::HS`2YWiH0]J^R0<Fk/P3>
a;/0^[2W0:fRW02RUi4209jET01F09fCT@2QTI40YHf=0;f@T`2jLgT0^f5Z0;YGG02iEUT0XdU809M=
BP2^Mg80Yh1k0:B7P`2GOgl0VGan0:1gO@2ZMGd0]W1h09M:D02HCTl0RE=?09enN`2>NGH0S7al08Yl
O029OGd0QGUi08IjNP25NgX0Qgel08QnO@23NGP0QGUi08IjNP28O7`0PgMg08UkN`27NGL0R7]e08Eh
L024MV/0RGa[08]lI`2APfT0Vha]0:jNNP2gYW/0akF50=C3R`3Da8H0c<1h0<FlK@2i]VL0dMF;096E
GP1HE2h0THAT0;>OOP2:KTT0Q6Dg099e>`2;L2/0OFLL08Ic9P1mJQh0H4/008Ub4P2/Ub@0/9`E0:nN
2039^a`0gMD]0=SD:P3Og3L0g]i20=kMD@3HeU/0_;MC09NA?@1/IAd0DTd=03/b000g;000;b<002/M
000^800202dO000H038T0011=0<0JelS09Z>DP1lKcX0MFLj06aK?@1`GTX0LU];085WFP28Jed0VgY[
0:B0L02OO6T0T71I08a/D`2?L5@0WGmS08=/D01bH4`0QWIW0;bbZ03Yh]X0oO[e0`00o`0Jooooo`<0
0?l04P2P8?0:0?n004@0X23`:P3oP0000`2P8?00oh000?n000080?n000H0X23`1P3oP0050:0Pl0<0
0?l04?ooool000kooooo0`00o`00:P3nk^h0W71_08Do?@2T?d<0[cPn0;Tf?P30=cl0c4=;0<HmA035
?4<0ad160;@f>P35DUD0eFe/0=McL@3JOGP0f8Aj0=>;O@3d_JT0e:R=0>BiV@3BZXH0`Z1j0=^hV02/
Qfd0o=710?G0^03_ZjP0mJj/0?bh^@3oa/L0^gUj08Q>C@2iT8h0YhV706aID`1EB480LFIP09J=QP2K
THP0W8n709^@RP80W96;02X0WY>=09nDSP2TVI<0Zj2J0;V/Y03>a;/0d/Ro0;N^Y@2YX9T0XIRA09fD
S`2NThl0XY>>0;2@T039TYL0_G1h0;]PJ@2lEed0]UAE09]3@@2OEU00[WM`0:^2O02QOW`0XGYk0:Uf
N`2iNh00Zf1W09I7C02@B4T0Tf5M09EiM@2=NgL0RG]j08MkN`29OGd0Q7Yi08EkNP29OW`0Qgaj08Il
N`25NgX208EiN@1?08MkO@22MWP0QGUk08IjNP25NGT0QGYh08MiMP28NgD0PWE]08IiL025Mf`0RGa/
08alK02CQ6d0WHia0:fNM`32]8<0bKj00<FnNP36ah40`LR>04=57P1]J4/0fl^b0:Z<LP1^BRH0^IAM
0;fKD@2ENR40WHLT08]g501`G@00XXlI0;FR7`2fY1@0/J460;f_3P3GcBD0h=`b0>KT>P3TiD40hnE6
0>CTCP3ViET0h^9P0=WIG`3>cET0][940:NS>02GTR`0RhHR08V17`2;PB00T8HT09V@:`2_XS/0_[5;
0<BgF@2TU4L0K5`Q069>:@1XDS/0PFMH08IZG`1oHeL0QfUN07eQD`2HOVd0Qg5J08ahG@2<NET0TgmJ
0:F@I`2NR6<0O6M805Q4:`1RDd00QWa`0<C0]`02003o01[ooooo0`00o`0C0:0Pl0H0oh00C02P8?0a
0?n000H0X23`203oP0030:0Pl0800?l04?ooool000kooooo0`00o`00CP3`g]h0T61P08Pl?02V?d<0
[3Dk0;di@034?TL0aT190<0j@`33>dD0bSi70<a0B@2j<cT0/2db0;8f>02_>c/0XcXf07dT7P2lOW<0
k[j`0:^0L03;XI40lljm0:9lL@31V980omGG0;mlP`2J@DL0Z4Q<0:]BE031Lg40XEeJ09]VHP2eT8X0
YXn909f>R@1oM6h0F4e705M>A`2=PW/0XIB>09jAR`2NThd0Vi2:09nDSP2NThd0WiB>0:2ES`2RUHd0
ZInF0<:h[`3;`[T0_[F^0;2WX02UW9D0X9N@0:6FT02WTHl0_9>G0<j?U`2lK7D0_UmW0;]FFP2dE5D0
VD4o0:IPF02dNG40[gah0:miN@2gMgP0`WYm0:=AE`2KBdh0QClo09]_J`2CNgL0Rgai08QmN`80RGem
00@0QWak08EkNP28O7`0Qgel0P26O7/208MkN`0508AhNP25NG/0Qg]m08EiN`26NW`00P25NG/208Ij
NP0[08=hMP25NWP0QgUh08UkN025MVl0QWIW08]kH@2FQeh0Wi1I0:>JE@2m_W80gnJW06aaB00m?1h0
]:RB0>_@_@1U@R@0V70l0>>mLP3;[TX0`jhk0;VY<02[W1d0^:PQ0<>c8P2o/1T0`K<D0;^^2P39`1H0
gMX]0>KT>@3WiS`0h^@k0>;U?P3WjDH0j^a=0>[[D@3`l5X0k^iL0>WXFP3MgU@0f]YD0=[GEP020=KA
D@0K0=K=C03FbdL0c/130<BgA@2`WdL0TWdl05i77@1J?RH0KU5107YLD@23HUT0RVaR085WFP23KEl0
L5m;08UmH`2GS6h0WI1]09^<H@2QSf40[iU`0:FAKP1cHT@0>c0L07A^H03jnOD00?l001[ooooo0`00
o`1W0:0Pl0T0oh0000<0X23`0?n0003oP0008P3oP0080:0Pl0P0oh000`2P8?000`00o`3ooooooooo
o`0>ooooo`003_ooool3003o000]0>;=c024DE00Rcdm0:Ln@`2/<cX0^ca00;`mA02k?TH0]ce80;8f
@@35?dX0aci80<TmAP39?TD0cDE90<U7B@35CD`0[4A108@g<@3_]:h0f:VS0?gBb`3a`[`0fjn^0>Vh
^`3oam00]65[0;Q9DP35CU@0]4Q80;1BD02ECTP0/Weg0:j=QP2NRX<0Vhj809fBSP2HSHT0LVMS05A9
A022M740WHn<0:>HU02PUHl0WiB>0080WiF<02`0WI>:09jCS@2NThd0Y9ZA0:bRV@2g[:H0_[>]0<6g
[P2f[:<0Z9^E0:>ASP2[Shh0`iBJ0<f>UP2jJG00]EUN0;MDE`2fE5<0X4M30:=CC02mKf/0a7Id0<Yi
N037LG80Ydi@0:1@D@23@T00XGUd091mM`2<OW/0QWaj08Z0O`29Ogh0S85o08MkN`27OG`0Rh6008Z0
O`26O7/0R7al08]oO`25NgX0QWak08QlO080Qg]k00@0RGem08EiN@25NGT0Qg]k0P26NWX0AP25NGT0
S7im08amN02;Nfh0T7mU09F4F02;Ncd0U8Tj0<C3J@3LhiL0];Z:05=B<`1iLE`0m>;>0;NIO@1dCa/0
fKEY0>38GP3D`T@0bKde0<W1<037^bL0b[lU0<_19038_Qh0a[dH0<S15P3Fdb@0h^0c0>SX>P3PhSH0
gMld0>?U?03Ri3/0h^<m0>7R?03UiT00iNQ30=_P?P3Lh4D0fme;0>OVF03Nfdh0f=960=K:?`3@`d00
`K8m0:nL@02HPCd0LE@X06119@24HDh0NUI:06@n=@1jF4h0OV1F07eUF@1gIeP0J61=07=]E`2PVX00
ZZ=o09^@H`2IS5l0Z9]_0;V]Q@1WH4<0KVaG0?Whl`00o`0Jooooo`<00?l0202P8?030?n000l0X23`
00<0oh000:0Pl02P8?00BP2P8?0_0?n000P0X23`2@3oP0000`2P8?000?l0ooooo`0?ooooo`003_oo
ool3003o000]0=2h^01lAT@0T3i00:TnA02`=ch0^ce10;Hk@02a>D80mXN@0>MdP@2k?DT0bD5=0<Tm
B03:?DD0bci60<Lo@`35@dD0_TY;08DV9037NGL0om7A0?Vl^`2GDE80j:b^0?o>e03jZ[D0[DUE0<]?
F@3:BDh0`D];0:i<B@2JDdd0^HR10:J8P02MRX@0W8n909J=R02JSh/0W96=081eL@1>@3d0FTm;081e
L@2JSh/0XYNA0080WI>:00<0WYB;09bAR`2MTX`00P2SVI00M@2WW9H0ZIjH0;R^Y@37_K@0dLBn0;RZ
Y@2]V9L0[h^=0<fHWP3SVZ40]EiV0;eMH@2nFUX0bFYV0<EXH`2]DTl0/UMF0<YZJ`30H640]EMG09e7
AP2FCdd0Z7Ue09UmN@2BOGX0Sgek09>4P@2>P7l0Sh6008eoOP2<P800SH>208UoOP27OG`0RWin08b0
P02;Ogl0RGmn08IjNP28O7`0RWin08]oO`27Ng/0RWin08QmN`2;OG`0Rgej08aoN@2>P7L0T81a0920
I`2FQ5`0TX5908em<P2]XD/0cLY]0=3CR03Qi;L0M7=G06mXEP3Fa[L0k]Jn07iM<P2gUU40mMek0>?C
FP3MdD/0fm=40=[@?@3KdC`0dl`e0=;<<03Abbd0d/d[0<g:8`3Jec00h^4i0>?T?P3Rhcd0h>8i0>7S
>03QhcL0gn8c0=kQ<P3Ohc@0g^8f0=_Q>@3MhD80i^M=0>?RBP3Je400e<Tf0<k1=`2n[S@0]J4n07iW
6`1[CAT0KD`Y09A`EP1eCc`0OEI707EA@`1WAcX0G48e065@@01ODT40Iem806YTBP2IU740]Zn30:FM
KP2KTf@0[:Ei09^IL`26QVh0nOWa003o000Jooooo`<00?l02@2P8?030?n000h0X23`00<0oh000:0P
l02P8?00B@2P8?090?n00080X23`9P3oP0070:0Pl0T0oh0000<0X23`003o0?ooool03oooool000ko
oooo0`00o`00;`2hW9/0PDM5090l?02/?d@0/3Ln0;/n@P2d>d00[CY10?N=U`3/PXh0/SY60<A1C`38
@Dl0b3m90<@kA@3:@DT0bD980<M6BP2[=cX0Ycdo0?NDU`2jEeX0ZCm309Lk?P3oYZ/0jHB<0;U7C`3=
Ce<0adU:0;i<B`2RAd80WemF0;Z?R02RQX80W8Z609j@S@2JSh/0Vi2>09Z?S@2QUY80SH:006UNG01:
?cd0FE1;08ImN02GSXL0X9F?0080WI:<00<0WY>=09^@RP2MTX`00P2OU8h09@2UVY@0[:6K0<Fj]P3G
b<D0c[Vh0;fKW036UIT0hijS0;m]L`3GNgh0aFEV0<MYI`3BMg80bF]Y0:m@CP2hE5@0]e1A0;mHF@2V
B4H0ZUID0;EdL02YNGD0Y7eh09YkMP2JOW/0VH5o099oN`2AOgd0TH9o0922P@2?PH00S85o08n1P02:
Ogd0SX>108b1O`27OG`00P29Ogh0C02:Ogd0Rh1n08eoOP2;OGX0SWmj08n1N02BPG40UHAZ09N5G`2D
Pdl0U89009:2=02[WD@0`kYM0<c8K`3BdI80h>2n096<N@2;PWT0/j:J0>SA`@27JTX0ZXYG0?[PT`3b
fg/0kme]0>kNI@3[gUh0j^1L0>CLE@3Qfe40h=Y>0=OEA03JfD<0emHn0=[I@03Kg480i^M;0>7SA03N
hC`0h^Hj0=oS=03Lh340gn<d0=kR=@3QiCT0g=lj0>?T@@3[idP0h=Xl0=G;<@3<`2h0_JlZ0;ZX>P1h
H`X0Ech0085S<@1lG3<0H3dM08YVC01ZAc40Tg9O07mSCP1PAc40ED0U05e::P1_HCh0KF<j09jGJ@2g
/h@0/Zio09BCI`2ZZX@0ZJbA0?Sil@00o`0Jooooo`<00?l02P2P8?030?n005L0X23`2`3oP0030:0P
l2L0oh000P2P8?000`3oP000X23`0?n000090?n000030:0Pl000o`3ooooo00oooooo000>ooooo`80
0?l002H0ooKd09anO024Ad@0UCln0:Tl@@2]=3T0^Sm30;]4BP2_@TP0eG5k0=eiQ@2Y>dP0]d9B0;]2
D@30@e40_T1<0<=4C`32@4X0`T=:0<97C02[<ST0_4M=0;a3BP3<CUD0WBP^0<EBF@3DFf80bDaB0<m>
DP34BTT0_U9?09U4?@2^Lf/0]I2809f5P@2IRXL0VXb909V>RP80VXn=0880W96=09nDTP2QUiD0RGmm
05iDDP18@C/0F55;08AkMP2OU8h0XIJ@09fBS02KT8X0W96;09Z?R@2OU8h0XiRB0::GT@2XWIT0^ZZX
0>?;b`3[a<L0hjnc0<f6S02bGF80cW9e0<m_L03KP7d0iHZ70?2BT03JNgT0b6AT0<=LG@30FEX0^5AD
0:U;B@2YF5D0ZF=Q0:mbK`2_N7D0ZGQd0:QlN@2SOGX0WWaj0:64P02IOGX0VH1l09MoN`2EP7d0TWmk
09>1O`2BPh00SGmn0923PP2>Ph40SX1m08n2NP2EQ7X0T81a09N6M02DQ6X0V8IR09B2E02@P4@0TX@m
0:FEA`2`Y500akeX0=;;N`3Mf9@0c/^N0:^YU02LUHd0XYRG0:>EU033/:X0KE=206U?;P2UREL0_j9P
0=k1L@3`eGX0m=Yi0??NM@3`gW00kn=]0>gSJP3ZhV@0in1N0>?OF@3Ofe<0emA90>_ZFP3Wie<0h>57
0>7S@03RiC`0hNDi0=oS=`3NhSD0gN4e0=oQ>03PgcT0i^<n0=oJ=P3Dbb/0c;lU0<Vj:`2n[c00ZILY
081[401mIQP0PfXW07QN8`2OPe<0MeX`089V@@2JP5d0M5Xg07IO=P21Jc`0JUHS06IH901fK3/0Q7i>
0:^WN02VYGT0Z:Z30;>fV`3hnO400?l06_ooool2003o00X0X23`1`3oP01A0:0Pl0d0oh001@2P8?0d
0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`800?l00:X0mncZ08Y[J021A440Vd=10:Dk?@2Z
<cL0^4540;Y9C`2Z@TT0VS]30;1DG`2TAU@0Z4MH0:m:G02]AUL0/4EE0;55E02b@Th0]dE?0;U5D02h
@d`0_TE>0<A5CP3<ATl0bD=<0<8lA@3?Ae40d4U@0<]8C@30BTX0[TY809M8@`2iQ7h0[8^409j9Q02G
RX@0Uhb809Z?R`2HSHT0VXn;09^?R`2JSh/0VI2;09fDS`2MUY00S8B105M?C018?S`0IU]G08b1O@2S
UI80Y9NA0:>FT02NU8/0WI>:09jCS@2RUi40Y9JC0:bJV02lW9d0gZfa0?Bc^@31L7L0/UEM0:];C`2e
DUD0gX200?ZOW03gW9T0lYND0?JKVP3UQhL0dG9`0==aL02oFe/0[di>0:97AP2MAD@0Wd]90:IEE02Y
GEd0/F]Y0;1`KP2eNgT0[GYg0:elN02WNgP0XWai0:21O02MP7`0Vh6009N2P@2FPh<0T7ij09>2NP2L
S7`0VXU_09R6HP2JQe`0U8==08mm?@2DPc/0X9=40;6VEP30]fX0eLb70>3GW03Hd:40`K^G0:FQSP2M
VYD0WiVK0:2JWP2SVJ40/jN[08ekN@1A>340IDHd06]6:`27Fc@0/H=B0=Z/L@3X^gL0klYj0?CEN`3d
fWT0mn9k0?CTM@3biG<0lnQb0>kVJP3]j6P0j>IO0>GTEP3Phd`0g>130>CV@`3RiD00g^4j0>;U?03M
gcH0g=he0=_J<P3Fdb`0eLdX0=339@3CaR`0cl<a0<^n=02i[2`0ZY/V0:2?9@2LS2d0W8Xf08il=01a
GAh0NVL]07MT:P1fHRD0/9iF0;RVFP1eHa`0IUDM07EW=P1iLD80`l2E0;2bS@2][iL0n?Wa003o01[o
oooo0P00o`0:0:0Pl0X0oh00C02P8?0=0?n000030=1@N02P8?00X23`00H0X23`<P3oP0000`2P8?00
0?l0ooooo`0?ooooo`003_ooool2003o002Z0>3Bc`1gEU40QDI109Hn?02V>cd0[CHj0;U2AP2_@DH0
XCa20;5HH02dHVd0/6Ib0:ISKP2MG6X0ZFUg0:ASL02IEf<0[V]g09aFHP2XGFP0[e]X0:90C@2]?T/0
aTIA0<e3B`3=@4P0cCe70<m3B`38ATX0_T]<0:=7A@2SGeX0^8b60:66O`2NS8D0VHf709^@R`2JShX0
VHf809Z>R@2LT8`0VXn;09V@R`2JTH/0Vi>=09nGT@2NUXl0UHb807mfL@1VG5P0HUIB06UKF024MW80
VXj909nDS`2NThd0XIJ@0:BET@2^TY<0_XfB0=VAVP3<Lg`0bEmX0=5OIP2nBDl0/Si30:Hg>@2bAdP0
^UED0<5MG03=JfX0g7Yi0>9oO@3UP7h0iX1n0>AmN`3FL6l0cVQW0<eWI`32G5h0/Ti?0:i8BP2aCDh0
[De=0:iADP2bFU/0[5UH0:mRH@2`JFL0/6m/0;5dM@2aNg`0ZWml0:21N02KPG00VhEW09J3EP2IRE00
WHe<0:bNEP2l[V<0b;ee0=38QP3?bI00a/6B0;VeTP2[YXl0YJ2C0:6LUP2PW9h0Wi^R09nKX`2MVJ40
X9VT0:BKY@2gZk@0Pg9i040X;01C=SH0FCL`05H`902NNFD0d:bA0;NELP2kVg<0^IQ/0<FVL03B]GL0
g;ik0>;5O03Yc7d0kM9k0>oGN03ag7@0k]aZ0>[KH03XfUP0j=eD0>OND03Vgdd0hme:0>;MA`3OfdD0
g=M30=[C@@3GcSh0eL/k0=?;>03EcCP0d//e0<k7<`3?aSP0a[hf0;Za<02bZC80XYT/09B:8P2=PA`0
OG4;0:6E9`3JcU/0gm=S0:nRAP1iKB40K6@W0;^hQP2b/XX0[K2D0?Sil@00o`0Jooooo`800?l02@2P
8?00103@D7P0oh000?n0003@D7P20?n000<0d51h1@3oP0000`3@D7P0X23`0:0Pl0140:0Pl0030=1@
N03oP000oh0000T0oh000P3@D7P=0:0Pl080d51h;@3oP0000`2P8?000?l0ooooo`0?ooooo`003_oo
ool2003o000S0>WKf01kG5L0OdA009I0?`2W?Cl0[3Di0;Q0AP2eA4X0XCa20:eFGP2iKWD0VUeT09QW
K@3S^l@0kL[A0>2ob03VaLh0lM;J0<f]^03V`/h0[gn=07`jB024;Cd0^dUE0<Y4C@3?@d`0c3m70<]2
B@36B4/0]dU:09i:B02bMG00[XV30:6:Q02MSXL00P2JShT08P2LTH/0WY6;09f?S02JSh/0WY>?09Z?
R`2HShP0W9><09ZARP2KTX/0WYF>09fDS`2PUi80W9>>08EjMP1MDTh0Bd0n06AIE@29OWX0X9F?0:VG
U@2bSHh0di2G0=EiQ02hB5@0bTeE0=A>E@3FCE@0ee1F0=1=DP38BTd0_4540;4j?02V<S<20:/k>P15
0;i@C`3@I680gG9a0=]aL@3IKfl0i7Yj0>QnOP3[OGh0hg1c0>5ZKP3BFEh0ae1D0<MDE`2oCU00/dI9
0;18B@2YADL0YDM80:18A`2LEE40/81b0=>`VP2mYH<0/ii_0;f^M@3>`hD0gM>F0=K<U`30]h`0ZZB4
09nJQP2QWI80WIZE09fIVP2MVj00W9VP0:2KY@2PVZ@0X9^R09fHW`2OVZ40WiRP0:ZPZ@2cZ;00Bci7
02hO9P0Z6ah0;b4Q04/m?03ahn00n>WT0?[Wh@3ggm/0i/c20<R[V@2gUh00[ha`0:IoGP2XPeT0^iEV
0<>PJ03E/W80fk]`0>?4L@3Yc700k=1_0>kEKP3bfW00l=Y]0080km][01X0lMma0?CTL`3UeUl0fm1D
0=cBCP3Id4<0f=0m0=gF@03HdC/0e]0l0=G@@035_c<0_kTa0<S1?02k]Bd0_;DY0;J_803IdT<0knM[
0>;KL`1bJad0ZjU^0;6cQ02Y[8l0n?Wa003o01[ooooo0P00o`0D0:0Pl0@0oh009@2P8?000`3oP000
X23`0:0Pl00N0:0Pl0X0oh005`2P8?0Y0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`800?l0
02@0k^?Q07iRGP1i@Sd0TdA00:0l?P2W=3T0^3m50;M4B`2X?d@0XDI=0;U/LP2MGf@0R5MK0??;d`3`
d=D0Sfie08Y[L@33YJd0_jB]0<ZZ]`2RNHL0Yfel09Q;F`2`AE<0adQC0<Q0BP39@4P0bTA;0<97BP2c
BdX0UTQ40;N0N@2ZQh40W8R109f>R@2NThl209Z?R`0909b>R`2KSHX0VHn;09Z?R`2PUI40UHb709^B
S@2JSh/0Vi2<0080W96=07T0Vi:=09jET02SVYD0Vi:=08ElM`1NDdl0C44m06QJE`2ANgd0^Hb@0=b?
U`35HF/0`DaE0<e;D`3DBe80eDQ>0=Y>D@3GC540eDeA0=A;DP3>BDh0dDiC0<]:CP2l?T40]CTk0:hf
=`2a?3`0`E5@0<mSH@3HK6X0eVYX0=Y/J`3GIfH0fVQX0=EQI03=FUd0cemN0=IXI`3HKVh0df]Z0<UQ
HP30FEX0`emO0:=BB`2YM6@0oM[60?;J`03FaZ@0dL>P0<boW@2j[i<0Z9f709nFQ@2TVi80XYZG0:6K
V`2TWZ00X9ZN0::MX`2PVj80XI^R0::KX`2RVj80WYNN0:6JX@2PVJ00WYNN0;R_]01LDeP0:AhR02dS
900^92<0:bHR0=SCc`3ak>H0k>CQ0>kThP3ain@0l^OQ0??Tg@3]g=80hlo40=K0/P33[IP0/YZ20:f@
LP2TPf00Xh1F0:b4D`2dRE80bIeP0<jQGP3T]Fl0k[mg0?75NP3meXH0on290?oRQP3ihGl0lmie0>_J
J03Te5X0hMAB0=_AB`3Hd4L0dle30=S@B@3>aSl0d<Po0<O0<P3>b3H0a;hZ0=SA@03RfeT0m>j008b5
=02PWV40/[B30:FXR@3ino000?l001[ooooo0P00o`0D0:0Pl0D0oh008`2P8?000`3oP000X23`0:0P
l00P0:0Pl0L0oh007P2P8?0T0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`<00?l002P0^:>N
07=8@P21@3X0TcXl0:0g>`2e@4H0^TE;0;A7C02Q@DD0/F5T0:IUJ@20CU40hKRl0?WIg02SPhH0=aXN
081UJP3G_<D0Wh6=0;bFX`3Q[;`0TTiM0:51D02oAe<0a4E@0<M3CP33A4/0_d]<0:a8AP2DBdD0]hEn
0:J8P02MRX@0VX^609Z?R`2KTXd0VY2>09^@SP2ISX`0VY2;0P2KT8`0102IT8/0W9>>09bAS@2JSh/2
09bAS@1<09ZARP2IT8T0WiRB09bES`2NUI00WIB?08j3P@1_Gel0J4iA09EQI`3EOhP0^4iH0<U@E`3:
C4l0cTY80=9<B@3CCTT0dda90=E;B@3DBTX0ede=0=A9C03FCU00eDeA0=5<C`3<BT`0_T120;<h>P2_
>CT0[3Pi0;0l?@32CTl0eF5R0=5OG`3BGV40d5iN0=1RH@3@I680g7=`0>R0O`3/Q8<0ggMd0<aTH@2e
GeL0VEi@0>o:^03/e/40aKBP0:ZMS02PU8H0YI^B0:JMV02QVIL0YijQ0::IWP2RW:00XifQ0:6KW`2T
WZ80XIbR0:2IX@2QUil0WYRL09fGV`2NV9`0W9JJ09VCU`2_ZJd0Lfea02`V:00f;Bh0:RDR020M6035
a;l0l_7/0>KUh@80j^KU02/0k>OT0>gUh`3^i>80lNKT0?;Wh`3ei^40mnKN0?7MdP3ZdlD0hLBd0=2]
V@2mV7h0]8][0:1dD@2EICl0YgI=0:IeBP2lT5d0eJ]a0>BlOP3]ahH0m]6:0?SEQ03deG/0m]Qf0>oG
J`3Xdf00jMIN0>_KH@3Qe580fm990<c3=P3MeDH0d<Pi0=[?B03Jd5L0l^^109VB@@2=S4/0/kF30:BX
Q`3hn^l00?l001[ooooo0`00o`0D0:0Pl0H0oh008@2P8?000`3oP000X23`0:0Pl00P0:0Pl0<0oh00
9`2P8?0O0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`<00?l002X0imcH07URFP1nDdX0T4a;
094g>@2gATd0_4E;0;a9CP2X@D@0Z59C0;9^K`2=EeL0XGMh0?KDd`3WbLT0Ide>0:J=T@3ig^D0Z8NB
0;J<V02WLh00NSY:0;5LK02/@e40^dMD0<A8D`31B4l0_Te?0:Q9A@2HDd`0^X^50:F6P@2MRXH0VX^8
09V>S02JT8h0Vi6?09bAS`2JSh/0Vi2<09bAS`2KT8h209Z?R`0j09jCS`2HSHT0WI:<09nDSP2KTX/0
W9><09jET02KTXd0WIFB09jFT`2UViT0Y9BD0::5Q`2OI6X0`FI]0;Q9D038DE<0`4]20;U5=P2b@Bl0
_d`i0<aC@P3@DT<0dU130=5;@P3DBTL0eTY90=E9BP3GCDd0e4a<0=I>C`3>B4T0b4I80;ln@P2o?T<0
[S0d0;Ll?`2c>cd0^4530<5?C`3;GU/0cVEQ0=A/J@3FL6`0eFm[0=afLP3@JVH0`V]S0:i^I035Vhl0
^YjC0:JCS02UV980WYBB0::IVP2PVYX0WiVK0:FOX`80WiVM01/0X9ZN09fHW02OVYh0X9ZN09fFW02L
UYX0ViFI09bFVP2NVIl0W9NM09VDVP2[YZX0Q7n303Da<P0^:2P0:2@Q01HE402c/Zd0mO7^0>STh@3Z
iN80kNCR0?3Rg`3bhn00lnCO0?;Ug`3`iMl00P3ai^00903aj>40lNKP0??XhP3ej>00m^GM0?3NdP3Z
elT0gLJh0=2cX`2nWH`0VGEQ08]OAP2@HDD0WVU:0:]cD034Rf00cYAR0=^SJ03U/6`0j;MX0>c3J@3[
bf@0hlaH0>?DD`3;_CP0f/a50>3>CP2lYc`0WI0Z0?[aU02ZXe<0Q8=00;NjQ@2RYXD0nO_`003o01[o
oooo0`00o`0D0:0Pl0H0oh00M@2P8?0H0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`@00?l0
0340W9:906=8?`2JJF@0XUQI0:]2B030BDl0^TE;0;9:B`2SAdP0[F=T0:9VIP23DE00b9jO0=:_[@36
YZL0_Z2R0>71aP2PNh<0`iRR0:McO`29C5/0]FQh09XjB02Z?T/0/ce90;a5B`2nD540X4E00:5NEP2^
PG/0U7Mc09^8Q02HRXL0V8f;09R>S@2HSX`0Vi2<09R=R@2LTHd0W96?09^@S02ISXX0VXn;09bAS@2G
S8P0WiB>09bAR`2KTX/0WIB=0080W9>>02<0WYBB09bBT02NTi40YI6B0;2=T@3=RY40]e=K0<5>D`37
DDl0]dTl0:a8<02eFcT0V40H09Xm502`CBH0^Dh/0<ID>@3;DSl0ce520<m=@03BCD@0eE170=A<AP3H
CDX0ddU90==;C@3DC500dT]A0<]8C@32@DH0_d550;@i>`2b?3`0ZcTh0<MGEP020<mQH01@0=Q/JP3E
JFH0_61J09aHC`2@HET0[Hj90:FAT02SUiL0X9FI0:2GW02PVYh0ViJJ09VCU`2NV9`0W9JH09^EU`2K
UYX0WYVM09jHW02NUid0WiVM09jGWP2KUY`0VYFK09fHW`2HUY/0YJ>X09RCV@0l=c/0:RHW02HR8@0D
40d0Y:2M0?KakP3]hn80kn?S0??Qg`3hh=`0jm;=0>cCcP3fh]/0m^?L0?OVgP3diml0k^OQ0>_Xh`3/
j>L0jnWZ0>kZj@3`jnP0l^[X0?GZiP3fin@0n^OS0?KKe`3[b<80ejnW0;n@R02`Og40XFaJ08UA>P24
B2`0MS`F08595P2;FQL0_IQ00=k3F03SceH0ckdm0=[6B`3Vd600Q6/K09B39`3kl9H0]k1O07in>02c
]Wl0XZJ30?Sjk@00o`0Jooooo`@00?l04`2P8?060?n002H0X23`0`3oP01C0:0Pl140oh0000<0X23`
003o0?ooool03oooool000kooooo1000o`00Z03Cc/P0FD]207ACC03CW9T0YTQ=0;]8C`2iAT/0]D]=
0:U9B`2SDED0[fU[07i0@@1H8240S5UH0>fo_`3[`L80ejn`07Y=DP2bPhT0ejF^09aWL@2gLGd0[e=P
0;U?F`2P:c@0/ca00;]?C@2UBd<0XEiF0;V=Q01^DD/0L5mH09B5PP2ISX`0VXn=09R=R`2KT8`0Vhj8
09f@RP2MSh`0XI>@09R=R@2KT8X0WI:<09^@RP2KTX/0VI2909fBSP2NThl0WI:>09bAS@2OU980WI:@
09f?SP2ZTI@0/HJ=0=65S`2lCUT0b4mD0<UBCP2_B3T0WdX[0?RfPP3W/W00aI140:5U702=B@P0TdH>
0:19702aDB/0^e8b0<ID>@3;DcX0d4lm0=9:?P3DBD80eT]80=E9BP3EBD`0f4]A0=E:D@3CB4l0cdI=
0=5:D037@TL0`Sm50;dl@@2i?Cl0ZRla0:`f=P2U@Sh0RD0j08eJEP2bT8h0XXj?0:6EU`2PUI/0X9JN
09bFVP2PVYh0VYBF09fGV@2LUi/0V9>G09^FW02MV9h0UY6G09^FW@2KUY`0WYVP09^FW@2MUj40WY^T
09ZGWP2[ZJh0Ui:H02hX;00/9RP0:R@V01H@402QV9T0o?3`0?7QhP3dg^00o=kN0<RRW`1dBdL0^96:
0?oKd`3Yb;l0]iV?0;bSW03bhm`0k^KS0>gYj03/j^/0inKT0>STh@3ZiN80knSR0?C[iP3djN<0l^KP
0?;Ug`3diN00nNKR0?SSgP3bfM@0kLk90>2j/@38WH`0cJ6407aD8`2hU4X0kM5^0>G>FP3E`DP0h/]K
0:B;9`1/DPL0[9`m0?S^S@2n^Eh0O7da0;2eN`2NY800nO_^003o01[ooooo1000o`0E0:0Pl0040=1@
N03oP000oh000?n001l0X23`00<0d51h0?n0002P8?000`2P8?080?n00540X23`3`3oP0000`2P8?00
0?l0ooooo`0?ooooo`003_ooool4003o000W0?Gfl@1oN700ED8k0=6ZX`2JC4d0/dY?0;Q9C`2cBD/0
/dmA0:58C02C@TP0TDE906dU:@2=BDX0b8R80>FYZ@30QHL0JB/^08e@E@3W[;80j:^b0;mhP@2?<ch0
XCM10:8Z<`2e?T80_U5>0:=9@@2SH5P0_Y:90:23O@1bGeT0FT]807MYJ02DQXD0W96?09^=RP2LShT0
WY6;0080Wi6>0480WI:<09jCS@2NThd0WiB>09ZARP2MU8d0WI:>09bAS@2MTXh0W96=09jCT@2OTI00
YI>C0:V;S@2iR8h0d7V60;m9E@3>CE80bTe;0<=GBP1l9`P0cYEN0?_AQ@3`cG40lLm]0>>jGP3;VdL0
/GT^09=B3P2EB``0VdTA0:Y>6`2lE2/0aE8c0<aB>`3ACcl0cd/o0==:A03GBDP0g4]@0=U8C`3GATd0
fTYC0=I6C`3IBE80dTE=0=58C`3<AdX0`TA70;A9B02BA400TEYG0;JCT@2UTI80X9FI09jEVP2NUih0
VYBH09bFVP2KUIT0VYFI09jIW@2KUY`0W9NM09RCV@2LUih209fHW`0T09nJX@2OVJ<0VIJO09bIXP2P
WJ@0][6g096:T@0Y8bL0;2HX02hU:00H3a80Wi>E0?c/k@3cf]d0nmgM0=^b/@1kBdL0/X5l0>fn^02m
T8X0L4Q005@_9P25J600m^GN0??Zi@3`j^X0dlo>08n;RP1aKFX0HUeJ07IaK@2KU8h0dlc60>kYi@3Z
iN80k>SU0P3/in@05@3`j>H0m>CU0?SNg`3og]T0on;B08IR?P2mW5T0lmIh0>K?F`3Ud5T0_JPo075J
001oJ0l0hM=Z0>_SN03;afH0NG/X0:^aM@2LXW`0nO_^003o000Jooooo`@00?l05@2P8?000`3@D7P0
oh000?n0000P0:0Pl0030=1@N03oP000X23`00<0X23`2`3oP0000`3@D7P0X23`0:0Pl01<0:0Pl0h0
oh0000<0X23`003o0?ooool03oooool000kooooo1@00o`00E@2n_KP0CDDj09j8O@27C4T0W4940:a5
B02/A4D0/DY=0:A4B02H>d<0USa509a2B`2;<SP0Nb8V07`V:@1j92L0QBX_07TS9P2QDE@0fX^@0:1>
E02>:S@0^T]D0<58C`33B4d0_Ta<0:Q9A@2NEe40_Xf60:J7PP2TSh`0QgEc061BD@1A@d80MVQW09J7
Q02OT8d0WHn<09j@S@2OTHh0XiRD09jCS`2LTHd0VXn;09^BS@2JTH`0W96=09Z?R`2MTXh0W96=09j@
S`2QTI40YI2?0:f9S@31R8l0c6ij0<Q:EP3ABU40cDQ90<iGC`2D=1`0XEd^0?o?S03_c700j/mT0>oH
J03cg6X0lMMY0=fnE03H]E40_Y<e0:9`6`2BDPP0VDT>0:]?802cBb@0aE8c0=1B?03ECD40fTa80=M6
B@3KB4h0fDI>0=U6D03JA4l00P3JAdl02P3FAd/0e4a@0<ACD@2TDdl0Uf1M0;FAT@2VTY@0X9FI09^E
V@2OV9l209bEW080W9NM0480WiZP09^HW`2IUYd0VIJM09nIX`2LUj00ViRO09fJX`2PWJH0W9VR09bI
X02WXZT0]Jje08EoP@0Y82<0=2/^038W:`0L4180XI6D0?[Vj03hfmd0n<o=09e[I`3c_[P0hJjZ0:=d
KP1hCDH0XGYc0<naY`3bfm<0nncW0>GKf@1jLW00KfMU09RCS`2JUI40RHB107MbK`16@Ch0EU5>0<[3
`@3Xhn00cLS40=SEd03Uh]d0j>?P0>gShP3ehN80n]kK0?oQeP1iF3L0^IYI0>gCM03Ud5T0kMeS0:2A
:P1RE000/jHe0>KNH@3TgfL0em9Z07mo:@2Z[fl0UYYe0?Sjk@00o`0Jooooo`D00?l02P2P8?020?n0
00T0X23`00<0oh000:0Pl02P8?007`2P8?000`3@D7P0oh000:0Pl0030:0Pl0h0oh00C02P8?0>0?n0
00030:0Pl000o`3ooooo00oooooo000>ooooo`D00?l002/0l?7/08V6O@1UFe40LTe6095=C02GATD0
Vd0o09Ph>@2O?3l0V3Dj09Pc>`2nEUl0Z3m60:@i?`2G:S00U2L]0:Hg?P2X>d40WCHj0:10@P2/Be80
XcQ00;4lA036BE40aTM>0;e9C02/B4P0WeAA0;f8Q02UPWh0WhZ50:>AS`2JS8/0MVQW04m1@01DATD0
Og5^09f?S02QTi00Wi6>09nDT02QUY80WY>?0080Vi:=07X0V8n:09jCS`2KT8`0WI:>09bAS@2NT8l0
Z9JF0:^ATP2cRXh0b8VB0<ERKP3<BUH0dTM>0==8B`3?D4X0/d@c098g603RVVP0mKec0?K:L@3cd6X0
mMMY0>kDI@3/eF<0lma/0??IJP3_dfP0gKMD0<BA>02aLRD0We4?0:Y<6030DRd0dE<l0=E;@03EAD@0
f4I90=a6C`3I@dh0eSm80=i7D03MATd0f4E;0=96B@33Cdh0Y5=?09ENF`2cTI00YY:D0::GV`2MUi/0
XijT0:2IX02QVZ40WiZQ09jIX02MVZ40W9VP09fJX@2IUYd0X9ZT09bHX@2OW:<0XIjW09nLX`2MVZ40
YZ6W0:FNY@2e[k<0M6]^02HM7P0d:R/0<bLY02<C502gY:H0on[/0>?5a@23Ee@0Q51;0=2KU@32SHT0
fjRT0?;3_@3ec<H0mmWA0?_Tg03nlN/0]ZbZ01/A3`28OW`0mo3Z0??/iP3dk>T0kn[W0=oJe`2CRX/0
N6m_0<6i]`2:QH40Qh9n08j;QP26PWl0^;2^0?[Wj@3fg]h0o^;G07aM@02gUeX0lMIk0>CAF`3[h680
Qg/;08Qn2`3Le4l0g=U>0>OTH`3Jf6/0PH4[0:J[J`2AUVh0n?[]003o01[ooooo1@00o`0g0:0Pl003
0=1@N03oP000X23`00@0X23`3`3oP01:0:0Pl0h0oh0000<0X23`003o0?ooool03oooool000kooooo
1P00o`00J`3^kNT0a/>l08IgKP1dCdT0OTU3095>B02NCDX0WD9109`e>02M<3D0[S]20;4j@02l@dX0
_D590;e0B032@dh0`TA?0<17CP32CE<0^DE>09`T;@2b=Cd0bDE@0<Y8DP31B4l0/dY>09e<B`30Q8<0
ZH5o09j6PP2NShX0Vi2<09jCS`2CR8H0K65O04/m?01_HF00V8f909nDT02NThd0WiB>09fDS@2KTX/0
WIB=09VBRP2MU8l0Vi:=09bCSP2NThl0WY2?0:FCT`2_TY@0/HB90=:?V031FfD0d4eE0=56C@3FAd/0
e4Y80=1<A`2c>Bh0Xc@P0:a:9`38LT40j9iQ0?ZlL`3mbGD0o=5c0?ODKP3be6H0kMAP0>gGGP3`eUd0
l<mN0??3H@3QWe<0X4HA0<YH=P3DCch0eDI20=a7B`3JAdl0fDI>0=I0B@3JA4d0fTE;0=E4B@3DBDh0
`e5@09m@B`2FHel0/Y>A0:FCT`2TVId0X9ZN0::KXP2NUih0WiRO09jIW`2MVj00WIZQ09bIX02MVZ<0
VYNP09nLY`2OVj@0XifW0080Y9nV03T0XijU0:6LXP2UWZD0/J^_06AKGP0[8B00<BDU02`N7@0`7Qh0
g<S70?o]jP35ZJH0[HN40>:e/P39V9@0[WAc0;AhM`2>Ee@0NDQ308]YH02_UXl0n^_T0>KMf02j[j/0
gmC@0=C9``2o]Zl0b;nh0>3Id`3omo@0d<S605Q>C@2SVIP0c<;108MoO@2TWi`0b/C40<g3a03gi>P0
mMgM0?oSf`2ALeL0[HiG0?;HP`3Qcel0gmEB0:JN6@3>ac/0em<k0=cJA`3RhU`0g]i`07eo:`2OYFL0
RY1Z0?Sjk@00o`006_ooool6003o00l0X23`0P3oP0030:0Pl0030?n0002P8?00oh0001l0X23`00<0
d51h0:0Pl02P8?001P2P8?0>0?n004T0X23`3P3oP0000`2P8?000?l0ooooo`0?ooooo`003_ooool8
003o001A0>kZi02fYIh0SG1Z085FD02@EU80U4Y70:5;BP2]Bd`0Zd550:/h?@2d>d00_D160;lmA@38
A4l0bD=>0<Y6D@3=BeD0`D9;0;Hd?P33?dX0bd=?0<]7DP36BE40^D]>09m5A@2fLW40/XF209j2OP2P
ShP0Uhb609Z?R`2LTHd0X9FC08f1P@1JCD`0GeA@08AiM@2MTXh0WiB>0:6FT02MU8d0W9><09ZCR`2M
U8l0Vi:=09bCSP2QUY80WHn>09N2P@2_Si80]XF;0=J>V@2oEf00cdaB0=A7C@3D@dP0e4E70=14@`3E
BdT0bDE00;Lo;`2V>R00VSTF09e96P2dKBl0dYA;0>NcG`3dbF/0lm=/0>ODF03Ted/0jmUC0?7DG03o
dGD0[6HQ0;U?9`3ADcd0f4]20=U7B03JAdd0edA<0080ed5:0540fDA:0=M6B`3?A4T0a5=C09Q:AP2L
JfL0/iFC0:>CU02SVYd0XIZQ0:BMY02PVJ00XIZQ0:2KX@2PWZ<0WY^R09fJX`2LVJ80W9VT09fJY@2K
UZ80V9:L09B>V02=R8l0QX6807QcN@1]If/0O7Ij04a3AP0]8B40=RHV02`H5`1@>3H0l]SG0?_RgP3j
gMT0k/c:0:j9R03U]kL0hZZ[0<^?S`3=Ti40a9B@0<6PV@1kIf00l>GO0=K?b@2FRhL0R7ei06aSG01X
GeP0D4U304i7@@25OGX0YIfJ0:JLV`2DRXT0Z9jM0:VQW`3CcLd0j>;T0?3Uj@3`gnD0l]cN0?oUgP2c
U7l0Tg=40?CHSP3PcFH0g=5C0<2i;@3QfdD0dm0`0=kMA@3Ph5X0h^5g06ea7@2>U5H0S99/0?Sjk@00
o`006_ooool8003o00d0X23`00<0oh000:0Pl03oP0000P2P8?030?n001l0X23`00<0d51h0:0Pl02P
8?00202P8?0<0?n004T0X23`3P3oP0000`2P8?000?l0ooooo`0?ooooo`003_ooool:003o000X0?K[
i`3B`;`0Z8b808MPF`23CTX0UU9?0:AED@2/DE00[TI70;91@`2h?d@0^ca30<0lA`36@4/0bD=>0<a4
D03?Ae<0cDE?0=17D@3=Ae00bTQ@0<9>D@2U@D<0[5iL0;b7P`2POgX0V8Am09Z=Q`2ISXX0Vi2<09Z?
S@2MTY00Uhb:05mDDP19@3/0IU]G08^0O02NThd0X9F?09bCS080WYF>0P2MU8d0MP2PUHl0Xi6?0:>9
RP2bRi00_hJ=0=R;U@2mDU/0cDY@0==8C@3DADT0eTE80=I7B@3?AD<0d4a70<U?A034ED80]dlf0:53
8@2H?a<0S3X809973P2PHb@0/84i0>O<H03SeTT0j=U<0>WBD03ogg@0bHi00:E7503BFSl0ddho0=A6
@P3E@d@0fDI<0=Q2B`3I@d`0fTM?0=Q7CP3AAT/0a5=C09U;B@2MK6P0/YBB09n?T02OUYT0V96H09F>
UP2BRi80S8F<08N2R@21O8<0O7J007MaN`1^JgH0J6Ab05mKJP1LEfD0CdUE04M4C@12?dH0BdI=04Y5
B`1?BTh0G5IJ03P]<@0f9RT0>b8U038D5022Hf40j<K40<:PWP2AKfd0JDY80;^IV@3aalP0jkVh0=VS
X@2]O7P0`Y^F0?oXi03ai=h0j>3M04A1?00n=S<0WIFB0;2[Y@2l]k40[jZV08f8Q01QG5T0If9O0=WA
cP2QVIH0OgYg08AoO01[IfH0M71a0??Zk@3`hNH0l]kP0?gUh@3I_:`0NEDa0>S6R@3^e7d0g/iM0<:h
=03OfDL0c//^0=cK@`3Ph5X0i>Eo05aQ4@1mQDT0SYI_0?Oik000o`0Jooooo`X00?l0302P8?020?n0
00030:0Pl03oP000oh0002d0X23`303oP0190:0Pl0d0oh0000<0X23`003o0?ooool03oooool000ko
oooo3000o`003P3omO<0imGA0;fQW@2FKfX0PTm;08i?BP2EBTD0Y4i=0:U;B`2[A4L0VB`a0:D`>@2i
?DP0a3i;0P3;@dd0T03@Ae40c4A>0<a6C@37C540^Da?09m7AP2mOG/0Zh1j09EjL`2GQWl0UhZ409^@
S02JShd0V8f;0:2ET`2OU980QGYh05U>BP17?3P0IEMD08UnN02OU900XiZC0:6HT@2MU8d0W9><09nB
S02VTY40ZH^=0;F8S@35QXh0eh6<0;i>F03?BE00ddQ?0==4BP3EATX0dDM70<U8@`38DTP0`5M40:E7
:`2<=a00RCT808i12@28@@<0Oc/007Dl001C9`00b:m40>?GA`3VfTH0imE;0??JI03/_F40VTP>0<=G
<`3BDC`0dTPn0=I6A@3FA4L0f4=90=Y4C@3F@d/0eTM=0<m7B`30DE80Uda90:9bL02DN7L0J5YJ05UC
E`1GD5L0CTM>04M0A`14?D@0AT5704I1B018@dX0BTA>04e7D`1DD5h0FEES06EPKP1ZI700M75j07ai
P023OXD0RhJ<0::MX@2BS8h0=BX^03`/;`11:2`0<Q@F07QHF@1oH5d0GC/i07mMF`3<[Z`0jLW709E/
JP3^_;/0_hj:08]OG020GeX0nnST0?W`j`3Sg]X0=34/065LF03Ie=00kNST0?3]j03`jnP0kn[W0>_V
h`20NgP0^[Fa0?Sck`3ak>P0n_Kc08Z6Q@27Ph@0m>k`0>cQi@3_gn80m^;Q0?SMe029IDd0/XeS0?OH
U@3Sbg40`;0o0=cCD03Ccch0gme<0=oOF`3Uj840GfHH07R0A02=UFh0moW/003o01[ooooo3000o`0;
0:0Pl0<0oh008P2P8?000`3@D7P0X23`0:0Pl0070:0Pl0h0oh00B@2P8?0=0?n000030:0Pl000o`3o
oooo00oooooo000>ooooo`l00?l008@0l>GQ0<fl]@2IP7/0MEA=07iCC029F540PdU50<F1P02[EU/0
VCDm0;@jA@2o>dH0a3i70<Y2C03<A4h0cTM>0<a;D032CU40ZdM70:aNG02oQH40W7Ma09=lMP2CPGd0
UHN409J;Q`2HSHT0VHj:09fBSP2PUI40WI:>08AiM@1FBdL0@SLc06QMF`2AQX80XIJB09nDT02MTXh0
XiFB0:B@S`2]SI00]X>:0<j6T@3DMX@0`DYG0==;E@3DAdl0e4E;0=56B@3=CDX0`e=80;IG@@1k=Pl0
NdL>0:^0<P32WD80bjQ40<NT?02mWCH0[i8/08Q`3P2/WBH0j=i;0>CJA03ReTH0k=UH0?gFK@2[IR40
[TdR0=1G?03FCT00eDM30=Q6A`3H@dT0fDA:0=M4BP3CA4P0dDU=0;eBD@29A3l0Wg=`09Z2P01lL700
MFmc07aeO01mN7h0PW^208N1Q@2;QXX0SHR>096:T@2GTYP0VYFL09nIX`2LUZ00WINQ09jIX02RWJ@0
W9NM09fFW@2GTID0ZjFY08=mO`0a:2/0=RX/03HW:P0b8200ck^j0=O2_`3NaL00o>3L0?oVhP3acLX0
a9B@0>^h]@3V][80Y7mi0<R/Z03iin<0l>GQ0?kgk`33_kH0Ee1803lh<P1GD4X0Ui:<0=S@c@3<al<0
ViJC03Xe<P2ZYj820>7LeP0G0=OBcP2`[JP0e]GA0>g/jP3YhnD0jn3T0>oOhP3li>@0bjRR06Y4<@3B
[8D0kLf@0<ZaG@3Veg00f=5F0=[FD03Ngel0i^V206I^6`1gOd<0Q8aU0?Sjk@00o`006_ooool?003o
00X0X23`0P3oP00P0:0Pl080oh001`2P8?0A0?n004X0X23`2`3oP0000`2P8?000?l0ooooo`0?oooo
o`003_oooolA003o000J0?Wdl03Kd//0/J:K08ijL@1TBD80aj:L0?c6aP2`IFT0^51G0;]3C02i?4@0
_Sa40<4kA036?dH0bDI<0<M:CP2nCDl0XD=30;Y`K@2dOg/0VGIb09=jMP2@OWX0ThF209:7P`2ISXX2
09b>R`1109bAS@2UVYH0WiBB07mdLP1HCD/0Ac`j06aQG@2@QH40X9FA0:BFT`2RSH`0/8fA0;Z2R`3I
RiP0dVaj0<A7E03BAU40eTI?0=95B`3>B4T0aTm90<9NC`1m<Q<0Sf0X0>?6MP3`gG@0jMiR0>WLF@3[
geT0k^5N0>kQH@3Zff@0gLmA0>OJCP3TedX0i]U?0>WFEP3ogW<0fImE09Q24@3<FC`0ddho0=Q:AP3C
@d<0f4=70=Y5B`3HAD/0edQ<0<m8C02jDE00RdY40:EnN@2[V9@0XYRG09fGV@2IU9X0WYVO09jHW02R
W:00WINK09bFVP2PVYh0W9FL0:6LXP2NVIl00P2LUid0?02KUY`0V9>I09F@U02GTID0Ui6C0:nYZ`1S
GEl0:B0Q03H/;@0W7Ah0CT920?CTi03njNH0onKR0?[KeP3P_KL0hKB_0=:OV`30SHT0VFaW08i]IP3k
i=h0m>GP0?7Xh`37`;P0bL:j0<o8`P2HTH/0GUMA065JE02IT8/0PGQc04U1?P21NGH0[:NQ03di<029
QG`0BTDo09ZGTP3[j^D0j>WT0>GSi03Xh^@0jn3T0?;Oh`3mh>@0YXF006M2;`2jV7<0d;9l0=S4O@2H
SBl0fMEJ0>7QI`3Tih00K7@O07Z4A@23Rf@0n?[]003o01[ooooo4@00o`0Y0:0Pl0<0oh001P2P8?0B
0?n004/0X23`2P3oP0000`2P8?000?l0ooooo`0?ooooo`003_oooolD003o000H0>gXi02k/Zd0Th9k
0;>FT02>GUX0V4];0;M@E032DEL0a4]B0;m0A`2j=cl0a4590<=2A`38CE00]4I70:U;B`31Mg@0]7mk
09YgL`2?Mg<0TX1l08j1N`2AQX00V8f90P2ISXX0@@2KT8`0XIJD09nDTP2NU980OWAb05eBD01=@T00
KF9P0920P02SRXd0/X^@0;eoRP3NRYT0bUi^0<a:F03BATl0e4A=0==8C@3<BTX0aE9;0;AHB@1W9@80
e;1V0?3MMP3Vfe/0h]a:0>7KA@3Uh4P0i=e70>SMC`3XfUD0jmQK0>WEG03ZeUd0im9K0>cBH@3geG40
o<]o09iE8P2jCS40dU130=E:A`3FADP0f4=90=a7C@3GADP0ddM80=1;C02eD4`0R4a40:^8Q02STHl0
WYFF09nKW02ET9H0VIBJ09VDV02MUi/0Ui6E09RBUP2ITYT0VIBJ09fHWP2FTIL0VIBJ0080VIBH03/0
U8nC09JAU@2ESi<0ViFG0:bVZ018@T80;2<T03D[;00Q5AD0PW9b0?_WiP3hg=T0dZZX0:n2O@3;W9H0
i[>/09UVHP2dQGl0UFaV06U<A03ehMX0m>WU0>SPg@19A400@Sdi05IAC@1ABDH0FE9<05mFD@1]HU`0
UXV30<Bg/@3Md/`0gMG;08Z1N027P7H0>SD_0<6n^@3al>`0i^KT0>CTi03Uhn@0j>CU0>KMgP3^g^40
nN3S0:B7P`1nHE<0U7IL06598`1BA0`0h]]a0>3MJP3Nhg`0Jg<N07J2@P1jQE/0nO_^003o000Joooo
oa@00?l09@2P8?030?n000030=1@N02P8?00X23`00@0X23`4P3oP01<0:0Pl0T0oh0000<0X23`003o
0?ooool03oooool000kooooo5P00o`00>@3el>`0f/g70;2GTP2:F5L0SD=40:58BP2_CDh0^diA0<9=
D`31AT/0`T=:0;i0A02mADL0/DE50:iCDP2oN7H0[W]g09UfL02BNG@0SW]e08f0NP2BQh<0UHZ609N<
R02JSh/0W96=09Z@SP2OUI<0XYRF0:2ET`24NGL0GeAB05E5A@1gGF00XGIm0;ilR03RRYP0aEEU0<]7
E@3BADh0dd=<0<m4B@3?CDd0`e9:0:eDA01e=@l0k<Uh0>_KJP3TgE40h]m40>?Q?`3Sgch0iMa10>?D
A@3_eUP0mLmV0??6J@020?O9L@080?S:M03jagP0om>D0<]nDP2R=Ah0cTi50=E;B@3C@TL20=]8CP0=
0==2A@3CBDT0bd]<0;ADD02:DDX0/96>0:6AT@2OUYL0W9NK09NBUP2IU9X0ViJJ09VDV00209RBUP06
09JAU`2HTiT0VYFK09NBV02GTYH0VIBH0`2FTID09P2ESi40Yj6S0:2JVP0i<340;R@U03HZ:P0R51@0
]::R0?o]k@2kVIP0FRXV0;^4O`3Z/JX0ciJ@0>Ja[@3lblL0R65L0:^@R@3jjN80o??^0<c7``0/:2D0
]K6^0=7<b@2n][<0DTY702HM601SEU00GU5;05I9@@1`He/0bL2f0<Ro]P39`[X0PWei09fLV03al>h0
i^KT0P3Ti>@04@3Ti>80i>3Q0>CIg@3fhnT0onO[0:V=RP1L@3@0>1h705I85`3SfgP0g]a]0=kSO@1a
Nb@0LH0o07F2E`3gnnd00?l001[ooooo5P00o`0S0:0Pl0@0oh001P2P8?0B0?n004h0X23`1`3oP000
0`2P8?000?l0ooooo`0?ooooo`003_oooolH003o000G0?ofm@3JaLD0X7Yg08QEDP23@T00TT910:E7
B02eBdl0`4U=0<I9C`37BU00`4M<0:i1A02YCDh0_7Ec0;R3O@2IM6`0T7E^08alMP2=PWh0SXF00968
P`2ES8L00P2HShX0<P2MU8l0VI6>09jDTP2PUYD0W9:A08YjN`1hFf00Kd5;09UBH03SQiH0aE1R0<m8
E`3DAe00dD5:0=15BP3?BDX0b55;0;MGB@1d;`P0i;e`0>_IJ@3Ped`0hmi40>?O@03Tfch0i]Q30>oF
E@3baV<0_g/f0;EO;02nISP0b6m30=V3E03QSf00o:f60?fTQP2]>BX0bdM30=E:C@3GB4h0eD9:0=U6
CP3EA4T0cTI:0<Y<C`2^DE40U5aK0;2@T@2QTI80WI:F0`2JU9P0202KUYX0VYFI09bGV`2HTiL0V9>I
09ZEV`2GTYP0V9>I0P2ET9@0?02IU9P0UY:C09FATP2GTi@0ZZBV08N1P`0c:2`0=RLZ03PX:@0d8B<0
hlk=0?oYj03U`[h0`8n;0=6FTP2mOWT0chn>0<F;RP2JI680Rf9N0?KMf03diml0m^oY0>OTg`1ZIF40
GEQD09N?S02KTi00<RXW02DK6@2PUI<0fm3<0=;7`@3BbL80[:BL028K5@1MF5@0P7ai0;^j^03]k>X0
iNGS0>GUi@3Ti>@0hn?S0>WUiP3/hND0kmoR0?kXj`2LPgl0E3X]04@/4P1OD1`0g]Qf0>7QL@3Mi7d0
Kg`T06Ui>01dPeX0mo_/003o01[ooooo6000o`0Q0:0Pl0@0oh001P2P8?0A0?n004l0X23`1`3oP000
0`2P8?000?l0ooooo`0?ooooo`003_oooolJ003o001m07kfM@1ai680FlU80;jLV02SLg00UUME0:9@
D02VATX0[3m70;50B@2jBE40]DiC0:eFE`2XHf00WfaX09efLP2DMg@0S7Qd08mnN02=OgP0Rgmi08f3
O02@Qh40Thb609RAR`2JTHh0VHn>09bBT@2STi<0Z8^>0:ioQP2iLGd0fW^:0;m9G03ABUX0ddEA0=E5
C`3BADd0d4M:0<Q:A`38Edd0SSDI0:AW;`3`bg<0j]IN0>GKCP3UgTP0iMe50>GIA@3liVH0_YDg09I;
502eCbh0]DH/0;M1;@2f?bd0]3l]0:hm;@2jA3T0^3Ha0<e4A03EBTd0eTM=0=E5B`3FATd0ddI;0<e9
CP32C4l0YDmA0:5^L@2`TY@0X92C09jCV02LU9X0W9FK09jHW@2KUIT0Ui6E09bFV`2JU9T0VYFJ09^E
VP2HTiP0V9>G09JAU@2ET9<0VI>F09FAT`2FTI@0V9FF0:ZWZ01HDU<0;28S03`/;`0Y5QP0OFU[0?3G
f033XJ<0[HF40<nQWP3CX9l0g:JU0<N>S@3FX9h0cIVI08iVI@3[dm00mn[V0>WQgP2ZYJ40[JJS0927
P`1oMFl0QGYd0:ZPV@2bZ:80SX>006]QG`1aJ6<0a[jg0:6IT`2LUi@0QX5n0;:^[@3YinL00P3Vi^D2
0>CTi00A0>GTh`3Xi>@0jn7R0?3Ph@3ji^H0Rg9^054g:016;Q80H5<O0=oJN03LgW80g^F306Mc8`1A
GRT0WJV90?[mlP00o`006_oooolJ003o00<0D91h1P2P8?000`3@D7P0X23`0:0Pl00C0:0Pl0D0oh00
1@2P8?000`3@D7P0oh000?n000080?n005@0X23`203oP0000`2P8?000?l0ooooo`0?ooooo`003_oo
oolN003o001i0?oim02]V9<0YX5k0;9mN@3DSY00WD]?09Ll@`2C>3d0VdI907/a<P2hOGl0jKVi09a_
L@2PN7P0UWAb08mbKP2<M700SW]g08]lM`2:OgT0SHAo0968P`2CRHL0V8f;09j?S02WSH`0]8N:0<b6
T03FN8H0_4UJ0<e9F03BA500dDA=0=95C@3AA4X0cDE70<i<BP36EDL0RRlD09YG8`3baG80l]IY0>WG
E`3Vfdh0h]M90>gOFP3fg6h0XFdO09E5402aDBL0_U<c0<ME>`3:Dcl0bTm00<e?@`3ACTH0d4]60=A:
B03@ATH0dTI90=15B03>Ad/0ad]=0;iAE02KDE80Zh>30:^BU@2OT9D0WY>I09bEW02MUYd0W9FL09ZC
VP2KU9/0VY>J09bEW02LUYX0V9:F09RCU`2FTID0UY2B09RAT`2ESi40V9:F09FATP2QWj00W9^I03Da
<00`:2H0=b/[02HF5`36][L0dK^n06mAD`2=Jf`0^YRG0;jKV@3W_kl0bI^H09IUH@2JKFX0gKNf0?_S
h@3einH0kN?Q079ZJ00e;BX06Q0>01lD400a9R00B3dg0597@`1XGU`0OWAb08f6P02PVI<0IUiI07]f
LP1nNWL0V9NE0?;`l@040>CTi00?0>GThP3Vh^40k>;S0?7Sh`3bgM`0Nf9K04X`7`13;0d0GeDN0>;O
OP3Mh7L0f>6804eH501jQ5l0lOSV00800?l06_oooolN003o01`0X23`103oP0070:0Pl0/0oh00DP2P
8?080?n000800?l04?ooool000kooooo7`00o`00B@31^[80MfUN07QQD`3J]J`0d9nH0=:FU@2SHF80
V5AE06@T902GHF40omCE0;R5R@2=EEP0ZW=f0:1bLP2HL6h0TW=`08mfL@2?O7H0SWmj0923O@2AQX80
TXN309f>R`2URhX0/8J80<Z<T@3?NH80]d]H0<a;F@3?AU00dDA=0=E8D03AA4X0dTE;0<e5A`3>CdT0
`U1508DU302SFbT0l;ac0?_GMP3bfF<0imQG0>KJE03YfUT0j/mP0:Uk9@2@EP`0Qd4309Y:5`2RBAl0
/50Z0;eF=@32ECP0a50i0<e@?P3?CD00cdQ40=18B03?BTd0a4a>0;YFF02DE5@0[8j>0:>@U02OU9X0
VY>J09ZCV`2MUYh0WiRP09VBVP2HTIP00P2OUId0;`2MUYd0VI:I09VCU`2FT9@0UHnA09RBTP2EShl0
V8nB09F<S`2^Z:X0Qh>202hX:00a;2T0=2`Z02dU8P3MeM80lNOU0>WKfP3Zf=P0lmkM0?oUhP3E/Zh0
[hJ10;bCS@1B:bH0]iFC0?gXi@3gj>D0hMKD0=G;bP3CcLd0ShV903di>P0W8b@0DDQ909J=SP2NU9<0
MF]Y08^2O@2<Pg`0XIVD0:VTX01EDDh0S8^90?;ak`3Ti>80iNGS00<0i>CT00d0i^;S0>_QhP3`h^80
k=OD06mFC`18;a/0@BX:06MM903QggX0g^Aj0=3JQ01EGb<0alfc00<00?l06_oooolO003o01`0X23`
0P3oP0090:0Pl0h0oh00CP2P8?070?n000<00?l04?ooool000kooooo7`00o`008@3Mg]P0LFmR04i7
=`1fIUH0b;6Q0?KAb03AY9h0`Hj:0;5kN@23DE00^XR90>N`]@28Be00OT5608mGF02JJ6L0WW1`09ad
LP2CM740TWIb09AmM`2AOWP0T85j09R5P@2LPX40ZH620<:7R`3:Nh40]DmJ0<M=F03?Ae40dDE>0=95
C@020=95B`1E0=A7C@3?AdT0cde=0<E@A`2F<Q/0U48J0=^KF`3jbWH0mmA`0>cBH`3VdUT0k]YT0?CI
KP3/bVP0e:]A0;F5<`2QJAh0UE@@08e61P2D@`/0Uc`=0:m78P36DcP0cU110<i>A@36BDL0`U1@0;=G
F02BG5d0ZYFD09^?T`2LUI`0VIBJ09VDV`2LUId0WIJN09RAV@2KU9/0WiFM09^DV`2LUI`0VI:I09VC
U`2MUi/0U8j@09NAT`2DSY00UHb?09V@T@2cZZ/0HeeM030[:00c;R/07QTE05aGD`3`kNP0jnSS0>gU
h`3`i>@0m>CT0?WQg`3C[J`0hkNc0:QoN@2JMFl0mMKA0?gVh03oknP0YYND04a2@01KEED0LFe^04Q6
B@0U8bH0:B@X04i8BP2LTi@0e/c;0??Yi`2]Y9l0]jj/0>SSg`25PGh0c<_90>c[j@020>GUh`80iNGU
00h0i>CT0>OSi03Xg]l0mNGU0>C?c01VCT80AB`F048^2@1`JRT0gn9g0=oVOP31bG`0UYi]0?Kjj@<0
0?l06_oooolO003o01`0X23`0P3oP00:0:0Pl100oh00B`2P8?060?n000040:0Pl000o`000?l0003o
013ooooo000>oooooal00?l004P0m_Sc0;6bZP1SI5H0CDXg08QmJ@3>^JP0cK2R0;>=Q03H[JL0_8n<
0:MgM`35TYD0b96F0;=jP02eOH00Z6ea08iCF@2LI6L0XVm^0:1cKP2LMfl0UGM_099iLP2FOgT0VGah
0:=kN`2jPHL0`gQo0;ACGP3:Ded0bdQ@0=19D03AATd0dTM>0=A7C`3BADd0dDI;0=A9CP3BCDh0cU5=
0:Pg:@2B;1<0]Edg0>BMI`3k`Wd0n/eh0?3AJ`3]eVH0jmIQ0?COJP3dgFT0kmQV0>G9G03I^540dJU:
0=fVEP2dJBl0Wd8G0<UG?03;DT40aTm70;YACP2[FUL0TFET0:JHV02HSi80V9>I09VDVP2KUY`0VIBJ
09NBV02ITYT309ZDV00o09VBV@2DSiD0UY6G09VDVP2FTID0UI2D096=SP2DSY00X9ZJ0:NNW`0l=380
<b/Y03@/:P0H4a00WIRE0?Odk`3Yi^40jn?Q0?3RhP3ehn<0lmOF0:UmOP3FXZ40fJVW0?kGdP3ifm<0
h<Fl0:N@R02gYYl0akbj09nIV@2<R8T0LFa`04i9C@0j=3P0:28T01/E5`17?Sl0OGEc05YBD01`J6H0
c/W606]WI03Yj>H0j>OU0>CThP3Ti^<0i>CT0>?Sh`3Uhn@0i^3R0>SNg`3ijNT0f<Bm05e6>018<QX0
?B`108Z5=`3Igg<0h^Z70<K?T03QilD0oOoe00<00?l06_oooolO003o00@0X23`00<0oh000:0Pl02P
8?005@2P8?000`3oP000d51h0:0Pl00;0:0Pl100oh00B@2P8?060?n000040:0Pl000o`000?l0003o
013ooooo000>ooooob400?l007H0eMK>07j0LP1LFDP0LFEE07UXF01MACT0d;:X09E`JP3<Xil0`9BD
0=NYZ`3LZjh0kK^l0<2<SP2/LGL0WF9V08MAD@1nCDT0SF9K09ekL@2HNW00V7aa09QgL02PMg<0]W]m
0;icN02YBU80`U5I0<U<DP3=C540d4]@0=5:D03@BDl0dDQ?0==8C`3EB4h0eT]@0==;C`3ED5<0`dM5
0:4_902B;QL0[5Lb0=B;F03e_G<0n<mc0?CAJ`3beVP0kmIR0>gHH`3_g6H0kmYW0?CHK@3og7l0kkI_
09554@30FCH0aUHn0<=EB02eEdl0WeQD09UdLP2NU9D0ViFI09JAU`2IU9X0VYFK09VDVP2MV9h0ViBK
09^EV@2HTIP0W9FL09ZEV`2GTYP0UY6G09F@UP2ET9L0UY6G092;S`2:QXL0WYZI08b6QP0[8b40=bl]
030X9P0V8Ah0d/k;0?7]jP3Xi>40kN?T0>oOhP3ghN@0kloB0:5`M030QXT0_hN60?W>b02eU8/0aJRP
071ID@2hYj00o?;`0?3ZjP3]jn`0k>[[0>GQhP3EdM80al?40:>OX02<R8T0R8:40:bVYP22O7`0J6AS
06aXI@3^kN/0inOU0P3SiN803`3Ti>@0iN?T0>KRh`3Wg^40j]_N0?g[j@38/ZL0DS/Y04@_4P0j;000
ZJM?0=ONMP3TkI@0hNNg0?_nj@04003o01[ooooo8@00o`0Z0:0Pl0h0oh00B02P8?070?n000@00?l0
4?ooool000kooooo8P00o`008P3/kNL0_;bd09JBQ`20N6d0D4@h08QfK02WShD0^9fD0=2bZP2EL6X0
eK2Z0?[Gd`3<YZ<0TFET0:1dL`2QN7H0Z85l08IQF@1`D4D0PV9E09QhJ`2QNg00Z7M`0;MjM`32M7@0
SBhb0:i1A@33Ce80a4a>0<I9C@37BD`0bTU=0=1>D03CC5020=59C@130=99D03ABU00d4U=0=5?C`38
CDP0[ST_09DZ5P2XBRT0eXAD0>^SJ03i^WD0o<Ag0?c<M`3hd740mLm/0??;J@3icG@0om>;0:EV<02S
BB@0_e]10;aKBP2_Fe00T5=>0:63P@2OUIH0WiVM09jHW02JU9P0VI:I09N@V02LUId0Ui2H09:;TP2?
RY40SXV@08AoQP23OXD0P7^207QcNP1XIFh0IF5X05iIH013@D@0MG5b06aVJ00l=SH0FU5B02TP8@1?
BDT0k^[Y0>WUi03Zi>@0k^;T0??Nh`3lgn@0bZ:Z099QI`31PhH0YFQW0;N6P@2=J600ZHj50;NVWP3X
gML0kNST0>OVi0030>KVi080j>SV00T0jNOX0>[Xj@3Vi>D0j>KW0<?1`@2>SH/0fm[H0>c/k03UiND0
0`3SiN@03P3Uhn@0jN3S0>cMhP3^g^40o^_W0:2:O@19<a`0@2d<03hc0039bf/0g>>40>K^Y@3cm]L0
nocd1000o`0Jooooob800?l0:`2P8?000`3@D7P0oh000?n0000:0?n004L0X23`1P3oP0000`2P8?00
0?l0003o0002003o013ooooo000>ooooobD00?l004L0k^kV0=C@a`2XWiH0XIB;0;2RU`36]J/0EShd
09f5N`3Qb/80hL[40;NKU`2eVIH0dKFb0??JeP3L`kh0YHb508A/HP1`EDX0OEeB091UG02_N7<0aX9o
09E4@@2I>CT0[dE50;=5AP2iAdL0_TY;0<9:B`37Bdd0bTa=0<a;C`3?C540c4U?0=5;DP3>BDh0dT]A
0=E@E@3BD580bdi<0;Q0>@2N<Ad0VSDI0:94802dGC00bGU40=><C03XYEl0lk=[0?RiMP3oahh0k:Qk
09Y18@2hF480]Ue=0:MMDP29E500W8:208=hO01nN7`0N79f06eWJ`1XHFP0H5UQ05YCF`1:@d/0C4E<
04m8D01:AD/0BdI<05A?E@0205QCFP0S05MBF@1QG6<0If9X07YhN`2@S8d0@Sho03li>@1RG5`091hN
096;R`3elO00i^;Q0>[Ti03^gn80n>7W0?;Cf@34Vj40jKRl0<66QP2@EE40WVmY0<>NUP3H_KH0nNKO
0?;Th@3/h^00jn?P0>_TgP3/hmh0jnCN0>SSg@3XiN00in?P0>KUh`3WiNH00P3UiND01037alD0jNWW
0>GUi@3Shn<20>?Ui00>0>GUi@3Whn@0j]kR0>cLg`3dh>40l=_F06iGA`15<1<0>2T007E^:P3GfgH0
i>^K0>gd`03ko^/5003o01[ooooo9@00o`0[0:0Pl0T0oh00A`2P8?070?n000D00?l04?ooool000ko
oooo:000o`002P3gm>l0i=oI0;ff[`25O7<0SXAj0:ROUP2k/Z/0d/W40>oUh`3om_D3003o001b0?K]
j03Kd<X0^ZVR09MnN@2=K6D0Sf9L08YABP2AAd40VT4m0:90?@2X@3d0Ychk0;A6A@2fA4@0_dU90<E>
D033Bdd0a4a>0<Y?DP3;CU80bD]>0<i=D@3@Ce<0dE5B0<m?C`3<Cd/0`TLo0;Ln<`2a>B/0Wb`I09d]
5`2O<aT0XCTL0;MD=`32I4/0gGiX0:<m;P2fDDD0]UmF09YED02@Hf00PVe]05]EE`1MEe/0FeIJ05aF
FP1NF5`0HUQP06]QJ@1YGfL0MFaa07abNP1oNGd0Qh6508V3Q`29PXT0SHJ=096;S`2ET9<0THf>0:bX
Y`2:QXD0;BTX02PT8@0Z9R<0;2PU0=GAcP3akNX0in?P0>WTh@3_hN40n^CV0>oAd`2/QHH0ZGai0;>2
O02TN6l0nM;;0?OFc`3Sa;l0lMSD0?CQg@3eh]h0mn3J0?KNe03jh=<0nn7D0?KSe@3`h]L0k>?J0>WT
gP3Yi^40i^GQ0=[Jf02MWId0k>c/0>GUi`3Ti>H0h^CS0>CTi03Vi>D0jN3S0>cMh03^g=`0nnKS0;^R
V`1:<Ad0@2`704Pn0@35`g00fnAo0>_c]`3hoMd0nogb1@00o`0JooooobP00?l02P2P8?03003o06/0
X23`1P3oP0000`2P8?000?l0003o0003003o013ooooo000>ooooob/00?l000@0k^kV0=OGc`3Vi]h0
n_Wd2@00o`00G@3om_80lN3I0=S1^@2kVY<0Vf]T08Y=B027@3`0T44l09M2?`2M@Sl0WC/h0:Do?@2^
A4@0/DE30;I6A@2lBTX0_DU:0<9;C@37Ce00b4e?0<a@DP3<CE00cdaA0<i<CP3AC4l0dDa=0=1;C03=
Bd/0a4A10;/n?02a=c@0Yc@_0:8b;P2fBD@0^EQB0:iMFP29CD`0Ug5`09f<SP2BS8h0THb@09NBUP2H
TYH0UHnC09R?U02NUIX0XIRM09^BU`2JTIH0ViFG09bFV02FT980UHnC09ZDUP2ESi40Thj>09VEU02[
Yj@0F5AA02@P7@0a;BX05Q8?06APG@3al>`0j^KS0>WTh@3[hN00l>3P0?SPh03hf=T0hKVi0=b/Z03F
Z:00oMG=0=F`ZP35Y9l0IdE30;:CT@3oh^80nmWG0?S;aP3W/ZX0dYb@0<nNS`3S_:d0mMW;0?KTf03`
i]`0j^KK0>OTg@3Shmh0gMgK0>KVi0020>CTi00?0>?Ui03Ti>@0in7S0>WOh03[fm/0ln3L0?OPf01k
I5@0@b/A03TY002=QSP0h^>50=kWR`3am/d0nog_00H00?l06_ooool[003o00@0X23`2@00o`1X0:0P
l0D0oh0000<0X23`003o0000o`001000o`0@ooooo`003_ooooll003o000E0?;QgP3:/Jd0YhJ1099Y
H`21CdP0Qd]308e4?P2B?c/0W44n0:4o?02T?SX0YSdj0:e1?`2bA4<0_4a;0;m=C@2nC4`0a4i@0<UA
D`3:Ce40bDe?0080cdiC00h0dDiD0=1=DP3>CE80ce5E0<a?D`34CDl0`EAG0;UMGP2JDe40PDm>0:F7
Q`2IRh`0Thf?09:<SP80U8j@0P2CSHl0@02ESi40V8nB09B;SP2DSY00UHnA09B>T02BSXd0TH^=09B>
T02ARhd0T8Z:0::MVP2DSh`0>C@a02`W900b;BX061@C0:FQX03elO00j>;R0>_Sh@3_hN40m^;S0?GK
fP3E/k80[h>20;N1O`2MJFD0aIRE0:b4PP3B[:/0YX1o0>6j^`3ohN80iJn_0:1BD02J@Cd0TCP`08Lg
;02;CD00Wg5R0<Z]W@3Yf<P0jn;A0>KSe03Yj=d0inSP0>CUg`3Ui^40hn?Q0>?Ui03Th^<0j=oP0>_M
g03_g]L0o^[O0<:]W013;Q<0>RP005U>403?bV`0fmaf0>O]XP3jo>@7003o01[ooooo?000o`1Q0:0P
l0P0oh001`00o`0@ooooo`003_ooooln003o000R0?ohl`3ei^40g/O10<JUWP2YO7L0TEYG08I5@@2@
AT<0Rchh09I3?@2K@cl0WD8m0:A5@@2T@Sl0ZD=10;97AP2iBDP0_TY;0<A=C`3:Ce@0bdiD0<]<D`3;
C5D0cDiG0<e@F03:CUH0a55H0;aGF`2aGf40PTI609E]K@2USHd0U8V908n9R`<0T8Z<0480ShV;09>=
S@2BS8`0UHb?0968R`2DRhh0Thf?096;R`2@S8/0SXR:08b6QP2>R8P0T8^80:JQWP1QG5T0:bHS03H^
;00U7A/0>cDe0=oIf@3_jNT0jn7P0>oQh@3dh^80n>;T0;bPW`31WY`0k<2o0>Nd/`2IJFP0OE=D0:f6
Q`3CZj`0gJna0?oDeP3b][P0Rd520:M9B@33Ged0`fUQ0;9UF`2@ETP0Ich/0615<01QDcT0NG9H0;fl
X03/k]P0i^_G0>CXf@3SimT0hnKK0>?Tg03Wi=d0j]oI0>gLdP3ch]00mnK<089_C`0j:@00>Rl00:BO
C@3Ui7X0g=ii0?3e_P3koNl7003o01[ooooo?P00o`1A0:0Pl0D0oh00202P8?080?n000030:0Pl000
o`000?l000D00?l04?ooool000kooooo@P00o`007P3olo80km_J0=Vm^P2fUI00WWE_08]LE021Bd40
Q4Dl08Y4?02EAT40X4Q40:A4?`2X?c`0[3hm0;I6A@2iATT0^4=90;]4BP30B540`d]E0<9=EP30CUH0
_UIM0;EOHP2GDe@0P59B0:B6QP2HR8T0ThV;08j8RP80T8Z<04<0ShJ90968R`2AR8/0U8^>09>:S@2@
QhX0TXN;09B9S@2BS8h0S8J808b6QP2=QhL0T8Z:09RAS`2>QX<0=bl]034Y9`0k<S<071<D07E/K`3f
kNh0k^;T0?7Nh03dg^00n^3S0?WOhP3O`L<0bjVX0<:LV`2KLW00Yh>40>W;c@3ognH0g;6h07Dg?03N
Si80`FQZ09`n?P3<KfX0_faT09EGC028GTh0WhIb0:VMQ@2PVgd0QHEQ0;:dS03Gg[80aLnU0=_W`@3O
j/P0hnc?0>K[e03Tim80inG@0>_Nb`3^g/@0nn_70<JhR`13<`00@3H007Ud603EefX0f=m_0>G/S`3f
nMH0nocd00L00?l06_oooom2003o04X0X23`603oP0000`2P8?000?l0003o0005003o013ooooo000>
ooooodH00?l001X0o>gX0>SDc@3:[JD0ZhIn09Q[I@2:EDl0S4m:08Y1?02HAD40W4910:12@02P?3`0
YSm00:Hl@02Y?440Zci40:e2B02cC500Ze5C09]CE01lAT@0UW=_09f8P`2CQH80TXZ808j9QP80SXR8
0480ShJ70968R`2?QXT0SXF80927RP2AR8/0ThR<08n4R02DRhh0RhF708f7Q`2<QXH0S8N409bFT`1F
CT`0:b<Q03L^;`0b:BX08QTL0;fg^@3gk?00l^?V0?7Mg`2XRhl0[XnD0>W:c`3mgN00kl_;0=>`[P2F
M780m]gL0?[Ti`3oj>l0_Y>L07`c>P2bEU/0ZD950<=MF`37L6L0TTi309meI`3Xdl80[ZRB0820I01h
NEL0NW]A08b<FP2<SeH0HFP_06ikA@26U640]lBI0<7<Y03?d:h0hMfj0>kP_@3gi[X0i=FJ07a`:021
Mb80Yj8n0=?BG03MhfT0gNAj0>[cY03jo>P8003o01[oooooAP00o`160:0Pl1L0oh0000<0d51h003o
0000o`001P00o`0@ooooo`003_oooom9003o000Q0?odl`3giN<0im;?0=Fi]P2/R8<0UfMS08eFD`28
Ad<0SD8m098o>`2J@Cd0WT0n0:=1@P2R@T<0X4Q60956@@1O9200QeaE0:25O02JRWd0T8Ij08j5N`2=
QWh0S8Eo08j6P`2<Qh@0ShV908f7Q`2;QHD0S8>60927RP2AQXX0SX>70080SXF603P0TXV:08Z1PP2@
RhP0RhB2030W:00c:2`0=BX^01XA501IDeL0jNCX0>gWj`3dj>`0l=_R09AfOP2EM7/0jLG90>[3aP2m
UYL0dZn]07mQG`33[:`0mN;T0?oYk`3BYk00Rd990<Y[L@36GF40afER0;EXGP2?FT`0i<Vh08IkJ@1[
IU00THeb08j6HP1hJch0IETO06=H5P1hM2`0JgD`06Mf=@1VN3h0FFHa05mQ;`1eKC`0VhUG09V5B02D
Q2l0[:4g0=C<D03EdTd0gN5F0=CMH03Sk940k?Bk07koM0P00?l06_oooom9003o0480X23`603oP000
0`20`0000?l0003o0006003o013ooooo000>ooooodd00?l005L0P?Yi0?WTh@3_d/h0g;Na0<RIT`2]
MW40X6=N09IBC`2BBdL0SDQ307`m=P1Y=2`0N5160:nCQ`2HQgD0ThQb08b6K02<QVd0S8I`08b7M02:
Q7@0RXIj08f9OP29Q7h0RHB008R3P02<Q880SH>408j4P`2=Ph40RX1n08f4O`2DRhH0Y9^F05Q@C00g
;B`0>S0a02@K7P0i<3<0d<[<0>cZj`3VhND0jn3V0?3Oi`3fgnL0mMOO0;BDV@20H6<0aZRX0>G9b02E
OGd0/9jO0??Pi03ih>H0omGO0:]OJ@2_D5P0bfAX0<QZJ02SGED0YWQ[0;6KS@1FCcd0gm[60=O@]P1a
HCl0I4lP0<ZeMP2VTTT0[jAF09>EBP1/MS40KGLh06Q^<01]JBX0Jf0N06]I4@1YE`40/J@d0=[ACP3=
bcP0fmi70=KMC`3QjWL0i^fW0?Omf@1nogT02000o`0Jooooodd00?l000<0D91h0:0Pl02P8?002`2P
8?060?n002<0X23`00<0oh000:0Pl02P8?001@2P8?0G0?n00003052@N000o`000?l000H00?l04?oo
ool000koooooDP00o`00DP3omO<0nnKS0>_BcP3H^KH0^ibI08Y_J02_VHh0imO80>WNbP34_j40WI]e
09VGKP2@Sf40RhYN08N4F`28QV00QXMU08J6JP25PVl0QH9c08Z6O@23OgH0Rh9m08^0NP2>PGP0Sh5f
09R:O@2XW8h0PWIZ03T/900l<Bd08QXG048m>P2n^[T0lO3^0>KUh`3Uhn@0jN?W0>gRj03jkO@0/9nU
089_L`2kZ:X0]jNX0:^MW@2h[:`0k=oR0?GPi`3H^L40hZjj0?f__@2`DV00_5IQ0<1TI`2QFeT0YgYd
09Z3N`1TFTh0Q7e[08IjHP1F@R40U7U:0>kCT03Nag/0Zi]>0>GNVP1kMcP0IV0T07M_<01lKRD0NVXE
09J78P3<`4X0e/i50<S7<@3FfSl0f^1<0=gVI@3Ukhl0koG70?[nk@1moW/8003o01[oooooDP00o`08
0:0Pl0/0oh00802P8?020?n000D0X23`5P3oP0000`2P8?00D91h003o0007003o013ooooo000>oooo
oeL00?l004/0ooWc0?Wek03glnL0l>oM0=SH_P31`Z00^;RB0:j_Q02SY7P0WYea09RIK`2?U6`0Q8QU
08>6J`25Q6l0QHAb07miJ`2;Og40UHEe09Z8LP2KQfh0[9Qm08QgF`0n;Q@0@C4J034R3`0h<1d0cLJd
0?[di03[j=T0inGI0>WVg@3/i>40jn?P0?3XiP3Hd<h0iM_J0?O]k03/in@0j^KU0?7[j`3^i^T0n^W_
0=2b_01[?DP0Z65a0;APL02lHVh0_V]c0:EYJ@2<IV<0[ibF05M>A@2o]jX0d/Nc05a9:`2QREd0k=:G
0>cES`2_WUX0]j]a07AW<01oKSH0PW4/079P302aX3P0gm5F0=C=@@3<b340c/lc0=_RA`3Hh5L0i>f2
0=oVX03ioN802P00o`0JoooooeL00?l00`2P8?0=0?n000<0X23`103oP0040:0Pl0030?n0002P8?00
X23`00l0X23`0`3oP0060:0Pl1D0oh002P00o`0@ooooo`003_oooomK003o00170?WjlP3gnN`0k>gM
0=cOb@30a:T0];NJ0:b_T02V[H`0VJ1o0::XS02WZi80NGUQ07=[EP2ZVX<0e;bP0<b`R`2/Sf<0PfPi
04hh1P0o:P00CCP;03`Z002YWFd0o_?50?C[`P3`j<@0l>W<0>oWd03_im@0knKE0>gUf03]im/0knSP
0>[Ug`3Yi^40iNCP0>STh@3Xhn80k^?W0?WVk02[RiH0P4aI09mOK@2`K7T0[g9j08aRI01dFUT0j=gK
09VDT02BSXD0QWia0555;`1dI4<0e<6F0?7O[@2=OTh0Lf8g09F2E`2=N4<0Je@>0;>Q?@3PdUL0d<Lj
0<S5;03<c300g>570=OPD@3RjgH0emnD0>cab03koNl02P00o`0Joooooe/00?l00`2P8?0J0?n000`0
X23`0`3oP0080:0Pl180oh0000<0X23`003o0000o`002000o`0@ooooo`003_oooomN003o001303oo
?P1mogP0O?af07GfK@1_lFH0I>ML05_OE03>dL<0[JbN0;:]W`3Hc;/0^:RA09F2H`2XU6`0`k:00<Ni
P02n/G40[j=K09jB@`33^6<0dlMb0=;3L@3=_Fl0d;ei0=S6Q`3Oc900iM>K0>cKZ03ah;<0ln:h0??R
_P3bh/D0lN?90?;UbP3`i/d0knGA0?;Ue`3hi]`0jLc70<BRWP2^SHX0Z8V70:RCSP3?a;h0lN_X0>[W
h`3Iem80clc30=K>`P3BbKP0_:nJ0;2RR038^IX0iM>_0<>_O`2COCD0c;QG0=[<CP3@bCL0b<H[0<kB
<`3FgD<0en5E0=cWL`3CgHT0hnW00?cnk`0;003o01[oooooGP00o`000`0Xb3`0D91h052@N0040830
00@0d51h503oP0060=1@N0`0X23`0P3@D7P?0?n000030=1@N000o`000?l000T00?l04?ooool000ko
ooooJ@00o`00=`3ooO@0ooc]0?ObgP3]j//0g]bc0=GDWP3Hf9@0g=V:0=[DP03OeW/0gLm^0=6oF`35
[d`0^Z8n0:fF;P2USRH0WhTV0:29:@2OQR`0[iE10;RNE033[6P0bKE`0>?AT@3_gZH0lMn_0?;Q]@3e
i[l0n>S60?WZb@3ik<`0mnc@0??Yd03]iM00kNGB0>gTd`3_i]D0l>SE0?cag@3HbkP0O6eF0>WJ^@2Z
V6P0Q74/0>KDL03Eb4P0b/<d0<O6;@3;cc@0f>1<0=7ME@3Nk7X0]lAe0<_CY03lonh03000o`0Joooo
ofT00?l00P2P8?0Q0?n00080X23`4@3oP0000`2P8?000?l0003o000:003o013ooooo000>ooooof/0
0?l003D0oOge0?knm03loNl0oOcZ0?Cef@3Zj/H0h=nc0=WHX03@bhL0dl]h0>3DL03WfVP0j=YM0>[L
F@3TeU40h<m;0=C3@@3:^3`0^jXh0:ZH:P2STBD0X8`Y09n7<@2[TT00_:9G0;nXI03;]WD0f/F20>OB
T@3_fih0lmjW0?CN[@3fgk<0m]nf0?SR^@3hhkP0o>Nj0?CO/P3SdJ40k]fY07UT8@3;]f00f<UF0<[2
>`35`S<0bL/i0=SOD@3CgU/0g>ek0<?CN`2OZGL0l_OP0?_lm00<003o01[oooooJ`00o`040:0Pl300
oh0000<0X23`003o0000o`002P00o`0@ooooo`003_oooom`003o000_0?gom03lonh0o?oT0?7_aP31
_h@0`KaZ0<k7G`3Ab540f=1;0=G<?`3Oe4@0hmM50>_OC`3[geD0k>1H0>cNF@3VeEX0f/IF0<nhD032
[4T0ZIHj09j==@2OSSH0WH/e09b7=P2bW500Zi==0;:IE`30YVT0aJ]^0<nfM03D_GX0g<N40>;?S@2b
Xf00UXHh0=g@L034_D/0_ki00<c?CP3BfeX0dMaR0=[ZO`3Ahhd0PY9D0<gF^@3loo@03@00o`0Joooo
og000?l00P2P8?0/0?n000030:0Pl000o`000?l000/00?l04?ooool000koooooLP00o`00;03lo_<0
ooob0>g]d@2c/H40/ZmZ0<W5K03BcV<0bL=90<W1?038_c@0bl<d0=?;>P3IdD00gM940=gDBP3OeUD0
hMUM0>?LJ03Sg740g]Uc0=gGM`3HdW@0d/U^0<o4JP35]el0^:QC0;>RD02ZV4@0Xi4k09R6<02GQc80
W8dl09B9?@3Ke8<0aLAZ0;>gEP36cVT0cMUc0<[JN032eG/0[<5d06j2A`2GYH40mok^3P00o`0Joooo
og800?l00P2P8?0Y0?n000030:0Pl000o`000?l000`00?l04?ooool000koooooM@00o`00:03Wi]40
Wj1h09fLH`2i]fd0c<Q]0=GBJ`3Cd5d0c<Y?0<k;BP3<bDH0b/M60<_6C030_d/0aLAH0<30G02m`F<0
`<=/0<C5M`31`WH0b<Eh0<g:O@3FcX<0fM660=kERP3OeXT0g]:60=gAQ@3GcX<0e/j60=K@S`2o_Wd0
Q8M207^2?P2;UU80R9MD096QHP20TEX0JGY=07V8J@3RjmP?003o01[oooooM@00o`0X0?n000l00?l0
4?ooool000koooooM@00o`006P3moOD0mOKX0=oOa`3?d:h0`L:F0<72R@2n`G`0`<Ec0<G:L036bfd0
a<M^0<_<O@3<cHT0dM:H0<_?W039c9l0f=fe0>;S`@3Oh;h0g^2k0>CV`@3Yi/<0k>[40?3/a`3akLL0
l>c60P3cklX02`3bkl`0k^c>0=kO`03:cJh0b<f_0<gC]`3CfKl0fN790>7Ye03[l^80mO_a01000?l0
6_oooome003o0080X23`8`3oP0020:0Pl1000?l04?ooool000koooooN@00o`003@3joN`0lOGL0>?W
a03<dZH0[kJ20;FmQ03?dj00jng30?;fe@3gnn80nokY0?[nk`3ko_<00`00o`020?golP030?knlP3m
o_00oOk`00@0oOga00<0oOgc003o0000o`005`00o`0JooooogT00?l000<0X23`0?n0003oP000203o
P0020:0Pl0<00?l02P2P8?0I003o013ooooo000>ooooog/00?l000L0oOod0?cnl@3joN`0nOc[0?cm
k@3mo_40oOod02X00?l06_oooomk003o00L0X23`:P00o`0@ooooo`003_oooon/003o01[ooooo[000
o`0@ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {220.938, 0}} -> {-0.0523276, -0.0277532, \
0.00527483, 0.00527483}, {{9.875, 190.438}, {215.625, 115.438}} -> {-15.0024, \
-13.1403, 1.05837, 1.05837}, {{208.5, 389.062}, {215.625, 115.438}} -> \
{-225.221, -13.1403, 1.05837, 1.05837}, {{9.875, 190.438}, {105.438, 5.25}} -> \
{-15.0189, -124.786, 1.05854, 1.05854}, {{208.5, 389.062}, {105.438, 5.25}} -> \
{-225.271, -124.786, 1.05854, 1.05854}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error plot", "Subsection"],

Cell[BoxData[{
    \(\(cnt1 = CountPixels[class1];\)\), "\[IndentingNewLine]", 
    \(\(cnt2 = CountPixels[class2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bar\  = \ {cnt1, \ cnt2}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(BarChart[bar[\([1]\)], \ bar[\([2]\)], \ 
        BarStyle \[Rule] {pointStyle1[\([1]\)], 
            pointStyle2[\([1]\)]}, \ \[IndentingNewLine]Frame \[Rule] True, 
        BarLabels \[Rule] {"\<Kellogs\>", "\<Tide\>"}, \ 
        imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.00640901 [
[.27273 -0.0125 -23 -12 ]
[.27273 -0.0125 23 0 ]
[.72727 -0.0125 -14 -12 ]
[.72727 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1429 -12 -4.5 ]
[-0.0125 .1429 0 4.5 ]
[-0.0125 .27108 -12 -4.5 ]
[-0.0125 .27108 0 4.5 ]
[-0.0125 .39926 -12 -4.5 ]
[-0.0125 .39926 0 4.5 ]
[-0.0125 .52744 -12 -4.5 ]
[-0.0125 .52744 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -23 0 ]
[.27273 .63053 23 12 ]
[.72727 .63053 -14 0 ]
[.72727 .63053 14 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -84 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kellogs) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tide) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1429 m
.00625 .1429 L
s
[(20)] -0.0125 .1429 1 0 Mshowa
0 .27108 m
.00625 .27108 L
s
[(40)] -0.0125 .27108 1 0 Mshowa
0 .39926 m
.00625 .39926 L
s
[(60)] -0.0125 .39926 1 0 Mshowa
0 .52744 m
.00625 .52744 L
s
[(80)] -0.0125 .52744 1 0 Mshowa
.125 Mabswid
0 .04676 m
.00375 .04676 L
s
0 .07881 m
.00375 .07881 L
s
0 .11085 m
.00375 .11085 L
s
0 .17494 m
.00375 .17494 L
s
0 .20699 m
.00375 .20699 L
s
0 .23903 m
.00375 .23903 L
s
0 .30312 m
.00375 .30312 L
s
0 .33517 m
.00375 .33517 L
s
0 .36721 m
.00375 .36721 L
s
0 .4313 m
.00375 .4313 L
s
0 .46335 m
.00375 .46335 L
s
0 .49539 m
.00375 .49539 L
s
0 .55948 m
.00375 .55948 L
s
0 .59153 m
.00375 .59153 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kellogs) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tide) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1429 m
1 .1429 L
s
.99375 .27108 m
1 .27108 L
s
.99375 .39926 m
1 .39926 L
s
.99375 .52744 m
1 .52744 L
s
.125 Mabswid
.99625 .04676 m
1 .04676 L
s
.99625 .07881 m
1 .07881 L
s
.99625 .11085 m
1 .11085 L
s
.99625 .17494 m
1 .17494 L
s
.99625 .20699 m
1 .20699 L
s
.99625 .23903 m
1 .23903 L
s
.99625 .30312 m
1 .30312 L
s
.99625 .33517 m
1 .33517 L
s
.99625 .36721 m
1 .36721 L
s
.99625 .4313 m
1 .4313 L
s
.99625 .46335 m
1 .46335 L
s
.99625 .49539 m
1 .49539 L
s
.99625 .55948 m
1 .55948 L
s
.99625 .59153 m
1 .59153 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .5 0 r
.09091 .01472 m
.09091 .19071 L
.27273 .19071 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .19071 L
.27273 .19071 L
.27273 .01472 L
.09091 .01472 L
s
1 .5 0 r
.54545 .01472 m
.54545 .06701 L
.72727 .06701 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .06701 L
.72727 .06701 L
.72727 .01472 L
.54545 .01472 L
s
.628 .126 .941 r
.27273 .01472 m
.27273 .47962 L
.45455 .47962 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .47962 L
.45455 .47962 L
.45455 .01472 L
.27273 .01472 L
s
.628 .126 .941 r
.72727 .01472 m
.72727 .60332 L
.90909 .60332 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .60332 L
.90909 .60332 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00Roooool3o`000?oooooo0oooool008kooooo00?o0000ooooooooool0
ooooool006cooooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol000000ooooooo0000
o`000003o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l0001oooooo`?o0000
0_ooool5o`0000;ooooo1?l00002ooooo`?o0000J?ooool006gooooo00Ko0000oooooooooooo0000
ooooool00007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0006_ooooo001]ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00ol00020ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00Go0000Ioooool006gooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000008?ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1Uooooo`00KOooool00ol0003oooooo`000003ooooo`?o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Go000000?oooooo`00
0?l000000_l0001mooooo`06o`000?oooooo0000ooooool0003ooooo0ol00004ooooo`?o00000ooo
ool3o`0006Sooooo001]ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2?ooooo`05o`000?oooooo0000ooooool000002_ooool00ol0003ooooo
ooooo`1/ooooo`00K?ooool3o`000003ooooool0003o000000Kooooo0ol00003ooooo`?o0000TOoo
ool5o`0000?ooooo00?o0000ooooooooool00oooool2o`0006kooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000Roooo
ool00000G000000Cooooo`008_ooool00`00003oooooooooo`1Looooo`03o`000?oooooooooo09[o
oooo00<00000ooooooooool0Foooool00`00003oooooooooo`0Aooooo`006_ooool2o`0000Kooooo
00<00000ooooooooool0G?ooool00ol0003oooooooooo`2Jooooo`0300000?oooooooooo05_ooooo
00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo00001Oooool00`00003ooooo
ooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co
0000oooooooooooo00001Ooooooo000005`000004oooool001Wooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Iooooo`04o`000?oo
ooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`006_oo
ool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?oo
ool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Ooooom0000003d0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Loooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000
003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1L
ooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
0000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000003o
O`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P
8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Loooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`004_ooool5o`0000?ooooo0_l00006ooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Cooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Gooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01_ooooo0`00000Cooooo`005Oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Loooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`004oooool3o`0000Cooooo0_l00006ooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo
00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
0?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`00
0000003ooooo01;ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03o
O`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01go
oooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05co
oooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo@000
000m0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Loooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003o0000o`00001Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_oo
ool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1L
ooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooo
ooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`03
00000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0
G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?l0003o000005cooooo00<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool0
0ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Loooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Dooooo`?o00000oooool2o`0000Kooooo00<00000ooooooooool0G?oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Eooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo05cooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool5o`0000;ooooo00Co0000
oooooooooooo00001Oooool00`00003o0000o`00001Looooo`030000002P8?00X23`03/0X23`00<0
0000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01_ooooo0`00
000Cooooo`004_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo
00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Cooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00001Oooool00`00003ooooo
ooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001Cooooo0_l0
0003ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool0G?ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Eooooo`03o`000?oooooooooo00;ooooo0_l0
0006ooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000
ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003o0000o`00001Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;o
oooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05co
oooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<0
0000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?l0003o000005cooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol00000
0000ooooo`0Booooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Loooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000005cooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<0
0000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`1L
ooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooo
ooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`03
00000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0
G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool001?ooooo0ol00004ooooo`;o00001_ooool00`00003o
ooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00<00000oooo
ooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooo
oooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool4o`00
00?ooooo00Co0000oooooooooooo00001Oooool00`00003o0000o`00001Looooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01_ooooo0`00000Cooooo`004_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0000Gooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Cooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
01Cooooo0_l00004ooooo`;o00001_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Loooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Rooooo`0300000?l0003o000005cooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07?oo
ool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05co
oooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooo
ooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000R
ooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1L
ooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`030000002P
8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l00000G?ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooooooo
05cooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`1Looooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`1Looooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`1Looooocl00000G_ooool00`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooo
ooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000o`000?l00000nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool0nOooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool001?ooooo0ol00004ooooo`;o00001_oo
ool00`00003oooooooooo`3iooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00001Oooool00`00003oooooooooo`3iooooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`3iooooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
4oooool3o`0000?ooooo00Co0000oooooooooooo00001Oooool00`00003o0000o`00003iooooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool06oooool3000001?ooooo000Booooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo
0?Wooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005
ooooo`0300000?oooooooooo0?Wooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Cooooo`?o00001?ooool2o`0000Kooooo00<00000oooo
ooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l00000nOooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000
ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOoo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000o`000?l00000nOooool00`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000oooo
ooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool0nOoooolo000001oooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool0oooooomHooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo0?ooooooF?ooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`1Looooo`03o`000?oooooooooo09[ooooo00<00000ooooooooool0Foooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`1Looooo`03o`000?oooooooooo09[ooooo
00<00000ooooooooool0Foooool00`00003oooooooooo`0Aooooo`008_oooooo000005`000004ooo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool008_ooooo0ol0003oooooo`?ooooo002>ooooo`03o`000?oooooooooo0?oooooo001/ooooo`?o
000000Coooooo`000?l0003ooooo0ol00002ooooo`Go000000?oooooo`000?l000000ol00002oooo
o`?o00000oooool4o`000003ooooool0003o000000;o0000Ooooool3o`0000;ooooo1Ol00002oooo
o`Co00000_ooool3o`0006Sooooo001]ooooo`06o`000?ooooooooooo`000?oooooo00001oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0OOooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0001[ooooo`00
KOooool00ol0003oooooo`000002ooooo`Go00000oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?o
0000P?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`05o`0006Oooooo001]ooooo`;o00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooool000000oooool00ol0003oooooo`000023ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
IOooool006gooooo00?o0000ooooool000000oooool3o`0000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`?o00000oooool5o`000003ooooool0003o000000;o0000OOoo
ool01_l0003oooooo`000?oooooo0000ooooo`?o00001?ooool3o`0000?ooooo0ol0001Xooooo`00
KOooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Soooool01Ol0003oooooo`000?oooooo000000[ooooo00?o0000ooooooooool0K?ooool006co
oooo0ol000000ooooooo0000o`000006ooooo`?o00000oooool3o`00097ooooo1Ol00003ooooo`03
o`000?oooooooooo00?ooooo0_l0001^ooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.378218, -9.66572, \
0.00636706, 0.45157}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2d mixture-of-Gaussians classification (RG plane)", "Section"],

Cell[CellGroupData[{

Cell["Visualize distributions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(which = {1, 2};\)\), "\[IndentingNewLine]", 
    \(\(gobj1\  = \ 
        PlotRepresentativeSample2D[data1, \ 2000, which, 
          pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample2D[data2, \ 2000, which, 
          pointStyle2];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Show[gobj1, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Show[gobj2, FrameTicks \[Rule] False, FrameLabel \[Rule] None, 
          nS];\)\), "\[IndentingNewLine]", 
    \(\(gbase = Show[g1, g2, nS];\)\), "\[IndentingNewLine]", 
    \(\(Show[GraphicsArray[{g1, g2}], \ imSize, \ yS];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47619 
%%ImageSize: 400 190.476 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0113379 0.47619 [
[ 0 0 0 0 ]
[ 1 .47619 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .47619 L
0 .47619 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0113379 0.477324 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.96078 .96078 Mdot
.71373 .72157 Mdot
.52941 .52549 Mdot
.13725 .14902 Mdot
.87843 .88235 Mdot
.11373 .1098 Mdot
.1098 .11373 Mdot
.77647 .78039 Mdot
.15294 .14902 Mdot
.13725 .12549 Mdot
.13333 .1451 Mdot
.1451 .13333 Mdot
.20784 .18824 Mdot
.17255 .15686 Mdot
.4902 .49804 Mdot
.1451 .13333 Mdot
.26275 .23137 Mdot
.23529 .21569 Mdot
.47451 .48235 Mdot
.89804 .82745 Mdot
1 .96863 Mdot
.13333 .12941 Mdot
.20784 .18824 Mdot
.24706 .20784 Mdot
.11373 .11765 Mdot
.3451 .16863 Mdot
.49804 .32941 Mdot
.65098 .53725 Mdot
.84314 .74902 Mdot
.94902 .89412 Mdot
.1451 .14118 Mdot
.18431 .16863 Mdot
.20392 .17647 Mdot
.20784 .20784 Mdot
.55294 .39216 Mdot
.41176 .14118 Mdot
.42353 .22745 Mdot
.36078 .2 Mdot
.38824 .25882 Mdot
.21569 .19608 Mdot
.21569 .20392 Mdot
.18824 .16863 Mdot
.22353 .20784 Mdot
.25098 .25098 Mdot
.52941 .17647 Mdot
.47843 .16863 Mdot
.41961 .19608 Mdot
.44706 .25882 Mdot
.33725 .17647 Mdot
.1451 .12941 Mdot
.14902 .11765 Mdot
.17647 .1451 Mdot
.24706 .23529 Mdot
1 .93725 Mdot
.58824 .18824 Mdot
.51373 .18039 Mdot
.45882 .22353 Mdot
.43137 .21569 Mdot
.43529 .26667 Mdot
.15686 .13725 Mdot
.21961 .19216 Mdot
.18039 .14902 Mdot
.26667 .26667 Mdot
1 .96471 Mdot
.77647 .36078 Mdot
.61176 .25882 Mdot
.45098 .2 Mdot
.4549 .25882 Mdot
.42745 .18824 Mdot
.18039 .14902 Mdot
.25098 .20784 Mdot
.14902 .11765 Mdot
.21961 .2 Mdot
.50196 .50196 Mdot
.73725 .32157 Mdot
.58039 .21176 Mdot
.4549 .18431 Mdot
.51765 .32157 Mdot
.46275 .18431 Mdot
.21176 .11765 Mdot
.18824 .15294 Mdot
.19608 .16471 Mdot
.18431 .16471 Mdot
.16471 .16078 Mdot
.82353 .72549 Mdot
.65882 .25098 Mdot
.53725 .16863 Mdot
.54118 .28627 Mdot
.54118 .34118 Mdot
.50588 .18824 Mdot
.23137 .07059 Mdot
.16471 .13725 Mdot
.23922 .21176 Mdot
.25882 .24706 Mdot
.14118 .13725 Mdot
.52941 .44314 Mdot
.37255 .12549 Mdot
.57647 .18824 Mdot
.5451 .17255 Mdot
.77255 .5451 Mdot
.64706 .43922 Mdot
.52549 .17255 Mdot
.28235 .09804 Mdot
.16863 .14118 Mdot
.27843 .25098 Mdot
.18431 .18039 Mdot
.15294 .10588 Mdot
.2902 .17255 Mdot
.96078 .92549 Mdot
.63922 .23922 Mdot
.54902 .16471 Mdot
.55686 .2 Mdot
.58039 .38039 Mdot
.49804 .2549 Mdot
.67059 .27059 Mdot
.23529 .11765 Mdot
.17255 .14118 Mdot
.22353 .21176 Mdot
.16863 .14902 Mdot
.29804 .12157 Mdot
.33725 .22353 Mdot
.8902 .82353 Mdot
.62353 .22353 Mdot
.56471 .16471 Mdot
.58824 .15686 Mdot
.55294 .33725 Mdot
.71373 .49412 Mdot
.53725 .2 Mdot
.5098 .2549 Mdot
.2 .13725 Mdot
.18431 .1451 Mdot
.18039 .14902 Mdot
.20392 .01961 Mdot
.67059 .51373 Mdot
.35294 .24706 Mdot
.88627 .83529 Mdot
.63137 .21961 Mdot
.59216 .16078 Mdot
.64706 .18039 Mdot
.78431 .55294 Mdot
.83137 .61569 Mdot
.67059 .41176 Mdot
.47451 .24706 Mdot
.27059 .15686 Mdot
.2 .13725 Mdot
.19216 .1098 Mdot
.33725 .10196 Mdot
.63529 .47843 Mdot
.61569 .50196 Mdot
.34902 .23529 Mdot
1 .97255 Mdot
.63137 .19216 Mdot
.64314 .17647 Mdot
.67059 .2 Mdot
.80392 .57255 Mdot
.41961 .21176 Mdot
.68627 .47059 Mdot
.8 .62745 Mdot
.25098 .12549 Mdot
.21961 .11765 Mdot
.26275 .08235 Mdot
.42745 .18039 Mdot
.66275 .52549 Mdot
.61569 .5098 Mdot
.41569 .29412 Mdot
.76078 .7098 Mdot
.53333 .19608 Mdot
.72549 .25882 Mdot
.66275 .19216 Mdot
.64314 .19216 Mdot
.83529 .63922 Mdot
.67059 .43922 Mdot
.58431 .40392 Mdot
.52157 .39608 Mdot
.37647 .18431 Mdot
.28235 .09412 Mdot
.49412 .18039 Mdot
.46667 .27451 Mdot
.56471 .47451 Mdot
.6 .49412 Mdot
.50588 .40392 Mdot
.63137 .56078 Mdot
.44706 .16863 Mdot
.67451 .23137 Mdot
.90196 .44706 Mdot
.76471 .27451 Mdot
.90588 .65098 Mdot
.48235 .26667 Mdot
.93333 .76078 Mdot
.61569 .50588 Mdot
.59216 .40784 Mdot
.38431 .20392 Mdot
.61176 .2549 Mdot
.63922 .44314 Mdot
.72549 .60392 Mdot
.58824 .48627 Mdot
.64706 .54118 Mdot
.39608 .29412 Mdot
.78824 .74902 Mdot
.60784 .21569 Mdot
.73725 .38039 Mdot
.83922 .38824 Mdot
.83922 .34902 Mdot
.9451 .69412 Mdot
.57647 .35294 Mdot
.76471 .61569 Mdot
.66275 .54902 Mdot
.39608 .2549 Mdot
.56471 .38824 Mdot
.6549 .29804 Mdot
.62745 .41569 Mdot
.72549 .6 Mdot
.54902 .38824 Mdot
.61961 .51765 Mdot
.62745 .52941 Mdot
.34118 .23922 Mdot
.98039 .9098 Mdot
.71373 .2549 Mdot
.92157 .57255 Mdot
.67843 .25098 Mdot
.8549 .38824 Mdot
.98431 .74902 Mdot
.54118 .27843 Mdot
.72941 .60784 Mdot
1 .88627 Mdot
1 .89804 Mdot
.84706 .64314 Mdot
.63922 .32157 Mdot
.67059 .44314 Mdot
.68627 .5451 Mdot
.49804 .32941 Mdot
.61569 .51373 Mdot
.65882 .55294 Mdot
.27059 .17255 Mdot
.91373 .87843 Mdot
.64314 .18431 Mdot
.85098 .54902 Mdot
.8902 .59216 Mdot
.67059 .25882 Mdot
.82745 .41961 Mdot
1 .85098 Mdot
.95294 .78431 Mdot
.85098 .73333 Mdot
.83529 .71765 Mdot
.81961 .67059 Mdot
.53333 .22353 Mdot
.67451 .37647 Mdot
.47843 .2549 Mdot
.51373 .32549 Mdot
.53333 .35686 Mdot
.64314 .56078 Mdot
.63922 .5451 Mdot
.23922 .13333 Mdot
.92941 .89412 Mdot
.5451 .54118 Mdot
.38431 .38824 Mdot
.56078 .18824 Mdot
.69412 .26667 Mdot
.56863 .29412 Mdot
.84314 .56471 Mdot
.74118 .29412 Mdot
.77647 .43137 Mdot
.67451 .38431 Mdot
.75294 .63529 Mdot
.95686 .75686 Mdot
.50588 .3451 Mdot
.86275 .6549 Mdot
.47451 .16471 Mdot
.66667 .33725 Mdot
.64314 .4902 Mdot
.52157 .3098 Mdot
.63529 .4902 Mdot
.63137 .58431 Mdot
.63529 .54118 Mdot
.20784 .12549 Mdot
.93725 .90196 Mdot
.18431 .16863 Mdot
.21569 .20392 Mdot
.83137 .83137 Mdot
.74902 .25098 Mdot
.93725 .70196 Mdot
1 .86667 Mdot
.83529 .53333 Mdot
.77647 .3451 Mdot
.57647 .2549 Mdot
.69804 .38824 Mdot
.89804 .74118 Mdot
.91765 .58431 Mdot
.98431 .79216 Mdot
.90196 .66667 Mdot
.48235 .18039 Mdot
.53333 .21569 Mdot
.55686 .43529 Mdot
.5098 .2902 Mdot
.61961 .47059 Mdot
.60392 .58824 Mdot
.61569 .5451 Mdot
.31373 .22353 Mdot
.66275 .60392 Mdot
.11373 .1098 Mdot
.24706 .21569 Mdot
.23137 .21961 Mdot
.86275 .76863 Mdot
.73333 .23529 Mdot
.98431 .84314 Mdot
.95686 .84706 Mdot
.66667 .3098 Mdot
.94902 .49412 Mdot
.61176 .26667 Mdot
.81569 .4902 Mdot
.86667 .68627 Mdot
.7451 .33333 Mdot
.9098 .67059 Mdot
.77647 .53725 Mdot
.56078 .25882 Mdot
.48235 .17255 Mdot
.58431 .47843 Mdot
.50196 .23529 Mdot
.56471 .41176 Mdot
.47843 .48235 Mdot
.61961 .56863 Mdot
.52941 .41176 Mdot
.22745 .15294 Mdot
.71373 .71765 Mdot
.27059 .25098 Mdot
.30196 .26667 Mdot
.1098 .1098 Mdot
.66275 .23529 Mdot
.6 .27059 Mdot
.98431 .85098 Mdot
.72157 .59608 Mdot
.8 .28627 Mdot
.95294 .48627 Mdot
.71373 .29804 Mdot
.80784 .52941 Mdot
.78039 .43922 Mdot
.86667 .49804 Mdot
.92157 .62745 Mdot
.82745 .56863 Mdot
.69412 .30196 Mdot
.81569 .63922 Mdot
.47451 .27059 Mdot
.5451 .22353 Mdot
.65098 .60784 Mdot
.42353 .41961 Mdot
.58039 .52157 Mdot
.51373 .38039 Mdot
.19216 .12157 Mdot
.12157 .12157 Mdot
.21176 .18039 Mdot
.21961 .17647 Mdot
.15294 .14118 Mdot
.59608 .21176 Mdot
.65882 .35294 Mdot
.83922 .68627 Mdot
.78431 .67059 Mdot
.80784 .32157 Mdot
.83137 .32549 Mdot
.9451 .51373 Mdot
.63922 .34902 Mdot
1 .78431 Mdot
.79608 .38824 Mdot
.64314 .29412 Mdot
.58431 .27843 Mdot
.60392 .25098 Mdot
.41176 .11765 Mdot
.41176 .24314 Mdot
.55294 .18824 Mdot
.40784 .27059 Mdot
.40392 .41569 Mdot
.52549 .46667 Mdot
.46667 .33725 Mdot
.4549 .3451 Mdot
.1098 .09804 Mdot
.22353 .20392 Mdot
.27843 .23529 Mdot
.27059 .2549 Mdot
.46667 .27843 Mdot
.6 .22353 Mdot
.76863 .60392 Mdot
.94902 .79216 Mdot
.64314 .4 Mdot
.81569 .30196 Mdot
.81569 .32157 Mdot
.74118 .47843 Mdot
.69804 .46667 Mdot
.75686 .29804 Mdot
.6902 .42353 Mdot
.69412 .34118 Mdot
1 .75686 Mdot
.59608 .16078 Mdot
.70588 .56471 Mdot
.54118 .19608 Mdot
.53333 .22353 Mdot
.49804 .50196 Mdot
.52549 .41569 Mdot
.4902 .40784 Mdot
.43922 .31765 Mdot
.34118 .30196 Mdot
.13333 .10196 Mdot
.21176 .18431 Mdot
.21961 .18431 Mdot
.35686 .36471 Mdot
.73333 .24706 Mdot
.83529 .65098 Mdot
.86275 .66667 Mdot
.8902 .77255 Mdot
.73333 .42353 Mdot
.83137 .28627 Mdot
.64706 .32941 Mdot
.70196 .60392 Mdot
.76078 .36471 Mdot
.70588 .41176 Mdot
.74118 .46275 Mdot
.61961 .38431 Mdot
.62353 .20784 Mdot
.47843 .13333 Mdot
.64706 .45098 Mdot
.55686 .18431 Mdot
.3451 .18824 Mdot
.43137 .38824 Mdot
.4549 .33725 Mdot
.49412 .40784 Mdot
.38039 .2902 Mdot
.18039 .15294 Mdot
.18431 .16471 Mdot
.20392 .17255 Mdot
.28627 .27451 Mdot
.56078 .41176 Mdot
.7451 .26275 Mdot
.90196 .73333 Mdot
.82353 .67451 Mdot
.83922 .70588 Mdot
.94118 .55686 Mdot
.78431 .33333 Mdot
.73333 .61569 Mdot
.63137 .53333 Mdot
.74118 .28235 Mdot
.63137 .4549 Mdot
.68627 .4902 Mdot
.57647 .34118 Mdot
.66275 .18824 Mdot
.52941 .26275 Mdot
.41569 .16863 Mdot
.4902 .18431 Mdot
.5451 .47843 Mdot
.6902 .58431 Mdot
.38431 .26275 Mdot
.43922 .35686 Mdot
.50588 .45098 Mdot
.17647 .14118 Mdot
.15294 .12549 Mdot
.15686 .12157 Mdot
.14118 .1451 Mdot
.63529 .24706 Mdot
.50196 .19216 Mdot
.6902 .5098 Mdot
.94118 .8 Mdot
.8 .68627 Mdot
.8 .28627 Mdot
.59216 .37647 Mdot
.63137 .58039 Mdot
.6902 .53333 Mdot
.74118 .28627 Mdot
.54902 .45882 Mdot
.58824 .46275 Mdot
.72157 .40784 Mdot
.66275 .21176 Mdot
.9098 .72157 Mdot
.5098 .21961 Mdot
.47451 .22353 Mdot
.67843 .64706 Mdot
.38039 .21176 Mdot
.52157 .38431 Mdot
.36471 .26667 Mdot
.13333 .09412 Mdot
.15294 .11765 Mdot
.22353 .19608 Mdot
.21961 .20392 Mdot
.81176 .80784 Mdot
.69412 .21176 Mdot
.9098 .74118 Mdot
.95294 .78824 Mdot
.82745 .67843 Mdot
1 .83922 Mdot
.72941 .31373 Mdot
.63529 .56863 Mdot
.61569 .57255 Mdot
.81961 .56471 Mdot
.66667 .28235 Mdot
.53725 .46667 Mdot
.52941 .45098 Mdot
.70196 .3098 Mdot
.63529 .25882 Mdot
.75294 .61961 Mdot
.5451 .24314 Mdot
.57647 .35686 Mdot
.54902 .53725 Mdot
.59608 .37647 Mdot
.49804 .32157 Mdot
.52549 .40392 Mdot
.1451 .11765 Mdot
.16471 .12941 Mdot
.19608 .16863 Mdot
.18824 .18431 Mdot
.44314 .21569 Mdot
.63137 .24706 Mdot
.96471 .79216 Mdot
.83922 .67451 Mdot
.83529 .70196 Mdot
.67451 .3098 Mdot
.65098 .45882 Mdot
.59216 .54902 Mdot
.60784 .56471 Mdot
.76471 .40392 Mdot
.56863 .29804 Mdot
.52941 .4902 Mdot
.61176 .4549 Mdot
.61176 .27843 Mdot
.60784 .31765 Mdot
.74118 .61176 Mdot
.49412 .2 Mdot
.58824 .38039 Mdot
.23922 .19608 Mdot
.5451 .31373 Mdot
.55294 .36471 Mdot
.38824 .28235 Mdot
.19216 .16471 Mdot
.15686 .12157 Mdot
.24314 .22353 Mdot
.12549 .10588 Mdot
.57647 .4549 Mdot
.7451 .25882 Mdot
.83922 .67451 Mdot
.61176 .43922 Mdot
.80392 .6549 Mdot
.89412 .70588 Mdot
.66667 .47059 Mdot
.63137 .58039 Mdot
.59608 .55294 Mdot
.81176 .59608 Mdot
.69804 .31373 Mdot
.54902 .50588 Mdot
.56078 .46275 Mdot
.54118 .24314 Mdot
.63137 .43529 Mdot
.83922 .7451 Mdot
.40392 .18431 Mdot
.4902 .19608 Mdot
.69412 .64706 Mdot
.54902 .37647 Mdot
.53725 .31373 Mdot
.59608 .48235 Mdot
.1451 .10588 Mdot
.26667 .23137 Mdot
.15294 .13333 Mdot
.17255 .14118 Mdot
.85882 .79216 Mdot
.68235 .23137 Mdot
.5451 .21569 Mdot
.70588 .51765 Mdot
.71373 .52941 Mdot
.92549 .8 Mdot
.64706 .33333 Mdot
.65882 .60392 Mdot
.61961 .57647 Mdot
.61961 .56078 Mdot
.72941 .37255 Mdot
.63137 .43529 Mdot
.52941 .4902 Mdot
.67451 .38824 Mdot
.57647 .45882 Mdot
.49804 .4 Mdot
.79216 .69804 Mdot
.43529 .20392 Mdot
.37647 .18431 Mdot
.24314 .2 Mdot
.59608 .42745 Mdot
.36863 .19216 Mdot
.77647 .70588 Mdot
.18039 .14902 Mdot
.24314 .2 Mdot
.15686 .12157 Mdot
.15686 .08627 Mdot
.8549 .79608 Mdot
.67843 .20784 Mdot
.65882 .27843 Mdot
.77255 .58431 Mdot
.76471 .58431 Mdot
.7451 .62353 Mdot
.58431 .32157 Mdot
.60392 .55294 Mdot
.68235 .63137 Mdot
.62353 .56863 Mdot
.76863 .4902 Mdot
.57255 .32549 Mdot
.54118 .49412 Mdot
.61176 .31765 Mdot
.54902 .46667 Mdot
.53333 .46275 Mdot
.74902 .67451 Mdot
.72941 .58824 Mdot
.36863 .20784 Mdot
.37255 .34902 Mdot
.47843 .36471 Mdot
.51765 .38039 Mdot
.79216 .72549 Mdot
.18824 .15294 Mdot
.32941 .27843 Mdot
.21569 .17647 Mdot
.18824 .11765 Mdot
.55686 .43922 Mdot
.84314 .73333 Mdot
.77255 .23529 Mdot
.38431 .17647 Mdot
.76471 .57647 Mdot
.75294 .58824 Mdot
.93725 .77647 Mdot
.68627 .56471 Mdot
.63922 .58824 Mdot
.67059 .63137 Mdot
.61569 .55686 Mdot
.7098 .36863 Mdot
.65098 .48235 Mdot
.57255 .47451 Mdot
.49412 .25098 Mdot
.52157 .47843 Mdot
.53333 .47843 Mdot
.67843 .60784 Mdot
.80392 .70196 Mdot
.2549 .16863 Mdot
.42353 .4 Mdot
.39216 .30196 Mdot
.64706 .54118 Mdot
.85882 .81961 Mdot
.17255 .13333 Mdot
.24706 .19216 Mdot
.2 .14902 Mdot
.62353 .53725 Mdot
.55686 .41569 Mdot
1 .96863 Mdot
.75294 .22745 Mdot
.56471 .22353 Mdot
.87059 .68235 Mdot
.6902 .53333 Mdot
.85882 .72549 Mdot
.68235 .51765 Mdot
.60784 .56471 Mdot
.78431 .7451 Mdot
.63137 .58824 Mdot
.76078 .56078 Mdot
.59608 .2902 Mdot
.56863 .48235 Mdot
.55686 .2902 Mdot
.54118 .49412 Mdot
.50588 .45882 Mdot
.54118 .48627 Mdot
.72549 .6549 Mdot
.77255 .6902 Mdot
.56078 .57647 Mdot
.48627 .38039 Mdot
.34902 .2549 Mdot
.8549 .81569 Mdot
.43137 .40784 Mdot
.20784 .15294 Mdot
.19216 .13333 Mdot
.46275 .40392 Mdot
.57255 .43137 Mdot
.5451 .43922 Mdot
.68627 .53725 Mdot
.75686 .21961 Mdot
.77647 .47059 Mdot
.87843 .68235 Mdot
.9098 .76863 Mdot
1 .87451 Mdot
.37647 .29412 Mdot
.59608 .55294 Mdot
.7098 .67059 Mdot
.61961 .58431 Mdot
.78824 .57255 Mdot
.59216 .30196 Mdot
.62745 .46667 Mdot
.57647 .4 Mdot
.52157 .47451 Mdot
.52157 .47451 Mdot
.52549 .47059 Mdot
.56863 .51373 Mdot
.83137 .76863 Mdot
.36863 .37647 Mdot
.57255 .45882 Mdot
.53725 .44706 Mdot
.87451 .84706 Mdot
.73725 .71765 Mdot
.18431 .13725 Mdot
.21961 .16863 Mdot
.42353 .35686 Mdot
.64314 .50196 Mdot
.56471 .46667 Mdot
.99216 .98039 Mdot
.68627 .18824 Mdot
.78039 .25098 Mdot
.84706 .51765 Mdot
.71373 .57647 Mdot
.93725 .67059 Mdot
.72549 .56471 Mdot
.61569 .57647 Mdot
.61961 .57647 Mdot
.82353 .78431 Mdot
.63529 .57647 Mdot
.73725 .34118 Mdot
.63137 .49412 Mdot
.56471 .28235 Mdot
.52941 .48235 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.53333 .48235 Mdot
.57647 .51765 Mdot
.77647 .78039 Mdot
.66667 .54902 Mdot
.5451 .46667 Mdot
.74118 .68627 Mdot
.8902 .89804 Mdot
.71373 .69804 Mdot
.56471 .52549 Mdot
.64314 .58039 Mdot
.49804 .38824 Mdot
.54902 .47451 Mdot
.3451 .26667 Mdot
.53333 .23529 Mdot
.77647 .25098 Mdot
.6902 .17647 Mdot
.93333 .7451 Mdot
.75686 .59608 Mdot
.75686 .45098 Mdot
.49804 .4549 Mdot
.61961 .56863 Mdot
.62745 .58431 Mdot
.6902 .6549 Mdot
.73725 .57647 Mdot
.6 .2549 Mdot
.76078 .47843 Mdot
.57647 .48235 Mdot
.52157 .48235 Mdot
.52941 .48235 Mdot
.52549 .47843 Mdot
.52157 .47843 Mdot
.58824 .52941 Mdot
.42353 .44314 Mdot
.8902 .74118 Mdot
.76471 .70196 Mdot
.86667 .8549 Mdot
.91765 .92549 Mdot
.8549 .8549 Mdot
.83529 .78431 Mdot
.35294 .24314 Mdot
.51373 .42745 Mdot
.6 .53333 Mdot
.4549 .43137 Mdot
.67451 .2 Mdot
.69804 .21176 Mdot
.78824 .27843 Mdot
.99216 .82353 Mdot
.70588 .38039 Mdot
.69804 .4902 Mdot
.44706 .40392 Mdot
.62745 .58431 Mdot
.61961 .57647 Mdot
.71373 .67451 Mdot
.80392 .55686 Mdot
.63922 .32549 Mdot
.62745 .31373 Mdot
.52549 .48627 Mdot
.5451 .50588 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.54902 .49412 Mdot
.58039 .53725 Mdot
.47451 .44314 Mdot
.83137 .76078 Mdot
.78431 .7451 Mdot
.9098 .9098 Mdot
.88235 .88627 Mdot
.90588 .90196 Mdot
.75686 .69804 Mdot
.47843 .33725 Mdot
.40784 .37647 Mdot
.6 .54902 Mdot
.81569 .72157 Mdot
.74118 .24706 Mdot
.78824 .2549 Mdot
.7451 .2902 Mdot
.52941 .2549 Mdot
.79216 .28627 Mdot
.61569 .54118 Mdot
.41569 .37255 Mdot
.61569 .57647 Mdot
.63922 .6 Mdot
.75686 .70588 Mdot
.7098 .36863 Mdot
.69804 .34118 Mdot
.67843 .46275 Mdot
.55686 .50196 Mdot
.52941 .4902 Mdot
.53725 .4902 Mdot
.53333 .4902 Mdot
.56471 .50196 Mdot
.76471 .77255 Mdot
.93333 .83922 Mdot
.85882 .82745 Mdot
.82353 .8 Mdot
.88627 .8902 Mdot
.87451 .8902 Mdot
.8549 .83137 Mdot
.49412 .40392 Mdot
.45882 .31765 Mdot
.41569 .39216 Mdot
.67451 .64706 Mdot
.56471 .23529 Mdot
.67843 .22745 Mdot
.78431 .24706 Mdot
.6549 .23922 Mdot
1 .65098 Mdot
.63529 .27843 Mdot
.60392 .56078 Mdot
.41176 .36863 Mdot
.61569 .57255 Mdot
.62353 .58039 Mdot
.80784 .72549 Mdot
.77255 .39608 Mdot
.71765 .31373 Mdot
.66275 .47451 Mdot
.56863 .49804 Mdot
.54118 .49804 Mdot
.53725 .49804 Mdot
.56078 .50588 Mdot
.57255 .5098 Mdot
.87843 .87843 Mdot
.66667 .54118 Mdot
.91765 .87843 Mdot
.8549 .85098 Mdot
.87059 .88235 Mdot
.88235 .89804 Mdot
.82353 .78039 Mdot
.50588 .38824 Mdot
.49804 .38824 Mdot
.43922 .41176 Mdot
.66275 .67451 Mdot
.66275 .23529 Mdot
.83529 .44314 Mdot
.7451 .25098 Mdot
.73725 .27843 Mdot
.83137 .35686 Mdot
.68235 .45098 Mdot
.60392 .56078 Mdot
.53725 .49804 Mdot
.63137 .58824 Mdot
.63922 .59608 Mdot
.92157 .76863 Mdot
.85882 .50196 Mdot
.75294 .34902 Mdot
.68627 .44706 Mdot
.63137 .51765 Mdot
.57647 .50588 Mdot
.55686 .50196 Mdot
.59608 .52549 Mdot
.78039 .74118 Mdot
.61176 .58431 Mdot
.64706 .53725 Mdot
.94118 .87059 Mdot
.8902 .87451 Mdot
.88235 .8902 Mdot
.87451 .88235 Mdot
.8 .74902 Mdot
.51373 .41569 Mdot
.4549 .35294 Mdot
.46275 .42353 Mdot
.97255 .97647 Mdot
.66667 .2 Mdot
.6902 .32941 Mdot
.69412 .27059 Mdot
.76863 .27059 Mdot
.81569 .28627 Mdot
.67451 .5451 Mdot
.60392 .56078 Mdot
.61569 .58824 Mdot
.63922 .58431 Mdot
.63529 .59216 Mdot
.95686 .70196 Mdot
.98039 .62353 Mdot
.82745 .44314 Mdot
.62353 .29412 Mdot
.67843 .47843 Mdot
.60784 .50588 Mdot
.61176 .54902 Mdot
.58039 .51373 Mdot
.84706 .81569 Mdot
.62745 .60392 Mdot
.41961 .27451 Mdot
.95686 .83529 Mdot
.95294 .9098 Mdot
.86275 .87843 Mdot
.86275 .87059 Mdot
.82745 .77647 Mdot
.61176 .54902 Mdot
.46275 .38431 Mdot
.45882 .40392 Mdot
.89804 .84314 Mdot
.72157 .25098 Mdot
.70588 .39216 Mdot
.56078 .23137 Mdot
.77647 .26667 Mdot
.78431 .27059 Mdot
.61961 .5451 Mdot
.61961 .56471 Mdot
.62745 .6 Mdot
.5451 .4902 Mdot
.64314 .58824 Mdot
.78431 .40392 Mdot
.83137 .45882 Mdot
.90588 .50588 Mdot
.64706 .2549 Mdot
.69804 .40784 Mdot
.65882 .50196 Mdot
.60392 .53333 Mdot
.77255 .73725 Mdot
.63137 .60784 Mdot
.63137 .6 Mdot
.44314 .27843 Mdot
.78824 .6549 Mdot
.94118 .86275 Mdot
.8902 .86275 Mdot
.8549 .84706 Mdot
.82353 .78431 Mdot
.66275 .61961 Mdot
.64314 .58824 Mdot
.47059 .43529 Mdot
.45098 .32157 Mdot
.72549 .25882 Mdot
.58824 .36471 Mdot
.67451 .47059 Mdot
.77647 .26667 Mdot
.7451 .29804 Mdot
.58824 .5451 Mdot
.6 .55686 Mdot
.61569 .58039 Mdot
.39608 .34118 Mdot
.65882 .56471 Mdot
.85882 .37255 Mdot
.66275 .24706 Mdot
.9098 .5098 Mdot
.77255 .36471 Mdot
.65098 .26667 Mdot
.71373 .47843 Mdot
.62745 .56471 Mdot
.77647 .75686 Mdot
.62745 .60784 Mdot
.62353 .59216 Mdot
.22745 .11765 Mdot
.62745 .49804 Mdot
.91765 .77255 Mdot
.92549 .8549 Mdot
.87451 .85098 Mdot
.83529 .81176 Mdot
.77255 .7451 Mdot
.82745 .79216 Mdot
.73333 .72157 Mdot
.49804 .26667 Mdot
.7098 .26667 Mdot
.8902 .73333 Mdot
.90196 .76078 Mdot
.79216 .26667 Mdot
.61961 .2902 Mdot
.60392 .56078 Mdot
.61961 .57647 Mdot
.61961 .58431 Mdot
.29412 .25098 Mdot
.71765 .53725 Mdot
.83922 .30196 Mdot
.65098 .19608 Mdot
.87843 .46275 Mdot
.8902 .43922 Mdot
.70196 .27451 Mdot
.58039 .33333 Mdot
.80784 .76471 Mdot
.63137 .61569 Mdot
.62745 .60392 Mdot
.66667 .62745 Mdot
.29412 .23922 Mdot
.87451 .76471 Mdot
.73333 .58431 Mdot
.92549 .81569 Mdot
.93725 .86667 Mdot
.85098 .81569 Mdot
.77255 .74902 Mdot
.8 .77647 Mdot
.69412 .70196 Mdot
.57647 .26667 Mdot
.65882 .24706 Mdot
.94118 .81569 Mdot
.63529 .47451 Mdot
.78431 .25098 Mdot
.71765 .50196 Mdot
.60392 .56078 Mdot
.62745 .58431 Mdot
.61176 .56863 Mdot
.36863 .32549 Mdot
.86275 .56078 Mdot
.8549 .30588 Mdot
.79608 .2902 Mdot
.75686 .31765 Mdot
.8549 .40784 Mdot
.82745 .41961 Mdot
.66275 .4549 Mdot
.72941 .68627 Mdot
.64314 .61961 Mdot
.63529 .60784 Mdot
.72157 .68627 Mdot
.84706 .82745 Mdot
.94902 .90588 Mdot
.69804 .60392 Mdot
.78824 .61569 Mdot
1 .8549 Mdot
.89412 .83137 Mdot
.80784 .77647 Mdot
.89804 .87059 Mdot
.64706 .65882 Mdot
.62745 .21569 Mdot
.69412 .38039 Mdot
.21569 .10196 Mdot
.57255 .30588 Mdot
.76471 .26667 Mdot
.61569 .54118 Mdot
.6 .55686 Mdot
.61176 .57647 Mdot
.6 .56471 Mdot
.43529 .37255 Mdot
.78824 .31373 Mdot
.83529 .29412 Mdot
.81961 .29804 Mdot
.67451 .21961 Mdot
.81569 .36863 Mdot
.87451 .46667 Mdot
.92549 .83922 Mdot
.63137 .6 Mdot
.64314 .61961 Mdot
.61569 .59216 Mdot
.17255 .14902 Mdot
.90196 .89804 Mdot
.93333 .89412 Mdot
.91765 .82745 Mdot
.58431 .39608 Mdot
.89412 .73725 Mdot
.93725 .84314 Mdot
.8 .76471 Mdot
.94902 .92157 Mdot
.90588 .86275 Mdot
.74118 .28235 Mdot
.55294 .34118 Mdot
.97647 .87059 Mdot
.65882 .29804 Mdot
.65882 .28627 Mdot
.6 .55686 Mdot
.60784 .56471 Mdot
.59608 .55294 Mdot
.60784 .57255 Mdot
.54902 .36471 Mdot
.72549 .27059 Mdot
.81961 .29412 Mdot
.83922 .30588 Mdot
.68235 .18824 Mdot
.80784 .39608 Mdot
.72941 .35686 Mdot
.64706 .59608 Mdot
.62353 .6 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.15686 .14118 Mdot
.92549 .89412 Mdot
.94118 .89804 Mdot
.96078 .9098 Mdot
.7451 .61569 Mdot
.67059 .45098 Mdot
.92549 .76471 Mdot
.87843 .80784 Mdot
.51765 .51373 Mdot
.60392 .41176 Mdot
.69804 .2902 Mdot
.82353 .68627 Mdot
.6549 .45098 Mdot
.70196 .23922 Mdot
.58039 .46667 Mdot
.60784 .56471 Mdot
.6 .55686 Mdot
.60784 .57255 Mdot
.61961 .57647 Mdot
.75686 .30588 Mdot
.60392 .23922 Mdot
.81176 .30196 Mdot
.82745 .28627 Mdot
.74902 .2549 Mdot
.81176 .38039 Mdot
.56471 .38039 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.61961 .59216 Mdot
.59608 .57647 Mdot
.96471 .9451 Mdot
.92157 .82353 Mdot
.93333 .90588 Mdot
.94902 .91765 Mdot
.92157 .78431 Mdot
.51765 .28235 Mdot
.8902 .81176 Mdot
.58039 .51373 Mdot
.97255 .98039 Mdot
.6902 .28235 Mdot
.68627 .41176 Mdot
.84314 .68627 Mdot
.90196 .60392 Mdot
.64706 .29412 Mdot
.6 .55686 Mdot
.61961 .56863 Mdot
.60784 .56471 Mdot
.61176 .56863 Mdot
.80392 .55686 Mdot
.62353 .2902 Mdot
.57647 .27451 Mdot
.8 .3098 Mdot
.83529 .28627 Mdot
.78039 .25882 Mdot
.68627 .26275 Mdot
.63137 .58431 Mdot
.61569 .59216 Mdot
.60784 .58824 Mdot
.61961 .60784 Mdot
.16471 .14118 Mdot
.97647 .87451 Mdot
.91373 .78431 Mdot
.92549 .91765 Mdot
.95686 .91373 Mdot
.97255 .8902 Mdot
.48627 .32941 Mdot
.64314 .5451 Mdot
.48627 .4902 Mdot
.33333 .25882 Mdot
.70196 .28627 Mdot
.55294 .28627 Mdot
.90588 .67451 Mdot
.63529 .16471 Mdot
.62745 .51373 Mdot
.60784 .55294 Mdot
.61569 .57255 Mdot
.61569 .57255 Mdot
.64706 .57647 Mdot
.80784 .30196 Mdot
.94118 .80392 Mdot
.58431 .29412 Mdot
.8 .32157 Mdot
.85098 .28235 Mdot
.81961 .28235 Mdot
.56863 .35294 Mdot
.60392 .58039 Mdot
.61176 .59216 Mdot
.62353 .60392 Mdot
.56863 .54118 Mdot
.98824 .92549 Mdot
.69804 .50588 Mdot
.96471 .89804 Mdot
.38431 .36471 Mdot
.91765 .89804 Mdot
.97255 .87059 Mdot
.90196 .81176 Mdot
.88235 .82745 Mdot
.97647 .98431 Mdot
.61176 .25882 Mdot
.58824 .23529 Mdot
.52157 .16471 Mdot
.55686 .16471 Mdot
.61961 .34118 Mdot
.31765 .26275 Mdot
.61961 .56471 Mdot
.60784 .57255 Mdot
.61961 .56471 Mdot
.7451 .32157 Mdot
.63137 .36471 Mdot
.9451 .84314 Mdot
.57255 .29804 Mdot
.83529 .30196 Mdot
.8549 .26667 Mdot
.74902 .34118 Mdot
.60784 .58431 Mdot
.62353 .60392 Mdot
.60392 .59216 Mdot
.6549 .63529 Mdot
.1098 .06275 Mdot
.56471 .36471 Mdot
.81176 .69412 Mdot
.59608 .57647 Mdot
.65882 .62745 Mdot
.9098 .8902 Mdot
.72549 .60392 Mdot
.57647 .52157 Mdot
.66667 .68627 Mdot
.41569 .3098 Mdot
.62353 .23529 Mdot
.59216 .16471 Mdot
.52549 .15294 Mdot
.74118 .28627 Mdot
.63922 .56863 Mdot
.6 .5451 Mdot
.61961 .57647 Mdot
.61569 .57255 Mdot
.78431 .53725 Mdot
.81176 .31373 Mdot
.95294 .81569 Mdot
.93725 .82745 Mdot
.66667 .29804 Mdot
.86275 .27451 Mdot
.82353 .27451 Mdot
.65098 .57255 Mdot
.62353 .60392 Mdot
.62745 .60392 Mdot
.61569 .60392 Mdot
.20392 .16471 Mdot
.51373 .34118 Mdot
.94902 .76471 Mdot
.10588 .06667 Mdot
.87451 .8549 Mdot
.52941 .5098 Mdot
.99608 .88627 Mdot
.52941 .48235 Mdot
.8549 .84706 Mdot
.77647 .76471 Mdot
.61961 .30196 Mdot
.73725 .26275 Mdot
.76078 .30196 Mdot
.79216 .28235 Mdot
.61961 .52549 Mdot
.29412 .23922 Mdot
.62353 .58039 Mdot
.60784 .57255 Mdot
.69412 .51765 Mdot
.83922 .27843 Mdot
.78431 .44706 Mdot
.94902 .83137 Mdot
.95294 .76471 Mdot
.86275 .27843 Mdot
.83529 .26667 Mdot
.69804 .57647 Mdot
.62353 .59608 Mdot
.60392 .59216 Mdot
.64314 .62353 Mdot
.16863 .12941 Mdot
.77255 .66275 Mdot
.70588 .47059 Mdot
.90196 .86667 Mdot
.87843 .85098 Mdot
.8 .76078 Mdot
.96078 .86667 Mdot
.87451 .83529 Mdot
.88627 .88627 Mdot
.97647 .97255 Mdot
.58039 .2902 Mdot
.74118 .25098 Mdot
.76863 .27059 Mdot
.77647 .28627 Mdot
.62745 .56078 Mdot
.40392 .34902 Mdot
.63137 .58824 Mdot
.61176 .57647 Mdot
.83922 .55686 Mdot
.83137 .27059 Mdot
.60392 .22353 Mdot
.95294 .82745 Mdot
1 .81961 Mdot
.8549 .27843 Mdot
.81176 .26667 Mdot
.63922 .57647 Mdot
.62745 .60784 Mdot
.61569 .60392 Mdot
.52549 .50588 Mdot
.21176 .14902 Mdot
.93333 .8 Mdot
.80392 .57647 Mdot
.58824 .5451 Mdot
.52157 .4902 Mdot
.66275 .63137 Mdot
1 .89804 Mdot
.75294 .72549 Mdot
.88627 .88235 Mdot
.82353 .75294 Mdot
.67451 .31765 Mdot
.77647 .25098 Mdot
.81569 .27843 Mdot
.73725 .52941 Mdot
.60392 .56078 Mdot
.4 .35686 Mdot
.61961 .58431 Mdot
.69804 .5451 Mdot
.82745 .28235 Mdot
.78824 .3098 Mdot
.57255 .27843 Mdot
.9098 .85098 Mdot
.82745 .30588 Mdot
.8549 .27843 Mdot
.61569 .42353 Mdot
.57255 .5451 Mdot
.43137 .41961 Mdot
.27843 .26667 Mdot
.21961 .17647 Mdot
.76078 .62745 Mdot
.92157 .72549 Mdot
.9098 .87843 Mdot
.68627 .66667 Mdot
.63137 .6 Mdot
.94118 .88235 Mdot
.93333 .83137 Mdot
.86275 .85882 Mdot
.96863 .97647 Mdot
.55686 .3098 Mdot
.64706 .18824 Mdot
.81569 .27843 Mdot
.74118 .4902 Mdot
.60392 .56078 Mdot
.34902 .30588 Mdot
.63137 .59608 Mdot
.7098 .53333 Mdot
.82745 .28235 Mdot
.75294 .34118 Mdot
.49804 .23137 Mdot
.90196 .8549 Mdot
.82353 .31765 Mdot
.83922 .26275 Mdot
.63529 .44706 Mdot
.27843 .25098 Mdot
.30196 .27843 Mdot
.4549 .44314 Mdot
.20784 .16471 Mdot
.36471 .23137 Mdot
.93333 .73725 Mdot
.8902 .87059 Mdot
.94118 .92157 Mdot
.97255 .95294 Mdot
.92549 .88235 Mdot
.96863 .84706 Mdot
.87451 .86667 Mdot
.96863 .97647 Mdot
.53725 .3451 Mdot
.72549 .22745 Mdot
.8 .29412 Mdot
.57647 .48627 Mdot
.6 .55686 Mdot
.25882 .21569 Mdot
.63922 .58431 Mdot
.72157 .28235 Mdot
.80392 .30196 Mdot
.76078 .61569 Mdot
.48235 .41176 Mdot
.99216 .83922 Mdot
.84706 .27451 Mdot
.75686 .28627 Mdot
.45882 .43529 Mdot
.55294 .53333 Mdot
.61176 .58824 Mdot
.59216 .56863 Mdot
.19608 .12549 Mdot
1 .8902 Mdot
.78431 .67451 Mdot
.24706 .21961 Mdot
.22745 .20784 Mdot
.6902 .67843 Mdot
.98824 .89412 Mdot
.90196 .84314 Mdot
.4 .43137 Mdot
.69412 .63529 Mdot
.69412 .31373 Mdot
.77647 .24706 Mdot
.70588 .49804 Mdot
.59608 .55294 Mdot
.62353 .58039 Mdot
.62745 .58431 Mdot
.82353 .42353 Mdot
.80784 .28235 Mdot
.94118 .86667 Mdot
.91765 .85882 Mdot
.91373 .83922 Mdot
.84706 .2902 Mdot
.81176 .28235 Mdot
.63529 .59608 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.59216 .56863 Mdot
.15294 .11373 Mdot
.87843 .74118 Mdot
.55686 .42745 Mdot
.81176 .78431 Mdot
.28627 .2549 Mdot
.2902 .27059 Mdot
.92157 .87843 Mdot
.81569 .69804 Mdot
.89412 .90588 Mdot
.73333 .69804 Mdot
.71765 .31373 Mdot
.76471 .25882 Mdot
.60392 .46667 Mdot
.59608 .55294 Mdot
.61961 .58039 Mdot
.63922 .54118 Mdot
.82353 .29804 Mdot
.70588 .3451 Mdot
.88235 .85882 Mdot
.91373 .83529 Mdot
.98824 .79608 Mdot
.84706 .26275 Mdot
.65882 .31765 Mdot
.58431 .56471 Mdot
.6 .57255 Mdot
.6 .58039 Mdot
.67451 .65098 Mdot
.98431 .90588 Mdot
.91373 .70588 Mdot
.95686 .91373 Mdot
.34902 .32157 Mdot
.97647 .94118 Mdot
.9451 .94118 Mdot
.93333 .87059 Mdot
.21176 .1451 Mdot
.46275 .5098 Mdot
.54118 .38039 Mdot
.76078 .30196 Mdot
.68235 .32549 Mdot
.54902 .4902 Mdot
.61176 .56863 Mdot
.37255 .32941 Mdot
.77255 .33333 Mdot
.81176 .30196 Mdot
.89412 .86667 Mdot
.93725 .83922 Mdot
.97255 .79216 Mdot
.83529 .29412 Mdot
.79608 .29412 Mdot
.62353 .58824 Mdot
.59608 .57255 Mdot
.59216 .57255 Mdot
.58431 .56078 Mdot
.13333 .07843 Mdot
.91765 .69412 Mdot
.67059 .56471 Mdot
.81961 .8 Mdot
.33725 .28627 Mdot
.5098 .4902 Mdot
.89412 .89412 Mdot
.36078 .25098 Mdot
.87059 .8902 Mdot
.92157 .85882 Mdot
.64706 .27843 Mdot
.68235 .2549 Mdot
.54902 .47451 Mdot
.59608 .56078 Mdot
.61176 .57255 Mdot
.77255 .31373 Mdot
.81176 .28627 Mdot
.87843 .84314 Mdot
.94902 .77647 Mdot
.85098 .51373 Mdot
.83529 .2902 Mdot
.79216 .29804 Mdot
.61569 .57255 Mdot
.61176 .59216 Mdot
.58431 .56471 Mdot
.59216 .57647 Mdot
.20392 .12941 Mdot
.74118 .49412 Mdot
.96471 .86667 Mdot
.59216 .56078 Mdot
.82353 .78039 Mdot
.50196 .48627 Mdot
.8902 .8902 Mdot
.32941 .22745 Mdot
.86667 .89412 Mdot
.88235 .78431 Mdot
.67451 .24706 Mdot
.70588 .45098 Mdot
.55686 .50588 Mdot
.60392 .57647 Mdot
.65098 .46667 Mdot
.82745 .27059 Mdot
.47451 .16078 Mdot
.89804 .86275 Mdot
.66667 .2549 Mdot
.72941 .3098 Mdot
.84706 .27843 Mdot
.61176 .40784 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.59608 .57647 Mdot
.16471 .12549 Mdot
.85882 .70196 Mdot
.67451 .44706 Mdot
.93725 .91765 Mdot
.48235 .44706 Mdot
.44314 .41569 Mdot
.89804 .89804 Mdot
.93725 .87451 Mdot
.53333 .4902 Mdot
.4902 .5451 Mdot
.62353 .30196 Mdot
.61176 .32157 Mdot
.56078 .47843 Mdot
.58824 .56078 Mdot
.7098 .52549 Mdot
.82353 .26667 Mdot
.63922 .25098 Mdot
.89804 .87059 Mdot
.75294 .36078 Mdot
.72941 .22353 Mdot
.83137 .27059 Mdot
.64706 .4549 Mdot
.61176 .58431 Mdot
.60392 .58039 Mdot
.6 .57647 Mdot
.17647 .13725 Mdot
.49412 .33725 Mdot
1 .80392 Mdot
.39216 .37255 Mdot
.9098 .86667 Mdot
.84706 .81961 Mdot
.90196 .90196 Mdot
.94118 .87843 Mdot
.54902 .51373 Mdot
.73725 .77647 Mdot
.83137 .55686 Mdot
.72157 .4902 Mdot
.56078 .44706 Mdot
.56863 .53333 Mdot
.8 .52549 Mdot
.81961 .26667 Mdot
.54118 .18431 Mdot
.88627 .84314 Mdot
.69412 .31765 Mdot
.81961 .30588 Mdot
.80784 .27843 Mdot
.67059 .57255 Mdot
.60392 .57647 Mdot
.59608 .57647 Mdot
.59608 .57255 Mdot
.21569 .16863 Mdot
.72941 .59608 Mdot
.60392 .42745 Mdot
.20784 .17647 Mdot
.40784 .36863 Mdot
.48235 .46275 Mdot
.89412 .89412 Mdot
.94902 .86667 Mdot
.88627 .87451 Mdot
.75686 .72941 Mdot
.63922 .38039 Mdot
.54118 .33725 Mdot
.56078 .46275 Mdot
.61569 .55686 Mdot
.78824 .29804 Mdot
.82353 .27059 Mdot
.94118 .73725 Mdot
.96471 .88235 Mdot
.63529 .28627 Mdot
.81176 .30196 Mdot
.62745 .32157 Mdot
.60392 .57647 Mdot
.62353 .58431 Mdot
.59216 .56863 Mdot
.52941 .51373 Mdot
.9451 .90588 Mdot
.6 .43922 Mdot
.96863 .9098 Mdot
.15294 .13725 Mdot
.54902 .51373 Mdot
.94902 .9451 Mdot
.90196 .88627 Mdot
.2549 .16471 Mdot
.33333 .37255 Mdot
.78431 .69412 Mdot
.72941 .53333 Mdot
.60392 .40784 Mdot
.56863 .49412 Mdot
.79216 .48235 Mdot
.82353 .27059 Mdot
.77255 .31373 Mdot
.92549 .82353 Mdot
.83137 .67059 Mdot
.59216 .23529 Mdot
.76078 .31373 Mdot
.61176 .58431 Mdot
.60784 .58039 Mdot
.61569 .59216 Mdot
.6 .56471 Mdot
.36078 .34118 Mdot
.97647 .88235 Mdot
.96078 .83922 Mdot
.44314 .42745 Mdot
.83922 .8 Mdot
.52157 .50588 Mdot
.89804 .89804 Mdot
.4 .30588 Mdot
.87451 .90196 Mdot
.38824 .39216 Mdot
.84706 .67843 Mdot
.70196 .47843 Mdot
.62745 .45098 Mdot
.63922 .48235 Mdot
.79608 .28235 Mdot
.81961 .27451 Mdot
.7098 .36471 Mdot
.92941 .83922 Mdot
.85098 .72157 Mdot
.79608 .32157 Mdot
.65098 .59608 Mdot
.59216 .57255 Mdot
.58039 .56078 Mdot
.56863 .55294 Mdot
.20392 .17255 Mdot
.94118 .88627 Mdot
.85098 .66275 Mdot
.78039 .73725 Mdot
.15686 .13333 Mdot
.55294 .52157 Mdot
.89412 .90196 Mdot
.97647 .91373 Mdot
.78431 .78431 Mdot
.83529 .83922 Mdot
.81569 .69804 Mdot
.86275 .67059 Mdot
.49412 .30196 Mdot
.62745 .46667 Mdot
.78824 .29804 Mdot
.82745 .28235 Mdot
.63137 .18431 Mdot
.97255 .81176 Mdot
.93725 .8549 Mdot
.77647 .33725 Mdot
.61961 .58039 Mdot
.61569 .59608 Mdot
.59216 .57255 Mdot
.56471 .5451 Mdot
.18824 .15686 Mdot
.93725 .87451 Mdot
.74902 .52941 Mdot
.98824 .94902 Mdot
.78039 .76471 Mdot
.26667 .24314 Mdot
.8902 .89804 Mdot
.99216 .92157 Mdot
.85098 .85882 Mdot
.73725 .73725 Mdot
.72157 .61569 Mdot
.8 .65098 Mdot
.43922 .31373 Mdot
.76078 .4549 Mdot
.77647 .28627 Mdot
.81961 .28627 Mdot
.68235 .22353 Mdot
.97647 .72941 Mdot
.97647 .80392 Mdot
.68627 .35686 Mdot
.61961 .59608 Mdot
.57255 .5451 Mdot
.47059 .45098 Mdot
.45882 .44314 Mdot
.93333 .91765 Mdot
.79216 .63529 Mdot
.55294 .40784 Mdot
.90196 .90196 Mdot
.91765 .9098 Mdot
.85882 .8549 Mdot
.89804 .8902 Mdot
.28627 .2 Mdot
.90196 .93333 Mdot
.63137 .58039 Mdot
.88235 .79216 Mdot
.86275 .76471 Mdot
.68627 .47059 Mdot
.70196 .27059 Mdot
.8 .29412 Mdot
.83529 .31373 Mdot
.60392 .20784 Mdot
.95294 .70196 Mdot
.71373 .36471 Mdot
.49412 .47059 Mdot
.2902 .26275 Mdot
.3451 .32549 Mdot
.47843 .47059 Mdot
.56863 .5451 Mdot
.94902 .82745 Mdot
.61961 .43529 Mdot
.92157 .8902 Mdot
.90588 .8902 Mdot
.78039 .78039 Mdot
.89804 .89804 Mdot
.43137 .34118 Mdot
.89412 .92157 Mdot
.66667 .63922 Mdot
.93725 .89804 Mdot
.55294 .42353 Mdot
.63529 .25098 Mdot
.77255 .30588 Mdot
.80784 .30196 Mdot
.76078 .27843 Mdot
.63137 .22353 Mdot
.71373 .37255 Mdot
.36471 .34118 Mdot
.41176 .37255 Mdot
.53725 .5098 Mdot
.67451 .65882 Mdot
.83529 .81961 Mdot
.93725 .81961 Mdot
.97647 .82353 Mdot
.96863 .87843 Mdot
.92549 .8902 Mdot
.61569 .61569 Mdot
.90196 .89412 Mdot
.2902 .19216 Mdot
.92157 .95294 Mdot
.98039 .97647 Mdot
.58039 .37255 Mdot
.61569 .23137 Mdot
.74118 .28627 Mdot
.80784 .30196 Mdot
.80392 .29412 Mdot
.71373 .28627 Mdot
.58039 .53333 Mdot
.59608 .56078 Mdot
.61176 .58824 Mdot
.57255 .55686 Mdot
.08627 .07059 Mdot
.94118 .87843 Mdot
.86667 .69412 Mdot
1 .88627 Mdot
.8902 .73725 Mdot
.9098 .90588 Mdot
.8902 .89804 Mdot
.96863 .87843 Mdot
.83922 .87059 Mdot
.79216 .69412 Mdot
.57255 .24706 Mdot
.69804 .26667 Mdot
.78824 .31765 Mdot
.81569 .30196 Mdot
.72549 .36471 Mdot
.57647 .55294 Mdot
.58431 .56078 Mdot
.57255 .55686 Mdot
.63529 .61569 Mdot
.64706 .63137 Mdot
.96078 .85882 Mdot
.77255 .59608 Mdot
.89804 .68627 Mdot
.62353 .44314 Mdot
.9098 .9098 Mdot
.89412 .88627 Mdot
.26275 .18039 Mdot
.9451 .96863 Mdot
.66275 .48627 Mdot
.60784 .26275 Mdot
.70588 .28235 Mdot
.79608 .29804 Mdot
.73725 .34118 Mdot
.58039 .5451 Mdot
.57647 .55294 Mdot
.56863 .5451 Mdot
.56078 .54118 Mdot
.23137 .20784 Mdot
.97255 .88627 Mdot
.63137 .45098 Mdot
.94902 .71373 Mdot
.56471 .33725 Mdot
.93725 .9451 Mdot
.8902 .89412 Mdot
.5098 .43529 Mdot
.91373 .93725 Mdot
.71373 .58431 Mdot
.58431 .27451 Mdot
.71373 .27451 Mdot
.76078 .30196 Mdot
.64314 .52549 Mdot
.56471 .54118 Mdot
.56471 .52941 Mdot
.55294 .52941 Mdot
.19216 .16078 Mdot
.9451 .87059 Mdot
.76078 .61176 Mdot
.86275 .69412 Mdot
.74902 .42353 Mdot
.52157 .52157 Mdot
.87451 .91765 Mdot
.93333 .87059 Mdot
.83529 .84314 Mdot
.98824 .92941 Mdot
.54902 .3098 Mdot
.62745 .23529 Mdot
.70196 .29804 Mdot
.57647 .52157 Mdot
.56078 .52549 Mdot
.57647 .53333 Mdot
.54902 .52941 Mdot
.19608 .16078 Mdot
.65882 .5451 Mdot
.58824 .4549 Mdot
.48627 .2 Mdot
.62353 .45882 Mdot
.54902 .54902 Mdot
.71765 .76863 Mdot
.89412 .83529 Mdot
.86667 .89412 Mdot
.90588 .82353 Mdot
.53333 .27843 Mdot
.63529 .25882 Mdot
.60392 .54118 Mdot
.55686 .52549 Mdot
.56471 .52941 Mdot
.54118 .50588 Mdot
.20784 .16471 Mdot
.94118 .85882 Mdot
.82353 .68627 Mdot
.82353 .6549 Mdot
.56078 .35294 Mdot
.47059 .41961 Mdot
.40392 .46275 Mdot
.6 .52157 Mdot
.83137 .86667 Mdot
.93725 .82353 Mdot
.57255 .29412 Mdot
.59608 .52941 Mdot
.54902 .52941 Mdot
.53333 .51373 Mdot
.55294 .51765 Mdot
.22745 .18824 Mdot
.92157 .87843 Mdot
.77647 .65882 Mdot
.97647 .87843 Mdot
.63922 .36471 Mdot
.44314 .38039 Mdot
.57647 .58431 Mdot
.41961 .34902 Mdot
.83922 .86667 Mdot
.98431 .90196 Mdot
.90588 .84314 Mdot
.55686 .55294 Mdot
.52157 .5098 Mdot
.55686 .50588 Mdot
.22353 .17255 Mdot
.90196 .89804 Mdot
.5098 .43529 Mdot
.96078 .90196 Mdot
.73725 .33725 Mdot
.51765 .4902 Mdot
.61569 .54118 Mdot
.48627 .43137 Mdot
.83922 .8549 Mdot
.97647 .98824 Mdot
.75686 .76078 Mdot
.59608 .6 Mdot
.49804 .47451 Mdot
.53333 .46667 Mdot
.80392 .77647 Mdot
.92157 .8902 Mdot
.91765 .90196 Mdot
.41961 .23922 Mdot
.54902 .4 Mdot
.63137 .53725 Mdot
.4549 .40392 Mdot
.83137 .80392 Mdot
.87451 .90196 Mdot
.83137 .84706 Mdot
.63529 .65882 Mdot
.8 .6902 Mdot
.30588 .22353 Mdot
.94118 .91373 Mdot
.93725 .9098 Mdot
.91373 .8902 Mdot
.6902 .42353 Mdot
.57255 .55686 Mdot
.53725 .47451 Mdot
.70196 .63137 Mdot
.84314 .87843 Mdot
.98039 .99608 Mdot
.65098 .67059 Mdot
.63529 .52941 Mdot
.4902 .42353 Mdot
.94902 .89412 Mdot
.94118 .89804 Mdot
.92549 .8902 Mdot
.49412 .33333 Mdot
.69804 .68235 Mdot
.87059 .80784 Mdot
.81176 .77647 Mdot
.87059 .9098 Mdot
.86667 .83529 Mdot
.87059 .84314 Mdot
.72549 .66275 Mdot
.88235 .8 Mdot
.96863 .89804 Mdot
1 .91373 Mdot
.91765 .90588 Mdot
.7451 .69804 Mdot
.61961 .53725 Mdot
.83922 .87451 Mdot
1 .99216 Mdot
.84706 .84706 Mdot
.81961 .74902 Mdot
.62745 .53725 Mdot
.86667 .79216 Mdot
.97255 .9098 Mdot
.92941 .89804 Mdot
.48627 .42745 Mdot
.83529 .78431 Mdot
.87059 .92549 Mdot
.98824 .99216 Mdot
.85098 .84706 Mdot
.91765 .86275 Mdot
.66667 .59608 Mdot
.73725 .63529 Mdot
.95294 .87059 Mdot
.98824 .90588 Mdot
.79608 .71765 Mdot
.82745 .87059 Mdot
.99216 1 Mdot
.80784 .78039 Mdot
.92157 .87451 Mdot
.8549 .77647 Mdot
.61569 .5451 Mdot
.77255 .67059 Mdot
.49804 .43922 Mdot
.82353 .85882 Mdot
.98824 1 Mdot
.78824 .77255 Mdot
.82745 .79608 Mdot
.88235 .85098 Mdot
.82353 .78824 Mdot
.63922 .56863 Mdot
.85882 .83137 Mdot
.76078 .83529 Mdot
.62353 .62745 Mdot
.8 .79216 Mdot
.75294 .74902 Mdot
.75686 .76078 Mdot
.87451 .83922 Mdot
.84706 .83137 Mdot
.56863 .63137 Mdot
.96078 .96471 Mdot
.75294 .77255 Mdot
.8 .80392 Mdot
.87451 .87843 Mdot
.9451 .92941 Mdot
.92549 .92157 Mdot
.85098 .88235 Mdot
.8902 .90588 Mdot
.93725 .9451 Mdot
.99216 1 Mdot
.99216 .99216 Mdot
.98824 .99608 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0113379 0.97619 0.464853 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.90588 .90588 Mdot
.49412 .4902 Mdot
.8 .8 Mdot
.17647 .16471 Mdot
.18039 .18431 Mdot
.13333 .11373 Mdot
.32157 .29412 Mdot
.36863 .37255 Mdot
.20784 .19216 Mdot
.28627 .25098 Mdot
.24314 .23922 Mdot
.21569 .2 Mdot
.26275 .21961 Mdot
.23529 .22353 Mdot
.17255 .16078 Mdot
.20392 .16863 Mdot
.3098 .27843 Mdot
.83922 .83922 Mdot
.2902 .2549 Mdot
.23922 .20392 Mdot
.2902 .27451 Mdot
1 .96471 Mdot
.79608 .7451 Mdot
.27451 .23137 Mdot
.26667 .22353 Mdot
.27059 .24314 Mdot
.9098 .81961 Mdot
.83529 .73333 Mdot
.72549 .51765 Mdot
.1451 .09412 Mdot
.18431 .14118 Mdot
.24706 .21176 Mdot
.16863 .15686 Mdot
.41569 .41569 Mdot
.55686 .55686 Mdot
.53725 .30196 Mdot
.64314 .4549 Mdot
.62353 .24706 Mdot
.15686 .08235 Mdot
.21569 .17647 Mdot
.27843 .25098 Mdot
.17647 .1451 Mdot
.90196 .85098 Mdot
.67451 .68235 Mdot
.11765 .11373 Mdot
.39216 .4 Mdot
.61176 .28627 Mdot
.60392 .40392 Mdot
.78431 .30196 Mdot
.25882 .09412 Mdot
.16863 .12941 Mdot
.25098 .22353 Mdot
.19216 .16078 Mdot
.34902 .23529 Mdot
.53725 .46275 Mdot
.85882 .76863 Mdot
.94902 .94902 Mdot
.1098 .10588 Mdot
.09412 .09804 Mdot
.83922 .83922 Mdot
.61176 .23922 Mdot
.67843 .42745 Mdot
.80784 .30588 Mdot
.21176 .0549 Mdot
.18824 .1451 Mdot
.24314 .22353 Mdot
.18824 .13333 Mdot
.47843 .30196 Mdot
.34902 .2 Mdot
.40392 .18431 Mdot
.55294 .43529 Mdot
.85098 .75294 Mdot
.99608 .95294 Mdot
.12549 .12157 Mdot
.22353 .22353 Mdot
.07059 .0902 Mdot
.71373 .27451 Mdot
.72549 .49804 Mdot
.74902 .30588 Mdot
.73725 .25098 Mdot
.22745 .12549 Mdot
.2 .15686 Mdot
.16078 .12941 Mdot
.22353 .02353 Mdot
.45882 .29412 Mdot
.43529 .2 Mdot
.35294 .16471 Mdot
.32941 .16863 Mdot
.37647 .27059 Mdot
.61176 .52941 Mdot
.89804 .81569 Mdot
1 1 Mdot
.10196 .10588 Mdot
.21961 .2 Mdot
.20392 .20392 Mdot
.31373 .32157 Mdot
.82353 .27451 Mdot
.56471 .2902 Mdot
.81961 .2902 Mdot
.83529 .36471 Mdot
.21961 .12157 Mdot
.20392 .16078 Mdot
.19216 .13725 Mdot
.54118 .27451 Mdot
.59608 .43922 Mdot
.55294 .24314 Mdot
.52157 .39216 Mdot
.32157 .17255 Mdot
.29804 .16078 Mdot
.31373 .16078 Mdot
.4902 .28627 Mdot
.61569 .59608 Mdot
.11373 .11765 Mdot
.26275 .25098 Mdot
.19216 .17255 Mdot
.0902 .09412 Mdot
.86275 .62745 Mdot
.69412 .22353 Mdot
.81961 .41569 Mdot
.86667 .30588 Mdot
.72941 .27059 Mdot
.25098 .12157 Mdot
.22745 .15686 Mdot
.27843 .08235 Mdot
.68235 .46275 Mdot
.53725 .37255 Mdot
.58431 .30196 Mdot
.72157 .57255 Mdot
.59216 .45882 Mdot
.4902 .32941 Mdot
.41176 .18431 Mdot
.40784 .18039 Mdot
.36471 .35294 Mdot
.12157 .12549 Mdot
.16078 .14902 Mdot
.16863 .14902 Mdot
.1098 .1098 Mdot
.82745 .28627 Mdot
.99216 .54118 Mdot
.80392 .26667 Mdot
.86667 .28627 Mdot
.69412 .2549 Mdot
.28627 .09804 Mdot
.2549 .09804 Mdot
.47843 .06667 Mdot
.51373 .31765 Mdot
.47843 .28627 Mdot
.42353 .23922 Mdot
.35686 .20392 Mdot
.71373 .55294 Mdot
.62745 .50196 Mdot
.48235 .15294 Mdot
.53333 .39216 Mdot
.39608 .39216 Mdot
.12549 .11373 Mdot
.13725 .11765 Mdot
.13725 .11765 Mdot
.09412 .10196 Mdot
.83922 .25098 Mdot
.84706 .32157 Mdot
.84706 .26667 Mdot
.8549 .2549 Mdot
.79608 .31373 Mdot
.34902 .07059 Mdot
.32157 .03137 Mdot
.77255 .27059 Mdot
.64706 .42745 Mdot
.49804 .26667 Mdot
.78431 .63922 Mdot
.30196 .16863 Mdot
.55294 .33725 Mdot
.64706 .54118 Mdot
.61961 .23529 Mdot
.55294 .44314 Mdot
.0549 .0549 Mdot
.12549 .11373 Mdot
.34902 .32941 Mdot
.1451 .12549 Mdot
.12549 .13333 Mdot
.86275 .27451 Mdot
.87059 .29804 Mdot
.85098 .2549 Mdot
.85098 .24706 Mdot
.87059 .32157 Mdot
.51373 .0902 Mdot
.50588 .08235 Mdot
.81176 .27451 Mdot
.64314 .38039 Mdot
.63922 .38039 Mdot
.68627 .54118 Mdot
.4 .25882 Mdot
.46667 .19216 Mdot
.67451 .56078 Mdot
.61176 .24706 Mdot
.55686 .45098 Mdot
.08627 .07843 Mdot
.12941 .12549 Mdot
.34118 .32157 Mdot
.11765 .10588 Mdot
.0902 .09804 Mdot
.86275 .27451 Mdot
.88627 .28235 Mdot
.85098 .24706 Mdot
.86667 .26275 Mdot
.93333 .35686 Mdot
.88235 .36863 Mdot
.85098 .34118 Mdot
.84314 .28627 Mdot
.60784 .34902 Mdot
.58431 .33725 Mdot
.67843 .54118 Mdot
.52549 .38431 Mdot
.51373 .2 Mdot
.72549 .61176 Mdot
.6 .28235 Mdot
.59216 .4902 Mdot
.12157 .11373 Mdot
.1451 .14118 Mdot
.29804 .28627 Mdot
.11373 .10196 Mdot
.07451 .07451 Mdot
.83922 .2902 Mdot
.8902 .28627 Mdot
.8902 .28627 Mdot
.88235 .27843 Mdot
.90196 .3098 Mdot
.92157 .36078 Mdot
.87059 .33333 Mdot
.89804 .30196 Mdot
.63922 .38431 Mdot
.59608 .37647 Mdot
.66275 .53333 Mdot
.38431 .23137 Mdot
.73333 .46275 Mdot
.67059 .52549 Mdot
.52941 .32941 Mdot
.58824 .44706 Mdot
.59608 .57255 Mdot
.14118 .13725 Mdot
.14118 .14118 Mdot
.09804 .09804 Mdot
.12941 .12549 Mdot
.81961 .82745 Mdot
.86275 .28235 Mdot
.87059 .27451 Mdot
.87843 .28235 Mdot
.88235 .28627 Mdot
.87059 .31765 Mdot
.91373 .36863 Mdot
.92157 .36863 Mdot
.86667 .27451 Mdot
.53725 .3098 Mdot
.54118 .36471 Mdot
.74902 .62745 Mdot
.53725 .41569 Mdot
.51373 .16863 Mdot
.69412 .56471 Mdot
.39608 .19608 Mdot
.35686 .23922 Mdot
.72941 .7098 Mdot
.12941 .12549 Mdot
.22745 .21569 Mdot
.21961 .21569 Mdot
.11373 .1098 Mdot
.52157 .52549 Mdot
.81961 .30196 Mdot
.86667 .28627 Mdot
.88235 .30588 Mdot
.87451 .29412 Mdot
.83137 .30196 Mdot
.89412 .40784 Mdot
.92549 .38039 Mdot
.90588 .31373 Mdot
.54118 .20392 Mdot
.50588 .32549 Mdot
.34902 .24706 Mdot
.38824 .24706 Mdot
.81569 .55686 Mdot
.68627 .52549 Mdot
.46275 .23137 Mdot
.52549 .36078 Mdot
.45882 .38824 Mdot
.12157 .12549 Mdot
.12157 .11765 Mdot
.20392 .20392 Mdot
.14902 .14118 Mdot
.43529 .43922 Mdot
.73725 .74118 Mdot
.81961 .28627 Mdot
.90196 .32941 Mdot
.92157 .36471 Mdot
.89804 .33333 Mdot
.87059 .38824 Mdot
.89412 .46667 Mdot
.90588 .4 Mdot
.87451 .29412 Mdot
.67843 .28235 Mdot
.63137 .41961 Mdot
.41176 .31373 Mdot
.31373 .17647 Mdot
.65098 .39216 Mdot
.79608 .64706 Mdot
.55686 .28235 Mdot
.7098 .50196 Mdot
.57647 .47843 Mdot
.08235 .08235 Mdot
.11373 .1098 Mdot
.13725 .13725 Mdot
.12157 .11373 Mdot
.47843 .47843 Mdot
.44706 .4549 Mdot
.61176 .38824 Mdot
.92157 .33333 Mdot
.98824 .4902 Mdot
.96078 .41961 Mdot
.91373 .37647 Mdot
.95294 .56863 Mdot
.86275 .48627 Mdot
.82353 .32549 Mdot
.84706 .28235 Mdot
.79216 .40784 Mdot
.52941 .40784 Mdot
.73333 .56863 Mdot
.78039 .65882 Mdot
.53725 .30196 Mdot
.84706 .61569 Mdot
.64706 .35686 Mdot
.6 .35686 Mdot
.95294 .9451 Mdot
.19608 .18039 Mdot
.13333 .12941 Mdot
.13333 .13333 Mdot
.05098 .0549 Mdot
.50588 .5098 Mdot
.41961 .42745 Mdot
.69412 .28627 Mdot
.89804 .3098 Mdot
.97647 .45882 Mdot
.95686 .41569 Mdot
.95294 .43137 Mdot
.96863 .56863 Mdot
.91765 .54118 Mdot
.99216 .50196 Mdot
.86275 .29804 Mdot
.80784 .37647 Mdot
.78431 .64706 Mdot
.44314 .26667 Mdot
.85098 .71765 Mdot
.38039 .23137 Mdot
.46667 .13333 Mdot
.64314 .32941 Mdot
.63529 .38824 Mdot
.89412 .8902 Mdot
.09412 .0902 Mdot
.13725 .13333 Mdot
.12941 .12941 Mdot
.51373 .51373 Mdot
.53333 .53333 Mdot
.47451 .48235 Mdot
.96078 .96078 Mdot
.93725 .34902 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.94902 .39216 Mdot
.92157 .42745 Mdot
.94118 .5098 Mdot
.91765 .44706 Mdot
.87059 .2902 Mdot
.8902 .33725 Mdot
.65098 .38039 Mdot
.89412 .71765 Mdot
.82353 .70588 Mdot
.45098 .30196 Mdot
.8549 .67059 Mdot
.70196 .33725 Mdot
.68627 .37255 Mdot
.7451 .67843 Mdot
.34902 .33725 Mdot
.08235 .06667 Mdot
.11765 .12157 Mdot
.18824 .18824 Mdot
.54118 .54118 Mdot
.51373 .51373 Mdot
.47843 .48627 Mdot
1 .97647 Mdot
.94902 .36078 Mdot
.95294 .38039 Mdot
.88235 .34902 Mdot
.93333 .38431 Mdot
.93333 .39608 Mdot
.89412 .40784 Mdot
.93725 .43529 Mdot
.88235 .31765 Mdot
.88627 .30588 Mdot
.62353 .28235 Mdot
.99608 .74902 Mdot
.88235 .72549 Mdot
.78431 .65098 Mdot
.95294 .72941 Mdot
.77255 .38431 Mdot
.72549 .39216 Mdot
.76863 .69804 Mdot
.2549 .24314 Mdot
.3451 .33725 Mdot
.11373 .12941 Mdot
.21569 .22353 Mdot
.56078 .55294 Mdot
.35686 .35294 Mdot
.47451 .48235 Mdot
.55294 .54902 Mdot
.85882 .29804 Mdot
.93333 .3451 Mdot
.97255 .4549 Mdot
.91373 .38039 Mdot
.92941 .38039 Mdot
.94902 .41176 Mdot
.91373 .39608 Mdot
.96863 .43529 Mdot
.90196 .3451 Mdot
.84706 .33725 Mdot
.73725 .38431 Mdot
.82353 .52157 Mdot
.91765 .71373 Mdot
.92157 .72941 Mdot
.78824 .3098 Mdot
.80392 .43922 Mdot
.71765 .5451 Mdot
.35294 .34902 Mdot
.21961 .21176 Mdot
.28235 .3098 Mdot
.17255 .17647 Mdot
.63137 .62745 Mdot
.33333 .33725 Mdot
.36471 .36863 Mdot
.49804 .48627 Mdot
.6549 .31765 Mdot
.91765 .32941 Mdot
.93725 .37647 Mdot
.94902 .43922 Mdot
.9451 .42353 Mdot
.91373 .36471 Mdot
.94902 .40392 Mdot
.94902 .41176 Mdot
.95686 .41569 Mdot
.90196 .3451 Mdot
.76078 .29412 Mdot
.74902 .31765 Mdot
.6902 .37255 Mdot
.82745 .56863 Mdot
.76078 .27059 Mdot
.82745 .37647 Mdot
.7098 .39608 Mdot
.81176 .80392 Mdot
.27451 .26667 Mdot
.42745 .43137 Mdot
.21569 .23529 Mdot
.09804 .10588 Mdot
.63529 .63529 Mdot
.54118 .5451 Mdot
.54902 .54902 Mdot
.76471 .7451 Mdot
.94902 .36078 Mdot
.95294 .36078 Mdot
.93725 .4 Mdot
.92157 .41569 Mdot
.95294 .43529 Mdot
.89804 .36078 Mdot
.92549 .37647 Mdot
.93725 .39608 Mdot
.9451 .41176 Mdot
.88235 .32549 Mdot
.83137 .37647 Mdot
.76863 .33725 Mdot
.67451 .28235 Mdot
.69804 .26275 Mdot
.83922 .30196 Mdot
.85882 .41961 Mdot
.75294 .67843 Mdot
.15294 .15294 Mdot
.83922 .82353 Mdot
.15686 .19216 Mdot
.14902 .16863 Mdot
.6902 .67843 Mdot
.38431 .38824 Mdot
.60392 .58824 Mdot
.57255 .49412 Mdot
.80392 .3098 Mdot
.91765 .34118 Mdot
.9451 .38431 Mdot
.87843 .41176 Mdot
.88235 .41961 Mdot
.94902 .42745 Mdot
.94118 .38431 Mdot
.90588 .35686 Mdot
.93333 .39216 Mdot
.96863 .44314 Mdot
.85882 .38431 Mdot
.8549 .40784 Mdot
.82745 .38039 Mdot
.79608 .3451 Mdot
.8549 .3098 Mdot
.86667 .32549 Mdot
.83529 .64314 Mdot
.85098 .8549 Mdot
.50196 .4902 Mdot
.89804 .90196 Mdot
.51765 .52941 Mdot
.12941 .12549 Mdot
.66275 .66667 Mdot
.31765 .31373 Mdot
.60392 .55686 Mdot
.97647 .92157 Mdot
.93725 .34118 Mdot
.93725 .35686 Mdot
.88235 .40784 Mdot
.83922 .47843 Mdot
.87059 .45098 Mdot
.93333 .39608 Mdot
.95294 .40392 Mdot
.91765 .37647 Mdot
.8902 .39608 Mdot
.92549 .35294 Mdot
.70588 .38824 Mdot
.87059 .47059 Mdot
.8549 .44314 Mdot
.87059 .39216 Mdot
.86667 .34118 Mdot
.82745 .34118 Mdot
.81961 .77647 Mdot
.60392 .6 Mdot
.34118 .33333 Mdot
.96078 .97647 Mdot
.5098 .50588 Mdot
.7451 .72941 Mdot
.61961 .61961 Mdot
.30588 .30196 Mdot
.93725 .70196 Mdot
.75294 .31765 Mdot
.91765 .33725 Mdot
.90196 .39216 Mdot
.81176 .49412 Mdot
.77647 .4902 Mdot
.81176 .40784 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.95294 .42745 Mdot
.84314 .37647 Mdot
.81176 .37647 Mdot
.47843 .21961 Mdot
.66275 .3451 Mdot
.82353 .45098 Mdot
.86667 .43922 Mdot
.87843 .32549 Mdot
.72941 .48235 Mdot
.84314 .82745 Mdot
.27843 .26667 Mdot
.94902 .94118 Mdot
.25098 .24314 Mdot
.66667 .65882 Mdot
.71765 .71373 Mdot
.66275 .66275 Mdot
.59216 .51765 Mdot
.54118 .3098 Mdot
.94902 .36863 Mdot
.90196 .34902 Mdot
.8 .47843 Mdot
.76863 .58431 Mdot
.91765 .69412 Mdot
.87451 .43922 Mdot
.9451 .39216 Mdot
.9451 .38824 Mdot
.83529 .45098 Mdot
.92941 .39216 Mdot
.33725 .14902 Mdot
.36863 .18039 Mdot
.4549 .24706 Mdot
.58039 .2902 Mdot
.71373 .34118 Mdot
.79216 .32941 Mdot
.86667 .78039 Mdot
.67451 .67451 Mdot
.96078 .93725 Mdot
.88235 .88235 Mdot
.91373 .90196 Mdot
.79216 .78824 Mdot
.72941 .71765 Mdot
.63922 .63529 Mdot
.67059 .31373 Mdot
.90588 .78431 Mdot
.93333 .35294 Mdot
.87843 .41176 Mdot
.82745 .67843 Mdot
.82353 .70588 Mdot
.69804 .53333 Mdot
.90196 .45098 Mdot
.93725 .38039 Mdot
.92941 .38039 Mdot
.58039 .32549 Mdot
.89804 .37255 Mdot
.22745 .12941 Mdot
.25882 .16078 Mdot
.3098 .17255 Mdot
.40392 .21176 Mdot
.57647 .16863 Mdot
.57647 .2902 Mdot
.5451 .51373 Mdot
.23922 .23529 Mdot
.76471 .74118 Mdot
.9451 .95686 Mdot
.84706 .83922 Mdot
.82353 .80784 Mdot
.76863 .75294 Mdot
.73333 .71373 Mdot
.78431 .31373 Mdot
.76471 .31765 Mdot
.93333 .37255 Mdot
.82353 .53725 Mdot
.7451 .67843 Mdot
.42745 .3451 Mdot
.36863 .22353 Mdot
.90588 .46275 Mdot
.9451 .39216 Mdot
.8902 .40784 Mdot
.43922 .21176 Mdot
.88235 .40392 Mdot
.18039 .11765 Mdot
.2 .12941 Mdot
.22745 .1451 Mdot
.28235 .16471 Mdot
.79216 .35294 Mdot
.27059 .16471 Mdot
.23529 .23529 Mdot
.19216 .19608 Mdot
.4549 .44314 Mdot
.49412 .49804 Mdot
.8549 .8549 Mdot
.83137 .82745 Mdot
.77255 .76863 Mdot
.75686 .67059 Mdot
.71765 .36471 Mdot
.92941 .36863 Mdot
.85882 .39216 Mdot
.85882 .71765 Mdot
.9098 .86275 Mdot
.34118 .2902 Mdot
1 .8549 Mdot
.92549 .4549 Mdot
.95294 .4 Mdot
.63529 .3451 Mdot
.34118 .06667 Mdot
.79608 .38039 Mdot
.15294 .12157 Mdot
.18039 .14118 Mdot
.2 .16078 Mdot
.27843 .16471 Mdot
.78431 .39608 Mdot
.21176 .18039 Mdot
.19608 .19216 Mdot
.10196 .11373 Mdot
.27451 .25882 Mdot
.81961 .81961 Mdot
.87059 .87059 Mdot
.85882 .85098 Mdot
.81176 .80784 Mdot
.89804 .65882 Mdot
.62745 .52157 Mdot
.90588 .33333 Mdot
.84314 .47843 Mdot
.83529 .74902 Mdot
.39216 .36078 Mdot
.37255 .33725 Mdot
.92549 .7098 Mdot
.92941 .46667 Mdot
.9451 .38824 Mdot
.32549 .15686 Mdot
.32157 .08235 Mdot
.79608 .38039 Mdot
.14118 .1098 Mdot
.20784 .17647 Mdot
.15686 .13725 Mdot
.21569 .05098 Mdot
.70588 .38039 Mdot
.14118 .13725 Mdot
.13725 .12941 Mdot
.2902 .29412 Mdot
.51765 .50588 Mdot
.88627 .87843 Mdot
.87843 .87843 Mdot
.87451 .87451 Mdot
.85098 .85098 Mdot
.7451 .41961 Mdot
1 .96471 Mdot
.88235 .32941 Mdot
.83922 .55686 Mdot
.85882 .81176 Mdot
.2549 .23922 Mdot
.81961 .78824 Mdot
.94902 .6902 Mdot
.93725 .47059 Mdot
.93725 .4 Mdot
.23922 .16078 Mdot
.32157 .10196 Mdot
.80784 .39216 Mdot
.15294 .13333 Mdot
.1451 .12549 Mdot
.13333 .11373 Mdot
.34118 .08235 Mdot
.56863 .34118 Mdot
.12157 .12157 Mdot
.1451 .12157 Mdot
.72157 .72941 Mdot
.86275 .85882 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.88235 .88235 Mdot
.87451 .87451 Mdot
.52157 .13333 Mdot
1 .96863 Mdot
.89412 .35686 Mdot
.86275 .61176 Mdot
.86667 .82745 Mdot
.25098 .23922 Mdot
.48627 .4549 Mdot
.80784 .47843 Mdot
.90196 .48235 Mdot
.92157 .38824 Mdot
.21961 .16078 Mdot
.55686 .40784 Mdot
.86275 .40784 Mdot
.1451 .10588 Mdot
.1451 .13333 Mdot
.1451 .12549 Mdot
.35294 .07451 Mdot
.54902 .32549 Mdot
.12549 .12549 Mdot
.1098 .07059 Mdot
.84706 .84706 Mdot
.87059 .86667 Mdot
.85098 .85098 Mdot
.87451 .87451 Mdot
.87059 .87059 Mdot
.87059 .87059 Mdot
.69804 .32549 Mdot
1 .96863 Mdot
.85882 .35294 Mdot
.89804 .65882 Mdot
.8902 .8549 Mdot
.30196 .28235 Mdot
.34118 .30196 Mdot
.73725 .41569 Mdot
.89804 .51373 Mdot
.9098 .39608 Mdot
.19216 .14902 Mdot
.75686 .66275 Mdot
.88235 .42353 Mdot
.16471 .07059 Mdot
.17255 .14118 Mdot
.14118 .12157 Mdot
.37647 .0902 Mdot
.54118 .31765 Mdot
.12549 .1098 Mdot
.29412 .24706 Mdot
.86667 .86275 Mdot
.91373 .91373 Mdot
.69412 .6902 Mdot
.87451 .87451 Mdot
.85882 .85882 Mdot
.86275 .86275 Mdot
.86275 .49804 Mdot
1 .97255 Mdot
.86667 .39216 Mdot
.97255 .73333 Mdot
.86275 .81961 Mdot
.26667 .23922 Mdot
.21176 .16078 Mdot
.83529 .58824 Mdot
.86275 .52157 Mdot
.87843 .38824 Mdot
.17255 .12941 Mdot
.43922 .36471 Mdot
.86275 .44314 Mdot
.23529 .03529 Mdot
.20784 .14902 Mdot
.15686 .12549 Mdot
.37255 .07059 Mdot
.52941 .30588 Mdot
.13725 .09804 Mdot
.8 .75686 Mdot
.87059 .86667 Mdot
.7451 .74902 Mdot
.4549 .45098 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.85882 .86667 Mdot
.79608 .43137 Mdot
1 .97255 Mdot
.83137 .39608 Mdot
.97647 .74118 Mdot
.79216 .7451 Mdot
.31765 .28627 Mdot
.50588 .45098 Mdot
1 .81569 Mdot
.87059 .56471 Mdot
.8902 .41961 Mdot
.17647 .14118 Mdot
.26667 .20784 Mdot
.72549 .37255 Mdot
.40392 .0902 Mdot
.27843 .12157 Mdot
.20392 .09412 Mdot
.38824 .0549 Mdot
.52941 .27059 Mdot
.2 .08627 Mdot
.56471 .52549 Mdot
.88627 .87843 Mdot
.27451 .28235 Mdot
.30588 .29412 Mdot
.87451 .85882 Mdot
.88627 .88627 Mdot
.87059 .87843 Mdot
.76471 .4 Mdot
1 .96471 Mdot
.81176 .41176 Mdot
.94118 .69804 Mdot
.76863 .71765 Mdot
.78824 .75294 Mdot
.80784 .75686 Mdot
.58039 .45098 Mdot
.94902 .67843 Mdot
.87059 .43137 Mdot
.19608 .16078 Mdot
.24314 .2 Mdot
.64706 .36863 Mdot
.73725 .29804 Mdot
.42745 .09804 Mdot
.31373 .06667 Mdot
.43137 .04314 Mdot
.56078 .23922 Mdot
.29412 .05882 Mdot
.57647 .54118 Mdot
.90588 .88627 Mdot
.26275 .28235 Mdot
.20392 .17255 Mdot
.90196 .87843 Mdot
.87843 .87843 Mdot
.86667 .87451 Mdot
.72941 .37255 Mdot
1 .96471 Mdot
.76863 .40392 Mdot
.86667 .61569 Mdot
.83922 .79608 Mdot
.51765 .4902 Mdot
.47843 .43922 Mdot
.4902 .40392 Mdot
.99608 .73725 Mdot
.86667 .44706 Mdot
.18431 .15686 Mdot
.20392 .17647 Mdot
.80784 .59216 Mdot
.81961 .35686 Mdot
.65098 .21961 Mdot
.47451 .12157 Mdot
.46667 .02353 Mdot
.60392 .20392 Mdot
.47451 .12549 Mdot
.64314 .61176 Mdot
.51373 .50196 Mdot
.26667 .28627 Mdot
.16863 .12549 Mdot
.96078 .93725 Mdot
.88235 .87843 Mdot
.87059 .87843 Mdot
.68627 .33333 Mdot
1 .95686 Mdot
.75294 .41176 Mdot
.77647 .52941 Mdot
.94902 .92549 Mdot
.35294 .3451 Mdot
.43529 .42353 Mdot
.74118 .67843 Mdot
1 .75686 Mdot
.84314 .44706 Mdot
.18039 .14902 Mdot
.17647 .1451 Mdot
.62353 .44706 Mdot
.8902 .5098 Mdot
.82745 .36471 Mdot
.73725 .2902 Mdot
.61176 .13333 Mdot
.7451 .26667 Mdot
.74902 .3098 Mdot
.84314 .80784 Mdot
.27059 .26667 Mdot
.22353 .23529 Mdot
.15294 .09804 Mdot
.8902 .87451 Mdot
.91373 .8902 Mdot
.87451 .88235 Mdot
.66275 .32549 Mdot
1 .95294 Mdot
.75294 .41569 Mdot
.66667 .43922 Mdot
.92549 .91373 Mdot
.19216 .18431 Mdot
.21569 .22353 Mdot
.91765 .87451 Mdot
.98039 .72941 Mdot
.83922 .46667 Mdot
.16471 .1451 Mdot
.18039 .14902 Mdot
.36863 .20392 Mdot
1 .68627 Mdot
.83529 .39216 Mdot
.88235 .41961 Mdot
.81176 .35294 Mdot
.85098 .32549 Mdot
.83922 .36863 Mdot
.68627 .64706 Mdot
.25882 .2549 Mdot
.15294 .15686 Mdot
.13725 .08235 Mdot
.63137 .61569 Mdot
.87451 .83922 Mdot
.86667 .87059 Mdot
.60392 .28627 Mdot
1 .9451 Mdot
.77255 .43529 Mdot
.61569 .42745 Mdot
.70196 .68627 Mdot
.56078 .5451 Mdot
.66275 .6549 Mdot
.9451 .91373 Mdot
.91765 .67059 Mdot
.80784 .46275 Mdot
.24706 .21961 Mdot
.18824 .15686 Mdot
.35294 .18824 Mdot
.99608 .58039 Mdot
1 .61961 Mdot
.86275 .45882 Mdot
.91373 .52157 Mdot
.90588 .36863 Mdot
.83922 .40392 Mdot
.30588 .28627 Mdot
.20392 .19608 Mdot
.16078 .16078 Mdot
.16471 .1098 Mdot
.57255 .55686 Mdot
.3451 .32157 Mdot
.86667 .87451 Mdot
.54118 .23922 Mdot
1 .9451 Mdot
.76078 .41176 Mdot
.66667 .52941 Mdot
.49412 .47059 Mdot
.90196 .87843 Mdot
.97255 .95294 Mdot
.93725 .90588 Mdot
.83529 .58824 Mdot
.80392 .46275 Mdot
.52157 .48627 Mdot
.18431 .15294 Mdot
.34118 .14902 Mdot
.9098 .44706 Mdot
.96078 .57255 Mdot
.98431 .58824 Mdot
1 .60784 Mdot
.92549 .38824 Mdot
.74902 .38431 Mdot
.26275 .24706 Mdot
.15294 .1451 Mdot
.14902 .1451 Mdot
.17255 .11765 Mdot
.59216 .56863 Mdot
.73333 .7098 Mdot
.87059 .87843 Mdot
.52157 .21961 Mdot
1 .94902 Mdot
.81176 .43529 Mdot
.82745 .73333 Mdot
.36863 .33725 Mdot
.52157 .49412 Mdot
.92941 .90588 Mdot
.95294 .9098 Mdot
.76863 .51765 Mdot
.80784 .46667 Mdot
.47059 .42745 Mdot
.15294 .13333 Mdot
.33333 .1098 Mdot
.93725 .42745 Mdot
.92549 .4549 Mdot
.94902 .49804 Mdot
.97647 .53725 Mdot
.95294 .41176 Mdot
.52941 .24706 Mdot
.19216 .18824 Mdot
.14902 .14902 Mdot
.15294 .14902 Mdot
.16471 .1098 Mdot
.62745 .60392 Mdot
.6902 .65882 Mdot
.86667 .87451 Mdot
.51373 .21176 Mdot
1 .96863 Mdot
.83137 .42353 Mdot
.86275 .8 Mdot
.34902 .30196 Mdot
.38431 .35686 Mdot
.91765 .89412 Mdot
.93725 .89412 Mdot
.72941 .47843 Mdot
.81569 .48235 Mdot
.29804 .24314 Mdot
.23137 .2 Mdot
.32941 .07451 Mdot
.95294 .41176 Mdot
.94902 .43137 Mdot
.91373 .41569 Mdot
.92157 .43529 Mdot
.95294 .4 Mdot
.43137 .19608 Mdot
.15294 .14902 Mdot
.16078 .16863 Mdot
.16078 .15294 Mdot
.17647 .12157 Mdot
.58431 .56863 Mdot
.20392 .17255 Mdot
.87059 .87059 Mdot
.5098 .21176 Mdot
.85098 .72157 Mdot
.85882 .49412 Mdot
.89804 .8549 Mdot
.31373 .26667 Mdot
.25882 .21569 Mdot
.93725 .90196 Mdot
.59216 .53725 Mdot
.95294 .72941 Mdot
.57255 .32941 Mdot
.27843 .23529 Mdot
.39608 .36863 Mdot
.47059 .09412 Mdot
.93725 .39608 Mdot
.93725 .40392 Mdot
.94118 .40784 Mdot
.93725 .4 Mdot
.92157 .35686 Mdot
.23922 .09412 Mdot
.12941 .13725 Mdot
.22353 .23137 Mdot
.14902 .14902 Mdot
.59608 .54902 Mdot
.35294 .32941 Mdot
.45882 .43922 Mdot
.86275 .87059 Mdot
.83137 .45098 Mdot
.62353 .34902 Mdot
.79608 .48235 Mdot
.77647 .71373 Mdot
.7098 .65882 Mdot
.73725 .6902 Mdot
.95294 .91765 Mdot
.58039 .51373 Mdot
1 .75686 Mdot
.29412 .14902 Mdot
.25098 .21176 Mdot
.54902 .5098 Mdot
.85098 .37255 Mdot
.93725 .38431 Mdot
.9451 .39216 Mdot
.9451 .39216 Mdot
.94118 .38039 Mdot
.92941 .36471 Mdot
.21176 .14118 Mdot
.15294 .17647 Mdot
.24314 .26275 Mdot
.12941 .12549 Mdot
.95686 .92941 Mdot
.55294 .52941 Mdot
.73725 .71373 Mdot
.86667 .85882 Mdot
.60392 .21176 Mdot
.88627 .40392 Mdot
.80392 .6549 Mdot
.81176 .71765 Mdot
.6 .55294 Mdot
.94902 .90196 Mdot
.78824 .77647 Mdot
1 .84314 Mdot
.8549 .50196 Mdot
.24706 .20392 Mdot
.27059 .23922 Mdot
.59216 .49804 Mdot
.9451 .39216 Mdot
.95294 .39216 Mdot
.9451 .38431 Mdot
.9451 .38431 Mdot
.93725 .36078 Mdot
.87451 .37255 Mdot
.18039 .17647 Mdot
.27059 .28627 Mdot
.13333 .14118 Mdot
.24314 .21569 Mdot
.88627 .88627 Mdot
.64314 .61961 Mdot
.83922 .80784 Mdot
.9098 .85098 Mdot
.5451 .33333 Mdot
.87059 .37255 Mdot
.87843 .80784 Mdot
.36078 .28627 Mdot
.28627 .23529 Mdot
.38039 .32549 Mdot
.4 .38039 Mdot
.7451 .46667 Mdot
.77255 .4549 Mdot
.24706 .22745 Mdot
.25098 .22353 Mdot
.66667 .41569 Mdot
.94118 .38431 Mdot
.90588 .40392 Mdot
.93333 .38824 Mdot
.93333 .38824 Mdot
.93333 .37255 Mdot
.79216 .45098 Mdot
.18824 .18824 Mdot
.20392 .21569 Mdot
.25882 .24706 Mdot
.39216 .34118 Mdot
.48627 .48235 Mdot
.37255 .32549 Mdot
.88235 .87451 Mdot
.81569 .62353 Mdot
1 .95686 Mdot
.86275 .49412 Mdot
.81176 .7451 Mdot
.44706 .4 Mdot
.3098 .2549 Mdot
.4549 .42745 Mdot
.83922 .77255 Mdot
1 .76471 Mdot
.39216 .23529 Mdot
.27843 .24706 Mdot
.25098 .21176 Mdot
.83137 .38039 Mdot
.92941 .39608 Mdot
.69804 .31765 Mdot
.88235 .37255 Mdot
.90196 .37647 Mdot
.90588 .36078 Mdot
.23922 .10196 Mdot
.14118 .14118 Mdot
.2902 .28235 Mdot
.42353 .40392 Mdot
.71373 .68627 Mdot
.35686 .34902 Mdot
.81961 .76078 Mdot
.86667 .87451 Mdot
.75686 .42745 Mdot
.67843 .38824 Mdot
.8902 .7098 Mdot
.90588 .86275 Mdot
.87059 .82745 Mdot
.89804 .85882 Mdot
.53333 .51765 Mdot
.98431 .78824 Mdot
.85098 .47843 Mdot
.26667 .20784 Mdot
.27059 .23529 Mdot
.27843 .18431 Mdot
.93725 .40392 Mdot
.88627 .47451 Mdot
.77255 .40784 Mdot
.63922 .25882 Mdot
.71373 .30196 Mdot
.84314 .35294 Mdot
.15294 .12941 Mdot
.36471 .35686 Mdot
.38039 .36078 Mdot
.18039 .15686 Mdot
.88627 .88627 Mdot
.89412 .8902 Mdot
.43137 .39216 Mdot
.88235 .86667 Mdot
.56863 .36078 Mdot
.92549 .52941 Mdot
.52157 .47059 Mdot
.48627 .47059 Mdot
.47843 .44314 Mdot
.56078 .53333 Mdot
.23529 .16078 Mdot
.84706 .59608 Mdot
.78824 .49412 Mdot
.23529 .19608 Mdot
.24314 .21569 Mdot
.44706 .09804 Mdot
.92157 .38824 Mdot
1 .87059 Mdot
.5451 .26275 Mdot
.74902 .54902 Mdot
.58824 .3451 Mdot
.77255 .43922 Mdot
.42745 .43922 Mdot
.26275 .25098 Mdot
.16471 .14902 Mdot
.14902 .12549 Mdot
.88235 .88235 Mdot
.8 .7451 Mdot
.87451 .87451 Mdot
.72549 .50588 Mdot
.91373 .78431 Mdot
.96863 .81961 Mdot
.43137 .4 Mdot
.37647 .34118 Mdot
.38039 .35294 Mdot
.40392 .38431 Mdot
.86667 .60392 Mdot
.83137 .46667 Mdot
.29412 .21176 Mdot
.25098 .22353 Mdot
.25098 .19216 Mdot
.92157 .38431 Mdot
.80392 .47059 Mdot
1 .85098 Mdot
.97255 .87451 Mdot
.96863 .85098 Mdot
1 .74118 Mdot
.42353 .35294 Mdot
.23922 .24314 Mdot
.18824 .17647 Mdot
.18431 .16863 Mdot
.9098 .9098 Mdot
.92941 .92549 Mdot
.51373 .46667 Mdot
.87843 .87059 Mdot
.61961 .36863 Mdot
.86667 .50196 Mdot
.37255 .32157 Mdot
.34902 .31765 Mdot
.35686 .32549 Mdot
.3451 .33725 Mdot
.90588 .72549 Mdot
.98039 .72157 Mdot
.80392 .52157 Mdot
.27059 .23137 Mdot
.23529 .21569 Mdot
.48627 .11765 Mdot
.90588 .41176 Mdot
.9451 .8549 Mdot
.87451 .75294 Mdot
.94902 .76078 Mdot
.96078 .85098 Mdot
.79608 .45098 Mdot
.21961 .23137 Mdot
.23529 .22745 Mdot
.18039 .16078 Mdot
.12941 .10588 Mdot
.87843 .88627 Mdot
.66667 .60392 Mdot
.87451 .87451 Mdot
.57647 .3451 Mdot
.63137 .46275 Mdot
.61961 .44706 Mdot
.3098 .21176 Mdot
.29412 .2 Mdot
.28235 .20392 Mdot
.40392 .32941 Mdot
.78431 .49412 Mdot
.92549 .47843 Mdot
.25098 .19608 Mdot
.23922 .21961 Mdot
.27059 .16078 Mdot
.93725 .39608 Mdot
.50588 .36863 Mdot
.54902 .36471 Mdot
1 .8549 Mdot
.9098 .81961 Mdot
.60392 .20392 Mdot
.24706 .22353 Mdot
.25882 .26667 Mdot
.17255 .15686 Mdot
.16863 .1451 Mdot
.88627 .88627 Mdot
.89804 .88235 Mdot
.69412 .67059 Mdot
.90196 .8549 Mdot
.58824 .50196 Mdot
.73333 .33333 Mdot
.88627 .6549 Mdot
.77647 .63922 Mdot
.83137 .62353 Mdot
.55686 .52549 Mdot
.7451 .47451 Mdot
.9451 .55686 Mdot
.68235 .50588 Mdot
.25098 .20784 Mdot
.23922 .2 Mdot
.85882 .40784 Mdot
.81176 .47059 Mdot
.99216 .88235 Mdot
.94118 .85882 Mdot
.78824 .47451 Mdot
.99608 .84706 Mdot
.48235 .24314 Mdot
.21176 .22353 Mdot
.17255 .16471 Mdot
.15686 .15294 Mdot
.50588 .4902 Mdot
.88627 .88627 Mdot
.41569 .37647 Mdot
.87059 .87843 Mdot
.70588 .47451 Mdot
.81176 .43529 Mdot
.87843 .51373 Mdot
.91765 .68235 Mdot
.82745 .55686 Mdot
.95294 .88235 Mdot
.60392 .39216 Mdot
.9451 .55686 Mdot
.77255 .50588 Mdot
.21176 .16863 Mdot
.28235 .25098 Mdot
.62353 .24314 Mdot
.83137 .44706 Mdot
.96078 .86667 Mdot
.93725 .87059 Mdot
.8549 .46275 Mdot
.96471 .83137 Mdot
.77647 .45098 Mdot
.20392 .21176 Mdot
.14902 .14118 Mdot
.14902 .1451 Mdot
.15294 .11765 Mdot
.8902 .8902 Mdot
.52549 .48627 Mdot
.87843 .87843 Mdot
.45098 .25098 Mdot
.72941 .41569 Mdot
.90588 .43137 Mdot
.85882 .52549 Mdot
.78824 .50588 Mdot
.77255 .69412 Mdot
.81176 .60784 Mdot
.95294 .51765 Mdot
.78824 .52157 Mdot
.43922 .39608 Mdot
.27451 .23922 Mdot
.67059 .28627 Mdot
.82353 .47059 Mdot
.98824 .87843 Mdot
.93333 .86667 Mdot
.83137 .4549 Mdot
1 .83137 Mdot
.73725 .43529 Mdot
.22353 .22353 Mdot
.14902 .13333 Mdot
.14902 .13333 Mdot
.17647 .13333 Mdot
.88627 .88627 Mdot
.45098 .39608 Mdot
.87843 .87843 Mdot
.44706 .26275 Mdot
.6 .35686 Mdot
.96078 .42745 Mdot
.8902 .48235 Mdot
1 .72157 Mdot
.54118 .45882 Mdot
.97647 .74118 Mdot
.93725 .4549 Mdot
.77647 .5098 Mdot
.53333 .4902 Mdot
.25882 .22353 Mdot
.69412 .29804 Mdot
.81569 .50588 Mdot
1 .87451 Mdot
.94902 .86667 Mdot
.84706 .49412 Mdot
1 .83529 Mdot
.72157 .43922 Mdot
.23137 .22353 Mdot
.14902 .13333 Mdot
.15294 .13333 Mdot
.21961 .17647 Mdot
.88627 .88627 Mdot
.62745 .56863 Mdot
.87451 .87451 Mdot
.58039 .41176 Mdot
.63137 .3451 Mdot
.97255 .42353 Mdot
.89412 .46667 Mdot
.96471 .67059 Mdot
.32549 .22745 Mdot
.9098 .56863 Mdot
.94118 .42353 Mdot
.51373 .3451 Mdot
.37255 .33725 Mdot
.21176 .17255 Mdot
.9098 .43529 Mdot
.40784 .23529 Mdot
.49804 .32941 Mdot
.97647 .85098 Mdot
.47451 .2549 Mdot
.63922 .27843 Mdot
.36863 .18431 Mdot
.23137 .21961 Mdot
.16078 .14902 Mdot
.1451 .1098 Mdot
.88235 .84706 Mdot
.8902 .8902 Mdot
.58824 .53333 Mdot
.87451 .87451 Mdot
.51765 .38431 Mdot
.9098 .42353 Mdot
.95686 .42353 Mdot
.90196 .48627 Mdot
.8549 .63529 Mdot
.98039 .75294 Mdot
.93725 .46275 Mdot
.92157 .40392 Mdot
.26667 .23922 Mdot
.47451 .43529 Mdot
.27059 .12941 Mdot
.87059 .43529 Mdot
.9451 .87059 Mdot
.98039 .90588 Mdot
.83922 .40392 Mdot
.9451 .8549 Mdot
.88235 .38039 Mdot
.21569 .17647 Mdot
.16078 .15294 Mdot
.17647 .15294 Mdot
.19216 .14902 Mdot
.88627 .88627 Mdot
.93333 .92941 Mdot
.51765 .49412 Mdot
.96078 .88235 Mdot
1 .96863 Mdot
.89412 .36863 Mdot
.95294 .41961 Mdot
.9098 .47059 Mdot
.94118 .65882 Mdot
.93333 .48235 Mdot
.9451 .40784 Mdot
.80784 .52157 Mdot
.26667 .24706 Mdot
.52549 .49412 Mdot
.75294 .33725 Mdot
.36078 .22745 Mdot
.45882 .28627 Mdot
.98431 .84314 Mdot
.47451 .26275 Mdot
.65882 .31765 Mdot
.53725 .31373 Mdot
.22745 .21569 Mdot
.14902 .14118 Mdot
.16471 .12549 Mdot
.45098 .43137 Mdot
.88627 .88627 Mdot
.85098 .81176 Mdot
.88235 .87451 Mdot
.7098 .61569 Mdot
.77255 .42745 Mdot
.92157 .39608 Mdot
.94902 .44314 Mdot
.8902 .49412 Mdot
.9098 .4549 Mdot
.9451 .40784 Mdot
.87451 .39608 Mdot
.28235 .24314 Mdot
.2549 .23137 Mdot
.63529 .39216 Mdot
.45882 .23922 Mdot
1 .87451 Mdot
.94118 .86667 Mdot
.83529 .48627 Mdot
1 .83529 Mdot
.83137 .42745 Mdot
.19608 .18431 Mdot
.15686 .15294 Mdot
.12157 .09804 Mdot
.44706 .41961 Mdot
.8902 .8902 Mdot
.86667 .85098 Mdot
.89412 .8902 Mdot
.5451 .45098 Mdot
.69804 .56471 Mdot
.86275 .43137 Mdot
.91765 .39608 Mdot
.95686 .46275 Mdot
.9451 .4549 Mdot
.94902 .40784 Mdot
.94902 .41569 Mdot
.30588 .22353 Mdot
.25882 .24314 Mdot
.46667 .30588 Mdot
.48235 .24706 Mdot
1 .88235 Mdot
.93725 .87843 Mdot
.80784 .45882 Mdot
.97255 .83922 Mdot
.87843 .40784 Mdot
.16078 .14902 Mdot
.15686 .1451 Mdot
.2549 .24314 Mdot
.33725 .31373 Mdot
.88627 .88627 Mdot
.91373 .91373 Mdot
.8902 .87451 Mdot
.94118 .87059 Mdot
.96471 .89804 Mdot
.76863 .42353 Mdot
.90196 .41176 Mdot
.94902 .42745 Mdot
.96471 .43137 Mdot
.95686 .40784 Mdot
.9098 .41176 Mdot
.30588 .23529 Mdot
.27059 .24706 Mdot
.38431 .13725 Mdot
.95686 .79216 Mdot
.65098 .43529 Mdot
.94118 .86275 Mdot
.45882 .2549 Mdot
.85882 .6 Mdot
.81176 .46275 Mdot
.16471 .16078 Mdot
.20784 .2 Mdot
.45882 .45098 Mdot
.15294 .12549 Mdot
.88627 .88627 Mdot
.69804 .68235 Mdot
.88235 .87843 Mdot
.36863 .29804 Mdot
.84706 .71373 Mdot
.81569 .43529 Mdot
.91765 .38431 Mdot
.95686 .40784 Mdot
.95686 .40784 Mdot
.94118 .40784 Mdot
.3098 .17255 Mdot
.27059 .23529 Mdot
.34902 .19608 Mdot
.7098 .41176 Mdot
.89412 .6549 Mdot
.9451 .87059 Mdot
.58824 .45098 Mdot
1 .79608 Mdot
.82353 .42353 Mdot
.18039 .17255 Mdot
.47843 .46275 Mdot
.21961 .21176 Mdot
.18039 .14118 Mdot
.88627 .88627 Mdot
.90196 .89412 Mdot
.90196 .89804 Mdot
.57647 .50588 Mdot
.93725 .81961 Mdot
.78824 .42745 Mdot
.96078 .41569 Mdot
.92941 .38039 Mdot
.9451 .40784 Mdot
.91765 .43922 Mdot
.21569 .15686 Mdot
.26275 .22745 Mdot
.75686 .37255 Mdot
.82353 .51373 Mdot
.64706 .36863 Mdot
.99216 .85098 Mdot
.98431 .87059 Mdot
.93333 .38431 Mdot
.39608 .2902 Mdot
.48627 .47059 Mdot
.16471 .14902 Mdot
.16471 .16078 Mdot
.95686 .94902 Mdot
.8902 .8902 Mdot
.32941 .30588 Mdot
.8902 .87451 Mdot
.74118 .73725 Mdot
.70588 .50196 Mdot
.92157 .40392 Mdot
.93333 .38039 Mdot
.92157 .37255 Mdot
.9451 .43529 Mdot
.22745 .12157 Mdot
.23137 .19608 Mdot
.74902 .37255 Mdot
.87451 .45098 Mdot
.74902 .36471 Mdot
.9098 .63922 Mdot
1 .78039 Mdot
.92941 .37647 Mdot
.43137 .35294 Mdot
.20392 .2 Mdot
.17255 .15686 Mdot
.16863 .15294 Mdot
.93333 .92549 Mdot
.8902 .8902 Mdot
.40784 .37255 Mdot
.8902 .87451 Mdot
.92157 .91765 Mdot
.83922 .42353 Mdot
.94118 .41569 Mdot
.9451 .42353 Mdot
.89804 .37647 Mdot
.43137 .14902 Mdot
.18824 .1098 Mdot
.34902 .13333 Mdot
.93725 .42745 Mdot
.91373 .41569 Mdot
.78824 .39608 Mdot
.78824 .4549 Mdot
.91765 .4 Mdot
.61569 .43137 Mdot
.16471 .14902 Mdot
.15294 .14902 Mdot
.17255 .15294 Mdot
.38039 .35294 Mdot
.8902 .8902 Mdot
.47843 .43922 Mdot
.88235 .87843 Mdot
.73725 .72157 Mdot
.80392 .45098 Mdot
.94118 .43529 Mdot
.90196 .44314 Mdot
.9098 .43529 Mdot
.55686 .20784 Mdot
.22745 .10588 Mdot
.38431 .07451 Mdot
.93725 .41961 Mdot
.93333 .41961 Mdot
.92157 .4549 Mdot
.88235 .42745 Mdot
.93725 .38431 Mdot
.26275 .18431 Mdot
.16078 .1451 Mdot
.15686 .1451 Mdot
.16078 .14118 Mdot
.96078 .95294 Mdot
.89412 .89412 Mdot
.81569 .76078 Mdot
.89412 .87843 Mdot
.91373 .91765 Mdot
.75686 .43529 Mdot
.84706 .43137 Mdot
.76471 .43922 Mdot
.81569 .4549 Mdot
.65098 .33333 Mdot
.24314 .06667 Mdot
.9098 .44314 Mdot
.94902 .41569 Mdot
.93725 .41961 Mdot
.94118 .42745 Mdot
.93333 .40392 Mdot
.90196 .4 Mdot
.20392 .2 Mdot
.16863 .14902 Mdot
.14902 .13725 Mdot
.15686 .13333 Mdot
.88627 .88627 Mdot
.90588 .8902 Mdot
.56078 .54118 Mdot
.94902 .92941 Mdot
.76471 .69804 Mdot
.6902 .43922 Mdot
.7451 .58039 Mdot
.65098 .47059 Mdot
.65882 .43137 Mdot
.53725 .25098 Mdot
.42745 .0549 Mdot
.95686 .44314 Mdot
.92941 .41176 Mdot
.92941 .41176 Mdot
.95294 .41569 Mdot
.93725 .38431 Mdot
.30196 .18431 Mdot
.16863 .15294 Mdot
.17255 .14118 Mdot
.1451 .12941 Mdot
.89804 .8902 Mdot
.8902 .8902 Mdot
.62353 .58039 Mdot
.88235 .87843 Mdot
.84314 .86275 Mdot
.73725 .60784 Mdot
1 .96471 Mdot
.91765 .8549 Mdot
.58431 .47451 Mdot
.6549 .40784 Mdot
.67059 .30196 Mdot
.93333 .44314 Mdot
.94902 .43922 Mdot
.94118 .41961 Mdot
.94902 .41176 Mdot
.94902 .4 Mdot
.3098 .16471 Mdot
.18039 .16078 Mdot
.17255 .13725 Mdot
.14902 .13333 Mdot
.95294 .9451 Mdot
.89412 .89412 Mdot
.49412 .46275 Mdot
.88235 .87843 Mdot
.96471 .98431 Mdot
.99216 .96471 Mdot
.70588 .63137 Mdot
.67059 .45098 Mdot
.81569 .41176 Mdot
.89412 .41176 Mdot
.95686 .45098 Mdot
.96471 .44314 Mdot
.95686 .4 Mdot
.8 .46275 Mdot
.18431 .13333 Mdot
.14902 .1451 Mdot
.16863 .1451 Mdot
.24314 .22353 Mdot
.89412 .8902 Mdot
.89804 .89412 Mdot
.88627 .88627 Mdot
.39216 .41569 Mdot
.8902 .78824 Mdot
.76078 .49804 Mdot
.78039 .41569 Mdot
.84314 .40784 Mdot
.8902 .41961 Mdot
.92549 .41569 Mdot
.86275 .43137 Mdot
.21176 .11373 Mdot
.05098 .04314 Mdot
.07059 .04706 Mdot
.24314 .23922 Mdot
.90588 .89804 Mdot
.88627 .88627 Mdot
.87451 .87451 Mdot
.39216 .39216 Mdot
1 .95294 Mdot
.85098 .70196 Mdot
.70588 .45882 Mdot
.76078 .41961 Mdot
.80392 .38824 Mdot
.84314 .38431 Mdot
.53725 .30196 Mdot
.4902 .48235 Mdot
.42745 .41961 Mdot
.44706 .44706 Mdot
.56078 .58039 Mdot
.89412 .8902 Mdot
.88627 .8902 Mdot
.9451 .91765 Mdot
1 .96471 Mdot
.93333 .77647 Mdot
.83529 .60392 Mdot
.77255 .46667 Mdot
.72941 .39216 Mdot
.77255 .6549 Mdot
.91765 .90196 Mdot
.90588 .89804 Mdot
.21569 .25098 Mdot
.31765 .33725 Mdot
.89804 .89412 Mdot
.88627 .89804 Mdot
.28235 .27059 Mdot
1 .94902 Mdot
.95686 .83529 Mdot
.81961 .67059 Mdot
.81961 .78431 Mdot
.87451 .86667 Mdot
.60392 .59608 Mdot
.27059 .32157 Mdot
.28627 .32941 Mdot
.8 .80784 Mdot
.78431 .80392 Mdot
.82745 .82353 Mdot
.62353 .60392 Mdot
.2549 .26275 Mdot
.61176 .61569 Mdot
.53725 .58039 Mdot
.6902 .73333 Mdot
.87451 .87843 Mdot
.89804 .9098 Mdot
.95686 .96863 Mdot
.39608 .44314 Mdot
.23922 .28627 Mdot
.9098 .93725 Mdot
.62353 .66667 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 190.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000_R000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002_oooone
o`00017ooooo]Ol0000;ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/Oooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooooooo
o`0Qooooo`03oomo0?oooooooooo08gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Uooooo`03oj0Pl?oooooooooo02Wooooo00?oX23`ooooooooool0GOooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0/Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00onP8?3oooooooooo`0=oooo
o`03oj0Pl?oooooooooo07Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool0/Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Kooooo00?oX23`ooooooooool0@Oooool00onP8?3oooooooooo`1Tooooo`03o`00
0?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`09ooooo`03oj0Pl?oooooooooo01Sooooo00?oX23`ooooooooool0R_oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2aooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool2oj0Pl1_ooooo00?oX23`ooooooooool07Oooool0
0onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo06Cooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool04?ooool00oooO`3oooooooooo`2Nooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0<_ooool00onP8?3oooooooooo`1looooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo00oooooo00?oogl0ooooooooool0Woooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?oX23`ooooooooool06_ooool00onP8?3o
ooooooooo`09ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool05_ooool00onP8?3o
ooooooooo`1Kooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo00cooooo
00?oogl0ooooooooool05oooool00oooO`3oooooooooo`28ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04Oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo01oooooo
00GoX23`oooooooooooooooooj0Pl01`ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo01Cooooo00?oogl0ooooooooool0V_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00[ooooo00?oX23`oooooonP8?00:oooool01OnP8?3oooooooooooooooooX23`00Go
oooo00?oX23`ooooooooool0K?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`0/ooooo`03oomo0?oooooooooo08;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0<ooooo`03oj0Pl?oooooooooo00Kooooo00GoX23`oooooooooooooooooj0Pl00Eooooo`03
oj0Pl?oooooooooo00Gooooo00CoX23`ooooooooooooX23`7Oooool00onP8?3oooooooooo`1Foooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo01Wooooo00?oogl0oooooooo
ool0UOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo00?oX23`oooooooo
ool00_ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo01gooooo00?oX23`oooooooo
ool00_ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo05Gooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool05?ooool00oooO`3oooooooooo`0Hooooo`03oomo
0?oooooooooo07oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03oj0P
l?oooooooooo00Oooooo00?oX23`ooooooooool01oooool00onP8?3oooooooooo`04ooooo`04oj0P
l?oooooooooooj0Pl2Kooooo00?oX23`ooooooooool0G?ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`0@ooooo`05oomo0?ooooooooooooooooooO`003_ooool00oooO`3o
ooooooooo`09ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool0MOooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo0_nP8?02ooooo`05oj0Pl?ooooooX23`oooo
oonP8?000_ooool00onP8?3oooooooooo`0=ooooo`04oj0Pl?oooooooooooj0Pl0Cooooo00?oX23`
ooooooooool01?ooool00onP8?3oooooooooo`0@ooooo`04oj0Pl?oooooooooooj0Pl6?ooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool04oooool01_ooO`3ooooooooooooo
O`3ooooooomo09Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`;oX23`
00Gooooooj0Pl?nP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`oooooooo
ool0R?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0@ooooo`;oogl0
3Oooool00oooO`3oooooooooo`2?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4Oooool00onP8?3ooooooj0Pl002ooooo`;oX23`0_ooool00onP8?3oooooooooo`02ooooo`03oj0P
l?oooooooooo01Oooooo00?oX23`ooooooooool0MOooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`0@ooooo`;oogl01?ooool3oomo00Gooooo00Koogl0oooooooooooooooo
oomo0?ooool2oomo0003ooooooooO`3ooooo01gooooo00?oogl0ooooooooool0J?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?oX23`oooooonP8?000_nP8?001Ooooooo
X23`ooooooooooooX23`00?ooooo0_nP8?05ooooo`03oj0Pl?oooooooooo02kooooo00?oX23`oooo
ooooool0F_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Booooo`03
oomo0?oooooooooo00Cooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0@ooooo`03
oomo0?oooooooooo07cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`;o
X23`0_ooool3oj0Pl0Cooooo00?oX23`ooooooooool01?ooool00onP8?3ooooooj0Pl003ooooo`03
oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool08?ooool00onP8?3oooooooooo`1Looooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo01Cooooo0oooO`000oooooooogl0
ooooo`02oomo00Cooooo0oooO`07ooooo`03oomo0?oooooooooo01;ooooo00?oogl0ooooooooool0
Koooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?oX23`oooooonP8?00
0_nP8?000oooooooX23`oj0Pl004oj0Pl0Cooooo00?oX23`ooooooooool00_ooool00onP8?3ooooo
ooooo`05ooooo`03oj0Pl?oooooooooo027ooooo00?oX23`ooooooooool0G?ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`0Fooooo`06oomo0?ooooooogl0oomo0?oooooo
ogl00oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo02Sooooo00?oogl0oooooooo
ool0G?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00CoX23`oooooonP
8?3ooooo0onP8?03ooooo`?oX23`7?ooool00onP8?3oooooooooo`0Booooo`03oj0Pl?oooooooooo
00Oooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`13ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo01Kooooo00?oogl0ooooooooO`000_ooO`001_oooooo
ogl0ooooooooO`3ooooooomo093ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0D
ooooo`?oX23`00?ooooooj0Pl?nP8?000_ooool01?nP8?3ooooooooooonP8?0Rooooo`03oj0Pl?oo
oooooooo06cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool05?ooool0
1?ooO`3ooooooomo0?ooool5oomo0003ooooooooO`3ooooo00;ooooo00?oogl0ooooooooool08Ooo
ool00oooO`3oooooooooo`1Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Ooo
ool;oj0Pl0?ooooo00CoX23`ooooooooooooX23`R_ooool00ol0003oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`0Eooooo`04oomo0?oooooooooooomo00;ooooo00?oogl0ooooooooO`00
0_ooool00oooO`3ooooooomo002>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6?ooool02?nP8?3ooooooj0Pl?nP8?3ooooooj0Pl?ooooooX23`0_ooool00onP8?3oooooooooo`0=
ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`1T
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo01_ooooo00Coogl0oooo
ooooO`3oogl00oooool01?ooO`3oooooooooooooO`07ooooo`03oomo0?oooooooooo02_ooooo00?o
ogl0ooooooooool02?ooool00oooO`3oooooooooo`18ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06?ooool8oj0Pl007oooooonP8?3ooooooooooonP8?3ooooooj0Pl00@ooooo`03
oj0Pl?oooooooooo01[ooooo00?oX23`ooooooooool0F_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`0Jooooo`03oomo0?oooooooooo00;ooooo0_ooO`0aooooo`03oomo
0?oooooooooo01;ooooo0_ooO`18ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6_ooool01OnP8?3ooooooj0Pl?nP8?3ooooo00?oX23`00?ooooooj0Pl?nP8?000_ooool2oj0Pl0;o
oooo00CoX23`ooooooooooooX23`0oooool01?nP8?3ooooooooooonP8?1kooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo01kooooo1oooO`05ooooo`03oomo0?oooooooooo
00gooooo00?oogl0ooooooooool02_ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo
00;ooooo00?oogl0ooooooooool01Oooool01oooO`3oooooooooooooO`3ooooooomo0?ooool00_oo
O`04ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool0?oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Sooooo00CoX23`oooooonP8?3ooooo0onP8?02ooooo`03oj0P
l?ooooooX23`00[ooooo0onP8?02ooooo`03oj0Pl?ooooooX23`00;ooooo00GoX23`oooooooooooo
oooooj0Pl00Looooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool0BOooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0Qooooo`05oomo0?oooooooooooooooooo
O`001oooool01OooO`3oooooooooooooooooogl0027ooooo00?oogl0ooooooooool01Oooool01Ooo
O`3oooooooooooooooooogl0057ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0M
ooooo`07oj0Pl?ooooooX23`oooooonP8?3ooooooj0Pl00Aooooo`03oj0Pl?ooooooX23`07Wooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool08Oooool4oomo01Cooooo00?o
ogl0ooooooooool01_ooool00oooO`3oooooooooo`0Gooooo`03oomo0?oooooooooo017ooooo00?o
ogl0ooooooooool01_ooool00oooO`3oooooooooo`0eooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06?ooool01?nP8?3oooooooooooooool2oj0Pl003oooooonP8?3ooooo00;oX23`
00?ooooooj0Pl?ooool03oooool00onP8?3oooooooooo`1iooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo01kooooo00Ooogl0oooooooooooooooooomo0?ooooooogl000Oo
oooo00?oogl0ooooooooool04Oooool00oooO`3oooooooooo`02ooooo`05oomo0?oooooooooooooo
ooooO`001?ooool00oooO`3ooooooomo0002ooooo`03oomo0?ooooooogl000?ooooo00?oogl0oooo
ooooool00_ooool01?ooO`3oooooooooooooO`0<ooooo`04oomo0?ooooooogl0oomo03oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo
00?oX23`ooooooooool01_ooool01?nP8?3ooooooooooonP8?03ooooo`03oj0Pl?oooooooooo00Wo
oooo00?oX23`ooooooooool01?ooool2oj0Pl6Wooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool08_ooool01?ooO`3oooooooooooooO`0Dooooo`03oomo0?oooooooooo00co
oooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`06ooooo`;oogl00_ooool00oooO`3o
oooooomo000:ooooo`04oomo0?oooooooooooomo00;ooooo0_ooO`0hooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07oooool00onP8?3oooooooooo`0Jooooo`03oj0Pl?oooooooooo
07;ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool08oooool3oomo0004
ooooooooO`3ooooooomo00Oooooo00?oogl0ooooooooool02oooool00oooO`3oooooooooo`06oooo
o`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooO`001?ooool00oooO`3ooooooomo000?oooo
o`07oomo0?ooooooogl0ooooooooO`3ooooooomo000looooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06Oooool00onP8?3oooooooooo`03ooooo`CoX23`0oooool2oj0Pl0;ooooo00?o
X23`ooooooooool03oooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00?ooooo00?o
X23`ooooooooool01?ooool00onP8?3oooooooooo`1Mooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo02Cooooo00Googl0oooooooooooooooooomo0007ooooo`03oomo0?oo
oooooooo00[ooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`03ooooo`;oogl01ooo
ool01OooO`3oooooooooooooooooogl001;ooooo0oooO`0jooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool08Oooool2oj0Pl005oooooonP8?3ooooooj0Pl?ooool00_nP8?08ooooo`03
oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`0;ooooo`03
oj0Pl?oooooooooo05Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
8oooool3oomo01cooooo00?oogl0ooooooooool01_ooool00oooO`3oooooooooo`1Sooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08Oooool00onP8?3oooooooooo`04ooooo`;oX23`
1_ooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?ooooooX23`01kooooo00?oX23`ooooooooool0
2Oooool00onP8?3oooooooooo`14ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo02;ooooo00?oogl0ooooooooool00oooO`000oooooooogl0oomo000Dooooo`03oomo0?oo
ooooogl000Kooooo00?oogl0ooooooooool06_ooool00oooO`3oooooooooo`02oomo00?ooooo00?o
ogl0ooooooooool01?ooool01OooO`3oooooooooooooO`3ooooo00;oogl0=_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo027ooooo00CoX23`ooooooooooooX23`1?ooool2oj0Pl0;o
oooo00?oX23`ooooooooool00_ooool01?nP8?3ooooooooooonP8?0@ooooo`03oj0Pl?oooooooooo
00?ooooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo
00Kooooo00?oX23`ooooooooool0A?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`0Wooooo`05oomo0?ooooooogl0ooooooooO`007_ooool00oooO`3ooooooomo000?oooo
o`04oomo0?oooooooooooomo00[ooooo00Coogl0ooooooooooooogl0@oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo027ooooo00GoX23`ooooooooooooX23`ooooo`02oj0Pl004oooo
oonP8?3ooooooj0Pl8Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
9_ooool01?ooO`3ooooooomo0?ooO`09ooooo`03oomo0?ooooooogl000?ooooo00?oogl0oooooooo
ool04oooool01?ooO`3oooooooooooooO`05ooooo`05oomo0?ooooooooooooooooooO`000_ooool0
1?ooO`3oooooooooooooO`05ooooo`;oogl00oooool2oomo00Oooooo0_ooO`08ooooo`03oomo0?oo
oooooooo00;ooooo00?oogl0ooooooooool0:Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02?ooooo2onP8?06ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`ooooooooool04Ooo
ool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`ooooooooool01Ooo
ool00onP8?3oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo03Sooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`0[ooooo`03oomo0?oooooo
oooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`0Zooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09oooool00onP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooo
oooo00Sooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`1`ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo02cooooo00?oogl0ooooooooool03oooool00ooo
O`3oooooooooo`0Eooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool01oooool00ooo
O`3oooooooooo`08ooooo`;oogl0>Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02Cooooo0_nP8?000oooooooX23`oj0Pl002ooooo`03oj0Pl?oooooooooo00?oX23`0oooool00onP
8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00;ooooo0onP8?02ooooo`03oj0Pl?oooooooooo
00Oooooo00?oX23`ooooooooool06Oooool00onP8?3oooooooooo`12ooooo`03o`000?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo02Wooooo00?oogl0ooooooooool00_ooool01?ooO`3o
ooooooooooooO`08ooooo`;oogl03?ooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooooooo
00;ooooo00?oogl0ooooooooool00oooool01?ooO`3oooooooooooooool2oomo0003ooooooooO`3o
oooo00;ooooo00?oogl0ooooooooO`000_ooool00oooO`3ooooooomo0006ooooo`03oomo0?oooooo
oooo00;ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Wooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0:Oooool3oj0Pl003oooooonP8?3oX23`00kooooo00?oX23`
ooooooooool02Oooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00cooooo00GoX23`
oooooooooooooooooj0Pl008ooooo`03oj0Pl?oooooooooo04?ooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool0;?ooool00oooO`3oooooooooo`0=ooooo`03oomo0?oooooo
oooo00Oooooo00?oogl0ooooooooool05Oooool2oomo057ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Xooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo00GoX23`oooooonP8?3ooooo
oj0Pl00Qooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool02_ooool00onP8?3ooooo
ooooo`11ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo02[ooooo0_oo
O`000oooooooogl0oomo0002ooooo`03oomo0?oooooooooo00Sooooo0_ooO`0Dooooo`04oomo0?oo
oooooooooomo00gooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`02ooooo`;oogl0
0oooool2oomo0003ooooooooO`3oogl000Kooooo00Coogl0ooooooooO`3ooooo0_ooO`04ooooo`?o
ogl09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?oX23`oooooooo
ool01?ooool6oj0Pl003oooooonP8?3ooooo00Sooooo00?oX23`ooooooooool01?ooool00onP8?3o
ooooooooo`08ooooo`;oX23`1?ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?ooooooX23`00co
oooo00?oX23`oooooonP8?005?ooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?ooooooX23`01[o
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0;Oooool01?ooO`3ooooo
ooooooooO`0:ooooo`03oomo0?oooooooooo00Kooooo00?oogl0ooooooooool02oooool01oooO`3o
ooooooooooooooooogl0ooooooooO`000oooool00oooO`3oooooooooo`05ooooo`05oomo0?oooooo
ooooooooooooO`000_ooool00oooO`3oooooooooo`03ooooo`04oomo0?oooooooooooomo00;ooooo
00?oogl0ooooooooool00oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00Cooooo
00?oogl0ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02_ooooo
00?oX23`ooooooooool00oooool01OnP8?3oooooooooooooooooX23`01Wooooo00CoX23`oooooooo
ooooX23`9oooool00onP8?3oooooooooo`0Iooooo`;oX23`6Oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`0aooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
O`002Oooool00oooO`3oooooooooo`08ooooo`;oogl03Oooool00oooO`3oooooooooo`02ooooo`03
oomo0?oooooooooo00Kooooo0_ooO`03ooooo`03oomo0?oooooooooo00?ooooo00Coogl0oooooooo
ooooogl01_ooool01OooO`3ooooooomo0?ooooooogl000;ooooo00Coogl0ooooooooooooogl02Ooo
ool00oooO`3ooooooomo000Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Ooo
ool00onP8?3ooooooj0Pl002ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`ooooooooool01Ooo
ool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool03_oo
ool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo01_ooooo00?oX23`ooooooooool05Ooo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0/ooooo`03oomo0?oooooo
ogl000Cooooo00?oogl0ooooooooool01?ooool01OooO`3oooooooooooooooooogl000cooooo00?o
ogl0ooooooooool01Oooool01?ooO`3oooooooooooooO`0=ooooo`03oomo0?oooooooooo00Cooooo
00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`04ooooo`;oogl000?ooooooomo0?ooool0
2?ooool00oooO`3ooooooomo0002ooooo`04oomo0?ooooooooooooooo`?oogl000Gooooooomo0?oo
oooooooooomo000Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:oooool00onP
8?3oooooooooo`02oj0Pl0Gooooo00?oX23`ooooooooool05Oooool00onP8?3oooooooooo`06oooo
o`03oj0Pl?oooooooooo02[ooooo00?oX23`ooooooooool02?ooool00onP8?3oooooooooo`04oooo
o`03oj0Pl?oooooooooo01Wooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooooooo
ool0<Oooool00oooO`3oooooooooo`0Booooo`03oomo0?oooooooooo00Wooooo00?oogl0oooooooo
ool04oooool00oooO`3oooooooooo`0:ooooo`07oomo0?ooooooooooooooooooO`3ooooooomo0003
ooooo`03oomo0?oooooooooo00Gooooo00Coogl0ooooooooooooogl01_ooool2oomo01kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`03oj0Pl?oooooooooo00kooooo00?o
X23`ooooooooool06?ooool00onP8?3oooooooooo`0Qooooo`03oj0Pl?oooooooooo00?ooooo00?o
X23`oooooonP8?00:?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`0`
ooooo`04oomo0?oooooooooooomo00Cooooo00?oogl0ooooooooool03Oooool01OooO`3ooooooooo
ooooooooogl000?ooooo00?oogl0ooooooooool02Oooool00oooO`3ooooooomo0004ooooo`;oogl0
00?ooooooomo0?ooool00oooool02OooO`3oooooooooooooooooogl0ooooooooO`3ooooooomo0007
ooooo`03oomo0?ooooooogl000?ooooo00Coogl0oooooooooooooooo0_ooO`03ooooo`04oomo0?oo
ooooooooooooo`Coogl000?ooooooomo0?ooool00_ooO`000oooooooogl0ooooo`0Gooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0<Oooool01OnP8?3oooooooooooooooooX23`02So
oooo00?oX23`ooooooooool03oooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?oooooooooo00oo
oooo00?oX23`oooooonP8?001_ooool3oj0Pl003oooooonP8?3ooooo01?ooooo00?o0000oooooooo
ool02Oooool000[ooooo00?o0000ooooooooool0@_ooool00oooO`3oooooooooo`0Eooooo`03oomo
0?oooooooooo00Gooooo00?oogl0ooooooooool03oooool00oooO`3oooooooooo`02ooooo`03oomo
0?ooooooogl000;ooooo00Googl0oooooooooooooooooomo0008ooooo`;oogl000?ooooooomo0?oo
O`000_ooO`04ooooo`03oomo0?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0/ooooo`03oj0Pl?ooooooX23`00;ooooo00?oX23`oooooonP8?00;Oooool00onP8?3o
ooooooooo`05ooooo`05oj0Pl?oooooooooooooooonP8?002?ooool2oj0Pl1gooooo00CoX23`oooo
ooooooooX23`0_ooool2oj0Pl1Cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0>Oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo01Cooooo00?oogl0oooo
ooooool00oooool01?ooO`3ooooooomo0?ooO`03ooooo`04oomo0?oooooooooooomo00?ooooo0_oo
O`000oooooooogl0ooooo`02ooooo`03oomo0?oooooooooo00Cooooo0_ooO`000oooooooogl0oooo
o`03ooooo`;oogl000Gooooooomo0?oooooooooooomo0002ooooo`;oogl00_ooool5oomo0003oooo
ooooO`3ooooo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03oj0P
l?oooooooooo00;ooooo0_nP8?03ooooo`05oj0Pl?ooooooX23`oooooonP8?000oooool01OnP8?3o
ooooooooooooooooX23`00Gooooo00?oX23`ooooooooool02?ooool01onP8?3ooooooooooooooooo
X23`oooooonP8?003Oooool00onP8?3ooooooj0Pl004ooooo`;oX23`2_ooool01OnP8?3ooooooooo
ooooooooX23`00Oooooo00?oX23`ooooooooool02oooool01?nP8?3ooooooj0Pl?ooool2oj0Pl0?o
oooo0_nP8?000oooooooX23`oj0Pl00Cooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo043ooooo00Googl0oooooooooooooooooomo0002ooooo`03oomo0?oooooooooo01Wo
oooo00Coogl0ooooooooooooogl01_ooool00oooO`3oooooooooo`02oomo013ooooo00?oogl0oooo
ooooool01oooool2oomo00;ooooo00Coogl0ooooooooooooogl07Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo037ooooo00CoX23`ooooooooooooX23`0_ooool00onP8?3ooooooooo
o`0Eooooo`03oj0Pl?oooooooooo03Cooooo00?oX23`ooooooooool04Oooool00onP8?3ooooooooo
o`0Dooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo06?ooooo00?oogl0
ooooooooool03?ooool3oomo00Kooooo00?oogl0ooooooooO`001Oooool00oooO`3ooooooomo0004
ooooo`?oogl00oooool2oomo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0o
ooooo`03oj0Pl?oooooooooo03Sooooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`0B
ooooo`;oX23`00?ooooooj0Pl?ooool05Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`0jooooo`;oogl01oooool2oomo013ooooo00?oogl0ooooooooool02oooool01Ooo
O`3oooooooooooooooooogl000Cooooo0_ooO`0;ooooo`03oomo0?oooooooooo00Wooooo00?oogl0
ooooooooO`001Oooool5oomo0005ooooooooO`3oooooooooooooO`006_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03Cooooo00WoX23`oooooooooooooooooj0Pl?ooooooX23`oooo
oonP8?004Oooool01_nP8?3ooooooooooonP8?3ooooooj0Pl0Sooooo00?oX23`oooooonP8?001ooo
ool00onP8?3oooooooooo`0=ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01?oo
ool00onP8?3oooooooooo`03ooooo`07oj0Pl?oooooooooooooooonP8?3ooooooj0Pl002ooooo`;o
X23`1?ooool01?nP8?3ooooooooooonP8?02ooooo`03oj0Pl?oooooooooo00oooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0Aoooool00oooO`3oooooooooo`0@ooooo`03
oomo0?oooooooooo00;ooooo00?oogl0ooooooooO`004_ooool00oooO`3ooooooomo0004ooooo`03
oomo0?oooooooooo00;ooooo00?oogl0ooooooooool01oooool00oooO`3ooooooomo000Tooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool00onP8?3oooooooooo`0[ooooo`03
oj0Pl?oooooooooo02?ooooo00?oX23`ooooooooool01?ooool01?nP8?3ooooooooooonP8?08oooo
o`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool03oooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`1;ooooo`05oomo0?ooooooooooooooooooO`003Oooool00ooo
O`3ooooooomo000:ooooo`;oogl000?ooooooomo0?ooool01?ooool01?ooO`3oooooooooooooO`02
ooooo`;oogl00oooool00oooO`3ooooooomo0004ooooo`03oomo0?ooooooogl000;ooooo00?oogl0
ooooooooool00_ooool01OooO`3ooooooomo0?ooooooogl001gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0fooooo`07oj0Pl?oooooooooooooooonP8?3ooooooj0Pl00:ooooo`03
oj0Pl?oooooooooo00oooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0Booooo`04
oj0Pl?oooooooooooj0Pl0Cooooo00?oX23`ooooooooool01_ooool01?nP8?3ooooooooooonP8?02
ooooo`03oj0Pl?ooooooX23`00gooooo00?oX23`oooooonP8?000oooool00onP8?3oooooooooo`0>
ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo03_ooooo00?oogl0oooo
ooooool04?ooool00oooO`3oooooooooo`05ooooo`05oomo0?ooooooooooooooooooO`002oooool0
0oooO`3oooooooooo`02ooooo`05oomo0?ooooooogl0ooooooooO`004Oooool00oooO`3ooooooomo
0008ooooo`04oomo0?ooooooogl0oomo027ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0^ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool00_ooool2oj0Pl0Cooooo
00?oX23`ooooooooool0D_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo01Cooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0>_ooool00oooO`3ooooooooo
o`02ooooo`03oomo0?oooooooooo01;ooooo00?oogl0ooooooooO`000_ooool00oooO`3ooooooooo
o`07ooooo`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooO`001Oooool00oooO`3ooooooomo
000Hooooo`03oomo0?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0`ooooo`03oj0Pl?oooooooooo00Wooooo0_nP8?02ooooo`;oX23`1?ooool00onP8?3ooooooooo
o`0<ooooo`;oX23`00?ooooooj0Pl?ooool00_ooool01OnP8?3oooooooooooooooooX23`00?ooooo
0_nP8?0;ooooo`04oj0Pl?oooooooooooj0Pl0Kooooo00?oX23`ooooooooool03Oooool00onP8?3o
ooooooooo`03ooooo`03oj0Pl?oooooooooo00;ooooo00GoX23`ooooooooooooX23`ooooo`02oj0P
l0;ooooo00CoX23`ooooooooooooX23`3_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`1Eooooo`03oomo0?oooooooooo00gooooo00?oogl0ooooooooool02Oooool00ooo
O`3oooooooooo`0?ooooo`05oomo0?ooooooooooooooooooO`000_ooool00oooO`3oooooooooo`0T
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool00onP8?3oooooooooo`0R
ooooo`03oj0Pl?oooooooooo013ooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`06
ooooo`03oj0Pl?oooooooooo01Kooooo00?oX23`ooooooooool00_ooool2oj0Pl0;ooooo00?oX23`
ooooooooool02oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1>oooo
o`05oomo0?ooooooogl0ooooooooO`000_ooool00oooO`3oooooooooo`06ooooo`05oomo0?oooooo
ogl0ooooooooO`004Oooool00oooO`3oooooooooo`0:ooooo`03oomo0?oooooooooo00Cooooo00?o
ogl0ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Kooooo00Go
X23`ooooooooooooX23`ooooo`02oj0Pl0;ooooo0_nP8?0Oooooo`03oj0Pl?oooooooooo00?ooooo
00?oX23`ooooooooool04_ooool00onP8?3oooooooooo`06ooooo`04oj0Pl?oooooooooooj0Pl0go
oooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00co
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0?Oooool2oomo00Gooooo
00?oogl0ooooooooool00oooool01OooO`3oooooooooooooooooogl000Sooooo00?oogl0oooooooo
O`000oooool2oomo0003ooooooooO`3ooooo00;ooooo00?oogl0ooooooooool01Oooool00oooO`3o
ooooooooo`0:ooooo`?oogl01Oooool01?ooO`3ooooooomo0?ooO`03ooooo`03oomo0?oooooooooo
02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0looooo`03oj0Pl?oooooooooo
00;ooooo00?oX23`oooooonP8?001_ooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo
00Oooooo00GoX23`oooooonP8?3ooooooj0Pl007ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`
ooooooooool01_ooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo00?ooooo00GoX23`
oooooooooooooooooj0Pl002ooooo`03oj0Pl?oooooooooo00?ooooo00CoX23`ooooooooooooX23`
0_ooool2oj0Pl0[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0?ooo
ool00oooO`3oooooooooo`03ooooo`04oomo0?oooooooooooomo02Kooooo00?oogl0ooooooooool0
4_ooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooooooo01_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0looooo`;oX23`;?ooool01?nP8?3ooooooooooonP8?0^ooooo`04
oj0Pl?oooooooooooj0Pl0Kooooo00?oX23`ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`14ooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
O`000_ooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo00;ooooo00Coogl0oooooooo
O`3oogl03_ooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo00Gooooo00?oogl0oooo
ooooool03oooool00oooO`3oooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0?Oooool2oj0Pl0;ooooo0_nP8?06ooooo`;oX23`7_ooool00onP8?3oooooooooo`05oooo
o`03oj0Pl?oooooooooo01Oooooo00CoX23`oooooooooooooooo0_nP8?04ooooo`03oj0Pl?oooooo
X23`00Kooooo00?oX23`oooooonP8?000_ooool4oj0Pl0[ooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0Q?ooool01OooO`3oooooooooooooooooogl002Sooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`11ooooo`03oj0Pl?ooooooX23`01Oooooo00?oX23`
ooooooooool01Oooool00onP8?3oooooooooo`0iooooo`;oX23`0_ooool01_nP8?3ooooooooooonP
8?3ooooooj0Pl0Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0?Ooo
ool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo00gooooo00?oogl0ooooooooool02_oo
ool2oomo0003ooooooooO`3ooooo00;ooooo00?oogl0ooooooooool01Oooool2oomo00cooooo0_oo
O`000oooooooogl0ooooo`04ooooo`03oomo0?ooooooogl002Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1<ooooo`03oj0Pl?oooooooooo00oooooo00?oX23`oooooonP8?007Ooo
ool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00_ooooo0_nP8?0=ooooo`04oj0Pl?oo
ooooX23`oj0Pl0cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0>?oo
ool00oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00;oogl00oooool00oooO`3ooooooooo
o`0Gooooo`03oomo0?oooooooooo01Cooooo0_ooO`02ooooo`03oomo0?oooooooooo00cooooo00?o
ogl0ooooooooool01Oooool00oooO`3oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0?_ooool2oj0Pl0Cooooo00?oX23`oooooonP8?004Oooool00onP8?3ooooooooo
o`03ooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`ooooooooool00_ooool00onP8?3ooooooooo
o`04ooooo`;oX23`1Oooool2oj0Pl0?ooooo0_nP8?0>ooooo`03oj0Pl?ooooooX23`00?ooooo00Co
X23`oooooonP8?3ooooo1?nP8?001?ooooooX23`oj0Pl?nP8?02ooooo`03oj0Pl?oooooooooo00Ko
oooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0?oooool00oooO`3ooooo
ooooo`04ooooo`03oomo0?oooooooooo01Kooooo00?oogl0ooooooooool01Oooool2oomo00gooooo
00?oogl0ooooooooool0>?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Sooooo
00?oX23`ooooooooool07Oooool00onP8?3oooooooooo`0Sooooo`;oX23`0_ooool2oj0Pl003oooo
oonP8?3ooooo00Sooooo00SoX23`oooooonP8?3oX23`oooooonP8?3ooooooj0Pl0[ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0C?ooool01OooO`3ooooooooooooooooo
ogl000?ooooo00?oogl0ooooooooool00_ooool2oomo00?ooooo00Googl0oooooooooooooooooomo
0002ooooo`;oogl01Oooool01?ooO`3oooooooooooooO`06ooooo`06oomo0?oooooooooooomo0?oo
ooooogl01Oooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo01oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`15ooooo`;oX23`4oooool2oj0Pl1Cooooo0onP8?09oooo
o`03oj0Pl?oooooooooo00?ooooo00?oX23`oooooonP8?000oooool01OnP8?3ooooooooooooooooo
X23`00Gooooo0_nP8?001?ooooooX23`oooooonP8?04ooooo`03oj0Pl?oooooooooo00;ooooo2?nP
8?08ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04;ooooo00?oogl0
ooooooooool01Oooool00oooO`3oooooooooo`09ooooo`;oogl01oooool01?ooO`3ooooooooooooo
O`0Cooooo`05oomo0?ooooooooooooooooooO`004Oooool00oooO`3oooooooooo`04ooooo`04oomo
0?oooooooooooomo01[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`12ooooo`03
oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool06Oooool01OnP8?3oooooooooooooooooX23`
00Oooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?oooooooooo
00Wooooo0_nP8?07ooooo`?oX23`00?ooooooj0Pl?ooool02?ooool00ol0003oooooooooo`09oooo
o`002_ooool00ol0003oooooooooo`12ooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
ool04?ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00?ooooo00?oogl0oooooooo
ool04_ooool00oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo00Cooooo00?oogl0oooooooo
ool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04?ooooo0_nP8?05ooooo`05
oj0Pl?ooooooX23`oooooonP8?003?ooool00onP8?3ooooooj0Pl00<ooooo`03oj0Pl?oooooooooo
00;ooooo00CoX23`ooooooooooooX23`2_ooool01?nP8?3ooooooj0Pl?nP8?09ooooo`;oX23`0_oo
ool00onP8?3oooooooooo`02ooooo`06oj0Pl?oooooooooooooooonP8?3ooooo0_nP8?02ooooo`04
oj0Pl?ooooooX23`ooooo`SoX23`2?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`19ooooo`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooool01_ooool00oooO`3o
ooooooooo`02ooooo`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooool0?_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo04?ooooo00?oX23`ooooooooool01?ooool01?nP8?3o
oooooooooonP8?0iooooo`03oj0Pl?oooooooooo01Gooooo0_nP8?000oooooooX23`ooooo`02oooo
o`04oj0Pl?ooooooX23`oj0Pl0Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000oooo
ooooool0COooool4oomo00Cooooo00?oogl0ooooooooO`000oooool00oooO`3oooooooooo`08oooo
o`03oomo0?oooooooooo01gooooo00Googl0oooooooooooooooooomo000Vooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0BOooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooo
oooo01;ooooo00?oX23`ooooooooool06_ooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?oooooo
oooo00Gooooo00GoX23`oooooooooooooooooj0Pl002ooooo`06oj0Pl?ooooooX23`oj0Pl?oooooo
X23`2?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1:ooooo`;oogl0
1oooool00oooO`3ooooooomo0006ooooo`04oomo0?ooooooooooooooo`?oogl01?ooool01OooO`3o
oooooomo0?ooooooogl000Wooooo00Googl0ooooooooooooogl0ooooo`02oomo00;ooooo00?oogl0
ooooooooool05Oooool00oooO`3oooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0G?ooool00onP8?3oooooooooo`02ooooo`05oj0Pl?oooooooooooooooonP8?003Ooo
ool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo00Cooooo00GoX23`oooooonP8?3ooooo
oj0Pl002ooooo`04oj0Pl?ooooooooooooooo`;oX23`1?ooool01?nP8?3ooooooj0Pl?nP8?02oooo
o`OoX23`0_ooool00onP8?3ooooooj0Pl003oj0Pl0Oooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0AOooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooooooo00[o
oooo00?oogl0ooooooooO`001Oooool00oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo047o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`13ooooo`03oj0Pl?oooooooooo00;o
oooo00?oX23`ooooooooool04oooool00onP8?3oooooooooo`0Dooooo`03oj0Pl?oooooooooo00So
oooo00GoX23`oooooonP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`oooo
ooooool03_ooool01onP8?3ooooooj0Pl?nP8?3ooooooj0Pl?ooool00onP8?06ooooo`03o`000?oo
oooooooo00Wooooo000:ooooo`03o`000?oooooooooo04Wooooo0_ooO`05ooooo`;oogl00oooool0
0oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool02oooool0
0oooO`3oooooooooo`04ooooo`04oomo0?oooooooooooomo00gooooo00?oogl0ooooooooool07Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04[ooooo0_nP8?000oooooooX23`oooo
o`0Pooooo`03oj0Pl?oooooooooo017ooooo00?oX23`ooooooooool00_nP8?09ooooo`04oj0Pl?oo
ooooX23`oj0Pl0;ooooo00?oX23`ooooooooool00_ooool2oj0Pl0?ooooo00CoX23`oooooooooooo
oooo1_nP8?000oooooooX23`ooooo`03ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo04cooooo00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`02ooooo`03oomo
0?oooooooooo00Gooooo00?oogl0ooooooooool01?ooool2oomo04Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`18ooooo`03oj0Pl?oooooooooo00Cooooo00CoX23`oooooooooooo
X23`6Oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`oooooooo
ool02oooool01?nP8?3ooooooooooonP8?02ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`oooo
ooooool01_ooool00onP8?3oooooooooo`04ooooo`08oj0Pl?oooooooooooj0Pl?ooooooX23`oooo
oonP8?06ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04Cooooo00?o
ogl0ooooooooool01oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00cooooo00?o
ogl0ooooooooool08_ooool00oooO`3oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0B_ooool01OnP8?3oooooooooooooooooX23`01gooooo00?oX23`ooooooooool0
1?ooool00onP8?3oooooooooo`0Fooooo`03oj0Pl?oooooooooo00Kooooo00KoX23`oooooooooooo
X23`oooooonP8?05ooooo`03oj0Pl?oooooooooo00Gooooo00CoX23`ooooooooooooX23`1Oooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1?ooooo`03oomo0?ooooooogl0
00Cooooo00?oogl0ooooooooO`001_ooool00oooO`3ooooooomo0006ooooo`03oomo0?oooooooooo
00;oogl000Gooooooomo0?oooooooooooomo0003ooooo`03oomo0?oooooooooo017ooooo00?oogl0
ooooooooool04Oooool00oooO`3oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0B_ooool2oj0Pl0?ooooo00?oX23`ooooooooool00_nP8?0<ooooo`03oj0Pl?oooooo
oooo00Gooooo00?oX23`ooooooooool01oooool01?nP8?3ooooooooooonP8?03ooooo`03oj0Pl?oo
oooooooo00?ooooo00CoX23`ooooooooooooX23`0_ooool01?nP8?3ooooooj0Pl?nP8?05ooooo`?o
X23`2?ooool2oj0Pl0Kooooo0onP8?02ooooo`?oX23`0_ooool00onP8?3oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo04Wooooo00?oogl0ooooooooool0
0_ooool2oomo00;ooooo00?oogl0ooooooooool01oooool00oooO`3oooooooooo`0>ooooo`03oomo
0?ooooooogl000Gooooo00?oogl0ooooooooool06Oooool00oooO`3ooooooomo000Mooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0A?ooool00onP8?3oooooooooo`08ooooo`05oj0P
l?oooooooooooooooonP8?003?ooool00onP8?3oooooooooo`0dooooo`;oX23`1_ooool00onP8?3o
oooooj0Pl003ooooo`03oj0Pl?oooooooooo00;oX23`00?ooooooj0Pl?ooool01?ooool00ol0003o
ooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1Aooooo`03oomo0?ooooooogl000?ooooo
00?oogl0ooooooooool00_ooool2oomo00?ooooo00?oogl0ooooooooool02Oooool3oomo0003oooo
ooooO`3oogl000;ooooo1?ooO`02ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool0
0_ooool00oooO`3oooooooooo`0Booooo`03oomo0?oooooooooo00oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1=ooooo`03oj0Pl?ooooooX23`00Sooooo00?oX23`ooooooooool0
1?ooool00onP8?3ooooooj0Pl003ooooo`03oj0Pl?ooooooX23`00Cooooo0_nP8?08ooooo`03oj0P
l?oooooooooo013ooooo00KoX23`oooooonP8?3oX23`oooooonP8?02ooooo`05oj0Pl?ooooooX23`
oooooonP8?000oooool2oj0Pl0Cooooo00CoX23`oooooonP8?3oX23`1_ooool00onP8?3ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo05Kooooo00?oogl0
ooooooooool02oooool00oooO`3ooooooomo0004ooooo`04oomo0?oooooooooooomo00;ooooo00Co
ogl0ooooooooooooogl04?ooool00oooO`3oooooooooo`0Yooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0COooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo01[ooooo
00?oX23`ooooooooool05?ooool01?nP8?3ooooooooooonP8?04ooooo`04oj0Pl?oooooooooooj0P
l0gooooo00GoX23`oooooonP8?3oX23`ooooo`02oj0Pl0Cooooo00?oX23`ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`15ooooo`03oomo0?oooooooooo
00_ooooo00Googl0oooooooooooooooooomo0004ooooo`07oomo0?oooooooooooomo0?ooooooogl0
ooooo`02oomo0003ooooooooO`3ooooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3ooooo
ooooo`02ooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool03Oooool00oooO`3ooooo
ooooo`06ooooo`03oomo0?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1Cooooo`04oj0Pl?oooooooooooj0Pl0Oooooo00?oX23`ooooooooool01_ooool00onP8?3o
ooooooooo`05ooooo`03oj0Pl?oooooooooo00Kooooo00GoX23`oooooooooooooooooj0Pl004oooo
o`03oj0Pl?oooooooooo00Wooooo0onP8?07ooooo`;oX23`1oooool00onP8?3oooooooooo`03oooo
o`04oj0Pl?oooooooooooj0Pl0?ooooo00GoX23`ooooooooooooooooo`00000;ooooo`002_ooool0
0ol0003oooooooooo`1Kooooo`?oogl000Gooooooomo0?oooooooooooomo0002ooooo`05oomo0?oo
ooooooooooooooooO`000oooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo00Gooooo
00?oogl0ooooooooool07Oooool00oooO`3oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0FOooool00onP8?3oooooooooo`0Wooooo`03oj0Pl?oooooooooo00;ooooo
00?oX23`ooooooooool00oooool00onP8?3oooooooooo`02ooooo`;oX23`2Oooool00onP8?3ooooo
ooooo`03ooooo`03oj0Pl?oooooooooo00[ooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0D_ooool01?ooO`3oooooooooooooO`05ooooo`03oomo0?oooooooooo00kooooo
00?oogl0ooooooooool01Oooool01OooO`3ooooooomo0?ooooooogl000;ooooo00?oogl0oooooooo
ool02_ooool00oooO`3oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0E?ooool00onP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`oooooooo
ool06Oooool2oj0Pl003oooooonP8?3ooooo00Oooooo00?oX23`ooooooooool01?ooool00onP8?3o
ooooooooo`02ooooo`03oj0Pl?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0E_ooool01?ooO`3oooooooooooooool4oomo0003ooooooooO`3ooooo00?o
ogl00_ooool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo00;ooooo00Coogl0oooooooo
ooooogl00oooool00oooO`3ooooooomo0004ooooo`04oomo0?oooooooooooomo02_ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Cooooo`03oj0Pl?oooooooooo00oooooo0_nP8?0E
ooooo`05oj0Pl?oooooooooooooooonP8?000_ooool00onP8?3oooooooooo`05ooooo`04oj0Pl?oo
ooooX23`oj0Pl0Gooooo0onP8?05ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1Booooo`03oomo0?oo
oooooooo00Gooooo00?oogl0ooooooooO`001_ooool2oomo00?ooooo00?oogl0ooooooooool01?oo
ool01?ooO`3oooooooooooooO`0Hooooo`03oomo0?oooooooooo02?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Booooo`04oj0Pl?ooooooX23`oj0Pl2[ooooo00?oX23`oooooooo
ool02Oooool01OnP8?3oooooooooooooooooX23`00cooooo00?oX23`oooooonP8?001Oooool00onP
8?3oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo05Co
oooo00?oogl0ooooooooool00_ooO`000oooooooogl0oomo0004oomo00Cooooo00?oogl0oooooooo
O`002?ooool2oomo00?ooooo00Ooogl0oooooooooooooooooomo0?ooooooogl000?ooooo00Googl0
oooooooooooooooooomo0004ooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool05_oo
ool00oooO`3oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Dooo
ool00onP8?3oooooooooo`03oj0Pl005oooooonP8?3oX23`oooooonP8?002Oooool00onP8?3ooooo
ooooo`0Oooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool00_ooool00onP8?3ooooo
ooooo`04ooooo`03oj0Pl?oooooooooo00gooooo00?oX23`ooooool000002oooool000[ooooo00?o
0000ooooooooool0G_ooool2oomo00?ooooo00?oogl0ooooooooool00_ooool00oooO`3ooooooooo
o`03ooooo`03oomo0?oooooooooo00cooooo00?oogl0ooooooooool00_ooool00oooO`3ooooooooo
o`0Rooooo`03oomo0?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1Jooooo`;oX23`2?ooool00onP8?3oooooooooo`0Sooooo`;oX23`0oooool00onP8?3ooooooooo
o`03ooooo`04oj0Pl?ooooooX23`oj0Pl0Cooooo00?oX23`ooooooooool04Oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`1Eooooo`03oomo0?oooooooooo00Gooooo0_oo
O`04ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool02oooool00oooO`3ooooooooo
o`0Jooooo`03oomo0?oooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1Fooooo`03oj0Pl?oooooooooo00kooooo00?oX23`ooooooooool05Oooool00onP8?3ooooooooo
o`04ooooo`03oj0Pl?oooooooooo00oooooo00?oX23`ooooooooool03Oooool00onP8?3ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo05Kooooo0_ooO`02
ooooo`;oogl00_ooool2oomo0005ooooooooO`3oogl0ooooooooO`001Oooool2oomo00Cooooo00Co
ogl0ooooooooooooogl01_ooool01OooO`3oooooooooooooooooogl001Sooooo00?oogl0oooooooo
ool01Oooool00oooO`3oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0FOooool2oj0Pl0[ooooo00?oX23`oooooonP8?001_ooool00onP8?3oooooooooo`07ooooo`04
oj0Pl?ooooooooooooooo`;oX23`00?ooooooj0Pl?ooool01oooool01?nP8?3ooooooooooonP8?04
ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`oooooonP8?005_ooool00onP8?3o0000ooooo`0:
ooooo`002_ooool00ol0003oooooooooo`1@ooooo`03oomo0?oooooooooo00Oooooo00Coogl0oooo
ooooO`3oogl01Oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo00_ooooo00?oogl0
ooooooooool09?ooool00oooO`3oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0F?ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo02Kooooo00?oX23`
ooooooooool04Oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0F_ooool00oooO`3ooooooomo0002oooo
o`;oogl00_ooool3oomo00Gooooo1?ooO`06ooooo`07oomo0?ooooooogl0ooooooooO`3ooooooomo
000Iooooo`;oogl04?ooool00oooO`3oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0FOooool01onP8?3oooooooooooooooooX23`oooooonP8?001Oooool00onP8?3o
oooooj0Pl00Gooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool01oooool00onP8?3o
ooooooooo`07ooooo`05oj0Pl?oooooooooooooooonP8?002?ooool00onP8?3oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo05[ooooo00?oogl0oooooooo
ool00oooool01?ooO`3oooooooooooooool2oomo00;ooooo00?oogl0ooooooooool0A_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo06kooooo00?oX23`ooooooooool06_ooool01?nP
8?3ooooooooooonP8?02ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01_ooool0
0onP8?3oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
05cooooo00?oogl0ooooooooool01?ooO`03ooooo`03oomo0?ooooooogl000?ooooo0_ooO`000ooo
ooooogl0oomo0003ooooo`03oomo0?oooooooooo00Gooooo0_ooO`03ooooo`03oomo0?ooooooogl0
00Sooooo00?oogl0ooooooooO`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
05[ooooo0_nP8?04ooooo`;oX23`00?ooooooj0Pl?ooool01_ooool00onP8?3oooooooooo`07oooo
o`;oX23`00?ooooooj0Pl?ooool03oooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?oooooooooo
00[ooooo00?oX23`ooooooooool02_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`1Pooooo`03oomo0?oooooooooo00?oogl00_ooool2oomo00Cooooo00?oogl0oooooooo
ool02?ooool01?ooO`3oooooooooooooO`03ooooo`03oomo0?oooooooooo013ooooo00?oogl0oooo
ooooool06oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05gooooo00?oX23`oooo
ooooool00_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00[ooooo00?oX23`oooo
ooooool01?ooool00onP8?3oooooooooo`0cooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo05oooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`04ooooo`?o
ogl00_ooool2oomo00Gooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`07ooooo`03
oomo0?ooooooogl002Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Wooooo`03
oj0Pl?oooooooooo02Oooooo00?oX23`ooooooooool06Oooool01OnP8?3ooooooooooooooooo0000
00_ooooo000:ooooo`03o`000?oooooooooo05Gooooo00?oogl0ooooooooool01oooool00oooO`3o
oooooomo0002oomo0004ooooooooO`3oogl0ooooo`;oogl000?ooooooomo0?ooO`000_ooool3oomo
0009ooooooooO`3oogl0ooooooooO`3ooooooomo0?ooooooogl000cooooo00?oogl0ooooooooool0
9oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05kooooo00GoX23`oooooooooooo
oooooj0Pl002ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool00oooool2oj0Pl0Go
oooo00?oX23`ooooooooool08Oooool00onP8?3oooooooooo`0;ooooo`03oj0Pl?l0003ooooo00[o
oooo000:ooooo`03o`000?oooooooooo05oooooo00?oogl0ooooooooool01Oooool2oomo00;ooooo
00?oogl0ooooooooool01_ooool00oooO`3oooooooooo`0Oooooo`03oomo0?oooooooooo01Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Pooooo`03oj0Pl?oooooooooo00Gooooo
00?oX23`ooooooooool06Oooool00onP8?3oooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo
000:ooooo`03o`000?oooooooooo067ooooo00Coogl0ooooooooO`3oogl00oooool4oomo00Oooooo
00?oogl0ooooooooool05?ooool01?ooO`3oooooooooooooO`04ooooo`;oogl04_ooool00oooO`3o
ooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0HOooool2oj0Pl003
oooooonP8?3ooooo00?ooooo0_nP8?0Booooo`03oj0Pl?oooooooooo013ooooo00GoX23`oooooonP
8?3ooooooj0Pl00Booooo`03oj0Pl?oooooooooo00Oooooo00?o0000ooooooooool02Oooool000[o
oooo00?o0000ooooooooool0IOooool5oomo00;ooooo0oooO`000oooooooogl0ooooo`0Cooooo`03
oomo0?oooooooooo013ooooo00?oogl0ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo07Kooooo00?oX23`ooooooooool0>?ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`1Vooooo`06oomo0?ooooooogl0ooooooooO`3ooooo0_ooO`05oooo
o`03oomo0?ooooooogl000;ooooo00Coogl0ooooooooooooogl00oooool00oooO`3oooooooooo`0>
ooooo`05oomo0?ooooooooooooooooooO`007?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo07[ooooo0_nP8?0Nooooo`03oj0Pl?oooooooooo01Cooooo00?o0000ooooooooool02Ooo
ool000[ooooo00?o0000ooooooooool0Ioooool2oomo0003ooooooooO`3oogl000;oogl000Gooooo
oomo0?oooooooooooomo0002ooooo`03oomo0?oooooooooo01;ooooo00Coogl0ooooooooooooogl0
0oooool00oooO`3oooooooooo`0>ooooo`03oomo0?oooooooooo00cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Vooooo`?oX23`1Oooool00onP8?3oooooooooo`0>ooooo`03oj0P
l?ooooooX23`013ooooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`04ooooo`04oj0P
l?ooooooX23`oj0Pl0Gooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
HOooool00oooO`3oooooooooo`03ooooo`?oogl000?ooooooomo0?ooO`000_ooool00oooO`3ooooo
oomo0008ooooo`04oomo0?oooooooooooomo00?ooooo00?oogl0ooooooooool00_ooool00oooO`3o
ooooooooo`04ooooo`03oomo0?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo06Cooooo
00Coogl0oooooooooooooooo2OooO`08ooooo`05oomo0?ooooooooooooooooooO`000_ooool00ooo
O`3oooooooooo`03ooooo`;oogl06_ooool00oooO`3oooooooooo`0<ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0G_ooool01OnP8?3oooooooooooooooooX23`00[ooooo00?oX23`
ooooooooool04oooool01OnP8?3oooooooooooooooooX23`02Sooooo00?oX23`o`000?ooool02_oo
ool000[ooooo00?o0000ooooooooool0JOooool3oomo0003ooooooooO`3oogl000;oogl03oooool0
1OooO`3oooooooooooooooooogl002cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`1Zooooo`03oj0Pl?oooooooooo02Kooooo00?oX23`ooooooooool06?ooool01?nP8?3ooooooooo
ool0000;ooooo`002_ooool00ol0003oooooooooo`1Yooooo`03oomo0?ooooooogl000Coogl000Go
oooooomo0?ooO`3ooooooomo0009ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooO`00
1oooool00oooO`3oooooooooo`0;ooooo`03oomo0?oooooooooo017ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Zooooo`03oj0Pl?ooooooX23`027ooooo00?oX23`ooooooooool0
1?ooool00onP8?3oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo06Sooooo00?oogl0ooooooooool00_ooool3oomo00oooooo00?oogl0ooooooooool0;ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06[ooooo00?oX23`ooooooooool0:_oo
ool00onP8?3oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooo
oooo06_ooooo00?oogl0ooooooooO`001Oooool2oomo00Gooooo0_ooO`03ooooo`03oomo0?oooooo
oooo00Gooooo00?oogl0ooooooooool05Oooool00oooO`3oooooooooo`0?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0KOooool2oj0Pl0Kooooo00?oX23`ooooooooool06oooool0
0onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo01Gooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0K?ooool4oomo00;ooooo00?oogl0ooooooooool00_ooool00ooo
O`3oooooooooo`06ooooo`03oomo0?ooooooogl000;ooooo00?oogl0ooooooooool0:Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo077ooooo00?oX23`ooooooooool02oooool01?nP
8?3ooooooooooonP8?0<ooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool05_ooool0
0onP8?3oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1[ooooo`03oomo0?oooooooooo
00;oogl03_ooool00oooO`3ooooooomo0002ooooo`04oomo0?ooooooogl0oomo00?ooooo00?oogl0
ooooooooool01Oooool00oooO`3oooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0Joooool01OnP8?3oooooooooooooooooX23`00gooooo00?oX23`ooooooooool05Ooo
ool01OnP8?3oooooooooooooooooX23`01Oooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0L?ooool01OooO`3oooooooooooooooooogl000kooooo0_ooO`0Xooooo`05oomo
0?ooooooooooooooool000004Oooool00ol0003oooooooooo`1/ooooo`03oj0Pl?oooooooooo00;o
oooo00?oX23`ooooooooool07?ooool01?nP8?3ooooooooooonP8?0Mooooo`03oj0Pl?oooooooooo
00Wooooo000:ooooo`03o`000?oooooooooo06gooooo00?oogl0ooooooooool00oooool2oomo013o
oooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Cooooo`03oomo0?oooooooooo00co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1_ooooo`03oj0Pl?oooooooooo01;o
oooo00?oX23`ooooooooool04Oooool00onP8?3oooooooooo`0Fooooo`03o`000?oooooooooo00Wo
oooo000:ooooo`03o`000?oooooooooo06?ooooo00?oogl0ooooooooool02oooool00oooO`3ooooo
ooooo`02oomo0003ooooooooO`3ooooo00;ooooo00?oogl0ooooooooool0<oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo07cooooo00?oX23`ooooooooool0<_ooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`1booooo`03oomo0?ooooooogl000Cooooo00?o
ogl0ooooooooool01Oooool01?ooO`3oooooooooooooO`06ooooo`05oomo0?oooooooooooooooooo
O`000oooool00oooO`3oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Koooool2oj0Pl1Sooooo0_nP8?0<ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Eooooo`03oomo
0?oooooooooo01Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Cooooo`03oj0P
l?oooooooooo01_ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0M_oo
ool2oomo0003ooooooooO`3ooooo017ooooo00?oogl0ooooooooool01?ooool00oooO`3ooooooooo
o`09ooooo`03oomo0?oooooooooo00kooooo00?oogl0o`000?ooool04?ooool00ol0003ooooooooo
o`1hooooo`03oj0Pl?oooooooooo00oooooo00?oX23`oooooonP8?009?ooool00ol0003ooooooooo
o`09ooooo`002_ooool00ol0003oooooooooo`1iooooo`03oomo0?oooooooooo00?ooooo00?oogl0
ooooooooool02?ooool01?ooO`3oooooooooooooO`03ooooo`03oomo0?oooooooooo00Cooooo00?o
ogl0ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Cooooo00?o
X23`ooooooooool04Oooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00_ooooo00?o
X23`oooooonP8?004_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`1_
ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooool03oooool00oooO`3oooooooooo`0V
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0MOooool01OnP8?3ooooooooooooo
ooooX23`00?ooooo00?oX23`ooooooooool02Oooool00onP8?3oooooooooo`0Cooooo`03oj0Pl?oo
oooooooo00Cooooo00?oX23`ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`1hooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool01Oooool0
0oooO`3oooooooooo`0<ooooo`03oomo0?ooooooogl000Kooooo00?oogl0ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06gooooo00?oX23`ooooooooool01?ooool0
0onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooooooo02Wooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0L_ooool00oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo
00Sooooo00Coogl0ooooooooooooogl01Oooool00oooO`3ooooooomo0005ooooo`03oomo0?oooooo
oooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`09ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0N_ooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooo
oooo00Sooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooo
oooo00Kooooo00?oX23`ooooooooool00oooool00ol0003oooooooooo`09ooooo`002_ooool00ol0
003oooooooooo`1dooooo`03oomo0?oooooooooo00;ooooo00Googl0oooooooooooooooooomo0005
ooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool01?ooool01OooO`3ooooooomo0?oo
ooooogl000Wooooo00?oogl0ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo07Kooooo00CoX23`ooooooooooooX23`2?ooool3oj0Pl0gooooo00?oX23`ooooooooool0
4oooool00onP8?3oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oo
oooooooo07[ooooo00?oogl0ooooooooool07?ooool00oooO`3ooooooomo000Eooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0M_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oo
oooooooo02Cooooo00?oX23`ooooooooool03?ooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`1dooooo`03oomo0?oooooooooo00Oooooo00Googl0ooooooooO`3ooooooomo
0004ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool00_ooool01?ooO`3ooooooomo
0?ooO`03ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo07[ooooo0_nP8?000oooooooX23`ooooo`03ooooo`03oj0P
l?oooooooooo02?ooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`2:ooooo`;oogl00oooool00oooO`3oooooooooo`06ooooo`03oomo0?oo
oooooooo00Oooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0R?ooool00onP8?3oooooooooo`0Gooooo`03oj0Pl?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0OOooool0
1?ooO`3oooooooooooooO`02ooooo`03oomo0?ooooooogl000Gooooo00Googl0oooooooooooooooo
oomo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Qoooool00onP8?3ooooo
ooooo`0Looooo`03oj0Pl?oooooooooo00Sooooo00?o0000ooooooooool02Oooool000[ooooo00?o
0000ooooooooool0NOooool00oooO`3oooooooooo`09ooooo`;oogl000?ooooooomo0?ooool00ooo
ool00oooO`3oooooooooo`03ooooo`05oomo0?ooooooooooooooooooO`001Oooool01OooO`3ooooo
ooooooooooooogl000?ooooo00?oogl0ooooooooool00_ooO`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0TOooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00go
oooo00?oX23`ooooooooool02?ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003ooooo
ooooo`25ooooo`03oomo0?oooooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`20ooooo`;oX23`6oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00[ooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0OOooool01OooO`3ooooooooo
ooooooooogl000[ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Aooooo`03oomo
0?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1nooooo`03oj0P
l?ooooooX23`00;oX23`1?ooool00onP8?3ooooooj0Pl005ooooo`03oj0Pl?oooooooooo00?ooooo
0onP8?06ooooo`05oj0Pl?oooooooooooooooonP8?003_ooool00ol0003oooooooooo`09ooooo`00
2_ooool00ol0003oooooooooo`1mooooo`04oomo0?oooooooooooomo00kooooo00?oogl0oooooooo
ool01?ooool00oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo00kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`22ooooo`03oj0Pl?oooooooooo017ooooo00?oX23`oooooooo
ool05?ooool01OnP8?3oooooooooooooooooX23`00_ooooo000:ooooo`03o`000?oooooooooo08Co
oooo00?oogl0ooooooooool01?ooool01?ooO`3oooooooooooooO`02ooooo`03oomo0?oooooooooo
00?ooooo00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`0<ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0W?ooool01OnP8?3oooooooooooooooooX23`013ooooo00?o0000
ooooooooool02Oooool000[ooooo00?o0000ooooooooool0QOooool00oooO`3oooooooooo`0<oooo
o`03oomo0?ooooooogl000Kooooo00?oogl0ooooooooO`003?ooool00oooO`3oooooooooo`02oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0NOooool00onP8?3oooooooooo`03oooo
o`05oj0Pl?oooooooooooooooonP8?003_ooool2oj0Pl0oooooo00?oX23`ooooooooool00_ooool0
1?nP8?3oooooooooooooool2oj0Pl0?ooooo00?o0000ooooooooool02Oooool000[ooooo00?o0000
ooooooooool0POooool00oooO`3oooooooooo`03ooooo`03oomo0?ooooooogl001?ooooo00?oogl0
ooooooooool01?ooool00oooO`3ooooooomo000:ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0P_ooool00onP8?3oooooooooo`0[ooooo`03oj0Pl?l0003ooooo00[ooooo000:oooo
o`03o`000?oooooooooo08Oooooo00Coogl0ooooooooO`3oogl02?ooool00oooO`3oooooooooo`05
ooooo`06oomo0?ooooooogl0oomo0?ooooooogl00oooool00oooO`3oooooooooo`0:ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0P_ooool00onP8?3oooooooooo`02ooooo`04oj0P
l?ooooooooooooooo`?oX23`00?ooooooj0Pl?ooool07?ooool01OnP8?3oooooooooooooooooX23`
00_ooooo000:ooooo`03o`000?oooooooooo08Cooooo00Coogl0ooooooooooooogl00_ooool00ooo
O`3ooooooomo0003ooooo`05oomo0?ooooooooooooooooooO`006Oooool01?ooO`3oooooooooool0
000Aooooo`03o`000?oooooooooo08?ooooo00?oX23`ooooooooool03Oooool00onP8?3ooooooooo
o`0Jooooo`03oj0Pl?l0003ooooo00[ooooo000:ooooo`03o`000?oooooooooo08Sooooo00?oogl0
ooooooooool01_ooool00oooO`3oooooooooo`0Eooooo`03oomo0?oooooooooo00Cooooo00?oogl0
o`000?ooool04?ooool00ol0003oooooooooo`27ooooo`06oj0Pl?oooooooooooooooonP8?3ooooo
0_nP8?07ooooo`05oj0Pl?oooooooooooooooonP8?004_ooool01OnP8?3oooooooooooooooooX23`
00_ooooo000:ooooo`03o`000?oooooooooo08Gooooo00?oogl0ooooooooool01?ooool00oooO`3o
ooooooooo`03ooooo`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooool00_ooool00oooO`3o
ooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0T?ooool00onP8?3o
ooooooooo`0Eooooo`03oj0Pl?oooooooooo00Kooooo00?o0000ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0R?ooool2oomo00;ooooo00?oogl0ooooooooO`002Oooool00oooO`3ooooo
oomo0008ooooo`04oomo0?ooooooooooooooo`;oogl02?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;7ooooo00?oX23`ooooooooool02Oooool000[ooooo00?o0000ooooooooool0
O_ooool00oooO`3oooooooooo`03ooooo`03oomo0?ooooooogl000?ooooo00?oogl0ooooooooool0
1Oooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo00;ooooo00Koogl0oooooooooooo
ogl0ooooooooO`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0R?ooool00onP
8?3oooooooooo`09ooooo`04oj0Pl?oooooooooooj0Pl1Wooooo00?o0000ooooooooool02Oooool0
00[ooooo00?o0000ooooooooool0POooool00oooO`3oooooooooo`08ooooo`Coogl000?ooooooomo
0?ooool00oooool00oooO`3oooooooooo`0<ooooo`03oomo0?ooooooogl000Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2;ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooo
ooooool04_ooool00onP8?3oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03
o`000?oooooooooo08Sooooo0oooO`03ooooo`;oogl000Cooooooomo0?ooooooogl01oooool00ooo
O`3oooooooooo`03ooooo`;oogl01Oooool00oooO`3oooooooooo`05ooooo`03oomo0?l0003ooooo
013ooooo00?o0000ooooooooool0T?ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo
00Cooooo0_nP8?0?ooooo`03oj0Pl?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo097o
oooo00?oogl0ooooooooool05?ooool00oooO`3oooooooooo`06ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0Roooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00[o
oooo00?oX23`ooooooooool03_ooool01?nP8?3oooooooooool0000;ooooo`002_ooool00ol0003o
ooooooooo`2<ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool00oooool2oomo00;o
oooo00?oogl0ooooooooool02Oooool00oooO`3oooooooooo`02oomo00;ooooo00Coogl0oooooooo
oooo00004Oooool00ol0003oooooooooo`2Yooooo`03oj0Pl?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool000[ooooo00?o0000ooooooooool0T?ooool2oomo0005ooooooooO`3ooooooooo
ooooO`001?ooool00oooO`3oooooooooo`05ooooo`;oogl000?ooooooomo0?ooool01_ooool01?oo
O`3oooooooooool0000Aooooo`03o`000?oooooooooo08gooooo00?oX23`ooooooooool01?ooool0
1OnP8?3oooooooooooooooooX23`01Sooooo00?oX23`ooooooooool02Oooool000[ooooo00?o0000
ooooooooool0S?ooool00oooO`3oooooooooo`03ooooo`03oomo0?oooooooooo017ooooo00?oogl0
ooooooooool00oooool01_ooO`3oooooooooooooooooogl0o`00017ooooo00?o0000ooooooooool0
R_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo01oooooo00?o0000ooooooooool0
2Oooool000[ooooo00?o0000ooooooooool0Soooool01OooO`3oooooooooooooooooogl000Gooooo
00Ooogl0ooooooooO`3ooooooomo0?ooooooogl000_ooooo00?oogl0ooooooooool00oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo08gooooo00GoX23`oooooonP8?3ooooooj0Pl002
ooooo`CoX23`0oooool00onP8?3oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo000:oooo
o`03o`000?oooooooooo09Gooooo0_ooO`0<ooooo`06oomo0?oooooooooooomo0?ooooooogl02?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09oooooo00?oX23`ooooooooool03ooo
ool00onP8?3oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Cooooo`05oomo0?oooooo
ogl0ooooooooO`001Oooool00oooO`3ooooooomo0002ooooo`;oogl000?ooooooomo0?ooool01Ooo
ool00oooO`3oooooooooo`02oomo0003o`000?oooooooooo00oooooo00?o0000ooooooooool0T?oo
ool01OnP8?3ooooooj0Pl?ooooooX23`00?ooooo00?oX23`ooooooooool01_ooool00onP8?3ooooo
ooooo`02ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`002_ooool00ol0003oooooooooo`2Eooooo`03oomo0?ooooooogl000?ooooo00Co
ogl0ooooooooooooogl00oooool01OooO`3oooooooooooooO`3ooooo00;oogl02?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo093ooooo00KoX23`ooooooooooooX23`oooooonP8?03
ooooo`;oX23`5_ooool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Boooo
o`03oomo0?oooooooooo00?oogl01Oooool00oooO`3oooooooooo`04ooooo`04oomo0?oooooooooo
oomo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2[ooooo`03oj0Pl?oooooo
oooo00?ooooo00?oX23`ooooooooool02Oooool000[ooooo00?o0000ooooooooool0QOooool00ooo
O`3oooooooooo`0;ooooo`03oomo0?oooooooooo00;ooooo00Coogl0ooooooooO`3ooooo0_ooO`03
ooooo`03oomo0?ooooooogl000;oogl00oooool00oooO`3oooooooooo`03ooooo`;oogl000?o0000
ooooooooool03oooool00ol0003oooooooooo`2Dooooo`;oX23`1?ooool00onP8?3oooooooooo`0<
ooooo`04oj0Pl?oooooooooooj0Pl0Cooooo00?oX23`ooooooooool02Oooool000[ooooo00?o0000
ooooooooool0Toooool00oooO`3oooooooooo`03ooooo`05oomo0?ooooooogl0oomo0?ooool00_oo
O`05ooooo`03oomo0?ooooooogl000Kooooo00Coogl0oooooooooooo00004Oooool00ol0003ooooo
ooooo`2^ooooo`04oj0Pl?oooooooooooj0Pl0_ooooo000:ooooo`03o`000?oooooooooo09;ooooo
00?oogl0ooooooooool00_ooO`03ooooo`;oogl01?ooool00oooO`3oooooooooo`06ooooo`03oomo
0?ooooooogl000;ooooo00Coogl0ooooooooO`3o00004Oooool00ol0003oooooooooo`2Eooooo`?o
X23`00Gooooooj0Pl?oooooooooooj0Pl002ooooo`03oj0Pl?ooooooX23`00Sooooo0_nP8?001?oo
ooooX23`ooooooooool2oj0Pl0_ooooo000:ooooo`03o`000?oooooooooo09?ooooo00?oogl0oooo
ooooool00oooO`000oooooooogl0ooooo`03ooooo`07oomo0?ooooooooooooooooooO`3ooooooomo
000:ooooo`03oomo0?l0003ooooo013ooooo00?o0000ooooooooool0U_ooool2oj0Pl0Gooooo00?o
X23`oooooonP8?000_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00Oooooo00?o
X23`ooooooooool02Oooool000[ooooo00?o0000ooooooooool0TOooool00oooO`3oooooooooo`02
ooooo`03oomo0?ooooooogl000;ooooo00?oogl0ooooooooool01?ooool01OooO`3ooooooooooooo
ooooogl000;ooooo00?oogl0ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo09Oooooo1?nP8?04ooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Booooo`;oogl01_ooool0
0oooO`3oooooooooo`04oomo0004ooooooooO`3oooooooooo`?oogl000?ooooooomo0?ooO`001Ooo
ool00oooO`3o0000ooooo`0@ooooo`03o`000?oooooooooo09Gooooo00?oX23`oooooonP8?000onP
8?000oooooooX23`ooooo`02ooooo`;oX23`0oooool2oj0Pl004oooooonP8?3ooooooj0Pl0Kooooo
00?o0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0TOooool00oooO`3ooooooomo
0004ooooo`03oomo0?oooooooooo00;ooooo0_ooO`05ooooo`03oomo0?ooooooogl000;oogl00_oo
ool2oomo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Hooooo`CoX23`2_oo
ool2oj0Pl0Kooooo00CoX23`ooooooooooooX23`2oooool000[ooooo00?o0000ooooooooool0Tooo
ool2oomo00?ooooo00?oogl0ooooooooO`000oooO`02ooooo`?oogl00_ooool2oomo00Cooooo0_oo
O`03ooooo`03oomo0?l0003ooooo013ooooo00?o0000ooooooooool0VOooool7oj0Pl0;ooooo00Go
X23`oooooooooooooooooj0Pl005ooooo`06oj0Pl?oooooooooooj0Pl?ooooooX23`2oooool000[o
oooo00?o0000ooooooooool0U_ooool00oooO`3oooooooooo`04oomo00Kooooo00Coogl0oooooooo
ooooogl00oooool00oooO`3ooooooomo0004ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0V_ooool01_nP8?3ooooooj0Pl?nP8?3ooooooj0Pl0Sooooo00?oX23`oooooonP8?001Ooo
ool2oj0Pl0_ooooo000:ooooo`03o`000?oooooooooo09Wooooo2oooO`02ooooo`03oomo0?oooooo
oooo00;ooooo00?oogl0ooooooooool00_ooool00oooO`3o0000ooooo`0@ooooo`03o`000?oooooo
oooo09_ooooo1onP8?0?ooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
09Sooooo00?oogl0ooooooooool00_ooool00oooO`3ooooooomo0003ooooo`;oogl00_ooool00ooo
O`3oooooooooo`04ooooo`04oomo0?ooooooooooo`00017ooooo00?o0000ooooooooool0W_ooool2
oj0Pl0;ooooo00GoX23`oooooooooooooooooj0Pl00:ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo09_ooooo00?oogl0ooooooooO`000_ooO`02ooooo`03oomo0?oooooo
ogl000;oogl00oooool2oomo00Cooooo00?oogl0o`000?ooool04?ooool00ol0003oooooooooo`2L
ooooo`03oj0Pl?oooooooooo00;oX23`2_ooool00onP8?3oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo000:ooooo`03o`000?oooooooooo09[ooooo00Googl0ooooooooooooogl0ooooo`02
oomo0003ooooooooO`3ooooo00;oogl000Cooooooomo0?ooooooogl01?ooool01?ooO`3ooooooooo
ool0000Aooooo`03o`000?oooooooooo09oooooo1?nP8?001_ooooooX23`oooooonP8?3ooooooj0P
l0Cooooo00GoX23`ooooooooooooooooo`00000;ooooo`002_ooool00ol0003oooooooooo`2Ioooo
o`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooO`000_ooool00oooO`3oooooooooo`02oomo
0004ooooooooO`3ooooooomo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2O
ooooo`03oj0Pl?ooooooX23`00Kooooo00?oX23`ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`002_ooool00ol0003oooooooooo`2Jooooo`03oomo0?oooooooooo00Kooooo1OooO`001Ooo
ooooogl0ooooooooooooogl000?ooooo00?oogl0o`000?ooool04?ooool00ol0003oooooooooo`2Q
ooooo`04oj0Pl?ooooooX23`oj0Pl0;ooooo0_nP8?08ooooo`03o`000?oooooooooo00Wooooo000:
ooooo`03o`000?oooooooooo09gooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`02
oomo00Oooooo00?oogl0ooooool000004Oooool00ol0003oooooooooo`2]ooooo`05oj0Pl?oooooo
ooooooooool000002oooool000[ooooo00?o0000ooooooooool0VOooool00oooO`3oooooooooo`06
ooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool00_ooool01?ooO`3oooooooooool0
000Aooooo`03o`000?oooooooooo0:Cooooo0_nP8?02ooooo`03oj0Pl?oooooooooo00Kooooo00?o
0000ooooooooool02Oooool000[ooooo00?o0000ooooooooool0Woooool00oooO`3oooooooooo`05
ooooo`03oomo0?oooooooooo00Cooooo00Coogl0oooooooooooo00004Oooool00ol0003ooooooooo
o`2Uooooo`03oj0Pl?oooooooooo00;oX23`1oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`2Qooooo`03oomo0?oooooooooo00cooooo00?oogl0o`000?ooool04?ooool0
0ol0003oooooooooo`2Qooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`002_ooool00ol0003oooooooooo`2Uooooo`03oomo0?ooooooogl0
00;ooooo00?oogl0ooooooooO`001?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:Sooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`09ooooo`002_ooool00ol0003o
ooooooooo`2^ooooo`04oomo0?ooooooooooo`00017ooooo00?o0000ooooooooool0Z?ooool2oj0P
l0Oooooo00?oX23`ooooooooool02Oooool000[ooooo00?o0000ooooooooool0X_ooool00oooO`3o
ooooooooo`06ooooo`03oomo0?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2Zooooo`03oj0Pl?ooooooX23`00?ooooo0_nP8?0;ooooo`002_ooool00ol0003ooooo
ooooo`2Yooooo`03oomo0?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2Wooooo`04oj0Pl?oooooooooooj0Pl0Kooooo00?oX23`ooooooooool02Oooool000[ooooo
00?o0000ooooooooool0ZOooool00oooO`3oooooooooo`04ooooo`03oomo0?l0003ooooo013ooooo
00?o0000ooooooooool0/?ooool2oj0Pl0_ooooo000:ooooo`03o`000?oooooooooo0:Oooooo00?o
ogl0ooooooooool00_ooool01_ooO`3oooooooooooooooooogl0o`00017ooooo00?o0000oooooooo
ool0ZOooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00Wooooo000:ooooo`03o`00
0?oooooooooo0:_ooooo00?oogl0ooooooooO`000oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0:[ooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`09ooooo`002_oo
ool00ol0003oooooooooo`2[ooooo`;oogl00_ooool00oooO`3oooooo`00000Aooooo`03o`000?oo
oooooooo0:_ooooo00?oX23`ooooooooool00oooool00ol0003oooooooooo`09ooooo`002_ooool0
0ol0003oooooooooo`2/ooooo`03oomo0?oooooooooo00;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Wooooo000:ooooo`03o`000?oooooooooo
0:kooooo0oooO`000ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;7ooooo00?o0000oooo
ooooool02Oooool000[ooooo/?l00003oomo00;o00004Ooooondo`000003oj0Pl?oooooooooo00Wo
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {189.438, 0}} -> {-0.0531273, -0.0238146, \
0.00527884, 0.00527884}, {{10.0625, 190.438}, {184.875, 4.5}} -> {-14.4237, \
-6.63736, 1.4157, 1.4157}, {{208.5, 388.938}, {184.875, 4.5}} -> {-295.249, \
-6.59083, 1.41521, 1.41521}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EM experiment #1: object 1 (Kellogs car)", "Subsection"],

Cell[CellGroupData[{

Cell["Extract 2d data", "Subsubsection"],

Cell[BoxData[
    \(\(d2d1 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ \((data1/255. )\))\);\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 4;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull[d2d1, k];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[d2d1, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({5.960000000000008`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsubsection"],

Cell[BoxData[
    \(\(model1 = \ em\  // \ Last;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EMAllPlot[model1, g1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.98077 .9065 m
.97921 .90385 L
.96584 .88462 L
.96154 .87469 L
.95752 .86538 L
.96154 .84702 L
.96286 .84615 L
.97264 .82692 L
.97186 .80769 L
.96875 .78846 L
.96335 .76923 L
.96154 .76356 L
.95624 .75 L
.94789 .73077 L
.94231 .71884 L
.9386 .71154 L
.92843 .69231 L
.92308 .68256 L
.91757 .67308 L
.90606 .65385 L
.90385 .6502 L
.89391 .63462 L
.88462 .6203 L
.88129 .61538 L
.86809 .59615 L
.86538 .59223 L
.85437 .57692 L
.84615 .56558 L
.84024 .55769 L
.82692 .54008 L
.82566 .53846 L
.81052 .51923 L
.80769 .51565 L
.79493 .5 L
.78846 .49213 L
.77893 .48077 L
.76923 .46936 L
.76259 .46154 L
.75 .44704 L
.74615 .44231 L
.73077 .42368 L
.7304 .42308 L
.71748 .40385 L
.73077 .385 L
.75 .38485 L
.76923 .38602 L
.78846 .3872 L
.80769 .38653 L
.82692 .38655 L
.84615 .38466 L
.84645 .38462 L
.86538 .37935 L
.88462 .36579 L
.88488 .36538 L
.89173 .34615 L
.88778 .32692 L
.88462 .31517 L
.87671 .30769 L
.86538 .2935 L
.86011 .28846 L
.84615 .27569 L
.83822 .26923 L
.82692 .26113 L
.81118 .25 L
.80769 .24821 L
.78846 .23691 L
.77804 .23077 L
.76923 .22739 L
.75 .21789 L
.73697 .21154 L
.73077 .21005 L
.71154 .2032 L
.69231 .19587 L
.68188 .19231 L
.67308 .19091 L
.65385 .1867 L
.63462 .18254 L
.61538 .17928 L
.59615 .17719 L
.57692 .17629 L
.55769 .17657 L
.53846 .17794 L
.51923 .18022 L
.5 .18304 L
.48077 .18582 L
.46154 .18816 L
.44231 .19074 L
.435 .19231 L
.42308 .196 L
.40611 .21154 L
.40385 .21675 L
.40107 .23077 L
.40162 .25 L
.40304 .26923 L
.38462 .2726 L
.37916 .26923 L
.36538 .26038 L
.35064 .25 L
.34615 .24685 L
.32692 .23324 L
.32331 .23077 L
.30769 .21995 L
.29521 .21154 L
.28846 .20626 L
.27045 .19231 L
.26923 .19114 L
.25 .17531 L
.24651 .17308 L
.23077 .15948 L
.22389 .15385 L
.21154 .1439 L
.20102 .13462 L
.19231 .12843 L
.17663 .11538 L
.17308 .11318 L
.15385 .09784 L
.15079 .09615 L
.13462 .08419 L
.11752 .07692 L
.11538 .07591 L
.09615 .07385 L
.09403 .07692 L
.09615 .08466 L
.0993 .09615 L
.1113 .11538 L
.11538 .12146 L
.12519 .13462 L
.13462 .14634 L
.14129 .15385 L
.15385 .16795 L
.15893 .17308 L
.17308 .18792 L
.17776 .19231 L
.19231 .20671 L
.19767 .21154 L
.21154 .22436 L
.2189 .23077 L
.23077 .24072 L
.24198 .25 L
.25 .25592 L
.26757 .26923 L
.26923 .27033 L
.28846 .28104 L
.29505 .28846 L
.30769 .29363 L
.32113 .30769 L
.32692 .3123 L
.34119 .32692 L
.34615 .33409 L
.35767 .34615 L
.36538 .35767 L
.37261 .36538 L
.38462 .38169 L
.38733 .38462 L
.40268 .40385 L
.40385 .40525 L
.41884 .42308 L
.42308 .42813 L
.43514 .44231 L
.44231 .45071 L
.45162 .46154 L
.46154 .473 L
.46828 .48077 L
.48077 .49501 L
.48513 .5 L
.5 .51673 L
.50219 .51923 L
.51923 .5382 L
.51946 .53846 L
.53677 .55769 L
.53846 .55961 L
.55416 .57692 L
.55769 .58087 L
.57167 .59615 L
.57692 .60196 L
.58929 .61538 L
.59615 .62288 L
.60703 .63462 L
.61538 .64363 L
.62491 .65385 L
.63462 .6642 L
.64293 .67308 L
.65385 .68458 L
.66112 .69231 L
.67308 .70478 L
.67947 .71154 L
.69231 .72478 L
.69799 .73077 L
.71154 .7446 L
.71669 .75 L
.73077 .76424 L
.73557 .76923 L
.75 .7837 L
.75461 .78846 L
.76923 .80298 L
.77383 .80769 L
.78846 .82209 L
.79322 .82692 L
.80769 .84103 L
.81279 .84615 L
.82692 .8598 L
.83254 .86538 L
.84615 .87839 L
.8525 .88462 L
.86538 .89679 L
.87268 .90385 L
.88462 .91499 L
.89662 .92308 L
.90385 .93297 L
.91723 .94231 L
.92308 .95068 L
.93792 .96154 L
.94231 .96828 L
.95869 .98077 L
.98077 .98077 L
F
0 g
.98077 .9065 m
.97921 .90385 L
.96584 .88462 L
.96154 .87469 L
.95752 .86538 L
.96154 .84702 L
.96286 .84615 L
.97264 .82692 L
.97186 .80769 L
.96875 .78846 L
.96335 .76923 L
.96154 .76356 L
.95624 .75 L
.94789 .73077 L
.94231 .71884 L
.9386 .71154 L
.92843 .69231 L
.92308 .68256 L
.91757 .67308 L
.90606 .65385 L
.90385 .6502 L
.89391 .63462 L
.88462 .6203 L
.88129 .61538 L
.86809 .59615 L
.86538 .59223 L
.85437 .57692 L
.84615 .56558 L
.84024 .55769 L
.82692 .54008 L
.82566 .53846 L
.81052 .51923 L
.80769 .51565 L
.79493 .5 L
.78846 .49213 L
.77893 .48077 L
.76923 .46936 L
.76259 .46154 L
.75 .44704 L
.74615 .44231 L
.73077 .42368 L
.7304 .42308 L
.71748 .40385 L
.73077 .385 L
.75 .38485 L
.76923 .38602 L
.78846 .3872 L
.80769 .38653 L
.82692 .38655 L
.84615 .38466 L
Mistroke
.84645 .38462 L
.86538 .37935 L
.88462 .36579 L
.88488 .36538 L
.89173 .34615 L
.88778 .32692 L
.88462 .31517 L
.87671 .30769 L
.86538 .2935 L
.86011 .28846 L
.84615 .27569 L
.83822 .26923 L
.82692 .26113 L
.81118 .25 L
.80769 .24821 L
.78846 .23691 L
.77804 .23077 L
.76923 .22739 L
.75 .21789 L
.73697 .21154 L
.73077 .21005 L
.71154 .2032 L
.69231 .19587 L
.68188 .19231 L
.67308 .19091 L
.65385 .1867 L
.63462 .18254 L
.61538 .17928 L
.59615 .17719 L
.57692 .17629 L
.55769 .17657 L
.53846 .17794 L
.51923 .18022 L
.5 .18304 L
.48077 .18582 L
.46154 .18816 L
.44231 .19074 L
.435 .19231 L
.42308 .196 L
.40611 .21154 L
.40385 .21675 L
.40107 .23077 L
.40162 .25 L
.40304 .26923 L
.38462 .2726 L
.37916 .26923 L
.36538 .26038 L
.35064 .25 L
.34615 .24685 L
.32692 .23324 L
Mistroke
.32331 .23077 L
.30769 .21995 L
.29521 .21154 L
.28846 .20626 L
.27045 .19231 L
.26923 .19114 L
.25 .17531 L
.24651 .17308 L
.23077 .15948 L
.22389 .15385 L
.21154 .1439 L
.20102 .13462 L
.19231 .12843 L
.17663 .11538 L
.17308 .11318 L
.15385 .09784 L
.15079 .09615 L
.13462 .08419 L
.11752 .07692 L
.11538 .07591 L
.09615 .07385 L
.09403 .07692 L
.09615 .08466 L
.0993 .09615 L
.1113 .11538 L
.11538 .12146 L
.12519 .13462 L
.13462 .14634 L
.14129 .15385 L
.15385 .16795 L
.15893 .17308 L
.17308 .18792 L
.17776 .19231 L
.19231 .20671 L
.19767 .21154 L
.21154 .22436 L
.2189 .23077 L
.23077 .24072 L
.24198 .25 L
.25 .25592 L
.26757 .26923 L
.26923 .27033 L
.28846 .28104 L
.29505 .28846 L
.30769 .29363 L
.32113 .30769 L
.32692 .3123 L
.34119 .32692 L
.34615 .33409 L
.35767 .34615 L
Mistroke
.36538 .35767 L
.37261 .36538 L
.38462 .38169 L
.38733 .38462 L
.40268 .40385 L
.40385 .40525 L
.41884 .42308 L
.42308 .42813 L
.43514 .44231 L
.44231 .45071 L
.45162 .46154 L
.46154 .473 L
.46828 .48077 L
.48077 .49501 L
.48513 .5 L
.5 .51673 L
.50219 .51923 L
.51923 .5382 L
.51946 .53846 L
.53677 .55769 L
.53846 .55961 L
.55416 .57692 L
.55769 .58087 L
.57167 .59615 L
.57692 .60196 L
.58929 .61538 L
.59615 .62288 L
.60703 .63462 L
.61538 .64363 L
.62491 .65385 L
.63462 .6642 L
.64293 .67308 L
.65385 .68458 L
.66112 .69231 L
.67308 .70478 L
.67947 .71154 L
.69231 .72478 L
.69799 .73077 L
.71154 .7446 L
.71669 .75 L
.73077 .76424 L
.73557 .76923 L
.75 .7837 L
.75461 .78846 L
.76923 .80298 L
.77383 .80769 L
.78846 .82209 L
.79322 .82692 L
.80769 .84103 L
.81279 .84615 L
Mistroke
.82692 .8598 L
.83254 .86538 L
.84615 .87839 L
.8525 .88462 L
.86538 .89679 L
.87268 .90385 L
.88462 .91499 L
.89662 .92308 L
.90385 .93297 L
.91723 .94231 L
.92308 .95068 L
.93792 .96154 L
.94231 .96828 L
.95869 .98077 L
Mfstroke
.2 g
.98077 .9794 m
.96154 .96532 L
.95311 .96154 L
.94231 .94966 L
.93055 .94231 L
.92308 .93311 L
.90983 .92308 L
.90385 .91608 L
.88925 .90385 L
.88462 .89873 L
.86871 .88462 L
.86538 .88109 L
.84829 .86538 L
.84615 .86317 L
.82807 .84615 L
.82692 .84499 L
.80807 .82692 L
.80769 .82654 L
.78846 .80782 L
.78833 .80769 L
.76923 .78882 L
.76886 .78846 L
.75 .76961 L
.74962 .76923 L
.73077 .75019 L
.73058 .75 L
.71177 .73077 L
.71154 .73053 L
.69325 .71154 L
.69231 .71057 L
.67499 .69231 L
.67308 .69034 L
.65698 .67308 L
.65385 .66985 L
.63924 .65385 L
.63462 .64908 L
.62177 .63462 L
.61538 .62804 L
.60167 .61538 L
.59615 .60674 L
.58394 .59615 L
.57692 .58525 L
.56641 .57692 L
.55769 .56717 L
.54908 .55769 L
.53846 .54572 L
.53194 .53846 L
.51923 .524 L
.515 .51923 L
.5 .502 L
.49825 .5 L
.48182 .48077 L
.48077 .47964 L
.46593 .46154 L
.46154 .45681 L
.45029 .44231 L
.44231 .4337 L
.43474 .42308 L
.42308 .41044 L
.41898 .40385 L
.40385 .38721 L
.40258 .38462 L
.38564 .36538 L
.38462 .36364 L
.37004 .34615 L
.36538 .33895 L
.35475 .32692 L
.34615 .31507 L
.33792 .30769 L
.32692 .29607 L
.31511 .28846 L
.30769 .2845 L
.28846 .27004 L
.27981 .26923 L
.26923 .25855 L
.25208 .25 L
.25 .24875 L
.23077 .23333 L
.22753 .23077 L
.21154 .21738 L
.20504 .21154 L
.19231 .19998 L
.1846 .19231 L
.17308 .18096 L
.16587 .17308 L
.15385 .15992 L
.14887 .15385 L
.13462 .13552 L
.13399 .13462 L
.12019 .11538 L
.11538 .10168 L
.11334 .09615 L
.11538 .09289 L
.13459 .09615 L
.13462 .09616 L
.15385 .10549 L
.16658 .11538 L
.17308 .11948 L
.18948 .13462 L
.19231 .13579 L
.21154 .15285 L
.2127 .15385 L
.23077 .17011 L
.23383 .17308 L
.25 .18828 L
.2537 .19231 L
.26923 .20743 L
.27268 .21154 L
.28846 .22856 L
.29121 .23077 L
.30769 .24692 L
.31044 .25 L
.32692 .26274 L
.33534 .26923 L
.34615 .27529 L
.36538 .28833 L
.36561 .28846 L
.38462 .30358 L
.39053 .30769 L
.40385 .31922 L
.4137 .32692 L
.42308 .33458 L
.43794 .34615 L
.44231 .34942 L
.46154 .36409 L
.46324 .36538 L
.48077 .37904 L
.48853 .38462 L
.5 .3929 L
.51923 .40183 L
.52037 .38462 L
.51923 .37874 L
.51675 .36538 L
.51614 .34615 L
.51923 .33934 L
.53846 .32913 L
.55769 .33447 L
.57692 .34249 L
.5829 .34615 L
.59615 .35641 L
.60757 .36538 L
.61538 .37357 L
.62959 .38462 L
.63462 .38954 L
.65058 .40385 L
.65385 .40704 L
.67075 .42308 L
.67308 .42541 L
.69003 .44231 L
.69231 .44467 L
.70842 .46154 L
.71154 .46492 L
.72593 .48077 L
.73077 .48627 L
.7426 .5 L
.75 .50886 L
.75846 .51923 L
.76923 .53284 L
.77355 .53846 L
.78788 .55769 L
.78846 .55849 L
.80143 .57692 L
.80769 .5862 L
.81409 .59615 L
.82582 .61538 L
.82692 .61714 L
.83652 .63462 L
.84579 .65385 L
.84615 .65471 L
.85352 .67308 L
.85889 .69231 L
.85871 .71154 L
.84615 .72334 L
.83642 .73077 L
.84423 .75 L
.84615 .75323 L
.85638 .76923 L
.86538 .78211 L
.86986 .78846 L
.8837 .80769 L
.88462 .80902 L
.89608 .82692 L
.90385 .83343 L
.91368 .84615 L
.92308 .85884 L
.92806 .86538 L
.94215 .88462 L
.94231 .88474 L
.95621 .90385 L
.96154 .90895 L
.97056 .92308 L
.98077 .93688 L
F
0 g
.98077 .9794 m
.96154 .96532 L
.95311 .96154 L
.94231 .94966 L
.93055 .94231 L
.92308 .93311 L
.90983 .92308 L
.90385 .91608 L
.88925 .90385 L
.88462 .89873 L
.86871 .88462 L
.86538 .88109 L
.84829 .86538 L
.84615 .86317 L
.82807 .84615 L
.82692 .84499 L
.80807 .82692 L
.80769 .82654 L
.78846 .80782 L
.78833 .80769 L
.76923 .78882 L
.76886 .78846 L
.75 .76961 L
.74962 .76923 L
.73077 .75019 L
.73058 .75 L
.71177 .73077 L
.71154 .73053 L
.69325 .71154 L
.69231 .71057 L
.67499 .69231 L
.67308 .69034 L
.65698 .67308 L
.65385 .66985 L
.63924 .65385 L
.63462 .64908 L
.62177 .63462 L
.61538 .62804 L
.60167 .61538 L
.59615 .60674 L
.58394 .59615 L
.57692 .58525 L
.56641 .57692 L
.55769 .56717 L
.54908 .55769 L
.53846 .54572 L
.53194 .53846 L
.51923 .524 L
.515 .51923 L
.5 .502 L
Mistroke
.49825 .5 L
.48182 .48077 L
.48077 .47964 L
.46593 .46154 L
.46154 .45681 L
.45029 .44231 L
.44231 .4337 L
.43474 .42308 L
.42308 .41044 L
.41898 .40385 L
.40385 .38721 L
.40258 .38462 L
.38564 .36538 L
.38462 .36364 L
.37004 .34615 L
.36538 .33895 L
.35475 .32692 L
.34615 .31507 L
.33792 .30769 L
.32692 .29607 L
.31511 .28846 L
.30769 .2845 L
.28846 .27004 L
.27981 .26923 L
.26923 .25855 L
.25208 .25 L
.25 .24875 L
.23077 .23333 L
.22753 .23077 L
.21154 .21738 L
.20504 .21154 L
.19231 .19998 L
.1846 .19231 L
.17308 .18096 L
.16587 .17308 L
.15385 .15992 L
.14887 .15385 L
.13462 .13552 L
.13399 .13462 L
.12019 .11538 L
.11538 .10168 L
.11334 .09615 L
.11538 .09289 L
.13459 .09615 L
.13462 .09616 L
.15385 .10549 L
.16658 .11538 L
.17308 .11948 L
.18948 .13462 L
.19231 .13579 L
Mistroke
.21154 .15285 L
.2127 .15385 L
.23077 .17011 L
.23383 .17308 L
.25 .18828 L
.2537 .19231 L
.26923 .20743 L
.27268 .21154 L
.28846 .22856 L
.29121 .23077 L
.30769 .24692 L
.31044 .25 L
.32692 .26274 L
.33534 .26923 L
.34615 .27529 L
.36538 .28833 L
.36561 .28846 L
.38462 .30358 L
.39053 .30769 L
.40385 .31922 L
.4137 .32692 L
.42308 .33458 L
.43794 .34615 L
.44231 .34942 L
.46154 .36409 L
.46324 .36538 L
.48077 .37904 L
.48853 .38462 L
.5 .3929 L
.51923 .40183 L
.52037 .38462 L
.51923 .37874 L
.51675 .36538 L
.51614 .34615 L
.51923 .33934 L
.53846 .32913 L
.55769 .33447 L
.57692 .34249 L
.5829 .34615 L
.59615 .35641 L
.60757 .36538 L
.61538 .37357 L
.62959 .38462 L
.63462 .38954 L
.65058 .40385 L
.65385 .40704 L
.67075 .42308 L
.67308 .42541 L
.69003 .44231 L
.69231 .44467 L
Mistroke
.70842 .46154 L
.71154 .46492 L
.72593 .48077 L
.73077 .48627 L
.7426 .5 L
.75 .50886 L
.75846 .51923 L
.76923 .53284 L
.77355 .53846 L
.78788 .55769 L
.78846 .55849 L
.80143 .57692 L
.80769 .5862 L
.81409 .59615 L
.82582 .61538 L
.82692 .61714 L
.83652 .63462 L
.84579 .65385 L
.84615 .65471 L
.85352 .67308 L
.85889 .69231 L
.85871 .71154 L
.84615 .72334 L
.83642 .73077 L
.84423 .75 L
.84615 .75323 L
.85638 .76923 L
.86538 .78211 L
.86986 .78846 L
.8837 .80769 L
.88462 .80902 L
.89608 .82692 L
.90385 .83343 L
.91368 .84615 L
.92308 .85884 L
.92806 .86538 L
.94215 .88462 L
.94231 .88474 L
.95621 .90385 L
.96154 .90895 L
.97056 .92308 L
.98077 .93688 L
Mfstroke
.3 g
.13462 .10425 m
.15385 .11191 L
.15883 .11538 L
.17308 .12395 L
.18577 .13462 L
.19231 .13933 L
.20594 .15385 L
.21154 .1599 L
.22697 .17308 L
.23077 .17479 L
.24635 .19231 L
.25 .19412 L
.26377 .21154 L
.26923 .21487 L
.28008 .23077 L
.28846 .23844 L
.29902 .25 L
.28846 .26567 L
.26923 .25516 L
.2586 .25 L
.25 .24495 L
.23293 .23077 L
.23077 .22926 L
.21154 .21255 L
.2104 .21154 L
.19231 .19505 L
.18956 .19231 L
.17308 .1756 L
.17083 .17308 L
.15408 .15385 L
.15385 .15351 L
.13849 .13462 L
.13462 .12715 L
.127 .11538 L
F
0 g
.13462 .10425 m
.15385 .11191 L
.15883 .11538 L
.17308 .12395 L
.18577 .13462 L
.19231 .13933 L
.20594 .15385 L
.21154 .1599 L
.22697 .17308 L
.23077 .17479 L
.24635 .19231 L
.25 .19412 L
.26377 .21154 L
.26923 .21487 L
.28008 .23077 L
.28846 .23844 L
.29902 .25 L
.28846 .26567 L
.26923 .25516 L
.2586 .25 L
.25 .24495 L
.23293 .23077 L
.23077 .22926 L
.21154 .21255 L
.2104 .21154 L
.19231 .19505 L
.18956 .19231 L
.17308 .1756 L
.17083 .17308 L
.15408 .15385 L
.15385 .15351 L
.13849 .13462 L
.13462 .12715 L
.127 .11538 L
.13462 .10425 L
s
.4 g
.15385 .11753 m
.17308 .12808 L
.18529 .13462 L
.19231 .14257 L
.20297 .15385 L
.21154 .16401 L
.22236 .17308 L
.23077 .17786 L
.24103 .19231 L
.25 .19786 L
.25836 .21154 L
.26923 .22037 L
.27576 .23077 L
.28652 .25 L
.26923 .25254 L
.26574 .25 L
.25 .24137 L
.23699 .23077 L
.23077 .22649 L
.21383 .21154 L
.21154 .20965 L
.19319 .19231 L
.19231 .19143 L
.17429 .17308 L
.17308 .17163 L
.15711 .15385 L
.15385 .14898 L
.14255 .13462 L
F
0 g
.15385 .11753 m
.17308 .12808 L
.18529 .13462 L
.19231 .14257 L
.20297 .15385 L
.21154 .16401 L
.22236 .17308 L
.23077 .17786 L
.24103 .19231 L
.25 .19786 L
.25836 .21154 L
.26923 .22037 L
.27576 .23077 L
.28652 .25 L
.26923 .25254 L
.26574 .25 L
.25 .24137 L
.23699 .23077 L
.23077 .22649 L
.21383 .21154 L
.21154 .20965 L
.19319 .19231 L
.19231 .19143 L
.17429 .17308 L
.17308 .17163 L
.15711 .15385 L
.15385 .14898 L
.14255 .13462 L
.15385 .11753 L
s
.5 g
.15385 .12275 m
.17308 .13211 L
.18088 .13462 L
.19231 .14566 L
.20197 .15385 L
.21154 .1658 L
.22018 .17308 L
.23077 .18078 L
.23836 .19231 L
.25 .2015 L
.25604 .21154 L
.26923 .22644 L
.27273 .23077 L
.26923 .24478 L
.25 .2378 L
.24109 .23077 L
.23077 .22382 L
.21675 .21154 L
.21154 .20726 L
.19572 .19231 L
.19231 .18894 L
.1768 .17308 L
.17308 .16859 L
.16001 .15385 L
.15385 .14423 L
.14672 .13462 L
F
0 g
.15385 .12275 m
.17308 .13211 L
.18088 .13462 L
.19231 .14566 L
.20197 .15385 L
.21154 .1658 L
.22018 .17308 L
.23077 .18078 L
.23836 .19231 L
.25 .2015 L
.25604 .21154 L
.26923 .22644 L
.27273 .23077 L
.26923 .24478 L
.25 .2378 L
.24109 .23077 L
.23077 .22382 L
.21675 .21154 L
.21154 .20726 L
.19572 .19231 L
.19231 .18894 L
.1768 .17308 L
.17308 .16859 L
.16001 .15385 L
.15385 .14423 L
.14672 .13462 L
.15385 .12275 L
s
.6 g
.15385 .12937 m
.17006 .13462 L
.17308 .13605 L
.19231 .14873 L
.20069 .15385 L
.21154 .1665 L
.21915 .17308 L
.23077 .18367 L
.2371 .19231 L
.25 .20528 L
.25462 .21154 L
.26593 .23077 L
.25 .23403 L
.24562 .23077 L
.23077 .22117 L
.21965 .21154 L
.21154 .20493 L
.19817 .19231 L
.19231 .1865 L
.17925 .17308 L
.17308 .16553 L
.16291 .15385 L
.15385 .13839 L
.15145 .13462 L
F
0 g
.15385 .12937 m
.17006 .13462 L
.17308 .13605 L
.19231 .14873 L
.20069 .15385 L
.21154 .1665 L
.21915 .17308 L
.23077 .18367 L
.2371 .19231 L
.25 .20528 L
.25462 .21154 L
.26593 .23077 L
.25 .23403 L
.24562 .23077 L
.23077 .22117 L
.21965 .21154 L
.21154 .20493 L
.19817 .19231 L
.19231 .1865 L
.17925 .17308 L
.17308 .16553 L
.16291 .15385 L
.15385 .13839 L
.15145 .13462 L
.15385 .12937 L
s
.7 g
.17308 .14002 m
.19231 .15186 L
.19686 .15385 L
.21154 .16733 L
.21801 .17308 L
.23077 .18664 L
.23596 .19231 L
.25 .20953 L
.25193 .21154 L
.25 .22923 L
.23077 .21846 L
.22265 .21154 L
.21154 .2026 L
.20062 .19231 L
.19231 .18406 L
.1817 .17308 L
.17308 .1623 L
.16593 .15385 L
F
0 g
.17308 .14002 m
.19231 .15186 L
.19686 .15385 L
.21154 .16733 L
.21801 .17308 L
.23077 .18664 L
.23596 .19231 L
.25 .20953 L
.25193 .21154 L
.25 .22923 L
.23077 .21846 L
.22265 .21154 L
.21154 .2026 L
.20062 .19231 L
.19231 .18406 L
.1817 .17308 L
.17308 .1623 L
.16593 .15385 L
.17308 .14002 L
s
.8 g
.17308 .14472 m
.19029 .15385 L
.19231 .1552 L
.21154 .16951 L
.21546 .17308 L
.23077 .18982 L
.2337 .19231 L
.24705 .21154 L
.23077 .21557 L
.22592 .21154 L
.21154 .2002 L
.20315 .19231 L
.19231 .18152 L
.18422 .17308 L
.17308 .15864 L
.16922 .15385 L
F
0 g
.17308 .14472 m
.19029 .15385 L
.19231 .1552 L
.21154 .16951 L
.21546 .17308 L
.23077 .18982 L
.2337 .19231 L
.24705 .21154 L
.23077 .21557 L
.22592 .21154 L
.21154 .2002 L
.20315 .19231 L
.19231 .18152 L
.18422 .17308 L
.17308 .15864 L
.16922 .15385 L
.17308 .14472 L
s
.9 g
.19231 .15898 m
.21074 .17308 L
.21154 .17384 L
.22956 .19231 L
.23077 .19403 L
.24026 .21154 L
.23077 .21229 L
.22981 .21154 L
.21154 .19764 L
.20583 .19231 L
.19231 .17878 L
.18691 .17308 L
F
0 g
.19231 .15898 m
.21074 .17308 L
.21154 .17384 L
.22956 .19231 L
.23077 .19403 L
.24026 .21154 L
.23077 .21229 L
.22981 .21154 L
.21154 .19764 L
.20583 .19231 L
.19231 .17878 L
.18691 .17308 L
.19231 .15898 L
s
1 g
.19231 .16382 m
.20596 .17308 L
.21154 .17834 L
.22484 .19231 L
.21154 .19479 L
.20886 .19231 L
.19231 .17564 L
.18995 .17308 L
F
0 g
.19231 .16382 m
.20596 .17308 L
.21154 .17834 L
.22484 .19231 L
.21154 .19479 L
.20886 .19231 L
.19231 .17564 L
.18995 .17308 L
.19231 .16382 L
s
.3 g
.38462 .32253 m
.39241 .32692 L
.40385 .33382 L
.42065 .34615 L
.42308 .3479 L
.44231 .36403 L
.44382 .36538 L
.46154 .38121 L
.46471 .38462 L
.48077 .39835 L
.48584 .40385 L
.5 .41525 L
.50778 .42308 L
.51923 .43186 L
.53465 .44231 L
.53846 .44821 L
.55602 .46154 L
.55769 .46308 L
.57692 .4805 L
.57724 .48077 L
.59615 .49775 L
.5987 .5 L
.61538 .51516 L
.61993 .51923 L
.63462 .53284 L
.64071 .53846 L
.65385 .55107 L
.66065 .55769 L
.67308 .57031 L
.67937 .57692 L
.69231 .59095 L
.69693 .59615 L
.71154 .61283 L
.7137 .61538 L
.73012 .63462 L
.73077 .6354 L
.74641 .65385 L
.75 .65825 L
.76236 .67308 L
.76923 .68155 L
.77808 .69231 L
.78846 .70515 L
.79366 .71154 L
.80769 .72893 L
.80918 .73077 L
.82395 .75 L
.82692 .75373 L
.83817 .76923 L
.84615 .77918 L
.85266 .78846 L
.86538 .80384 L
.868 .80769 L
.88462 .82643 L
.88493 .82692 L
.90161 .84615 L
.90385 .84977 L
.91637 .86538 L
.92308 .87004 L
.93006 .88462 L
.94231 .9035 L
.94244 .90385 L
.95306 .92308 L
.94231 .93285 L
.92753 .92308 L
.92308 .92004 L
.90385 .90487 L
.90219 .90385 L
.88462 .88828 L
.87953 .88462 L
.86538 .87096 L
.85839 .86538 L
.84615 .85319 L
.83792 .84615 L
.82692 .83508 L
.81782 .82692 L
.80769 .81668 L
.79802 .80769 L
.78846 .798 L
.77848 .78846 L
.76923 .77906 L
.7592 .76923 L
.75 .75986 L
.74017 .75 L
.73077 .74041 L
.72139 .73077 L
.71154 .7207 L
.70284 .71154 L
.69231 .70076 L
.68452 .69231 L
.67308 .68058 L
.66641 .67308 L
.65385 .66021 L
.64847 .65385 L
.63462 .63966 L
.63064 .63462 L
.61538 .61903 L
.60933 .61538 L
.59615 .5984 L
.59174 .59615 L
.57692 .57793 L
.57434 .57692 L
.55769 .55829 L
.55715 .55769 L
.54024 .53846 L
.53846 .53655 L
.52365 .51923 L
.51923 .51449 L
.50731 .5 L
.5 .49211 L
.49114 .48077 L
.48077 .46948 L
.47501 .46154 L
.46154 .44663 L
.45873 .44231 L
.44231 .42357 L
.44203 .42308 L
.42375 .40385 L
.42308 .39933 L
.40836 .38462 L
.40385 .37375 L
.39544 .36538 L
.385 .34615 L
.38462 .34548 L
.37628 .32692 L
F
0 g
.38462 .32253 m
.39241 .32692 L
.40385 .33382 L
.42065 .34615 L
.42308 .3479 L
.44231 .36403 L
.44382 .36538 L
.46154 .38121 L
.46471 .38462 L
.48077 .39835 L
.48584 .40385 L
.5 .41525 L
.50778 .42308 L
.51923 .43186 L
.53465 .44231 L
.53846 .44821 L
.55602 .46154 L
.55769 .46308 L
.57692 .4805 L
.57724 .48077 L
.59615 .49775 L
.5987 .5 L
.61538 .51516 L
.61993 .51923 L
.63462 .53284 L
.64071 .53846 L
.65385 .55107 L
.66065 .55769 L
.67308 .57031 L
.67937 .57692 L
.69231 .59095 L
.69693 .59615 L
.71154 .61283 L
.7137 .61538 L
.73012 .63462 L
.73077 .6354 L
.74641 .65385 L
.75 .65825 L
.76236 .67308 L
.76923 .68155 L
.77808 .69231 L
.78846 .70515 L
.79366 .71154 L
.80769 .72893 L
.80918 .73077 L
.82395 .75 L
.82692 .75373 L
.83817 .76923 L
.84615 .77918 L
.85266 .78846 L
Mistroke
.86538 .80384 L
.868 .80769 L
.88462 .82643 L
.88493 .82692 L
.90161 .84615 L
.90385 .84977 L
.91637 .86538 L
.92308 .87004 L
.93006 .88462 L
.94231 .9035 L
.94244 .90385 L
.95306 .92308 L
.94231 .93285 L
.92753 .92308 L
.92308 .92004 L
.90385 .90487 L
.90219 .90385 L
.88462 .88828 L
.87953 .88462 L
.86538 .87096 L
.85839 .86538 L
.84615 .85319 L
.83792 .84615 L
.82692 .83508 L
.81782 .82692 L
.80769 .81668 L
.79802 .80769 L
.78846 .798 L
.77848 .78846 L
.76923 .77906 L
.7592 .76923 L
.75 .75986 L
.74017 .75 L
.73077 .74041 L
.72139 .73077 L
.71154 .7207 L
.70284 .71154 L
.69231 .70076 L
.68452 .69231 L
.67308 .68058 L
.66641 .67308 L
.65385 .66021 L
.64847 .65385 L
.63462 .63966 L
.63064 .63462 L
.61538 .61903 L
.60933 .61538 L
.59615 .5984 L
.59174 .59615 L
.57692 .57793 L
Mistroke
.57434 .57692 L
.55769 .55829 L
.55715 .55769 L
.54024 .53846 L
.53846 .53655 L
.52365 .51923 L
.51923 .51449 L
.50731 .5 L
.5 .49211 L
.49114 .48077 L
.48077 .46948 L
.47501 .46154 L
.46154 .44663 L
.45873 .44231 L
.44231 .42357 L
.44203 .42308 L
.42375 .40385 L
.42308 .39933 L
.40836 .38462 L
.40385 .37375 L
.39544 .36538 L
.385 .34615 L
.38462 .34548 L
.37628 .32692 L
.38462 .32253 L
Mfstroke
.4 g
.42308 .36332 m
.42664 .36538 L
.44231 .37533 L
.45443 .38462 L
.46154 .38998 L
.4783 .40385 L
.48077 .40584 L
.5 .42285 L
.50004 .42308 L
.51923 .44139 L
.52272 .44231 L
.53846 .46011 L
.54402 .46154 L
.55769 .4742 L
.56483 .48077 L
.57692 .49222 L
.58521 .5 L
.59615 .5106 L
.60518 .51923 L
.61538 .52934 L
.62474 .53846 L
.63462 .54846 L
.64388 .55769 L
.65385 .56802 L
.66259 .57692 L
.67308 .58803 L
.68087 .59615 L
.69231 .60853 L
.69873 .61538 L
.71154 .62953 L
.71619 .63462 L
.73077 .65101 L
.73331 .65385 L
.75 .67294 L
.75012 .67308 L
.76617 .69231 L
.76923 .69583 L
.78187 .71154 L
.78846 .71918 L
.79743 .73077 L
.80769 .74268 L
.81311 .75 L
.82692 .76581 L
.82931 .76923 L
.84615 .78796 L
.84646 .78846 L
.86477 .80769 L
.86538 .81158 L
.88025 .82692 L
.88462 .83682 L
.89363 .84615 L
.90385 .86407 L
.90502 .86538 L
.91536 .88462 L
.90385 .89181 L
.89356 .88462 L
.88462 .87823 L
.86881 .86538 L
.86538 .86265 L
.84636 .84615 L
.84615 .84598 L
.82692 .82833 L
.82519 .82692 L
.80769 .81015 L
.80483 .80769 L
.78846 .79161 L
.78498 .78846 L
.76923 .77276 L
.76548 .76923 L
.75 .75366 L
.74627 .75 L
.73077 .73431 L
.72729 .73077 L
.71154 .71476 L
.70851 .71154 L
.69231 .69502 L
.68988 .69231 L
.67308 .67514 L
.67136 .67308 L
.65385 .65517 L
.65285 .65385 L
.63462 .63519 L
.63426 .63462 L
.61557 .61538 L
.61538 .61518 L
.59792 .59615 L
.59615 .59425 L
.58059 .57692 L
.57692 .57299 L
.56355 .55769 L
.55769 .55139 L
.54675 .53846 L
.53846 .52948 L
.53016 .51923 L
.51923 .50725 L
.51368 .5 L
.5 .48472 L
.4972 .48077 L
.48077 .46182 L
.48059 .46154 L
.46497 .44231 L
.46154 .43787 L
.44994 .42308 L
.44231 .41273 L
.42977 .40385 L
.42308 .38506 L
.42253 .38462 L
.41551 .36538 L
F
0 g
.42308 .36332 m
.42664 .36538 L
.44231 .37533 L
.45443 .38462 L
.46154 .38998 L
.4783 .40385 L
.48077 .40584 L
.5 .42285 L
.50004 .42308 L
.51923 .44139 L
.52272 .44231 L
.53846 .46011 L
.54402 .46154 L
.55769 .4742 L
.56483 .48077 L
.57692 .49222 L
.58521 .5 L
.59615 .5106 L
.60518 .51923 L
.61538 .52934 L
.62474 .53846 L
.63462 .54846 L
.64388 .55769 L
.65385 .56802 L
.66259 .57692 L
.67308 .58803 L
.68087 .59615 L
.69231 .60853 L
.69873 .61538 L
.71154 .62953 L
.71619 .63462 L
.73077 .65101 L
.73331 .65385 L
.75 .67294 L
.75012 .67308 L
.76617 .69231 L
.76923 .69583 L
.78187 .71154 L
.78846 .71918 L
.79743 .73077 L
.80769 .74268 L
.81311 .75 L
.82692 .76581 L
.82931 .76923 L
.84615 .78796 L
.84646 .78846 L
.86477 .80769 L
.86538 .81158 L
.88025 .82692 L
.88462 .83682 L
Mistroke
.89363 .84615 L
.90385 .86407 L
.90502 .86538 L
.91536 .88462 L
.90385 .89181 L
.89356 .88462 L
.88462 .87823 L
.86881 .86538 L
.86538 .86265 L
.84636 .84615 L
.84615 .84598 L
.82692 .82833 L
.82519 .82692 L
.80769 .81015 L
.80483 .80769 L
.78846 .79161 L
.78498 .78846 L
.76923 .77276 L
.76548 .76923 L
.75 .75366 L
.74627 .75 L
.73077 .73431 L
.72729 .73077 L
.71154 .71476 L
.70851 .71154 L
.69231 .69502 L
.68988 .69231 L
.67308 .67514 L
.67136 .67308 L
.65385 .65517 L
.65285 .65385 L
.63462 .63519 L
.63426 .63462 L
.61557 .61538 L
.61538 .61518 L
.59792 .59615 L
.59615 .59425 L
.58059 .57692 L
.57692 .57299 L
.56355 .55769 L
.55769 .55139 L
.54675 .53846 L
.53846 .52948 L
.53016 .51923 L
.51923 .50725 L
.51368 .5 L
.5 .48472 L
.4972 .48077 L
.48077 .46182 L
.48059 .46154 L
Mistroke
.46497 .44231 L
.46154 .43787 L
.44994 .42308 L
.44231 .41273 L
.42977 .40385 L
.42308 .38506 L
.42253 .38462 L
.41551 .36538 L
.42308 .36332 L
Mfstroke
.5 g
.46154 .40181 m
.46451 .40385 L
.48077 .41544 L
.49018 .42308 L
.5 .43097 L
.51312 .44231 L
.51923 .44296 L
.53485 .46154 L
.53846 .46297 L
.55582 .48077 L
.55769 .48194 L
.57622 .5 L
.57692 .50056 L
.59615 .51922 L
.59617 .51923 L
.61538 .53809 L
.61577 .53846 L
.63462 .55737 L
.63494 .55769 L
.65372 .57692 L
.65385 .57706 L
.67211 .59615 L
.67308 .5972 L
.69004 .61538 L
.69231 .61784 L
.70753 .63462 L
.71154 .63898 L
.72462 .65385 L
.73077 .66061 L
.74137 .67308 L
.75 .68264 L
.75791 .69231 L
.76923 .70493 L
.77441 .71154 L
.78846 .72723 L
.79108 .73077 L
.80769 .74925 L
.8082 .75 L
.82447 .76923 L
.82692 .77235 L
.83984 .78846 L
.84615 .79676 L
.86117 .80769 L
.86538 .82268 L
.87072 .82692 L
.88011 .84615 L
.86538 .85253 L
.85712 .84615 L
.84615 .83769 L
.83356 .82692 L
.82692 .82134 L
.81175 .80769 L
.80769 .80411 L
.79087 .78846 L
.78846 .78625 L
.77062 .76923 L
.76923 .76792 L
.75084 .75 L
.75 .74996 L
.73142 .73077 L
.73077 .73053 L
.71231 .71154 L
.71154 .71109 L
.69244 .69231 L
.69231 .69146 L
.674 .67308 L
.67308 .67156 L
.65581 .65385 L
.65385 .65137 L
.63788 .63462 L
.63462 .63086 L
.62021 .61538 L
.61538 .61004 L
.6028 .59615 L
.59615 .5889 L
.58563 .57692 L
.57692 .56742 L
.56868 .55769 L
.55769 .5456 L
.55191 .53846 L
.53846 .52341 L
.53525 .51923 L
.51923 .50079 L
.51866 .5 L
.50268 .48077 L
.5 .47741 L
.48728 .46154 L
.48077 .45303 L
.47253 .44231 L
.46154 .42685 L
.45888 .42308 L
.44941 .40385 L
F
0 g
.46154 .40181 m
.46451 .40385 L
.48077 .41544 L
.49018 .42308 L
.5 .43097 L
.51312 .44231 L
.51923 .44296 L
.53485 .46154 L
.53846 .46297 L
.55582 .48077 L
.55769 .48194 L
.57622 .5 L
.57692 .50056 L
.59615 .51922 L
.59617 .51923 L
.61538 .53809 L
.61577 .53846 L
.63462 .55737 L
.63494 .55769 L
.65372 .57692 L
.65385 .57706 L
.67211 .59615 L
.67308 .5972 L
.69004 .61538 L
.69231 .61784 L
.70753 .63462 L
.71154 .63898 L
.72462 .65385 L
.73077 .66061 L
.74137 .67308 L
.75 .68264 L
.75791 .69231 L
.76923 .70493 L
.77441 .71154 L
.78846 .72723 L
.79108 .73077 L
.80769 .74925 L
.8082 .75 L
.82447 .76923 L
.82692 .77235 L
.83984 .78846 L
.84615 .79676 L
.86117 .80769 L
.86538 .82268 L
.87072 .82692 L
.88011 .84615 L
.86538 .85253 L
.85712 .84615 L
.84615 .83769 L
.83356 .82692 L
Mistroke
.82692 .82134 L
.81175 .80769 L
.80769 .80411 L
.79087 .78846 L
.78846 .78625 L
.77062 .76923 L
.76923 .76792 L
.75084 .75 L
.75 .74996 L
.73142 .73077 L
.73077 .73053 L
.71231 .71154 L
.71154 .71109 L
.69244 .69231 L
.69231 .69146 L
.674 .67308 L
.67308 .67156 L
.65581 .65385 L
.65385 .65137 L
.63788 .63462 L
.63462 .63086 L
.62021 .61538 L
.61538 .61004 L
.6028 .59615 L
.59615 .5889 L
.58563 .57692 L
.57692 .56742 L
.56868 .55769 L
.55769 .5456 L
.55191 .53846 L
.53846 .52341 L
.53525 .51923 L
.51923 .50079 L
.51866 .5 L
.50268 .48077 L
.5 .47741 L
.48728 .46154 L
.48077 .45303 L
.47253 .44231 L
.46154 .42685 L
.45888 .42308 L
.44941 .40385 L
.46154 .40181 L
Mfstroke
.6 g
.5 .44043 m
.50243 .44231 L
.51923 .4491 L
.52624 .46154 L
.53846 .46734 L
.54822 .48077 L
.55769 .48645 L
.56922 .5 L
.57692 .50562 L
.59514 .51923 L
.59615 .52483 L
.6118 .53846 L
.61538 .54418 L
.62971 .55769 L
.63462 .56379 L
.64786 .57692 L
.65385 .58374 L
.66589 .59615 L
.67308 .60405 L
.68369 .61538 L
.69231 .62476 L
.70122 .63462 L
.71154 .64584 L
.71851 .65385 L
.73077 .66724 L
.73564 .67308 L
.75 .68887 L
.75273 .69231 L
.76923 .71061 L
.76992 .71154 L
.78653 .73077 L
.78846 .73312 L
.80239 .75 L
.80769 .75668 L
.81775 .76923 L
.82692 .78135 L
.83235 .78846 L
.84557 .80769 L
.84615 .80866 L
.85216 .82692 L
.84615 .82695 L
.84612 .82692 L
.82692 .81322 L
.82031 .80769 L
.80769 .7972 L
.79794 .78846 L
.78846 .78007 L
.77684 .76923 L
.76923 .76221 L
.7565 .75 L
.75 .74929 L
.7367 .73077 L
.73077 .72855 L
.71731 .71154 L
.71154 .70825 L
.69313 .69231 L
.69231 .68803 L
.67644 .67308 L
.67308 .6677 L
.65915 .65385 L
.65385 .64717 L
.64175 .63462 L
.63462 .62637 L
.62442 .61538 L
.61538 .60528 L
.60723 .59615 L
.59615 .58384 L
.59021 .57692 L
.57692 .56204 L
.57335 .55769 L
.55769 .53979 L
.55665 .53846 L
.54032 .51923 L
.53846 .51699 L
.52449 .5 L
.51923 .49341 L
.50921 .48077 L
.5 .46854 L
.49478 .46154 L
.48243 .44231 L
F
0 g
.5 .44043 m
.50243 .44231 L
.51923 .4491 L
.52624 .46154 L
.53846 .46734 L
.54822 .48077 L
.55769 .48645 L
.56922 .5 L
.57692 .50562 L
.59514 .51923 L
.59615 .52483 L
.6118 .53846 L
.61538 .54418 L
.62971 .55769 L
.63462 .56379 L
.64786 .57692 L
.65385 .58374 L
.66589 .59615 L
.67308 .60405 L
.68369 .61538 L
.69231 .62476 L
.70122 .63462 L
.71154 .64584 L
.71851 .65385 L
.73077 .66724 L
.73564 .67308 L
.75 .68887 L
.75273 .69231 L
.76923 .71061 L
.76992 .71154 L
.78653 .73077 L
.78846 .73312 L
.80239 .75 L
.80769 .75668 L
.81775 .76923 L
.82692 .78135 L
.83235 .78846 L
.84557 .80769 L
.84615 .80866 L
.85216 .82692 L
.84615 .82695 L
.84612 .82692 L
.82692 .81322 L
.82031 .80769 L
.80769 .7972 L
.79794 .78846 L
.78846 .78007 L
.77684 .76923 L
.76923 .76221 L
.7565 .75 L
Mistroke
.75 .74929 L
.7367 .73077 L
.73077 .72855 L
.71731 .71154 L
.71154 .70825 L
.69313 .69231 L
.69231 .68803 L
.67644 .67308 L
.67308 .6677 L
.65915 .65385 L
.65385 .64717 L
.64175 .63462 L
.63462 .62637 L
.62442 .61538 L
.61538 .60528 L
.60723 .59615 L
.59615 .58384 L
.59021 .57692 L
.57692 .56204 L
.57335 .55769 L
.55769 .53979 L
.55665 .53846 L
.54032 .51923 L
.53846 .51699 L
.52449 .5 L
.51923 .49341 L
.50921 .48077 L
.5 .46854 L
.49478 .46154 L
.48243 .44231 L
.5 .44043 L
Mfstroke
.7 g
.51923 .46668 m
.53846 .47929 L
.53933 .48077 L
.55769 .49414 L
.56176 .5 L
.57692 .51176 L
.58966 .51923 L
.59615 .53044 L
.60689 .53846 L
.61538 .54966 L
.62473 .55769 L
.63462 .56928 L
.64275 .57692 L
.65385 .58926 L
.66073 .59615 L
.67308 .6096 L
.67857 .61538 L
.69231 .63028 L
.69623 .63462 L
.71154 .65128 L
.71375 .65385 L
.73077 .67258 L
.73118 .67308 L
.74806 .69231 L
.75 .69456 L
.76446 .71154 L
.76923 .71728 L
.78041 .73077 L
.78846 .74088 L
.79574 .75 L
.80769 .766 L
.81009 .76923 L
.82081 .78846 L
.80769 .7887 L
.80739 .78846 L
.78846 .77315 L
.78405 .76923 L
.76923 .75612 L
.76267 .75 L
.75 .74506 L
.74226 .73077 L
.73077 .72461 L
.72248 .71154 L
.71154 .70423 L
.69624 .69231 L
.69231 .68382 L
.68021 .67308 L
.67308 .66327 L
.66332 .65385 L
.65385 .6425 L
.64617 .63462 L
.63462 .62144 L
.62901 .61538 L
.61538 .60003 L
.61196 .59615 L
.59615 .57821 L
.59507 .57692 L
.57839 .55769 L
.57692 .55599 L
.5621 .53846 L
.55769 .53317 L
.54628 .51923 L
.53846 .50938 L
.53114 .5 L
.51923 .48371 L
.51716 .48077 L
F
0 g
.51923 .46668 m
.53846 .47929 L
.53933 .48077 L
.55769 .49414 L
.56176 .5 L
.57692 .51176 L
.58966 .51923 L
.59615 .53044 L
.60689 .53846 L
.61538 .54966 L
.62473 .55769 L
.63462 .56928 L
.64275 .57692 L
.65385 .58926 L
.66073 .59615 L
.67308 .6096 L
.67857 .61538 L
.69231 .63028 L
.69623 .63462 L
.71154 .65128 L
.71375 .65385 L
.73077 .67258 L
.73118 .67308 L
.74806 .69231 L
.75 .69456 L
.76446 .71154 L
.76923 .71728 L
.78041 .73077 L
.78846 .74088 L
.79574 .75 L
.80769 .766 L
.81009 .76923 L
.82081 .78846 L
.80769 .7887 L
.80739 .78846 L
.78846 .77315 L
.78405 .76923 L
.76923 .75612 L
.76267 .75 L
.75 .74506 L
.74226 .73077 L
.73077 .72461 L
.72248 .71154 L
.71154 .70423 L
.69624 .69231 L
.69231 .68382 L
.68021 .67308 L
.67308 .66327 L
.66332 .65385 L
.65385 .6425 L
Mistroke
.64617 .63462 L
.63462 .62144 L
.62901 .61538 L
.61538 .60003 L
.61196 .59615 L
.59615 .57821 L
.59507 .57692 L
.57839 .55769 L
.57692 .55599 L
.5621 .53846 L
.55769 .53317 L
.54628 .51923 L
.53846 .50938 L
.53114 .5 L
.51923 .48371 L
.51716 .48077 L
.51923 .46668 L
Mfstroke
.2 g
.57692 .20646 m
.59615 .20329 L
.61538 .20278 L
.63462 .20414 L
.65385 .20696 L
.67308 .2107 L
.67724 .21154 L
.69231 .21596 L
.71154 .22263 L
.73077 .22976 L
.73359 .23077 L
.75 .2386 L
.76923 .24851 L
.77211 .25 L
.78846 .26024 L
.80139 .26923 L
.80769 .27385 L
.82355 .28846 L
.82692 .28905 L
.83875 .30769 L
.84588 .32692 L
.84005 .34615 L
.82692 .35646 L
.80769 .36067 L
.78846 .36187 L
.76923 .36104 L
.75 .35863 L
.73077 .35486 L
.71154 .34996 L
.69231 .34706 L
.6895 .34615 L
.67308 .34063 L
.65385 .336 L
.63462 .32946 L
.62766 .32692 L
.61538 .32243 L
.59615 .31402 L
.58739 .30769 L
.57692 .30265 L
.56139 .28846 L
.55769 .2832 L
.54757 .26923 L
.54062 .25 L
.54303 .23077 L
.55769 .21473 L
.56327 .21154 L
F
0 g
.57692 .20646 m
.59615 .20329 L
.61538 .20278 L
.63462 .20414 L
.65385 .20696 L
.67308 .2107 L
.67724 .21154 L
.69231 .21596 L
.71154 .22263 L
.73077 .22976 L
.73359 .23077 L
.75 .2386 L
.76923 .24851 L
.77211 .25 L
.78846 .26024 L
.80139 .26923 L
.80769 .27385 L
.82355 .28846 L
.82692 .28905 L
.83875 .30769 L
.84588 .32692 L
.84005 .34615 L
.82692 .35646 L
.80769 .36067 L
.78846 .36187 L
.76923 .36104 L
.75 .35863 L
.73077 .35486 L
.71154 .34996 L
.69231 .34706 L
.6895 .34615 L
.67308 .34063 L
.65385 .336 L
.63462 .32946 L
.62766 .32692 L
.61538 .32243 L
.59615 .31402 L
.58739 .30769 L
.57692 .30265 L
.56139 .28846 L
.55769 .2832 L
.54757 .26923 L
.54062 .25 L
.54303 .23077 L
.55769 .21473 L
.56327 .21154 L
.57692 .20646 L
s
.8 g
.55769 .50594 m
.57437 .51923 L
.57692 .52129 L
.59611 .53846 L
.59615 .5385 L
.61538 .55654 L
.61686 .55769 L
.63462 .57554 L
.63617 .57692 L
.65385 .5952 L
.65483 .59615 L
.67308 .61538 L
.67308 .61538 L
.69098 .63462 L
.69231 .63604 L
.70845 .65385 L
.71154 .65727 L
.72551 .67308 L
.73077 .67911 L
.7421 .69231 L
.75 .70173 L
.75812 .71154 L
.76923 .72551 L
.77335 .73077 L
.76923 .74834 L
.75 .73336 L
.74884 .73077 L
.73077 .71619 L
.7283 .71154 L
.71154 .69725 L
.7047 .69231 L
.69231 .67748 L
.68711 .67308 L
.67308 .65717 L
.66955 .65385 L
.65385 .63641 L
.65208 .63462 L
.63477 .61538 L
.63462 .61522 L
.61749 .59615 L
.61538 .59382 L
.60063 .57692 L
.59615 .57178 L
.58424 .55769 L
.57692 .54892 L
.56845 .53846 L
.55769 .5247 L
.55358 .51923 L
F
0 g
.55769 .50594 m
.57437 .51923 L
.57692 .52129 L
.59611 .53846 L
.59615 .5385 L
.61538 .55654 L
.61686 .55769 L
.63462 .57554 L
.63617 .57692 L
.65385 .5952 L
.65483 .59615 L
.67308 .61538 L
.67308 .61538 L
.69098 .63462 L
.69231 .63604 L
.70845 .65385 L
.71154 .65727 L
.72551 .67308 L
.73077 .67911 L
.7421 .69231 L
.75 .70173 L
.75812 .71154 L
.76923 .72551 L
.77335 .73077 L
.76923 .74834 L
.75 .73336 L
.74884 .73077 L
.73077 .71619 L
.7283 .71154 L
.71154 .69725 L
.7047 .69231 L
.69231 .67748 L
.68711 .67308 L
.67308 .65717 L
.66955 .65385 L
.65385 .63641 L
.65208 .63462 L
.63477 .61538 L
.63462 .61522 L
.61749 .59615 L
.61538 .59382 L
.60063 .57692 L
.59615 .57178 L
.58424 .55769 L
.57692 .54892 L
.56845 .53846 L
.55769 .5247 L
.55358 .51923 L
.55769 .50594 L
s
.3 g
.59615 .22706 m
.61538 .22084 L
.63462 .22012 L
.65385 .22172 L
.67308 .22512 L
.69231 .2299 L
.69553 .23077 L
.71154 .23616 L
.73077 .2441 L
.74349 .25 L
.75 .25323 L
.76923 .2648 L
.77559 .26923 L
.78846 .27796 L
.7981 .28846 L
.80769 .30067 L
.81158 .30769 L
.81285 .32692 L
.80769 .33372 L
.78846 .34527 L
.76923 .34457 L
.75 .34329 L
.73077 .34019 L
.71154 .33555 L
.69231 .3298 L
.68276 .32692 L
.67308 .3232 L
.65385 .31451 L
.6396 .30769 L
.63462 .30502 L
.61538 .29224 L
.61052 .28846 L
.59615 .27663 L
.59186 .26923 L
.58377 .25 L
.59219 .23077 L
F
0 g
.59615 .22706 m
.61538 .22084 L
.63462 .22012 L
.65385 .22172 L
.67308 .22512 L
.69231 .2299 L
.69553 .23077 L
.71154 .23616 L
.73077 .2441 L
.74349 .25 L
.75 .25323 L
.76923 .2648 L
.77559 .26923 L
.78846 .27796 L
.7981 .28846 L
.80769 .30067 L
.81158 .30769 L
.81285 .32692 L
.80769 .33372 L
.78846 .34527 L
.76923 .34457 L
.75 .34329 L
.73077 .34019 L
.71154 .33555 L
.69231 .3298 L
.68276 .32692 L
.67308 .3232 L
.65385 .31451 L
.6396 .30769 L
.63462 .30502 L
.61538 .29224 L
.61052 .28846 L
.59615 .27663 L
.59186 .26923 L
.58377 .25 L
.59219 .23077 L
.59615 .22706 L
s
.9 g
.59615 .54814 m
.60717 .55769 L
.61538 .56477 L
.62812 .57692 L
.63462 .58301 L
.64769 .59615 L
.65385 .60225 L
.66642 .61538 L
.67308 .62228 L
.68449 .63462 L
.69231 .64306 L
.70195 .65385 L
.71154 .66466 L
.71878 .67308 L
.73077 .68735 L
.73481 .69231 L
.73077 .70537 L
.71631 .69231 L
.71154 .68806 L
.69619 .67308 L
.69231 .66937 L
.67714 .65385 L
.67308 .64977 L
.65881 .63462 L
.65385 .62943 L
.64109 .61538 L
.63462 .60835 L
.62394 .59615 L
.61538 .58641 L
.60745 .57692 L
.59615 .56322 L
.59186 .55769 L
F
0 g
.59615 .54814 m
.60717 .55769 L
.61538 .56477 L
.62812 .57692 L
.63462 .58301 L
.64769 .59615 L
.65385 .60225 L
.66642 .61538 L
.67308 .62228 L
.68449 .63462 L
.69231 .64306 L
.70195 .65385 L
.71154 .66466 L
.71878 .67308 L
.73077 .68735 L
.73481 .69231 L
.73077 .70537 L
.71631 .69231 L
.71154 .68806 L
.69619 .67308 L
.69231 .66937 L
.67714 .65385 L
.67308 .64977 L
.65881 .63462 L
.65385 .62943 L
.64109 .61538 L
.63462 .60835 L
.62394 .59615 L
.61538 .58641 L
.60745 .57692 L
.59615 .56322 L
.59186 .55769 L
.59615 .54814 L
s
.4 g
.63462 .23823 m
.65385 .23305 L
.67308 .23716 L
.69231 .24216 L
.71154 .24881 L
.71465 .25 L
.73077 .25601 L
.75 .26778 L
.75208 .26923 L
.76923 .27815 L
.77521 .28846 L
.78576 .30769 L
.76923 .3264 L
.76708 .32692 L
.75 .32847 L
.7331 .32692 L
.73077 .32688 L
.71154 .32326 L
.69231 .31684 L
.67308 .30864 L
.67104 .30769 L
.65385 .29986 L
.63897 .28846 L
.63462 .28482 L
.62047 .26923 L
.61699 .25 L
F
0 g
.63462 .23823 m
.65385 .23305 L
.67308 .23716 L
.69231 .24216 L
.71154 .24881 L
.71465 .25 L
.73077 .25601 L
.75 .26778 L
.75208 .26923 L
.76923 .27815 L
.77521 .28846 L
.78576 .30769 L
.76923 .3264 L
.76708 .32692 L
.75 .32847 L
.7331 .32692 L
.73077 .32688 L
.71154 .32326 L
.69231 .31684 L
.67308 .30864 L
.67104 .30769 L
.65385 .29986 L
.63897 .28846 L
.63462 .28482 L
.62047 .26923 L
.61699 .25 L
.63462 .23823 L
s
.3 g
.65385 .48058 m
.65431 .48077 L
.67308 .49305 L
.68097 .5 L
.69231 .51125 L
.6995 .51923 L
.71154 .53416 L
.71465 .53846 L
.72636 .55769 L
.71154 .57269 L
.69231 .55784 L
.69216 .55769 L
.67406 .53846 L
.67308 .53729 L
.65994 .51923 L
.65385 .50966 L
.64866 .5 L
.64553 .48077 L
F
0 g
.65385 .48058 m
.65431 .48077 L
.67308 .49305 L
.68097 .5 L
.69231 .51125 L
.6995 .51923 L
.71154 .53416 L
.71465 .53846 L
.72636 .55769 L
.71154 .57269 L
.69231 .55784 L
.69216 .55769 L
.67406 .53846 L
.67308 .53729 L
.65994 .51923 L
.65385 .50966 L
.64866 .5 L
.64553 .48077 L
.65385 .48058 L
s
.5 g
.65385 .25823 m
.67308 .25396 L
.69231 .25675 L
.71154 .25863 L
.7265 .26923 L
.73077 .27269 L
.7498 .28846 L
.74913 .30769 L
.73077 .31351 L
.71154 .30819 L
.70898 .30769 L
.69231 .30179 L
.67308 .29581 L
.66676 .28846 L
.65385 .27586 L
.64972 .26923 L
F
0 g
.65385 .25823 m
.67308 .25396 L
.69231 .25675 L
.71154 .25863 L
.7265 .26923 L
.73077 .27269 L
.7498 .28846 L
.74913 .30769 L
.73077 .31351 L
.71154 .30819 L
.70898 .30769 L
.69231 .30179 L
.67308 .29581 L
.66676 .28846 L
.65385 .27586 L
.64972 .26923 L
.65385 .25823 L
s
1 g
.65385 .61362 m
.65556 .61538 L
.67308 .63308 L
.67443 .63462 L
.67308 .63796 L
.67004 .63462 L
.65385 .61777 L
.65194 .61538 L
F
0 g
.65385 .61362 m
.65556 .61538 L
.67308 .63308 L
.67443 .63462 L
.67308 .63796 L
.67004 .63462 L
.65385 .61777 L
.65194 .61538 L
.65385 .61362 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48572 Mtetra
.77165 .48572 .77677 .49222 .78848 .48871 .78339 .48218 Mtetra
.78339 .48218 .78848 .48871 .80024 .48518 .79518 .47863 Mtetra
.663 .741 .908 r
.79518 .47863 .80024 .48518 .81205 .48164 .80702 .47506 Mtetra
.80702 .47506 .81205 .48164 .8239 .47808 .81891 .47149 Mtetra
.81891 .47149 .8239 .47808 .8358 .47452 .83085 .4679 Mtetra
.663 .741 .909 r
.83085 .4679 .8358 .47452 .84776 .47095 .84284 .46432 Mtetra
.662 .742 .909 r
.84284 .46432 .84776 .47095 .85976 .46738 .85488 .46075 Mtetra
.66 .742 .91 r
.85488 .46075 .85976 .46738 .87182 .46381 .86698 .4572 Mtetra
.658 .743 .912 r
.86698 .4572 .87182 .46381 .88393 .46027 .87913 .45371 Mtetra
.655 .744 .915 r
.87913 .45371 .88393 .46027 .89609 .45677 .89135 .45029 Mtetra
.649 .745 .92 r
.89135 .45029 .89609 .45677 .90832 .45333 .90364 .44704 Mtetra
.619 .74 .933 r
.90364 .44704 .90832 .45333 .92062 .45004 .91608 .44456 Mtetra
.436 .682 .967 r
.91608 .44456 .92062 .45004 .93307 .44747 .92901 .44555 Mtetra
.454 0 0 r
.92901 .44555 .93307 .44747 .94598 .44804 .94307 .45465 Mtetra
.737 .29 .189 r
.94307 .45465 .94598 .44804 .9599 .45555 .95791 .46851 Mtetra
.544 .176 .294 r
.95791 .46851 .9599 .45555 .97442 .46634 .97128 .47006 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .50719 Mtetra
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48626 Mtetra
.74307 .48626 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48572 .76648 .47918 Mtetra
.76648 .47918 .77165 .48572 .78339 .48218 .77826 .47561 Mtetra
.663 .741 .908 r
.77826 .47561 .78339 .48218 .79518 .47863 .79008 .47203 Mtetra
.79008 .47203 .79518 .47863 .80702 .47506 .80196 .46844 Mtetra
.80196 .46844 .80702 .47506 .81891 .47149 .81388 .46485 Mtetra
.663 .741 .909 r
.81388 .46485 .81891 .47149 .83085 .4679 .82586 .46126 Mtetra
.662 .742 .909 r
.82586 .46126 .83085 .4679 .84284 .46432 .83789 .45767 Mtetra
.66 .742 .911 r
.83789 .45767 .84284 .46432 .85488 .46075 .84997 .45413 Mtetra
.658 .743 .913 r
.84997 .45413 .85488 .46075 .86698 .4572 .86211 .45064 Mtetra
.654 .744 .916 r
.86211 .45064 .86698 .4572 .87913 .45371 .87432 .44724 Mtetra
.647 .745 .921 r
.87432 .44724 .87913 .45371 .89135 .45029 .8866 .44403 Mtetra
.615 .74 .935 r
.8866 .44403 .89135 .45029 .90364 .44704 .89903 .44164 Mtetra
.406 .67 .968 r
.89903 .44164 .90364 .44704 .91608 .44456 .91198 .44304 Mtetra
.56 0 0 r
.91198 .44304 .91608 .44456 .92901 .44555 .92616 .45376 Mtetra
.764 .342 .248 r
.92616 .45376 .92901 .44555 .94307 .45465 .94134 .47103 Mtetra
.587 .241 .35 r
.94134 .47103 .94307 .45465 .95791 .46851 .95502 .47513 Mtetra
0 0 0 r
.95502 .47513 .95791 .46851 .97128 .47006 .96582 .45688 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.65712 .50427 .66261 .51063 .67397 .50719 .6685 .5008 Mtetra
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49383 Mtetra
.69141 .49383 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48327 Mtetra
.72613 .48327 .73144 .48979 .74307 .48626 .7378 .47972 Mtetra
.7378 .47972 .74307 .48626 .75475 .48273 .74951 .47616 Mtetra
.74951 .47616 .75475 .48273 .76648 .47918 .76127 .47258 Mtetra
.663 .741 .908 r
.76127 .47258 .76648 .47918 .77826 .47561 .77309 .46899 Mtetra
.77309 .46899 .77826 .47561 .79008 .47203 .78495 .46539 Mtetra
.78495 .46539 .79008 .47203 .80196 .46844 .79686 .46178 Mtetra
.662 .741 .909 r
.79686 .46178 .80196 .46844 .81388 .46485 .80882 .45818 Mtetra
.661 .742 .909 r
.80882 .45818 .81388 .46485 .82586 .46126 .82083 .45459 Mtetra
.66 .742 .911 r
.82083 .45459 .82586 .46126 .83789 .45767 .8329 .45104 Mtetra
.657 .743 .913 r
.8329 .45104 .83789 .45767 .84997 .45413 .84503 .44755 Mtetra
.653 .744 .917 r
.84503 .44755 .84997 .45413 .86211 .45064 .85723 .44417 Mtetra
.645 .746 .923 r
.85723 .44417 .86211 .45064 .87432 .44724 .8695 .441 Mtetra
.61 .74 .937 r
.8695 .441 .87432 .44724 .8866 .44403 .88192 .4387 Mtetra
.375 .657 .967 r
.88192 .4387 .8866 .44403 .89903 .44164 .89487 .44048 Mtetra
.639 .083 0 r
.89487 .44048 .89903 .44164 .91198 .44304 .90916 .45284 Mtetra
.784 .381 .289 r
.90916 .45284 .91198 .44304 .92616 .45376 .92467 .47381 Mtetra
.62 .289 .388 r
.92467 .47381 .92616 .45376 .94134 .47103 .93872 .48106 Mtetra
0 0 0 r
.93872 .48106 .94134 .47103 .95502 .47513 .94947 .46165 Mtetra
.87 .702 .671 r
.94947 .46165 .95502 .47513 .96582 .45688 .95926 .43559 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.65158 .49786 .65712 .50427 .6685 .5008 .663 .49437 Mtetra
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49383 .68597 .48735 Mtetra
.68597 .48735 .69141 .49383 .70294 .49033 .69753 .48382 Mtetra
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48027 Mtetra
.70913 .48027 .71451 .48681 .72613 .48327 .72078 .47671 Mtetra
.72078 .47671 .72613 .48327 .7378 .47972 .73248 .47313 Mtetra
.73248 .47313 .7378 .47972 .74951 .47616 .74423 .46954 Mtetra
.663 .741 .908 r
.74423 .46954 .74951 .47616 .76127 .47258 .75603 .46594 Mtetra
.75603 .46594 .76127 .47258 .77309 .46899 .76788 .46233 Mtetra
.76788 .46233 .77309 .46899 .78495 .46539 .77977 .45871 Mtetra
.662 .741 .909 r
.77977 .45871 .78495 .46539 .79686 .46178 .79172 .45509 Mtetra
.661 .742 .91 r
.79172 .45509 .79686 .46178 .80882 .45818 .80372 .45149 Mtetra
.659 .742 .911 r
.80372 .45149 .80882 .45818 .82083 .45459 .81577 .44793 Mtetra
.656 .743 .913 r
.81577 .44793 .82083 .45459 .8329 .45104 .82789 .44445 Mtetra
.652 .744 .917 r
.82789 .44445 .8329 .45104 .84503 .44755 .84007 .44109 Mtetra
.643 .746 .924 r
.84007 .44109 .84503 .44755 .85723 .44417 .85233 .43796 Mtetra
.606 .74 .94 r
.85233 .43796 .85723 .44417 .8695 .441 .86474 .43575 Mtetra
.345 .644 .965 r
.86474 .43575 .8695 .441 .88192 .4387 .87769 .43786 Mtetra
.696 .155 0 r
.87769 .43786 .88192 .4387 .89487 .44048 .89206 .45181 Mtetra
.799 .411 .319 r
.89206 .45181 .89487 .44048 .90916 .45284 .9079 .47674 Mtetra
.646 .326 .415 r
.9079 .47674 .90916 .45284 .92467 .47381 .92236 .48778 Mtetra
0 0 .139 r
.92236 .48778 .92467 .47381 .93872 .48106 .93311 .46752 Mtetra
.887 .706 .653 r
.93311 .46752 .93872 .48106 .94947 .46165 .94254 .43757 Mtetra
.743 .578 .67 r
.94254 .43757 .94947 .46165 .95926 .43559 .9534 .41957 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.646 .49141 .65158 .49786 .663 .49437 .65745 .48789 Mtetra
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48027 .70371 .47368 Mtetra
.70371 .47368 .70913 .48027 .72078 .47671 .7154 .47009 Mtetra
.7154 .47009 .72078 .47671 .73248 .47313 .72713 .46649 Mtetra
.663 .741 .908 r
.72713 .46649 .73248 .47313 .74423 .46954 .73891 .46288 Mtetra
.73891 .46288 .74423 .46954 .75603 .46594 .75075 .45925 Mtetra
.75075 .45925 .75603 .46594 .76788 .46233 .76263 .45562 Mtetra
.662 .741 .909 r
.76263 .45562 .76788 .46233 .77977 .45871 .77456 .45199 Mtetra
.661 .742 .91 r
.77456 .45199 .77977 .45871 .79172 .45509 .78654 .44838 Mtetra
.659 .742 .911 r
.78654 .44838 .79172 .45509 .80372 .45149 .79859 .44482 Mtetra
.656 .743 .914 r
.79859 .44482 .80372 .45149 .81577 .44793 .81069 .44134 Mtetra
.651 .744 .918 r
.81069 .44134 .81577 .44793 .82789 .44445 .82285 .438 Mtetra
.641 .746 .925 r
.82285 .438 .82789 .44445 .84007 .44109 .8351 .43491 Mtetra
.602 .74 .942 r
.8351 .43491 .84007 .44109 .85233 .43796 .8475 .43276 Mtetra
.317 .632 .963 r
.8475 .43276 .85233 .43796 .86474 .43575 .86043 .43517 Mtetra
.736 .211 0 r
.86043 .43517 .86474 .43575 .87769 .43786 .87486 .45063 Mtetra
.811 .434 .342 r
.87486 .45063 .87769 .43786 .89206 .45181 .891 .47967 Mtetra
.668 .355 .434 r
.891 .47967 .89206 .45181 .9079 .47674 .90591 .49516 Mtetra
.103 0 .249 r
.90591 .49516 .9079 .47674 .92236 .48778 .91672 .47448 Mtetra
.903 .712 .635 r
.91672 .47448 .92236 .48778 .93311 .46752 .92581 .44037 Mtetra
.747 .569 .655 r
.92581 .44037 .93311 .46752 .94254 .43757 .93637 .41933 Mtetra
.697 .583 .724 r
.93637 .41933 .94254 .43757 .9534 .41957 .94842 .41035 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.64038 .48491 .646 .49141 .65745 .48789 .65186 .48136 Mtetra
.65186 .48136 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47423 Mtetra
.67496 .47423 .68049 .48082 .69208 .47726 .68658 .47065 Mtetra
.68658 .47065 .69208 .47726 .70371 .47368 .69825 .46705 Mtetra
.69825 .46705 .70371 .47368 .7154 .47009 .70997 .46343 Mtetra
.663 .741 .908 r
.70997 .46343 .7154 .47009 .72713 .46649 .72174 .4598 Mtetra
.72174 .4598 .72713 .46649 .73891 .46288 .73356 .45616 Mtetra
.73356 .45616 .73891 .46288 .75075 .45925 .74542 .45252 Mtetra
.662 .741 .909 r
.74542 .45252 .75075 .45925 .76263 .45562 .75734 .44888 Mtetra
.661 .742 .91 r
.75734 .44888 .76263 .45562 .77456 .45199 .76931 .44526 Mtetra
.659 .742 .911 r
.76931 .44526 .77456 .45199 .78654 .44838 .78133 .44169 Mtetra
.655 .743 .914 r
.78133 .44169 .78654 .44838 .79859 .44482 .79342 .43821 Mtetra
.65 .744 .919 r
.79342 .43821 .79859 .44482 .81069 .44134 .80557 .43488 Mtetra
.639 .746 .926 r
.80557 .43488 .81069 .44134 .82285 .438 .81781 .43183 Mtetra
.598 .74 .944 r
.81781 .43183 .82285 .438 .8351 .43491 .83019 .42975 Mtetra
.293 .621 .959 r
.83019 .42975 .8351 .43491 .8475 .43276 .8431 .43239 Mtetra
.765 .253 0 r
.8431 .43239 .8475 .43276 .86043 .43517 .85756 .44923 Mtetra
.821 .453 .358 r
.85756 .44923 .86043 .43517 .87486 .45063 .87396 .48244 Mtetra
.686 .378 .448 r
.87396 .48244 .87486 .45063 .891 .47967 .88933 .50301 Mtetra
.213 0 .323 r
.88933 .50301 .891 .47967 .90591 .49516 .90028 .48246 Mtetra
.919 .721 .618 r
.90028 .48246 .90591 .49516 .91672 .47448 .90905 .44402 Mtetra
.751 .563 .642 r
.90905 .44402 .91672 .47448 .92581 .44037 .91929 .41954 Mtetra
.696 .567 .705 r
.91929 .41954 .92581 .44037 .93637 .41933 .93123 .40939 Mtetra
.696 .686 .836 r
.93123 .40939 .93637 .41933 .94842 .41035 .94376 .40377 Mtetra
.664 .741 .908 r
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50983 Mtetra
.53318 .50983 .53912 .51615 .55019 .51274 .54428 .50639 Mtetra
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47835 Mtetra
.63471 .47835 .64038 .48491 .65186 .48136 .64622 .47478 Mtetra
.64622 .47478 .65186 .48136 .66338 .47781 .65778 .4712 Mtetra
.65778 .4712 .66338 .47781 .67496 .47423 .66939 .4676 Mtetra
.66939 .4676 .67496 .47423 .68658 .47065 .68105 .46399 Mtetra
.68105 .46399 .68658 .47065 .69825 .46705 .69275 .46036 Mtetra
.663 .741 .908 r
.69275 .46036 .69825 .46705 .70997 .46343 .7045 .45672 Mtetra
.7045 .45672 .70997 .46343 .72174 .4598 .7163 .45307 Mtetra
.7163 .45307 .72174 .4598 .73356 .45616 .72816 .44941 Mtetra
.662 .741 .909 r
.72816 .44941 .73356 .45616 .74542 .45252 .74006 .44575 Mtetra
.661 .742 .91 r
.74006 .44575 .74542 .45252 .75734 .44888 .75201 .44212 Mtetra
.659 .742 .911 r
.75201 .44212 .75734 .44888 .76931 .44526 .76402 .43854 Mtetra
.655 .743 .914 r
.76402 .43854 .76931 .44526 .78133 .44169 .77609 .43506 Mtetra
.649 .744 .919 r
.77609 .43506 .78133 .44169 .79342 .43821 .78823 .43175 Mtetra
.637 .746 .927 r
.78823 .43175 .79342 .43821 .80557 .43488 .80045 .42872 Mtetra
.595 .74 .945 r
.80045 .42872 .80557 .43488 .81781 .43183 .81281 .42669 Mtetra
.273 .612 .956 r
.81281 .42669 .81781 .43183 .83019 .42975 .82569 .42951 Mtetra
.786 .285 0 r
.82569 .42951 .83019 .42975 .8431 .43239 .84015 .44755 Mtetra
.83 .468 .371 r
.84015 .44755 .8431 .43239 .85756 .44923 .85676 .48489 Mtetra
.703 .398 .458 r
.85676 .48489 .85756 .44923 .87396 .48244 .8726 .51111 Mtetra
.297 .059 .374 r
.8726 .51111 .87396 .48244 .88933 .50301 .88376 .49137 Mtetra
.935 .73 .601 r
.88376 .49137 .88933 .50301 .90028 .48246 .89225 .44852 Mtetra
.754 .558 .63 r
.89225 .44852 .90028 .48246 .90905 .44402 .90218 .42021 Mtetra
.695 .552 .687 r
.90218 .42021 .90905 .44402 .91929 .41954 .91399 .40872 Mtetra
.696 .67 .82 r
.91399 .40872 .91929 .41954 .93123 .40939 .92649 .40284 Mtetra
.709 .783 .91 r
.92649 .40284 .93123 .40939 .94376 .40377 .93909 .39736 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50983 .5272 .50347 Mtetra
.5272 .50347 .53318 .50983 .54428 .50639 .53833 .5 Mtetra
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48245 Mtetra
.59465 .48245 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47533 Mtetra
.61751 .47533 .62325 .48191 .63471 .47835 .629 .47175 Mtetra
.629 .47175 .63471 .47835 .64622 .47478 .64055 .46816 Mtetra
.64055 .46816 .64622 .47478 .65778 .4712 .65214 .46454 Mtetra
.65214 .46454 .65778 .4712 .66939 .4676 .66378 .46092 Mtetra
.66378 .46092 .66939 .4676 .68105 .46399 .67547 .45728 Mtetra
.663 .741 .908 r
.67547 .45728 .68105 .46399 .69275 .46036 .68721 .45362 Mtetra
.68721 .45362 .69275 .46036 .7045 .45672 .69899 .44996 Mtetra
.69899 .44996 .7045 .45672 .7163 .45307 .71083 .44629 Mtetra
.662 .741 .909 r
.71083 .44629 .7163 .45307 .72816 .44941 .72271 .44262 Mtetra
.661 .742 .91 r
.72271 .44262 .72816 .44941 .74006 .44575 .73465 .43898 Mtetra
.659 .742 .911 r
.73465 .43898 .74006 .44575 .75201 .44212 .74665 .43539 Mtetra
.655 .743 .914 r
.74665 .43539 .75201 .44212 .76402 .43854 .7587 .4319 Mtetra
.648 .744 .919 r
.7587 .4319 .76402 .43854 .77609 .43506 .77083 .42859 Mtetra
.636 .746 .928 r
.77083 .42859 .77609 .43506 .78823 .43175 .78303 .42559 Mtetra
.593 .74 .946 r
.78303 .42559 .78823 .43175 .80045 .42872 .79537 .4236 Mtetra
.26 .606 .954 r
.79537 .4236 .80045 .42872 .81281 .42669 .80821 .42652 Mtetra
.8 .308 0 r
.80821 .42652 .81281 .42669 .82569 .42951 .82263 .44554 Mtetra
.837 .481 .38 r
.82263 .44554 .82569 .42951 .84015 .44755 .83939 .48685 Mtetra
.718 .415 .465 r
.83939 .48685 .84015 .44755 .85676 .48489 .85569 .5192 Mtetra
.364 .123 .41 r
.85569 .5192 .85676 .48489 .8726 .51111 .86712 .50103 Mtetra
.951 .742 .584 r
.86712 .50103 .8726 .51111 .88376 .49137 .87539 .45384 Mtetra
.759 .554 .621 r
.87539 .45384 .88376 .49137 .89225 .44852 .88501 .42135 Mtetra
.694 .539 .672 r
.88501 .42135 .89225 .44852 .90218 .42021 .89669 .40833 Mtetra
.694 .652 .803 r
.89669 .40833 .90218 .42021 .91399 .40872 .90917 .40217 Mtetra
.712 .784 .909 r
.90917 .40217 .91399 .40872 .92649 .40284 .92176 .39657 Mtetra
.727 .8 .91 r
.92176 .39657 .92649 .40284 .93909 .39736 .93432 .39043 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.52117 .49706 .5272 .50347 .53833 .5 .53233 .49357 Mtetra
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48245 .58881 .47588 Mtetra
.58881 .47588 .59465 .48245 .60606 .4789 .60024 .4723 Mtetra
.60024 .4723 .60606 .4789 .61751 .47533 .61172 .46871 Mtetra
.61172 .46871 .61751 .47533 .629 .47175 .62325 .4651 Mtetra
.62325 .4651 .629 .47175 .64055 .46816 .63483 .46148 Mtetra
.63483 .46148 .64055 .46816 .65214 .46454 .64645 .45784 Mtetra
.64645 .45784 .65214 .46454 .66378 .46092 .65813 .45418 Mtetra
.663 .741 .908 r
.65813 .45418 .66378 .46092 .67547 .45728 .66985 .45052 Mtetra
.66985 .45052 .67547 .45728 .68721 .45362 .68162 .44684 Mtetra
.68162 .44684 .68721 .45362 .69899 .44996 .69344 .44315 Mtetra
.662 .741 .909 r
.69344 .44315 .69899 .44996 .71083 .44629 .70531 .43947 Mtetra
.661 .742 .91 r
.70531 .43947 .71083 .44629 .72271 .44262 .71723 .43581 Mtetra
.659 .742 .911 r
.71723 .43581 .72271 .44262 .73465 .43898 .72921 .43221 Mtetra
.655 .743 .914 r
.72921 .43221 .73465 .43898 .74665 .43539 .74125 .42872 Mtetra
.647 .744 .92 r
.74125 .42872 .74665 .43539 .7587 .4319 .75336 .42541 Mtetra
.634 .746 .929 r
.75336 .42541 .7587 .4319 .77083 .42859 .76554 .42243 Mtetra
.591 .74 .947 r
.76554 .42243 .77083 .42859 .78303 .42559 .77787 .42045 Mtetra
.253 .603 .953 r
.77787 .42045 .78303 .42559 .79537 .4236 .79066 .4234 Mtetra
.81 .324 .015 r
.79066 .4234 .79537 .4236 .80821 .42652 .805 .44316 Mtetra
.844 .492 .386 r
.805 .44316 .80821 .42652 .82263 .44554 .82184 .48813 Mtetra
.731 .43 .471 r
.82184 .48813 .82263 .44554 .83939 .48685 .83855 .52697 Mtetra
.417 .174 .435 r
.83855 .52697 .83939 .48685 .85569 .5192 .85033 .51122 Mtetra
.967 .755 .565 r
.85033 .51122 .85569 .5192 .86712 .50103 .85846 .45991 Mtetra
.763 .552 .612 r
.85846 .45991 .86712 .50103 .87539 .45384 .86777 .42294 Mtetra
.693 .527 .658 r
.86777 .42294 .87539 .45384 .88501 .42135 .87932 .40819 Mtetra
.691 .632 .785 r
.87932 .40819 .88501 .42135 .89669 .40833 .89178 .40175 Mtetra
.714 .785 .908 r
.89178 .40175 .89669 .40833 .90917 .40217 .90436 .39606 Mtetra
.733 .808 .911 r
.90436 .39606 .90917 .40217 .92176 .39657 .91691 .3897 Mtetra
.742 .787 .89 r
.91691 .3897 .92176 .39657 .93432 .39043 .92944 .38285 Mtetra
.664 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.4708 .50453 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .49759 Mtetra
.49286 .49759 .49899 .504 .51006 .50054 .50396 .4941 Mtetra
.50396 .4941 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48708 Mtetra
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.5715 .47286 .57742 .47945 .58881 .47588 .58292 .46926 Mtetra
.58292 .46926 .58881 .47588 .60024 .4723 .59438 .46566 Mtetra
.59438 .46566 .60024 .4723 .61172 .46871 .6059 .46203 Mtetra
.6059 .46203 .61172 .46871 .62325 .4651 .61746 .4584 Mtetra
.61746 .4584 .62325 .4651 .63483 .46148 .62907 .45475 Mtetra
.62907 .45475 .63483 .46148 .64645 .45784 .64072 .45108 Mtetra
.663 .741 .908 r
.64072 .45108 .64645 .45784 .65813 .45418 .65243 .4474 Mtetra
.65243 .4474 .65813 .45418 .66985 .45052 .66418 .44371 Mtetra
.66418 .44371 .66985 .45052 .68162 .44684 .67599 .44001 Mtetra
.662 .741 .909 r
.67599 .44001 .68162 .44684 .69344 .44315 .68784 .43631 Mtetra
.661 .741 .91 r
.68784 .43631 .69344 .44315 .70531 .43947 .69975 .43264 Mtetra
.659 .742 .911 r
.69975 .43264 .70531 .43947 .71723 .43581 .71171 .42902 Mtetra
.655 .742 .914 r
.71171 .42902 .71723 .43581 .72921 .43221 .72374 .42552 Mtetra
.647 .744 .92 r
.72374 .42552 .72921 .43221 .74125 .42872 .73582 .42221 Mtetra
.634 .746 .929 r
.73582 .42221 .74125 .42872 .75336 .42541 .74799 .41924 Mtetra
.59 .741 .948 r
.74799 .41924 .75336 .42541 .76554 .42243 .76029 .41726 Mtetra
.253 .604 .953 r
.76029 .41726 .76554 .42243 .77787 .42045 .77303 .42017 Mtetra
.816 .334 .026 r
.77303 .42017 .77787 .42045 .79066 .4234 .78727 .44037 Mtetra
.85 .5 .391 r
.78727 .44037 .79066 .4234 .805 .44316 .80411 .48858 Mtetra
.743 .443 .474 r
.80411 .48858 .805 .44316 .82184 .48813 .82118 .53409 Mtetra
.462 .215 .453 r
.82118 .53409 .82184 .48813 .83855 .52697 .83335 .52166 Mtetra
.981 .77 .544 r
.83335 .52166 .83855 .52697 .85033 .51122 .84141 .46661 Mtetra
.767 .551 .605 r
.84141 .46661 .85033 .51122 .85846 .45991 .85046 .42494 Mtetra
.692 .517 .646 r
.85046 .42494 .85846 .45991 .86777 .42294 .86187 .40826 Mtetra
.687 .613 .767 r
.86187 .40826 .86777 .42294 .87932 .40819 .87432 .40153 Mtetra
.714 .783 .906 r
.87432 .40153 .87932 .40819 .89178 .40175 .88691 .3958 Mtetra
.738 .816 .912 r
.88691 .3958 .89178 .40175 .90436 .39606 .89944 .38925 Mtetra
.75 .793 .887 r
.89944 .38925 .90436 .39606 .91691 .3897 .91194 .38206 Mtetra
.749 .769 .869 r
.91194 .38206 .91691 .3897 .92944 .38285 .92444 .37464 Mtetra
.664 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.46457 .49813 .4708 .50453 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .49759 .48668 .49114 Mtetra
.48668 .49114 .49286 .49759 .50396 .4941 .49781 .48762 Mtetra
.49781 .48762 .50396 .4941 .5151 .4906 .50898 .48409 Mtetra
.50898 .48409 .5151 .4906 .52629 .48708 .5202 .48054 Mtetra
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46621 Mtetra
.56553 .46621 .5715 .47286 .58292 .46926 .57698 .46259 Mtetra
.57698 .46259 .58292 .46926 .59438 .46566 .58848 .45896 Mtetra
.58848 .45896 .59438 .46566 .6059 .46203 .60002 .45531 Mtetra
.60002 .45531 .6059 .46203 .61746 .4584 .61162 .45164 Mtetra
.61162 .45164 .61746 .4584 .62907 .45475 .62326 .44796 Mtetra
.663 .741 .908 r
.62326 .44796 .62907 .45475 .64072 .45108 .63495 .44427 Mtetra
.63495 .44427 .64072 .45108 .65243 .4474 .64669 .44057 Mtetra
.64669 .44057 .65243 .4474 .66418 .44371 .65848 .43685 Mtetra
.663 .741 .909 r
.65848 .43685 .66418 .44371 .67599 .44001 .67032 .43314 Mtetra
.661 .741 .909 r
.67032 .43314 .67599 .44001 .68784 .43631 .68221 .42945 Mtetra
.659 .742 .911 r
.68221 .42945 .68784 .43631 .69975 .43264 .69415 .42582 Mtetra
.655 .742 .914 r
.69415 .42582 .69975 .43264 .71171 .42902 .70616 .4223 Mtetra
.647 .744 .92 r
.70616 .4223 .71171 .42902 .72374 .42552 .71823 .41898 Mtetra
.633 .745 .929 r
.71823 .41898 .72374 .42552 .73582 .42221 .73038 .41601 Mtetra
.59 .741 .948 r
.73038 .41601 .73582 .42221 .74799 .41924 .74265 .41402 Mtetra
.26 .608 .955 r
.74265 .41402 .74799 .41924 .76029 .41726 .75533 .41681 Mtetra
.819 .338 .029 r
.75533 .41681 .76029 .41726 .77303 .42017 .76943 .43717 Mtetra
.856 .508 .394 r
.76943 .43717 .77303 .42017 .78727 .44037 .78619 .48808 Mtetra
.755 .455 .477 r
.78619 .48808 .78727 .44037 .80411 .48858 .80354 .54023 Mtetra
.5 .25 .467 r
.80354 .54023 .80411 .48858 .82118 .53409 .81615 .53202 Mtetra
.993 .785 .519 r
.81615 .53202 .82118 .53409 .83335 .52166 .82424 .47379 Mtetra
.772 .551 .599 r
.82424 .47379 .83335 .52166 .84141 .46661 .83306 .42729 Mtetra
.692 .509 .635 r
.83306 .42729 .84141 .46661 .85046 .42494 .84435 .40851 Mtetra
.682 .593 .749 r
.84435 .40851 .85046 .42494 .86187 .40826 .85677 .40148 Mtetra
.713 .78 .904 r
.85677 .40148 .86187 .40826 .87432 .40153 .86937 .39575 Mtetra
.742 .823 .915 r
.86937 .39575 .87432 .40153 .88691 .3958 .88191 .38907 Mtetra
.758 .798 .885 r
.88191 .38907 .88691 .3958 .89944 .38925 .89439 .38155 Mtetra
.758 .771 .864 r
.89439 .38155 .89944 .38925 .91194 .38206 .90685 .37367 Mtetra
.75 .751 .853 r
.90685 .37367 .91194 .38206 .92444 .37464 .91935 .3659 Mtetra
.664 .741 .908 r
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.45829 .49168 .46457 .49813 .4756 .49464 .46935 .48816 Mtetra
.46935 .48816 .4756 .49464 .48668 .49114 .48046 .48463 Mtetra
.48046 .48463 .48668 .49114 .49781 .48762 .49162 .48109 Mtetra
.49162 .48109 .49781 .48762 .50898 .48409 .50282 .47753 Mtetra
.50282 .47753 .50898 .48409 .5202 .48054 .51406 .47396 Mtetra
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46621 .55952 .45952 Mtetra
.55952 .45952 .56553 .46621 .57698 .46259 .571 .45587 Mtetra
.571 .45587 .57698 .46259 .58848 .45896 .58253 .45221 Mtetra
.58253 .45221 .58848 .45896 .60002 .45531 .59411 .44853 Mtetra
.59411 .44853 .60002 .45531 .61162 .45164 .60573 .44484 Mtetra
.663 .741 .908 r
.60573 .44484 .61162 .45164 .62326 .44796 .61741 .44113 Mtetra
.61741 .44113 .62326 .44796 .63495 .44427 .62913 .43741 Mtetra
.62913 .43741 .63495 .44427 .64669 .44057 .6409 .43369 Mtetra
.663 .741 .909 r
.6409 .43369 .64669 .44057 .65848 .43685 .65273 .42996 Mtetra
.661 .741 .909 r
.65273 .42996 .65848 .43685 .67032 .43314 .6646 .42626 Mtetra
.659 .742 .911 r
.6646 .42626 .67032 .43314 .68221 .42945 .67653 .4226 Mtetra
.655 .742 .914 r
.67653 .4226 .68221 .42945 .69415 .42582 .68852 .41907 Mtetra
.647 .743 .92 r
.68852 .41907 .69415 .42582 .70616 .4223 .70057 .41573 Mtetra
.633 .745 .929 r
.70057 .41573 .70616 .4223 .71823 .41898 .7127 .41275 Mtetra
.591 .741 .948 r
.7127 .41275 .71823 .41898 .73038 .41601 .72494 .41072 Mtetra
.274 .616 .958 r
.72494 .41072 .73038 .41601 .74265 .41402 .73756 .41332 Mtetra
.818 .337 .024 r
.73756 .41332 .74265 .41402 .75533 .41681 .75151 .43355 Mtetra
.861 .514 .395 r
.75151 .43355 .75533 .41681 .76943 .43717 .7681 .48651 Mtetra
.765 .465 .478 r
.7681 .48651 .76943 .43717 .78619 .48808 .78563 .54507 Mtetra
.533 .279 .476 r
.78563 .54507 .78619 .48808 .80354 .54023 .79869 .54191 Mtetra
.999 .799 .488 r
.79869 .54191 .80354 .54023 .81615 .53202 .80691 .48125 Mtetra
.777 .552 .594 r
.80691 .48125 .81615 .53202 .82424 .47379 .81556 .4299 Mtetra
.691 .502 .626 r
.81556 .4299 .82424 .47379 .83306 .42729 .82672 .40888 Mtetra
.677 .574 .732 r
.82672 .40888 .83306 .42729 .84435 .40851 .83914 .40153 Mtetra
.71 .773 .901 r
.83914 .40153 .84435 .40851 .85677 .40148 .85175 .39588 Mtetra
.744 .831 .918 r
.85175 .39588 .85677 .40148 .86937 .39575 .8643 .38911 Mtetra
.764 .803 .884 r
.8643 .38911 .86937 .39575 .88191 .38907 .87676 .3813 Mtetra
.766 .772 .858 r
.87676 .3813 .88191 .38907 .89439 .38155 .88919 .37297 Mtetra
.758 .75 .845 r
.88919 .37297 .89439 .38155 .90685 .37367 .90165 .36466 Mtetra
.746 .736 .842 r
.90165 .36466 .90685 .37367 .91935 .3659 .91419 .35678 Mtetra
.664 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.45196 .48518 .45829 .49168 .46935 .48816 .46305 .48164 Mtetra
.46305 .48164 .46935 .48816 .48046 .48463 .47419 .47808 Mtetra
.47419 .47808 .48046 .48463 .49162 .48109 .48538 .47451 Mtetra
.48538 .47451 .49162 .48109 .50282 .47753 .49661 .47092 Mtetra
.49661 .47092 .50282 .47753 .51406 .47396 .50788 .46732 Mtetra
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45643 Mtetra
.542 .45643 .54809 .46315 .55952 .45952 .55346 .45277 Mtetra
.55346 .45277 .55952 .45952 .571 .45587 .56497 .4491 Mtetra
.56497 .4491 .571 .45587 .58253 .45221 .57654 .44541 Mtetra
.57654 .44541 .58253 .45221 .59411 .44853 .58814 .4417 Mtetra
.663 .741 .908 r
.58814 .4417 .59411 .44853 .60573 .44484 .5998 .43798 Mtetra
.5998 .43798 .60573 .44484 .61741 .44113 .61151 .43425 Mtetra
.61151 .43425 .61741 .44113 .62913 .43741 .62327 .43051 Mtetra
.62327 .43051 .62913 .43741 .6409 .43369 .63507 .42677 Mtetra
.662 .741 .909 r
.63507 .42677 .6409 .43369 .65273 .42996 .64693 .42304 Mtetra
.659 .742 .911 r
.64693 .42304 .65273 .42996 .6646 .42626 .65884 .41937 Mtetra
.655 .742 .914 r
.65884 .41937 .6646 .42626 .67653 .4226 .67081 .41581 Mtetra
.647 .743 .919 r
.67081 .41581 .67653 .4226 .68852 .41907 .68284 .41245 Mtetra
.633 .745 .928 r
.68284 .41245 .68852 .41907 .70057 .41573 .69495 .40945 Mtetra
.592 .741 .947 r
.69495 .40945 .70057 .41573 .7127 .41275 .70717 .40738 Mtetra
.294 .626 .961 r
.70717 .40738 .7127 .41275 .72494 .41072 .71972 .40973 Mtetra
.815 .331 .011 r
.71972 .40973 .72494 .41072 .73756 .41332 .73349 .42952 Mtetra
.865 .519 .394 r
.73349 .42952 .73756 .41332 .75151 .43355 .74985 .48381 Mtetra
.775 .475 .479 r
.74985 .48381 .75151 .43355 .7681 .48651 .76745 .54831 Mtetra
.562 .305 .483 r
.76745 .54831 .7681 .48651 .78563 .54507 .78096 .55094 Mtetra
.996 .809 .449 r
.78096 .55094 .78563 .54507 .79869 .54191 .7894 .48873 Mtetra
.782 .553 .59 r
.7894 .48873 .79869 .54191 .80691 .48125 .79794 .43269 Mtetra
.691 .496 .619 r
.79794 .43269 .80691 .48125 .81556 .4299 .809 .40928 Mtetra
.671 .556 .716 r
.809 .40928 .81556 .4299 .82672 .40888 .8214 .40161 Mtetra
.705 .763 .898 r
.8214 .40161 .82672 .40888 .83914 .40153 .83404 .3961 Mtetra
.744 .837 .921 r
.83404 .3961 .83914 .40153 .85175 .39588 .8466 .38932 Mtetra
.77 .808 .883 r
.8466 .38932 .85175 .39588 .8643 .38911 .85906 .38128 Mtetra
.773 .773 .852 r
.85906 .38128 .8643 .38911 .87676 .3813 .87147 .37252 Mtetra
.766 .748 .837 r
.87147 .37252 .87676 .3813 .88919 .37297 .88389 .36366 Mtetra
.754 .733 .833 r
.88389 .36366 .88919 .37297 .90165 .36466 .89637 .3552 Mtetra
.74 .725 .837 r
.89637 .3552 .90165 .36466 .91419 .35678 .90896 .34744 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47506 Mtetra
.4567 .47506 .46305 .48164 .47419 .47808 .46787 .47148 Mtetra
.46787 .47148 .47419 .47808 .48538 .47451 .47909 .46788 Mtetra
.47909 .46788 .48538 .47451 .49661 .47092 .49035 .46427 Mtetra
.49035 .46427 .49661 .47092 .50788 .46732 .50166 .46064 Mtetra
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .45699 Mtetra
.51301 .45699 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45643 .53586 .44966 Mtetra
.53586 .44966 .542 .45643 .55346 .45277 .54736 .44598 Mtetra
.54736 .44598 .55346 .45277 .56497 .4491 .5589 .44227 Mtetra
.5589 .44227 .56497 .4491 .57654 .44541 .57049 .43855 Mtetra
.663 .741 .908 r
.57049 .43855 .57654 .44541 .58814 .4417 .58214 .43482 Mtetra
.58214 .43482 .58814 .4417 .5998 .43798 .59383 .43107 Mtetra
.59383 .43107 .5998 .43798 .61151 .43425 .60557 .42732 Mtetra
.60557 .42732 .61151 .43425 .62327 .43051 .61736 .42356 Mtetra
.662 .741 .909 r
.61736 .42356 .62327 .43051 .63507 .42677 .6292 .41982 Mtetra
.66 .742 .911 r
.6292 .41982 .63507 .42677 .64693 .42304 .64109 .41613 Mtetra
.655 .742 .914 r
.64109 .41613 .64693 .42304 .65884 .41937 .65304 .41254 Mtetra
.648 .743 .919 r
.65304 .41254 .65884 .41937 .67081 .41581 .66506 .40916 Mtetra
.634 .744 .928 r
.66506 .40916 .67081 .41581 .68284 .41245 .67714 .40612 Mtetra
.595 .741 .946 r
.67714 .40612 .68284 .41245 .69495 .40945 .68933 .40398 Mtetra
.319 .638 .965 r
.68933 .40398 .69495 .40945 .70717 .40738 .70182 .40603 Mtetra
.807 .317 0 r
.70182 .40603 .70717 .40738 .71972 .40973 .7154 .42511 Mtetra
.869 .523 .392 r
.7154 .42511 .71972 .40973 .73349 .42952 .73145 .47996 Mtetra
.784 .483 .479 r
.73145 .47996 .73349 .42952 .74985 .48381 .74901 .54969 Mtetra
.588 .327 .488 r
.74901 .54969 .74985 .48381 .76745 .54831 .76293 .55871 Mtetra
.976 .811 .397 r
.76293 .55871 .76745 .54831 .78096 .55094 .77168 .49598 Mtetra
.787 .556 .586 r
.77168 .49598 .78096 .55094 .7894 .48873 .78019 .43551 Mtetra
.692 .492 .612 r
.78019 .43551 .7894 .48873 .79794 .43269 .79116 .40964 Mtetra
.665 .539 .701 r
.79116 .40964 .79794 .43269 .809 .40928 .80356 .40164 Mtetra
.698 .751 .893 r
.80356 .40164 .809 .40928 .8214 .40161 .81622 .39633 Mtetra
.742 .843 .926 r
.81622 .39633 .8214 .40161 .83404 .3961 .8288 .38964 Mtetra
.774 .812 .883 r
.8288 .38964 .83404 .3961 .8466 .38932 .84127 .38142 Mtetra
.779 .773 .847 r
.84127 .38142 .8466 .38932 .85906 .38128 .85367 .37227 Mtetra
.773 .746 .828 r
.85367 .37227 .85906 .38128 .87147 .37252 .86605 .36288 Mtetra
.761 .729 .823 r
.86605 .36288 .87147 .37252 .88389 .36366 .87849 .35383 Mtetra
.747 .72 .827 r
.87849 .35383 .88389 .36366 .89637 .3552 .89103 .3455 Mtetra
.732 .718 .838 r
.89103 .3455 .89637 .3552 .90896 .34744 .90371 .33806 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.43916 .47203 .44558 .47863 .4567 .47506 .45031 .46843 Mtetra
.45031 .46843 .4567 .47506 .46787 .47148 .46151 .46482 Mtetra
.46151 .46482 .46787 .47148 .47909 .46788 .47275 .4612 Mtetra
.47275 .4612 .47909 .46788 .49035 .46427 .48404 .45756 Mtetra
.48404 .45756 .49035 .46427 .50166 .46064 .49538 .4539 Mtetra
.49538 .4539 .50166 .46064 .51301 .45699 .50676 .45023 Mtetra
.50676 .45023 .51301 .45699 .52441 .45334 .5182 .44654 Mtetra
.5182 .44654 .52441 .45334 .53586 .44966 .52968 .44284 Mtetra
.52968 .44284 .53586 .44966 .54736 .44598 .5412 .43913 Mtetra
.5412 .43913 .54736 .44598 .5589 .44227 .55278 .43539 Mtetra
.55278 .43539 .5589 .44227 .57049 .43855 .56441 .43165 Mtetra
.663 .741 .908 r
.56441 .43165 .57049 .43855 .58214 .43482 .57608 .42789 Mtetra
.57608 .42789 .58214 .43482 .59383 .43107 .5878 .42412 Mtetra
.5878 .42412 .59383 .43107 .60557 .42732 .59958 .42034 Mtetra
.662 .741 .909 r
.59958 .42034 .60557 .42732 .61736 .42356 .6114 .41658 Mtetra
.66 .742 .91 r
.6114 .41658 .61736 .42356 .6292 .41982 .62328 .41287 Mtetra
.656 .742 .913 r
.62328 .41287 .6292 .41982 .64109 .41613 .63521 .40926 Mtetra
.649 .743 .918 r
.63521 .40926 .64109 .41613 .65304 .41254 .6472 .40584 Mtetra
.635 .744 .927 r
.6472 .40584 .65304 .41254 .66506 .40916 .65927 .40277 Mtetra
.598 .741 .944 r
.65927 .40277 .66506 .40916 .67714 .40612 .67143 .40054 Mtetra
.347 .651 .968 r
.67143 .40054 .67714 .40612 .68933 .40398 .68385 .40223 Mtetra
.794 .297 0 r
.68385 .40223 .68933 .40398 .70182 .40603 .69723 .42035 Mtetra
.873 .526 .389 r
.69723 .42035 .70182 .40603 .7154 .42511 .71293 .47497 Mtetra
.793 .491 .478 r
.71293 .47497 .7154 .42511 .73145 .47996 .73032 .54904 Mtetra
.611 .346 .492 r
.73032 .54904 .73145 .47996 .74901 .54969 .7446 .56481 Mtetra
.928 .796 .327 r
.7446 .56481 .74901 .54969 .76293 .55871 .75373 .50268 Mtetra
.793 .559 .584 r
.75373 .50268 .76293 .55871 .77168 .49598 .7623 .43823 Mtetra
.692 .489 .607 r
.7623 .43823 .77168 .49598 .78019 .43551 .77321 .40987 Mtetra
.66 .525 .688 r
.77321 .40987 .78019 .43551 .79116 .40964 .7856 .40152 Mtetra
.688 .735 .886 r
.7856 .40152 .79116 .40964 .80356 .40164 .79829 .3965 Mtetra
.736 .846 .932 r
.79829 .3965 .80356 .40164 .81622 .39633 .8109 .38998 Mtetra
.776 .816 .884 r
.8109 .38998 .81622 .39633 .8288 .38964 .82338 .38167 Mtetra
.784 .773 .843 r
.82338 .38167 .8288 .38964 .84127 .38142 .83578 .37219 Mtetra
.778 .743 .821 r
.83578 .37219 .84127 .38142 .85367 .37227 .84814 .36229 Mtetra
.767 .725 .813 r
.84814 .36229 .85367 .37227 .86605 .36288 .86054 .35264 Mtetra
.753 .715 .816 r
.86054 .35264 .86605 .36288 .87849 .35383 .87304 .34372 Mtetra
.738 .713 .827 r
.87304 .34372 .87849 .35383 .89103 .3455 .88566 .33575 Mtetra
.722 .715 .842 r
.88566 .33575 .89103 .3455 .90371 .33806 .89843 .32876 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.43268 .46538 .43916 .47203 .45031 .46843 .44386 .46176 Mtetra
.44386 .46176 .45031 .46843 .46151 .46482 .45509 .45812 Mtetra
.45509 .45812 .46151 .46482 .47275 .4612 .46637 .45446 Mtetra
.46637 .45446 .47275 .4612 .48404 .45756 .47769 .4508 Mtetra
.47769 .4508 .48404 .45756 .49538 .4539 .48905 .44711 Mtetra
.48905 .44711 .49538 .4539 .50676 .45023 .50047 .44341 Mtetra
.50047 .44341 .50676 .45023 .5182 .44654 .51193 .4397 Mtetra
.51193 .4397 .5182 .44654 .52968 .44284 .52344 .43597 Mtetra
.52344 .43597 .52968 .44284 .5412 .43913 .535 .43222 Mtetra
.535 .43222 .5412 .43913 .55278 .43539 .54661 .42846 Mtetra
.663 .741 .908 r
.54661 .42846 .55278 .43539 .56441 .43165 .55827 .42469 Mtetra
.55827 .42469 .56441 .43165 .57608 .42789 .56998 .4209 Mtetra
.56998 .4209 .57608 .42789 .5878 .42412 .58173 .41711 Mtetra
.662 .741 .909 r
.58173 .41711 .5878 .42412 .59958 .42034 .59354 .41334 Mtetra
.66 .741 .91 r
.59354 .41334 .59958 .42034 .6114 .41658 .6054 .4096 Mtetra
.656 .742 .913 r
.6054 .4096 .6114 .41658 .62328 .41287 .61732 .40596 Mtetra
.649 .743 .918 r
.61732 .40596 .62328 .41287 .63521 .40926 .62929 .4025 Mtetra
.636 .744 .926 r
.62929 .4025 .63521 .40926 .6472 .40584 .64133 .39938 Mtetra
.602 .742 .943 r
.64133 .39938 .6472 .40584 .65927 .40277 .65346 .39706 Mtetra
.378 .665 .97 r
.65346 .39706 .65927 .40277 .67143 .40054 .66581 .39836 Mtetra
.774 .268 0 r
.66581 .39836 .67143 .40054 .68385 .40223 .679 .4153 Mtetra
.877 .527 .384 r
.679 .4153 .68385 .40223 .69723 .42035 .6943 .46892 Mtetra
.801 .498 .476 r
.6943 .46892 .69723 .42035 .71293 .47497 .71141 .54625 Mtetra
.632 .364 .494 r
.71141 .54625 .71293 .47497 .73032 .54904 .72597 .56889 Mtetra
.84 .753 .237 r
.72597 .56889 .73032 .54904 .7446 .56481 .73556 .50853 Mtetra
.799 .563 .581 r
.73556 .50853 .7446 .56481 .75373 .50268 .74425 .4407 Mtetra
.693 .486 .602 r
.74425 .4407 .75373 .50268 .7623 .43823 .75513 .40987 Mtetra
.655 .511 .677 r
.75513 .40987 .7623 .43823 .77321 .40987 .76751 .40117 Mtetra
.677 .716 .878 r
.76751 .40117 .77321 .40987 .7856 .40152 .78024 .39649 Mtetra
.728 .849 .938 r
.78024 .39649 .7856 .40152 .79829 .3965 .79288 .39024 Mtetra
.776 .819 .886 r
.79288 .39024 .79829 .3965 .8109 .38998 .80539 .38194 Mtetra
.788 .773 .84 r
.80539 .38194 .8109 .38998 .82338 .38167 .81779 .3722 Mtetra
.783 .74 .814 r
.81779 .3722 .82338 .38167 .83578 .37219 .83014 .36185 Mtetra
.772 .72 .804 r
.83014 .36185 .83578 .37219 .84814 .36229 .84252 .35162 Mtetra
.759 .71 .806 r
.84252 .35162 .84814 .36229 .86054 .35264 .85497 .34209 Mtetra
.744 .707 .817 r
.85497 .34209 .86054 .35264 .87304 .34372 .86755 .33357 Mtetra
.728 .709 .832 r
.86755 .33357 .87304 .34372 .88566 .33575 .88027 .32611 Mtetra
.713 .714 .85 r
.88027 .32611 .88566 .33575 .89843 .32876 .89314 .31962 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46593 Mtetra
.40388 .46593 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.42616 .45868 .43268 .46538 .44386 .46176 .43737 .45503 Mtetra
.43737 .45503 .44386 .46176 .45509 .45812 .44863 .45136 Mtetra
.44863 .45136 .45509 .45812 .46637 .45446 .45993 .44768 Mtetra
.45993 .44768 .46637 .45446 .47769 .4508 .47128 .44398 Mtetra
.47128 .44398 .47769 .4508 .48905 .44711 .48268 .44027 Mtetra
.48268 .44027 .48905 .44711 .50047 .44341 .49413 .43654 Mtetra
.49413 .43654 .50047 .44341 .51193 .4397 .50562 .4328 Mtetra
.50562 .4328 .51193 .4397 .52344 .43597 .51716 .42904 Mtetra
.51716 .42904 .52344 .43597 .535 .43222 .52876 .42527 Mtetra
.663 .741 .908 r
.52876 .42527 .535 .43222 .54661 .42846 .5404 .42148 Mtetra
.5404 .42148 .54661 .42846 .55827 .42469 .55209 .41768 Mtetra
.55209 .41768 .55827 .42469 .56998 .4209 .56383 .41387 Mtetra
.662 .741 .909 r
.56383 .41387 .56998 .4209 .58173 .41711 .57562 .41008 Mtetra
.66 .741 .91 r
.57562 .41008 .58173 .41711 .59354 .41334 .58746 .40632 Mtetra
.657 .742 .912 r
.58746 .40632 .59354 .41334 .6054 .4096 .59935 .40265 Mtetra
.65 .742 .917 r
.59935 .40265 .6054 .4096 .61732 .40596 .61131 .39915 Mtetra
.638 .743 .925 r
.61131 .39915 .61732 .40596 .62929 .4025 .62333 .39597 Mtetra
.606 .742 .941 r
.62333 .39597 .62929 .4025 .64133 .39938 .63543 .39354 Mtetra
.41 .678 .971 r
.63543 .39354 .64133 .39938 .65346 .39706 .64772 .39443 Mtetra
.745 .227 0 r
.64772 .39443 .65346 .39706 .66581 .39836 .66072 .41 Mtetra
.879 .527 .378 r
.66072 .41 .66581 .39836 .679 .4153 .67559 .46189 Mtetra
.809 .504 .474 r
.67559 .46189 .679 .4153 .6943 .46892 .69232 .54128 Mtetra
.651 .379 .495 r
.69232 .54128 .6943 .46892 .71141 .54625 .70707 .57067 Mtetra
.704 .674 .128 r
.70707 .57067 .71141 .54625 .72597 .56889 .71714 .51321 Mtetra
.805 .568 .58 r
.71714 .51321 .72597 .56889 .73556 .50853 .72604 .44275 Mtetra
.695 .485 .599 r
.72604 .44275 .73556 .50853 .74425 .4407 .73692 .40955 Mtetra
.65 .5 .666 r
.73692 .40955 .74425 .4407 .75513 .40987 .7493 .40048 Mtetra
.664 .695 .869 r
.7493 .40048 .75513 .40987 .76751 .40117 .76206 .39621 Mtetra
.715 .848 .945 r
.76206 .39621 .76751 .40117 .78024 .39649 .77474 .39032 Mtetra
.774 .822 .89 r
.77474 .39032 .78024 .39649 .79288 .39024 .78728 .38213 Mtetra
.789 .772 .838 r
.78728 .38213 .79288 .39024 .80539 .38194 .7997 .37224 Mtetra
.786 .737 .808 r
.7997 .37224 .80539 .38194 .81779 .3722 .81205 .36149 Mtetra
.776 .715 .795 r
.81205 .36149 .81779 .3722 .83014 .36185 .82441 .35072 Mtetra
.763 .704 .796 r
.82441 .35072 .83014 .36185 .84252 .35162 .83683 .3406 Mtetra
.749 .701 .806 r
.83683 .3406 .84252 .35162 .85497 .34209 .84937 .3315 Mtetra
.734 .703 .822 r
.84937 .3315 .85497 .34209 .86755 .33357 .86205 .32356 Mtetra
.718 .709 .841 r
.86205 .32356 .86755 .33357 .88027 .32611 .87488 .31668 Mtetra
.703 .717 .86 r
.87488 .31668 .88027 .32611 .89314 .31962 .88785 .31069 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46593 .39725 .45924 Mtetra
.39725 .45924 .40388 .46593 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
.43083 .44825 .43737 .45503 .44863 .45136 .44211 .44455 Mtetra
.44211 .44455 .44863 .45136 .45993 .44768 .45345 .44084 Mtetra
.45345 .44084 .45993 .44768 .47128 .44398 .46483 .43712 Mtetra
.46483 .43712 .47128 .44398 .48268 .44027 .47626 .43338 Mtetra
.47626 .43338 .48268 .44027 .49413 .43654 .48774 .42962 Mtetra
.48774 .42962 .49413 .43654 .50562 .4328 .49926 .42585 Mtetra
.49926 .42585 .50562 .4328 .51716 .42904 .51084 .42206 Mtetra
.663 .741 .908 r
.51084 .42206 .51716 .42904 .52876 .42527 .52246 .41826 Mtetra
.52246 .41826 .52876 .42527 .5404 .42148 .53413 .41444 Mtetra
.53413 .41444 .5404 .42148 .55209 .41768 .54585 .41062 Mtetra
.662 .741 .909 r
.54585 .41062 .55209 .41768 .56383 .41387 .55763 .40681 Mtetra
.661 .741 .91 r
.55763 .40681 .56383 .41387 .57562 .41008 .56945 .40302 Mtetra
.658 .742 .912 r
.56945 .40302 .57562 .41008 .58746 .40632 .58133 .39932 Mtetra
.651 .742 .916 r
.58133 .39932 .58746 .40632 .59935 .40265 .59326 .39578 Mtetra
.64 .743 .924 r
.59326 .39578 .59935 .40265 .61131 .39915 .60526 .39254 Mtetra
.611 .742 .938 r
.60526 .39254 .61131 .39915 .62333 .39597 .61733 .38999 Mtetra
.441 .69 .971 r
.61733 .38999 .62333 .39597 .63543 .39354 .62956 .39045 Mtetra
.702 .172 0 r
.62956 .39045 .63543 .39354 .64772 .39443 .64238 .40453 Mtetra
.882 .526 .369 r
.64238 .40453 .64772 .39443 .66072 .41 .65681 .45402 Mtetra
.816 .51 .471 r
.65681 .45402 .66072 .41 .67559 .46189 .67307 .53422 Mtetra
.669 .393 .495 r
.67307 .53422 .67559 .46189 .69232 .54128 .68791 .56994 Mtetra
0 0 0 r
.68791 .56994 .69232 .54128 .70707 .57067 .69848 .51645 Mtetra
.811 .574 .579 r
.69848 .51645 .70707 .57067 .71714 .51321 .70767 .44422 Mtetra
.696 .484 .596 r
.70767 .44422 .71714 .51321 .72604 .44275 .71859 .40882 Mtetra
.646 .49 .657 r
.71859 .40882 .72604 .44275 .73692 .40955 .73097 .39937 Mtetra
.65 .672 .858 r
.73097 .39937 .73692 .40955 .7493 .40048 .74375 .39555 Mtetra
.698 .845 .953 r
.74375 .39555 .7493 .40048 .76206 .39621 .75647 .39011 Mtetra
.769 .824 .895 r
.75647 .39011 .76206 .39621 .77474 .39032 .76905 .38215 Mtetra
.789 .771 .837 r
.76905 .38215 .77474 .39032 .78728 .38213 .78149 .3722 Mtetra
.788 .733 .802 r
.78149 .3722 .78728 .38213 .7997 .37224 .79385 .36115 Mtetra
.779 .71 .788 r
.79385 .36115 .7997 .37224 .81205 .36149 .8062 .3499 Mtetra
.767 .698 .787 r
.8062 .3499 .81205 .36149 .82441 .35072 .8186 .3392 Mtetra
.753 .695 .796 r
.8186 .3392 .82441 .35072 .83683 .3406 .83111 .32954 Mtetra
.738 .697 .812 r
.83111 .32954 .83683 .3406 .84937 .3315 .84375 .32109 Mtetra
.723 .704 .832 r
.84375 .32109 .84937 .3315 .86205 .32356 .85654 .31381 Mtetra
.707 .712 .852 r
.85654 .31381 .86205 .32356 .87488 .31668 .86948 .30751 Mtetra
.693 .72 .87 r
.86948 .30751 .87488 .31668 .88785 .31069 .88254 .30194 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44881 Mtetra
.40174 .44881 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.41296 .44512 .41959 .45193 .43083 .44825 .42423 .44141 Mtetra
.42423 .44141 .43083 .44825 .44211 .44455 .43555 .43769 Mtetra
.43555 .43769 .44211 .44455 .45345 .44084 .44691 .43395 Mtetra
.44691 .43395 .45345 .44084 .46483 .43712 .45833 .4302 Mtetra
.45833 .4302 .46483 .43712 .47626 .43338 .46979 .42643 Mtetra
.46979 .42643 .47626 .43338 .48774 .42962 .48129 .42264 Mtetra
.48129 .42264 .48774 .42962 .49926 .42585 .49285 .41884 Mtetra
.663 .741 .908 r
.49285 .41884 .49926 .42585 .51084 .42206 .50446 .41502 Mtetra
.50446 .41502 .51084 .42206 .52246 .41826 .51611 .4112 Mtetra
.51611 .4112 .52246 .41826 .53413 .41444 .52782 .40736 Mtetra
.662 .741 .909 r
.52782 .40736 .53413 .41444 .54585 .41062 .53957 .40353 Mtetra
.661 .741 .91 r
.53957 .40353 .54585 .41062 .55763 .40681 .55138 .39972 Mtetra
.658 .742 .911 r
.55138 .39972 .55763 .40681 .56945 .40302 .56324 .39598 Mtetra
.653 .742 .915 r
.56324 .39598 .56945 .40302 .58133 .39932 .57515 .39239 Mtetra
.642 .743 .922 r
.57515 .39239 .58133 .39932 .59326 .39578 .58712 .38908 Mtetra
.616 .742 .936 r
.58712 .38908 .59326 .39578 .60526 .39254 .59917 .38641 Mtetra
.47 .701 .969 r
.59917 .38641 .60526 .39254 .61733 .38999 .61135 .38643 Mtetra
.641 .099 0 r
.61135 .38643 .61733 .38999 .62956 .39045 .624 .39894 Mtetra
.884 .523 .357 r
.624 .39894 .62956 .39045 .64238 .40453 .638 .44548 Mtetra
.823 .514 .468 r
.638 .44548 .64238 .40453 .65681 .45402 .65373 .52519 Mtetra
.685 .406 .494 r
.65373 .52519 .65681 .45402 .67307 .53422 .66854 .56659 Mtetra
0 0 .096 r
.66854 .56659 .67307 .53422 .68791 .56994 .6796 .51801 Mtetra
.818 .58 .579 r
.6796 .51801 .68791 .56994 .69848 .51645 .68914 .44496 Mtetra
.698 .483 .593 r
.68914 .44496 .69848 .51645 .70767 .44422 .70013 .4076 Mtetra
.643 .482 .65 r
.70013 .4076 .70767 .44422 .71859 .40882 .71251 .39776 Mtetra
.636 .649 .846 r
.71251 .39776 .71859 .40882 .73097 .39937 .72531 .39441 Mtetra
.678 .839 .96 r
.72531 .39441 .73097 .39937 .74375 .39555 .73806 .38952 Mtetra
.761 .824 .902 r
.73806 .38952 .74375 .39555 .75647 .39011 .75068 .38189 Mtetra
.787 .77 .837 r
.75068 .38189 .75647 .39011 .76905 .38215 .76316 .372 Mtetra
.788 .73 .799 r
.76316 .372 .76905 .38215 .78149 .3722 .77555 .36074 Mtetra
.78 .705 .781 r
.77555 .36074 .78149 .3722 .79385 .36115 .7879 .34909 Mtetra
.769 .692 .778 r
.7879 .34909 .79385 .36115 .8062 .3499 .80029 .33787 Mtetra
.756 .688 .786 r
.80029 .33787 .8062 .3499 .8186 .3392 .81277 .32765 Mtetra
.742 .691 .802 r
.81277 .32765 .8186 .3392 .83111 .32954 .82538 .31869 Mtetra
.727 .698 .822 r
.82538 .31869 .83111 .32954 .84375 .32109 .83814 .31099 Mtetra
.712 .707 .844 r
.83814 .31099 .84375 .32109 .85654 .31381 .85104 .30437 Mtetra
.697 .716 .864 r
.85104 .30437 .85654 .31381 .86948 .30751 .86407 .29857 Mtetra
.685 .725 .88 r
.86407 .29857 .86948 .30751 .88254 .30194 .87722 .29336 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44881 .39504 .44199 Mtetra
.39504 .44199 .40174 .44881 .41296 .44512 .40629 .43827 Mtetra
.40629 .43827 .41296 .44512 .42423 .44141 .41759 .43453 Mtetra
.41759 .43453 .42423 .44141 .43555 .43769 .42893 .43078 Mtetra
.42893 .43078 .43555 .43769 .44691 .43395 .44033 .42701 Mtetra
.44033 .42701 .44691 .43395 .45833 .4302 .45177 .42323 Mtetra
.45177 .42323 .45833 .4302 .46979 .42643 .46326 .41943 Mtetra
.46326 .41943 .46979 .42643 .48129 .42264 .4748 .41561 Mtetra
.663 .741 .908 r
.4748 .41561 .48129 .42264 .49285 .41884 .48639 .41178 Mtetra
.48639 .41178 .49285 .41884 .50446 .41502 .49803 .40794 Mtetra
.49803 .40794 .50446 .41502 .51611 .4112 .50972 .40408 Mtetra
.663 .741 .909 r
.50972 .40408 .51611 .4112 .52782 .40736 .52145 .40023 Mtetra
.661 .741 .909 r
.52145 .40023 .52782 .40736 .53957 .40353 .53324 .3964 Mtetra
.659 .742 .911 r
.53324 .3964 .53957 .40353 .55138 .39972 .54508 .39263 Mtetra
.654 .742 .914 r
.54508 .39263 .55138 .39972 .56324 .39598 .55698 .389 Mtetra
.644 .743 .921 r
.55698 .389 .56324 .39598 .57515 .39239 .56893 .38562 Mtetra
.621 .742 .933 r
.56893 .38562 .57515 .39239 .58712 .38908 .58094 .38282 Mtetra
.498 .71 .965 r
.58094 .38282 .58712 .38908 .59917 .38641 .59307 .3824 Mtetra
.555 .007 0 r
.59307 .3824 .59917 .38641 .61135 .38643 .60557 .39328 Mtetra
.885 .518 .342 r
.60557 .39328 .61135 .38643 .624 .39894 .61916 .43642 Mtetra
.829 .518 .463 r
.61916 .43642 .624 .39894 .638 .44548 .63432 .51442 Mtetra
.699 .417 .493 r
.63432 .51442 .638 .44548 .65373 .52519 .649 .56061 Mtetra
0 0 .186 r
.649 .56061 .65373 .52519 .66854 .56659 .66052 .51768 Mtetra
.825 .588 .58 r
.66052 .51768 .66854 .56659 .6796 .51801 .67045 .44483 Mtetra
.7 .484 .592 r
.67045 .44483 .6796 .51801 .68914 .44496 .68155 .40582 Mtetra
.64 .475 .643 r
.68155 .40582 .68914 .44496 .70013 .4076 .69393 .39559 Mtetra
.622 .626 .833 r
.69393 .39559 .70013 .4076 .71251 .39776 .70674 .39272 Mtetra
.654 .829 .967 r
.70674 .39272 .71251 .39776 .72531 .39441 .71953 .38843 Mtetra
.75 .824 .909 r
.71953 .38843 .72531 .39441 .73806 .38952 .73219 .38125 Mtetra
.784 .768 .839 r
.73219 .38125 .73806 .38952 .75068 .38189 .74471 .37154 Mtetra
.787 .726 .796 r
.74471 .37154 .75068 .38189 .76316 .372 .75713 .36019 Mtetra
.78 .701 .775 r
.75713 .36019 .76316 .372 .77555 .36074 .76949 .34822 Mtetra
.771 .687 .771 r
.76949 .34822 .77555 .36074 .7879 .34909 .78188 .33654 Mtetra
.759 .682 .777 r
.78188 .33654 .7879 .34909 .80029 .33787 .79434 .3258 Mtetra
.745 .684 .792 r
.79434 .3258 .80029 .33787 .81277 .32765 .80693 .31635 Mtetra
.731 .691 .813 r
.80693 .31635 .81277 .32765 .82538 .31869 .81966 .30822 Mtetra
.716 .702 .836 r
.81966 .30822 .82538 .31869 .83814 .31099 .83253 .30126 Mtetra
.701 .712 .857 r
.83253 .30126 .83814 .31099 .85104 .30437 .84553 .29523 Mtetra
.688 .722 .875 r
.84553 .29523 .85104 .30437 .86407 .29857 .85865 .28985 Mtetra
.678 .729 .888 r
.85865 .28985 .86407 .29857 .87722 .29336 .87187 .28489 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .4351 Mtetra
.38828 .4351 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.39956 .43136 .40629 .43827 .41759 .43453 .41089 .42759 Mtetra
.41089 .42759 .41759 .43453 .42893 .43078 .42227 .42381 Mtetra
.42227 .42381 .42893 .43078 .44033 .42701 .43369 .42001 Mtetra
.43369 .42001 .44033 .42701 .45177 .42323 .44517 .4162 Mtetra
.44517 .4162 .45177 .42323 .46326 .41943 .45669 .41237 Mtetra
.45669 .41237 .46326 .41943 .4748 .41561 .46826 .40852 Mtetra
.663 .741 .908 r
.46826 .40852 .4748 .41561 .48639 .41178 .47988 .40467 Mtetra
.47988 .40467 .48639 .41178 .49803 .40794 .49155 .4008 Mtetra
.49155 .4008 .49803 .40794 .50972 .40408 .50327 .39693 Mtetra
.662 .741 .909 r
.50327 .39693 .50972 .40408 .52145 .40023 .51504 .39307 Mtetra
.659 .741 .911 r
.51504 .39307 .52145 .40023 .53324 .3964 .52686 .38927 Mtetra
.655 .742 .914 r
.52686 .38927 .53324 .3964 .54508 .39263 .53873 .38559 Mtetra
.646 .742 .919 r
.53873 .38559 .54508 .39263 .55698 .389 .55066 .38214 Mtetra
.626 .742 .931 r
.55066 .38214 .55698 .389 .56893 .38562 .56266 .37921 Mtetra
.523 .717 .961 r
.56266 .37921 .56893 .38562 .58094 .38282 .57474 .37837 Mtetra
.44 0 0 r
.57474 .37837 .58094 .38282 .59307 .3824 .5871 .38763 Mtetra
.885 .51 .323 r
.5871 .38763 .59307 .3824 .60557 .39328 .60031 .42702 Mtetra
.835 .521 .458 r
.60031 .42702 .60557 .39328 .61916 .43642 .61488 .50218 Mtetra
.713 .427 .49 r
.61488 .50218 .61916 .43642 .63432 .51442 .62933 .55211 Mtetra
.005 0 .254 r
.62933 .55211 .63432 .51442 .649 .56061 .64125 .51535 Mtetra
.833 .596 .581 r
.64125 .51535 .649 .56061 .66052 .51768 .65162 .44372 Mtetra
.702 .485 .591 r
.65162 .44372 .66052 .51768 .67045 .44483 .66285 .40344 Mtetra
.638 .469 .638 r
.66285 .40344 .67045 .44483 .68155 .40582 .67524 .39281 Mtetra
.609 .604 .821 r
.67524 .39281 .68155 .40582 .69393 .39559 .68805 .39041 Mtetra
.627 .815 .972 r
.68805 .39041 .69393 .39559 .70674 .39272 .70086 .38677 Mtetra
.736 .822 .918 r
.70086 .38677 .70674 .39272 .71953 .38843 .71356 .38011 Mtetra
.778 .766 .842 r
.71356 .38011 .71953 .38843 .73219 .38125 .72613 .37071 Mtetra
.784 .723 .795 r
.72613 .37071 .73219 .38125 .74471 .37154 .73858 .3594 Mtetra
.78 .696 .771 r
.73858 .3594 .74471 .37154 .75713 .36019 .75097 .34722 Mtetra
.771 .681 .764 r
.75097 .34722 .75713 .36019 .76949 .34822 .76337 .33516 Mtetra
.76 .676 .769 r
.76337 .33516 .76949 .34822 .78188 .33654 .77583 .32396 Mtetra
.748 .678 .784 r
.77583 .32396 .78188 .33654 .79434 .3258 .7884 .31403 Mtetra
.734 .685 .804 r
.7884 .31403 .79434 .3258 .80693 .31635 .8011 .30548 Mtetra
.719 .696 .827 r
.8011 .30548 .80693 .31635 .81966 .30822 .81394 .29819 Mtetra
.704 .708 .85 r
.81394 .29819 .81966 .30822 .83253 .30126 .82692 .2919 Mtetra
.691 .718 .87 r
.82692 .2919 .83253 .30126 .84553 .29523 .84001 .28635 Mtetra
.681 .727 .885 r
.84001 .28635 .84553 .29523 .85865 .28985 .85321 .28127 Mtetra
.673 .733 .895 r
.85321 .28127 .85865 .28985 .87187 .28489 .8665 .27649 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43193 Mtetra
.37021 .43193 .37705 .43884 .38828 .4351 .38147 .42817 Mtetra
.38147 .42817 .38828 .4351 .39956 .43136 .39278 .42439 Mtetra
.39278 .42439 .39956 .43136 .41089 .42759 .40414 .4206 Mtetra
.40414 .4206 .41089 .42759 .42227 .42381 .41555 .41679 Mtetra
.41555 .41679 .42227 .42381 .43369 .42001 .427 .41296 Mtetra
.427 .41296 .43369 .42001 .44517 .4162 .43851 .40912 Mtetra
.43851 .40912 .44517 .4162 .45669 .41237 .45006 .40526 Mtetra
.663 .741 .908 r
.45006 .40526 .45669 .41237 .46826 .40852 .46166 .40138 Mtetra
.46166 .40138 .46826 .40852 .47988 .40467 .47332 .3975 Mtetra
.47332 .3975 .47988 .40467 .49155 .4008 .48502 .39361 Mtetra
.662 .741 .909 r
.48502 .39361 .49155 .4008 .50327 .39693 .49677 .38973 Mtetra
.66 .741 .91 r
.49677 .38973 .50327 .39693 .51504 .39307 .50857 .3859 Mtetra
.656 .742 .913 r
.50857 .3859 .51504 .39307 .52686 .38927 .52043 .38217 Mtetra
.648 .742 .918 r
.52043 .38217 .52686 .38927 .53873 .38559 .53234 .37865 Mtetra
.63 .742 .928 r
.53234 .37865 .53873 .38559 .55066 .38214 .5443 .37559 Mtetra
.545 .723 .956 r
.5443 .37559 .55066 .38214 .56266 .37921 .55635 .37435 Mtetra
0 .231 .677 r
.55635 .37435 .56266 .37921 .57474 .37837 .56858 .38201 Mtetra
.884 .498 .298 r
.56858 .38201 .57474 .37837 .5871 .38763 .58145 .41745 Mtetra
.841 .524 .452 r
.58145 .41745 .5871 .38763 .60031 .42702 .59544 .48879 Mtetra
.726 .436 .487 r
.59544 .48879 .60031 .42702 .61488 .50218 .60959 .54129 Mtetra
.136 0 .303 r
.60959 .54129 .61488 .50218 .62933 .55211 .62184 .51097 Mtetra
.84 .605 .583 r
.62184 .51097 .62933 .55211 .64125 .51535 .63265 .44154 Mtetra
.705 .487 .59 r
.63265 .44154 .64125 .51535 .65162 .44372 .64404 .40041 Mtetra
.637 .465 .634 r
.64404 .40041 .65162 .44372 .66285 .40344 .65644 .3894 Mtetra
.598 .583 .808 r
.65644 .3894 .66285 .40344 .67524 .39281 .66924 .38744 Mtetra
.599 .798 .976 r
.66924 .38744 .67524 .39281 .68805 .39041 .68207 .38446 Mtetra
.718 .818 .927 r
.68207 .38446 .68805 .39041 .70086 .38677 .6948 .37841 Mtetra
.77 .763 .847 r
.6948 .37841 .70086 .38677 .71356 .38011 .70741 .36943 Mtetra
.781 .719 .795 r
.70741 .36943 .71356 .38011 .72613 .37071 .71991 .35828 Mtetra
.778 .692 .768 r
.71991 .35828 .72613 .37071 .73858 .3594 .73234 .34602 Mtetra
.77 .676 .759 r
.73234 .34602 .73858 .3594 .75097 .34722 .74476 .33368 Mtetra
.761 .671 .763 r
.74476 .33368 .75097 .34722 .76337 .33516 .75722 .32208 Mtetra
.749 .672 .776 r
.75722 .32208 .76337 .33516 .77583 .32396 .76978 .31172 Mtetra
.736 .679 .795 r
.76978 .31172 .77583 .32396 .7884 .31403 .78246 .30276 Mtetra
.722 .69 .819 r
.78246 .30276 .7884 .31403 .8011 .30548 .79528 .29513 Mtetra
.708 .703 .843 r
.79528 .29513 .8011 .30548 .81394 .29819 .80823 .28858 Mtetra
.694 .715 .865 r
.80823 .28858 .81394 .29819 .82692 .2919 .8213 .28285 Mtetra
.683 .724 .881 r
.8213 .28285 .82692 .2919 .84001 .28635 .83448 .27765 Mtetra
.675 .731 .893 r
.83448 .27765 .84001 .28635 .85321 .28127 .84774 .27279 Mtetra
.669 .736 .9 r
.84774 .27279 .85321 .28127 .8665 .27649 .86109 .26812 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43193 .36332 .42497 Mtetra
.36332 .42497 .37021 .43193 .38147 .42817 .37461 .42118 Mtetra
.37461 .42118 .38147 .42817 .39278 .42439 .38595 .41737 Mtetra
.38595 .41737 .39278 .42439 .40414 .4206 .39734 .41355 Mtetra
.39734 .41355 .40414 .4206 .41555 .41679 .40878 .40971 Mtetra
.40878 .40971 .41555 .41679 .427 .41296 .42026 .40585 Mtetra
.42026 .40585 .427 .41296 .43851 .40912 .4318 .40198 Mtetra
.663 .741 .908 r
.4318 .40198 .43851 .40912 .45006 .40526 .44338 .39809 Mtetra
.44338 .39809 .45006 .40526 .46166 .40138 .45502 .39419 Mtetra
.45502 .39419 .46166 .40138 .47332 .3975 .4667 .39028 Mtetra
.662 .741 .909 r
.4667 .39028 .47332 .3975 .48502 .39361 .47843 .38639 Mtetra
.66 .741 .91 r
.47843 .38639 .48502 .39361 .49677 .38973 .49022 .38252 Mtetra
.657 .742 .912 r
.49022 .38252 .49677 .38973 .50857 .3859 .50205 .37875 Mtetra
.65 .742 .917 r
.50205 .37875 .50857 .3859 .52043 .38217 .51394 .37516 Mtetra
.635 .742 .926 r
.51394 .37516 .52043 .38217 .53234 .37865 .52588 .37197 Mtetra
.565 .728 .951 r
.52588 .37197 .53234 .37865 .5443 .37559 .53789 .37034 Mtetra
0 .356 .792 r
.53789 .37034 .5443 .37559 .55635 .37435 .55003 .37648 Mtetra
.881 .481 .264 r
.55003 .37648 .55635 .37435 .56858 .38201 .5626 .40788 Mtetra
.846 .525 .444 r
.5626 .40788 .56858 .38201 .58145 .41745 .57603 .47457 Mtetra
.738 .444 .484 r
.57603 .47457 .58145 .41745 .59544 .48879 .58983 .52844 Mtetra
.241 .002 .337 r
.58983 .52844 .59544 .48879 .60959 .54129 .60232 .50458 Mtetra
.848 .616 .586 r
.60232 .50458 .60959 .54129 .62184 .51097 .61356 .43825 Mtetra
.707 .489 .59 r
.61356 .43825 .62184 .51097 .63265 .44154 .62514 .39674 Mtetra
.636 .462 .63 r
.62514 .39674 .63265 .44154 .64404 .40041 .63754 .38536 Mtetra
.588 .565 .796 r
.63754 .38536 .64404 .40041 .65644 .3894 .65033 .38378 Mtetra
.57 .778 .977 r
.65033 .38378 .65644 .3894 .66924 .38744 .66316 .38147 Mtetra
.697 .812 .936 r
.66316 .38147 .66924 .38744 .68207 .38446 .67592 .37608 Mtetra
.76 .761 .853 r
.67592 .37608 .68207 .38446 .6948 .37841 .68858 .36761 Mtetra
.775 .716 .797 r
.68858 .36761 .6948 .37841 .70741 .36943 .70112 .35675 Mtetra
.775 .688 .767 r
.70112 .35675 .70741 .36943 .71991 .35828 .71359 .34453 Mtetra
.769 .672 .755 r
.71359 .34453 .71991 .35828 .73234 .34602 .72604 .33202 Mtetra
.76 .665 .757 r
.72604 .33202 .73234 .34602 .74476 .33368 .73851 .32011 Mtetra
.75 .667 .769 r
.73851 .32011 .74476 .33368 .75722 .32208 .75107 .30937 Mtetra
.738 .674 .788 r
.75107 .30937 .75722 .32208 .76978 .31172 .76374 .30004 Mtetra
.725 .685 .812 r
.76374 .30004 .76978 .31172 .78246 .30276 .77654 .29208 Mtetra
.71 .698 .836 r
.77654 .29208 .78246 .30276 .79528 .29513 .78947 .28528 Mtetra
.697 .711 .859 r
.78947 .28528 .79528 .29513 .80823 .28858 .80252 .27935 Mtetra
.685 .721 .877 r
.80252 .27935 .80823 .28858 .8213 .28285 .81567 .27403 Mtetra
.676 .729 .89 r
.81567 .27403 .8213 .28285 .83448 .27765 .82892 .26909 Mtetra
.67 .735 .898 r
.82892 .26909 .83448 .27765 .84774 .27279 .84224 .26436 Mtetra
.667 .738 .903 r
.84224 .26436 .84774 .27279 .86109 .26812 .85564 .25973 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42497 .35637 .41796 Mtetra
.35637 .41796 .36332 .42497 .37461 .42118 .3677 .41414 Mtetra
.3677 .41414 .37461 .42118 .38595 .41737 .37907 .4103 Mtetra
.37907 .4103 .38595 .41737 .39734 .41355 .39048 .40644 Mtetra
.39048 .40644 .39734 .41355 .40878 .40971 .40195 .40257 Mtetra
.40195 .40257 .40878 .40971 .42026 .40585 .41347 .39869 Mtetra
.663 .741 .908 r
.41347 .39869 .42026 .40585 .4318 .40198 .42503 .39478 Mtetra
.42503 .39478 .4318 .40198 .44338 .39809 .43665 .39087 Mtetra
.43665 .39087 .44338 .39809 .45502 .39419 .44832 .38694 Mtetra
.662 .741 .909 r
.44832 .38694 .45502 .39419 .4667 .39028 .46003 .38302 Mtetra
.661 .741 .91 r
.46003 .38302 .4667 .39028 .47843 .38639 .4718 .37913 Mtetra
.658 .742 .912 r
.4718 .37913 .47843 .38639 .49022 .38252 .48361 .37532 Mtetra
.652 .742 .916 r
.48361 .37532 .49022 .38252 .50205 .37875 .49548 .37166 Mtetra
.639 .742 .923 r
.49548 .37166 .50205 .37875 .51394 .37516 .5074 .36835 Mtetra
.582 .731 .945 r
.5074 .36835 .51394 .37516 .52588 .37197 .51938 .36636 Mtetra
.029 .467 .877 r
.51938 .36636 .52588 .37197 .53789 .37034 .53143 .37107 Mtetra
.874 .457 .22 r
.53143 .37107 .53789 .37034 .55003 .37648 .54374 .39843 Mtetra
.851 .524 .435 r
.54374 .39843 .55003 .37648 .5626 .40788 .55667 .45986 Mtetra
.749 .451 .479 r
.55667 .45986 .5626 .40788 .57603 .47457 .57007 .5139 Mtetra
.325 .066 .359 r
.57007 .5139 .57603 .47457 .58983 .52844 .58272 .49628 Mtetra
.856 .627 .591 r
.58272 .49628 .58983 .52844 .60232 .50458 .59437 .43384 Mtetra
.71 .492 .591 r
.59437 .43384 .60232 .50458 .61356 .43825 .60616 .39242 Mtetra
.636 .46 .628 r
.60616 .39242 .61356 .43825 .62514 .39674 .61857 .38071 Mtetra
.58 .55 .785 r
.61857 .38071 .62514 .39674 .63754 .38536 .63133 .37944 Mtetra
.542 .756 .976 r
.63133 .37944 .63754 .38536 .65033 .38378 .64415 .37776 Mtetra
.674 .804 .945 r
.64415 .37776 .65033 .38378 .66316 .38147 .65693 .37306 Mtetra
.748 .757 .86 r
.65693 .37306 .66316 .38147 .67592 .37608 .66962 .36518 Mtetra
.769 .713 .8 r
.66962 .36518 .67592 .37608 .68858 .36761 .68221 .35474 Mtetra
.771 .684 .767 r
.68221 .35474 .68858 .36761 .70112 .35675 .69473 .34269 Mtetra
.767 .668 .753 r
.69473 .34269 .70112 .35675 .71359 .34453 .70721 .33013 Mtetra
.759 .661 .753 r
.70721 .33013 .71359 .34453 .72604 .33202 .7197 .318 Mtetra
.75 .661 .763 r
.7197 .318 .72604 .33202 .73851 .32011 .73227 .30695 Mtetra
.739 .668 .781 r
.73227 .30695 .73851 .32011 .75107 .30937 .74493 .29729 Mtetra
.727 .68 .804 r
.74493 .29729 .75107 .30937 .76374 .30004 .75772 .28902 Mtetra
.713 .693 .83 r
.75772 .28902 .76374 .30004 .77654 .29208 .77063 .28197 Mtetra
.699 .707 .854 r
.77063 .28197 .77654 .29208 .78947 .28528 .78366 .27586 Mtetra
.687 .719 .873 r
.78366 .27586 .78947 .28528 .80252 .27935 .79679 .27041 Mtetra
.678 .728 .887 r
.79679 .27041 .80252 .27935 .81567 .27403 .81002 .26538 Mtetra
.671 .734 .897 r
.81002 .26538 .81567 .27403 .82892 .26909 .82332 .26059 Mtetra
.667 .737 .902 r
.82332 .26059 .82892 .26909 .84224 .26436 .8367 .25593 Mtetra
.665 .739 .905 r
.8367 .25593 .84224 .26436 .85564 .25973 .85016 .25132 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41473 Mtetra
.33807 .41473 .3451 .42177 .35637 .41796 .34937 .41089 Mtetra
.34937 .41089 .35637 .41796 .3677 .41414 .36072 .40704 Mtetra
.36072 .40704 .3677 .41414 .37907 .4103 .37213 .40317 Mtetra
.37213 .40317 .37907 .4103 .39048 .40644 .38357 .39929 Mtetra
.38357 .39929 .39048 .40644 .40195 .40257 .39507 .39538 Mtetra
.663 .741 .908 r
.39507 .39538 .40195 .40257 .41347 .39869 .40662 .39147 Mtetra
.40662 .39147 .41347 .39869 .42503 .39478 .41822 .38754 Mtetra
.41822 .38754 .42503 .39478 .43665 .39087 .42986 .38359 Mtetra
.42986 .38359 .43665 .39087 .44832 .38694 .44156 .37965 Mtetra
.661 .741 .909 r
.44156 .37965 .44832 .38694 .46003 .38302 .45331 .37573 Mtetra
.659 .741 .911 r
.45331 .37573 .46003 .38302 .4718 .37913 .46511 .37188 Mtetra
.654 .742 .914 r
.46511 .37188 .4718 .37913 .48361 .37532 .47695 .36815 Mtetra
.642 .742 .921 r
.47695 .36815 .48361 .37532 .49548 .37166 .48885 .36473 Mtetra
.596 .734 .94 r
.48885 .36473 .49548 .37166 .5074 .36835 .5008 .36242 Mtetra
.174 .553 .931 r
.5008 .36242 .5074 .36835 .51938 .36636 .51279 .3658 Mtetra
.86 .421 .16 r
.51279 .3658 .51938 .36636 .53143 .37107 .52489 .38924 Mtetra
.855 .522 .422 r
.52489 .38924 .53143 .37107 .54374 .39843 .53737 .44498 Mtetra
.759 .457 .473 r
.53737 .44498 .54374 .39843 .55667 .45986 .55036 .49807 Mtetra
.392 .118 .373 r
.55036 .49807 .55667 .45986 .57007 .5139 .56309 .48627 Mtetra
.865 .641 .597 r
.56309 .48627 .57007 .5139 .58272 .49628 .57511 .42834 Mtetra
.713 .495 .592 r
.57511 .42834 .58272 .49628 .59437 .43384 .58709 .38748 Mtetra
.637 .46 .627 r
.58709 .38748 .59437 .43384 .60616 .39242 .59952 .3755 Mtetra
.574 .537 .776 r
.59952 .3755 .60616 .39242 .61857 .38071 .61224 .37444 Mtetra
.517 .734 .973 r
.61224 .37444 .61857 .38071 .63133 .37944 .62505 .37334 Mtetra
.648 .793 .952 r
.62505 .37334 .63133 .37944 .64415 .37776 .63783 .36933 Mtetra
.735 .753 .867 r
.63783 .36933 .64415 .37776 .65693 .37306 .65055 .36212 Mtetra
.761 .71 .804 r
.65055 .36212 .65693 .37306 .66962 .36518 .66318 .35218 Mtetra
.766 .681 .768 r
.66318 .35218 .66962 .36518 .68221 .35474 .67575 .34043 Mtetra
.764 .664 .752 r
.67575 .34043 .68221 .35474 .69473 .34269 .68827 .32795 Mtetra
.758 .657 .75 r
.68827 .32795 .69473 .34269 .70721 .33013 .7008 .31571 Mtetra
.75 .657 .758 r
.7008 .31571 .70721 .33013 .7197 .318 .71337 .30443 Mtetra
.74 .663 .775 r
.71337 .30443 .7197 .318 .73227 .30695 .72604 .29449 Mtetra
.728 .675 .798 r
.72604 .29449 .73227 .30695 .74493 .29729 .73882 .28595 Mtetra
.715 .689 .824 r
.73882 .28595 .74493 .29729 .75772 .28902 .75171 .27866 Mtetra
.701 .703 .849 r
.75171 .27866 .75772 .28902 .77063 .28197 .76472 .27237 Mtetra
.689 .716 .869 r
.76472 .27237 .77063 .28197 .78366 .27586 .77784 .26679 Mtetra
.679 .726 .885 r
.77784 .26679 .78366 .27586 .79679 .27041 .79104 .26167 Mtetra
.672 .733 .895 r
.79104 .26167 .79679 .27041 .81002 .26538 .80433 .25682 Mtetra
.668 .737 .901 r
.80433 .25682 .81002 .26538 .82332 .26059 .81769 .25212 Mtetra
.666 .739 .905 r
.81769 .25212 .82332 .26059 .8367 .25593 .83112 .24748 Mtetra
.665 .741 .907 r
.83112 .24748 .8367 .25593 .85016 .25132 .84462 .24286 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42293 Mtetra
.28613 .42293 .29333 .42991 .30445 .42614 .29727 .41913 Mtetra
.29727 .41913 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41148 Mtetra
.3197 .41148 .32681 .41855 .33807 .41473 .33099 .40763 Mtetra
.33099 .40763 .33807 .41473 .34937 .41089 .34232 .40377 Mtetra
.34232 .40377 .34937 .41089 .36072 .40704 .3537 .39988 Mtetra
.3537 .39988 .36072 .40704 .37213 .40317 .36513 .39598 Mtetra
.36513 .39598 .37213 .40317 .38357 .39929 .37661 .39207 Mtetra
.37661 .39207 .38357 .39929 .39507 .39538 .38814 .38814 Mtetra
.663 .741 .908 r
.38814 .38814 .39507 .39538 .40662 .39147 .39972 .38419 Mtetra
.39972 .38419 .40662 .39147 .41822 .38754 .41134 .38023 Mtetra
.41134 .38023 .41822 .38754 .42986 .38359 .42302 .37627 Mtetra
.662 .741 .909 r
.42302 .37627 .42986 .38359 .44156 .37965 .43475 .37233 Mtetra
.66 .741 .91 r
.43475 .37233 .44156 .37965 .45331 .37573 .44653 .36843 Mtetra
.655 .742 .913 r
.44653 .36843 .45331 .37573 .46511 .37188 .45836 .36464 Mtetra
.646 .742 .919 r
.45836 .36464 .46511 .37188 .47695 .36815 .47024 .36112 Mtetra
.609 .736 .935 r
.47024 .36112 .47695 .36815 .48885 .36473 .48216 .35851 Mtetra
.293 .616 .957 r
.48216 .35851 .48885 .36473 .5008 .36242 .49409 .36069 Mtetra
.836 .369 .076 r
.49409 .36069 .5008 .36242 .51279 .3658 .50603 .3804 Mtetra
.859 .518 .407 r
.50603 .3804 .51279 .3658 .52489 .38924 .51813 .43022 Mtetra
.769 .461 .466 r
.51813 .43022 .52489 .38924 .53737 .44498 .53071 .48136 Mtetra
.447 .159 .38 r
.53071 .48136 .53737 .44498 .55036 .49807 .54345 .47477 Mtetra
.873 .656 .605 r
.54345 .47477 .55036 .49807 .56309 .48627 .55578 .42181 Mtetra
.717 .5 .595 r
.55578 .42181 .56309 .48627 .57511 .42834 .56797 .38198 Mtetra
.637 .46 .626 r
.56797 .38198 .57511 .42834 .58709 .38748 .58041 .36977 Mtetra
.57 .527 .767 r
.58041 .36977 .58709 .38748 .59952 .3755 .59309 .36885 Mtetra
.497 .713 .968 r
.59309 .36885 .59952 .3755 .61224 .37444 .60586 .36825 Mtetra
.621 .781 .958 r
.60586 .36825 .61224 .37444 .62505 .37334 .61864 .36491 Mtetra
.719 .749 .876 r
.61864 .36491 .62505 .37334 .63783 .36933 .63138 .35838 Mtetra
.752 .707 .809 r
.63138 .35838 .63783 .36933 .65055 .36212 .64405 .34904 Mtetra
.761 .678 .771 r
.64405 .34904 .65055 .36212 .66318 .35218 .65666 .3377 Mtetra
.76 .661 .752 r
.65666 .3377 .66318 .35218 .67575 .34043 .66922 .32542 Mtetra
.756 .653 .748 r
.66922 .32542 .67575 .34043 .68827 .32795 .68179 .31319 Mtetra
.749 .653 .755 r
.68179 .31319 .68827 .32795 .7008 .31571 .69439 .30177 Mtetra
.739 .659 .771 r
.69439 .30177 .7008 .31571 .71337 .30443 .70706 .29161 Mtetra
.729 .67 .793 r
.70706 .29161 .71337 .30443 .72604 .29449 .71984 .28284 Mtetra
.716 .685 .818 r
.71984 .28284 .72604 .29449 .73882 .28595 .73272 .27535 Mtetra
.703 .7 .844 r
.73272 .27535 .73882 .28595 .75171 .27866 .74571 .2689 Mtetra
.691 .714 .866 r
.74571 .2689 .75171 .27866 .76472 .27237 .75881 .2632 Mtetra
.681 .725 .883 r
.75881 .2632 .76472 .27237 .77784 .26679 .772 .25799 Mtetra
.673 .732 .894 r
.772 .25799 .77784 .26679 .79104 .26167 .78527 .25309 Mtetra
.669 .737 .901 r
.78527 .25309 .79104 .26167 .80433 .25682 .79861 .24834 Mtetra
.666 .74 .905 r
.79861 .24834 .80433 .25682 .81769 .25212 .81202 .24367 Mtetra
.665 .742 .907 r
.81202 .24367 .81769 .25212 .83112 .24748 .8255 .23903 Mtetra
.664 .742 .908 r
.8255 .23903 .83112 .24748 .84462 .24286 .83905 .23438 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42293 .27888 .4159 Mtetra
.27888 .4159 .28613 .42293 .29727 .41913 .29005 .41207 Mtetra
.29005 .41207 .29727 .41913 .30846 .41532 .30127 .40823 Mtetra
.30127 .40823 .30846 .41532 .3197 .41148 .31253 .40436 Mtetra
.31253 .40436 .3197 .41148 .33099 .40763 .32384 .40048 Mtetra
.32384 .40048 .33099 .40763 .34232 .40377 .33521 .39659 Mtetra
.33521 .39659 .34232 .40377 .3537 .39988 .34662 .39267 Mtetra
.34662 .39267 .3537 .39988 .36513 .39598 .35808 .38874 Mtetra
.35808 .38874 .36513 .39598 .37661 .39207 .36959 .3848 Mtetra
.663 .741 .908 r
.36959 .3848 .37661 .39207 .38814 .38814 .38115 .38083 Mtetra
.38115 .38083 .38814 .38814 .39972 .38419 .39276 .37686 Mtetra
.39276 .37686 .39972 .38419 .41134 .38023 .40442 .37288 Mtetra
.662 .741 .909 r
.40442 .37288 .41134 .38023 .42302 .37627 .41613 .36891 Mtetra
.66 .741 .91 r
.41613 .36891 .42302 .37627 .43475 .37233 .42789 .36497 Mtetra
.657 .742 .912 r
.42789 .36497 .43475 .37233 .44653 .36843 .43969 .36113 Mtetra
.649 .742 .917 r
.43969 .36113 .44653 .36843 .45836 .36464 .45155 .35751 Mtetra
.619 .737 .931 r
.45155 .35751 .45836 .36464 .47024 .36112 .46345 .35464 Mtetra
.385 .658 .966 r
.46345 .35464 .47024 .36112 .48216 .35851 .47534 .35574 Mtetra
.79 .291 0 r
.47534 .35574 .48216 .35851 .49409 .36069 .48715 .37196 Mtetra
.861 .511 .387 r
.48715 .37196 .49409 .36069 .50603 .3804 .49895 .41582 Mtetra
.777 .464 .458 r
.49895 .41582 .50603 .3804 .51813 .43022 .51115 .46416 Mtetra
.492 .191 .382 r
.51115 .46416 .51813 .43022 .53071 .48136 .52383 .46207 Mtetra
.882 .673 .616 r
.52383 .46207 .53071 .48136 .54345 .47477 .53642 .41435 Mtetra
.72 .505 .598 r
.53642 .41435 .54345 .47477 .55578 .42181 .54879 .37598 Mtetra
.639 .461 .627 r
.54879 .37598 .55578 .42181 .56797 .38198 .56125 .36361 Mtetra
.568 .52 .761 r
.56125 .36361 .56797 .38198 .58041 .36977 .57388 .36274 Mtetra
.481 .694 .961 r
.57388 .36274 .58041 .36977 .59309 .36885 .58661 .36254 Mtetra
.595 .768 .962 r
.58661 .36254 .59309 .36885 .60586 .36825 .59937 .35981 Mtetra
.702 .744 .884 r
.59937 .35981 .60586 .36825 .61864 .36491 .61212 .35398 Mtetra
.742 .704 .816 r
.61212 .35398 .61864 .36491 .63138 .35838 .62482 .3453 Mtetra
.754 .676 .774 r
.62482 .3453 .63138 .35838 .64405 .34904 .63747 .33448 Mtetra
.756 .658 .754 r
.63747 .33448 .64405 .34904 .65666 .3377 .65008 .32251 Mtetra
.753 .65 .748 r
.65008 .32251 .65666 .3377 .66922 .32542 .66268 .3104 Mtetra
.747 .65 .753 r
.66268 .3104 .66922 .32542 .68179 .31319 .6753 .29895 Mtetra
.739 .656 .767 r
.6753 .29895 .68179 .31319 .69439 .30177 .68799 .28867 Mtetra
.729 .667 .789 r
.68799 .28867 .69439 .30177 .70706 .29161 .70077 .27974 Mtetra
.717 .682 .815 r
.70077 .27974 .70706 .29161 .71984 .28284 .71365 .27209 Mtetra
.705 .698 .841 r
.71365 .27209 .71984 .28284 .73272 .27535 .72663 .26551 Mtetra
.692 .713 .865 r
.72663 .26551 .73272 .27535 .74571 .2689 .73971 .25972 Mtetra
.682 .726 .883 r
.73971 .25972 .74571 .2689 .75881 .2632 .75289 .25445 Mtetra
.674 .735 .896 r
.75289 .25445 .75881 .2632 .772 .25799 .76614 .2495 Mtetra
.67 .741 .904 r
.76614 .2495 .772 .25799 .78527 .25309 .77946 .24472 Mtetra
.667 .744 .908 r
.77946 .24472 .78527 .25309 .79861 .24834 .79286 .24 Mtetra
.666 .746 .91 r
.79286 .24 .79861 .24834 .81202 .24367 .80632 .23531 Mtetra
.665 .746 .91 r
.80632 .23531 .81202 .24367 .8255 .23903 .81984 .23061 Mtetra
.81984 .23061 .8255 .23903 .83905 .23438 .83343 .22589 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41266 Mtetra
.26041 .41266 .26775 .41972 .27888 .4159 .27156 .40882 Mtetra
.27156 .40882 .27888 .4159 .29005 .41207 .28276 .40496 Mtetra
.28276 .40496 .29005 .41207 .30127 .40823 .29401 .40108 Mtetra
.29401 .40108 .30127 .40823 .31253 .40436 .3053 .39719 Mtetra
.3053 .39719 .31253 .40436 .32384 .40048 .31665 .39327 Mtetra
.31665 .39327 .32384 .40048 .33521 .39659 .32804 .38935 Mtetra
.32804 .38935 .33521 .39659 .34662 .39267 .33948 .3854 Mtetra
.33948 .3854 .34662 .39267 .35808 .38874 .35097 .38144 Mtetra
.663 .741 .908 r
.35097 .38144 .35808 .38874 .36959 .3848 .36251 .37746 Mtetra
.36251 .37746 .36959 .3848 .38115 .38083 .3741 .37347 Mtetra
.3741 .37347 .38115 .38083 .39276 .37686 .38574 .36948 Mtetra
.662 .741 .909 r
.38574 .36948 .39276 .37686 .40442 .37288 .39743 .36548 Mtetra
.661 .741 .91 r
.39743 .36548 .40442 .37288 .41613 .36891 .40917 .36151 Mtetra
.658 .741 .912 r
.40917 .36151 .41613 .36891 .42789 .36497 .42096 .35762 Mtetra
.651 .742 .916 r
.42096 .35762 .42789 .36497 .43969 .36113 .4328 .35391 Mtetra
.628 .739 .927 r
.4328 .35391 .43969 .36113 .45155 .35751 .44468 .35081 Mtetra
.455 .686 .965 r
.44468 .35081 .45155 .35751 .46345 .35464 .45654 .35096 Mtetra
.707 .176 0 r
.45654 .35096 .46345 .35464 .47534 .35574 .46826 .36399 Mtetra
.863 .5 .361 r
.46826 .36399 .47534 .35574 .48715 .37196 .47982 .40198 Mtetra
.785 .465 .447 r
.47982 .40198 .48715 .37196 .49895 .41582 .49168 .44686 Mtetra
.529 .216 .38 r
.49168 .44686 .49895 .41582 .51115 .46416 .50425 .44847 Mtetra
.89 .692 .629 r
.50425 .44847 .51115 .46416 .52383 .46207 .51702 .4061 Mtetra
.724 .511 .601 r
.51702 .4061 .52383 .46207 .53642 .41435 .52957 .36954 Mtetra
.641 .464 .628 r
.52957 .36954 .53642 .41435 .54879 .37598 .54205 .35711 Mtetra
.568 .515 .756 r
.54205 .35711 .54879 .37598 .56125 .36361 .55463 .35618 Mtetra
.472 .677 .955 r
.55463 .35618 .56125 .36361 .57388 .36274 .5673 .35628 Mtetra
.57 .755 .965 r
.5673 .35628 .57388 .36274 .58661 .36254 .58003 .3541 Mtetra
.684 .739 .892 r
.58003 .3541 .58661 .36254 .59937 .35981 .59277 .34895 Mtetra
.731 .702 .823 r
.59277 .34895 .59937 .35981 .61212 .35398 .6055 .34096 Mtetra
.747 .674 .78 r
.6055 .34096 .61212 .35398 .62482 .3453 .61818 .33074 Mtetra
.751 .657 .757 r
.61818 .33074 .62482 .3453 .63747 .33448 .63083 .31921 Mtetra
.75 .648 .749 r
.63083 .31921 .63747 .33448 .65008 .32251 .64347 .30735 Mtetra
.745 .648 .753 r
.64347 .30735 .65008 .32251 .66268 .3104 .65613 .296 Mtetra
.738 .654 .766 r
.65613 .296 .66268 .3104 .6753 .29895 .66884 .28571 Mtetra
.729 .665 .788 r
.66884 .28571 .6753 .29895 .68799 .28867 .68163 .27673 Mtetra
.718 .681 .814 r
.68163 .27673 .68799 .28867 .70077 .27974 .69451 .26903 Mtetra
.705 .7 .842 r
.69451 .26903 .70077 .27974 .71365 .27209 .70749 .26241 Mtetra
.693 .718 .868 r
.70749 .26241 .71365 .27209 .72663 .26551 .72056 .2566 Mtetra
.683 .734 .889 r
.72056 .2566 .72663 .26551 .73971 .25972 .73373 .25133 Mtetra
.675 .746 .904 r
.73373 .25133 .73971 .25972 .75289 .25445 .74697 .24637 Mtetra
.671 .754 .913 r
.74697 .24637 .75289 .25445 .76614 .2495 .76028 .24154 Mtetra
.669 .758 .917 r
.76028 .24154 .76614 .2495 .77946 .24472 .77365 .23676 Mtetra
.669 .759 .918 r
.77365 .23676 .77946 .24472 .79286 .24 .78709 .23196 Mtetra
.669 .758 .917 r
.78709 .23196 .79286 .24 .80632 .23531 .80059 .22714 Mtetra
.669 .755 .915 r
.80059 .22714 .80632 .23531 .81984 .23061 .81415 .2223 Mtetra
.668 .752 .913 r
.81415 .2223 .81984 .23061 .83343 .22589 .82777 .21745 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.24188 .40941 .24931 .41649 .26041 .41266 .25302 .40555 Mtetra
.25302 .40555 .26041 .41266 .27156 .40882 .26419 .40168 Mtetra
.26419 .40168 .27156 .40882 .28276 .40496 .27542 .39779 Mtetra
.27542 .39779 .28276 .40496 .29401 .40108 .2867 .39388 Mtetra
.2867 .39388 .29401 .40108 .3053 .39719 .29802 .38995 Mtetra
.29802 .38995 .3053 .39719 .31665 .39327 .30939 .38601 Mtetra
.30939 .38601 .31665 .39327 .32804 .38935 .32082 .38205 Mtetra
.32082 .38205 .32804 .38935 .33948 .3854 .33229 .37808 Mtetra
.663 .741 .908 r
.33229 .37808 .33948 .3854 .35097 .38144 .34381 .37408 Mtetra
.34381 .37408 .35097 .38144 .36251 .37746 .35538 .37008 Mtetra
.35538 .37008 .36251 .37746 .3741 .37347 .367 .36606 Mtetra
.367 .36606 .3741 .37347 .38574 .36948 .37867 .36204 Mtetra
.661 .741 .909 r
.37867 .36204 .38574 .36948 .39743 .36548 .39039 .35805 Mtetra
.659 .741 .911 r
.39039 .35805 .39743 .36548 .40917 .36151 .40216 .35411 Mtetra
.654 .741 .914 r
.40216 .35411 .40917 .36151 .42096 .35762 .41398 .35031 Mtetra
.635 .739 .923 r
.41398 .35031 .42096 .35762 .4328 .35391 .42584 .34701 Mtetra
.507 .704 .959 r
.42584 .34701 .4328 .35391 .44468 .35081 .43768 .34635 Mtetra
.564 .012 0 r
.43768 .34635 .44468 .35081 .45654 .35096 .44934 .3565 Mtetra
.863 .484 .327 r
.44934 .3565 .45654 .35096 .46826 .36399 .46072 .38887 Mtetra
.793 .465 .433 r
.46072 .38887 .46826 .36399 .47982 .40198 .47229 .4298 Mtetra
.56 .234 .373 r
.47229 .4298 .47982 .40198 .49168 .44686 .48472 .4343 Mtetra
.897 .714 .646 r
.48472 .4343 .49168 .44686 .50425 .44847 .49762 .3972 Mtetra
.727 .517 .606 r
.49762 .3972 .50425 .44847 .51702 .4061 .51031 .36277 Mtetra
.643 .468 .631 r
.51031 .36277 .51702 .4061 .52957 .36954 .5228 .35035 Mtetra
.569 .513 .753 r
.5228 .35035 .52957 .36954 .54205 .35711 .53533 .34928 Mtetra
.468 .664 .947 r
.53533 .34928 .54205 .35711 .55463 .35618 .54795 .34957 Mtetra
.549 .741 .966 r
.54795 .34957 .55463 .35618 .5673 .35628 .56064 .34785 Mtetra
.666 .733 .9 r
.56064 .34785 .5673 .35628 .58003 .3541 .57337 .34335 Mtetra
.719 .7 .832 r
.57337 .34335 .58003 .3541 .59277 .34895 .5861 .33607 Mtetra
.739 .673 .786 r
.5861 .33607 .59277 .34895 .6055 .34096 .59881 .32652 Mtetra
.746 .656 .761 r
.59881 .32652 .6055 .34096 .61818 .33074 .6115 .31554 Mtetra
.745 .648 .752 r
.6115 .31554 .61818 .33074 .63083 .31921 .62418 .30409 Mtetra
.742 .647 .755 r
.62418 .30409 .63083 .31921 .64347 .30735 .63688 .29301 Mtetra
.736 .654 .769 r
.63688 .29301 .64347 .30735 .65613 .296 .64961 .28291 Mtetra
.727 .667 .791 r
.64961 .28291 .65613 .296 .66884 .28571 .66242 .27407 Mtetra
.717 .687 .82 r
.66242 .27407 .66884 .28571 .68163 .27673 .67532 .26653 Mtetra
.705 .711 .853 r
.67532 .26653 .68163 .27673 .69451 .26903 .68831 .26008 Mtetra
.692 .736 .885 r
.68831 .26008 .69451 .26903 .70749 .26241 .70139 .25444 Mtetra
.681 .76 .911 r
.70139 .25444 .70749 .26241 .72056 .2566 .71455 .2493 Mtetra
.673 .778 .929 r
.71455 .2493 .72056 .2566 .73373 .25133 .72779 .2444 Mtetra
.671 .79 .938 r
.72779 .2444 .73373 .25133 .74697 .24637 .74109 .23953 Mtetra
.672 .795 .94 r
.74109 .23953 .74697 .24637 .76028 .24154 .75444 .23459 Mtetra
.675 .793 .938 r
.75444 .23459 .76028 .24154 .77365 .23676 .76785 .22956 Mtetra
.677 .787 .933 r
.76785 .22956 .77365 .23676 .78709 .23196 .78132 .22444 Mtetra
.678 .779 .927 r
.78132 .22444 .78709 .23196 .80059 .22714 .79484 .21929 Mtetra
.676 .77 .921 r
.79484 .21929 .80059 .22714 .81415 .2223 .80843 .21415 Mtetra
.674 .761 .916 r
.80843 .21415 .81415 .2223 .82777 .21745 .82208 .20905 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40227 Mtetra
.2344 .40227 .24188 .40941 .25302 .40555 .24556 .39839 Mtetra
.24556 .39839 .25302 .40555 .26419 .40168 .25677 .39448 Mtetra
.25677 .39448 .26419 .40168 .27542 .39779 .26802 .39056 Mtetra
.26802 .39056 .27542 .39779 .2867 .39388 .27933 .38662 Mtetra
.27933 .38662 .2867 .39388 .29802 .38995 .29068 .38266 Mtetra
.29068 .38266 .29802 .38995 .30939 .38601 .30208 .37869 Mtetra
.30208 .37869 .30939 .38601 .32082 .38205 .31353 .3747 Mtetra
.31353 .3747 .32082 .38205 .33229 .37808 .32503 .37069 Mtetra
.663 .741 .908 r
.32503 .37069 .33229 .37808 .34381 .37408 .33659 .36667 Mtetra
.33659 .36667 .34381 .37408 .35538 .37008 .34819 .36263 Mtetra
.34819 .36263 .35538 .37008 .367 .36606 .35984 .3586 Mtetra
.662 .741 .909 r
.35984 .3586 .367 .36606 .37867 .36204 .37154 .35457 Mtetra
.66 .741 .91 r
.37154 .35457 .37867 .36204 .39039 .35805 .38329 .35059 Mtetra
.655 .741 .913 r
.38329 .35059 .39039 .35805 .40216 .35411 .39509 .34672 Mtetra
.641 .74 .921 r
.39509 .34672 .40216 .35411 .41398 .35031 .40693 .34324 Mtetra
.546 .716 .951 r
.40693 .34324 .41398 .35031 .42584 .34701 .41875 .34188 Mtetra
0 .19 .631 r
.41875 .34188 .42584 .34701 .43768 .34635 .43038 .34949 Mtetra
.859 .458 .278 r
.43038 .34949 .43768 .34635 .44934 .3565 .44164 .37659 Mtetra
.799 .461 .416 r
.44164 .37659 .44934 .3565 .46072 .38887 .45298 .41325 Mtetra
.586 .246 .36 r
.45298 .41325 .46072 .38887 .47229 .4298 .46525 .41984 Mtetra
.903 .739 .667 r
.46525 .41984 .47229 .4298 .48472 .4343 .47821 .38781 Mtetra
.731 .525 .613 r
.47821 .38781 .48472 .4343 .49762 .3972 .49102 .35573 Mtetra
.646 .472 .634 r
.49102 .35573 .49762 .3972 .51031 .36277 .50353 .34342 Mtetra
.572 .514 .751 r
.50353 .34342 .51031 .36277 .5228 .35035 .516 .34215 Mtetra
.469 .654 .941 r
.516 .34215 .5228 .35035 .53533 .34928 .52856 .3425 Mtetra
.531 .729 .965 r
.52856 .3425 .53533 .34928 .54795 .34957 .5412 .34116 Mtetra
.647 .728 .907 r
.5412 .34116 .54795 .34957 .56064 .34785 .5539 .33724 Mtetra
.706 .699 .841 r
.5539 .33724 .56064 .34785 .57337 .34335 .56663 .33069 Mtetra
.73 .673 .795 r
.56663 .33069 .57337 .34335 .5861 .33607 .57936 .32188 Mtetra
.739 .657 .769 r
.57936 .32188 .5861 .33607 .59881 .32652 .59209 .31159 Mtetra
.74 .649 .758 r
.59209 .31159 .59881 .32652 .6115 .31554 .6048 .30075 Mtetra
.738 .65 .762 r
.6048 .30075 .6115 .31554 .62418 .30409 .61754 .2902 Mtetra
.732 .659 .777 r
.61754 .2902 .62418 .30409 .63688 .29301 .63032 .28061 Mtetra
.724 .677 .804 r
.63032 .28061 .63688 .29301 .64961 .28291 .64316 .2723 Mtetra
.713 .706 .842 r
.64316 .2723 .64961 .28291 .66242 .27407 .65609 .26532 Mtetra
.699 .744 .886 r
.65609 .26532 .66242 .27407 .67532 .26653 .66911 .25946 Mtetra
.68 .786 .93 r
.66911 .25946 .67532 .26653 .68831 .26008 .68222 .25436 Mtetra
.661 .825 .962 r
.68222 .25436 .68831 .26008 .70139 .25444 .69541 .24963 Mtetra
.649 .854 .978 r
.69541 .24963 .70139 .25444 .71455 .2493 .70866 .24492 Mtetra
.65 .871 .982 r
.70866 .24492 .71455 .2493 .72779 .2444 .72196 .23998 Mtetra
.664 .875 .978 r
.72196 .23998 .72779 .2444 .74109 .23953 .73529 .23471 Mtetra
.681 .868 .97 r
.73529 .23471 .74109 .23953 .75444 .23459 .74867 .22913 Mtetra
.693 .851 .958 r
.74867 .22913 .75444 .23459 .76785 .22956 .76208 .22334 Mtetra
.698 .829 .945 r
.76208 .22334 .76785 .22956 .78132 .22444 .77555 .21749 Mtetra
.696 .805 .933 r
.77555 .21749 .78132 .22444 .79484 .21929 .78907 .2117 Mtetra
.69 .785 .923 r
.78907 .2117 .79484 .21929 .80843 .21415 .80267 .20607 Mtetra
.684 .769 .916 r
.80267 .20607 .80843 .21415 .82208 .20905 .81634 .20063 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40227 .22685 .39508 Mtetra
.22685 .39508 .2344 .40227 .24556 .39839 .23804 .39116 Mtetra
.23804 .39116 .24556 .39839 .25677 .39448 .24928 .38723 Mtetra
.24928 .38723 .25677 .39448 .26802 .39056 .26056 .38327 Mtetra
.26056 .38327 .26802 .39056 .27933 .38662 .2719 .3793 Mtetra
.2719 .3793 .27933 .38662 .29068 .38266 .28328 .37531 Mtetra
.28328 .37531 .29068 .38266 .30208 .37869 .29471 .37131 Mtetra
.29471 .37131 .30208 .37869 .31353 .3747 .30619 .36728 Mtetra
.663 .741 .908 r
.30619 .36728 .31353 .3747 .32503 .37069 .31772 .36325 Mtetra
.31772 .36325 .32503 .37069 .33659 .36667 .32931 .3592 Mtetra
.32931 .3592 .33659 .36667 .34819 .36263 .34094 .35514 Mtetra
.662 .741 .909 r
.34094 .35514 .34819 .36263 .35984 .3586 .35262 .35108 Mtetra
.661 .741 .91 r
.35262 .35108 .35984 .3586 .37154 .35457 .36435 .34706 Mtetra
.657 .741 .912 r
.36435 .34706 .37154 .35457 .38329 .35059 .37613 .34313 Mtetra
.646 .74 .918 r
.37613 .34313 .38329 .35059 .39509 .34672 .38795 .3395 Mtetra
.576 .724 .944 r
.38795 .3395 .39509 .34672 .40693 .34324 .39976 .33755 Mtetra
0 .384 .812 r
.39976 .33755 .40693 .34324 .41875 .34188 .41137 .34295 Mtetra
.848 .42 .21 r
.41137 .34295 .41875 .34188 .43038 .34949 .42257 .3652 Mtetra
.804 .453 .393 r
.42257 .3652 .43038 .34949 .44164 .37659 .43373 .39746 Mtetra
.606 .252 .342 r
.43373 .39746 .44164 .37659 .45298 .41325 .44583 .40539 Mtetra
.907 .766 .694 r
.44583 .40539 .45298 .41325 .46525 .41984 .4588 .3781 Mtetra
.735 .534 .62 r
.4588 .3781 .46525 .41984 .47821 .38781 .47169 .34853 Mtetra
.649 .478 .639 r
.47169 .34853 .47821 .38781 .49102 .35573 .48422 .33641 Mtetra
.576 .517 .751 r
.48422 .33641 .49102 .35573 .50353 .34342 .49664 .33488 Mtetra
.475 .648 .934 r
.49664 .33488 .50353 .34342 .516 .34215 .50914 .3352 Mtetra
.519 .719 .964 r
.50914 .3352 .516 .34215 .52856 .3425 .52173 .33412 Mtetra
.629 .722 .914 r
.52173 .33412 .52856 .3425 .5412 .34116 .53439 .33074 Mtetra
.691 .698 .851 r
.53439 .33074 .5412 .34116 .5539 .33724 .54711 .32491 Mtetra
.719 .674 .805 r
.54711 .32491 .5539 .33724 .56663 .33069 .55985 .31693 Mtetra
.731 .659 .779 r
.55985 .31693 .56663 .33069 .57936 .32188 .5726 .30751 Mtetra
.733 .653 .77 r
.5726 .30751 .57936 .32188 .59209 .31159 .58535 .29755 Mtetra
.731 .656 .776 r
.58535 .29755 .59209 .31159 .6048 .30075 .59813 .28794 Mtetra
.725 .672 .797 r
.59813 .28794 .6048 .30075 .61754 .2902 .61095 .27937 Mtetra
.715 .702 .837 r
.61095 .27937 .61754 .2902 .63032 .28061 .62385 .27222 Mtetra
.696 .752 .895 r
.62385 .27222 .63032 .28061 .64316 .2723 .63683 .2665 Mtetra
.656 .819 .962 r
.63683 .2665 .64316 .2723 .65609 .26532 .64992 .26194 Mtetra
.576 .874 .994 r
.64992 .26194 .65609 .26532 .66911 .25946 .66309 .25802 Mtetra
.47 .878 .948 r
.66309 .25802 .66911 .25946 .68222 .25436 .67634 .25416 Mtetra
.408 .86 .875 r
.67634 .25416 .68222 .25436 .69541 .24963 .68963 .24985 Mtetra
.432 .874 .852 r
.68963 .24985 .69541 .24963 .70866 .24492 .70294 .24475 Mtetra
.523 .918 .885 r
.70294 .24475 .70866 .24492 .72196 .23998 .71626 .23879 Mtetra
.629 .952 .934 r
.71626 .23879 .72196 .23998 .73529 .23471 .72959 .23209 Mtetra
.702 .946 .958 r
.72959 .23209 .73529 .23471 .74867 .22913 .74292 .22496 Mtetra
.732 .908 .956 r
.74292 .22496 .74867 .22913 .76208 .22334 .7563 .21773 Mtetra
.732 .862 .942 r
.7563 .21773 .76208 .22334 .77555 .21749 .76973 .2107 Mtetra
.721 .821 .927 r
.76973 .2107 .77555 .21749 .78907 .2117 .78324 .20403 Mtetra
.706 .791 .917 r
.78324 .20403 .78907 .2117 .80267 .20607 .79685 .19781 Mtetra
.693 .77 .911 r
.79685 .19781 .80267 .20607 .81634 .20063 .81054 .192 Mtetra
.664 .741 .908 r
.18589 .39958 .19358 .40674 .20462 .40287 .19696 .39568 Mtetra
.19696 .39568 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .39508 .21925 .38783 Mtetra
.21925 .38783 .22685 .39508 .23804 .39116 .23047 .38388 Mtetra
.23047 .38388 .23804 .39116 .24928 .38723 .24173 .37991 Mtetra
.24173 .37991 .24928 .38723 .26056 .38327 .25304 .37593 Mtetra
.25304 .37593 .26056 .38327 .2719 .3793 .26441 .37192 Mtetra
.26441 .37192 .2719 .3793 .28328 .37531 .27582 .3679 Mtetra
.27582 .3679 .28328 .37531 .29471 .37131 .28728 .36387 Mtetra
.663 .741 .908 r
.28728 .36387 .29471 .37131 .30619 .36728 .29879 .35981 Mtetra
.29879 .35981 .30619 .36728 .31772 .36325 .31035 .35574 Mtetra
.31035 .35574 .31772 .36325 .32931 .3592 .32197 .35167 Mtetra
.663 .741 .909 r
.32197 .35167 .32931 .3592 .34094 .35514 .33363 .34759 Mtetra
.661 .741 .909 r
.33363 .34759 .34094 .35514 .35262 .35108 .34534 .34353 Mtetra
.658 .741 .911 r
.34534 .34353 .35262 .35108 .36435 .34706 .3571 .33954 Mtetra
.65 .741 .916 r
.3571 .33954 .36435 .34706 .37613 .34313 .3689 .33579 Mtetra
.598 .729 .937 r
.3689 .33579 .37613 .34313 .38795 .3395 .3807 .33335 Mtetra
.125 .528 .916 r
.3807 .33335 .38795 .3395 .39976 .33755 .39231 .33688 Mtetra
.823 .359 .112 r
.39231 .33688 .39976 .33755 .41137 .34295 .40348 .35479 Mtetra
.807 .44 .363 r
.40348 .35479 .41137 .34295 .42257 .3652 .41453 .38263 Mtetra
.622 .25 .317 r
.41453 .38263 .42257 .3652 .43373 .39746 .42646 .3912 Mtetra
.906 .794 .725 r
.42646 .3912 .43373 .39746 .44583 .40539 .4394 .36822 Mtetra
.739 .543 .629 r
.4394 .36822 .44583 .40539 .4588 .3781 .45234 .34125 Mtetra
.653 .486 .645 r
.45234 .34125 .4588 .3781 .47169 .34853 .46487 .3294 Mtetra
.581 .521 .753 r
.46487 .3294 .47169 .34853 .48422 .33641 .47725 .32757 Mtetra
.484 .645 .928 r
.47725 .32757 .48422 .33641 .49664 .33488 .48969 .32777 Mtetra
.51 .712 .962 r
.48969 .32777 .49664 .33488 .50914 .3352 .50222 .32687 Mtetra
.612 .718 .92 r
.50222 .32687 .50914 .3352 .52173 .33412 .51484 .32396 Mtetra
.675 .698 .863 r
.51484 .32396 .52173 .33412 .53439 .33074 .52754 .31885 Mtetra
.706 .677 .819 r
.52754 .31885 .53439 .33074 .54711 .32491 .54027 .31179 Mtetra
.719 .664 .794 r
.54027 .31179 .54711 .32491 .55985 .31693 .55303 .30346 Mtetra
.722 .66 .788 r
.55303 .30346 .55985 .31693 .5726 .30751 .56582 .29476 Mtetra
.719 .67 .801 r
.56582 .29476 .5726 .30751 .58535 .29755 .57864 .28662 Mtetra
.708 .698 .838 r
.57864 .28662 .58535 .29755 .59813 .28794 .59152 .27979 Mtetra
.68 .754 .907 r
.59152 .27979 .59813 .28794 .61095 .27937 .60448 .27467 Mtetra
.59 .834 .991 r
.60448 .27467 .61095 .27937 .62385 .27222 .61755 .27121 Mtetra
.308 .793 .897 r
.61755 .27121 .62385 .27222 .63683 .2665 .63073 .26894 Mtetra
.033 0 0 r
.63073 .26894 .63683 .2665 .64992 .26194 .64401 .26706 Mtetra
.167 0 0 r
.64401 .26706 .64992 .26194 .66309 .25802 .65735 .26467 Mtetra
.164 0 0 r
.65735 .26467 .66309 .25802 .67634 .25416 .67071 .26099 Mtetra
.07 0 0 r
.67071 .26099 .67634 .25416 .68963 .24985 .68406 .25556 Mtetra
0 0 0 r
.68406 .25556 .68963 .24985 .70294 .24475 .69736 .24834 Mtetra
.39 .803 .597 r
.69736 .24834 .70294 .24475 .71626 .23879 .71062 .2397 Mtetra
.652 .967 .818 r
.71062 .2397 .71626 .23879 .72959 .23209 .72386 .23026 Mtetra
.773 .978 .913 r
.72386 .23026 .72959 .23209 .74292 .22496 .73711 .22071 Mtetra
.789 .917 .925 r
.73711 .22071 .74292 .22496 .7563 .21773 .75042 .21158 Mtetra
.768 .854 .915 r
.75042 .21158 .7563 .21773 .76973 .2107 .76381 .20322 Mtetra
.74 .808 .906 r
.76381 .20322 .76973 .2107 .78324 .20403 .77732 .19574 Mtetra
.715 .778 .902 r
.77732 .19574 .78324 .20403 .79685 .19781 .79093 .18907 Mtetra
.696 .76 .901 r
.79093 .18907 .79685 .19781 .81054 .192 .80466 .18304 Mtetra
.664 .741 .908 r
.17814 .39237 .18589 .39958 .19696 .39568 .18924 .38844 Mtetra
.18924 .38844 .19696 .39568 .20808 .39177 .20039 .38449 Mtetra
.20039 .38449 .20808 .39177 .21925 .38783 .21158 .38052 Mtetra
.21158 .38052 .21925 .38783 .23047 .38388 .22283 .37654 Mtetra
.22283 .37654 .23047 .38388 .24173 .37991 .23412 .37254 Mtetra
.23412 .37254 .24173 .37991 .25304 .37593 .24546 .36852 Mtetra
.24546 .36852 .25304 .37593 .26441 .37192 .25686 .36449 Mtetra
.25686 .36449 .26441 .37192 .27582 .3679 .2683 .36044 Mtetra
.663 .741 .908 r
.2683 .36044 .27582 .3679 .28728 .36387 .27979 .35637 Mtetra
.27979 .35637 .28728 .36387 .29879 .35981 .29133 .35228 Mtetra
.29133 .35228 .29879 .35981 .31035 .35574 .30292 .34819 Mtetra
.30292 .34819 .31035 .35574 .32197 .35167 .31457 .34409 Mtetra
.662 .741 .909 r
.31457 .34409 .32197 .35167 .33363 .34759 .32626 .34 Mtetra
.66 .741 .91 r
.32626 .34 .33363 .34759 .34534 .34353 .338 .33596 Mtetra
.653 .741 .914 r
.338 .33596 .34534 .34353 .3571 .33954 .34978 .3321 Mtetra
.614 .733 .931 r
.34978 .3321 .3571 .33954 .3689 .33579 .36156 .32927 Mtetra
.283 .612 .956 r
.36156 .32927 .3689 .33579 .3807 .33335 .37317 .33132 Mtetra
.774 .269 0 r
.37317 .33132 .3807 .33335 .39231 .33688 .38434 .34554 Mtetra
.804 .418 .323 r
.38434 .34554 .39231 .33688 .40348 .35479 .39533 .36899 Mtetra
.629 .237 .282 r
.39533 .36899 .40348 .35479 .41453 .38263 .40713 .3775 Mtetra
.9 .822 .761 r
.40713 .3775 .41453 .38263 .42646 .3912 .42 .35834 Mtetra
.742 .555 .64 r
.42 .35834 .42646 .3912 .4394 .36822 .43296 .33396 Mtetra
.657 .494 .652 r
.43296 .33396 .4394 .36822 .45234 .34125 .4455 .32247 Mtetra
.587 .528 .756 r
.4455 .32247 .45234 .34125 .46487 .3294 .45783 .32031 Mtetra
.495 .644 .923 r
.45783 .32031 .46487 .3294 .47725 .32757 .4702 .32031 Mtetra
.506 .706 .96 r
.4702 .32031 .47725 .32757 .48969 .32777 .48268 .3195 Mtetra
.595 .714 .927 r
.48268 .3195 .48969 .32777 .50222 .32687 .49526 .31701 Mtetra
.658 .698 .876 r
.49526 .31701 .50222 .32687 .51484 .32396 .50792 .31261 Mtetra
.69 .681 .836 r
.50792 .31261 .51484 .32396 .52754 .31885 .52064 .30658 Mtetra
.703 .671 .815 r
.52064 .30658 .52754 .31885 .54027 .31179 .5334 .29956 Mtetra
.704 .672 .816 r
.5334 .29956 .54027 .31179 .55303 .30346 .5462 .2925 Mtetra
.692 .691 .845 r
.5462 .2925 .55303 .30346 .56582 .29476 .55905 .28641 Mtetra
.655 .74 .912 r
.55905 .28641 .56582 .29476 .57864 .28662 .57198 .2821 Mtetra
.508 .806 .999 r
.57198 .2821 .57864 .28662 .59152 .27979 .58501 .27996 Mtetra
0 0 0 r
.58501 .27996 .59152 .27979 .60448 .27467 .59817 .2798 Mtetra
.362 0 0 r
.59817 .2798 .60448 .27467 .61755 .27121 .61146 .28085 Mtetra
.442 0 .065 r
.61146 .28085 .61755 .27121 .63073 .26894 .62486 .2819 Mtetra
.433 .014 .144 r
.62486 .2819 .63073 .26894 .64401 .26706 .63833 .28156 Mtetra
.377 0 .151 r
.63833 .28156 .64401 .26706 .65735 .26467 .65179 .27866 Mtetra
.272 0 .1 r
.65179 .27866 .65735 .26467 .67071 .26099 .66519 .27259 Mtetra
.086 0 0 r
.66519 .27259 .67071 .26099 .68406 .25556 .67849 .26343 Mtetra
0 0 0 r
.67849 .26343 .68406 .25556 .69736 .24834 .69168 .2519 Mtetra
.639 .924 .65 r
.69168 .2519 .69736 .24834 .71062 .2397 .70481 .23913 Mtetra
.84 .996 .84 r
.70481 .23913 .71062 .2397 .72386 .23026 .71792 .22626 Mtetra
.853 .926 .877 r
.71792 .22626 .72386 .23026 .73711 .22071 .73108 .21421 Mtetra
.816 .853 .876 r
.73108 .21421 .73711 .22071 .75042 .21158 .74434 .20352 Mtetra
.775 .802 .875 r
.74434 .20352 .75042 .21158 .76381 .20322 .75773 .19432 Mtetra
.74 .771 .878 r
.75773 .19432 .76381 .20322 .77732 .19574 .77126 .18648 Mtetra
.712 .754 .885 r
.77126 .18648 .77732 .19574 .79093 .18907 .78492 .17972 Mtetra
.693 .745 .891 r
.78492 .17972 .79093 .18907 .80466 .18304 .7987 .17372 Mtetra
.664 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.18146 .38114 .18924 .38844 .20039 .38449 .19263 .37715 Mtetra
.19263 .37715 .20039 .38449 .21158 .38052 .20386 .37316 Mtetra
.20386 .37316 .21158 .38052 .22283 .37654 .21513 .36914 Mtetra
.21513 .36914 .22283 .37654 .23412 .37254 .22645 .36511 Mtetra
.22645 .36511 .23412 .37254 .24546 .36852 .23782 .36106 Mtetra
.23782 .36106 .24546 .36852 .25686 .36449 .24924 .35699 Mtetra
.24924 .35699 .25686 .36449 .2683 .36044 .26072 .35291 Mtetra
.663 .741 .908 r
.26072 .35291 .2683 .36044 .27979 .35637 .27224 .34881 Mtetra
.27224 .34881 .27979 .35637 .29133 .35228 .28381 .34469 Mtetra
.28381 .34469 .29133 .35228 .30292 .34819 .29543 .34057 Mtetra
.662 .741 .909 r
.29543 .34057 .30292 .34819 .31457 .34409 .3071 .33645 Mtetra
.66 .741 .91 r
.3071 .33645 .31457 .34409 .32626 .34 .31882 .33237 Mtetra
.655 .741 .913 r
.31882 .33237 .32626 .34 .338 .33596 .33059 .32843 Mtetra
.624 .735 .926 r
.33059 .32843 .338 .33596 .34978 .3321 .34236 .32531 Mtetra
.364 .648 .965 r
.34236 .32531 .34978 .3321 .36156 .32927 .35395 .32649 Mtetra
.706 .168 0 r
.35395 .32649 .36156 .32927 .37317 .33132 .36512 .3381 Mtetra
.787 .379 .277 r
.36512 .3381 .37317 .33132 .38434 .34554 .37611 .35705 Mtetra
.619 .204 .233 r
.37611 .35705 .38434 .34554 .39533 .36899 .38782 .36452 Mtetra
.886 .845 .799 r
.38782 .36452 .39533 .36899 .40713 .3775 .4006 .34859 Mtetra
.745 .567 .653 r
.4006 .34859 .40713 .3775 .42 .35834 .41355 .32673 Mtetra
.661 .504 .661 r
.41355 .32673 .42 .35834 .43296 .33396 .42608 .31568 Mtetra
.593 .537 .761 r
.42608 .31568 .43296 .33396 .4455 .32247 .43838 .31318 Mtetra
.508 .646 .919 r
.43838 .31318 .4455 .32247 .45783 .32031 .45069 .31292 Mtetra
.506 .703 .958 r
.45069 .31292 .45783 .32031 .4702 .32031 .46311 .31212 Mtetra
.58 .711 .932 r
.46311 .31212 .4702 .32031 .48268 .3195 .47563 .30996 Mtetra
.638 .699 .89 r
.47563 .30996 .48268 .3195 .49526 .31701 .48825 .30627 Mtetra
.669 .685 .856 r
.48825 .30627 .49526 .31701 .50792 .31261 .50094 .30129 Mtetra
.679 .678 .842 r
.50094 .30129 .50792 .31261 .52064 .30658 .51369 .29573 Mtetra
.672 .686 .855 r
.51369 .29573 .52064 .30658 .5334 .29956 .52649 .29058 Mtetra
.634 .715 .905 r
.52649 .29058 .5334 .29956 .5462 .2925 .53935 .28693 Mtetra
.486 .76 .991 r
.53935 .28693 .5462 .2925 .55905 .28641 .5523 .28565 Mtetra
0 .513 .706 r
.5523 .28565 .55905 .28641 .57198 .2821 .56537 .28708 Mtetra
.481 0 0 r
.56537 .28708 .57198 .2821 .58501 .27996 .5786 .29086 Mtetra
.554 .112 .154 r
.5786 .29086 .58501 .27996 .59817 .2798 .59198 .29584 Mtetra
.547 .15 .241 r
.59198 .29584 .59817 .2798 .61146 .28085 .60549 .30026 Mtetra
.507 .134 .267 r
.60549 .30026 .61146 .28085 .62486 .2819 .61908 .30219 Mtetra
.435 .073 .251 r
.61908 .30219 .62486 .2819 .63833 .28156 .63264 .30001 Mtetra
.308 0 .184 r
.63264 .30001 .63833 .28156 .65179 .27866 .6461 .29296 Mtetra
.067 0 .019 r
.6461 .29296 .65179 .27866 .66519 .27259 .65941 .28132 Mtetra
0 0 0 r
.65941 .28132 .66519 .27259 .67849 .26343 .67256 .26627 Mtetra
.826 .981 .693 r
.67256 .26627 .67849 .26343 .69168 .2519 .68559 .24954 Mtetra
.918 .946 .801 r
.68559 .24954 .69168 .2519 .70481 .23913 .69858 .23283 Mtetra
.882 .857 .812 r
.69858 .23283 .70481 .23913 .71792 .22626 .71162 .21746 Mtetra
.833 .796 .816 r
.71162 .21746 .71792 .22626 .73108 .21421 .72476 .20415 Mtetra
.789 .759 .826 r
.72476 .20415 .73108 .21421 .74434 .20352 .73805 .19307 Mtetra
.753 .741 .841 r
.73805 .19307 .74434 .20352 .75773 .19432 .7515 .18398 Mtetra
.723 .733 .859 r
.7515 .18398 .75773 .19432 .77126 .18648 .7651 .17643 Mtetra
.7 .731 .875 r
.7651 .17643 .77126 .18648 .78492 .17972 .77883 .16997 Mtetra
.684 .733 .888 r
.77883 .16997 .78492 .17972 .7987 .17372 .79268 .1642 Mtetra
.664 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37377 Mtetra
.17361 .37377 .18146 .38114 .19263 .37715 .18482 .36976 Mtetra
.18482 .36976 .19263 .37715 .20386 .37316 .19607 .36573 Mtetra
.19607 .36573 .20386 .37316 .21513 .36914 .20737 .36168 Mtetra
.20737 .36168 .21513 .36914 .22645 .36511 .21872 .35762 Mtetra
.21872 .35762 .22645 .36511 .23782 .36106 .23012 .35354 Mtetra
.23012 .35354 .23782 .36106 .24924 .35699 .24157 .34944 Mtetra
.663 .741 .908 r
.24157 .34944 .24924 .35699 .26072 .35291 .25307 .34532 Mtetra
.25307 .34532 .26072 .35291 .27224 .34881 .26462 .34119 Mtetra
.26462 .34119 .27224 .34881 .28381 .34469 .27623 .33705 Mtetra
.663 .741 .909 r
.27623 .33705 .28381 .34469 .29543 .34057 .28788 .3329 Mtetra
.661 .741 .909 r
.28788 .3329 .29543 .34057 .3071 .33645 .29958 .32878 Mtetra
.657 .741 .912 r
.29958 .32878 .3071 .33645 .31882 .33237 .31132 .32477 Mtetra
.628 .735 .924 r
.31132 .32477 .31882 .33237 .33059 .32843 .32307 .32153 Mtetra
.341 .634 .961 r
.32307 .32153 .33059 .32843 .34236 .32531 .3346 .32299 Mtetra
.704 .165 0 r
.3346 .32299 .34236 .32531 .35395 .32649 .34566 .33415 Mtetra
.733 .311 .246 r
.34566 .33415 .35395 .32649 .36512 .3381 .35675 .34803 Mtetra
.557 .117 .159 r
.35675 .34803 .36512 .3381 .37611 .35705 .3685 .3526 Mtetra
.864 .854 .83 r
.3685 .3526 .37611 .35705 .38782 .36452 .38118 .33908 Mtetra
.747 .58 .668 r
.38118 .33908 .38782 .36452 .4006 .34859 .3941 .31963 Mtetra
.665 .516 .672 r
.3941 .31963 .4006 .34859 .41355 .32673 .40662 .30905 Mtetra
.6 .547 .767 r
.40662 .30905 .41355 .32673 .42608 .31568 .41888 .30623 Mtetra
.522 .65 .915 r
.41888 .30623 .42608 .31568 .43838 .31318 .43115 .30565 Mtetra
.51 .701 .956 r
.43115 .30565 .43838 .31318 .45069 .31292 .44351 .30479 Mtetra
.568 .708 .937 r
.44351 .30479 .45069 .31292 .46311 .31212 .45598 .30288 Mtetra
.617 .699 .903 r
.45598 .30288 .46311 .31212 .47563 .30996 .46854 .29979 Mtetra
.644 .688 .877 r
.46854 .29979 .47563 .30996 .48825 .30627 .48119 .2958 Mtetra
.648 .684 .87 r
.48119 .2958 .48825 .30627 .50094 .30129 .49391 .29164 Mtetra
.623 .694 .895 r
.49391 .29164 .50094 .30129 .51369 .29573 .50668 .28834 Mtetra
.526 .717 .96 r
.50668 .28834 .51369 .29573 .52649 .29058 .51951 .28705 Mtetra
.132 .624 .912 r
.51951 .28705 .52649 .29058 .53935 .28693 .53244 .28866 Mtetra
.46 0 0 r
.53244 .28866 .53935 .28693 .5523 .28565 .54551 .29346 Mtetra
.605 .132 .104 r
.54551 .29346 .5523 .28565 .56537 .28708 .55874 .30088 Mtetra
.616 .203 .237 r
.55874 .30088 .56537 .28708 .5786 .29086 .57215 .30938 Mtetra
.59 .207 .284 r
.57215 .30938 .5786 .29086 .59198 .29584 .58572 .31674 Mtetra
.536 .167 .288 r
.58572 .31674 .59198 .29584 .60549 .30026 .59937 .32049 Mtetra
.438 .073 .246 r
.59937 .32049 .60549 .30026 .61908 .30219 .61301 .31868 Mtetra
.236 0 .118 r
.61301 .31868 .61908 .30219 .63264 .30001 .62652 .31045 Mtetra
0 0 0 r
.62652 .31045 .63264 .30001 .6461 .29296 .63986 .29631 Mtetra
.852 .978 .677 r
.63986 .29631 .6461 .29296 .65941 .28132 .653 .27794 Mtetra
.941 .902 .758 r
.653 .27794 .65941 .28132 .67256 .26627 .666 .25762 Mtetra
.894 .799 .748 r
.666 .25762 .67256 .26627 .68559 .24954 .67894 .23753 Mtetra
.847 .739 .744 r
.67894 .23753 .68559 .24954 .69858 .23283 .6919 .21931 Mtetra
.808 .707 .753 r
.6919 .21931 .69858 .23283 .71162 .21746 .70498 .20381 Mtetra
.776 .694 .773 r
.70498 .20381 .71162 .21746 .72476 .20415 .7182 .19118 Mtetra
.748 .693 .799 r
.7182 .19118 .72476 .20415 .73805 .19307 .7316 .18108 Mtetra
.723 .7 .828 r
.7316 .18108 .73805 .19307 .7515 .18398 .74516 .17292 Mtetra
.702 .711 .855 r
.74516 .17292 .7515 .18398 .7651 .17643 .75886 .1661 Mtetra
.686 .721 .876 r
.75886 .1661 .7651 .17643 .77883 .16997 .77269 .16013 Mtetra
.676 .729 .89 r
.77269 .16013 .77883 .16997 .79268 .1642 .78661 .15463 Mtetra
.664 .741 .908 r
.15452 .37038 .16246 .37777 .17361 .37377 .16571 .36635 Mtetra
.16571 .36635 .17361 .37377 .18482 .36976 .17694 .36231 Mtetra
.17694 .36231 .18482 .36976 .19607 .36573 .18822 .35825 Mtetra
.18822 .35825 .19607 .36573 .20737 .36168 .19955 .35416 Mtetra
.19955 .35416 .20737 .36168 .21872 .35762 .21093 .35007 Mtetra
.21093 .35007 .21872 .35762 .23012 .35354 .22236 .34595 Mtetra
.663 .741 .908 r
.22236 .34595 .23012 .35354 .24157 .34944 .23384 .34182 Mtetra
.23384 .34182 .24157 .34944 .25307 .34532 .24537 .33767 Mtetra
.24537 .33767 .25307 .34532 .26462 .34119 .25695 .33351 Mtetra
.25695 .33351 .26462 .34119 .27623 .33705 .26858 .32934 Mtetra
.662 .741 .909 r
.26858 .32934 .27623 .33705 .28788 .3329 .28026 .32519 Mtetra
.658 .741 .911 r
.28026 .32519 .28788 .3329 .29958 .32878 .29199 .32112 Mtetra
.623 .732 .925 r
.29199 .32112 .29958 .32878 .31132 .32477 .3037 .31801 Mtetra
.085 .489 .897 r
.3037 .31801 .31132 .32477 .32307 .32153 .31499 .32202 Mtetra
.792 .322 .116 r
.31499 .32202 .32307 .32153 .3346 .32299 .3257 .33721 Mtetra
.609 .214 .27 r
.3257 .33721 .3346 .32299 .34566 .33415 .33707 .34446 Mtetra
.316 0 .009 r
.33707 .34446 .34566 .33415 .35675 .34803 .34911 .34226 Mtetra
.839 .823 .834 r
.34911 .34226 .35675 .34803 .3685 .3526 .36174 .32995 Mtetra
.747 .592 .684 r
.36174 .32995 .3685 .3526 .38118 .33908 .37461 .3127 Mtetra
.669 .529 .684 r
.37461 .3127 .38118 .33908 .3941 .31963 .38711 .30264 Mtetra
.607 .559 .774 r
.38711 .30264 .3941 .31963 .40662 .30905 .39935 .2995 Mtetra
.537 .655 .911 r
.39935 .2995 .40662 .30905 .41888 .30623 .41157 .29857 Mtetra
.519 .702 .953 r
.41157 .29857 .41888 .30623 .43115 .30565 .42387 .29755 Mtetra
.56 .707 .939 r
.42387 .29755 .43115 .30565 .44351 .30479 .43629 .29578 Mtetra
.6 .699 .913 r
.43629 .29578 .44351 .30479 .45598 .30288 .4488 .29313 Mtetra
.621 .69 .893 r
.4488 .29313 .45598 .30288 .46854 .29979 .4614 .28991 Mtetra
.616 .685 .892 r
.4614 .28991 .46854 .29979 .48119 .2958 .47406 .28682 Mtetra
.57 .69 .922 r
.47406 .28682 .48119 .2958 .49391 .29164 .48678 .28491 Mtetra
.409 .685 .975 r
.48678 .28491 .49391 .29164 .50668 .28834 .49956 .28529 Mtetra
0 .459 .777 r
.49956 .28529 .50668 .28834 .51951 .28705 .51243 .28883 Mtetra
.556 0 0 r
.51243 .28883 .51951 .28705 .53244 .28866 .52543 .29574 Mtetra
.649 .175 .113 r
.52543 .29574 .53244 .28866 .54551 .29346 .5386 .3053 Mtetra
.649 .222 .219 r
.5386 .3053 .54551 .29346 .55874 .30088 .55196 .31573 Mtetra
.615 .208 .247 r
.55196 .31573 .55874 .30088 .57215 .30938 .56549 .32453 Mtetra
.542 .134 .217 r
.56549 .32453 .57215 .30938 .58572 .31674 .57913 .32897 Mtetra
.362 0 .077 r
.57913 .32897 .58572 .31674 .59937 .32049 .59277 .32696 Mtetra
0 0 0 r
.59277 .32696 .59937 .32049 .61301 .31868 .60632 .31768 Mtetra
.901 .97 .815 r
.60632 .31768 .61301 .31868 .62652 .31045 .61969 .30186 Mtetra
.893 .798 .748 r
.61969 .30186 .62652 .31045 .63986 .29631 .63287 .28149 Mtetra
.847 .704 .705 r
.63287 .28149 .63986 .29631 .653 .27794 .64591 .25917 Mtetra
.812 .657 .69 r
.64591 .25917 .653 .27794 .666 .25762 .65887 .23732 Mtetra
.786 .634 .692 r
.65887 .23732 .666 .25762 .67894 .23753 .67186 .2177 Mtetra
.765 .626 .706 r
.67186 .2177 .67894 .23753 .6919 .21931 .68494 .20119 Mtetra
.747 .631 .732 r
.68494 .20119 .6919 .21931 .70498 .20381 .69817 .18787 Mtetra
.73 .646 .765 r
.69817 .18787 .70498 .20381 .7182 .19118 .71156 .17735 Mtetra
.714 .667 .802 r
.71156 .17735 .7182 .19118 .7316 .18108 .72511 .16894 Mtetra
.698 .689 .837 r
.72511 .16894 .7316 .18108 .74516 .17292 .73879 .16199 Mtetra
.685 .708 .865 r
.73879 .16199 .74516 .17292 .75886 .1661 .7526 .15594 Mtetra
.675 .722 .885 r
.7526 .15594 .75886 .1661 .77269 .16013 .76651 .1504 Mtetra
.669 .731 .896 r
.76651 .1504 .77269 .16013 .78661 .15463 .7805 .14511 Mtetra
.664 .741 .908 r
.14652 .36293 .15452 .37038 .16571 .36635 .15773 .35887 Mtetra
.15773 .35887 .16571 .36635 .17694 .36231 .16899 .35479 Mtetra
.16899 .35479 .17694 .36231 .18822 .35825 .1803 .3507 Mtetra
.1803 .3507 .18822 .35825 .19955 .35416 .19166 .34659 Mtetra
.19166 .34659 .19955 .35416 .21093 .35007 .20307 .34245 Mtetra
.20307 .34245 .21093 .35007 .22236 .34595 .21453 .33831 Mtetra
.663 .741 .908 r
.21453 .33831 .22236 .34595 .23384 .34182 .22604 .33414 Mtetra
.22604 .33414 .23384 .34182 .24537 .33767 .2376 .32996 Mtetra
.2376 .32996 .24537 .33767 .25695 .33351 .24921 .32577 Mtetra
.662 .741 .909 r
.24921 .32577 .25695 .33351 .26858 .32934 .26087 .32159 Mtetra
.659 .741 .91 r
.26087 .32159 .26858 .32934 .28026 .32519 .27257 .31748 Mtetra
.601 .725 .932 r
.27257 .31748 .28026 .32519 .29199 .32112 .28422 .31489 Mtetra
.557 .024 0 r
.28422 .31489 .29199 .32112 .3037 .31801 .29498 .3252 Mtetra
.832 .455 .34 r
.29498 .3252 .3037 .31801 .31499 .32202 .30473 .35243 Mtetra
.46 .137 .331 r
.30473 .35243 .31499 .32202 .3257 .33721 .3167 .35024 Mtetra
0 0 0 r
.3167 .35024 .3257 .33721 .33707 .34446 .32958 .33429 Mtetra
.803 .729 .783 r
.32958 .33429 .33707 .34446 .34911 .34226 .34227 .32128 Mtetra
.742 .599 .697 r
.34227 .32128 .34911 .34226 .36174 .32995 .35507 .30598 Mtetra
.673 .543 .697 r
.35507 .30598 .36174 .32995 .37461 .3127 .36755 .29646 Mtetra
.615 .572 .782 r
.36755 .29646 .37461 .3127 .38711 .30264 .37976 .29301 Mtetra
.552 .661 .908 r
.37976 .29301 .38711 .30264 .39935 .2995 .39194 .2917 Mtetra
.531 .704 .95 r
.39194 .2917 .39935 .2995 .41157 .29857 .4042 .29045 Mtetra
.559 .708 .94 r
.4042 .29045 .41157 .29857 .42387 .29755 .41656 .28867 Mtetra
.591 .7 .918 r
.41656 .28867 .42387 .29755 .43629 .29578 .42902 .28625 Mtetra
.606 .69 .902 r
.42902 .28625 .43629 .29578 .4488 .29313 .44156 .28345 Mtetra
.596 .683 .902 r
.44156 .28345 .4488 .29313 .4614 .28991 .45417 .28091 Mtetra
.544 .679 .927 r
.45417 .28091 .4614 .28991 .47406 .28682 .46683 .27959 Mtetra
.386 .658 .966 r
.46683 .27959 .47406 .28682 .48678 .28491 .47955 .28051 Mtetra
0 .478 .84 r
.47955 .28051 .48678 .28491 .49956 .28529 .49234 .28443 Mtetra
.498 0 0 r
.49234 .28443 .49956 .28529 .51243 .28883 .50524 .29149 Mtetra
.642 .11 0 r
.50524 .29149 .51243 .28883 .52543 .29574 .51829 .30091 Mtetra
.658 .161 .056 r
.51829 .30091 .52543 .29574 .5386 .3053 .53153 .31093 Mtetra
.614 .11 .031 r
.53153 .31093 .5386 .3053 .55196 .31573 .54494 .31907 Mtetra
.432 0 0 r
.54494 .31907 .55196 .31573 .56549 .32453 .55848 .32275 Mtetra
.39 .83 .946 r
.55848 .32275 .56549 .32453 .57913 .32897 .57207 .32002 Mtetra
.775 .777 .855 r
.57207 .32002 .57913 .32897 .59277 .32696 .5856 .31023 Mtetra
.782 .661 .73 r
.5856 .31023 .59277 .32696 .60632 .31768 .599 .2942 Mtetra
.769 .607 .678 r
.599 .2942 .60632 .31768 .61969 .30186 .61225 .27395 Mtetra
.755 .579 .658 r
.61225 .27395 .61969 .30186 .63287 .28149 .62538 .252 Mtetra
.744 .566 .654 r
.62538 .252 .63287 .28149 .64591 .25917 .63844 .2307 Mtetra
.734 .564 .662 r
.63844 .2307 .64591 .25917 .65887 .23732 .65152 .21166 Mtetra
.725 .57 .68 r
.65152 .21166 .65887 .23732 .67186 .2177 .66467 .19569 Mtetra
.717 .586 .708 r
.66467 .19569 .67186 .2177 .68494 .20119 .67795 .18283 Mtetra
.709 .611 .745 r
.67795 .18283 .68494 .20119 .69817 .18787 .69137 .17262 Mtetra
.7 .641 .787 r
.69137 .17262 .69817 .18787 .71156 .17735 .70494 .16442 Mtetra
.691 .672 .827 r
.70494 .16442 .71156 .17735 .72511 .16894 .71862 .1576 Mtetra
.681 .699 .86 r
.71862 .1576 .72511 .16894 .73879 .16199 .73242 .15161 Mtetra
.674 .718 .882 r
.73242 .15161 .73879 .16199 .7526 .15594 .74631 .14609 Mtetra
.669 .729 .895 r
.74631 .14609 .7526 .15594 .76651 .1504 .76029 .1408 Mtetra
.666 .736 .902 r
.76029 .1408 .76651 .1504 .7805 .14511 .77434 .13562 Mtetra
.664 .741 .908 r
.13846 .35542 .14652 .36293 .15773 .35887 .1497 .35133 Mtetra
.1497 .35133 .15773 .35887 .16899 .35479 .16098 .34722 Mtetra
.16098 .34722 .16899 .35479 .1803 .3507 .17232 .34309 Mtetra
.17232 .34309 .1803 .3507 .19166 .34659 .18371 .33894 Mtetra
.18371 .33894 .19166 .34659 .20307 .34245 .19515 .33478 Mtetra
.663 .741 .908 r
.19515 .33478 .20307 .34245 .21453 .33831 .20663 .3306 Mtetra
.20663 .3306 .21453 .33831 .22604 .33414 .21817 .3264 Mtetra
.21817 .3264 .22604 .33414 .2376 .32996 .22976 .32219 Mtetra
.663 .741 .909 r
.22976 .32219 .2376 .32996 .24921 .32577 .2414 .31798 Mtetra
.659 .741 .91 r
.2414 .31798 .24921 .32577 .26087 .32159 .25309 .31385 Mtetra
.557 .709 .942 r
.25309 .31385 .26087 .32159 .27257 .31748 .26462 .31219 Mtetra
.87 .427 .097 r
.26462 .31219 .27257 .31748 .28422 .31489 .27439 .33358 Mtetra
.839 .514 .439 r
.27439 .33358 .28422 .31489 .29498 .3252 .28219 .38423 Mtetra
.372 .106 .375 r
.28219 .38423 .29498 .3252 .30473 .35243 .29518 .36909 Mtetra
.938 .901 .507 r
.29518 .36909 .30473 .35243 .3167 .35024 .30982 .32944 Mtetra
.751 .604 .695 r
.30982 .32944 .3167 .35024 .32958 .33429 .32275 .31316 Mtetra
.728 .59 .701 r
.32275 .31316 .32958 .33429 .34227 .32128 .33548 .29949 Mtetra
.677 .557 .712 r
.33548 .29949 .34227 .32128 .35507 .30598 .34792 .29051 Mtetra
.622 .585 .792 r
.34792 .29051 .35507 .30598 .36755 .29646 .36011 .2868 Mtetra
.568 .668 .906 r
.36011 .2868 .36755 .29646 .37976 .29301 .37226 .28507 Mtetra
.546 .707 .946 r
.37226 .28507 .37976 .29301 .39194 .2917 .38448 .28353 Mtetra
.565 .709 .938 r
.38448 .28353 .39194 .2917 .4042 .29045 .3968 .2816 Mtetra
.59 .701 .92 r
.3968 .2816 .4042 .29045 .41656 .28867 .40921 .27917 Mtetra
.603 .69 .904 r
.40921 .27917 .41656 .28867 .42902 .28625 .4217 .27643 Mtetra
.595 .68 .9 r
.4217 .27643 .42902 .28625 .44156 .28345 .43426 .2739 Mtetra
.556 .671 .914 r
.43426 .2739 .44156 .28345 .45417 .28091 .44687 .27235 Mtetra
.456 .653 .944 r
.44687 .27235 .45417 .28091 .46683 .27959 .45953 .27264 Mtetra
.233 .582 .945 r
.45953 .27264 .46683 .27959 .47955 .28051 .47225 .27538 Mtetra
0 .399 .801 r
.47225 .27538 .47955 .28051 .49234 .28443 .48505 .28067 Mtetra
.358 0 0 r
.48505 .28067 .49234 .28443 .50524 .29149 .49798 .2878 Mtetra
.378 0 0 r
.49798 .2878 .50524 .29149 .51829 .30091 .51107 .29526 Mtetra
0 .399 .815 r
.51107 .29526 .51829 .30091 .53153 .31093 .52433 .30095 Mtetra
.402 .592 .921 r
.52433 .30095 .53153 .31093 .54494 .31907 .53773 .30274 Mtetra
.614 .584 .796 r
.53773 .30274 .54494 .31907 .55848 .32275 .5512 .29907 Mtetra
.673 .553 .71 r
.5512 .29907 .55848 .32275 .57207 .32002 .56467 .28949 Mtetra
.692 .532 .665 r
.56467 .28949 .57207 .32002 .5856 .31023 .57807 .27479 Mtetra
.698 .521 .644 r
.57807 .27479 .5856 .31023 .599 .2942 .59138 .25669 Mtetra
.699 .516 .637 r
.59138 .25669 .599 .2942 .61225 .27395 .60461 .23734 Mtetra
.698 .517 .639 r
.60461 .23734 .61225 .27395 .62538 .252 .61779 .21864 Mtetra
.696 .524 .651 r
.61779 .21864 .62538 .252 .63844 .2307 .63099 .20195 Mtetra
.694 .539 .671 r
.63099 .20195 .63844 .2307 .65152 .21166 .64425 .18786 Mtetra
.693 .562 .702 r
.64425 .18786 .65152 .21166 .66467 .19569 .6576 .17637 Mtetra
.691 .593 .741 r
.6576 .17637 .66467 .19569 .67795 .18283 .67108 .1671 Mtetra
.688 .63 .785 r
.67108 .1671 .67795 .18283 .69137 .17262 .68466 .15949 Mtetra
.683 .666 .827 r
.68466 .15949 .69137 .17262 .70494 .16442 .69836 .15299 Mtetra
.677 .696 .86 r
.69836 .15299 .70494 .16442 .71862 .1576 .71215 .14717 Mtetra
.671 .716 .883 r
.71215 .14717 .71862 .1576 .73242 .15161 .72603 .14173 Mtetra
.667 .729 .896 r
.72603 .14173 .73242 .15161 .74631 .14609 .74 .13647 Mtetra
.665 .736 .902 r
.74 .13647 .74631 .14609 .76029 .1408 .75403 .13128 Mtetra
.664 .739 .906 r
.75403 .13128 .76029 .1408 .77434 .13562 .76814 .12611 Mtetra
.664 .741 .908 r
.13033 .34785 .13846 .35542 .1497 .35133 .1416 .34373 Mtetra
.1416 .34373 .1497 .35133 .16098 .34722 .15291 .33958 Mtetra
.15291 .33958 .16098 .34722 .17232 .34309 .16428 .33542 Mtetra
.16428 .33542 .17232 .34309 .18371 .33894 .17569 .33124 Mtetra
.663 .741 .908 r
.17569 .33124 .18371 .33894 .19515 .33478 .18716 .32704 Mtetra
.18716 .32704 .19515 .33478 .20663 .3306 .19868 .32283 Mtetra
.19868 .32283 .20663 .3306 .21817 .3264 .21024 .3186 Mtetra
.21024 .3186 .21817 .3264 .22976 .32219 .22186 .31436 Mtetra
.659 .74 .91 r
.22186 .31436 .22976 .32219 .2414 .31798 .23352 .31023 Mtetra
.488 .682 .952 r
.23352 .31023 .2414 .31798 .25309 .31385 .24491 .30978 Mtetra
.921 .549 .297 r
.24491 .30978 .25309 .31385 .26462 .31219 .25323 .34594 Mtetra
.842 .541 .479 r
.25323 .34594 .26462 .31219 .27439 .33358 .25788 .43109 Mtetra
.338 .1 .398 r
.25788 .43109 .27439 .33358 .28219 .38423 .2723 .40074 Mtetra
.999 .829 .534 r
.2723 .40074 .28219 .38423 .29518 .36909 .28976 .32777 Mtetra
.703 .511 .626 r
.28976 .32777 .29518 .36909 .30982 .32944 .30316 .30564 Mtetra
.702 .561 .692 r
.30316 .30564 .30982 .32944 .32275 .31316 .31583 .29326 Mtetra
.68 .572 .727 r
.31583 .29326 .32275 .31316 .33548 .29949 .32824 .28481 Mtetra
.629 .6 .801 r
.32824 .28481 .33548 .29949 .34792 .29051 .3404 .28085 Mtetra
.582 .675 .903 r
.3404 .28085 .34792 .29051 .36011 .2868 .35253 .27872 Mtetra
.563 .711 .941 r
.35253 .27872 .36011 .2868 .37226 .28507 .36471 .27683 Mtetra
.576 .712 .935 r
.36471 .27683 .37226 .28507 .38448 .28353 .37699 .27465 Mtetra
.596 .703 .918 r
.37699 .27465 .38448 .28353 .3968 .2816 .38936 .27204 Mtetra
.609 .692 .902 r
.38936 .27204 .3968 .2816 .40921 .27917 .40182 .26909 Mtetra
.609 .68 .892 r
.40182 .26909 .40921 .27917 .4217 .27643 .41434 .26617 Mtetra
.588 .668 .894 r
.41434 .26617 .4217 .27643 .43426 .2739 .42692 .26383 Mtetra
.54 .652 .908 r
.42692 .26383 .43426 .2739 .44687 .27235 .43954 .26272 Mtetra
.456 .624 .924 r
.43954 .26272 .44687 .27235 .45953 .27264 .45221 .26332 Mtetra
.348 .576 .926 r
.45221 .26332 .45953 .27264 .47225 .27538 .46495 .2657 Mtetra
.28 .528 .91 r
.46495 .2657 .47225 .27538 .48505 .28067 .47779 .26935 Mtetra
.323 .51 .886 r
.47779 .26935 .48505 .28067 .49798 .2878 .49076 .27313 Mtetra
.441 .511 .834 r
.49076 .27313 .49798 .2878 .51107 .29526 .50387 .27553 Mtetra
.543 .505 .764 r
.50387 .27553 .51107 .29526 .52433 .30095 .51711 .27501 Mtetra
.603 .496 .705 r
.51711 .27501 .52433 .30095 .53773 .30274 .53045 .2705 Mtetra
.634 .489 .667 r
.53045 .2705 .53773 .30274 .5512 .29907 .54383 .26173 Mtetra
.651 .485 .645 r
.54383 .26173 .5512 .29907 .56467 .28949 .5572 .24933 Mtetra
.661 .484 .635 r
.5572 .24933 .56467 .28949 .57807 .27479 .57053 .23457 Mtetra
.666 .487 .634 r
.57053 .23457 .57807 .27479 .59138 .25669 .58383 .21901 Mtetra
.669 .495 .641 r
.58383 .21901 .59138 .25669 .60461 .23734 .59711 .20401 Mtetra
.672 .508 .655 r
.59711 .20401 .60461 .23734 .61779 .21864 .61041 .19052 Mtetra
.674 .529 .679 r
.61041 .19052 .61779 .21864 .63099 .20195 .62375 .17896 Mtetra
.677 .557 .712 r
.62375 .17896 .63099 .20195 .64425 .18786 .63718 .1693 Mtetra
.679 .594 .753 r
.63718 .1693 .64425 .18786 .6576 .17637 .6507 .16124 Mtetra
.679 .633 .797 r
.6507 .16124 .6576 .17637 .67108 .1671 .66431 .15437 Mtetra
.676 .671 .837 r
.66431 .15437 .67108 .1671 .68466 .15949 .67801 .14829 Mtetra
.672 .7 .867 r
.67801 .14829 .68466 .15949 .69836 .15299 .6918 .14268 Mtetra
.669 .719 .887 r
.6918 .14268 .69836 .15299 .71215 .14717 .70567 .13733 Mtetra
.666 .73 .898 r
.70567 .13733 .71215 .14717 .72603 .14173 .71962 .1321 Mtetra
.665 .736 .903 r
.71962 .1321 .72603 .14173 .74 .13647 .73363 .12692 Mtetra
.664 .739 .906 r
.73363 .12692 .74 .13647 .75403 .13128 .74772 .12174 Mtetra
.664 .74 .907 r
.74772 .12174 .75403 .13128 .76814 .12611 .76188 .11654 Mtetra
.664 .741 .908 r
.12213 .34022 .13033 .34785 .1416 .34373 .13343 .33606 Mtetra
.13343 .33606 .1416 .34373 .15291 .33958 .14477 .33188 Mtetra
.14477 .33188 .15291 .33958 .16428 .33542 .15616 .32769 Mtetra
.15616 .32769 .16428 .33542 .17569 .33124 .16761 .32347 Mtetra
.663 .741 .908 r
.16761 .32347 .17569 .33124 .18716 .32704 .1791 .31924 Mtetra
.1791 .31924 .18716 .32704 .19868 .32283 .19065 .31499 Mtetra
.19065 .31499 .19868 .32283 .21024 .3186 .20225 .31074 Mtetra
.659 .74 .91 r
.20225 .31074 .21024 .3186 .22186 .31436 .21389 .30659 Mtetra
.413 .649 .955 r
.21389 .30659 .22186 .31436 .23352 .31023 .22512 .30724 Mtetra
.929 .589 .37 r
.22512 .30724 .23352 .31023 .24491 .30978 .23184 .35775 Mtetra
.845 .554 .497 r
.23184 .35775 .24491 .30978 .25323 .34594 .23261 .48064 Mtetra
.326 .099 .408 r
.23261 .48064 .25323 .34594 .25788 .43109 .2485 .43689 Mtetra
.972 .752 .548 r
.2485 .43689 .25788 .43109 .2723 .40074 .26946 .32783 Mtetra
.668 .455 .587 r
.26946 .32783 .2723 .40074 .28976 .32777 .2835 .29866 Mtetra
.671 .519 .67 r
.2835 .29866 .28976 .32777 .30316 .30564 .29611 .28728 Mtetra
.681 .585 .742 r
.29611 .28728 .30316 .30564 .31583 .29326 .30848 .27934 Mtetra
.636 .615 .812 r
.30848 .27934 .31583 .29326 .32824 .28481 .32063 .27517 Mtetra
.596 .682 .901 r
.32063 .27517 .32824 .28481 .3404 .28085 .33273 .27265 Mtetra
.579 .715 .936 r
.33273 .27265 .3404 .28085 .35253 .27872 .34489 .27039 Mtetra
.588 .716 .932 r
.34489 .27039 .35253 .27872 .36471 .27683 .35713 .26791 Mtetra
.605 .707 .916 r
.35713 .26791 .36471 .27683 .37699 .27465 .36947 .26503 Mtetra
.62 .696 .899 r
.36947 .26503 .37699 .27465 .38936 .27204 .3819 .26176 Mtetra
.625 .683 .885 r
.3819 .26176 .38936 .27204 .40182 .26909 .3944 .25829 Mtetra
.619 .67 .877 r
.3944 .25829 .40182 .26909 .41434 .26617 .40696 .25499 Mtetra
.599 .654 .876 r
.40696 .25499 .41434 .26617 .42692 .26383 .41957 .25232 Mtetra
.567 .633 .877 r
.41957 .25232 .42692 .26383 .43954 .26272 .43222 .25061 Mtetra
.531 .604 .871 r
.43222 .25061 .43954 .26272 .45221 .26332 .44494 .24997 Mtetra
.51 .57 .852 r
.44494 .24997 .45221 .26332 .46495 .2657 .45772 .25009 Mtetra
.517 .538 .816 r
.45772 .25009 .46495 .2657 .47779 .26935 .47061 .25027 Mtetra
.546 .512 .769 r
.47061 .25027 .47779 .26935 .49076 .27313 .48362 .24956 Mtetra
.577 .494 .724 r
.48362 .24956 .49076 .27313 .50387 .27553 .49674 .247 Mtetra
.603 .482 .688 r
.49674 .247 .50387 .27553 .51711 .27501 .50995 .24195 Mtetra
.621 .477 .664 r
.50995 .24195 .51711 .27501 .53045 .2705 .52322 .23425 Mtetra
.634 .475 .65 r
.52322 .23425 .53045 .2705 .54383 .26173 .53653 .22432 Mtetra
.642 .478 .645 r
.53653 .22432 .54383 .26173 .5572 .24933 .54984 .21298 Mtetra
.649 .484 .648 r
.54984 .21298 .5572 .24933 .57053 .23457 .56316 .2012 Mtetra
.654 .496 .658 r
.56316 .2012 .57053 .23457 .58383 .21901 .57649 .18984 Mtetra
.659 .515 .677 r
.57649 .18984 .58383 .21901 .59711 .20401 .58984 .17947 Mtetra
.663 .54 .704 r
.58984 .17947 .59711 .20401 .61041 .19052 .60325 .17034 Mtetra
.668 .573 .739 r
.60325 .17034 .61041 .19052 .62375 .17896 .61672 .16241 Mtetra
.671 .612 .78 r
.61672 .16241 .62375 .17896 .63718 .1693 .63026 .15549 Mtetra
.673 .651 .82 r
.63026 .15549 .63718 .1693 .6507 .16124 .64389 .14931 Mtetra
.671 .684 .854 r
.64389 .14931 .6507 .16124 .66431 .15437 .65759 .14361 Mtetra
.669 .709 .878 r
.65759 .14361 .66431 .15437 .67801 .14829 .67137 .1382 Mtetra
.666 .724 .892 r
.67137 .1382 .67801 .14829 .6918 .14268 .68523 .13293 Mtetra
.665 .733 .901 r
.68523 .13293 .6918 .14268 .70567 .13733 .69915 .12773 Mtetra
.664 .738 .905 r
.69915 .12773 .70567 .13733 .71962 .1321 .71315 .12254 Mtetra
.664 .74 .907 r
.71315 .12254 .71962 .1321 .73363 .12692 .72722 .11735 Mtetra
.664 .741 .907 r
.72722 .11735 .73363 .12692 .74772 .12174 .74135 .11214 Mtetra
.664 .741 .908 r
.74135 .11214 .74772 .12174 .76188 .11654 .75556 .1069 Mtetra
.11387 .33253 .12213 .34022 .13343 .33606 .12519 .32833 Mtetra
.12519 .32833 .13343 .33606 .14477 .33188 .13656 .32412 Mtetra
.13656 .32412 .14477 .33188 .15616 .32769 .14799 .31989 Mtetra
.663 .741 .908 r
.14799 .31989 .15616 .32769 .16761 .32347 .15946 .31564 Mtetra
.15946 .31564 .16761 .32347 .1791 .31924 .17098 .31138 Mtetra
.17098 .31138 .1791 .31924 .19065 .31499 .18256 .3071 Mtetra
.659 .74 .91 r
.18256 .3071 .19065 .31499 .20225 .31074 .19417 .30293 Mtetra
.373 .63 .954 r
.19417 .30293 .20225 .31074 .21389 .30659 .2053 .30407 Mtetra
.93 .603 .396 r
.2053 .30407 .21389 .30659 .22512 .30724 .21085 .36268 Mtetra
.849 .563 .503 r
.21085 .36268 .22512 .30724 .23184 .35775 .20834 .51153 Mtetra
.322 .097 .409 r
.20834 .51153 .23184 .35775 .23261 .48064 .22514 .46171 Mtetra
.925 .686 .559 r
.22514 .46171 .23261 .48064 .2485 .43689 .24912 .32677 Mtetra
.643 .421 .566 r
.24912 .32677 .2485 .43689 .26946 .32783 .26378 .29208 Mtetra
.643 .48 .647 r
.26378 .29208 .26946 .32783 .2835 .29866 .27633 .28155 Mtetra
.681 .597 .755 r
.27633 .28155 .2835 .29866 .29611 .28728 .28865 .27409 Mtetra
.643 .63 .822 r
.28865 .27409 .29611 .28728 .30848 .27934 .30078 .26975 Mtetra
.608 .689 .9 r
.30078 .26975 .30848 .27934 .32063 .27517 .31287 .26687 Mtetra
.593 .718 .931 r
.31287 .26687 .32063 .27517 .33273 .27265 .325 .26426 Mtetra
.6 .719 .928 r
.325 .26426 .33273 .27265 .34489 .27039 .33722 .26147 Mtetra
.615 .711 .914 r
.33722 .26147 .34489 .27039 .35713 .26791 .34953 .25831 Mtetra
.63 .701 .897 r
.34953 .25831 .35713 .26791 .36947 .26503 .36193 .25472 Mtetra
.639 .689 .88 r
.36193 .25472 .36947 .26503 .3819 .26176 .37441 .25077 Mtetra
.642 .676 .867 r
.37441 .25077 .3819 .26176 .3944 .25829 .38696 .24667 Mtetra
.636 .661 .858 r
.38696 .24667 .3944 .25829 .40696 .25499 .39957 .2427 Mtetra
.623 .644 .85 r
.39957 .2427 .40696 .25499 .41957 .25232 .41222 .23914 Mtetra
.606 .621 .84 r
.41222 .23914 .41957 .25232 .43222 .25061 .42493 .2361 Mtetra
.593 .594 .822 r
.42493 .2361 .43222 .25061 .44494 .24997 .43771 .23347 Mtetra
.589 .564 .794 r
.43771 .23347 .44494 .24997 .45772 .25009 .45055 .2309 Mtetra
.593 .537 .762 r
.45055 .2309 .45772 .25009 .47061 .25027 .46349 .22788 Mtetra
.602 .516 .73 r
.46349 .22788 .47061 .25027 .48362 .24956 .47652 .22389 Mtetra
.613 .502 .704 r
.47652 .22389 .48362 .24956 .49674 .247 .48963 .21857 Mtetra
.622 .494 .686 r
.48963 .21857 .49674 .247 .50995 .24195 .50281 .21186 Mtetra
.63 .493 .676 r
.50281 .21186 .50995 .24195 .52322 .23425 .51604 .20398 Mtetra
.637 .496 .674 r
.51604 .20398 .52322 .23425 .53653 .22432 .52931 .19538 Mtetra
.643 .506 .68 r
.52931 .19538 .53653 .22432 .54984 .21298 .54261 .18658 Mtetra
.649 .521 .694 r
.54261 .18658 .54984 .21298 .56316 .2012 .55594 .17804 Mtetra
.655 .544 .716 r
.55594 .17804 .56316 .2012 .57649 .18984 .56932 .17008 Mtetra
.661 .573 .745 r
.56932 .17008 .57649 .18984 .58984 .17947 .58274 .1628 Mtetra
.666 .607 .78 r
.58274 .1628 .58984 .17947 .60325 .17034 .59623 .15619 Mtetra
.668 .643 .816 r
.59623 .15619 .60325 .17034 .61672 .16241 .60978 .15012 Mtetra
.669 .676 .848 r
.60978 .15012 .61672 .16241 .63026 .15549 .6234 .14445 Mtetra
.668 .702 .872 r
.6234 .14445 .63026 .15549 .64389 .14931 .6371 .13903 Mtetra
.666 .719 .888 r
.6371 .13903 .64389 .14931 .65759 .14361 .65086 .13375 Mtetra
.665 .73 .898 r
.65086 .13375 .65759 .14361 .67137 .1382 .6647 .12853 Mtetra
.664 .736 .903 r
.6647 .12853 .67137 .1382 .68523 .13293 .6786 .12334 Mtetra
.664 .739 .906 r
.6786 .12334 .68523 .13293 .69915 .12773 .69258 .11815 Mtetra
.664 .74 .907 r
.69258 .11815 .69915 .12773 .71315 .12254 .70663 .11294 Mtetra
.664 .741 .908 r
.70663 .11294 .71315 .12254 .72722 .11735 .72074 .10771 Mtetra
.72074 .10771 .72722 .11735 .74135 .11214 .73493 .10245 Mtetra
.73493 .10245 .74135 .11214 .75556 .1069 .74918 .09717 Mtetra
.10554 .32477 .11387 .33253 .12519 .32833 .11689 .32054 Mtetra
.11689 .32054 .12519 .32833 .13656 .32412 .12829 .31629 Mtetra
.12829 .31629 .13656 .32412 .14799 .31989 .13974 .31203 Mtetra
.663 .741 .908 r
.13974 .31203 .14799 .31989 .15946 .31564 .15124 .30775 Mtetra
.15124 .30775 .15946 .31564 .17098 .31138 .1628 .30345 Mtetra
.659 .74 .91 r
.1628 .30345 .17098 .31138 .18256 .3071 .17439 .29925 Mtetra
.399 .643 .955 r
.17439 .29925 .18256 .3071 .19417 .30293 .18549 .30001 Mtetra
.93 .602 .394 r
.18549 .30001 .19417 .30293 .2053 .30407 .19083 .3565 Mtetra
.854 .567 .503 r
.19083 .3565 .2053 .30407 .21085 .36268 .18721 .50612 Mtetra
.319 .091 .402 r
.18721 .50612 .21085 .36268 .20834 .51153 .20388 .46043 Mtetra
.874 .629 .565 r
.20388 .46043 .20834 .51153 .22514 .46171 .22904 .32172 Mtetra
.624 .399 .555 r
.22904 .32172 .22514 .46171 .24912 .32677 .24399 .28573 Mtetra
.622 .453 .632 r
.24399 .28573 .24912 .32677 .26378 .29208 .25647 .27607 Mtetra
.68 .609 .769 r
.25647 .27607 .26378 .29208 .27633 .28155 .26875 .26905 Mtetra
.648 .644 .832 r
.26875 .26905 .27633 .28155 .28865 .27409 .28086 .26458 Mtetra
.618 .696 .899 r
.28086 .26458 .28865 .27409 .30078 .26975 .29293 .26137 Mtetra
.606 .722 .927 r
.29293 .26137 .30078 .26975 .31287 .26687 .30504 .25843 Mtetra
.611 .723 .925 r
.30504 .25843 .31287 .26687 .325 .26426 .31724 .25536 Mtetra
.623 .716 .913 r
.31724 .25536 .325 .26426 .33722 .26147 .32952 .25196 Mtetra
.637 .706 .897 r
.32952 .25196 .33722 .26147 .34953 .25831 .34189 .24813 Mtetra
.649 .696 .88 r
.34189 .24813 .34953 .25831 .36193 .25472 .35435 .24385 Mtetra
.655 .684 .865 r
.35435 .24385 .36193 .25472 .37441 .25077 .36689 .23924 Mtetra
.657 .672 .853 r
.36689 .23924 .37441 .25077 .38696 .24667 .37949 .23446 Mtetra
.652 .659 .843 r
.37949 .23446 .38696 .24667 .39957 .2427 .39215 .22973 Mtetra
.645 .642 .833 r
.39215 .22973 .39957 .2427 .41222 .23914 .40487 .22517 Mtetra
.636 .623 .82 r
.40487 .22517 .41222 .23914 .42493 .2361 .41763 .22081 Mtetra
.629 .601 .803 r
.41763 .22081 .42493 .2361 .43771 .23347 .43046 .21652 Mtetra
.626 .579 .782 r
.43046 .21652 .43771 .23347 .45055 .2309 .44336 .21209 Mtetra
.626 .56 .76 r
.44336 .21209 .45055 .2309 .46349 .22788 .45633 .20727 Mtetra
.629 .546 .742 r
.45633 .20727 .46349 .22788 .47652 .22389 .46937 .2019 Mtetra
.633 .538 .729 r
.46937 .2019 .47652 .22389 .48963 .21857 .48247 .19591 Mtetra
.638 .536 .722 r
.48247 .19591 .48963 .21857 .50281 .21186 .49564 .18942 Mtetra
.643 .541 .724 r
.49564 .18942 .50281 .21186 .51604 .20398 .50885 .18262 Mtetra
.648 .552 .732 r
.50885 .18262 .51604 .20398 .52931 .19538 .52212 .17575 Mtetra
.653 .569 .748 r
.52212 .17575 .52931 .19538 .54261 .18658 .53543 .16904 Mtetra
.658 .593 .771 r
.53543 .16904 .54261 .18658 .55594 .17804 .54879 .1626 Mtetra
.663 .621 .798 r
.54879 .1626 .55594 .17804 .56932 .17008 .56221 .15649 Mtetra
.666 .651 .826 r
.56221 .15649 .56932 .17008 .58274 .1628 .57569 .1507 Mtetra
.667 .679 .852 r
.57569 .1507 .58274 .1628 .59623 .15619 .58923 .14516 Mtetra
.667 .702 .873 r
.58923 .14516 .59623 .15619 .60978 .15012 .60284 .13979 Mtetra
.666 .718 .888 r
.60284 .13979 .60978 .15012 .6234 .14445 .61652 .13453 Mtetra
.665 .729 .897 r
.61652 .13453 .6234 .14445 .6371 .13903 .63027 .12933 Mtetra
.664 .735 .903 r
.63027 .12933 .6371 .13903 .65086 .13375 .64409 .12414 Mtetra
.664 .738 .905 r
.64409 .12414 .65086 .13375 .6647 .12853 .65797 .11895 Mtetra
.664 .74 .907 r
.65797 .11895 .6647 .12853 .6786 .12334 .67193 .11374 Mtetra
.664 .741 .907 r
.67193 .11374 .6786 .12334 .69258 .11815 .68595 .10851 Mtetra
.664 .741 .908 r
.68595 .10851 .69258 .11815 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.09714 .31695 .10554 .32477 .11689 .32054 .10852 .31268 Mtetra
.10852 .31268 .11689 .32054 .12829 .31629 .11995 .3084 Mtetra
.663 .741 .908 r
.11995 .3084 .12829 .31629 .13974 .31203 .13143 .3041 Mtetra
.13143 .3041 .13974 .31203 .15124 .30775 .14296 .29979 Mtetra
.66 .741 .909 r
.14296 .29979 .15124 .30775 .1628 .30345 .15453 .29554 Mtetra
.474 .677 .954 r
.15453 .29554 .1628 .30345 .17439 .29925 .1657 .29521 Mtetra
.928 .584 .36 r
.1657 .29521 .17439 .29925 .18549 .30001 .17189 .34029 Mtetra
.858 .568 .497 r
.17189 .34029 .18549 .30001 .19083 .3565 .16991 .46477 Mtetra
.312 .073 .381 r
.16991 .46477 .19083 .3565 .18721 .50612 .18547 .43058 Mtetra
.825 .581 .57 r
.18547 .43058 .18721 .50612 .20388 .46043 .2094 .31172 Mtetra
.61 .385 .551 r
.2094 .31172 .20388 .46043 .22904 .32172 .22414 .27952 Mtetra
.612 .443 .629 r
.22414 .27952 .22904 .32172 .24399 .28573 .23653 .27081 Mtetra
.679 .622 .784 r
.23653 .27081 .24399 .28573 .25647 .27607 .24876 .26419 Mtetra
.653 .658 .843 r
.24876 .26419 .25647 .27607 .26875 .26905 .26085 .25962 Mtetra
.627 .702 .899 r
.26085 .25962 .26875 .26905 .28086 .26458 .27291 .25614 Mtetra
.617 .725 .923 r
.27291 .25614 .28086 .26458 .29293 .26137 .28501 .2529 Mtetra
.62 .726 .922 r
.28501 .2529 .29293 .26137 .30504 .25843 .29718 .24957 Mtetra
.629 .72 .912 r
.29718 .24957 .30504 .25843 .31724 .25536 .30943 .24598 Mtetra
.642 .712 .899 r
.30943 .24598 .31724 .25536 .32952 .25196 .32178 .24198 Mtetra
.653 .703 .883 r
.32178 .24198 .32952 .25196 .34189 .24813 .33422 .23754 Mtetra
.662 .694 .869 r
.33422 .23754 .34189 .24813 .35435 .24385 .34673 .23269 Mtetra
.667 .684 .857 r
.34673 .23269 .35435 .24385 .36689 .23924 .35933 .22754 Mtetra
.668 .675 .847 r
.35933 .22754 .36689 .23924 .37949 .23446 .37198 .22223 Mtetra
.665 .665 .84 r
.37198 .22223 .37949 .23446 .39215 .22973 .38469 .21692 Mtetra
.661 .654 .832 r
.38469 .21692 .39215 .22973 .40487 .22517 .39745 .21169 Mtetra
.655 .641 .824 r
.39745 .21169 .40487 .22517 .41763 .22081 .41026 .20654 Mtetra
.651 .627 .813 r
.41026 .20654 .41763 .22081 .43046 .21652 .42313 .2014 Mtetra
.648 .614 .802 r
.42313 .2014 .43046 .21652 .44336 .21209 .43606 .1962 Mtetra
.648 .604 .792 r
.43606 .1962 .44336 .21209 .45633 .20727 .44905 .19084 Mtetra
.648 .599 .785 r
.44905 .19084 .45633 .20727 .46937 .2019 .4621 .1853 Mtetra
.65 .598 .783 r
.4621 .1853 .46937 .2019 .48247 .19591 .47521 .1796 Mtetra
.653 .604 .786 r
.47521 .1796 .48247 .19591 .49564 .18942 .48838 .1738 Mtetra
.657 .615 .796 r
.48838 .1738 .49564 .18942 .50885 .18262 .50161 .16799 Mtetra
.66 .631 .81 r
.50161 .16799 .50885 .18262 .52212 .17575 .51489 .16226 Mtetra
.663 .65 .828 r
.51489 .16226 .52212 .17575 .53543 .16904 .52823 .15664 Mtetra
.664 .671 .847 r
.52823 .15664 .53543 .16904 .54879 .1626 .54163 .15115 Mtetra
.665 .691 .864 r
.54163 .15115 .54879 .1626 .56221 .15649 .55509 .14579 Mtetra
.665 .708 .879 r
.55509 .14579 .56221 .15649 .57569 .1507 .56861 .14051 Mtetra
.665 .721 .891 r
.56861 .14051 .57569 .1507 .58923 .14516 .58221 .1353 Mtetra
.664 .73 .898 r
.58221 .1353 .58923 .14516 .60284 .13979 .59587 .13011 Mtetra
.664 .735 .903 r
.59587 .13011 .60284 .13979 .61652 .13453 .60959 .12493 Mtetra
.664 .738 .905 r
.60959 .12493 .61652 .13453 .63027 .12933 .62339 .11975 Mtetra
.664 .74 .907 r
.62339 .11975 .63027 .12933 .64409 .12414 .63725 .11454 Mtetra
.664 .741 .907 r
.63725 .11454 .64409 .12414 .65797 .11895 .65119 .10932 Mtetra
.664 .741 .908 r
.65119 .10932 .65797 .11895 .67193 .11374 .66519 .10407 Mtetra
.66519 .10407 .67193 .11374 .68595 .10851 .67926 .0988 Mtetra
.67926 .0988 .68595 .10851 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.08867 .30906 .09714 .31695 .10852 .31268 .10008 .30476 Mtetra
.663 .741 .908 r
.10008 .30476 .10852 .31268 .11995 .3084 .11153 .30045 Mtetra
.11153 .30045 .11995 .3084 .13143 .3041 .12304 .29611 Mtetra
.662 .741 .909 r
.12304 .29611 .13143 .3041 .14296 .29979 .13459 .29181 Mtetra
.552 .707 .943 r
.13459 .29181 .14296 .29979 .15453 .29554 .14588 .29012 Mtetra
.914 .527 .259 r
.14588 .29012 .15453 .29554 .1657 .29521 .15356 .31958 Mtetra
.863 .563 .478 r
.15356 .31958 .1657 .29521 .17189 .34029 .15506 .4055 Mtetra
.287 .025 .33 r
.15506 .4055 .17189 .34029 .16991 .46477 .16918 .38404 Mtetra
.781 .543 .576 r
.16918 .38404 .16991 .46477 .18547 .43058 .19012 .29844 Mtetra
.599 .378 .552 r
.19012 .29844 .18547 .43058 .2094 .31172 .20423 .27346 Mtetra
.61 .45 .64 r
.20423 .27346 .2094 .31172 .22414 .27952 .21652 .26575 Mtetra
.679 .638 .801 r
.21652 .26575 .22414 .27952 .23653 .27081 .22869 .2595 Mtetra
.656 .671 .852 r
.22869 .2595 .23653 .27081 .24876 .26419 .24076 .25485 Mtetra
.635 .708 .899 r
.24076 .25485 .24876 .26419 .26085 .25962 .2528 .25113 Mtetra
.626 .728 .92 r
.2528 .25113 .26085 .25962 .27291 .25614 .26489 .24764 Mtetra
.627 .729 .92 r
.26489 .24764 .27291 .25614 .28501 .2529 .27704 .24409 Mtetra
.634 .724 .912 r
.27704 .24409 .28501 .2529 .29718 .24957 .28927 .24032 Mtetra
.645 .717 .901 r
.28927 .24032 .29718 .24957 .30943 .24598 .30159 .23623 Mtetra
.655 .71 .888 r
.30159 .23623 .30943 .24598 .32178 .24198 .314 .23172 Mtetra
.665 .702 .875 r
.314 .23172 .32178 .24198 .33422 .23754 .32649 .22681 Mtetra
.671 .696 .864 r
.32649 .22681 .33422 .23754 .34673 .23269 .33906 .22156 Mtetra
.675 .689 .856 r
.33906 .22156 .34673 .23269 .35933 .22754 .35169 .21609 Mtetra
.675 .684 .851 r
.35169 .21609 .35933 .22754 .37198 .22223 .36439 .21052 Mtetra
.673 .679 .848 r
.36439 .21052 .37198 .22223 .38469 .21692 .37713 .20497 Mtetra
.67 .674 .845 r
.37713 .20497 .38469 .21692 .39745 .21169 .38993 .19948 Mtetra
.666 .669 .843 r
.38993 .19948 .39745 .21169 .41026 .20654 .40277 .19408 Mtetra
.663 .664 .84 r
.40277 .19408 .41026 .20654 .42313 .2014 .41567 .18874 Mtetra
.661 .66 .838 r
.41567 .18874 .42313 .2014 .43606 .1962 .42863 .18343 Mtetra
.66 .659 .837 r
.42863 .18343 .43606 .1962 .44905 .19084 .44164 .17812 Mtetra
.661 .66 .839 r
.44164 .17812 .44905 .19084 .4621 .1853 .45471 .1728 Mtetra
.661 .665 .843 r
.45471 .1728 .4621 .1853 .47521 .1796 .46784 .16747 Mtetra
.662 .674 .85 r
.46784 .16747 .47521 .1796 .48838 .1738 .48103 .16215 Mtetra
.663 .684 .86 r
.48103 .16215 .48838 .1738 .50161 .16799 .49428 .15686 Mtetra
.664 .696 .87 r
.49428 .15686 .50161 .16799 .51489 .16226 .5076 .15161 Mtetra
.665 .708 .88 r
.5076 .15161 .51489 .16226 .52823 .15664 .52097 .14639 Mtetra
.665 .718 .889 r
.52097 .14639 .52823 .15664 .54163 .15115 .53441 .14121 Mtetra
.664 .726 .896 r
.53441 .14121 .54163 .15115 .55509 .14579 .54792 .13604 Mtetra
.664 .732 .901 r
.54792 .13604 .55509 .14579 .56861 .14051 .56149 .13088 Mtetra
.664 .736 .904 r
.56149 .13088 .56861 .14051 .58221 .1353 .57513 .12572 Mtetra
.664 .739 .906 r
.57513 .12572 .58221 .1353 .59587 .13011 .58883 .12054 Mtetra
.664 .74 .907 r
.58883 .12054 .59587 .13011 .60959 .12493 .60261 .11534 Mtetra
.664 .741 .907 r
.60261 .11534 .60959 .12493 .62339 .11975 .61645 .11012 Mtetra
.664 .741 .908 r
.61645 .11012 .62339 .11975 .63725 .11454 .63036 .10488 Mtetra
.63036 .10488 .63725 .11454 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09431 Mtetra
.65839 .09431 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.08013 .30111 .08867 .30906 .10008 .30476 .09156 .29678 Mtetra
.663 .741 .908 r
.09156 .29678 .10008 .30476 .11153 .30045 .10305 .29242 Mtetra
.662 .741 .908 r
.10305 .29242 .11153 .30045 .12304 .29611 .11458 .28808 Mtetra
.607 .726 .929 r
.11458 .28808 .12304 .29611 .13459 .29181 .12598 .2852 Mtetra
.801 .314 0 r
.12598 .2852 .13459 .29181 .14588 .29012 .13519 .30033 Mtetra
.867 .54 .429 r
.13519 .30033 .14588 .29012 .15356 .31958 .14048 .34937 Mtetra
.2 0 .173 r
.14048 .34937 .15356 .31958 .15506 .4055 .15339 .33738 Mtetra
.743 .517 .587 r
.15339 .33738 .15506 .4055 .16918 .38404 .17091 .28483 Mtetra
.593 .381 .563 r
.17091 .28483 .16918 .38404 .19012 .29844 .18424 .26767 Mtetra
.617 .477 .668 r
.18424 .26767 .19012 .29844 .20423 .27346 .19642 .26088 Mtetra
.68 .657 .821 r
.19642 .26088 .20423 .27346 .21652 .26575 .20854 .25494 Mtetra
.659 .683 .861 r
.20854 .25494 .21652 .26575 .22869 .2595 .22059 .25025 Mtetra
.641 .713 .9 r
.22059 .25025 .22869 .2595 .24076 .25485 .23262 .24632 Mtetra
.633 .73 .917 r
.23262 .24632 .24076 .25485 .2528 .25113 .24469 .2426 Mtetra
.634 .731 .918 r
.24469 .2426 .2528 .25113 .26489 .24764 .25682 .23886 Mtetra
.639 .727 .912 r
.25682 .23886 .26489 .24764 .27704 .24409 .26902 .23495 Mtetra
.647 .722 .903 r
.26902 .23495 .27704 .24409 .28927 .24032 .28132 .23078 Mtetra
.656 .716 .892 r
.28132 .23078 .28927 .24032 .30159 .23623 .29369 .22626 Mtetra
.665 .71 .881 r
.29369 .22626 .30159 .23623 .314 .23172 .30615 .22138 Mtetra
.671 .705 .872 r
.30615 .22138 .314 .23172 .32649 .22681 .31869 .21617 Mtetra
.676 .701 .865 r
.31869 .21617 .32649 .22681 .33906 .22156 .3313 .21073 Mtetra
.678 .698 .862 r
.3313 .21073 .33906 .22156 .35169 .21609 .34397 .20515 Mtetra
.677 .697 .861 r
.34397 .20515 .35169 .21609 .36439 .21052 .35669 .19956 Mtetra
.676 .697 .862 r
.35669 .19956 .36439 .21052 .37713 .20497 .36947 .19401 Mtetra
.673 .697 .864 r
.36947 .19401 .37713 .20497 .38993 .19948 .38229 .18856 Mtetra
.67 .697 .866 r
.38229 .18856 .38993 .19948 .40277 .19408 .39516 .18321 Mtetra
.668 .698 .869 r
.39516 .18321 .40277 .19408 .41567 .18874 .40809 .17794 Mtetra
.666 .7 .872 r
.40809 .17794 .41567 .18874 .42863 .18343 .42107 .17273 Mtetra
.665 .703 .875 r
.42107 .17273 .42863 .18343 .44164 .17812 .43411 .16756 Mtetra
.665 .707 .879 r
.43411 .16756 .44164 .17812 .45471 .1728 .44721 .16242 Mtetra
.664 .712 .883 r
.44721 .16242 .45471 .1728 .46784 .16747 .46038 .15728 Mtetra
.664 .717 .888 r
.46038 .15728 .46784 .16747 .48103 .16215 .4736 .15216 Mtetra
.664 .723 .893 r
.4736 .15216 .48103 .16215 .49428 .15686 .48689 .14704 Mtetra
.664 .728 .897 r
.48689 .14704 .49428 .15686 .5076 .15161 .50024 .14192 Mtetra
.664 .732 .901 r
.50024 .14192 .5076 .15161 .52097 .14639 .51366 .13679 Mtetra
.664 .736 .903 r
.51366 .13679 .52097 .14639 .53441 .14121 .52714 .13166 Mtetra
.664 .738 .905 r
.52714 .13166 .53441 .14121 .54792 .13604 .54069 .1265 Mtetra
.664 .739 .906 r
.54069 .1265 .54792 .13604 .56149 .13088 .5543 .12134 Mtetra
.664 .74 .907 r
.5543 .12134 .56149 .13088 .57513 .12572 .56798 .11614 Mtetra
.664 .741 .908 r
.56798 .11614 .57513 .12572 .58883 .12054 .58173 .11093 Mtetra
.58173 .11093 .58883 .12054 .60261 .11534 .59555 .10569 Mtetra
.59555 .10569 .60261 .11534 .61645 .11012 .60944 .10042 Mtetra
.60944 .10042 .61645 .11012 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09431 .65152 .08447 Mtetra
.65152 .08447 .65839 .09431 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.663 .741 .908 r
.07152 .29309 .08013 .30111 .09156 .29678 .08298 .28872 Mtetra
.08298 .28872 .09156 .29678 .10305 .29242 .09449 .28435 Mtetra
.638 .735 .918 r
.09449 .28435 .10305 .29242 .11458 .28808 .10596 .28066 Mtetra
0 .363 .812 r
.10596 .28066 .11458 .28808 .12598 .2852 .11633 .28576 Mtetra
.854 .448 .268 r
.11633 .28576 .12598 .2852 .13519 .30033 .1246 .3082 Mtetra
0 0 0 r
.1246 .3082 .13519 .30033 .14048 .34937 .13675 .30143 Mtetra
.713 .509 .611 r
.13675 .30143 .14048 .34937 .15339 .33738 .15152 .2732 Mtetra
.594 .4 .589 r
.15152 .2732 .15339 .33738 .17091 .28483 .16415 .26222 Mtetra
.633 .528 .717 r
.16415 .26222 .17091 .28483 .18424 .26767 .17623 .25618 Mtetra
.68 .677 .84 r
.17623 .25618 .18424 .26767 .19642 .26088 .18831 .25051 Mtetra
.662 .694 .869 r
.18831 .25051 .19642 .26088 .20854 .25494 .20033 .24578 Mtetra
.646 .718 .9 r
.20033 .24578 .20854 .25494 .22059 .25025 .21235 .24168 Mtetra
.64 .732 .915 r
.21235 .24168 .22059 .25025 .23262 .24632 .2244 .23777 Mtetra
.639 .733 .917 r
.2244 .23777 .23262 .24632 .24469 .2426 .23651 .23385 Mtetra
.642 .73 .912 r
.23651 .23385 .24469 .2426 .25682 .23886 .2487 .22982 Mtetra
.649 .725 .905 r
.2487 .22982 .25682 .23886 .26902 .23495 .26096 .22557 Mtetra
.656 .721 .896 r
.26096 .22557 .26902 .23495 .28132 .23078 .27331 .22105 Mtetra
.664 .716 .887 r
.27331 .22105 .28132 .23078 .29369 .22626 .28573 .21621 Mtetra
.67 .712 .879 r
.28573 .21621 .29369 .22626 .30615 .22138 .29824 .2111 Mtetra
.675 .709 .874 r
.29824 .2111 .30615 .22138 .31869 .21617 .31082 .20575 Mtetra
.677 .708 .871 r
.31082 .20575 .31869 .21617 .3313 .21073 .32346 .20027 Mtetra
.678 .708 .871 r
.32346 .20027 .3313 .21073 .34397 .20515 .33615 .19475 Mtetra
.677 .71 .873 r
.33615 .19475 .34397 .20515 .35669 .19956 .3489 .18926 Mtetra
.675 .712 .876 r
.3489 .18926 .35669 .19956 .36947 .19401 .3617 .18384 Mtetra
.672 .715 .881 r
.3617 .18384 .36947 .19401 .38229 .18856 .37455 .17851 Mtetra
.67 .718 .885 r
.37455 .17851 .38229 .18856 .39516 .18321 .38745 .17328 Mtetra
.668 .721 .889 r
.38745 .17328 .39516 .18321 .40809 .17794 .4004 .16811 Mtetra
.666 .724 .892 r
.4004 .16811 .40809 .17794 .42107 .17273 .41342 .16299 Mtetra
.665 .727 .896 r
.41342 .16299 .42107 .17273 .43411 .16756 .42649 .1579 Mtetra
.665 .73 .898 r
.42649 .1579 .43411 .16756 .44721 .16242 .43963 .15282 Mtetra
.664 .732 .901 r
.43963 .15282 .44721 .16242 .46038 .15728 .45283 .14774 Mtetra
.664 .735 .903 r
.45283 .14774 .46038 .15728 .4736 .15216 .46609 .14265 Mtetra
.664 .737 .904 r
.46609 .14265 .4736 .15216 .48689 .14704 .47942 .13755 Mtetra
.664 .738 .905 r
.47942 .13755 .48689 .14704 .50024 .14192 .49281 .13243 Mtetra
.664 .739 .906 r
.49281 .13243 .50024 .14192 .51366 .13679 .50627 .12729 Mtetra
.664 .74 .907 r
.50627 .12729 .51366 .13679 .52714 .13166 .5198 .12213 Mtetra
.664 .741 .907 r
.5198 .12213 .52714 .13166 .54069 .1265 .53339 .11694 Mtetra
.664 .741 .908 r
.53339 .11694 .54069 .1265 .5543 .12134 .54705 .11173 Mtetra
.54705 .11173 .5543 .12134 .56798 .11614 .56078 .1065 Mtetra
.56078 .1065 .56798 .11614 .58173 .11093 .57457 .10123 Mtetra
.57457 .10123 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.663 .741 .908 r
.06283 .28501 .07152 .29309 .08298 .28872 .07432 .28061 Mtetra
.654 .739 .912 r
.07432 .28061 .08298 .28872 .09449 .28435 .08582 .27647 Mtetra
.474 .684 .958 r
.08582 .27647 .09449 .28435 .10596 .28066 .09688 .27596 Mtetra
.488 0 0 r
.09688 .27596 .10596 .28066 .11633 .28576 .10699 .28302 Mtetra
.634 .893 .986 r
.10699 .28302 .11633 .28576 .1246 .3082 .11877 .27839 Mtetra
.691 .529 .663 r
.11877 .27839 .1246 .3082 .13675 .30143 .1318 .2643 Mtetra
.605 .448 .643 r
.1318 .2643 .13675 .30143 .15152 .2732 .14396 .25714 Mtetra
.652 .597 .78 r
.14396 .25714 .15152 .2732 .16415 .26222 .15596 .25162 Mtetra
.679 .695 .858 r
.15596 .25162 .16415 .26222 .17623 .25618 .16799 .24617 Mtetra
.663 .703 .877 r
.16799 .24617 .17623 .25618 .18831 .25051 .17999 .24143 Mtetra
.65 .722 .901 r
.17999 .24143 .18831 .25051 .20033 .24578 .19199 .23719 Mtetra
.645 .734 .914 r
.19199 .23719 .20033 .24578 .21235 .24168 .20402 .23311 Mtetra
.644 .735 .915 r
.20402 .23311 .21235 .24168 .2244 .23777 .21612 .22903 Mtetra
.646 .732 .912 r
.21612 .22903 .2244 .23777 .23651 .23385 .22828 .22488 Mtetra
.65 .729 .906 r
.22828 .22488 .23651 .23385 .2487 .22982 .24052 .22056 Mtetra
.656 .725 .899 r
.24052 .22056 .2487 .22982 .26096 .22557 .25284 .21602 Mtetra
.662 .721 .892 r
.25284 .21602 .26096 .22557 .27331 .22105 .26523 .21124 Mtetra
.668 .717 .885 r
.26523 .21124 .27331 .22105 .28573 .21621 .2777 .2062 Mtetra
.672 .715 .881 r
.2777 .2062 .28573 .21621 .29824 .2111 .29025 .20097 Mtetra
.675 .714 .878 r
.29025 .20097 .29824 .2111 .31082 .20575 .30286 .19561 Mtetra
.676 .715 .878 r
.30286 .19561 .31082 .20575 .32346 .20027 .31552 .19018 Mtetra
.676 .717 .88 r
.31552 .19018 .32346 .20027 .33615 .19475 .32824 .18477 Mtetra
.674 .72 .884 r
.32824 .18477 .33615 .19475 .3489 .18926 .34101 .17941 Mtetra
.672 .724 .888 r
.34101 .17941 .3489 .18926 .3617 .18384 .35384 .17412 Mtetra
.67 .727 .892 r
.35384 .17412 .3617 .18384 .37455 .17851 .36671 .16891 Mtetra
.668 .73 .896 r
.36671 .16891 .37455 .17851 .38745 .17328 .37964 .16376 Mtetra
.666 .733 .899 r
.37964 .16376 .38745 .17328 .4004 .16811 .39263 .15866 Mtetra
.665 .735 .902 r
.39263 .15866 .4004 .16811 .41342 .16299 .40569 .15357 Mtetra
.665 .737 .904 r
.40569 .15357 .41342 .16299 .42649 .1579 .4188 .1485 Mtetra
.664 .738 .905 r
.4188 .1485 .42649 .1579 .43963 .15282 .43197 .14342 Mtetra
.664 .739 .906 r
.43197 .14342 .43963 .15282 .45283 .14774 .44521 .13832 Mtetra
.664 .74 .907 r
.44521 .13832 .45283 .14774 .46609 .14265 .45852 .13321 Mtetra
.45852 .13321 .46609 .14265 .47942 .13755 .47188 .12808 Mtetra
.664 .741 .907 r
.47188 .12808 .47942 .13755 .49281 .13243 .48532 .12292 Mtetra
.664 .741 .908 r
.48532 .12292 .49281 .13243 .50627 .12729 .49882 .11774 Mtetra
.49882 .11774 .50627 .12729 .5198 .12213 .51239 .11254 Mtetra
.51239 .11254 .5198 .12213 .53339 .11694 .52603 .1073 Mtetra
.52603 .1073 .53339 .11694 .54705 .11173 .53973 .10205 Mtetra
.53973 .10205 .54705 .11173 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10123 .56734 .09145 Mtetra
.56734 .09145 .57457 .10123 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.66 .741 .909 r
.05407 .27686 .06283 .28501 .07432 .28061 .06558 .27251 Mtetra
.612 .73 .929 r
.06558 .27251 .07432 .28061 .08582 .27647 .07695 .26943 Mtetra
.432 .694 .975 r
.07695 .26943 .08582 .27647 .09688 .27596 .08798 .26919 Mtetra
.647 .779 .944 r
.08798 .26919 .09688 .27596 .10699 .28302 .09962 .26512 Mtetra
.676 .589 .75 r
.09962 .26512 .10699 .28302 .11877 .27839 .11177 .25765 Mtetra
.627 .538 .734 r
.11177 .25765 .11877 .27839 .1318 .2643 .12367 .25237 Mtetra
.666 .665 .839 r
.12367 .25237 .1318 .2643 .14396 .25714 .13559 .24718 Mtetra
.678 .709 .871 r
.13559 .24718 .14396 .25714 .15596 .25162 .14758 .24191 Mtetra
.664 .711 .883 r
.14758 .24191 .15596 .25162 .16799 .24617 .15956 .23716 Mtetra
.654 .726 .902 r
.15956 .23716 .16799 .24617 .17999 .24143 .17154 .2328 Mtetra
.649 .735 .912 r
.17154 .2328 .17999 .24143 .19199 .23719 .18356 .22858 Mtetra
.648 .736 .914 r
.18356 .22858 .19199 .23719 .20402 .23311 .19564 .22437 Mtetra
.649 .734 .911 r
.19564 .22437 .20402 .23311 .21612 .22903 .20778 .22011 Mtetra
.652 .731 .907 r
.20778 .22011 .21612 .22903 .22828 .22488 .21999 .21572 Mtetra
.657 .728 .902 r
.21999 .21572 .22828 .22488 .24052 .22056 .23228 .21116 Mtetra
.662 .725 .896 r
.23228 .21116 .24052 .22056 .25284 .21602 .24465 .2064 Mtetra
.666 .722 .89 r
.24465 .2064 .25284 .21602 .26523 .21124 .25708 .20143 Mtetra
.67 .72 .886 r
.25708 .20143 .26523 .21124 .2777 .2062 .26959 .1963 Mtetra
.673 .719 .884 r
.26959 .1963 .2777 .2062 .29025 .20097 .28217 .19103 Mtetra
.674 .72 .884 r
.28217 .19103 .29025 .20097 .30286 .19561 .29481 .18571 Mtetra
.674 .722 .885 r
.29481 .18571 .30286 .19561 .31552 .19018 .3075 .18037 Mtetra
.673 .724 .888 r
.3075 .18037 .31552 .19018 .32824 .18477 .32024 .17507 Mtetra
.671 .728 .892 r
.32024 .17507 .32824 .18477 .34101 .17941 .33304 .16982 Mtetra
.669 .731 .896 r
.33304 .16982 .34101 .17941 .35384 .17412 .34589 .16463 Mtetra
.668 .734 .899 r
.34589 .16463 .35384 .17412 .36671 .16891 .3588 .15949 Mtetra
.666 .736 .902 r
.3588 .15949 .36671 .16891 .37964 .16376 .37176 .15438 Mtetra
.665 .738 .904 r
.37176 .15438 .37964 .16376 .39263 .15866 .38479 .14929 Mtetra
.664 .739 .906 r
.38479 .14929 .39263 .15866 .40569 .15357 .39788 .1442 Mtetra
.664 .74 .906 r
.39788 .1442 .40569 .15357 .4188 .1485 .41103 .13911 Mtetra
.664 .74 .907 r
.41103 .13911 .4188 .1485 .43197 .14342 .42424 .134 Mtetra
.664 .741 .907 r
.42424 .134 .43197 .14342 .44521 .13832 .43752 .12887 Mtetra
.664 .741 .908 r
.43752 .12887 .44521 .13832 .45852 .13321 .45087 .12372 Mtetra
.45087 .12372 .45852 .13321 .47188 .12808 .46428 .11854 Mtetra
.46428 .11854 .47188 .12808 .48532 .12292 .47776 .11334 Mtetra
.47776 .11334 .48532 .12292 .49882 .11774 .4913 .10811 Mtetra
.4913 .10811 .49882 .11774 .51239 .11254 .50491 .10286 Mtetra
.50491 .10286 .51239 .11254 .52603 .1073 .51859 .09758 Mtetra
.51859 .09758 .52603 .1073 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.649 .738 .915 r
.04524 .26866 .05407 .27686 .06558 .27251 .05672 .2646 Mtetra
.612 .737 .934 r
.05672 .2646 .06558 .27251 .07695 .26943 .06812 .26146 Mtetra
.648 .746 .921 r
.06812 .26146 .07695 .26943 .08798 .26919 .07972 .25739 Mtetra
.663 .665 .842 r
.07972 .25739 .08798 .26919 .09962 .26512 .0915 .25238 Mtetra
.647 .643 .832 r
.0915 .25238 .09962 .26512 .11177 .25765 .10327 .24782 Mtetra
.67 .71 .877 r
.10327 .24782 .11177 .25765 .12367 .25237 .11515 .24285 Mtetra
.675 .719 .882 r
.11515 .24285 .12367 .25237 .13559 .24718 .12709 .23772 Mtetra
.665 .718 .888 r
.12709 .23772 .13559 .24718 .14758 .24191 .13904 .23296 Mtetra
.656 .729 .903 r
.13904 .23296 .14758 .24191 .15956 .23716 .151 .22851 Mtetra
.652 .736 .911 r
.151 .22851 .15956 .23716 .17154 .2328 .16301 .22417 Mtetra
.651 .737 .912 r
.16301 .22417 .17154 .2328 .18356 .22858 .17507 .21984 Mtetra
.652 .736 .911 r
.17507 .21984 .18356 .22858 .19564 .22437 .18719 .21547 Mtetra
.654 .733 .908 r
.18719 .21547 .19564 .22437 .20778 .22011 .19938 .21102 Mtetra
.657 .731 .904 r
.19938 .21102 .20778 .22011 .21999 .21572 .21164 .20643 Mtetra
.661 .728 .899 r
.21164 .20643 .21999 .21572 .23228 .21116 .22397 .20168 Mtetra
.665 .726 .894 r
.22397 .20168 .23228 .21116 .24465 .2064 .23638 .19676 Mtetra
.668 .724 .891 r
.23638 .19676 .24465 .2064 .25708 .20143 .24886 .19169 Mtetra
.671 .723 .889 r
.24886 .19169 .25708 .20143 .26959 .1963 .2614 .18651 Mtetra
.672 .724 .888 r
.2614 .18651 .26959 .1963 .28217 .19103 .27401 .18127 Mtetra
.672 .725 .889 r
.27401 .18127 .28217 .19103 .29481 .18571 .28667 .176 Mtetra
.671 .727 .892 r
.28667 .176 .29481 .18571 .3075 .18037 .29938 .17075 Mtetra
.67 .73 .895 r
.29938 .17075 .3075 .18037 .32024 .17507 .31215 .16554 Mtetra
.668 .733 .898 r
.31215 .16554 .32024 .17507 .33304 .16982 .32498 .16036 Mtetra
.667 .735 .901 r
.32498 .16036 .33304 .16982 .34589 .16463 .33786 .15523 Mtetra
.666 .737 .903 r
.33786 .15523 .34589 .16463 .3588 .15949 .3508 .15011 Mtetra
.665 .739 .905 r
.3508 .15011 .3588 .15949 .37176 .15438 .36381 .14501 Mtetra
.664 .74 .906 r
.36381 .14501 .37176 .15438 .38479 .14929 .37687 .13991 Mtetra
.664 .74 .907 r
.37687 .13991 .38479 .14929 .39788 .1442 .39 .13479 Mtetra
.664 .741 .907 r
.39 .13479 .39788 .1442 .41103 .13911 .40319 .12966 Mtetra
.664 .741 .908 r
.40319 .12966 .41103 .13911 .42424 .134 .41644 .12451 Mtetra
.41644 .12451 .42424 .134 .43752 .12887 .42976 .11934 Mtetra
.42976 .11934 .43752 .12887 .45087 .12372 .44315 .11414 Mtetra
.44315 .11414 .45087 .12372 .46428 .11854 .4566 .10892 Mtetra
.4566 .10892 .46428 .11854 .47776 .11334 .47013 .10367 Mtetra
.47013 .10367 .47776 .11334 .4913 .10811 .48371 .09839 Mtetra
.48371 .09839 .4913 .10811 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .0824 Mtetra
.52489 .0824 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.65 .74 .916 r
.03632 .26046 .04524 .26866 .05672 .2646 .04783 .25635 Mtetra
.652 .741 .914 r
.04783 .25635 .05672 .2646 .06812 .26146 .05941 .25214 Mtetra
.654 .715 .893 r
.05941 .25214 .06812 .26146 .07972 .25739 .07106 .24782 Mtetra
.654 .71 .889 r
.07106 .24782 .07972 .25739 .0915 .25238 .08277 .24345 Mtetra
.67 .731 .896 r
.08277 .24345 .0915 .25238 .10327 .24782 .09461 .23859 Mtetra
.673 .726 .889 r
.09461 .23859 .10327 .24782 .11515 .24285 .10651 .23358 Mtetra
.665 .723 .893 r
.10651 .23358 .11515 .24285 .12709 .23772 .11843 .22881 Mtetra
.658 .731 .903 r
.11843 .22881 .12709 .23772 .13904 .23296 .13038 .22429 Mtetra
.655 .737 .91 r
.13038 .22429 .13904 .23296 .151 .22851 .14237 .21985 Mtetra
.654 .738 .911 r
.14237 .21985 .151 .22851 .16301 .22417 .15441 .21542 Mtetra
.654 .737 .91 r
.15441 .21542 .16301 .22417 .17507 .21984 .16651 .21096 Mtetra
.656 .735 .908 r
.16651 .21096 .17507 .21984 .18719 .21547 .17867 .20644 Mtetra
.658 .733 .905 r
.17867 .20644 .18719 .21547 .19938 .21102 .19091 .20181 Mtetra
.661 .731 .901 r
.19091 .20181 .19938 .21102 .21164 .20643 .20322 .19706 Mtetra
.664 .729 .898 r
.20322 .19706 .21164 .20643 .22397 .20168 .21559 .19217 Mtetra
.667 .727 .895 r
.21559 .19217 .22397 .20168 .23638 .19676 .22804 .18715 Mtetra
.669 .727 .893 r
.22804 .18715 .23638 .19676 .24886 .19169 .24055 .18203 Mtetra
.67 .727 .892 r
.24055 .18203 .24886 .19169 .2614 .18651 .25312 .17685 Mtetra
.67 .728 .893 r
.25312 .17685 .2614 .18651 .27401 .18127 .26575 .17164 Mtetra
.67 .73 .895 r
.26575 .17164 .27401 .18127 .28667 .176 .27844 .16644 Mtetra
.669 .732 .897 r
.27844 .16644 .28667 .176 .29938 .17075 .29118 .16125 Mtetra
.668 .734 .9 r
.29118 .16125 .29938 .17075 .31215 .16554 .30398 .15609 Mtetra
.667 .736 .902 r
.30398 .15609 .31215 .16554 .32498 .16036 .31684 .15095 Mtetra
.666 .738 .904 r
.31684 .15095 .32498 .16036 .33786 .15523 .32976 .14583 Mtetra
.665 .739 .905 r
.32976 .14583 .33786 .15523 .3508 .15011 .34274 .14071 Mtetra
.664 .74 .906 r
.34274 .14071 .3508 .15011 .36381 .14501 .35577 .13559 Mtetra
.664 .741 .907 r
.35577 .13559 .36381 .14501 .37687 .13991 .36888 .13046 Mtetra
.36888 .13046 .37687 .13991 .39 .13479 .38204 .12531 Mtetra
.664 .741 .908 r
.38204 .12531 .39 .13479 .40319 .12966 .39527 .12014 Mtetra
.39527 .12014 .40319 .12966 .41644 .12451 .40857 .11494 Mtetra
.40857 .11494 .41644 .12451 .42976 .11934 .42193 .10972 Mtetra
.42193 .10972 .42976 .11934 .44315 .11414 .43536 .10448 Mtetra
.43536 .10448 .44315 .11414 .4566 .10892 .44886 .0992 Mtetra
.44886 .0992 .4566 .10892 .47013 .10367 .46242 .09391 Mtetra
.46242 .09391 .47013 .10367 .48371 .09839 .47605 .08858 Mtetra
.47605 .08858 .48371 .09839 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .0824 .51736 .07245 Mtetra
.51736 .07245 .52489 .0824 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.005 w
.5258 .3301 m
.5516 .33134 L
.5774 .34449 L
.57898 .3452 L
.6032 .36085 L
.61844 .371 L
.629 .38049 L
.649 .3968 L
.6548 .40261 L
.6766 .4226 L
.6806 .42681 L
.70228 .4484 L
.7064 .45292 L
.72631 .4742 L
.7322 .48097 L
.74883 .5 L
.758 .51115 L
.76989 .5258 L
.7838 .54394 L
.78951 .5516 L
.80791 .5774 L
.8096 .57971 L
.82512 .6032 L
.8354 .62022 L
.8401 .629 L
.85394 .6548 L
.8612 .67439 L
.8635 .6806 L
.87059 .7064 L
.8612 .72677 L
.8354 .72977 L
.8096 .71777 L
.79139 .7064 L
.7838 .70165 L
.758 .68218 L
.7559 .6806 L
.7322 .66061 L
.72546 .6548 L
.7064 .63685 L
.69815 .629 L
.6806 .61108 L
.67297 .6032 L
.6548 .5833 L
.64949 .5774 L
.629 .55338 L
.62751 .5516 L
.60659 .5258 L
.6032 .5214 L
.58709 .5 L
.5774 .4863 L
Mistroke
.56924 .4742 L
.55287 .4484 L
.5516 .44686 L
.53779 .4226 L
.5259 .3968 L
.5258 .39645 L
.51571 .371 L
.51436 .3452 L
.5258 .3301 L
Mfstroke
.629 .22774 m
.6548 .22513 L
.6806 .22396 L
.7064 .23391 L
.72607 .242 L
.7322 .24527 L
.758 .25505 L
.77205 .2678 L
.7838 .27767 L
.79828 .2936 L
.80356 .3194 L
.7838 .32942 L
.758 .33111 L
.7322 .32931 L
.7064 .32028 L
.70393 .3194 L
.6806 .30981 L
.6548 .29648 L
.65115 .2936 L
.629 .27603 L
.62123 .2678 L
.61111 .242 L
.629 .22774 L
s
.1646 .13156 m
.1761 .1388 L
.1904 .14983 L
.20711 .1646 L
.2162 .17344 L
.232 .1904 L
.242 .20285 L
.25009 .2162 L
.242 .22148 L
.23258 .2162 L
.2162 .20419 L
.2002 .1904 L
.1904 .18111 L
.17462 .1646 L
.1646 .15268 L
.15515 .1388 L
.1646 .13156 L
s
.5 .44364 m
.50632 .4484 L
.5258 .46457 L
.53669 .4742 L
.5516 .48781 L
.5646 .5 L
.5774 .51224 L
.59134 .5258 L
.6032 .53749 L
.61732 .5516 L
.629 .5634 L
.6427 .5774 L
.6548 .58989 L
.66757 .6032 L
.6806 .61691 L
.69197 .629 L
.7064 .64448 L
.71593 .6548 L
.7322 .67261 L
.73942 .6806 L
.758 .70138 L
.76243 .7064 L
.7838 .73095 L
.78487 .7322 L
.80661 .758 L
.8096 .76163 L
.82736 .7838 L
.8354 .79432 L
.84631 .8096 L
.8354 .81992 L
.82253 .8096 L
.8096 .79848 L
.79327 .7838 L
.7838 .77503 L
.76581 .758 L
.758 .75047 L
.73934 .7322 L
.7322 .72511 L
.71357 .7064 L
.7064 .69911 L
.68836 .6806 L
.6806 .67255 L
.66365 .6548 L
.6548 .64544 L
.63939 .629 L
.629 .6178 L
.61558 .6032 L
.6032 .58958 L
.59224 .5774 L
.5774 .5607 L
Mistroke
.56941 .5516 L
.5516 .531 L
.54718 .5258 L
.5258 .50011 L
.52571 .5 L
.50541 .4742 L
.5 .46691 L
.48757 .4484 L
.5 .44364 L
Mfstroke
0 g
.03 w
.69121 .52963 Mdot
.70782 .27819 Mdot
.2018 .17578 Mdot
.66959 .63318 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.96078 .96078 Mdot
.71373 .72157 Mdot
.52941 .52549 Mdot
.13725 .14902 Mdot
.87843 .88235 Mdot
.11373 .1098 Mdot
.1098 .11373 Mdot
.77647 .78039 Mdot
.15294 .14902 Mdot
.13725 .12549 Mdot
.13333 .1451 Mdot
.1451 .13333 Mdot
.20784 .18824 Mdot
.17255 .15686 Mdot
.4902 .49804 Mdot
.1451 .13333 Mdot
.26275 .23137 Mdot
.23529 .21569 Mdot
.47451 .48235 Mdot
.89804 .82745 Mdot
1 .96863 Mdot
.13333 .12941 Mdot
.20784 .18824 Mdot
.24706 .20784 Mdot
.11373 .11765 Mdot
.3451 .16863 Mdot
.49804 .32941 Mdot
.65098 .53725 Mdot
.84314 .74902 Mdot
.94902 .89412 Mdot
.1451 .14118 Mdot
.18431 .16863 Mdot
.20392 .17647 Mdot
.20784 .20784 Mdot
.55294 .39216 Mdot
.41176 .14118 Mdot
.42353 .22745 Mdot
.36078 .2 Mdot
.38824 .25882 Mdot
.21569 .19608 Mdot
.21569 .20392 Mdot
.18824 .16863 Mdot
.22353 .20784 Mdot
.25098 .25098 Mdot
.52941 .17647 Mdot
.47843 .16863 Mdot
.41961 .19608 Mdot
.44706 .25882 Mdot
.33725 .17647 Mdot
.1451 .12941 Mdot
.14902 .11765 Mdot
.17647 .1451 Mdot
.24706 .23529 Mdot
1 .93725 Mdot
.58824 .18824 Mdot
.51373 .18039 Mdot
.45882 .22353 Mdot
.43137 .21569 Mdot
.43529 .26667 Mdot
.15686 .13725 Mdot
.21961 .19216 Mdot
.18039 .14902 Mdot
.26667 .26667 Mdot
1 .96471 Mdot
.77647 .36078 Mdot
.61176 .25882 Mdot
.45098 .2 Mdot
.4549 .25882 Mdot
.42745 .18824 Mdot
.18039 .14902 Mdot
.25098 .20784 Mdot
.14902 .11765 Mdot
.21961 .2 Mdot
.50196 .50196 Mdot
.73725 .32157 Mdot
.58039 .21176 Mdot
.4549 .18431 Mdot
.51765 .32157 Mdot
.46275 .18431 Mdot
.21176 .11765 Mdot
.18824 .15294 Mdot
.19608 .16471 Mdot
.18431 .16471 Mdot
.16471 .16078 Mdot
.82353 .72549 Mdot
.65882 .25098 Mdot
.53725 .16863 Mdot
.54118 .28627 Mdot
.54118 .34118 Mdot
.50588 .18824 Mdot
.23137 .07059 Mdot
.16471 .13725 Mdot
.23922 .21176 Mdot
.25882 .24706 Mdot
.14118 .13725 Mdot
.52941 .44314 Mdot
.37255 .12549 Mdot
.57647 .18824 Mdot
.5451 .17255 Mdot
.77255 .5451 Mdot
.64706 .43922 Mdot
.52549 .17255 Mdot
.28235 .09804 Mdot
.16863 .14118 Mdot
.27843 .25098 Mdot
.18431 .18039 Mdot
.15294 .10588 Mdot
.2902 .17255 Mdot
.96078 .92549 Mdot
.63922 .23922 Mdot
.54902 .16471 Mdot
.55686 .2 Mdot
.58039 .38039 Mdot
.49804 .2549 Mdot
.67059 .27059 Mdot
.23529 .11765 Mdot
.17255 .14118 Mdot
.22353 .21176 Mdot
.16863 .14902 Mdot
.29804 .12157 Mdot
.33725 .22353 Mdot
.8902 .82353 Mdot
.62353 .22353 Mdot
.56471 .16471 Mdot
.58824 .15686 Mdot
.55294 .33725 Mdot
.71373 .49412 Mdot
.53725 .2 Mdot
.5098 .2549 Mdot
.2 .13725 Mdot
.18431 .1451 Mdot
.18039 .14902 Mdot
.20392 .01961 Mdot
.67059 .51373 Mdot
.35294 .24706 Mdot
.88627 .83529 Mdot
.63137 .21961 Mdot
.59216 .16078 Mdot
.64706 .18039 Mdot
.78431 .55294 Mdot
.83137 .61569 Mdot
.67059 .41176 Mdot
.47451 .24706 Mdot
.27059 .15686 Mdot
.2 .13725 Mdot
.19216 .1098 Mdot
.33725 .10196 Mdot
.63529 .47843 Mdot
.61569 .50196 Mdot
.34902 .23529 Mdot
1 .97255 Mdot
.63137 .19216 Mdot
.64314 .17647 Mdot
.67059 .2 Mdot
.80392 .57255 Mdot
.41961 .21176 Mdot
.68627 .47059 Mdot
.8 .62745 Mdot
.25098 .12549 Mdot
.21961 .11765 Mdot
.26275 .08235 Mdot
.42745 .18039 Mdot
.66275 .52549 Mdot
.61569 .5098 Mdot
.41569 .29412 Mdot
.76078 .7098 Mdot
.53333 .19608 Mdot
.72549 .25882 Mdot
.66275 .19216 Mdot
.64314 .19216 Mdot
.83529 .63922 Mdot
.67059 .43922 Mdot
.58431 .40392 Mdot
.52157 .39608 Mdot
.37647 .18431 Mdot
.28235 .09412 Mdot
.49412 .18039 Mdot
.46667 .27451 Mdot
.56471 .47451 Mdot
.6 .49412 Mdot
.50588 .40392 Mdot
.63137 .56078 Mdot
.44706 .16863 Mdot
.67451 .23137 Mdot
.90196 .44706 Mdot
.76471 .27451 Mdot
.90588 .65098 Mdot
.48235 .26667 Mdot
.93333 .76078 Mdot
.61569 .50588 Mdot
.59216 .40784 Mdot
.38431 .20392 Mdot
.61176 .2549 Mdot
.63922 .44314 Mdot
.72549 .60392 Mdot
.58824 .48627 Mdot
.64706 .54118 Mdot
.39608 .29412 Mdot
.78824 .74902 Mdot
.60784 .21569 Mdot
.73725 .38039 Mdot
.83922 .38824 Mdot
.83922 .34902 Mdot
.9451 .69412 Mdot
.57647 .35294 Mdot
.76471 .61569 Mdot
.66275 .54902 Mdot
.39608 .2549 Mdot
.56471 .38824 Mdot
.6549 .29804 Mdot
.62745 .41569 Mdot
.72549 .6 Mdot
.54902 .38824 Mdot
.61961 .51765 Mdot
.62745 .52941 Mdot
.34118 .23922 Mdot
.98039 .9098 Mdot
.71373 .2549 Mdot
.92157 .57255 Mdot
.67843 .25098 Mdot
.8549 .38824 Mdot
.98431 .74902 Mdot
.54118 .27843 Mdot
.72941 .60784 Mdot
1 .88627 Mdot
1 .89804 Mdot
.84706 .64314 Mdot
.63922 .32157 Mdot
.67059 .44314 Mdot
.68627 .5451 Mdot
.49804 .32941 Mdot
.61569 .51373 Mdot
.65882 .55294 Mdot
.27059 .17255 Mdot
.91373 .87843 Mdot
.64314 .18431 Mdot
.85098 .54902 Mdot
.8902 .59216 Mdot
.67059 .25882 Mdot
.82745 .41961 Mdot
1 .85098 Mdot
.95294 .78431 Mdot
.85098 .73333 Mdot
.83529 .71765 Mdot
.81961 .67059 Mdot
.53333 .22353 Mdot
.67451 .37647 Mdot
.47843 .2549 Mdot
.51373 .32549 Mdot
.53333 .35686 Mdot
.64314 .56078 Mdot
.63922 .5451 Mdot
.23922 .13333 Mdot
.92941 .89412 Mdot
.5451 .54118 Mdot
.38431 .38824 Mdot
.56078 .18824 Mdot
.69412 .26667 Mdot
.56863 .29412 Mdot
.84314 .56471 Mdot
.74118 .29412 Mdot
.77647 .43137 Mdot
.67451 .38431 Mdot
.75294 .63529 Mdot
.95686 .75686 Mdot
.50588 .3451 Mdot
.86275 .6549 Mdot
.47451 .16471 Mdot
.66667 .33725 Mdot
.64314 .4902 Mdot
.52157 .3098 Mdot
.63529 .4902 Mdot
.63137 .58431 Mdot
.63529 .54118 Mdot
.20784 .12549 Mdot
.93725 .90196 Mdot
.18431 .16863 Mdot
.21569 .20392 Mdot
.83137 .83137 Mdot
.74902 .25098 Mdot
.93725 .70196 Mdot
1 .86667 Mdot
.83529 .53333 Mdot
.77647 .3451 Mdot
.57647 .2549 Mdot
.69804 .38824 Mdot
.89804 .74118 Mdot
.91765 .58431 Mdot
.98431 .79216 Mdot
.90196 .66667 Mdot
.48235 .18039 Mdot
.53333 .21569 Mdot
.55686 .43529 Mdot
.5098 .2902 Mdot
.61961 .47059 Mdot
.60392 .58824 Mdot
.61569 .5451 Mdot
.31373 .22353 Mdot
.66275 .60392 Mdot
.11373 .1098 Mdot
.24706 .21569 Mdot
.23137 .21961 Mdot
.86275 .76863 Mdot
.73333 .23529 Mdot
.98431 .84314 Mdot
.95686 .84706 Mdot
.66667 .3098 Mdot
.94902 .49412 Mdot
.61176 .26667 Mdot
.81569 .4902 Mdot
.86667 .68627 Mdot
.7451 .33333 Mdot
.9098 .67059 Mdot
.77647 .53725 Mdot
.56078 .25882 Mdot
.48235 .17255 Mdot
.58431 .47843 Mdot
.50196 .23529 Mdot
.56471 .41176 Mdot
.47843 .48235 Mdot
.61961 .56863 Mdot
.52941 .41176 Mdot
.22745 .15294 Mdot
.71373 .71765 Mdot
.27059 .25098 Mdot
.30196 .26667 Mdot
.1098 .1098 Mdot
.66275 .23529 Mdot
.6 .27059 Mdot
.98431 .85098 Mdot
.72157 .59608 Mdot
.8 .28627 Mdot
.95294 .48627 Mdot
.71373 .29804 Mdot
.80784 .52941 Mdot
.78039 .43922 Mdot
.86667 .49804 Mdot
.92157 .62745 Mdot
.82745 .56863 Mdot
.69412 .30196 Mdot
.81569 .63922 Mdot
.47451 .27059 Mdot
.5451 .22353 Mdot
.65098 .60784 Mdot
.42353 .41961 Mdot
.58039 .52157 Mdot
.51373 .38039 Mdot
.19216 .12157 Mdot
.12157 .12157 Mdot
.21176 .18039 Mdot
.21961 .17647 Mdot
.15294 .14118 Mdot
.59608 .21176 Mdot
.65882 .35294 Mdot
.83922 .68627 Mdot
.78431 .67059 Mdot
.80784 .32157 Mdot
.83137 .32549 Mdot
.9451 .51373 Mdot
.63922 .34902 Mdot
1 .78431 Mdot
.79608 .38824 Mdot
.64314 .29412 Mdot
.58431 .27843 Mdot
.60392 .25098 Mdot
.41176 .11765 Mdot
.41176 .24314 Mdot
.55294 .18824 Mdot
.40784 .27059 Mdot
.40392 .41569 Mdot
.52549 .46667 Mdot
.46667 .33725 Mdot
.4549 .3451 Mdot
.1098 .09804 Mdot
.22353 .20392 Mdot
.27843 .23529 Mdot
.27059 .2549 Mdot
.46667 .27843 Mdot
.6 .22353 Mdot
.76863 .60392 Mdot
.94902 .79216 Mdot
.64314 .4 Mdot
.81569 .30196 Mdot
.81569 .32157 Mdot
.74118 .47843 Mdot
.69804 .46667 Mdot
.75686 .29804 Mdot
.6902 .42353 Mdot
.69412 .34118 Mdot
1 .75686 Mdot
.59608 .16078 Mdot
.70588 .56471 Mdot
.54118 .19608 Mdot
.53333 .22353 Mdot
.49804 .50196 Mdot
.52549 .41569 Mdot
.4902 .40784 Mdot
.43922 .31765 Mdot
.34118 .30196 Mdot
.13333 .10196 Mdot
.21176 .18431 Mdot
.21961 .18431 Mdot
.35686 .36471 Mdot
.73333 .24706 Mdot
.83529 .65098 Mdot
.86275 .66667 Mdot
.8902 .77255 Mdot
.73333 .42353 Mdot
.83137 .28627 Mdot
.64706 .32941 Mdot
.70196 .60392 Mdot
.76078 .36471 Mdot
.70588 .41176 Mdot
.74118 .46275 Mdot
.61961 .38431 Mdot
.62353 .20784 Mdot
.47843 .13333 Mdot
.64706 .45098 Mdot
.55686 .18431 Mdot
.3451 .18824 Mdot
.43137 .38824 Mdot
.4549 .33725 Mdot
.49412 .40784 Mdot
.38039 .2902 Mdot
.18039 .15294 Mdot
.18431 .16471 Mdot
.20392 .17255 Mdot
.28627 .27451 Mdot
.56078 .41176 Mdot
.7451 .26275 Mdot
.90196 .73333 Mdot
.82353 .67451 Mdot
.83922 .70588 Mdot
.94118 .55686 Mdot
.78431 .33333 Mdot
.73333 .61569 Mdot
.63137 .53333 Mdot
.74118 .28235 Mdot
.63137 .4549 Mdot
.68627 .4902 Mdot
.57647 .34118 Mdot
.66275 .18824 Mdot
.52941 .26275 Mdot
.41569 .16863 Mdot
.4902 .18431 Mdot
.5451 .47843 Mdot
.6902 .58431 Mdot
.38431 .26275 Mdot
.43922 .35686 Mdot
.50588 .45098 Mdot
.17647 .14118 Mdot
.15294 .12549 Mdot
.15686 .12157 Mdot
.14118 .1451 Mdot
.63529 .24706 Mdot
.50196 .19216 Mdot
.6902 .5098 Mdot
.94118 .8 Mdot
.8 .68627 Mdot
.8 .28627 Mdot
.59216 .37647 Mdot
.63137 .58039 Mdot
.6902 .53333 Mdot
.74118 .28627 Mdot
.54902 .45882 Mdot
.58824 .46275 Mdot
.72157 .40784 Mdot
.66275 .21176 Mdot
.9098 .72157 Mdot
.5098 .21961 Mdot
.47451 .22353 Mdot
.67843 .64706 Mdot
.38039 .21176 Mdot
.52157 .38431 Mdot
.36471 .26667 Mdot
.13333 .09412 Mdot
.15294 .11765 Mdot
.22353 .19608 Mdot
.21961 .20392 Mdot
.81176 .80784 Mdot
.69412 .21176 Mdot
.9098 .74118 Mdot
.95294 .78824 Mdot
.82745 .67843 Mdot
1 .83922 Mdot
.72941 .31373 Mdot
.63529 .56863 Mdot
.61569 .57255 Mdot
.81961 .56471 Mdot
.66667 .28235 Mdot
.53725 .46667 Mdot
.52941 .45098 Mdot
.70196 .3098 Mdot
.63529 .25882 Mdot
.75294 .61961 Mdot
.5451 .24314 Mdot
.57647 .35686 Mdot
.54902 .53725 Mdot
.59608 .37647 Mdot
.49804 .32157 Mdot
.52549 .40392 Mdot
.1451 .11765 Mdot
.16471 .12941 Mdot
.19608 .16863 Mdot
.18824 .18431 Mdot
.44314 .21569 Mdot
.63137 .24706 Mdot
.96471 .79216 Mdot
.83922 .67451 Mdot
.83529 .70196 Mdot
.67451 .3098 Mdot
.65098 .45882 Mdot
.59216 .54902 Mdot
.60784 .56471 Mdot
.76471 .40392 Mdot
.56863 .29804 Mdot
.52941 .4902 Mdot
.61176 .4549 Mdot
.61176 .27843 Mdot
.60784 .31765 Mdot
.74118 .61176 Mdot
.49412 .2 Mdot
.58824 .38039 Mdot
.23922 .19608 Mdot
.5451 .31373 Mdot
.55294 .36471 Mdot
.38824 .28235 Mdot
.19216 .16471 Mdot
.15686 .12157 Mdot
.24314 .22353 Mdot
.12549 .10588 Mdot
.57647 .4549 Mdot
.7451 .25882 Mdot
.83922 .67451 Mdot
.61176 .43922 Mdot
.80392 .6549 Mdot
.89412 .70588 Mdot
.66667 .47059 Mdot
.63137 .58039 Mdot
.59608 .55294 Mdot
.81176 .59608 Mdot
.69804 .31373 Mdot
.54902 .50588 Mdot
.56078 .46275 Mdot
.54118 .24314 Mdot
.63137 .43529 Mdot
.83922 .7451 Mdot
.40392 .18431 Mdot
.4902 .19608 Mdot
.69412 .64706 Mdot
.54902 .37647 Mdot
.53725 .31373 Mdot
.59608 .48235 Mdot
.1451 .10588 Mdot
.26667 .23137 Mdot
.15294 .13333 Mdot
.17255 .14118 Mdot
.85882 .79216 Mdot
.68235 .23137 Mdot
.5451 .21569 Mdot
.70588 .51765 Mdot
.71373 .52941 Mdot
.92549 .8 Mdot
.64706 .33333 Mdot
.65882 .60392 Mdot
.61961 .57647 Mdot
.61961 .56078 Mdot
.72941 .37255 Mdot
.63137 .43529 Mdot
.52941 .4902 Mdot
.67451 .38824 Mdot
.57647 .45882 Mdot
.49804 .4 Mdot
.79216 .69804 Mdot
.43529 .20392 Mdot
.37647 .18431 Mdot
.24314 .2 Mdot
.59608 .42745 Mdot
.36863 .19216 Mdot
.77647 .70588 Mdot
.18039 .14902 Mdot
.24314 .2 Mdot
.15686 .12157 Mdot
.15686 .08627 Mdot
.8549 .79608 Mdot
.67843 .20784 Mdot
.65882 .27843 Mdot
.77255 .58431 Mdot
.76471 .58431 Mdot
.7451 .62353 Mdot
.58431 .32157 Mdot
.60392 .55294 Mdot
.68235 .63137 Mdot
.62353 .56863 Mdot
.76863 .4902 Mdot
.57255 .32549 Mdot
.54118 .49412 Mdot
.61176 .31765 Mdot
.54902 .46667 Mdot
.53333 .46275 Mdot
.74902 .67451 Mdot
.72941 .58824 Mdot
.36863 .20784 Mdot
.37255 .34902 Mdot
.47843 .36471 Mdot
.51765 .38039 Mdot
.79216 .72549 Mdot
.18824 .15294 Mdot
.32941 .27843 Mdot
.21569 .17647 Mdot
.18824 .11765 Mdot
.55686 .43922 Mdot
.84314 .73333 Mdot
.77255 .23529 Mdot
.38431 .17647 Mdot
.76471 .57647 Mdot
.75294 .58824 Mdot
.93725 .77647 Mdot
.68627 .56471 Mdot
.63922 .58824 Mdot
.67059 .63137 Mdot
.61569 .55686 Mdot
.7098 .36863 Mdot
.65098 .48235 Mdot
.57255 .47451 Mdot
.49412 .25098 Mdot
.52157 .47843 Mdot
.53333 .47843 Mdot
.67843 .60784 Mdot
.80392 .70196 Mdot
.2549 .16863 Mdot
.42353 .4 Mdot
.39216 .30196 Mdot
.64706 .54118 Mdot
.85882 .81961 Mdot
.17255 .13333 Mdot
.24706 .19216 Mdot
.2 .14902 Mdot
.62353 .53725 Mdot
.55686 .41569 Mdot
1 .96863 Mdot
.75294 .22745 Mdot
.56471 .22353 Mdot
.87059 .68235 Mdot
.6902 .53333 Mdot
.85882 .72549 Mdot
.68235 .51765 Mdot
.60784 .56471 Mdot
.78431 .7451 Mdot
.63137 .58824 Mdot
.76078 .56078 Mdot
.59608 .2902 Mdot
.56863 .48235 Mdot
.55686 .2902 Mdot
.54118 .49412 Mdot
.50588 .45882 Mdot
.54118 .48627 Mdot
.72549 .6549 Mdot
.77255 .6902 Mdot
.56078 .57647 Mdot
.48627 .38039 Mdot
.34902 .2549 Mdot
.8549 .81569 Mdot
.43137 .40784 Mdot
.20784 .15294 Mdot
.19216 .13333 Mdot
.46275 .40392 Mdot
.57255 .43137 Mdot
.5451 .43922 Mdot
.68627 .53725 Mdot
.75686 .21961 Mdot
.77647 .47059 Mdot
.87843 .68235 Mdot
.9098 .76863 Mdot
1 .87451 Mdot
.37647 .29412 Mdot
.59608 .55294 Mdot
.7098 .67059 Mdot
.61961 .58431 Mdot
.78824 .57255 Mdot
.59216 .30196 Mdot
.62745 .46667 Mdot
.57647 .4 Mdot
.52157 .47451 Mdot
.52157 .47451 Mdot
.52549 .47059 Mdot
.56863 .51373 Mdot
.83137 .76863 Mdot
.36863 .37647 Mdot
.57255 .45882 Mdot
.53725 .44706 Mdot
.87451 .84706 Mdot
.73725 .71765 Mdot
.18431 .13725 Mdot
.21961 .16863 Mdot
.42353 .35686 Mdot
.64314 .50196 Mdot
.56471 .46667 Mdot
.99216 .98039 Mdot
.68627 .18824 Mdot
.78039 .25098 Mdot
.84706 .51765 Mdot
.71373 .57647 Mdot
.93725 .67059 Mdot
.72549 .56471 Mdot
.61569 .57647 Mdot
.61961 .57647 Mdot
.82353 .78431 Mdot
.63529 .57647 Mdot
.73725 .34118 Mdot
.63137 .49412 Mdot
.56471 .28235 Mdot
.52941 .48235 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.53333 .48235 Mdot
.57647 .51765 Mdot
.77647 .78039 Mdot
.66667 .54902 Mdot
.5451 .46667 Mdot
.74118 .68627 Mdot
.8902 .89804 Mdot
.71373 .69804 Mdot
.56471 .52549 Mdot
.64314 .58039 Mdot
.49804 .38824 Mdot
.54902 .47451 Mdot
.3451 .26667 Mdot
.53333 .23529 Mdot
.77647 .25098 Mdot
.6902 .17647 Mdot
.93333 .7451 Mdot
.75686 .59608 Mdot
.75686 .45098 Mdot
.49804 .4549 Mdot
.61961 .56863 Mdot
.62745 .58431 Mdot
.6902 .6549 Mdot
.73725 .57647 Mdot
.6 .2549 Mdot
.76078 .47843 Mdot
.57647 .48235 Mdot
.52157 .48235 Mdot
.52941 .48235 Mdot
.52549 .47843 Mdot
.52157 .47843 Mdot
.58824 .52941 Mdot
.42353 .44314 Mdot
.8902 .74118 Mdot
.76471 .70196 Mdot
.86667 .8549 Mdot
.91765 .92549 Mdot
.8549 .8549 Mdot
.83529 .78431 Mdot
.35294 .24314 Mdot
.51373 .42745 Mdot
.6 .53333 Mdot
.4549 .43137 Mdot
.67451 .2 Mdot
.69804 .21176 Mdot
.78824 .27843 Mdot
.99216 .82353 Mdot
.70588 .38039 Mdot
.69804 .4902 Mdot
.44706 .40392 Mdot
.62745 .58431 Mdot
.61961 .57647 Mdot
.71373 .67451 Mdot
.80392 .55686 Mdot
.63922 .32549 Mdot
.62745 .31373 Mdot
.52549 .48627 Mdot
.5451 .50588 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.54902 .49412 Mdot
.58039 .53725 Mdot
.47451 .44314 Mdot
.83137 .76078 Mdot
.78431 .7451 Mdot
.9098 .9098 Mdot
.88235 .88627 Mdot
.90588 .90196 Mdot
.75686 .69804 Mdot
.47843 .33725 Mdot
.40784 .37647 Mdot
.6 .54902 Mdot
.81569 .72157 Mdot
.74118 .24706 Mdot
.78824 .2549 Mdot
.7451 .2902 Mdot
.52941 .2549 Mdot
.79216 .28627 Mdot
.61569 .54118 Mdot
.41569 .37255 Mdot
.61569 .57647 Mdot
.63922 .6 Mdot
.75686 .70588 Mdot
.7098 .36863 Mdot
.69804 .34118 Mdot
.67843 .46275 Mdot
.55686 .50196 Mdot
.52941 .4902 Mdot
.53725 .4902 Mdot
.53333 .4902 Mdot
.56471 .50196 Mdot
.76471 .77255 Mdot
.93333 .83922 Mdot
.85882 .82745 Mdot
.82353 .8 Mdot
.88627 .8902 Mdot
.87451 .8902 Mdot
.8549 .83137 Mdot
.49412 .40392 Mdot
.45882 .31765 Mdot
.41569 .39216 Mdot
.67451 .64706 Mdot
.56471 .23529 Mdot
.67843 .22745 Mdot
.78431 .24706 Mdot
.6549 .23922 Mdot
1 .65098 Mdot
.63529 .27843 Mdot
.60392 .56078 Mdot
.41176 .36863 Mdot
.61569 .57255 Mdot
.62353 .58039 Mdot
.80784 .72549 Mdot
.77255 .39608 Mdot
.71765 .31373 Mdot
.66275 .47451 Mdot
.56863 .49804 Mdot
.54118 .49804 Mdot
.53725 .49804 Mdot
.56078 .50588 Mdot
.57255 .5098 Mdot
.87843 .87843 Mdot
.66667 .54118 Mdot
.91765 .87843 Mdot
.8549 .85098 Mdot
.87059 .88235 Mdot
.88235 .89804 Mdot
.82353 .78039 Mdot
.50588 .38824 Mdot
.49804 .38824 Mdot
.43922 .41176 Mdot
.66275 .67451 Mdot
.66275 .23529 Mdot
.83529 .44314 Mdot
.7451 .25098 Mdot
.73725 .27843 Mdot
.83137 .35686 Mdot
.68235 .45098 Mdot
.60392 .56078 Mdot
.53725 .49804 Mdot
.63137 .58824 Mdot
.63922 .59608 Mdot
.92157 .76863 Mdot
.85882 .50196 Mdot
.75294 .34902 Mdot
.68627 .44706 Mdot
.63137 .51765 Mdot
.57647 .50588 Mdot
.55686 .50196 Mdot
.59608 .52549 Mdot
.78039 .74118 Mdot
.61176 .58431 Mdot
.64706 .53725 Mdot
.94118 .87059 Mdot
.8902 .87451 Mdot
.88235 .8902 Mdot
.87451 .88235 Mdot
.8 .74902 Mdot
.51373 .41569 Mdot
.4549 .35294 Mdot
.46275 .42353 Mdot
.97255 .97647 Mdot
.66667 .2 Mdot
.6902 .32941 Mdot
.69412 .27059 Mdot
.76863 .27059 Mdot
.81569 .28627 Mdot
.67451 .5451 Mdot
.60392 .56078 Mdot
.61569 .58824 Mdot
.63922 .58431 Mdot
.63529 .59216 Mdot
.95686 .70196 Mdot
.98039 .62353 Mdot
.82745 .44314 Mdot
.62353 .29412 Mdot
.67843 .47843 Mdot
.60784 .50588 Mdot
.61176 .54902 Mdot
.58039 .51373 Mdot
.84706 .81569 Mdot
.62745 .60392 Mdot
.41961 .27451 Mdot
.95686 .83529 Mdot
.95294 .9098 Mdot
.86275 .87843 Mdot
.86275 .87059 Mdot
.82745 .77647 Mdot
.61176 .54902 Mdot
.46275 .38431 Mdot
.45882 .40392 Mdot
.89804 .84314 Mdot
.72157 .25098 Mdot
.70588 .39216 Mdot
.56078 .23137 Mdot
.77647 .26667 Mdot
.78431 .27059 Mdot
.61961 .5451 Mdot
.61961 .56471 Mdot
.62745 .6 Mdot
.5451 .4902 Mdot
.64314 .58824 Mdot
.78431 .40392 Mdot
.83137 .45882 Mdot
.90588 .50588 Mdot
.64706 .2549 Mdot
.69804 .40784 Mdot
.65882 .50196 Mdot
.60392 .53333 Mdot
.77255 .73725 Mdot
.63137 .60784 Mdot
.63137 .6 Mdot
.44314 .27843 Mdot
.78824 .6549 Mdot
.94118 .86275 Mdot
.8902 .86275 Mdot
.8549 .84706 Mdot
.82353 .78431 Mdot
.66275 .61961 Mdot
.64314 .58824 Mdot
.47059 .43529 Mdot
.45098 .32157 Mdot
.72549 .25882 Mdot
.58824 .36471 Mdot
.67451 .47059 Mdot
.77647 .26667 Mdot
.7451 .29804 Mdot
.58824 .5451 Mdot
.6 .55686 Mdot
.61569 .58039 Mdot
.39608 .34118 Mdot
.65882 .56471 Mdot
.85882 .37255 Mdot
.66275 .24706 Mdot
.9098 .5098 Mdot
.77255 .36471 Mdot
.65098 .26667 Mdot
.71373 .47843 Mdot
.62745 .56471 Mdot
.77647 .75686 Mdot
.62745 .60784 Mdot
.62353 .59216 Mdot
.22745 .11765 Mdot
.62745 .49804 Mdot
.91765 .77255 Mdot
.92549 .8549 Mdot
.87451 .85098 Mdot
.83529 .81176 Mdot
.77255 .7451 Mdot
.82745 .79216 Mdot
.73333 .72157 Mdot
.49804 .26667 Mdot
.7098 .26667 Mdot
.8902 .73333 Mdot
.90196 .76078 Mdot
.79216 .26667 Mdot
.61961 .2902 Mdot
.60392 .56078 Mdot
.61961 .57647 Mdot
.61961 .58431 Mdot
.29412 .25098 Mdot
.71765 .53725 Mdot
.83922 .30196 Mdot
.65098 .19608 Mdot
.87843 .46275 Mdot
.8902 .43922 Mdot
.70196 .27451 Mdot
.58039 .33333 Mdot
.80784 .76471 Mdot
.63137 .61569 Mdot
.62745 .60392 Mdot
.66667 .62745 Mdot
.29412 .23922 Mdot
.87451 .76471 Mdot
.73333 .58431 Mdot
.92549 .81569 Mdot
.93725 .86667 Mdot
.85098 .81569 Mdot
.77255 .74902 Mdot
.8 .77647 Mdot
.69412 .70196 Mdot
.57647 .26667 Mdot
.65882 .24706 Mdot
.94118 .81569 Mdot
.63529 .47451 Mdot
.78431 .25098 Mdot
.71765 .50196 Mdot
.60392 .56078 Mdot
.62745 .58431 Mdot
.61176 .56863 Mdot
.36863 .32549 Mdot
.86275 .56078 Mdot
.8549 .30588 Mdot
.79608 .2902 Mdot
.75686 .31765 Mdot
.8549 .40784 Mdot
.82745 .41961 Mdot
.66275 .4549 Mdot
.72941 .68627 Mdot
.64314 .61961 Mdot
.63529 .60784 Mdot
.72157 .68627 Mdot
.84706 .82745 Mdot
.94902 .90588 Mdot
.69804 .60392 Mdot
.78824 .61569 Mdot
1 .8549 Mdot
.89412 .83137 Mdot
.80784 .77647 Mdot
.89804 .87059 Mdot
.64706 .65882 Mdot
.62745 .21569 Mdot
.69412 .38039 Mdot
.21569 .10196 Mdot
.57255 .30588 Mdot
.76471 .26667 Mdot
.61569 .54118 Mdot
.6 .55686 Mdot
.61176 .57647 Mdot
.6 .56471 Mdot
.43529 .37255 Mdot
.78824 .31373 Mdot
.83529 .29412 Mdot
.81961 .29804 Mdot
.67451 .21961 Mdot
.81569 .36863 Mdot
.87451 .46667 Mdot
.92549 .83922 Mdot
.63137 .6 Mdot
.64314 .61961 Mdot
.61569 .59216 Mdot
.17255 .14902 Mdot
.90196 .89804 Mdot
.93333 .89412 Mdot
.91765 .82745 Mdot
.58431 .39608 Mdot
.89412 .73725 Mdot
.93725 .84314 Mdot
.8 .76471 Mdot
.94902 .92157 Mdot
.90588 .86275 Mdot
.74118 .28235 Mdot
.55294 .34118 Mdot
.97647 .87059 Mdot
.65882 .29804 Mdot
.65882 .28627 Mdot
.6 .55686 Mdot
.60784 .56471 Mdot
.59608 .55294 Mdot
.60784 .57255 Mdot
.54902 .36471 Mdot
.72549 .27059 Mdot
.81961 .29412 Mdot
.83922 .30588 Mdot
.68235 .18824 Mdot
.80784 .39608 Mdot
.72941 .35686 Mdot
.64706 .59608 Mdot
.62353 .6 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.15686 .14118 Mdot
.92549 .89412 Mdot
.94118 .89804 Mdot
.96078 .9098 Mdot
.7451 .61569 Mdot
.67059 .45098 Mdot
.92549 .76471 Mdot
.87843 .80784 Mdot
.51765 .51373 Mdot
.60392 .41176 Mdot
.69804 .2902 Mdot
.82353 .68627 Mdot
.6549 .45098 Mdot
.70196 .23922 Mdot
.58039 .46667 Mdot
.60784 .56471 Mdot
.6 .55686 Mdot
.60784 .57255 Mdot
.61961 .57647 Mdot
.75686 .30588 Mdot
.60392 .23922 Mdot
.81176 .30196 Mdot
.82745 .28627 Mdot
.74902 .2549 Mdot
.81176 .38039 Mdot
.56471 .38039 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.61961 .59216 Mdot
.59608 .57647 Mdot
.96471 .9451 Mdot
.92157 .82353 Mdot
.93333 .90588 Mdot
.94902 .91765 Mdot
.92157 .78431 Mdot
.51765 .28235 Mdot
.8902 .81176 Mdot
.58039 .51373 Mdot
.97255 .98039 Mdot
.6902 .28235 Mdot
.68627 .41176 Mdot
.84314 .68627 Mdot
.90196 .60392 Mdot
.64706 .29412 Mdot
.6 .55686 Mdot
.61961 .56863 Mdot
.60784 .56471 Mdot
.61176 .56863 Mdot
.80392 .55686 Mdot
.62353 .2902 Mdot
.57647 .27451 Mdot
.8 .3098 Mdot
.83529 .28627 Mdot
.78039 .25882 Mdot
.68627 .26275 Mdot
.63137 .58431 Mdot
.61569 .59216 Mdot
.60784 .58824 Mdot
.61961 .60784 Mdot
.16471 .14118 Mdot
.97647 .87451 Mdot
.91373 .78431 Mdot
.92549 .91765 Mdot
.95686 .91373 Mdot
.97255 .8902 Mdot
.48627 .32941 Mdot
.64314 .5451 Mdot
.48627 .4902 Mdot
.33333 .25882 Mdot
.70196 .28627 Mdot
.55294 .28627 Mdot
.90588 .67451 Mdot
.63529 .16471 Mdot
.62745 .51373 Mdot
.60784 .55294 Mdot
.61569 .57255 Mdot
.61569 .57255 Mdot
.64706 .57647 Mdot
.80784 .30196 Mdot
.94118 .80392 Mdot
.58431 .29412 Mdot
.8 .32157 Mdot
.85098 .28235 Mdot
.81961 .28235 Mdot
.56863 .35294 Mdot
.60392 .58039 Mdot
.61176 .59216 Mdot
.62353 .60392 Mdot
.56863 .54118 Mdot
.98824 .92549 Mdot
.69804 .50588 Mdot
.96471 .89804 Mdot
.38431 .36471 Mdot
.91765 .89804 Mdot
.97255 .87059 Mdot
.90196 .81176 Mdot
.88235 .82745 Mdot
.97647 .98431 Mdot
.61176 .25882 Mdot
.58824 .23529 Mdot
.52157 .16471 Mdot
.55686 .16471 Mdot
.61961 .34118 Mdot
.31765 .26275 Mdot
.61961 .56471 Mdot
.60784 .57255 Mdot
.61961 .56471 Mdot
.7451 .32157 Mdot
.63137 .36471 Mdot
.9451 .84314 Mdot
.57255 .29804 Mdot
.83529 .30196 Mdot
.8549 .26667 Mdot
.74902 .34118 Mdot
.60784 .58431 Mdot
.62353 .60392 Mdot
.60392 .59216 Mdot
.6549 .63529 Mdot
.1098 .06275 Mdot
.56471 .36471 Mdot
.81176 .69412 Mdot
.59608 .57647 Mdot
.65882 .62745 Mdot
.9098 .8902 Mdot
.72549 .60392 Mdot
.57647 .52157 Mdot
.66667 .68627 Mdot
.41569 .3098 Mdot
.62353 .23529 Mdot
.59216 .16471 Mdot
.52549 .15294 Mdot
.74118 .28627 Mdot
.63922 .56863 Mdot
.6 .5451 Mdot
.61961 .57647 Mdot
.61569 .57255 Mdot
.78431 .53725 Mdot
.81176 .31373 Mdot
.95294 .81569 Mdot
.93725 .82745 Mdot
.66667 .29804 Mdot
.86275 .27451 Mdot
.82353 .27451 Mdot
.65098 .57255 Mdot
.62353 .60392 Mdot
.62745 .60392 Mdot
.61569 .60392 Mdot
.20392 .16471 Mdot
.51373 .34118 Mdot
.94902 .76471 Mdot
.10588 .06667 Mdot
.87451 .8549 Mdot
.52941 .5098 Mdot
.99608 .88627 Mdot
.52941 .48235 Mdot
.8549 .84706 Mdot
.77647 .76471 Mdot
.61961 .30196 Mdot
.73725 .26275 Mdot
.76078 .30196 Mdot
.79216 .28235 Mdot
.61961 .52549 Mdot
.29412 .23922 Mdot
.62353 .58039 Mdot
.60784 .57255 Mdot
.69412 .51765 Mdot
.83922 .27843 Mdot
.78431 .44706 Mdot
.94902 .83137 Mdot
.95294 .76471 Mdot
.86275 .27843 Mdot
.83529 .26667 Mdot
.69804 .57647 Mdot
.62353 .59608 Mdot
.60392 .59216 Mdot
.64314 .62353 Mdot
.16863 .12941 Mdot
.77255 .66275 Mdot
.70588 .47059 Mdot
.90196 .86667 Mdot
.87843 .85098 Mdot
.8 .76078 Mdot
.96078 .86667 Mdot
.87451 .83529 Mdot
.88627 .88627 Mdot
.97647 .97255 Mdot
.58039 .2902 Mdot
.74118 .25098 Mdot
.76863 .27059 Mdot
.77647 .28627 Mdot
.62745 .56078 Mdot
.40392 .34902 Mdot
.63137 .58824 Mdot
.61176 .57647 Mdot
.83922 .55686 Mdot
.83137 .27059 Mdot
.60392 .22353 Mdot
.95294 .82745 Mdot
1 .81961 Mdot
.8549 .27843 Mdot
.81176 .26667 Mdot
.63922 .57647 Mdot
.62745 .60784 Mdot
.61569 .60392 Mdot
.52549 .50588 Mdot
.21176 .14902 Mdot
.93333 .8 Mdot
.80392 .57647 Mdot
.58824 .5451 Mdot
.52157 .4902 Mdot
.66275 .63137 Mdot
1 .89804 Mdot
.75294 .72549 Mdot
.88627 .88235 Mdot
.82353 .75294 Mdot
.67451 .31765 Mdot
.77647 .25098 Mdot
.81569 .27843 Mdot
.73725 .52941 Mdot
.60392 .56078 Mdot
.4 .35686 Mdot
.61961 .58431 Mdot
.69804 .5451 Mdot
.82745 .28235 Mdot
.78824 .3098 Mdot
.57255 .27843 Mdot
.9098 .85098 Mdot
.82745 .30588 Mdot
.8549 .27843 Mdot
.61569 .42353 Mdot
.57255 .5451 Mdot
.43137 .41961 Mdot
.27843 .26667 Mdot
.21961 .17647 Mdot
.76078 .62745 Mdot
.92157 .72549 Mdot
.9098 .87843 Mdot
.68627 .66667 Mdot
.63137 .6 Mdot
.94118 .88235 Mdot
.93333 .83137 Mdot
.86275 .85882 Mdot
.96863 .97647 Mdot
.55686 .3098 Mdot
.64706 .18824 Mdot
.81569 .27843 Mdot
.74118 .4902 Mdot
.60392 .56078 Mdot
.34902 .30588 Mdot
.63137 .59608 Mdot
.7098 .53333 Mdot
.82745 .28235 Mdot
.75294 .34118 Mdot
.49804 .23137 Mdot
.90196 .8549 Mdot
.82353 .31765 Mdot
.83922 .26275 Mdot
.63529 .44706 Mdot
.27843 .25098 Mdot
.30196 .27843 Mdot
.4549 .44314 Mdot
.20784 .16471 Mdot
.36471 .23137 Mdot
.93333 .73725 Mdot
.8902 .87059 Mdot
.94118 .92157 Mdot
.97255 .95294 Mdot
.92549 .88235 Mdot
.96863 .84706 Mdot
.87451 .86667 Mdot
.96863 .97647 Mdot
.53725 .3451 Mdot
.72549 .22745 Mdot
.8 .29412 Mdot
.57647 .48627 Mdot
.6 .55686 Mdot
.25882 .21569 Mdot
.63922 .58431 Mdot
.72157 .28235 Mdot
.80392 .30196 Mdot
.76078 .61569 Mdot
.48235 .41176 Mdot
.99216 .83922 Mdot
.84706 .27451 Mdot
.75686 .28627 Mdot
.45882 .43529 Mdot
.55294 .53333 Mdot
.61176 .58824 Mdot
.59216 .56863 Mdot
.19608 .12549 Mdot
1 .8902 Mdot
.78431 .67451 Mdot
.24706 .21961 Mdot
.22745 .20784 Mdot
.6902 .67843 Mdot
.98824 .89412 Mdot
.90196 .84314 Mdot
.4 .43137 Mdot
.69412 .63529 Mdot
.69412 .31373 Mdot
.77647 .24706 Mdot
.70588 .49804 Mdot
.59608 .55294 Mdot
.62353 .58039 Mdot
.62745 .58431 Mdot
.82353 .42353 Mdot
.80784 .28235 Mdot
.94118 .86667 Mdot
.91765 .85882 Mdot
.91373 .83922 Mdot
.84706 .2902 Mdot
.81176 .28235 Mdot
.63529 .59608 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.59216 .56863 Mdot
.15294 .11373 Mdot
.87843 .74118 Mdot
.55686 .42745 Mdot
.81176 .78431 Mdot
.28627 .2549 Mdot
.2902 .27059 Mdot
.92157 .87843 Mdot
.81569 .69804 Mdot
.89412 .90588 Mdot
.73333 .69804 Mdot
.71765 .31373 Mdot
.76471 .25882 Mdot
.60392 .46667 Mdot
.59608 .55294 Mdot
.61961 .58039 Mdot
.63922 .54118 Mdot
.82353 .29804 Mdot
.70588 .3451 Mdot
.88235 .85882 Mdot
.91373 .83529 Mdot
.98824 .79608 Mdot
.84706 .26275 Mdot
.65882 .31765 Mdot
.58431 .56471 Mdot
.6 .57255 Mdot
.6 .58039 Mdot
.67451 .65098 Mdot
.98431 .90588 Mdot
.91373 .70588 Mdot
.95686 .91373 Mdot
.34902 .32157 Mdot
.97647 .94118 Mdot
.9451 .94118 Mdot
.93333 .87059 Mdot
.21176 .1451 Mdot
.46275 .5098 Mdot
.54118 .38039 Mdot
.76078 .30196 Mdot
.68235 .32549 Mdot
.54902 .4902 Mdot
.61176 .56863 Mdot
.37255 .32941 Mdot
.77255 .33333 Mdot
.81176 .30196 Mdot
.89412 .86667 Mdot
.93725 .83922 Mdot
.97255 .79216 Mdot
.83529 .29412 Mdot
.79608 .29412 Mdot
.62353 .58824 Mdot
.59608 .57255 Mdot
.59216 .57255 Mdot
.58431 .56078 Mdot
.13333 .07843 Mdot
.91765 .69412 Mdot
.67059 .56471 Mdot
.81961 .8 Mdot
.33725 .28627 Mdot
.5098 .4902 Mdot
.89412 .89412 Mdot
.36078 .25098 Mdot
.87059 .8902 Mdot
.92157 .85882 Mdot
.64706 .27843 Mdot
.68235 .2549 Mdot
.54902 .47451 Mdot
.59608 .56078 Mdot
.61176 .57255 Mdot
.77255 .31373 Mdot
.81176 .28627 Mdot
.87843 .84314 Mdot
.94902 .77647 Mdot
.85098 .51373 Mdot
.83529 .2902 Mdot
.79216 .29804 Mdot
.61569 .57255 Mdot
.61176 .59216 Mdot
.58431 .56471 Mdot
.59216 .57647 Mdot
.20392 .12941 Mdot
.74118 .49412 Mdot
.96471 .86667 Mdot
.59216 .56078 Mdot
.82353 .78039 Mdot
.50196 .48627 Mdot
.8902 .8902 Mdot
.32941 .22745 Mdot
.86667 .89412 Mdot
.88235 .78431 Mdot
.67451 .24706 Mdot
.70588 .45098 Mdot
.55686 .50588 Mdot
.60392 .57647 Mdot
.65098 .46667 Mdot
.82745 .27059 Mdot
.47451 .16078 Mdot
.89804 .86275 Mdot
.66667 .2549 Mdot
.72941 .3098 Mdot
.84706 .27843 Mdot
.61176 .40784 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.59608 .57647 Mdot
.16471 .12549 Mdot
.85882 .70196 Mdot
.67451 .44706 Mdot
.93725 .91765 Mdot
.48235 .44706 Mdot
.44314 .41569 Mdot
.89804 .89804 Mdot
.93725 .87451 Mdot
.53333 .4902 Mdot
.4902 .5451 Mdot
.62353 .30196 Mdot
.61176 .32157 Mdot
.56078 .47843 Mdot
.58824 .56078 Mdot
.7098 .52549 Mdot
.82353 .26667 Mdot
.63922 .25098 Mdot
.89804 .87059 Mdot
.75294 .36078 Mdot
.72941 .22353 Mdot
.83137 .27059 Mdot
.64706 .4549 Mdot
.61176 .58431 Mdot
.60392 .58039 Mdot
.6 .57647 Mdot
.17647 .13725 Mdot
.49412 .33725 Mdot
1 .80392 Mdot
.39216 .37255 Mdot
.9098 .86667 Mdot
.84706 .81961 Mdot
.90196 .90196 Mdot
.94118 .87843 Mdot
.54902 .51373 Mdot
.73725 .77647 Mdot
.83137 .55686 Mdot
.72157 .4902 Mdot
.56078 .44706 Mdot
.56863 .53333 Mdot
.8 .52549 Mdot
.81961 .26667 Mdot
.54118 .18431 Mdot
.88627 .84314 Mdot
.69412 .31765 Mdot
.81961 .30588 Mdot
.80784 .27843 Mdot
.67059 .57255 Mdot
.60392 .57647 Mdot
.59608 .57647 Mdot
.59608 .57255 Mdot
.21569 .16863 Mdot
.72941 .59608 Mdot
.60392 .42745 Mdot
.20784 .17647 Mdot
.40784 .36863 Mdot
.48235 .46275 Mdot
.89412 .89412 Mdot
.94902 .86667 Mdot
.88627 .87451 Mdot
.75686 .72941 Mdot
.63922 .38039 Mdot
.54118 .33725 Mdot
.56078 .46275 Mdot
.61569 .55686 Mdot
.78824 .29804 Mdot
.82353 .27059 Mdot
.94118 .73725 Mdot
.96471 .88235 Mdot
.63529 .28627 Mdot
.81176 .30196 Mdot
.62745 .32157 Mdot
.60392 .57647 Mdot
.62353 .58431 Mdot
.59216 .56863 Mdot
.52941 .51373 Mdot
.9451 .90588 Mdot
.6 .43922 Mdot
.96863 .9098 Mdot
.15294 .13725 Mdot
.54902 .51373 Mdot
.94902 .9451 Mdot
.90196 .88627 Mdot
.2549 .16471 Mdot
.33333 .37255 Mdot
.78431 .69412 Mdot
.72941 .53333 Mdot
.60392 .40784 Mdot
.56863 .49412 Mdot
.79216 .48235 Mdot
.82353 .27059 Mdot
.77255 .31373 Mdot
.92549 .82353 Mdot
.83137 .67059 Mdot
.59216 .23529 Mdot
.76078 .31373 Mdot
.61176 .58431 Mdot
.60784 .58039 Mdot
.61569 .59216 Mdot
.6 .56471 Mdot
.36078 .34118 Mdot
.97647 .88235 Mdot
.96078 .83922 Mdot
.44314 .42745 Mdot
.83922 .8 Mdot
.52157 .50588 Mdot
.89804 .89804 Mdot
.4 .30588 Mdot
.87451 .90196 Mdot
.38824 .39216 Mdot
.84706 .67843 Mdot
.70196 .47843 Mdot
.62745 .45098 Mdot
.63922 .48235 Mdot
.79608 .28235 Mdot
.81961 .27451 Mdot
.7098 .36471 Mdot
.92941 .83922 Mdot
.85098 .72157 Mdot
.79608 .32157 Mdot
.65098 .59608 Mdot
.59216 .57255 Mdot
.58039 .56078 Mdot
.56863 .55294 Mdot
.20392 .17255 Mdot
.94118 .88627 Mdot
.85098 .66275 Mdot
.78039 .73725 Mdot
.15686 .13333 Mdot
.55294 .52157 Mdot
.89412 .90196 Mdot
.97647 .91373 Mdot
.78431 .78431 Mdot
.83529 .83922 Mdot
.81569 .69804 Mdot
.86275 .67059 Mdot
.49412 .30196 Mdot
.62745 .46667 Mdot
.78824 .29804 Mdot
.82745 .28235 Mdot
.63137 .18431 Mdot
.97255 .81176 Mdot
.93725 .8549 Mdot
.77647 .33725 Mdot
.61961 .58039 Mdot
.61569 .59608 Mdot
.59216 .57255 Mdot
.56471 .5451 Mdot
.18824 .15686 Mdot
.93725 .87451 Mdot
.74902 .52941 Mdot
.98824 .94902 Mdot
.78039 .76471 Mdot
.26667 .24314 Mdot
.8902 .89804 Mdot
.99216 .92157 Mdot
.85098 .85882 Mdot
.73725 .73725 Mdot
.72157 .61569 Mdot
.8 .65098 Mdot
.43922 .31373 Mdot
.76078 .4549 Mdot
.77647 .28627 Mdot
.81961 .28627 Mdot
.68235 .22353 Mdot
.97647 .72941 Mdot
.97647 .80392 Mdot
.68627 .35686 Mdot
.61961 .59608 Mdot
.57255 .5451 Mdot
.47059 .45098 Mdot
.45882 .44314 Mdot
.93333 .91765 Mdot
.79216 .63529 Mdot
.55294 .40784 Mdot
.90196 .90196 Mdot
.91765 .9098 Mdot
.85882 .8549 Mdot
.89804 .8902 Mdot
.28627 .2 Mdot
.90196 .93333 Mdot
.63137 .58039 Mdot
.88235 .79216 Mdot
.86275 .76471 Mdot
.68627 .47059 Mdot
.70196 .27059 Mdot
.8 .29412 Mdot
.83529 .31373 Mdot
.60392 .20784 Mdot
.95294 .70196 Mdot
.71373 .36471 Mdot
.49412 .47059 Mdot
.2902 .26275 Mdot
.3451 .32549 Mdot
.47843 .47059 Mdot
.56863 .5451 Mdot
.94902 .82745 Mdot
.61961 .43529 Mdot
.92157 .8902 Mdot
.90588 .8902 Mdot
.78039 .78039 Mdot
.89804 .89804 Mdot
.43137 .34118 Mdot
.89412 .92157 Mdot
.66667 .63922 Mdot
.93725 .89804 Mdot
.55294 .42353 Mdot
.63529 .25098 Mdot
.77255 .30588 Mdot
.80784 .30196 Mdot
.76078 .27843 Mdot
.63137 .22353 Mdot
.71373 .37255 Mdot
.36471 .34118 Mdot
.41176 .37255 Mdot
.53725 .5098 Mdot
.67451 .65882 Mdot
.83529 .81961 Mdot
.93725 .81961 Mdot
.97647 .82353 Mdot
.96863 .87843 Mdot
.92549 .8902 Mdot
.61569 .61569 Mdot
.90196 .89412 Mdot
.2902 .19216 Mdot
.92157 .95294 Mdot
.98039 .97647 Mdot
.58039 .37255 Mdot
.61569 .23137 Mdot
.74118 .28627 Mdot
.80784 .30196 Mdot
.80392 .29412 Mdot
.71373 .28627 Mdot
.58039 .53333 Mdot
.59608 .56078 Mdot
.61176 .58824 Mdot
.57255 .55686 Mdot
.08627 .07059 Mdot
.94118 .87843 Mdot
.86667 .69412 Mdot
1 .88627 Mdot
.8902 .73725 Mdot
.9098 .90588 Mdot
.8902 .89804 Mdot
.96863 .87843 Mdot
.83922 .87059 Mdot
.79216 .69412 Mdot
.57255 .24706 Mdot
.69804 .26667 Mdot
.78824 .31765 Mdot
.81569 .30196 Mdot
.72549 .36471 Mdot
.57647 .55294 Mdot
.58431 .56078 Mdot
.57255 .55686 Mdot
.63529 .61569 Mdot
.64706 .63137 Mdot
.96078 .85882 Mdot
.77255 .59608 Mdot
.89804 .68627 Mdot
.62353 .44314 Mdot
.9098 .9098 Mdot
.89412 .88627 Mdot
.26275 .18039 Mdot
.9451 .96863 Mdot
.66275 .48627 Mdot
.60784 .26275 Mdot
.70588 .28235 Mdot
.79608 .29804 Mdot
.73725 .34118 Mdot
.58039 .5451 Mdot
.57647 .55294 Mdot
.56863 .5451 Mdot
.56078 .54118 Mdot
.23137 .20784 Mdot
.97255 .88627 Mdot
.63137 .45098 Mdot
.94902 .71373 Mdot
.56471 .33725 Mdot
.93725 .9451 Mdot
.8902 .89412 Mdot
.5098 .43529 Mdot
.91373 .93725 Mdot
.71373 .58431 Mdot
.58431 .27451 Mdot
.71373 .27451 Mdot
.76078 .30196 Mdot
.64314 .52549 Mdot
.56471 .54118 Mdot
.56471 .52941 Mdot
.55294 .52941 Mdot
.19216 .16078 Mdot
.9451 .87059 Mdot
.76078 .61176 Mdot
.86275 .69412 Mdot
.74902 .42353 Mdot
.52157 .52157 Mdot
.87451 .91765 Mdot
.93333 .87059 Mdot
.83529 .84314 Mdot
.98824 .92941 Mdot
.54902 .3098 Mdot
.62745 .23529 Mdot
.70196 .29804 Mdot
.57647 .52157 Mdot
.56078 .52549 Mdot
.57647 .53333 Mdot
.54902 .52941 Mdot
.19608 .16078 Mdot
.65882 .5451 Mdot
.58824 .4549 Mdot
.48627 .2 Mdot
.62353 .45882 Mdot
.54902 .54902 Mdot
.71765 .76863 Mdot
.89412 .83529 Mdot
.86667 .89412 Mdot
.90588 .82353 Mdot
.53333 .27843 Mdot
.63529 .25882 Mdot
.60392 .54118 Mdot
.55686 .52549 Mdot
.56471 .52941 Mdot
.54118 .50588 Mdot
.20784 .16471 Mdot
.94118 .85882 Mdot
.82353 .68627 Mdot
.82353 .6549 Mdot
.56078 .35294 Mdot
.47059 .41961 Mdot
.40392 .46275 Mdot
.6 .52157 Mdot
.83137 .86667 Mdot
.93725 .82353 Mdot
.57255 .29412 Mdot
.59608 .52941 Mdot
.54902 .52941 Mdot
.53333 .51373 Mdot
.55294 .51765 Mdot
.22745 .18824 Mdot
.92157 .87843 Mdot
.77647 .65882 Mdot
.97647 .87843 Mdot
.63922 .36471 Mdot
.44314 .38039 Mdot
.57647 .58431 Mdot
.41961 .34902 Mdot
.83922 .86667 Mdot
.98431 .90196 Mdot
.90588 .84314 Mdot
.55686 .55294 Mdot
.52157 .5098 Mdot
.55686 .50588 Mdot
.22353 .17255 Mdot
.90196 .89804 Mdot
.5098 .43529 Mdot
.96078 .90196 Mdot
.73725 .33725 Mdot
.51765 .4902 Mdot
.61569 .54118 Mdot
.48627 .43137 Mdot
.83922 .8549 Mdot
.97647 .98824 Mdot
.75686 .76078 Mdot
.59608 .6 Mdot
.49804 .47451 Mdot
.53333 .46667 Mdot
.80392 .77647 Mdot
.92157 .8902 Mdot
.91765 .90196 Mdot
.41961 .23922 Mdot
.54902 .4 Mdot
.63137 .53725 Mdot
.4549 .40392 Mdot
.83137 .80392 Mdot
.87451 .90196 Mdot
.83137 .84706 Mdot
.63529 .65882 Mdot
.8 .6902 Mdot
.30588 .22353 Mdot
.94118 .91373 Mdot
.93725 .9098 Mdot
.91373 .8902 Mdot
.6902 .42353 Mdot
.57255 .55686 Mdot
.53725 .47451 Mdot
.70196 .63137 Mdot
.84314 .87843 Mdot
.98039 .99608 Mdot
.65098 .67059 Mdot
.63529 .52941 Mdot
.4902 .42353 Mdot
.94902 .89412 Mdot
.94118 .89804 Mdot
.92549 .8902 Mdot
.49412 .33333 Mdot
.69804 .68235 Mdot
.87059 .80784 Mdot
.81176 .77647 Mdot
.87059 .9098 Mdot
.86667 .83529 Mdot
.87059 .84314 Mdot
.72549 .66275 Mdot
.88235 .8 Mdot
.96863 .89804 Mdot
1 .91373 Mdot
.91765 .90588 Mdot
.7451 .69804 Mdot
.61961 .53725 Mdot
.83922 .87451 Mdot
1 .99216 Mdot
.84706 .84706 Mdot
.81961 .74902 Mdot
.62745 .53725 Mdot
.86667 .79216 Mdot
.97255 .9098 Mdot
.92941 .89804 Mdot
.48627 .42745 Mdot
.83529 .78431 Mdot
.87059 .92549 Mdot
.98824 .99216 Mdot
.85098 .84706 Mdot
.91765 .86275 Mdot
.66667 .59608 Mdot
.73725 .63529 Mdot
.95294 .87059 Mdot
.98824 .90588 Mdot
.79608 .71765 Mdot
.82745 .87059 Mdot
.99216 1 Mdot
.80784 .78039 Mdot
.92157 .87451 Mdot
.8549 .77647 Mdot
.61569 .5451 Mdot
.77255 .67059 Mdot
.49804 .43922 Mdot
.82353 .85882 Mdot
.98824 1 Mdot
.78824 .77255 Mdot
.82745 .79608 Mdot
.88235 .85098 Mdot
.82353 .78824 Mdot
.63922 .56863 Mdot
.85882 .83137 Mdot
.76078 .83529 Mdot
.62353 .62745 Mdot
.8 .79216 Mdot
.75294 .74902 Mdot
.75686 .76078 Mdot
.87451 .83922 Mdot
.84706 .83137 Mdot
.56863 .63137 Mdot
.96078 .96471 Mdot
.75294 .77255 Mdot
.8 .80392 Mdot
.87451 .87843 Mdot
.9451 .92941 Mdot
.92549 .92157 Mdot
.85098 .88235 Mdot
.8902 .90588 Mdot
.93725 .9451 Mdot
.99216 1 Mdot
.99216 .99216 Mdot
.98824 .99608 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooo
ool>00000003o`0000000000000009`000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003oooooooooooooool=00000004o`00000I6AT06ATI01TI6I`000001?ooool00`00003ooooo
ooooo`3?ooooo`002Oooool01000003oooooooooooooool?000000D06ATIV@000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`l000001P0I6AVH000000Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo3`00000201TI6@<00000
00<06ATIo`0000000000UP000004ooooo`0300000?oooooooooo08_ooooo0_l00012ooooo`002Ooo
ool01000003oooooooooooooool?000000806ATI00?o000003<c<`0c<c<0100000000ol000000000
0000002B000000Cooooo00<00000ooooooooool0R?ooool3o`000003ooooool0003ooooo047ooooo
0009ooooo`0400000?ooooooooooooooo`l000000P0I6AT00ol00000<c<c03<c<`03o`0009H00000
1?ooool00`00003oooooooooo`26ooooo`;o00000oooool00onY_NSo0000o`000011ooooo`002Ooo
ool01000003oooooooooooooool@0000000501TI6@000000<c<c03<c<ol000000P1<C4`2o`0009@0
00001?ooool00`00003oooooooooo`23ooooo`?o00000_ooool4ojVmj003o`000?oooooo0000043o
oooo0009ooooo`0400000?oooooooooooooooa00000000Co000001TI6@00003o0000101<C4`3o`00
000300000?l00000000008l000001?ooool00`00003oooooooooo`20ooooo`?o00000_ooool7ojVm
j003o`000?oooooo0000043ooooo0009ooooo`0400000?oooooooooooooooa<0000000?o000004a<
C01<C4`00P1<C4`3o`000080000000<06ATI000000000000S@000004ooooo`0300000?oooooooooo
07kooooo0_l00003ooooo`WoZKgX00Co0000ojVmj?oooooo0000?oooool000Wooooo00@00000oooo
oooooooooooo500000000ol00000C4a<04a<C002o`00000307moOol0003o000000;o000000<06ATI
000000000000S0000004ooooo`0300000?oooooooooo07_ooooo0ol00002ooooo`coZKgX00Go0000
ojVmj?ooooooooooo`00000nooooo`002Oooool01000003ooooooooooooooolE000000[o000000<0
6ATIo`0000000000R`000004ooooo`0300000?oooooooooo07Wooooo0_l00003ooooo`koZKgX00Go
0000ojVmj?nY_NSoooooo`00000nooooo`002Oooool01000003ooooooooooooooolD000000Go0000
0P2IVIT2o`00000407moOol0003o000001TI6H`000001?ooool00`00003oooooooooo`1fooooo`?o
00000_oooolAojVmj006o`000?nY_NSoZKgXojVmj?oooooo0000?Oooool000Wooooo00@00000oooo
oooooooooooo5P000003o`000080VIVI1Ol000000`0000006ATI0000002:000000Cooooo00<00000
ooooooooool0M?ooool2o`0000;ooooo5?nY_NP00ol0003oZKgXojVmj002ojVmj003o`000?oooooo
oooo03_ooooo0009ooooo`0400000?oooooooooooooooaL000001Ol000000`3<c<co0000o`000002
o`0000030000000I6AT06ATI08T000001?ooool00`00003oooooooooo`1aooooo`?o00000_oooolF
ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ooooooooool0>_ooool000Wooooo00@00000oooo
oooooooooooo60000004o`0000<0c<c<1?l000000`0000006ATI00000027000000Cooooo00<00000
ooooooooool0K_ooool3o`0000;ooooo6OnY_NP00ol0003oZKgXojVmj003ojVmj003ooooool0003o
oooo03[ooooo0009ooooo`0400000?oooooooooooooooaL0000000<06ATIo`000?l000000_l00003
0<c<c0Go000000<0000001TI6Ol00000QP000004ooooo`0300000?oooooooooo06cooooo0_l00003
oooooacoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oooooooooo`0iooooo`002Oooool01000
003ooooooooooooooolH0000000301TI6@00003o000000;o00000P3<c<`6o`0000030000000I6AT0
6ATI08D000001?ooool00`00003oooooooooo`1Yooooo`?o00000_oooolOojVmj003o`000?nY_NSo
ZKgX00?oZKgX00?oooooo`000?ooool0>Oooool000Wooooo00@00000oooooooooooooooo60000000
0ol00000000000000004o`000080oooo1Ol000000`0000006ATI01TI6@24000000Cooooo00<00000
ooooooooool0Ioooool2o`0000?ooooo8OnY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0003o
oooo03Sooooo0009ooooo`0400000?oooooooooooooooa/000001Ol000020?ooo`Go000000<00000
01TI6Ol00000P`000004ooooo`0300000?oooooooooo06Cooooo0ol00002ooooobCoZKgX00?o0000
ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`0hooooo`002Oooool01000003ooooooooooooooolL
000000Go00000P3oool5o`0000030000000I6AT06ATI034000003`0I6AU2000000Cooooo00<00000
ooooooooool0H_ooool2o`0000?ooooo9_nY_NP00ol0003oZKgXojVmj005ojVmj003ooooool0003o
oooo03Oooooo0009ooooo`0400000?oooooooooooooooa/0000000?o000000000?l000001?l00002
0?ooo`Ko00000P0I6ATY000001d06ATI>`000004ooooo`0300000?oooooooooo05oooooo0ol00002
ooooobWoZKgX00?o0000ojVmj?nY_NP01_nY_NP00ooooooo0000ooooo`0fooooo`002Oooool01000
003ooooooooooooooolN000000co000000<0000001TI6@0I6AT07`0000000ol00000000001TI6@0V
01TI6@80000000?o0000000000000000<`000004ooooo`0300000?oooooooooo05gooooo0_l00003
ooooob_oZKgX00?o0000ojVmj?nY_NP01onY_NP00ol0003oooooooooo`0eooooo`002Oooool01000
003ooooooooooooooolN0000000301TI6@00003o000000?o00000P3Vi^H5o`0000040000000I6AT0
6ATI01TI6A/00000;`0I6ATd000000Cooooo00<00000ooooooooool0F_ooool3o`0000;ooooo;_nY
_NP00ol0003oZKgXojVmj008ojVmj003o`000?oooooooooo03Cooooo0009ooooo`0400000?oooooo
oooooooooal0000000<06ATI00000?l000001?l000000`3Vi^Ko0000o`000003o`0000040000000I
6AT06ATI01TI6AP000006`0I6AT?o`0000X06ATI<@000004ooooo`0300000?oooooooooo05Oooooo
0ol00003oooooc3oZKgX00?o0000ojVmj?nY_NP02?nY_NP00ooooooo0000ooooo`0dooooo`002Ooo
ool01000003ooooooooooooooolO00000003o`0000000000000000_o000000D0000001TI6@0I6AT0
6ATIo`00000D00000003o`00000I6AT06ATI01T06ATI00?o000003<c<`0c<c<03@0c<c<7o`0000L0
6ATI00<00000o`0000000000:P000004ooooo`0300000?oooooooooo05Gooooo0_l00003oooooc?o
ZKgX00?o0000ojVmj?nY_NP02OnY_NP00ol0003oooooooooo`0cooooo`002Oooool01000003ooooo
oooooooooolQ0000000301TI6Ol0003o000000Co00000P2c/k<4o`0000030000000I6AT06ATI0080
6ATI4`00000K01TI6@03o`00000c<c<0<c<c01D0<c<c0ol0000701TI6BX000001?ooool00`00003o
ooooooooo`1Booooo`?o00000ooooolcojVmj0;oZKgW00?o0000ojVmj?nY_NP02OnY_NP00ooooooo
0000ooooo`0cooooo`002Oooool01000003ooooooooooooooolR0000000301TI6@00003o000000?o
00000P2c/k<4o`00000303<c<`0000006ATI00<06ATI4P00000J01TI6@03o`00000c<c<0<c<c00L0
<c<c2ol0000703<c<`?o00001@0I6ATY000000Cooooo00<00000ooooooooool0D?ooool2o`0000Co
oooo7?nY_NP2ojVmi`GoZKgX00?oZKgWojVmj?nY_NP00onY_NP00onY_>OoZKgXojVmj003ojVmj0;o
ZKcW0_nY_NP01onY_>OoZKgWojVmionY_NOo0000ojVmj?nY_>L01OnY_NP00onY_NOoZKgXojVmj002
ojVmj003o`000?oooooooooo03;ooooo0009ooooo`0400000?ooooooooooooooobD000001Ol00000
0`2IVIWo000007moO`02o`00000303<c<ol000006ATI00@06ATI4000000I01TI6@03o`00000c<c<0
<c<c00H0<c<c0_l0000;04a<C0Co00001P0c<c<00ol000006ATI01TI6@0501TI6BH000001?ooool0
0`00003oooooooooo`1=ooooo`?o00000ooooolGojVmj003ojVmionY_NSoZKgX00?oZKgX00?oZKcW
ojVmionY_NL00_nY_NL00onY_NSoZKcWojVmi`03ojVmi`03ojVmj?nY_>OoZKcW00?oZKcW0_nY_NP3
ojVli`03ojZjiOnY_>OoZKcW00;oZKcW0_nY_NL01?l0003oZKcWojVlionY_>L2ojVmj004ojZlionY
_NOoZKgWojVmi`;oZKgX00?oZKgWooooool00000<oooool000Wooooo00@00000oooooooooooooooo
9P00000:o`00000303<c<`0000006ATI00@06ATI3`00000H01TI6@03o`00000c<c<0<c<c00H0<c<c
00?o000004a<C01<C4`01`1<C4`4o`0000@0C4a<1?l0000303<c<`Co00001@0I6ATT000000Cooooo
00<00000ooooooooool0Boooool2o`0000Cooooo5_nY_NP2ojVli`?oZKgW00?oZKgXojVlionY_>L0
0onY_>L2ojVmi`04ojVki_nY_>OoZKcWojVli`;oZKgW0_nY^^D2ojVli`04ojZghonZ^^GoZ[[UojZj
i@;oZKcW00CoZ[SSojZjiOnZ^^GoZ[[U0_nY_>L01onZ^NCoZ[_VojZki_l0003oZ[_VojVlionZ^^D0
1?nZ_>L00onY_NOoZ[cVojZliP03ojVmi`03ooooool0003ooooo037ooooo0009ooooo`0400000?oo
ooooooooooooobH0000000<06ATI00000?l000000ol000001`1oOgoo0000o`00001<C4co000003<c
<`0000001P0I6AT=000001P06ATI00?o000003<c<`0c<c<01P0c<c<00ol00000C4a<04a<C00404a<
C0?o0000101VIVH4o`0000@0C4a<0ol0000403<c<`;o00001@0I6ATR000000Cooooo00<00000oooo
ooooool0B?ooool3o`0000?ooooo0onY_NL00onY_NSoZKgWojVmi`04ojVmj0;oZKgW1OnY_NP00onY
_NOoZKgXojVmj003ojVmj0GoZKcW00?oZKgWojVki_nY_>L01?nY_>L2ojVii@?oZK_V00KoZKcWojZh
i?nZ^>CoZ[STojVjiOnZ/ml4ojZgh`03ojZjiOn[/mooZk?O00?oZ[SS00?oZ[[Uoj^eh?n[]N000onZ
^N@00onZ^nKo0000oj^hh`03ojZji@;oZ[cW00?oZ[[UojZli_nZ_>H00_nZ_>H01?nY_NOoZ[cVojZl
i_l0000booooo`002Oooool01000003ooooooooooooooolY000000Go000000H0IVIVo`00001<C4co
000003<c<`00000601TI6@`00000600I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<
00@0C4a<00?o000006IVIP1VIVH02@1VIVH3o`0000@0C4a<0_l0000403<c<`03o`00000I6AT06ATI
00@06ATI80000004ooooo`0300000?oooooooooo04Gooooo0ol00004ooooo`;oZ[gW0_nY_NL00onZ
_NOoZKgWojVmi`02ojVmi`03ojVmj?nY_NOoZKgW00?oZKgW00?oZKgXojVlionY_>L00onY_NL00onY
_NSoZKcWojVli`05ojVli`04ojVjiOnY^nKoZK_VojVkiP;oZKcW0_nZ]n<00onY^NGoZ[3MojZ`g@03
ojZeh@;oZ[ST00CoZZgJojZcgonZ/mooZ[?O0_nZ]n<00on[[MWoZk?Ooj^cg`02oj^cg`03ojZhhon[
[m[oZkGP00?oZkGP00CoZ[WTojbcgOn[^>?o00000_n[^><00onZ^^GoZkORoj^ghP03ojZji@;oZ[cV
0_n[^^D01?nZ_>KoZk_Uooooool0000aooooo`002Oooool01000003ooooooooooooooolX00000003
o`000000003o000000;o00000P1VIVH2o`00000404a<C?l00000<c<c000000H06ATI2`00000H01TI
6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000IVIV06IVIP0=06IV
IPCo00000P1<C4`2o`0000<0<c<c0ol0000401TI6@0300000?l00000000001`000001?ooool00`00
003oooooooooo`13ooooo`;o00000_ooool2ojZliP?oZ[cW00?oZ[gWojZlionZ_>L00onZ_NL2ojVm
i`03ojZlionY_NOoZKgW00?oZKgW00?oZ[cWojVlionY_>L00_nY_>L00onY_NOoZK_VojVli`04ojVl
i`;oZKWT0onY^^D01_nY^nKoZ[GQojZehOnZ]N7oZ[OSojV[f0CoZ[3M00?oZ[GQojZVdonZ[MX00onZ
[MX00onZ/mooZjC@oj^]f@03oj^]f@;oZk?O00Co[:KAoj^_f_n[[m[oZjoJ0_n[]N001on]ZmKo[;?M
ojbcgOn//mgo0000oj^hhon]/]`01?n[]n800onZ^^Go[;OQojbgh@02oj^ji@06ojbhh_n[^nGoZk_U
oj^kiOoooooo0000<?ooool000Wooooo00@00000oooooooooooooooo:P00000201TI6@0300000?l0
003o000000<0C4a<00Co000003<c<`0c<c<000001`0I6AT9000001P06ATI00?o000003<c<`0c<c<0
1@0c<c<00ol00000C4a<04a<C00304a<C003o`00001VIVH0IVIV00D0IVIV1Ol0000706IVIP;o0000
0P1<C4`2o`0000@0<c<c00?o000001TI6@0I6AT0100I6ATL000000Cooooo00<00000ooooooooool0
@?ooool3o`0000;ooooo00?oZk_VojZli_nZ_>H00_nZ_>H00onZ_>OoZ[cVojZliP03ojZli`03ojZm
ionZ_>KoZ[cV00?oZ[cW00?oZKgWojZli_nZ_>H00onZ_>L2ojVli`04ojZjiOnY^nKoZK_VojVkiP;o
ZKcW0_nY]n<00onY^NCoZJoLojVbgP03ojVbgP;oZ[GQ00CoZJKCojV[f?nYZmSoZJ_H0_nZ/=d01?nY
W/coZZKCojZVdonZY]<2ojZ]fP04ojZKaon[Y=3oZjC@oj^Td0?oZjgI1?n/Y]400on[[m[o[J;<ojf[
eP03ojf[eP03ojbcgOn^Z]?o000000?o[K;L0_n[]n82ojjbg003ojbghOn_]Mgo[;SR00?o[;SR00Co
Zk_Uojfjhooooooo0000<?ooool000Wooooo00@00000oooooooooooooooo:`00000201TI6@050000
000c<c?o000004a<C?l00000100c<c<00`0000006ATI01TI6@0501TI6@P00000600I6AT00ol00000
<c<c03<c<`0503<c<`03o`00001<C4`0C4a<00<0C4a<00?o000006IVIP1VIVH00`1VIVH2o`0000D0
Ogmo1Ol0000406IVIP05o`00001<C4`0C4a<04a<C?l00000100c<c<00ol000006ATI01TI6@0401TI
6A/000001?ooool00`00003oooooooooo`0nooooo`;o00000oooool01?n[^nGoZk_Voj^ki_n[^nH2
ojZliP03oj^kiOnZ_>KoZ[cV00;oZ[cV00?oZ[cWoj^ki_nZ_>H00onZ_>H00onZ_>OoZ[_VojZliP03
ojZliP03ojZlionZ^^GoZ[[U00?oZ[[U00KoZK_VojVfh_nY]^;oZKKRojVghonY[=T3ojV_g0?oZK;N
1?nYY]<2ojV[f004ojZ`gOnYW/coZIk<ojVNc0;oZZKC00CoZZgJojZKaonZVlOoZY_70on[Y=000on[
[MWoZic7oj^La`02ojbVd@04ojfH`?n]X/co[J;<ojfRc0;o[J_F00Oo/:78ojjZdon^Z]?o0000ojjZ
don]/]co/:cC00?o[[;L00Co/[3FojnegOn_]Mgo[kGM0_n/^>801_n_^>3o[K[Sojfjhon]^^?ooooo
o`0002oooooo0009ooooo`0400000?ooooooooooooooob`000000P0I6AT00`000000<c<co`000006
03<c<`8000001`0I6AT6000001T06ATI00?o000003<c<`0c<c<01@0c<c<00ol00000C4a<04a<C002
04a<C003o`00001VIVH0IVIV00<0IVIV00?o000007moO`1oOgl02@1oOgl00ol00000IVIV06IVIP02
06IVIP05o`00001<C4`0C4a<04a<C?l00000100c<c<00ol000006ATI01TI6@0401TI6AX000001?oo
ool00`00003oooooooooo`0kooooo`?o00000_ooool2oj^ji@?oZk_U00?oZk_Voj^jiOn[^^D00on[
^nD2ojZliP04oj^kiOn[^nKoZk_Voj^kiP;oZ[cV0_n[^^D2ojZkiP;oZ[cV0_nZ^N@2ojZji@04ojZc
gonZ]>7oZ[CQojZdh@;oZKKR00CoZJ[GojV/fOnY[=WoZJcI0onY[m`00onY/]koZ:7?ojRQc`03ojVV
d`03ojV[f?nXUlGoZ9O500?oZIk<00?oZZKCojVB__nZVlL00onZVlL2oj^Td005oj^B_On[W<OoZic7
oj^Laon/Y]400on]V<02ojfRc0Co/:7800?o[Z[Co`000?ncY<T00on`[=<01_n^/]co/[3Fok:`e_nb
/=Ko[kGMok>ffPCo[kSP00Go[K[Sojnkhon_^n?oooooo`00000^ooooo`002Oooool01000003ooooo
ooooooooool/00000006o`0000000000000000000?l0000000001`0c<c<2000000H06ATI00<00000
o`00000000000P00000I01TI6@03o`00000c<c<0<c<c00D0<c<c00?o000004a<C01<C4`00P1<C4`0
0ol00000IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo00X0Ogmo0ol0000206IVIP?o000000@0C4a<
o`000?l0003o00000P0c<c<00ol000006ATI01TI6@0401TI6AT000001?ooool00`00003ooooooooo
o`0iooooo`;o00000oooool2oj^ji0?oZk[U00?oZk_Uoj^ji?n[^^@00on[^^D00on[^nGoZk[Toj^j
i003oj^ki@05oj^ki_n[^^CoZk[Toj^ji?n[^^D00_n[]n83oj^hh`03ojZii?nZ/mooZ[?O00?oZ[?O
00?oZ[CQojVXe_nYZ]L00onYZ]L2ojV/f@;oZJoL00CoZ9g;ojRQconXXLooZ:7?0_nYY]<00onWTKoo
Z9O5ojRGa@02ojRGa@03ojVNc?nWRkOoZI:n00;oZI:n0onZVlL4oj^B_@03oj^Laon]S[Ko[IS000?o
[IS000?o[J;<ok2G_On`Ukd00on`XLP01_ncY<Wo0000ok>TbOncY<Wo/:cCokJZc@?o/[3F00Co^K?C
ok>ff_nc]][o/kKJ0_n_^>000onc^moo[k_Sojnkh`02ojnkh`03o`000?oooooooooo02cooooo0009
ooooo`0400000?oooooooooooooooc0000000P0I6AT00`000000<c<c03<c<`0603<c<`8000008`0I
6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0C4a<0080C4a<00?o000006IVIP1VIVH00P1V
IVH2o`0000h0Ogmo00?o000006IVIP1VIVH00P1VIVH01Ol00000C4a<04a<C01<C4co00000080<c<c
0_l0000501TI6@03o`0000000000000001D000001?ooool00`00003oooooooooo`0fooooo`?o0000
0oooool5oj^ji003oj^jiOn/^N?oZk[T00?oZk[T00?oZk[Uojbihon[^^@00on[^^@00on[^nGo[;WS
ojbih`02oj^ji003ojbghOn[]n;oZkOR00;oZkOR00?oZkSSoj^bg_nZ/ml01?nZ/ml01?nXZ=KoZJSF
ojVXe_nYZ=H3ojVZe`03ojV/fOnWV/WoYi[900?oZ9g;00?oZ:7?ojF=^onWTKl00onWTKl2ojRGa@04
ojJ5/OnWRkOoYh^gojN;]`?oZI:n00?oZY_7ojV:]?n[T[d00on[T[d3ojf>]P?o[IS01?n`Ukd01_n`
XLSo]IbnokFL__l0003o/jC9okZU``?o]Z[=00Go/[3FokVcdoni/m?o^K?Cok>ffP02okVkf`?o/k_O
0_n_^n<2ok6ni003o`000?oooooooooo02_ooooo0009ooooo`0400000?oooooooooooooooc000000
00Co000001TI6@0I6AT000002@0c<c<00`0000006ATI01TI6@0Q01TI6@03o`00000c<c<0<c<c00D0
<c<c00?o000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP0306IVIP03o`00001oOgl0Ogmo00`0
Ogmo00Go000006IVIP1VIVH0IVIVo`00000304a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI
6@0I6AT0100I6ATF000000Cooooo00<00000ooooooooool0<oooool3o`0000Cooooo1_n[^^@4ojbi
h`;oZk[T00Co[;SRojbihon/^N?o[;WS0_n[^^@2ojbhhP03ojbihon/]^3o[;KP00?o[;OQ0_n[]n80
1?n[/]goZk;Noj^bg_n[/]h2ojZcg`04ojVXe_nXZ=KoZ:SFojRXeP?oZJSF00?oZJ[GojJIb?nWV/T0
0onWV/T00onXWL_oY8ZiojF=^`02ojF=^`?oYi6o00?oZ9O5ojJ5/OnVQK400onWRkL2ojVB_P04ojR3
[OnYR[CoZHZdojV:]0;oZi:m00?o[8N]ojf>]_n]S[H00_n]S[H00on]V<3o/Hncok2G_@03ok2G_@?o
]Ibn00Co0000okZU`onjYL?o^ZG30_nfZ/d01?no/Lco^K?CokVcdoni/m<4okVkf`03ok>kgonf`N;o
]/7R00;o/KkT00?o//;Vo`000?ooool0;?ooool000Wooooo00@00000oooooooooooooooo=@000000
0ol00000<c<c03<c<`0603<c<`8000008P0I6AT00ol00000<c<c03<c<`0503<c<`03o`00001<C4`0
C4a<0080C4a<0_l0000406IVIP03o`00001oOgl0Ogmo00`0Ogmo00Go000006IVIP1VIVH0IVIVo`00
000304a<C003o`00000c<c<0<c<c0080<c<c0_l0000501TI6AD000001?ooool00`00003ooooooooo
o`0aooooo`;o00001?ooool2ojZji@CoZk[T0_n[^N<4ojbih`Go[;SR00Go[;WSojfghOn]]n7o[KOQ
ojbhhP02ojfeg`?o[;KP00?o[;OQojbbgOn//]d00on[/]d00on[/]koZJWGojVXeP03ojVXeP;oZ:SF
0_nYZ=H01?nUVLSoYYW8ojJIb?nVVLP2ojNJb@03oj>9^?nTR[WoY8Zi00CoYHfk00?oYi6oojB1[_nV
QK400onVQK42ojN;]`?oZ8>]0onYR[@01?n[T[go[8N]ojb7[On/Qjd3ojf>]P?o/Hnc0_n`Ukd01_ng
U[Go]IbnokFL__neW;ko^ZG3o`0000;o^ZG300Go]Z[=oknac?no/Lco_k7<okVcd`02ol2me`;o^K_K
00Co_LGPokK1h_nf`N;o]/7R1?nb`^H00ol0003oooooooooo`0Zooooo`002Oooool01000003ooooo
oooooooooole0000000301TI6@000000<c<c00P0<c<c00<0000001TI6@0I6AT07`0I6AT00ol00000
<c<c03<c<`0603<c<`;o0000101<C4`01Ol00000IVIV06IVIP1VIVKo000000h0Ogmo00Go000006IV
IP1VIVH0IVIVo`00000404a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT00`0I6AT0
0ol0000000000000000B000000Cooooo00<00000ooooooooool0;_ooool3o`0000Cooooo0_nY^^D3
ojZji@03oj^ji?n[^NCoZkWT00?oZkWS00?o[;WSojbhh_n/^>801?n/^>83ojfgh003ojfghOn]]Mko
[KGO00?o[KGO00?o[;KPojfbg?n//]d00on//]d00on[/]goZZ_GojVYe`02ojVYe`?oZJSF00?oZ:SF
ojFJb_nUVLP00onUVLP2ojJIb003ojNJbOnSRKSoXhVh00?oY8Zi0_nUSK/00onSOZcoY86^ojB1[P04
ojJ5/@;oYh^g00CoYgjXojR3[OnXPjgoZ8>]0_nYR[@4ojb7[@;o[Hjf00Go/HV[ok6?/onaSk?o/Hnc
ok2G_@03okNF]@;o]Ibn00Co_j6ko`000?njYL?o^ZG30ono/L`01?o9`]?o`;gGol2meoo0_ML4okg5
h003okK1h_nganKo]lOV00;o//;V0_naaNT00ol0003oooooooooo`0Yooooo`002Oooool01000003o
oooooooooooooole000000806ATI00<0000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0O01TI
6@03o`00000c<c<0<c<c00L0<c<c0_l0000304a<C0;o00000P1VIVH3o`0000/0Ogmo00?o000006IV
IP1VIVH00P1VIVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI
6@0I6AT00`0I6ATD000000Cooooo00<00000ooooooooool0;?ooool2o`0000Gooooo0_nY^nH3ojVj
i@03ojZjiOnZ^NCoZ[WT00?oZkWT00?oZkWSoj^hh_n[^>800_n/^>801?n/]n7o[;KPojbfh?n/]^02
ojfgh0Co[KGN0_n]]Ml4ojfbg0;o[;;M00CoZjcHojZ[eonZZmOoZZ_G0onYZML00onYZ=KoYIg=ojFJ
bP02ojFJbP?oYIW800?oYYW8oj:9^_nSRKP00onSRKP2ojB:^@03ojF=^onSOZcoXgj/00?oY86^0onV
QK400onWRkOoYgjXojMnZ003ojR3[@03ojV:]?n/PZOo[8:W00?o[8N]00Co[Hjfok69ZonaRJ_o/HV[
0_naSk<4okNF]@05okFL__noXK_o_j6ko`000?njYL<00_o6/LD01Ono/LcobL;ColW2doo9`]?o`;gG
00;oa/gO0_nmaN02okg>i`03okO7i_ndb^[o]<[Z00;o/LGY00?o[lCZo`000?ooool0:_ooool000Wo
oooo00@00000oooooooooooooooo=P00000201TI6@030000000c<c<0<c<c00L0<c<c00?o000001TI
6@0I6AT07`0I6AT2o`0000T0<c<c00?o000004a<C01<C4`00P1<C4`00ol00000IVIV06IVIP0206IV
IP?o00001`1oOgl00ol00000IVIV06IVIP0306IVIP03o`00001<C4`0C4a<0080C4a<00?o000003<c
<`0c<c<00P0c<c<00ol000006ATI01TI6@0401TI6A<000001?ooool00`00003oooooooooo`0Yoooo
o`?o00000_ooool2ojNlj0?oZ;_W00?oZK_VojRkionX^nL00onY^^H00onZ^NCoZKWUojVii@03ojZh
h`03oj^hh_n[]n;oZkOR00?o[;OQ00?o[;KPojbegon/]Ml01?n]]Mh6ojfbg0;o[:gI0on[[=P00onZ
ZmOoYjCBojJPd002ojJPd0?oYIg=0onUV/X00onUVLSoXH^moj:9^P02oj:9^P?oXhVh00?oY8Zioj5n
[OnSOZ`00_nSOZ`3ojB1[P;oYXFa00CoYW^UojMnZ?nWOZSoYgjX0onXPjd3ojb2Y`?o[8N]1?naRJ/0
0onaSk?o^I6^okVA[P03okNF]@?o_j6k00Co0000olJaaOo6/LGoa[750oo9`]<2om3Jh003olK=goo4
f^[oa=[Z00;o_LkW0_nhd^d00ondb^[o/<S/ojo4jP03ojo4jP03o`000?oooooooooo02Sooooo0009
ooooo`0400000?ooooooooooooooocH0000000?o000001TI6@0I6AT00P00000803<c<`030000000I
6AT06ATI02006ATI0_l0000803<c<`;o00000`1<C4`4o`0000<0IVIV1?l0000207moO`;o00001P1V
IVH00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT0100I
6ATB000000Cooooo00<00000ooooooooool09oooool2o`0000?ooooo1OnW_>P00onX^nOoYk_XojNk
j003ojRki`03ojVji_nX^^KoZ;[V00?oZKWU00?oZ[SSojVhi?n[]n800on[]n800on/]n7oZkKQojbe
g`03ojbeg`03ojfeg_n]/mgo[K;L00Co[K;L00?o[:oIojb]fOn/[MT00_n/[MT00on[[=SoZJODojNT
dP02ojNTdP?oYZ3@00?oYIg=oj2Db?nPSl800_nPSl82oj6;_@?oXXVj0onSRKP3oj5n[@?oXgj/0_nT
PJh00onVQK7oYW^UojIkY@04ojMnZ0;oZ8>]0on/PZL3ojb7[@04ok:6Y_naRJ_o/HV[ok69Z`?o^I6^
0ongU[D01_o3X;Co_j6koknQ^ol0003oc[C0olJaa@;oeL_@00CobL;Com3Jh?o@f^3obN[/0oo4f^X0
1?nkg?7o^=;]okSBkOnbc^h3ok38k0;o[lCZ0_n/`^X00ol0003oooooooooo`0Wooooo`002Oooool0
1000003oooooooooooooooli000000806ATI00<0000003<c<`0c<c<01P0c<c<00`0000006ATI01TI
6@0Q01TI6@?o00001`0c<c<2o`0000D0C4a<0_l0000506IVIP;o00001`1VIVH00ol00000C4a<04a<
C00304a<C003o`00000c<c<0<c<c0080<c<c00?o000001TI6@0I6AT01@0I6AT00ol0000000000000
000>000000Cooooo00<00000ooooooooool09?ooool3o`0000?ooooo00?oYkcYojNlj?nW_>P00onW
_>P00onV_>WoYk_XojNkj002ojNkj003ojRkionV^nSoZ;[V00?oZ;[V00?oZKWUojNii_nY^>@00_nY
^>@2oj^ghP04ojVghon[]^7oZkKQoj^fh@;o[;GO00CoZkCOojfcgOn]/mgo[K?M0_n]/]`01?n//=_o
[:oIojb_fOn/[mT2ojb]f@04ojZZeonYYmCoZJODojVWe0?oYjCB00?oYZ3@oj6IcOnPU<P00_nPU<P3
oj2?`P;oXH^m0onRRKX00onSRKSoWgj_oj5n[@02oj5n[@?oXgj/0_nTPJh3ojIkY@CoYgjX00?oZ8>]
oj]nY?n/PZL00on/PZL00on/Qjgo/XJVok:6YP03ok69Z`Co^I6^00Oo]iJeol>P]?o3X;Co_j6koljd
`?l0003oc[C000?oeL_@00?of^gPom3Jh?o9j^`00_o9j^`00oo4f^[o^mcaok_Ll@04ok;>kP03ok38
k?n]aN_o[LG[00;o[<;Z00?oZl3Yo`000?ooool0:?ooool000Wooooo00@00000oooooooooooooooo
>P0000000`0I6AT0000003<c<`0403<c<`8000000P0c<c<2000002@06ATI0ol0000603<c<`;o0000
1@1<C4`2o`0000/0IVIV00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`0303<c<`03o`00
000I6AT06ATI00@06ATI4@000004ooooo`0300000?oooooooooo02;ooooo0_l00004ooooo`;oYkcX
0_nW_>T2ojNlj0CoY[cY0_nW^nP01?nV^nWoY[_XojJkj?nV^nP2ojRjiP05ojJjionW^NKoYkWVojNi
i_nY^>@00_nW^>D3ojVgh`03oj^fhOnZ]N7oZ[GQ00?oZkCO00?o[K?Moj^bgOn[/]d00on//=/00on/
[mWoZjcHojZZe`03ojZZe`;oZJOD0_nWY=801?nRWm7oXIW=oj6IcOnQVLd2oj2Db0?oX8o20_nQRkd2
oj:9^P03oib0]?nOOZooWgj_00?oXGj]0onSOZ`00onTPJkoY7ZUojAjY@03ojIkY@?oYgjX0on[OZ@3
ojb2Y`?o/XJV0_naRJ/2ok^@Z@?o^I6^0oo3X;@2oljd`004o`000?oQfloohM_?omG;d0;of^gP00?o
aO[YolWZk?o9j^`00_nkj?@00onkg?7o/]Caok;Dl@02ok;>kP;o[LO]00?o[LG[oj_1j_n[`>T00on[
`>T00ol0003oooooooooo`0Vooooo`002Oooool01000003ooooooooooooooolk0000000301TI6@00
0000<c<c0080<c<c00<0000004a<C01<C4`00P00000203<c<`030000000I6AT06ATI02@06ATI00?o
000003<c<`0c<c<01@0c<c<3o`0000@0C4a<1ol0000206IVIP;o00001`1<C4`00ol00000<c<c03<c
<`0303<c<`03o`00000I6AT06ATI00D06ATI40000004ooooo`0300000?oooooooooo01oooooo0ol0
0004ooooo`;oZ;_W00?oYkcXojNjionW^^L01_nV_>T3ojFlj@;oY[_Y00CoY[_XojFkjOnU^nWoYK_Y
0_nV^^L00onW^NKoY[WWojJii`03ojNhi@03ojVghonW]nCoYkOT00?oZ[GQ00?oZkCOojZcgon[/]d0
0on[/]d00on//=_oZZoKoj^/f002oj^/f0?oZZ[G00?oZJODojFTeOnUY=D00onRWm42oj6Ic@?oX9C8
00CoX8o2oiN9`onJQ;[oVXBj0onLP;@3oimn[`?oXGj]0_nSOZ`3ojAjY@?oYW^U0_nWOZP01?nZO:;o
ZgjToj]nY?n[OZ@2ojb2Y`03ok:4XonbQZKo/XJV00;o/XJV00?o/HV[ok^@ZOnkT:T00_niTJh2olVR
/@;o`j2d00?of;fnoljd`?l000000_oQfll00ooGo]Oof^gPolGjj@02ok?bm@;o^nSd0_nafOD00onb
e?7o[LW^ojg9kP02ojg7k@04oj_2j_n[`N[oZl7Zoj_1jP;oZl3Y00?oZ[kXooooool000009oooool0
00Wooooo00@00000oooooooooooooooo>`00000201TI6@040000000c<c<0<c<c000000@0C4a<00@0
000003<c<`0c<c<000004`0I6AT4000000l06ATI0ol0000703<c<`?o0000201<C4`2o`0000P0C4a<
00?o000003<c<`0c<c<0100c<c<00ol000006ATI01TI6@0501TI6A0000001?ooool00`00003ooooo
ooooo`0Looooo`?o00000_ooool2ojbih`?oZ[WT00?oZ;_WojZghonZ]n<00onW^^L00onV_>WoYkWV
ojNiiP03ojJlj@03ojFljOnU^nWoY;cZ00?oY;cZ00?oYK_Yoj>kj_nT^^T00_nT^^T3ojJii`03ojNh
iOnU^>OoYkOT00?oYkOT00?oZ[GQojNehonZ/ml00_nZ/ml2oj^bg@04ojVag_nZ[m_oZZoKojZ_f`?o
ZjcH00?oZZ[GojJXeonUY=D00onUY=D2oj:Od@03oj6IcOnGV=;oUY3;00;oUY3;0_nGRL<3oiZ4^P?o
W82d0_nOOZl3oj5n[@03oj=n[?nRNJKoY7ZU00;oY7ZU0onVNjD00onWOZSoZWbRojYlXP03oj]nY003
ojb2YonbQ:?o/XBS00Co/XJV0onkT:T01OniTJkobJ:aolVR/Oo9X[7o`j2d00;of;fn00Gojo;=o`00
0?oQflooeokGojKgd@02oj7ck`05ok?bmOn^g_So[]khojkNn?nafOD00_n/bo000on]bNkoZl;[oj_2
jP03oj_2jP03oj_1j_nZ_^SoZ[kX00?oZ[kX00?o0000ooooooooool09Oooool000Wooooo00@00000
oooooooooooooooo?000000201TI6@040000000c<c<0<c<c000000@0C4a<00@0000003<c<`0c<c<0
0000400I6AT2000000@0<c<c1000000>01TI6@?o00001`0c<c<4o`0000d0C4a<00?o000003<c<`0c
<c<01@0c<c<00ol000006ATI01TI6@0501TI6A0000001?ooool00`00003oooooooooo`0Jooooo`;o
00000oooool2oj^ki@?o[;WS00?oZ[WTojbhhOn/^>400onZ]n<00onW^^OoZKKRojNiiP03ojNiiP03
ojJljOnV^>KoYK_Y00;oYK_Y0_nT_>X4oj>kjP03ojBjjOnR^n_oX[_[00?oXk[Y0_nU^>L2ojNgi005
ojFgi_nW]N?oYkGSojNehonZ/ml00_nW/n83ojVagP03ojZ_fonW[mgoYjoM00;oZ:cJ0onVZ=L2ojFT
e@03oinTfOnKW]OoVikG00?oUiSB0onFT</2oiN9``;oVXBj0onLP;@2oimn[`;oXGj]00?oWWZYoj9i
Y_nRNJH01?nTNZD2ojIkY@CoZWbR0_n[OZ@4ok:4X`?o/XJV0onkT:T4olVR/@?of;fn00?ojo;=o`00
0?mScIP00_n5jn800onQlnooZMojoj_:l005ojc;l0;oZl;Z0_n[`^/2oj_2jP?oZ[kX00?oZ[gXojVm
j?nY_NP00_nY_NP00ol0003oooooooooo`0Tooooo`002Oooool01000003ooooooooooooooolm0000
000501TI6@000000<c<c03<c<`0000001@1<C4`010000000<c<c03<c<`00000?01TI6@030000000c
<c<0<c<c00L0<c<c00?o000001TI6@0I6AT03P0I6AT4o`0000L0<c<c2_l0000204a<C003o`00000c
<c<0<c<c00D0<c<c00?o000001TI6@0I6AT01P0I6AT@000000Cooooo00<00000ooooooooool05ooo
ool3o`0000?ooooo0_nW]N<3oj^ki@03ojbihon[]N3o[;SQ00?o[;SQ00?oZ[OSojfeg_nY]^800_nY
]^82ojNiiP;oZK?P0_nV^>H01?nU^nWoYKOVojFgi_nU]nH3oj>kjP;oX[[Z0onR^n/00onS^^WoX;[[
oj2jj`03oj:ij@;oYKOV00?oYkGSojBfi_nT]^H00onW/n800onY/MkoY[;QojN_g@03ojN_g@;oZ:cJ
00?oYZSGoj:YfonRZM/00onOY=T2oi^Ne`?oUiSB0_nFT</2oiN9``?oVXBj0_nLP;@00onOOZooVW^`
oiijZ@02oiijZ@?oXWVV0onTNZD00onVNjGoZG^RojYlXP03ojYlXP;oZgjT1?nbQ:<2ok:6YP;o_Y2W
0_nkT:T01oo?Z;3obJ:aolVR/Oo9X[7oi<boomRm__o[l/d00_l000001?nVf_[oY]kkojKNnon/and3
oj_:l0;o[<_`0_n[`NT00on[`^[oZkgWojZnj004ojZnj004ojZmionZ_NSoZ[gXojZmj0;oZKgX00?o
Z[gXooooool000009Oooool000Wooooo00@00000oooooooooooooooo?P0000001@0I6AT0000003<c
<`0c<c<0000000D0C4a<00Co00000000000c<c?o00000P00000;01TI6@030000000c<c<0<c<c00T0
<c<c0P00000B01TI6@Oo00002P0c<c<2o`0000P0<c<c00?o000001TI6@0I6AT01P0I6AT@000000Co
oooo00<00000ooooooooool05_ooool2o`0000?ooooo00?oYkOTojNehonW]N<00_nW]N<00on[^nGo
YJCDoj^eh002oj^eh0;o[;SQ00GoZZ[Fojfeg_n]]Mko[KGNojVfhP03ojfaf`03ojVch?n^[MOo[ZgG
00?oZK7N00?oYKOVojR^g?nT]^H00onT]^H2oj:jjP03oj:kjonP^^_oX;[[00?oX;[[00?oX[WYoiji
k?nQ^>T00_nQ^>T3ojBfiP03ojNch_nS]>GoY[;Q00;oY[;Q0_nW[md00onS/>7oY:gMojB]g@04oj:Y
f`;oWjCI00?oVikGoi6Rh?n7V]h00_n7V]h2oh:AfP;oQ8W@0on;Pl@2oi=n^@?oVW^`0_nNNZT3oj9i
YP;oY7ZU00CoYWbUojUkX_nYNj;oZG^R0onZO:800on[OZCo/XBSok:4X`03ok:4X`05ok:6Y_nnT:Oo
_Y2Wokj@YonkT:T00_o?Z;02olVR/@07onC<_ol0003o0000o`000?nYdoKo0000ojk2j@04ojc7k@03
oj_:l?n/_^Oo[;kW00;oZl7Y00Go[;cUoj^mion[_NOoZkgWojZnj002oj^liP?oZ[gW00?oZ[gXojZm
ionZ_NL00onZ_NP00ol0003oooooooooo`0Sooooo`002Oooool01000003oooooooooooooooln0000
00806ATI00<0000003<c<`0000001`1<C4`01@000000<c<c03<c<`0c<c<0000000X06ATI00<00000
03<c<`0c<c<02`0c<c<00`0000006ATI01TI6@0F01TI6@?o0000400c<c<00ol000006ATI01TI6@07
01TI6A0000001?ooool00`00003oooooooooo`0Fooooo`03o`000?nV_N[oY[gY00;oY[gY0_nW]n@2
ojNeh`05ojVZeonUY=CoYJCDojFTe?n[]N000_nPRK/3ojZZeP03ojfeg_nVV<OoYYS700?o[K7K1?n^
[ML00onY/Mko[ZSBojR^g002ojR^g0;oY;KV00GoYj_Joj:ei_nR]NKoX[GVoj2jj`02oj2ciP?oWKW/
0_nN^N`00onQ^>WoW;W/oibik003oingj@;oXkCU00?oY[;Qoj6ciOnQ/nD00onS/>42ojB]g@;oXZWK
00?oWZ_PoiVWh?nIYn000onAX^03ohNJgP;oPY7J00CoQ8W@oh^3a?n;PlCoRh?40_nCO[T3oiYk/0?o
WWZY0_nRNJH00onTNZGoYWbUojIlY@03ojUkXP?oZWbR00?oZgjTok:4XonbQ:<00onbQ:<4okj@Y`03
ok^@ZOo?Z;3ocjR`00?o000000Ooi<boom?k/OnYdoKo/KcRojk2jOl0003o[/;Y00;o[<O]0_n^^n<0
0on/_^Oo[[WRojbli@03ojbli@03oj^mion/^nCo[;_T00?oZkcV00GoZ[gWoj^li_n[_>KoZ[gWojZl
iP04ojZmi`03o`000?oooooooooo02;ooooo0009ooooo`0400000?oooooooooooooooch0000000Ko
000001TI6@0I6AT0000003<c<`00000704a<C0050000000c<c<0<c<c03<c<`0000002@0I6AT00`00
0000<c<c03<c<`0<03<c<`8000006@0I6AT7o`0000<0<c<c1_l0000901TI6A4000001?ooool00`00
003oooooooooo`0Fooooo`04o`000?nV_N[oY[gZojJmj@;oW;c_0_nU_^/3ojVZe`03ojFTe?n]U[oo
X8Vk00?oX8Vk00?oZZ[FoiYbY?nVV<L00onVV<L00on]/M_oXXNgoj:7]`02ojj]e`05oiejZon^Z=;o
[ZSBojjXd_nX[]`00_n]Xld3ojN[fP03oj:ei_nWZ=OoYjSG00?oX;?V00?oWKW/oijbi_nK^>d00onK
^>d2oibik003oingjOnI^>goWKKY00;oWKKY0onQ/nD00onS/>7oW[;Voin^hP02oin^hP?oWZ_P0_nI
Yn03oi6Rh0;oQi[N0_n2TMX2ohB9d0?oRh?40_nCO[T2oiYk/0?oWWZY0_nRNJH3ojIlY@?oZG^R0onZ
O:86ok:4X`04ol6DZ?nnT:Oo_Y2Wokj@Y`?o000000GocjR`oo3V`_oTc;oodo^aokBffP03ok6lhP03
ojk2jOl0003o/KON00;o[[_S00Co/KKMojjih_n^^N;o[[WR0_n/_>D2ojjihP03ojbki?n]^N;o[;_U
00?o[;_U00?oZkcVoj^kiOnZ_>H00_nZ_>H2ojZmi`03ojZliol0003ooooo02?ooooo0009ooooo`04
00000?oooooooooooooood0000000P0I6AT00`000000<c<c0000000204a<C0@0000000<0C4a<0000
000000000P0c<c<00`0000006ATI01TI6@0601TI6@030000000c<c<0<c<c00h0<c<c00<0000001TI
6@0I6AT07@0I6AT3o`0000h06ATI4P000004ooooo`0300000?oooooooooo01Kooooo00?o0000ojJm
j_nV_>X00_nV_>X2oiblk`;oYKk[00?oZJ[GojG7lOn]U[l00_n]U[l2oj29^`04ok27ZOnJLZCoVW:T
oiYbY0;oYYS700GoV6JFoj:7]onRQkOoXXNgojj]e`03oiejZ`;o[ZSB1?n]Xld00onWZm[o[Io8ojNX
e`03ojNXe`03oj2ci_nUY=CoW[;V00;oW[;V0_nK^>d01?nK/>KoUkO^oiNgk_nG]nh2oiVhk@?oWKKY
00?oXK?UoiZdj_nN/^H00_nN/^H3oin^hP03oij[h?nK[^CoUZ_T00;oUZ_T0on:Y^P2ogBOk003oeVC
kOm7QnSoAhOX00?oRh?40_nCO[T3oiYk/0;oWWZY00?oXWVVoj9mZ_nVO:D00onVO:D3ojUkXP;oZWbR
1OnbQ:<2ol6DZ0?o000000?of;BdolnX/?o?Z;000_o`i/84okBffP06ok6lh_nd/mOo];?Gok6gg_l0
003o];;G0ona]]d00on^^N;o/;KMok2fg@02ojjihP04ok2gg_n]^N;o[KWRojfihP;o[;_U00Go[K[S
oj^kiOn[^nGoZk_UojZliP02oj^li@?oZ[cW00?o0000ooooooooool08Oooool000Wooooo00@00000
oooooooooooooooo@@000000100I6AT0000003<c<`00000204a<C0050000001VIVH0IVIV06IVIP00
00000P1<C4`010000000<c<c03<c<`00000701TI6@030000000c<c<0<c<c00h0<c<c00<0000001TI
6@0I6AT0;@0I6ATC000000Cooooo00<00000ooooooooool05Oooool01_l0003ooooooooooooooooo
Y[cZojRmj0CoW;[]0_m^/OT01?nUao7o[IJoojfF_onPRK/2ok27Z@?oVW:T00?oYYS7oiQVU_nHIYH0
0onRQkL4oiejZ`03ojjXd_nLLj?oW7>S00?o[J?=0on]WlP2ojNXe`05ojjKa?nUY=CoYJCDojFTe?nN
/^H00_nTXM83oi^`iP03oiNgk_nH[^KoV:kV00;oU;O_0onF]nh2oiZdjP03oijbi_nH/n_oV;?[00;o
Vk7V0onK[^@3oiJ[i004ohZVj?n>ZnWoM:OaogBWl@;o>iCa0_m7QnP2oe:2hP;oTgji0onJNk000onN
NZWoVWjdoj9mZP02oj9mZP?oYWbU0onYNj800onZO:;o/XFTok:4X`03ok:4X`?o00000_nnT:L2omRd
]003olnX/?o`i/;ol>K200;o]joA0_nd]]X01_ng[]3o];?GokBceond/mOo];;Go`0000;o];;G00?o
/KKMok>cf?n`]]d00_n`]]d4ok2ggP03ojfih_n_^=oo[K[S00?o[K[S00GoZk_Uojfjhon]^^?oZkcU
ojbki004oj^liP03o`000?oooooooooo023ooooo0009ooooo`0400000?oooooooooooooood800000
00H06ATI0000000c<c<0000004a<C000000406IVIP040000001<C4`0C4a<00000080<c<c00<00000
01TI6@0I6AT01@0I6AT00`000000<c<c03<c<`0>03<c<`800000;00I6ATD000000Cooooo00<00000
ooooooooool05Oooool01?l0003oooooooooooooool3ojRmj0;oW;[]00KoYkgYogV_mOmi[oGoNJoe
ojfF_onRi?`3ok27Z@?oVW:T1?nHIYH2oj:7]`CoWGZ[1?nLLj<00on]XlgoW76QoiaaX@02ojfOb0Co
[Y_400?oYJCDojjH`On^V<400onTXM800onK/>KoXYg?oiR^iP03oiR^iP;oU;O_00?oU[O^oi2fl?nC
]^l00onC]^l2oiRcj`;oVk7V00?oVjkToiZ`ionJ/>L00onH[^H2ohj[j@;oM:Oa0olkU?401?l0I/go
DX;Rog22eOm`P]D3oh^1``;oVWjd0onROJX3ojIlY@;oZG^R00Co/HRZok:5Y?nbQJCo/XFT0ol00004
ol6DZ005okj@YooH];Cof;Bdom[j[Oo`i/800ong[m44okN^d006okBceong[]3o]jk@okBbeol0003o
]joA0onc/mP00on`]]go/k?Iok>cf@02ok2ggP04ok:df_n_^=oo[kSOojnhg`;o[K[S0_n_^>000on]
^^?o[[WQojbki002ojbki0;oZkcV00?o[;_Uo`000?ooool08Oooool000Wooooo00@00000oooooooo
oooooooo@P0000001?l000006ATI00000000000204a<C0030000001VIVH0IVIV0080IVIV00@00000
04a<C01<C4co00000P0c<c<00ol000006ATI01TI6@0401TI6@030000000c<c<0<c<c0100<c<c00<0
000001TI6@0I6AT09`0I6ATF000000Cooooo00<00000ooooooooool05Oooool00ol0003ooooooooo
o`02ooooo`04ojRmj?nY_NSoZKgXojVmj0;oYkgY00GoNJoeoj>ljonS_>_oXkc[oj;To003ok27Z@;o
VW:T1?nHIYH00onRQkOoUf6@oiMQT003oiejZ`CoW7>S0onLLJ400on]WlSoWg>QoimcX@03ojjKa0Co
[YS100?oY:7BojjE_OnRWLl00_nRWLl2oiR^iP04oj6IcOnD[>OoU:cWoiB/i`;oT;K`0_nC]^l00on;
]?;oT;G`oi2el003oiNcj`?oV[3W00CoV:kVoi^`i_nH[^KoV:kV1?n;[Nd2of:Xm`03o`1jeomK003o
L8;E00?oRh730_nJO[@3oj9mZP?oYWbU00?oZG^Rok68Z_naR:X00ol00002ok:4X`03olBK[Oo1U:So
`IBX00;o`IBX0ooH];@01?oJnZgo^Z[:okZZb_ng[m42okZZb@;o]jk@00Co^Z[9okN^d?ng[]3o]jk@
0_ng[m400ol0003o]joAok>cf002okN`dP03ok>cfOnf/MCo][7D00?o/[CJ00?o[kSOok:ffonb]]/0
0_n_^>001_na]mgo[[WQojjihOn^^N7o[;_TojjjhPCo[;_U00?o0000ooooooooool07oooool000Wo
oooo00@00000oooooooooooooooo@`00000201TI6@@0000000?o000006IVIP1VIVH00P1VIVH40000
0080<c<c0P00000401TI6@03o`00000c<c<0<c<c0140<c<c00?o000001TI6@0I6AT03`0I6AT]0000
00Cooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`KoZKgX00?oXkc[ojVm
j?nRi?`00on`QjT00onJLZCo]X:LoiQVUP03oiQVUP?oUf6@0_nMNZ/00onIH8goW7>SoiacX`02oiac
X`?oW76Q1?nOLj400on^VlCoY7ZUojAjY@02ojjH`@05oj^4Zon^UKgo[YFmojjE_OnRWLl00_n^T[X3
oj6Ic@03oiB/ionOUL[oWiG:00?oTJ_W0_n;]?82oi2el003oiNcjon?]O3oSkG`00;oUk?[0onK/>H2
oiR^iP;oRjg]00CoWJoToi6`k?nA/>coTK3/0_mX[oT01?m`P]GoRh73oh^1`on;PL<2oiYn]0?oXWfZ
0_nVO:D3o`0000?o/XFT00Co/XBSolBK[Oo4Vjgoa9^]0oo1U:P01?oTc;oof;Bdom[j[OnlYl@2okZZ
bPOo^Z[900?o]jk@okZ[bonjZl/00_ng[m401?l0003o]k3BokN`d_ng/=84okJae003ok:df_ne/]Ko
/[KK00;o/[KK1?na]md00on^^N7o/;ONojjjhP02ojjjhP;o[;_U0_n]^^<00ol0003oooooooooo`0N
ooooo`002Oooool01000003ooooooooooooooom4000000806ATI00@0000003<c<`00000000001P1V
IVH3000000<0<c<c0P00000201TI6@030000000c<c<0<c<c0180<c<c0P00000?01TI6Bd000001?oo
ool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo2?nY_NP3ok27Z@03oiYbY?nf
PYcoV6JF00?oV6JF0onGHI001?nMNZ_oVF2=oiUPSOnIH8d2oiacX`04oiaRSOnLLJ7oW76QoiaaX@Co
Wg>Q0onTNZD01?n^V<7oZhB[oj^4Zon[Q:/2ojjE_@Co[Y:j00?oXIW=ojf>]_nOULX00onOULX00onA
ZnOoWI;8ohfYj002ohfYj0;oQkCc0on?]O02oiNcj`03oi^`i_nI/^WoVK;Y00?oW[3T0_nM[n@00onA
/>coYJoNojF_gP02oinai@?oRh730_nJO[@3oj9mZP;o000000Co[8feok68Z_naR:[o/HRZ0_nbQJ@4
olBK[@;o`IBX0_oTc;l01?oH];Co_:O4okbWa?njZ/X2okbWa003okZZbOnmYlCo_JO400?o^Z[90onj
Zl/2okZ/c003o`000?nj[<co]k3B00;o^Zk=0_nf/M@01Oni[loo]K;FokFbe_ne/]Ko/[KK00;o]K?G
0_na]md01Ond]MWo/;ONok2gg_n`]mko[[[R00;o/;SO0_n]^^<00on_^N7o0000ooooo`0Oooooo`00
2Oooool01000003ooooooooooooooom5000000806ATI00@0000003<c<`00000000001`1VIVH00`00
003o000003<c<`0303<c<`<000005P0c<c<00`0000006ATI01TI6@0;01TI6Bh000001?ooool00`00
003oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo1onY_NP01OnRi?co/8NYok27ZOnJLZCo
]X:L00?oV6JF00Co_XBFoiMQT?nGHI3oUf6@1?nIH8d2oiacX`04oiaRSOnLLJ7oW76QoimVSPCoWg>Q
0onTNZD4oj^4Z`03ojjE_OncSk7o[Y:j00?o[Y:j0on]S[H2oinEbP05ojb;/_nMT/SoWI;8oifBb?n=
ZNP00_nKSlH2ohVWj@?oQ;?c0_n?]?03oiVbj@04oij`i?nM/^OoY;3PojB`h0CoYJoN00CoWk7Uojf]
eon/[m[o06K@0_nJO[@3o`0000?o[8fe0onaR:X2ok:5Y005olRY^_o4Vjgoa9^]olBK[Oo1U:P00_oT
c;l01?nmYL7o_:O4okbWa?nnYL03okbWa0Co_JO400Co^Z[9okfXaOnmZ<Go^Z_;0_nmZLH2okZ/c004
o`000?nj[/go^Zk=okZ^c@Co^Jo?00Go]K;FokR`dOnh/=7o]K?GokRbd`04okBef@05ok2gg_nc]]_o
/kKKok2hgonb]md01?n_^N400ol0003oooooooooo`0Mooooo`002Oooool01000003ooooooooooooo
oom6000000806ATI00<00000o`00000000000P1VIVH50000000306IVIP000000000000D0<c<c00<0
000003<c<`0c<c<05@0c<c<00ol000006ATI01TI6@0901TI6Bl000001?ooool00`00003ooooooooo
o`0Dooooo`03o`000?oooooooooo00Sooooo1onY_NP00on`QjWo0000okJ2W002okJ2W0;oV6JF00Co
_XBFoiMQT?nGHI3oUf6@1?nIH8d00onLLj?oW6:=oiaRS@02oiaaX@;oWfJ>0_nOLj401?nTJi3oY7ZU
ojAjYOnTNZD4oj^4Z`?o/hna0_n^T[X01?njUk?o[Hjfojf>]_n]S[H4ojb;/P;oWI;81?nKSlH2ohVW
j@03ohBclon5Y^[oP[?d00;oP[?d0_nA]Nl3oifbi`;oY;3P0_nU[mh01?n[[m_o[JgGojf]eon][ML3
o`0000?oWIG;0on/SKD3ok68ZP03ok:5Y?o8ZK[ob:Vj00?oa9^]00Goi_S@onC<_onmYL7o_JG1okbW
a003okjU`003okbWa?noY/3o_jK000;o_JO400Co_jO1okfXaOnmZ<Go_JS50onmZLH01Onj[<co_J_7
okf[aol0003o^Zk=00;o_:c90_ni[ll01?nl[L_o^;3AokR`dOnh/=43okRbd`;o];GI0_ng/mH00onc
]]_o][CHok:gg@02ok:gg@;o[kWQ0_na^=h00ol0003oooooooooo`0Looooo`002Oooool01000003o
oooooooooooooom6000000<06ATI00D0000004a<C0000000IVIV0000000407moO`80000000<0C4a<
0000000c<c<06`0c<c<00`0000006ATI01TI6@0901TI6Bl000001?ooool00`00003oooooooooo`0D
ooooo`03o`000?oooooooooo00[ooooo1_nY_NP01?l0003o]X:LokJ2W?nfPY`2oiQVUP04okj4U_nG
HI3oUf6@oiMQT0CoVF2=00CoW7>SoiaRSOnLHXgoW76Q0onOIXh2oimcX@;oY6^@00?oY7ZUoj]dU_n[
M9H00on[Q:/3ok>?/@04ojjB^_njUk?o^YNcokZG/`;o[Hjf1?n/Rk800onMT/SoZhN_oj^7[`02oi^?
aP04ojZ4[?nIS<CoVHc4oiV<a0;oQJKZ0on2/o@2oi6ek`03oifbionD]^koXk;S00?oXk;S00CoZjoK
o`000?l0003o00001?ncZm03oifEb`?o[8fe0_naR:X3olRY^P?oa9^]00Goi_S@okjU`?nmYL7o_JG1
oknU_`03okjU`0?o_jK000Go_JO4oknW`OnoYl7o_jO1okfXa@02oknX`P;o_JW600Go_jW3okf[aonm
ZlOo_J_7o`000002okb/b@05okV_conl[L_o_:g;okb]bonh/=400_nk[ld00onh/]?o^k3@okNceP02
okNceP05okZbd_nf]=So][CHokJdf?nb]md00_nd]]X2ok6hgP03ok>gg?l0003ooooo01gooooo0009
ooooo`0400000?ooooooooooooooodL000000P0I6AT20000000404a<C0000000IVIV000000@0Ogmo
0P0000000`1<C4`0000003<c<`0K03<c<`030000000I6AT06ATI00T06ATI;P000004ooooo`030000
0?oooooooooo01Cooooo00?o0000ooooooooool02_ooool6ojVmj005o`000?nfPYco]X:LokJ2W?nH
IYH00_nnQ9H3oiMQT0CoVF2=0onLHXd01OnLLJ7oWfJ>oimVS_nOIXkoWg>Q00?oY6^@00?oY7ZUoj]d
U_n[M9H00_n[Q:/2ok>2X0;o/hna1?njUk<00on]S[Ko_IVbokfI/P03ojb;/P?oZhN_00CoVho6ojZ4
[?nZQ:coZXB/0_nIS<@4oiN9`P;oPZG[0_n1/oD2oiBfkP05oj>bhol0003o0000o`000?nX/^000on`
[]H2ok>[d004okB]dOnhZL_oWIG;oifEb`?o[8fe00?o/HRZolK6f_o6a]X00oo8ZKX01Oo4Vjgoi_S@
okjU`?nnYL3o_JG100?o_jFo00?o_ZG0ol2V_oo0Y[l00_noY/001?o1Ykoo_jO1oknW`OnoYl43oknX
`P09okfYa_noZL?o_jW3oknY`onmZlOo_j[4o`000?nl[<Wo_jc600?o_:g;00Co_jg8ok^_cOnk[lgo
^jo=0onk/=001_ng/mKo^[;BokZbd_nj/];o][CHokVde0?o];KJ1?nc]m`00ol0003oooooooooo`0K
ooooo`002Oooool01000003ooooooooooooooom8000000806ATI0`0000000`1VIVH0000007moO`04
07moO`80000000<0C4a<0000000c<c<06`0c<c<00`0000006ATI01TI6@0801TI6Bh000001?ooool0
0`00003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo1_nY_NP3okJ2W003oiQVU_nnQ9Ko
_XBF00;oUf6@00?oah^CoiUPSOnIH8d00_nIH8d3oiaRS@CoWfJ>00GoWg>QojA[T?nTJi3oY6^@ojAj
Y@02oj]dUP04oj^4ZoncPZ3o/h:Pok>2X0;o/hna00Co`9ZaokZG/onjUk?o^YNc0onmVK82ojb;/P04
oknG[on[QjooZhN_oj^7[`CoZXB/00?oVHc4ojV1ZOnGRL800onGRL82oiJ7`@;oOZC/0ol000000on1
]?GoV;K]oiRfk@02ojRbh003ok2^e_n//]co[;;L00?o]:gA00Go^:W;okR/c_n/SKGo[8feof?DlP03
olK6fP;ob:Vj0onnYl82okjU`0Co_jFo0oo0Y[l01OnoY/3o`JNool6W_oo1Ykoo_jO100;o`ZRo0_no
Z<83oknY``05ol:Z`OnoZ/Co_j[4oknZa?l000000_no[<H01Onl[L_o_jg8okn]b?no[LSo^jo=00;o
_Zo:00?o^k3@okf`cOnj/]800_nj/]801Onl//oo^KCDokVde?ni]=Co];KJ00;o]kGG0_nc]m`00onf
]]Woooooo`00000Looooo`002Oooool01000003ooooooooooooooom800000003o`00000I6AT06ATI
00D0000000?o000007moO`1oOgl00P1oOgl00ol00000000000000002000001/0<c<c00?o00000000
000I6AT0200I6AT]000000Cooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`0=oooo
o`CoZKgX0onfPY`00onHIYKo_XBFokj4UP02oiMQT003olN;TonIH8goVF2=00;oVF2=0onLHXd4oimV
SPCoY6^@0on[M9H4ok>2X003ok>?/Oo0V[7o`9Za00?o^YNc0onmVK801?n/Rk;o_iN_oknG[onoUjl2
oj^7[`CoZXB/0onYPJT2oiN9`P03ojQnY_nFQl7o000000;o00000_nDQL02og^Uk@;oP[Kf0_nL]n/4
ojbbg003okB]dOn`/]Wo^:c>00?o^:c>00?o^jS7okZ/boo6a]X00_nmZ<@4okjW`P03okjU`?o0Z<7o
`:S100;o_jFo0_o1Z<42ol2V_`Co`JNo0oo2Z;l01?noZ<;o`ZW0ol:Y`?noZL<3ol:Z`@05oknZa?o2
Zl?o`Z_3o`000?no[<H00ono[LP01?o2[/Ko_Zo:okj_b_nn[lX3okf`c@05okZbd_nl//oo_;;?okbb
coni]=@00_nk/m800ong]MOo^[GDokJff@03okJff@03o`000?oooooooooo01[ooooo0009ooooo`04
00000?ooooooooooooooodX0000000D06ATI0000000c<c<0000004a<C002000000D0Ogmo0`000000
0`1<C4`000000000000K03<c<`030000000I6AT06ATI00L06ATI;0000004ooooo`0300000?oooooo
oooo01Cooooo00?o0000ooooooooool03Oooool4ojVmj0?o]X:L0onnQ9H2oiMQT003olN;TonIH8go
VF2=00;oVF2=0onLHXd4oimVSPCoY6^@0on[M9H4ok>2X0Co`9Za00?o^YNcolfjb?o=^/P00_nmVK84
oknG[`03oj^7[onoU:_o_iB[00?oZXB/0onYPJT01?nGRL;o0000o`000?l00002oiJ7`@CoU8G00_mk
YNd2oh:fmP;oW;O[0_n//]`01?nQ^>Wo/;;Iok2bfOn`/]T2okR/cP05okBbeonj[<_o^Zc;okZ/bonm
Z<@00_nm[<T3okjW`P?o`:S100Go_jFool6X`Oo1Z<7o`JS1ol2V_`02ol:Y`0;o`JNo0_o3ZL02ol:X
_`?o`ZW01?o2Z/43ol:[``04o`000?o2[LCo`Zg4okn]b0?o`Zk600Go_Zo:ol6`bOo1/<Wo_K3=ol2a
b`03okbbc`04okncc_nk/m;o^k?Bok^cdP?o^[GD0_nf]]T2okRge`03o`000?oooooooooo01Wooooo
0009ooooo`0400000?oooooooooooooood/0000000D06ATI0000000c<c<0000004a<C002000000H0
Ogmo0P00000204a<C0030000000c<c<0<c<c01T0<c<c00<0000001TI6@0I6AT01`0I6AT[000000Co
oooo00<00000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`?oZKgX0_nfPY`01?nY_NSo
_XBFokj4U_nnQ9H2oiMQT005olN;TonIH8goVF2=oiUPSOoCU9400onLHXd4oimVSPCoY6^@0on[M9H4
ok>2X005oo3VPOo0V[7o`9ZaojNmjOnX_NP00_o=^/P00onmVK;oe];EomKBe@03oknG[`?o_iB[0_nZ
Q:`00onnTJOoZH6Yo`000002o`0000?oZ7jV00?oUXO1ojMlYOnWO:D00_nDQL001?nVNZ?oThC0oi>4
`?nCQ<02ogVUk`?oQ;Sf0_nQ^>T00on`/]WoYK[XokBbe`03okBbe`03okZ/bonh/mCo_Jc900?o_Jc9
00?o_ZO2okn/aono[<L00_o0Z<401?o1[LKo`JS1ol6X`Oo1Z<43ol:Y`005ol6W_oo3ZL3o`jW0ol>Y
`?o2Z;l00_o4Zl000oo2ZL3oa:c1olB/`@03ol:Z`@07olF]`_o2Zl?o`Z_3ol:]a?l0003o`Zg4olF_
a@03ol:^aP?o`K390oo0/L/01Onl//oo_k?>okncc_no/lko^k?B00;o_[CA00?o^[GDokbfdonh]mL0
0_nh]mL00onk]mKo0000ooooo`0Jooooo`002Oooool01000003ooooooooooooooom<0000000601TI
6Ol00000<c<c00000?l00000IVIV2P0000000`1<C4co000003<c<`0J03<c<`03o`00000I6AT06ATI
00L06ATI:P000004ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04Oooool01?nY
_NSo]X:LojVmj?nY_NP3okj4UP;oUf6@00Goah^CoiUPSOnIH8goVF2=om>DT@02oiaRS@03omnQT?nO
IXkoWfJ>00;oWfJ>0onTJi001?oh`8coZgBFoj]dU_ooe8P3ok>2X0;ol>J100Co`9ZaojVmj?nY_NSo
Z;gX0_nY_NP2ojRmj@04omKBeOnoUjoo_iN_oknG[`?o_iB[00CoZXB/okjAYol0003o00000_nYPJT0
1?nmSZ?oZ7jVojQnY_nXOZH3ojMlY@04oiB5`?nVNZ?oYWZSojIjX`;oThC00onBPl03ogRWl0;oQk[g
0_nU^^P2okBbe`04ojZki_nh/mCo^;?DokRce0;o_Jc900Go^k?Bokn/aono[<Oo_jc7ol2X`@03ol6]
aP03ol6X`Oo2[LGo`Zg500;o`ZW00oo3ZL001?o5[lCoa:_0olB[`?o4Zl04olB/`@04ol:Z`Oo5[L;o
aJg2ol:[``;oaJk300Go`Zg4o`000?o5[lGoaJo5ol:^aP02olBaa`03ol6`bOo4//Woa;;900;o`;7;
0ono/lh01?o2]Lko_[CAokjddOnn]=43okbfd`05okRgeonk]mKo^kOFooooool000006_ooool000Wo
oooo00@00000ooooooooooooooooC000000201TI6@040000000c<c<0000006IVIP8000001P2IVIT2
0000000304a<C0000000000001X0<c<c00<0000001TI6@0I6AT0200I6AT00ol0000000000000000V
000000Cooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0Booooo`?oZKgX0onnQ9H0
0onGHI3oah^ColN;T`03oiUPS@04om>DTOnLHXgoW6:=omnQT0?oWfJ>00Gok:n?ojA[T?nTJi3oY6^@
ooS0S002oj]dUP;oomB80_ncPZ000oo`iX7oZKgXojVmj006ojVmj004ojRmjOnY_NSoZKgXoknG[`;o
gM[D00Co_iB[o`000?l0003o00000_nnTJL00onYPJWo_HjSokf>X`03ojQnYP?oYgbU1?nVNZ<00onC
Q<3oYGRRoi:3`003oi:3`004ogRWl?nAPl3oMjWbogNYlP?oS;gg0onZ^nH00onh/mCo[kgTok^cdP03
ok^cdP03okn/aonm]=3o`Jg600;o`Jg600Go`;C?ol:]aOo2[LGo`Zg5ol:Y`002olB^a004ol>Y`?o5
[lCoaJo4olF_a0;oa:_000Coa[34olB/`Oo4[<7oak740oo5[L83olF^``;oaJo500?o0000olNdaoo4
/LL00_o4/LL3olBbb@04ol2aboo3]<_o`kC;oknccP?o`[G>00Co_[CAol2gd?o0]m3o_;KC0_no^=<0
1Onk]mKo_KWFoooooooooooo000001Wooooo0009ooooo`0400000?ooooooooooooooodd000000P0I
6AT30000000306IVIP000000000000D0VIVI0`00000204a<C0030000000c<c<0<c<c01P0<c<c00<0
000001TI6@0I6AT01`0I6ATY000000Cooooo00<00000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`;oZKgX0onnQ9H00onGHI3oah^ColN;T`03oiUPS@04om>DTOnLHXgoW6:=omnQT0?oWfJ>
00Gok:n?ojA[T?nTJi3oY6^@ooS0S002oj]dUP;oomB800?o/h:Poo3VPOnY_NP03?nY_NP3o`000003
oknDZooRf<co_Y6W00;o_Y6W00?oZH6Yokf>XonmSZ<00_nXOZH01?nmRj7oYgbUojMlYOnWO:D4ojIj
X`?oYGRR0_nBPl001?nTMj7oTH?0oi63`?nAPl02ogNYlP?oS;gg00?oZ[_Voi71mon__N@00_n__N@2
ok^cdP05ok>nh_nm]=3o_KC@okfdd?o1[LH00oo0]<l2ol:]a@?oa:k41?o5[l@01?o4Zl3oa[34olJ`
a?o4[<43olNaa004olF]`_o7//Goak;5olF^``;oak?600GoaJo5o`000?o7]<OoakC7olBaa`02olNe
b@;oa;;90oo3]</3ol:ecP04olBid?o0]m3o`;O@ol2gd0?o_kSC0onm^MH00ooooooo0000ooooo`0H
ooooo`002Oooool01000003ooooooooooooooom>000000806ATI100000000`1oOgl0000009VIV@04
09VIV@80000000Co000004a<C01<C4`000006P0c<c<00`0000006ATI01TI6@0701TI6BP000001?oo
ool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00GoZKgXokj4U_nnQ9Ko_XBF
oiMQT002olN;T`?oVF2=00CodiBAoiaRSOnLHXgogj6@0onOIXh01Oo/[hooY6^@ojA[T?nTJi3on<2<
00;oZgBF0_ooe8P00oncPZ3ol>J1ojVmj009ojVmj0?o000000?oZKgXojRmj?noU:/00_oRf<`3okjA
Y`Co_HjS00CoZ7jVokf;XOnmRj7oYgbU0_nlR9h3ojIjX`?oYGRR00CoTX?0ojAgXOnTMj7oY7NQ0_nA
Pl04oi63`@;oN:gd0_nA`OL00on__NCoV<CfoiS4mP03ok>nhP03okfdd?nh_n3o`;C?00?o`;C?00Co
`Zg5ol:ecOo2]Lgoa:k40_o4]/`3olF_a0?oa[340oo7/L@01?o8^L_oak;5olNbaOo7//D3olNcaP;o
akC700?o0000olVkcOo7]LT00_o7]LT01?o4//Woa[O;olJgboo3]</2olFhc@05ol:ec_o4^M3oa;W@
olBid?o0]m000_o2^]801?no^=?o`K_Eol6keOnm^MH2okjle`03ooooool0003ooooo01Oooooo0009
ooooo`0400000?ooooooooooooooodl0000000<06ATIo`00000c<c<00`0000000`1oOgl0000009VI
V@0209VIV@H0000000<0C4a<0000000c<c<06@0c<c<00ol00000000001TI6@0701TI6BL000001?oo
ool00`00003oooooooooo`0Cooooo`03o`000?oooooooooo01Gooooo0onnQ9H00onGHI3oah^ColN;
T`02oiUPS@;odiBA0_nLHXd01OoOXI3oWfJ>oimVS_nOIXkok:n?00?oY6^@00?on<2<oj]dU_n[M9H0
0_ooe8P00oncPZ3oZKgXojVmj006ojVmj0?o00001onY_NP01?oRf<co_Y6WokjAYonnTJL4okf>X`04
ojQnY_nmRj7o_H^QojMlY@;o_8RN0_nVNZ<01?nkQYcoYGRRojEhX_nUN:84ojAgX@03oi63`?nTMZ3o
Y7JP00;oTH?100CoXgJPoi65`_nAQL;oTHG20_mk/OH3oiS4mP03ok>nh_nNaoGo^;oP00;o^;oP0_o0
]<l01?nl`=go`[G=ol:ecOo2]Ld4olBfc004olF_a?o6]lcoa[O<olJ`a0;oakS;00Goak74olRiboo8
^L_ob;W;olNba@02olVib`08olNca_o9^/cobK[<olNdaoo9^lgo0000olVkcOo7]LT2olVlcP04olJg
boo8_M3ob;g@olFhc@;oakkB0_o4^M001?o5_]?o`[[Bol:jd_o2^]83ol6ke@?o_[cG0_ooool00ol0
003oooooooooo`0Eooooo`002Oooool01000003ooooooooooooooom@0000000401TI6@000000<c<c
o`000080000000Co000009VIV@2IVIT0VIVI0P0000000`2IVIT0000007moO`020000000304a<C000
0000<c<c01T0<c<c00<0000001TI6@0I6AT01`0I6AT00ol0000000000000000S000000Cooooo00<0
0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`?o_XBF00?oUf6@olN;Too7Ri<00_nI
H8d2om>DT@;oW6:=00Gogj6@oimVS_nOIXkoWfJ>onb_S`02ojA[T0;on<2<00CoZgBFoooDR?ooe8So
omB81_nY_NP3o`0000coZKgX00?o_Y6WonKB`_nmSZ<00onmSZ<3okf;X@03ojMlYOnlR9ko_8RN00;o
YWZS00Co^hJLojEhX_nUN:;oYGRR1?nTMj43ojAfX004oi63`OnSMZ3oXgJPoj=fX0;oTHG20onAQ/@3
ognfm`;oW/Oe00Co^;oPojG;lonUbo?oYL_c0_nl`=d00oo2]Lgo_l7Loko1g002olBfc004ol;2f_o6
]lcoa[O<olJgc0?oakS;0oo8^L/01?o8a=KobKW;olViboo9^L/3olVjc0?obK_=00Co0000olVlc_o9
_<kobKc>0oo8_M03olNndPCoaKkC00Co`[[BolBoe_o4_mKo`K_E0_o2_mP01Onn_=Oo_l3Joko0f_oo
oooo000001Oooooo0009ooooo`0400000?oooooooooooooooe00000000Co000001TI6@000000<c<c
1000000209VIV@0:0000002c/k<0000009VIV@000000Ogmo00000?l00000C4a<000001X0<c<c00<0
000001TI6@0I6AT01`0I6ATU000000Cooooo00<00000ooooooooool04_ooool00ol0003ooooooooo
o`0Fooooo`?o_XBF0oo7Ri<2oiUPS@;odiBA00?oW6:=omnQT?oOXI000onOIXh00oo/[hooY6^@ojA[
T002ooS0S004oj]dU_ooe8SoomB8oooDR0?oZKgX0ol0000@ojVmj0;oi];20onmSZ<3okf;X@Co_8RN
00CoYWZSok^6W?nkQYcoYGRR0_njQ9/3ojAgX@?oY7JP1?nSMZ000onAQL;oXgFPoj=eX002oi66a0Co
TXW60_n4^oT2ojG;l`06oh[1nOn/cO7o[<gaojc=lOno`Mco//o_1?o2`]X01?o6]lcoaL?HolG3f?o7
^</2olO4e`05olRiboo8a=Kob<CFolS4e_o9^L/00_o9aMH02?o9^/cobLGFolW5e_o9^lgobLGFo`00
0?o9aMKobKc>0_o9aML01?o8_M3ob<GGolS5eoo7_]82olO5f0;oaKkC0_o5aMX01?o4_mKoa<GKolC5
foo2_mP2ol;5g@05oko0f_noa=ko_lCNooooool000005_ooool000Wooooo00@00000oooooooooooo
ooooDP0000000`0I6AT0000003<c<`0200000004o`0000000000VIVI00000080/k>c00?o00000000
000000000`0000000`1<C4`000000000000;03<c<`?o00002`0c<c<00ol000006ATI01TI6@0701TI
6B@000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo0onnQ9H3olN;
T`;oVF2=0_oCU9400onLHXgogj6@omnQT002oimVSP;ok:n?0_nTJi02ooS0S004oj]dU_ooe8SoomB8
ojVmj0?o00005?nY_NP01?oVd/;o_HjSokf>XooWbkT3okf;X@Co_8RN0onkQY`00onUN:;o^XBKokZ4
V`03ojAgX@?oY7JP1?nSMZ03oj=eX003oi66a?nSMJ3oXgFP00?oTXW60onDS<P3oh[1n@03ojc=lOnA
ao[oTLOj00;o//o_0_o2`]X2okOAk@04olG3f?nld^_o_=;[olO4e`;o_m;X0oo8a=H9olW5eP04o`00
0?o9aMOobLGGolW5e`?ob<GG0oo7aMP3olG5fP04ol?=h_o4aM_oa<GKolC5f`?o`/GM0onoa=h2oooo
o`03o`000?oooooooooo01?ooooo0009ooooo`0400000?oooooooooooooooe8000000P0I6AT20000
0005o`0000000000000000000?l000001@2c/k<400000080C4a<00<0000003<c<`0c<c<0200c<c<0
0ol00000C4a<04a<C002o`0000X0<c<c00<0000001TI6@0I6AT01`0I6ATS000000Cooooo00<00000
ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`?o_XBF0oo7Ri<2oiUPS@;odiBA00?oW6:=
omnQT?oOXI000_nOIXh2onb_S`;oY6^@0_oh`8`01?n[M9KoomB8o`000?l0000HojVmj004okf>XooW
bkWoil^ionO;^@;o_H^Q1?nlR9h3ok^6W003ojEhX_njQ9_o^XBK00;oY7NQ00Go^H:IojAfX?nTMZ3o
Y7JPokR1V@03oj=fX0OoXgFP00?oTXW6oj9eX?nRMJ000_nDS<P4oiJ@b`03oi77n_nIULkoVIG>00;o
VLci0_ngdNd2oj3@n003okcBjonWe?OoYmCg00?o_m;X00Cob<CFol;Bi_o2d^KobLGF0_o4d^D01?o9
aMKoa];SolKBhoo9aMH2olKAhP05o`000?o9aMOoa]3RolK@h_o8aML00_o6cn801?o7aMSoaLkRolG>
h_o5aMX3ol?=hP04olC5foo2c>;o`/cRol;5g@;o_l_S00Go_lCNokg9honmbN?oooooo`00000Eoooo
o`002Oooool01000003ooooooooooooooomC000000806ATI1`0000050;>c/`03o`00000000000000
0080000000<0C4a<0000000c<c<0200c<c<00ol00000C4a<04a<C00204a<C003o`00000c<c<0<c<c
00P0<c<c00<0000001TI6@0I6AT01`0I6ATR000000Cooooo00<00000ooooooooool04_ooool00ol0
003oooooooooo`0Fooooo`;o_XBF00GoooooolN;Too7Ri?oah^CoiUPS@02om>DT@;oW6:=0_oOXI02
oimVSP;ok:n?0_nTJi001?oh`8co0000o`000?l0000KojVmj0?oil^i00?o_H^QonS4/OnlR9h00onl
R9h3ok^6W0?o^XBK0_nTMj42okV2V@03ojAfX?nhPIWo^86I00?oXgJP1onSMJ03oj9eX003oiB<b?nR
MZ7oXWJQ00?oUY3;0onIULh4oi^JdP04oj3@n?nOX=GoWj3EojODm`;oXZKH0on]e_D01?o2d^Ko/]Sc
ok;Hloo4d^D2okOIl@03olKBhonjfO3o^]W`00;oa]7R00?o_=S^o`000?o6d>800_nmend01?o6cn;o
_]K[okkFjoo5c^82okkDj`;o`lgR00?o_M;Zol;<h_o2c>800_nld>T01?nobn?o^lkYok_>jOnmbN<2
ok[<j003ooooool0003ooooo01?ooooo0009ooooo`0400000?oooooooooooooooe<0000000Go0000
0000000I6AT0000003<c<`0300000003o`0000000000/k>c00@0/k>c0P0000001Ol00000IVIV0000
001<C4`0000000P0<c<c00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0803<c<`030000
000I6AT06ATI00L06ATI00?o00000000000000007P000004ooooo`0300000?oooooooooo01;ooooo
00?o0000ooooooooool05_ooool00onnQ9Koooooooooo`03olN;T`03oiUPSOoCU97odiBA00;oW6:=
0_oOXI02oimVSP;ok:n?0ol000000ooh`8coomB8ojVmj00NojVmj003okf;XOoXa;7oj<Ba00;o_8RN
00CoikfZok^6W?nkQYco^hJL1?njQ9/01?nTMj7o^H:IokV2VOnTMZ02okR1V@;oXgJP00Go]gnHoj=e
X?nSMJ3oXgFPokInU`03oj=eX0?oXWFP1?nRMZ401?nFT<_oXgNRoj=gX_nIULh2oj=hX`;oVi[B00Co
XgVToinPeOnOX=GoWj3E0onRY]P4ojJ/f`04ok;HlonY/MkoZK7NokOIl@;o[KOP00?o^]W`ok2lh_n`
_>800_nlf>h00ol0003o//3TokgGk@02okC3i@04okkFjoneaNKo]LGVokkDj`;o]/OW00?o_M;ZokK8
ionfb>L00_nld>T2okK8j004ok_>jOnfb>So]/SXok[<j0;o]LSX00?o0000ooooooooool04_ooool0
00Wooooo00@00000ooooooooooooooooE@0000000`0I6AWo000003<c<`0200000003o`0000000000
000000D0/k>c10000000101VIVH0000004a<C000000703<c<`03o`00001<C4`0C4a<00<0C4a<00?o
000003<c<`0c<c<02@0c<c<00`0000006ATI01TI6@0601TI6B4000001?ooool00`00003ooooooooo
o`0Booooo`03o`000?oooooooooo01Wooooo0oo7Ri<00onIH8godiBAom>DT@02oiaRS@;ogj6@00Go
WfJ>o`000?l0003o0000ojA[T003ooS0S23oZKgX0ooXa;42okb8WP04onNmZ_nkQYco^hJLok^6W0Co
^XBK0oniPYT00onTMZ3o^86IokR1V@02oj=fX0;o]gnH00?oXgFPokInUonfOYL00onSMJ03oj9eX0Co
XWJQ0onSMj83oj=hX`05oi^Jd_nSNJCoXgVToj=iY?nOX=D00_nTNjH00onRY]SoYGfXojEmZ002ojJ/
f`;oYWnZ00CoZK7NojN2[OnWPZgo[KOP0_nXQ[000on`_>;oZXVcojZ9/`02ok;0i003o`000?n[S[Oo
]<?U00;o[I:k00Co]LGVojjG_on^Ukoo]/OW0_n_W<@00onfb>Oo/:78ok2Qb002okK8j004ok6VcOnf
b>So]/SXok:[d@;o]LSX0_nb[mH00ol0003oooooooooo`0Aooooo`002Oooool01000003ooooooooo
oooooomF0000000301TI6@000000<c<c00D000000`2c/k<60000000406IVIP000000C4a<000000L0
<c<c00?o000004a<C01<C4`00`1<C4`00ol00000<c<c03<c<`0903<c<`030000000I6AT06ATI00H0
6ATI80000004ooooo`0300000?oooooooooo017ooooo00?o0000ooooooooool06_ooool3olN;T`03
oiUPSOoCU97odiBA00;oW6:=0ol000001?nOIXkok:n?onb_SonTJi03ooS0S27oZKgX0_oXa;401?nl
R9koikfZonNmZ_oW_JX2ok^6W0Co^XBK0oniPYT4okR1V@04oj=fX?ngOiSo]gnHoj=eX0;o]WjG0_nS
MJ001?neOIOoXWFPoj9eX?nRMJ04oj9fX@?oXgNR0onSN:<4oj=iY0?oY7^V0onUOJP4ojIoZP?oYh:]
0onXQ[03ojZ9/`?oZhjg00Co0000ojfB^on]T[_o[I:k0on^Ukl3ojnLa0?o/:780onaY/d3ok:[d@?o
/ZoF00?o/YFiooooool000004_ooool000Wooooo00@00000ooooooooooooooooEP00000201TI6@03
0000000c<c<000000080000000H0VIVI0000002c/k<0/k>c0000003<c<`600000080C4a<00?o0000
03<c<`0c<c<0100c<c<00ol00000C4a<04a<C00404a<C0;o00002@0c<c<00`0000006ATI01TI6@07
01TI6Al000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo0oo7Ri<0
0onIH8godiBAo`000002o`0000;ogj6@0_nOIXh2onb_S`03ojA[T?oh`8con<2<02CoZKgX00Ko_8RN
onNmZ_oW_J[oikfZok^6W?oU]ZD4okZ4V`?o^H:I1?nhPIT3okMoV003oj=eX?nfOYOo]WjG00;oXgFP
0_neOIL00onRMJ3o]7fGoj9fX@02oj9fX@04okAlUonSMj;oXgNRoj=gXP?oXgRS1?nSNJ@3ojAkYP?o
YGfX00Co/GbIojIoZ_nVOj[oYWnZ0onWPZd3ojR6/0?oZXVc00Go/7jNoj^>]on[S[OoZhjgo`000002
ojfB^`04ok62X_n^Ukoo[YNook64Y@;o[ic400Go/HJXok2Qb?naRJco/HV/ok6Vc@02ok6=[`04ok:[
dOnbTKCo/Y6dok:_eP?o/YFi00?o0000ooooooooool04?ooool000Wooooo00@00000oooooooooooo
ooooEP0000001_l00000000001TI6@000000<c<co`000080000000?o00000000000000000`3<c<`2
000000040;>c/`00003o000000000080C4a<0P00000503<c<`03o`00001<C4`0C4a<00D0C4a<00?o
000003<c<`0c<c<01`0c<c<00`0000006ATI01TI6@0701TI6@03o`0000000000000001/000001?oo
ool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo0_o7Ri<3o`000003om>DTOnL
HXgogj6@00;ogj6@00GoWfJ>onb_Soo/[hook:n?ojA[T002ooS0S2CoZKgX1?oW_JX00onkQYcoiKJU
onFfY@02okZ4V`04on>aXOniPYWo^H:IokV2V@Co^86I0ongOiP00onSMJ3o]WjGokInU`02oj=eX0;o
]GfG00?oXWFPokAmUondOIL00_nRMZ42okAlU`03oj=gX_ncO9OoXgRS00;oXgRS00Co/g^Goj=iY?nS
NJCoXgVT0_nTNjH00onbNiSoYGfXojEmZ002ok5lV@;oYWnZ0_naO9X01?nWPZgo/GfKok5mVonXQ[02
ok5mW003ojZ9/on`OYko/7jN00;oZhjg00?o/82Po`000?n]T[/00_naPZ801?n^Ukoo/HBUok64YOn_
W<@2ok66Z0?o/HV/0onaSJl3ok:A]0Co/YFi00?oooooo`000?ooool04?ooool000Wooooo00@00000
ooooooooooooooooF@0000001@0I6AWo000000000000003o000000<0000000?o00000<c<c03<c<`0
0P3<c<`5000000<0C4a<00<0000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<C00404a<C003o`00
000c<c<0<c<c00P0<c<c00<0000001TI6@0I6AT01P0I6ATN000000Cooooo00<00000ooooooooool0
4Oooool00ol0003oooooooooo`0Iooooo`?o000000Goah^Com>DTOoCU97odiBAoiaRS@03omnQT004
oimVS_o/[hook:n?onb_S`?on<2<9OnY_NP3onNmZP03ok^6W?oU]ZGoiKJU00;o^XBK00Cohk6QokV2
VOniPYWo^H:I1?nhPIT3okMoV0Co]WjG00CoXgFPokEmUoneOIOoXWFP0_ndOIL01OnRMZ7o]7bGokAl
UondO9OoXgNR00;o/gbG00?oXgRSok=kUoncNiL00_nSNJ@2ok9kU`04ojAkY_nbNiSo/W^HojEmZ0;o
/GbI0_nVOjX2ok5lVP04ojN2[OnaOI_o/GfKojR6/0;o/GfL00GoZXVcok1nW_n`OYko/7jNoj^>]`02
ok20X003o`000?naPZ;o/H:R00?o/HBU0onaQZP3ok69[0?o/Hf_00Co`92Tok:A]?nbTKCo_i6W0onb
UKT00onnTj_o0000o`00000@ooooo`002Oooool01000003ooooooooooooooomJ0000000301TI6@00
0000000000H00000103<c<`600000080C4a<00?o000003<c<`0c<c<00`0c<c<00ol00000C4a<04a<
C00404a<C003o`00000c<c<0<c<c00P0<c<c00?o000001TI6@0I6AT01P0I6ATM000000Cooooo00<0
0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`?o000000CoooooolN;Too7Ri?oah^C
0ooCU9401OnLHXgogj6@omnQT?oOXI3oWfJ>00?ok:n?00?on<2<ojVmj?nY_NP0:?nY_NP3onFfY@03
okZ4VooS/J7ohk6Q00;o^H:I00?ohJbMokR1VOnhPIT00_nhPIT3okMoV0Co]WjG0oneOIL3okAmU`05
oj9fXOndO9Oo]7bGokAlUonSMj800_ncO9L00onSN:?o/g^Gok=kU`02oj=iY0;o/W^G00CoY7^Vok9k
V?nbNiSoYGfX0onaO9T01?nVOj[o/GbJok5lV_nWPZd2ok5mV`03ojR6/?naOIco/GfL00Co/7jN0on`
P:000onaPZ;o0000ok62XP03ok64Y@;o/HJX0_o2SIh01?naRJco`HjQol6>XOnaSJl2ol2@Y0;o/Y6d
0_noTJL01OnbUKWo_Y>[okjCZooooooo0000013ooooo0009ooooo`0400000?oooooooooooooooe/0
000000@06ATI00000000003o00000`0000000ol0000000000<c<c0030<c<c0060000002c/k<00000
o`00001VIVH000000P1<C4`00`000000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<00@0C4a<00?o
000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0601TI6A`000001?ooool00`00003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Cooooo0_l00004ooooo`?oah^C0ooCU9401OnLHXgogj6@omnQ
T?oOXI3oWfJ>00?ok:n?:onY_NP3onFfY@06okZ4VooS/J7ohk6Qon>aXOniPYWohJbM0onhPIT01?oO
Yi[o]gnHokMoV?ngOiP4okInU`?o]GfG0ondOIL01?nRMZ7o]7bGokAlUondO9L3ok=lU`05oj=hXonc
NiOo/g^Gok=kUonSNJ@00_nbNiL3ok9kV0Co/GbI0onaO9X3ok5mV`?o/GfL1?n`OYh3ok20X0;o/H:R
00?o0000ok64YOnaQ:D00_o3SI`01?naQZSo`XfNol:=W_naRJ`2ol6>X@04ok6=[oo0T:Co`92Tol2@
Y0?o_i6W0onnTj/00ooooooo0000ooooo`0?ooooo`002Oooool01000003ooooooooooooooomK0000
000301TI6@000000<c<c00<0000000?o0000000000000000103<c<`00`000000/k>c000000020000
000406IVIP000000C4a<000000D0<c<c00?o000004a<C01<C4`0101<C4`00ol00000<c<c03<c<`08
03<c<`030000000I6AT06ATI00L06ATI00?o000000000000000060000004ooooo`0300000?oooooo
oooo013ooooo00?o0000ooooooooool04_ooool3o`0000Kooooo0_o7Ri<01OoooooodiBAom>DTOoC
U97oW6:=00?ogj6@00CoWfJ>onb_Soo/[hook:n?;?nY_NP2onFfY@05okZ4VooS/J7ohk6Qon>aXOni
PYT00_oQ[9d2okR1V@04omnWV_ngOiSo]gnHokMoV0Co]WjG0oneOIL3okAmU`Co]7bG0oncO9L4ok=k
U`?o/W^G0onbNiP4ok5lV@?o/GbJ0onaOI/3ok5mW004olR=Uon`OYko/7jNok1nWP;o/82P00KoaHfI
ok62X_naPZ;o0000olB=V_naQ:D2ol>=W004ok66Z?o2SIko`XfNok69[0;o`HjQ1?o0T:@3oknAY`?o
_Y>[00?oooooo`000?ooool03oooool000Wooooo00@00000ooooooooooooooooG00000000`0I6AT0
000003<c<`06000000<0c<c<00?o00000000002c/k<00`000000101VIVH0000004a<C000000503<c
<`03o`00001<C4`0C4a<00@0C4a<00?o000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0601TI
6A/000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo0ol00009oooo
o`;oah^C00Coooooom>DTOoCU97odiBA1?oOXI000onOIXkok:n?onb_S`0_ojVmj0Cohk6Q00?o^H:I
on6/WOoQ[9d00_nhPIT01?oOYi[o]gnHokMoV?oMY9P4okInU`?o]GfG0ondOIL4okAlU`?o/gbG1?nc
NiL3ok9kU`?o/W^H1?naO9T3ok5lVP?o/GfK00CobHjFok5mW?naOIcob8fG0_n`OYh00oo6SISo/82P
ok20X002olF=V@04ok62X_o4SI[o0000ok64Y@;o`hfL0oo2SIh3ol6>X@04on^hW_o0T:Co`92Tol2@
Y0;o_i6W0_oS]:L01OnnTj_og[>[omjcZooooooo000000oooooo0009ooooo`0400000?oooooooooo
oooooed0000000<06ATI0000000c<c<010000000102c/k<000000<c<c03<c<`2o`0000030000002c
/k<0000000<000000P1<C4`00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<00<0C4a<00?o
000003<c<`0c<c<0200c<c<00`0000006ATI01TI6@0701TI6AX000001?ooool00`00003ooooooooo
o`0@ooooo`03o`000?oooooooooo00cooooo0ol0000<ooooo`03olN;Tooooooooooo00?odiBA1?oO
XI03onb_S`03oooooonY_NSoZKgX02goZKgX0ooS/J401?niPYWohJbMon6/WOnhPIT3omnWVP03okMo
V?oMY9So]WjG00;o]WjG00Gofj2GokEmUoneOIOo]GfGomVMUP02okAmU`Co]7bG0oncO9L4ok=kU`?o
/W^G0onbNiP4ok5lV@?o/GbJ00CobhnEok5mVonaOI_obHjF0_naOI`00oo8SIOo/7jNok1nWP02olJ=
V004ok20X?o5SIWoaHfIok62XP;oa8fJ00?o0000ol>=W?o3SI`00oo2SIh01?o_^YWo`HjQol6>XOo[
^9h2ol2@Y0;oikJR00Co_i6Won>dYooS]:Oo_Y>[0_oN/j/00ooooooo0000ooooo`0>ooooo`002Ooo
ool01000003ooooooooooooooomN0000000501TI6@000000<c<c00000?l000000P0000000ol00000
0000o`0000020>KViP;o00000P0000000ol0000000000000000204a<C0800000100c<c<2o`0000@0
C4a<00?o000003<c<`0c<c<0200c<c<00ol00000000001TI6@0701TI6AT000001?ooool00`00003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo0ol0000?ooooo`03olN;Tooooooooooo00?o
diBA1?oOXI03onb_S`;ooooo;_nY_NP3on>aX@?ohJbM00Ko^86IomnWV_oOYi[ogjNJokMoV?oMY9P3
okInU`03om^PUoneOIOo]GfG00;ofIfF0_ndOIL01OoGVYGo]7bGokAlUondO9OoeIRD00;o/gbG1?nc
NiL3ok9kU`04olnBU?nbNiSo/W^HoljAU0?o/GbI0_naO9X2ol^?U@;o/GfK00CobHjFok5mW?naOIco
b8fG0_n`OYh2olJ=V004ok20X?o5SIWoaHfIok62XP;oa8fJ00?o0000ol>=W?o3SI`00oo2SIh01?o_
^YWo`HjQol6>XOo[^9h2ol2@Y0;oikJR00Co_i6Won>dYooS]:Oo_Y>[0_oN/j/00on;;D_o0000oooo
o`0>ooooo`002Oooool01000003ooooooooooooooomO0000000301TI6@000000<c<c0080000000Go
00000000000000000000o`0000020>KViP;o00001@00000304a<C0030000000c<c<0<c<c00<0<c<c
00Go000004a<C01<C4`0C4a<o`00000;03<c<`030000000I6AT06ATI00L06ATI00?o000000000000
00005@000004ooooo`0300000?oooooooooo013ooooo00?o0000ooooooooool01_ooool3o`0001Go
oooo0ooCU944omnQT0;ok:n?1?ooool`ojVmj0?ohJbM00Go^86IomnWV_oOYi[ogjNJokMoV002omfT
V0;o]WjG00?ofj2GokEmUoneOIL00_oIWIH2okAmU`03omNJUOndO9Oo]7bG00;oeIRD0_ncO9L01?oC
UYCo/g^Gok=kUoncNiL2ok9kU`;oci:D0_nbNiP01?o>TICo/GbIok5lVOo<T9@2ok5lVP;obhnE0_na
OI/01?o9SYKo/GfLolR=Uoo8SIL2ok1nWP;oaXfH00?o/82PolF=VOo5SIT00oo4SIX01?o3SIco0000
ol>=W?oc_ID2ol:=WP03onnjVOo1SZ7ojkRN00;ojkRN00?o`92TonNfX_oW]Z800ooS]:L3omjcZ`;o
00003oooool000Wooooo00@00000ooooooooooooooooH00000000`0I6AT0000003<c<`0600000007
o`00003Vi^H0i^KV0>KVi_l000000000o`00000400000080C4a<00?o000003<c<`0c<c<00`0c<c<0
0ol00000C4a<o`00000=03<c<`030000000I6AT06ATI00L06ATI5`000004ooooo`0300000?oooooo
oooo013ooooo00?o0000ooooooooool00oooool3o`0001Sooooo0_oCU9400ooooooogj6@omnQT002
omnQT003ooooooo/[hoooooo00Cooooo<?nY_NP2on6/W@CogjNJ00Co]gnHomfTV?oMY9So]WjG0ooK
X9L00oneOIOofIfFomVMUP02okAmU`03omNJUOndO9Oo]7bG00;oeIRD0_ncO9L01?oCUYCo/g^Gok=k
UooAU9@2ok9kU`;oci:D0_nbNiP00oo>TICo/GbIok5lV@02olb@U004ok5lV_o;SiGobhnEok5mV`;o
bHjF00Go/GfLolR=Uoo8SIOob8fGok1nWP02olJ=V0?oaHfI0oo4SIX01?og`I3o`hfLo`000?oc_ID2
ol:=WP;okkZI0oo[^9h3onNfXP?ohkBW00GoooooomjcZoooooooooooo`00000?ooooo`002Oooool0
1000003ooooooooooooooomP00000006o`00000I6AWo000003<c<`00003o00000`000002o`0000<0
i^KV00?o00000000000000000P0000001@1VIVH0000004a<C01<C4`0000000D0<c<c00?o000003<c
<`0c<c<03@0c<c<00`0000006ATI01TI6@0701TI6AH000001?ooool00`00003oooooooooo`0?oooo
o`04o`000?ooooooooooooooo`?o00006oooool2om>DT@04oooooooOXI3ogj6@omnQT0;ooooo00?o
k:n?ooooooooool01Oooool^ojVmj003on6/WOnY_NSogjNJ00?ogjNJ0ooMY9P01OnfOYOofj2Gom^P
UooKX9Oo]GfG00;ofIfF0_ndOIL00ooGVYGo]7bGokAlU`02omFHU0;o/gbG00CodiJDok=kUoncNiOo
dIBD0_nbNiL2olnBU0;o/W^H00?ocY6Dok5lVOnaO9T00_o<T9@01?naO9[obhnEol^?UOnaOI/3olV>
UP?ob8fG0oo6SIP3olF=V@?oa8fJ00Goml6@ol>=W?o3SIco0000ol:=WP03onnjV@?ojkRN0ooW]Z80
0ooooooohkBWooooo`04ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooooooo
ooooof80000000<06ATI00000?l000000`0000000ol000000000o`0000040>KViP09o`0000000000
000007moO`000000IVIV0000001<C4`0000001D0<c<c00<0000001TI6@0I6AT01`0I6ATF000000Co
oooo00<00000ooooooooool03oooool4o`0001kooooo0_oCU9401?oooooogj6@omnQT?oOXI0;oooo
oc3oZKgX0ooOYiX3omfTV005okInUooKX9Oofj2Gom^PUoneOIL00_oIWIH00ondOIOoeiZEomNJU@02
okAlU`;oeIRD0_ncO9L00ooCUYCo/g^Gok=kU`02om6DU004ok9kUoo?TYCoci:Dok9kV0;ocY6D0_na
O9T2olb@U004ok5lV_o;SiGobhnEol^?U@?obHjF0oo8SIL3olJ=V0?oaHfI00SonlF;olB=V_o4SI[o
ml6@ol>=W?oc_IGo0000oo>mU@?okkZI0oo[^9h00oooooooikJRooooo`07ooooo`03o`000?oooooo
oooo00gooooo0009ooooo`0400000?ooooooooooooooof8000000P0I6AT700000005o`00003Vi^H0
i^KV0>KVi_l000000`0000001P1oOgl0000006IVIP000000C4a<000001D0<c<c00<0000001TI6@0I
6AT01`0I6ATE000000Cooooo00<00000ooooooooool03oooool2o`00023ooooo00CodiBAoooooooo
oooooooo0_oOXI0;oooooc3oZKgX0ooOYiX3omfTV005okInUooKX9Oofj2Gom^PUoneOIL00_oIWIH0
0ondOIOoeiZEomNJU@02okAlU`;oeIRD00?o/gbGom>FU?oCUY@00_ncNiL2om6DU004ok9kUoo?TYCo
ci:Dok9kV0;ocY6D0_naO9T2olb@U004ok5lV_o;SiGobhnEol^?U@?obHjF0oo8SIL3olJ=V004ook8
Q?o5SIWoaHfIoo_5R`;oa8fJ00Goml6@ol>=W?oc_IGolkfEo`000003onnjV@03ocH0D_o[^9kooooo
00_ooooo00?o0000ooooooooool03?ooool000Wooooo00@00000ooooooooooooooooH`00000201TI
6@L0000000Go00000>KViP3Vi^H0i^KVo`0000030000000307moO`00000000000080C4a<00?o0000
03<c<`0c<c<04P0c<c<00`0000006ATI01TI6@0701TI6AD000001?ooool00`00003oooooooooo`0A
ooooo`03o`000?oooooooooo01gooooo00GodiBAooooooooooooooooomnQT00=oooooc3oZKgX00?o
gjNJojVmj?oMY9P00_oMY9P4om^PU`CofIfF0_oGVYD2okAlU`;oeIRD00?o/gbGom>FU?oCUY@00_nc
NiL2om6DU004ok9kUoo?TYCoci:Dok9kV0?ocY6D00?o/GbIolb@U?o<T9@01?o;SiD3olV>UP?ob8fG
00CoolalolJ=V?o6SISoo/R40_o5SIT00ookaH_oa8fJooO1T002ooO1T0?olkfE00Go0000onnjVOoo
ooooooooon^hWP0<ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooooooooooo
of<0000000?o000001TI6@0I6AT00`0000000ol00000000000000002o`0000<0i^KV00?o00000000
000000001000000204a<C0030000000c<c<0<c<c0180<c<c00<0000001TI6@0I6AT01`0I6AT00ol0
000000000000000A000000Cooooo00<00000ooooooooool04_ooool00ol0003oooooooooo`0Loooo
o`05om>DTOoooooooooooooooooOXI003_oooolbojVmj0;ogJBH1?oKX9L4omVMUP?oeiZE00Co]7bG
omFHU?oEV9CoeIRD0_oCUY@2ok=kU`;odIBD00Co/W^GolnBU?o?TYCoci:D0oo>TI@3olb@U0CobhnE
0oo9SYH3olR=U`04ooo<O?o6SISoaXfHook8Q0;oaHfI00?onlF;olB=V_og`I000_og`I03oo>mU@03
ooooool0003ooooo00kooooo00?o0000ooooooooool03?ooool000Wooooo00@00000oooooooooooo
ooooIP0000000`0I6AT000000000000200000004o`00000000000000o`0000<0i^KV0_l000050000
0080C4a<00<0000003<c<`0c<c<04@0c<c<00`0000006ATI01TI6@0701TI6A@000001?ooool00`00
003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?ogj6@ooooooooool03_ooool`ojVm
j0;ogJBH00CoZKgXom^PUooKX9Oofj2G1?oIWIH3omNJU@CoeIRD0ooCUY@00oncNiOodIBDom6DU004
olnBU0?ocY6D0oo<T9@4ol^?U@?obHjF00Coo/mbolR=Uoo8SIOoolal0_o6SIP00oonb8CoaHfIoo_5
R`02oo_5R`?oml6@0_oc_ID2ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?oo
ool000Wooooo00@00000ooooooooooooooooI`0000000`0I6AT000000000000500000003o`00003V
i^H0i^KV0080i^KV00?o000000000?l000000P0000001?l00000C4a<04a<C000000C03<c<`030000
000I6AT06ATI00L06ATI4`000004ooooo`0300000?oooooooooo01Cooooo0_l0000aooooobooZKgX
00?ogJBHojVmj?nY_NP00ooKX9L4omVMUP?oeiZE1?oEV9@3om>FU0?odIBD1?o?TY@3oljAU0?oc92D
1?o;SiD3olV>UP05ook?L_o8SIOob8fGooo<O?o6SIP00_onb8@01?o5SIWonlF;oo_5RookaH/3ooO1
T003oooooooc_IGooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`002Oooool01000003ooooooooooooooomX0000000501TI6Ol00000000000000?l000000`000000
1_l00000i^KVo`000?l00000i^KVo`0000<0000000Go00000000001<C4`0C4a<0000000C03<c<`03
o`00000I6AT06ATI00L06ATI4P000004ooooo`0300000?oooooooooo01Kooooo00?o0000oooooooo
ool0;ooooolaojVmj0;ofj2G00?oZKgXomVMU_oIWIH00_oIWIH3omNJU@CoeIRD0ooCUY@3om6DU0Co
ci:D0oo>TI@3olb@U004ong;Doo;SiGobhnEol^?U@;obHjF0_oncg801?o8SIOoolalooo<O?o6SIP3
ook8Q0?onlF;00?oooooooO1T?ooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo0009ooooo`0400000?ooooooooooooooofP0000000@06ATI0000000c<c?o00001000
00001_l00000i^KVo`000?l00000i^KVo`0000@0000000@0IVIV0000001<C4`00000500c<c<00`00
00006ATI01TI6@0701TI6@03o`0000000000000000h000001?ooool00`00003oooooooooo`0Goooo
o`03o`000?oooooooooo02oooooo<OnY_NP00ooKX9OoZKgXocd0EP03omVMUP?oeiZE1?oEV9@3om>F
U0?odIBD1?o?TY@3oljAU004omO0??o<T9Coc92Dong;D`;obhnE00?onLmUolV>U_o9SYH00_oncg80
1?o8SIOoolalooo<O?ooc7`3ook8Q0;onlF;2oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00cooooo0009ooooo`0400000?ooooooooooooooofT0000000<06ATI0000000c<c<01@00
00001_l00000i^KVo`000?l00000i^KVo`0000@0000000@0IVIV0000001<C4`000004`0c<c<00`00
00006ATI01TI6@0701TI6A4000001?ooool00`00003oooooooooo`0Hooooo`03o`000?oooooooooo
02oooooo<?nY_NP00ooKX9OoZKgXocd0EP02omVMUP04ojVmj?oGVYGoeiZEomNJU@CoeIRD0ooCUY@3
om6DU0Coci:D0oo>TI@01?oG`3coc92Dolb@U?o]be<2ol^?U@;onLmU00CobHjFook?L_oncg;ob8fG
0oooc7`3ook8Q0gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`002Ooo
ool01000003ooooooooooooooomZ0000000301TI6@000000<c<c00D0000000So00000>KVi_l0003o
00000>KVi_l000000000o`000080000000@0IVIVo`00001<C4`000004`0c<c<00`0000006ATI01TI
6@0701TI6A0000001?ooool00`00003oooooooooo`0Iooooo`;o0000<?oooolbojVmj006omVMU_nY
_NSoZKgXob80COoGVYGoZKgX0ooEV9@01?l002oodiJDom>FU?oCUY@3om6DU004o`000?o?TYCoci:D
okB/80;ocY6D0_oG`3`2olb@U003ong;Doo;SiGobhnE00;onLmU00CobHjFook?L_oncg;oo/mb0_oo
c7`2ooooo`03ook8Q?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`002Oooool01000003ooooooooooooooomZ00000003o`00000I6AWo00000080000000Ko
00000000000000000000o`00003Vi^H2o`0000030>KVi_l0000000000080000000Go000006IVIP00
0000C4a<0000000B03<c<`030000000I6AT06ATI00P06ATI3`000004ooooo`0300000?oooooooooo
01_ooooo00?o0000ooooooooool0;_oooolaojVmj007omVMU_nY_NSoZKgXob80COoGVYGoooooo`40
@@02omFHU004o`00;ooCUYCodiJDo`0060;odIBD0_l00002olnBU003okB/8?o>TICocY6D00;oel0l
00?oc92Dong;Doo]be<00_o;SiD2ooW?I@05olV>U_oncg;oo/mbook?L_ooc7`05?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooof`0
00000P0I6AT01`00003o000000000000003o000000000?l00000103Vi^H00ol00000000000000003
00000080C4a<00<0000003<c<`0c<c<03`0c<c<00`0000006ATI01TI6@0801TI6@l000001?ooool0
0`00003oooooooooo`0Looooo`03o`000?oooooooooo02kooooo;onY_NP5ooooo`03omNJUOoooooo
0@1100;oeIRD0_l002l01?oCUYCoooooo`006?oAU9@2o`0000;oci:D0_nd[2001?o>TICoel0lomO0
??o<T9@3ong;D`03ol^?UOoicfGonLmU00?oo/mb5oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooofd000000P0I6AT600000003o`00
003Vi^H0i^KV0080i^KV00Co000000000000003o00000P00000204a<C0030000000c<c<0<c<c00l0
<c<c00<0000001TI6@0I6AT0200I6AT>000000Cooooo00<00000ooooooooool07Oooool00ol0003o
ooooooooo`0^ooooobcoZKgX2Oooool02ol1047oeIRDoooooooooooo000_om>FU?oooooo000Hom6D
U?oooooo000000;oci:D0_nd[2001?o>TICoooooomO0??oG`3`3ong;D`04ooW?IOooooooooooook?
LQWooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`002Oooool01000003o
oooooooooooooom^000000806ATI00Co000000000000003o00000P0000000ol00000i^KV0>KViP02
0>KViP;o00000`0000001?l00000000004a<C?l0000A03<c<`030000000I6AT06ATI00L06ATI00<0
0000o`00000000002`000004ooooo`0300000?oooooooooo01kooooo0_l0000_ooooobOoZKgX3_oo
ool02?oEV9Coooooooooool002oodiJDooooool001SodIBD0_ooool2olnBU003oooooond[23ocY6D
00;ooooo00Goel0long;DoooooooooooooW?I@0Mooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02oooool000Wooooo00@00000ooooooooooooooooK`0000001@0I6AT0000003<c<ol0
0000IVIV008000000_l000040>KViP06o`000000000000000000001VIVH000000P1<C4`00`000000
<c<c03<c<`0>03<c<`030000000I6AT06ATI00P06ATI3@000004ooooo`0300000?oooooooooo023o
oooo00?o0000ooooooooool0;OoooolRojVmj1;ooooo00GoeIRDoooooooooooo000_om>FU002oooo
o`08om6DU?ooooooooooo`000?nd[23ooooookB/8?oG`3`3ooooo`03ong;Dooooooooooo01oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooo
oooooom`0000000501TI6@000000<c<c0000001VIVH00P0000000`3<c<co00000>KViP030>KViP08
o`000000000000000000001VIVH0000004a<C000000@03<c<`030000000I6AT06ATI00T06ATI3000
0004ooooo`0300000?oooooooooo027ooooo00?o0000ooooooooool0;_oooolNojVmj4Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooo
oom`000000806ATI00@0000003<c<`000000IVIV0P0000000`3<c<co00000>KViP020>KViP09o`00
000000000000o`0000000000IVIV0000001<C4`000000100<c<c00<0000001TI6@0I6AT0200I6AT<
000000Cooooo00<00000ooooooooool08_ooool00ol0003oooooooooo`0^oooooaWoZKgXCOooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooo
ooooog4000000P0I6AT01?l00000<c<c00000?l00002000000030<c<c?l0003o00000080i^KV0_l0
00050000000304a<C?l00000<c<c00h0<c<c00<0000001TI6@0I6AT02@0I6AT;000000Cooooo00<0
0000ooooooooool08oooool00ol0003oooooooooo`0^oooooaCoZKgXD_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?ooooooooooooooog8000000P0I
6AT00`000000<c<co`00000200000004o`00003<c<`0c<c<o`000080i^KV00Go0000000000000000
000007moO`020000000304a<C0000000<c<c00d0<c<c00<0000001TI6@0I6AT02P0I6AT00ol00000
000000000007000000Cooooo00<00000ooooooooool09?ooool2o`0002oooooo4?nY_NQFooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooo
ooooM00000000`0I6AT0000003<c<`0400000080c<c<00Co00000>KViP3Vi^Ko000010000000101V
IVH0000004a<C000000>03<c<`030000000I6AT06ATI00T06ATI2P000004ooooo`0300000?oooooo
oooo02Kooooo00?o0000ooooooooool0;Oooool=ojVmj5Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooome0000000401TI6@000000
<c<c000000;o00000P0000001`3<c<co00000>KViP3Vi^Ko000000000?l000000P000000101VIVKo
000004a<C000000=03<c<`030000000I6AT06ATI00X06ATI2@000004ooooo`0300000?oooooooooo
02Oooooo00?o0000ooooooooool0;Oooool8ojVmj5gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooomg0000000303<c<`00003o0000
00@0000000Go00000>KViP3Vi^Ko00000<c<c0030000000406IVIP000000C4a<000000d0<c<c00<0
000001TI6@0I6AT02P0I6AT9000000Cooooo00<00000ooooooooool0:?ooool00ol0003ooooooooo
o`0]ooooo`?oZKgXH_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009
ooooo`0400000?ooooooooooooooogP0000000<0<c<c00000000000010000002o`0000<0c<c<1000
000204a<C0030000000c<c<0<c<c00X0<c<c00<0000001TI6@0I6AT02`0I6AT8000000Cooooo00<0
0000ooooooooool0:Oooool2o`0002gooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo0009ooooo`0400000?ooooooooooooooogL0000000<0
6ATI0000000c<c<01P0000001?l00000c<c<0<c<c03<c<`300000005o`0000000000C4a<04a<C?l0
00002`0c<c<00`0000006ATI01TI6@0;01TI6@P000001?ooool00`00003oooooooooo`0[ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo0009ooooo`0400000?ooooooooooooooogP0000000<06ATI00000000
00000`0000000ol000000000000000040<c<c00300000?l00000000000<0000000<0C4a<0000000c
<c<02@0c<c<00`0000006ATI01TI6@0<01TI6@L000001?ooool00`00003oooooooooo`0/ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0I?ooool01Ol0003ooooooooooooooooo0000
00_ooooo0009ooooo`0400000?ooooooooooooooogT000000P0I6AT00`000000<c<c000000020000
0003o`0000000000c<c<00<0c<c<100000000`1VIVH000000000000903<c<`030000000I6AT06ATI
00d06ATI00?o000000000000000010000004ooooo`0300000?oooooooooo02gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`1Uooooo`04o`000?ooooooooooo`0000_ooooo0009oooo
o`0400000?ooooooooooooooogT0000000?o000001TI6@0I6AT00P0000000`1<C4`0000000000002
000000@0c<c<00?o00000000000000000P0000000`1<C4`0000003<c<`0503<c<`800000400I6AT7
000000Cooooo00<00000ooooooooool0;_ooool2o`0002Sooooo00?o0000ooooooooool0I_ooool0
0ol0003oooooo`00000;ooooo`002Oooool01000003ooooooooooooooomk000000806ATI0P000000
0`1<C4`00000o`000002000000@0c<c<0P0000001Ol0000000000000001<C4`0000000@0<c<c00<0
000001TI6@0I6AT04@0I6AT6000000Cooooo00<00000ooooooooool0<?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002oooool000Wooooo00@00000
ooooooooooooooooO00000001@0I6AT0000003<c<`00003o00000080000000<0/k>co`0000000000
0P3<c<`01@000000/k>c000000000000IVIV00800000100c<c<00`0000006ATI01TI6@0A01TI6@H0
00001?ooool00`00003oooooooooo`0aooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0Ioooool00ol0003oooooo`00000:ooooo`002Oooool01000003ooooooooooooooomm00000003
01TI6@000000<c<c00@000000P2c/k<2000000<0/k>c0P0000000`1VIVH000000000000403<c<`03
0000000I6AT06ATI01406ATI1@000004ooooo`0300000?oooooooooo03;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Xooooo`;o00002_ooool000Wooooo00@00000oooooooooooo
ooooO@0000001?l000006ATI0000000c<c<5000000030;>c/`000000/k>c0080/k>c100000000`1<
C4`0000003<c<`0203<c<`030000000I6AT06ATI01406ATI1@000004ooooo`0300000?oooooooooo
03?ooooo0_l0000Sooooo`03o`000?oooooooooo06Oooooo0ol0000:ooooo`002Oooool01000003o
oooooooooooooomo0000000301TI6@000000000000<0000000?o00000000002c/k<0102c/k<01`00
003o0000000000000000C4a<o`00000000000P0c<c<00`0000006ATI01TI6@0A01TI6@@000001?oo
ool00`00003oooooooooo`0eooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Hooo
ool4o`0000gooooo0009ooooo`0400000?oooooooooooooooh0000000P0I6AT00`000000<c<c0000
000200000003o`0000000000/k>c0080/k>c00<0000009VIV@0000000P0000001@1<C4`0000003<c
<`0c<c<0000001<06ATI10000004ooooo`0300000?oooooooooo03Kooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`1Pooooo`?o00004Oooool000Wooooo00@00000oooooooooooooooo
P00000000ol000006ATI01TI6@050000000309VIV@000000/k>c0080/k>c00<0000009VIV@000000
0P0000001@1<C4`0000003<c<`0c<c<0000001<06ATI0`000004ooooo`0300000?oooooooooo03Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`Co00005?ooool000Wooooo
00@00000ooooooooooooooooPP00000201TI6@@0000000?o00000000000000000`2c/k<01`000000
VIVI00000?l00000000004a<C00000000P0c<c<00`0000006ATI01TI6@0@01TI6@03o`0000000000
000000Cooooo00<00000ooooooooool0>?ooool2o`0001kooooo00?o0000ooooooooool0F?ooool4
o`0001Sooooo0009ooooo`0400000?oooooooooooooooh<0000000H06ATI0000000c<c<00000o`00
001VIVH200000004o`00002c/k<0/k>c00000080VIVI0P0000001@1<C4`0000003<c<`0c<c<00000
01806ATI0`000004ooooo`0300000?oooooooooo03[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`1Dooooo`Co00007?ooool000Wooooo00@00000ooooooooooooooooQ00000000`0I
6AT0000003<c<`020000000406IVIP000000000000000080/k>c00<0000009VIV@2IVIT00P000000
1@1<C4`0000003<c<`0c<c<0000001406ATI0`000004ooooo`0300000?oooooooooo03_ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`?o00008?ooool000Wooooo00@00000
ooooooooooooooooQ00000001?l000006ATI0000000c<c<20000000606IVIP000000VIVI0000002c
/k<000000P2IVIT400000080<c<c00<0000001TI6@0I6AT0400I6AT2000000Cooooo00<00000oooo
ooooool0??ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04gooooo1?l0000Soooo
o`002Oooool01000003ooooooooooooooon60000000301TI6@00000000000080000000?o00000000
000000000`00000209VIV@0400000?l00000000000000080<c<c00<0000001TI6@0I6AT03`0I6AT2
000000Cooooo00<00000ooooooooool0?Oooool2o`0001Wooooo00?o0000ooooooooool0BOooool4
o`0002Oooooo0009ooooo`0400000?ooooooooooooooohL000000P0I6AT00`000000<c<c00000003
000000@0VIVI00<0000007moO`0000000P00000203<c<`030000000I6AT06ATI00h06ATI0P000004
ooooo`0300000?oooooooooo03oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`15
ooooo`Co0000:oooool000Wooooo00@00000ooooooooooooooooQ`0000000ol000006ATI01TI6@02
0000000404a<C00000000000000000@0VIVI00D0000007moO`1oOgl00000o`00000203<c<`030000
000I6AT06ATI00h06ATI00<00000ooooooooool00_ooool00`00003oooooooooo`10ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0@oooool3o`0002oooooo0009ooooo`0400000?oo
ooooooooooooohT000000P0I6AT20000000304a<C000003o0000008000000`2IVIT00`000000Ogmo
07moO`0200000080<c<c00<0000001TI6@0I6AT03@0I6AT00`00003oooooooooo`02ooooo`030000
0?oooooooooo047ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0oooooo`Co0000
<_ooool000Wooooo00@00000ooooooooooooooooRP00000201TI6@80000000Go000006IVIP000000
Ogmo0000000209VIV@080000001oOgl0Ogmo0000001<C4`0000003<c<`00000?01TI6@0300000?oo
oooooooo00;ooooo00<00000ooooooooool0@_ooool2o`0001?ooooo00?o0000ooooooooool0>ooo
ool4o`0003Kooooo0009ooooo`0400000?oooooooooooooooh/000000P0I6AT30000000606IVIP00
0000Ogmo0000002IVIT000000P1oOgl20000000404a<C0000000<c<c000000h06ATI00<00000oooo
ooooool00_ooool00`00003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0=oooool4o`0003[ooooo0009ooooo`0400000?oooooooooooooooh/0000000?o000001TI
6@0I6AT00`0000003@1VIVH0000007moO`00003o00000000001oOgoo000006IVIP000000C4a<o`00
000000003P0I6AT00`00003oooooooooo`02ooooo`0300000?oooooooooo04Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0cooooo`Co0000?_ooool000Wooooo00@00000oooooooo
ooooooooS@0000000`0I6AWo000000000002000000;o000000<0Ogmo00000?l000000P1oOgl01P00
0000IVIVo`0000000000<c<co`0000d06ATI00<00000ooooooooool00_ooool00`00003ooooooooo
o`16ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool3o`0004;ooooo0009
ooooo`0400000?ooooooooooooooohh000000P0I6AT00`000000<c<c00000002000000@0Ogmo00<0
000006IVIP1VIVH00P0000000`0c<c<0000001TI6@0;01TI6@0300000?oooooooooo00;ooooo00<0
0000ooooooooool0Aoooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l0
0015ooooo`002Oooool01000003ooooooooooooooon>00000005o`00000I6AT06ATI0000000c<c<0
1000000307moO`030000001VIVH0IVIV0080000000<0<c<c0000000I6AT02@0I6AT2000000Cooooo
00<00000ooooooooool0B?ooool2o`0000gooooo00?o0000ooooooooool0:?ooool4o`0004Wooooo
0009ooooo`0400000?oooooooooooooooi0000000P0I6AT01P000000<c<c000000000000IVIV0000
0080Ogmo0P00000206IVIP0400000?l00000<c<c000000P06ATI0`000004ooooo`0300000?oooooo
oooo04[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`Co0000COooool0
00Wooooo00@00000ooooooooooooooooT@00000201TI6@070000000c<c?o00000000001VIVKo0000
0000000406IVIP8000000P0c<c<00`0000006ATI01TI6@0501TI6@<000001?ooool00`00003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool3o`00057ooooo
0009ooooo`0400000?oooooooooooooooi8000000P0I6AT20000000304a<C0000000IVIV00H0IVIV
0P00000203<c<`030000000I6AT06ATI00@06ATI0`000004ooooo`0300000?oooooooooo04cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000E?ooool000Wooooo00@0
0000ooooooooooooooooTP0000000ol000006ATI01TI6@020000000304a<C0000000IVIV00D0IVIV
00Go000004a<C0000000<c<c0000000501TI6@@000001?ooool00`00003oooooooooo`1=ooooo`;o
00002?ooool00ol0003oooooooooo`0Iooooo`Co0000F?ooool000Wooooo00@00000oooooooooooo
ooooU00000001`0I6AWo0000000000000000C4a<o`00000000001@1VIVH00`000000C4a<o`000002
000000@06ATI10000004ooooo`0300000?oooooooooo04oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Eooooo`Co0000G?ooool000Wooooo00@00000ooooooooooooooooU@000002
01TI6@0500000?l00000000004a<C0000000101VIVH00`000000C4a<04a<C002000000D06ATI00?o
00000000000000001?ooool00`00003oooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04_ooool3o`00063ooooo0009ooooo`0400000?oooooooooooooooiD0000000Oo
000001TI6@0I6AT0000003<c<`000000C4a<008000000`1VIVH00`000000C4a<04a<C002000000@0
6ATI0`000004ooooo`0300000?oooooooooo057ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0>ooooo`Co0000Hoooool000Wooooo00@00000ooooooooooooooooU`00000201TI6@03
o`00000c<c<000000080C4a<00<0000006IVIP1VIVH00P000000101<C4`0000003<c<`00000401TI
6@8000001?ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0003oooooooooo`0:oooo
o`Co0000Ioooool000Wooooo00@00000ooooooooooooooooV000000201TI6@070000000c<c?o0000
0000001<C4co00000000000304a<C0040000000c<c<0<c<c000000<06ATI0P000004ooooo`030000
0?oooooooooo05Cooooo00Co0000oooooooooooo00002?ooool4o`0006_ooooo0009ooooo`040000
0?oooooooooooooooiX0000000D06ATI0000000c<c<0<c<c0000000604a<C0040000000c<c<0<c<c
000000<06ATI00<00000ooooooooool00_ooool00`00003oooooooooo`1Eooooo`03o`000?oooooo
000000Gooooo0ol0001_ooooo`002Oooool01000003ooooooooooooooonK0000000501TI6@00003o
000003<c<`0000001P1<C4`010000000<c<c03<c<ol0000301TI6@0500000?ooooooooooooooo`00
0000F?ooool2o`000003ooooool0003o000000;o0000L_ooool000Wooooo00@00000oooooooooooo
ooooW00000001@0I6AT0000003<c<ol00000000000D0C4a<00D0000003<c<`0c<c<0<c<c00000002
01TI6@05o`000?ooooooooooooooo`000000FOooool2o`0007Kooooo0009ooooo`0400000?oooooo
oooooooooid0000000@06ATI0000000c<c<0<c<c0P00000404a<C0040000000c<c<0<c<c00000080
6ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooonN00000003
01TI6@00000000000080<c<c00D0000004a<C01<C4`0C4a<0000000303<c<`030000000I6AWooooo
00?ooooo00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooW`00000201TI
6@040000000c<c<0<c<co`0000<0C4a<00D0000003<c<`0c<c<0000001TI6@04ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?oooooooooooooooil000000`0I6AT01P000000<c<c03<c
<`000000C4a<000000@0<c<c00<00000ooooooooool00_ooool00`00003oooooooooo`3?ooooo`00
2Oooool01000003ooooooooooooooonR0000000501TI6@000000<c<c03<c<`0000001P0c<c<01@00
003oooooooooooooool000000=7ooooo0009ooooo`0400000?oooooooooooooooj<0000000<06ATI
o`00000c<c<01`0c<c<4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooooooo
oooooj<000000P0I6AT00`000000<c<c03<c<`0503<c<`Cooooo00<00000ooooooooool0coooool0
00Wooooo00@00000ooooooooooooooooY@0000000`0I6AT0000003<c<`0503<c<`Cooooo00<00000
ooooooooool0coooool000Wooooo00@00000ooooooooooooooooYP0000000`0I6AT0000003<c<`04
03<c<`Cooooo00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooYP000000
1?l000006ATI00000000000303<c<`Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
ooooooooooooooooZ000000201TI6@80000000<0<c<cooooooooool00_ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooonY000000<06ATI00<00000ooooooooool00_oo
ool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooonZ000000<06ATI00D0
0000oooooooooooooooo0000003Aooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Ooooonf00000=7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7o
oooo003ooooooi7ooooo003ooooooi7ooooo0009oooookKo00004Ooooonfo`0000[ooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Rooooo`03oomo0?oooooooooo08gooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo017ooooo00?oogl0ooooooooool0W_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
3?ooool01OooO`3oooooooooooooooooogl001Kooooo00?oogl0ooooooooool0R?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00oooO`3ooooooooo
o`0Dooooo`03oomo0?oooooooooo08?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?oogl0
ooooooooool0U_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04Oooool01OooO`3oooooooooooooooooogl001[ooooo00?oogl0ooooooooool0Ooooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05Oooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooooooo01?o
oooo00?oogl0ooooooooool0MOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00oooO`3ooooo
oomo0003ooooo`;oogl01_ooool00oooO`3oooooooooo`2@ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Aooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool0Uoooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04Oooool00oooO`3oooooooooo`03ooooo`;oogl01_ooool01?ooO`3ooooooooooooo
ool2oomo0003ooooooooO`3oogl001oooooo00?oogl0ooooooooool0J?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04oooool01OooO`3oooooooooooooO`3ooooo00;oogl000?ooooooomo0?ooool00_oo
ool2oomo0003ooooooooO`3ooooo00Kooooo00?oogl0ooooooooool01_ooool00oooO`3ooooooooo
o`0:ooooo`03oomo0?oooooooooo06oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool06_ooool3o`00oiGooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0E
ooooo`03oomo0?ooooooogl000?ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`2=
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01Wooooo00Co003ooooo
oooooooooooo0_l00?nCooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool4
oomo0003ooooooooO`3oogl000?oogl000?ooooooomo0?ooool01Oooool00oooO`3oooooooooo`0X
ooooo`03oomo0?oooooooooo05cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool06Oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo093ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Gooooo`?oogl000Cooooooomo0?ooO`3oogl0:Oooool0
0oooO`3oooooooooo`1Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01[ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05Oooool2oomo0004ooooooooO`3oooooooooo`Coogl00_ooool0
0oooO`3ooooooomo002>ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
01_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`2>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07Oooool00oooO`3ooooooomo0002ooooo`05oomo0?oooooooooo
ooooooooO`00=Oooool00oooO`3oooooooooo`1Cooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo01cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`2=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool01?ooO`3oooooooooooooO`0>
ooooo`03oomo0?oooooooooo03Kooooo00?oogl0ooooooooool0B?ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Mooooo`03o`00oooooooooooo00?o000000?o003ooooo
ooooool0S?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?oogl0oooo
ooooool00oooO`000oooooooogl0ooooo`07ooooo`03oomo0?oooooooooo02Cooooo00?oogl0oooo
ooooool01_ooool00oooO`3oooooooooo`02ooooo`;oogl000?ooooooomo0?ooool00oooool00ooo
O`3oooooooooo`05ooooo`03oomo0?oooooooooo03oooooo00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool07_ooool00ol00?oo0000o`000003o`0008kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Nooooo`?oogl00oooool00oooO`3oooooooooo`04ooooo`03
oomo0?oooooooooo00gooooo00?oogl0ooooooooool02_ooool00oooO`3oooooooooo`03ooooo`03
oomo0?oooooooooo00;ooooo00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`1Aooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01oooooo1Ol000000ol00?oooooo
ooooo`2;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool01?ooO`3ooooo
oomo0?ooO`08ooooo`04oomo0?oooooooooooomo00Sooooo00?oogl0ooooooooool01Oooool00ooo
O`3oooooooooo`0?ooooo`03oomo0?oooooooooo00Gooooo00Coogl0ooooooooooooogl04Oooool0
0oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo03Kooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool07oooool5o`000003ooooool00?oooooo08_ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Nooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooo
ooooool01_ooool00oooO`3oooooooooo`0Kooooo`03oomo0?oooooooooo00Oooooo00?oogl0oooo
ooooO`000oooool00oooO`3oooooooooo`0Eooooo`03oomo0?oooooooooo03gooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool08?ooool3o`0000?ooooo00?o003ooooooooo
ool0ROooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00Coogl0oooooooo
oooooooo0_ooO`0Looooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool01_ooool2oomo
00Cooooo00?oogl0ooooooooool01oooool00oooO`3ooooooomo000=ooooo`03oomo0?ooooooogl0
043ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08Oooool2o`00o`Co
oooo00?o003oooooooooool0R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;o
oooo00Googl0ooooooooO`3ooooooomo0002ooooo`03oomo0?oooooooooo00Gooooo00?oogl0oooo
ooooool01oooool01OooO`3oooooooooooooooooogl000[ooooo00?oogl0ooooooooool02_ooool2
oomo00Sooooo0_ooO`02ooooo`03oomo0?ooooooogl000Oooooo00Coogl0ooooooooO`3oogl00_oo
ool00oooO`3oooooooooo`02oomo03Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool08oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo08Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Tooooo`;oogl00_ooool00oooO`3oooooooooo`0N
ooooo`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooool01Oooool00oooO`3ooooooomo000B
ooooo`03oomo0?oooooooooo03gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool09?ooool2o`00o`?ooooo00?o003oooooooooool0Q_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo02Cooooo0_ooO`03ooooo`03oomo0?oooooooooo00Cooooo00?oogl0oooo
ooooool02oooool01OooO`3oooooooooooooooooogl000Sooooo00Coogl0ooooooooooooogl01_oo
ool2oomo00Oooooo00Coogl0ooooooooooooogl04oooool3oomo03[ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool09_ooool01?l00?ooooooooooool00?n8ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08_ooool00oooO`3oooooooooo`03oomo0003oooo
ooooO`3oogl001Cooooo00?oogl0ooooooooool0:?ooool01?ooO`3oooooooooooooO`09ooooo`03
oomo0?oooooooooo03Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
9oooool2o`00o`03ooooool00?oooooo08Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Uooooo`04oomo0?oooooooooooomo01Sooooo00?oogl0ooooooooool01Oooool00oooO`3o
ooooooooo`0Jooooo`03oomo0?ooooooogl000cooooo00?oogl0ooooooooool00_ooool2oomo03Ko
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0:Oooool00ol00?oooooo
ooooo`26ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09oooool00oooO`3ooooo
oomo0002ooooo`03oomo0?oooooooooo01cooooo00?oogl0ooooooooO`002oooool01oooO`3ooooo
ooooooooooooogl0ooooooooO`002oooool00oooO`3oooooooooo`02oomo00Oooooo00?oogl0oooo
ooooool03?ooool00oooO`3oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo06oooooo3Ol00?lfooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0:Oooool00oooO`3oooooooooo`08ooooo`;oogl01?ooool00oooO`3oooooooooo`0Cooooo`03
oomo0?ooooooogl000[ooooo00?oogl0ooooooooO`000oooool00oooO`3oooooooooo`03ooooo`;o
ogl00_ooool00oooO`3ooooooomo0008ooooo`03oomo0?oooooooooo00Kooooo00?oogl0oooooooo
ool0;_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1^ooooo`03o`00
oooooooooooo00_ooooo0ol00?lcooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
;?ooool2oomo00[ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`07ooooo`03oomo
0?oooooooooo00_ooooo00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`07ooooo`03oomo
0?oooooooooo00Sooooo0_ooO`07ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool0
:_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1]ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool0<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Wooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0:ooooo`03oomo0?oo
oooooooo01Sooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`03ooooo`04oomo0?oo
ooooooooooooo`;oogl01?ooool2oomo00Kooooo00?oogl0ooooooooool02Oooool00oooO`3ooooo
ooooo`04ooooo`03oomo0?oooooooooo02Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0K?ooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo02oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0]ooooo`03oomo0?oooooooooo00;ooooo00?o
ogl0ooooooooool01Oooool01?ooO`3oooooooooooooO`09ooooo`03oomo0?ooooooogl001Gooooo
00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`03ooooo`04oomo0?oooooooooooomo00So
oooo00?oogl0ooooooooool0<oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1/ooooo`03o`00oooooooooooo01;ooooo1?l00?l]ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0;?ooool00oooO`3oooooooooo`0>ooooo`03oomo0?oooooooooo01;ooooo
00?oogl0ooooooooool03oooool00oooO`3oooooooooo`08ooooo`;oogl00oooool2oomo0003oooo
ooooO`3ooooo00Sooooo00?oogl0ooooooooO`001Oooool2oomo02Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0K?ooool00ol00?ooooooooooo`0Fooooo`;o003o:ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00Coogl0oooooooooooooooo
0_ooO`02ooooo`03oomo0?oooooooooo00Wooooo00?oogl0ooooooooool05Oooool00oooO`3ooooo
ooooo`0Aooooo`03oomo0?oooooooooo00?ooooo00Googl0oooooooooooooooooomo0002ooooo`03
oomo0?oooooooooo00Gooooo00Coogl0oooooooooooooooo0_ooO`04ooooo`;oogl09oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1]ooooo`03o`00oooooooooooo01Oo
oooo00?o003oooooooooool0:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02ko
oooo00?oogl0ooooooooO`002?ooool01?ooO`3oooooooooooooO`06ooooo`;oogl02Oooool2oomo
00?ooooo00Ooogl0oooooooooooooooooomo0?ooooooogl000;ooooo00?oogl0ooooooooool00ooo
ool01?ooO`3oooooooooooooO`03ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooO`00
0_ooool2oomo0003ooooooooO`3ooooo00Cooooo00?oogl0ooooooooO`000_ooool2oomo00;ooooo
00?oogl0ooooooooool00_ooO`0Vooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo06gooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`0Wooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0<Oooool00oooO`3oooooooooo`02ooooo`03oomo0?oo
oooooooo00Wooooo00?oogl0ooooooooool05oooool00oooO`3oooooooooo`0<ooooo`03oomo0?oo
oooooooo00_ooooo00?oogl0ooooooooool01_ooool2oomo013ooooo00?oogl0ooooooooO`006ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1]ooooo`;o003o3Oooool3
o`0000[ooooo0_l00?lWooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool0
1oooO`3ooooooomo0?ooooooogl0ooooooooO`001oooool01OooO`3oooooooooooooooooogl000Ko
oooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`04ooooo`03oomo0?ooooooogl000;o
oooo00?oogl0ooooooooool02oooool01oooO`3oooooooooooooooooogl0ooooooooO`001_ooool0
1OooO`3oooooooooooooooooogl000?ooooo1?ooO`02ooooo`03oomo0?oooooooooo00Cooooo1?oo
O`001_ooooooogl0ooooooooooooogl0ooooo`Coogl00_ooool00oooO`3oooooooooo`0Hooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06oooooo0_l00?l:ooooo`Go0000
2oooool00ol00?ooooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
<?ooool00oooO`3oooooooooo`0Fooooo`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool0
4Oooool2oomo01Gooooo00?oogl0ooooooooO`002?ooool00oooO`3oooooooooo`07ooooo`;oogl0
0oooool01?ooO`3oooooooooooooO`0Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo077ooooo00?o003oooooooooool01oooool5o`0000_ooooo00?o003oooooooooool0
9?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?oogl0ooooooooool0
0_ooool00oooO`3oooooooooo`0Booooo`05oomo0?ooooooooooooooooooO`002oooool00oooO`3o
oooooomo0004ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooool00_ooool01OooO`3o
oooooomo0?ooooooogl000gooooo00Googl0oooooooooooooooooomo0004ooooo`04oomo0?oooooo
ooooooooo`;oogl00oooool01_ooO`3ooooooomo0?ooO`3ooooooomo01Sooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0L_ooool00ol00?ooooooooooo`06ooooo`Go0000
3?ooool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
>_ooool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo01Cooooo00?oogl0ooooooooool0
0_ooool01OooO`3ooooooomo0?ooooooogl000cooooo00Coogl0oooooooooooooooo0_ooO`03oooo
o`05oomo0?oooooooooooomo0?ooool00_ooO`03ooooo`04oomo0?oooooooooooomo00;ooooo00?o
ogl0ooooooooool00_ooO`000oooooooogl0oomo0004oomo00;ooooo00?oogl0ooooooooool06?oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1cooooo`03o`00oooooooo
oooo00Kooooo0ol0000>ooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`11ooooo`03oomo0?oooooooooo01Gooooo00?oogl0ooooooooool01Oooool0
0oooO`3oooooooooo`02ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooool02oooool0
0oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool01?ooool0
0oooO`3ooooooomo000Kooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
07?ooooo0_l00?lHooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`11ooooo`04oomo0?oooooooooooomo00?ooooo00?oogl0ooooooooool06?ooool2
oomo0003ooooooooO`3ooooo00Gooooo00Coogl0oooooooooooooooo1OooO`06ooooo`03oomo0?oo
ooooogl000Cooooo00Coogl0ooooooooooooogl01?ooool4oomo00;ooooo0_ooO`000oooooooogl0
ooooo`0Looooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo07Gooooo0ol0
0?lEooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0jooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool03oooool00oooO`3ooooooooo
o`0?ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool02_ooool00oooO`3ooooooooo
o`09ooooo`03oomo0?oooooooooo00Gooooo0oooO`03ooooo`03oomo0?oooooooooo01_ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0N?ooool2o`00oaCooooo00?o003o
ooooooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo00?oogl0
ooooooooool01_ooool00oooO`3oooooooooo`0Looooo`03oomo0?oooooooooo01oooooo00?oogl0
ooooooooO`002?ooool2oomo0005ooooooooO`3oooooooooooooO`006_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`1jooooo`;o003o4_ooool00ol00?ooooooooooo`0Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool01OooO`3ooooooooooooo
ooooogl000kooooo00?oogl0ooooooooool01?ooO`0<ooooo`03oomo0?oooooooooo00Cooooo00?o
ogl0ooooooooO`000_ooool3oomo0005ooooooooO`3oooooooooooooO`001?ooool00oooO`3ooooo
oomo0002ooooo`05oomo0?ooooooogl0ooooooooO`001?ooool00oooO`3oooooooooo`0Kooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo07cooooo0ol00?l>ooooo`;o003o
8oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04cooooo00Googl0oooooooooooo
oooooomo000Jooooo`03oomo0?oooooooooo00Kooooo00Coogl0ooooooooooooogl00_ooool00ooo
O`3oooooooooo`09ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool01?ooool00ooo
O`3oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo07oo
oooo0_l00?l;ooooo`03o`00oooooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0kooooo`;oogl00_ooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooooooo00Ko
oooo00Coogl0ooooooooooooogl02Oooool00oooO`3ooooooomo0004ooooo`06oomo0?oooooooooo
oomo0?ooooooogl01oooool00oooO`3oooooooooo`07ooooo`;oogl02Oooool01?ooO`3ooooooomo
0?ooO`02ooooo`03oomo0?oooooooooo01cooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0G?ooool70000oakooooo2ol00?lVooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0@?ooool00oooO`3oooooooooo`0Booooo`03oomo0?ooooooogl001[ooooo00?o
ogl0ooooooooool01?ooool00oooO`3oooooooooo`0fooooo`03o`000?oooooooooo00Sooooo0009
ooooo`03o`000?oooooooooo05cooooo00<0003oooooooooool01?ooool20000odgooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1?ooooo`05oomo0?ooooooogl0ooooooooO`000_oo
ool00oooO`3oooooooooo`06ooooo`05oomo0?ooooooogl0ooooooooO`000_ooool00oooO`3ooooo
ooooo`09ooooo`04oomo0?oooooooooooomo00cooooo0_ooO`04ooooo`?oogl09oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Kooooo`030000oooooooooooo00Oooooo
00?o003oooooooooool0B_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo
0_ooO`04ooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool03?ooool00oooO`3ooooo
ooooo`02ooooo`03oomo0?ooooooogl000?ooooo00?oogl0ooooooooool01Oooool00oooO`3ooooo
ooooo`0:ooooo`;oogl01_ooool01?ooO`3ooooooomo0?ooO`0/ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo05[ooooo00<0003oooooooooool02Oooool20000od[ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1?ooooo`03oomo0?oooooooooo00Kooooo
00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0Kooooo`03oomo0?oooooooooo00[ooooo
00?oogl0ooooooooool09_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`1Jooooo`030000oooooooooooo00_ooooo0P000?m8ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0@?ooool00oooO`3oooooooooo`03ooooo`04oomo0?oooooooooooomo00Gooooo
00?oogl0ooooooooool04?ooool2oomo0003ooooooooO`3ooooo00Wooooo00Googl0oooooooooooo
oooooomo000@ooooo`03oomo0?oooooooooo00cooooo00?oogl0ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Jooooo`030000oooooooooooo00gooooo
0P000?m6ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0AOooool01OooO`3ooooo
ooooooooooooogl000;ooooo00?oogl0ooooooooool03_ooool00oooO`3oooooooooo`05ooooo`03
oomo0?oooooooooo017ooooo00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`0?ooooo`03
oomo0?oooooooooo01cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
F_ooool00`000?ooooooooooo`0?ooooo`030000oooooooooooo04?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0mooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool0
3_ooool00oooO`3oooooooooo`0:ooooo`;oogl000?ooooooomo0?ooool00_ooool00oooO`3ooooo
ooooo`05ooooo`;oogl03?ooool2oomo0003ooooooooO`3ooooo00?ooooo0_ooO`000oooooooogl0
oomo000Xooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05[ooooo00<0
003oooooooooool04?ooool00`000?ooooooooooo`12ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0A_ooool2oomo03Gooooo00?oogl0ooooooooool04?ooool00oooO`3ooooooooo
o`0Oooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05[ooooo00<0003o
ooooooooool04Oooool00`000?ooooooooooo`11ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0>Oooool00oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00;oogl00_ooool0
0oooO`3oooooooooo`0Hooooo`03oomo0?oooooooooo01Gooooo00Coogl0ooooooooooooogl05_oo
ool00oooO`3oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo05_ooooo00<0003oooooooooool04Oooool00`000?ooooooooooo`10ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0?oooool00oooO`3oooooooooo`04ooooo`03oomo0?oooooo
oooo00Cooooo00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooo
oooo00;ooooo0_ooO`02ooooo`03oomo0?oooooooooo00?oogl01oooool00oooO`3oooooooooo`04
ooooo`06oomo0?oooooooooooomo0?ooooooogl01Oooool00oooO`3oooooooooo`0:ooooo`03oomo
0?oooooooooo023ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Fooo
ool00`000?ooooooooooo`0Booooo`030000oooooooooooo03oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1@ooooo`03oomo0?oooooooooo00Sooooo00?oogl0ooooooooool03ooo
ool00oooO`3oooooooooo`07ooooo`03oomo0?oooooooooo03Sooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0Foooool00`000?ooooooooooo`0Cooooo`030000oooooooo
oooo03kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`12ooooo`;oogl01?ooool0
1?ooO`3oooooooooooooO`0;ooooo`;oogl01oooool2oomo0003ooooooooO`3ooooo01;ooooo00Co
ogl0oooooooooooooooo0_ooO`0@ooooo`03oomo0?oooooooooo00Cooooo00Coogl0oooooooooooo
ogl06_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Looooo`030000
oooooooooooo01?ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05_ooooo00?oogl0ooooooooool02?ooool00oooO`3oooooooooo`0Oooooo`03oomo
0?oooooooooo00Cooooo00?oogl0ooooooooool08?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`1Looooo`030000oooooooooooo01Cooooo00<0003oooooooooool0??oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo00?oogl0ooooooooool02ooo
ool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool02Ooo
ool00oooO`3oooooooooo`0nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo05gooooo00<0003oooooooooool05?ooool00`000?ooooooooooo`0kooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Boooool00oooO`3oooooooooo`03oomo00Cooooo0_ooO`00
0oooooooogl0ooooo`02ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool00_ooool0
1?ooO`3ooooooomo0?ooool2oomo00oooooo00Googl0oooooooooooooooooomo0007ooooo`04oomo
0?oooooooooooomo00cooooo00?oogl0ooooooooool06?ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`1Mooooo`030000oooooooooooo01Gooooo00<0003oooooooooool0
>_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04cooooo00?oogl0ooooooooool0
1Oooool00oooO`3oooooooooo`05ooooo`03oomo0?oooooooooo00?ooooo0_ooO`06ooooo`03oomo
0?oooooooooo00Wooooo00Coogl0ooooooooooooogl00_ooool00oooO`3oooooooooo`0cooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05gooooo00<0003oooooooooool0
5_ooool00`000?ooooooooooo`0iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
A_ooool02?ooO`3oooooooooooooO`3ooooooomo0?ooooooogl01?ooool00oooO`3oooooooooo`05
ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooool02_ooool00oooO`3oooooooooo`0Q
ooooo`03oomo0?oooooooooo01gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0G_ooool00`000?ooooooooooo`0Fooooo`03o`00o`000?oooooo03Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1@ooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooo
ooooool02Oooool00oooO`3oooooooooo`08ooooo`03oomo0?oooooooooo00[ooooo00?oogl0oooo
ooooool01Oooool01?ooO`3oooooooooooooO`0=ooooo`03oomo0?oooooooooo01gooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0G_ooool00`000?ooooooooooo`0Hoooo
o`030000oooooooooooo03Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=oooo
o`03oomo0?oooooooooo00Gooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`04oooo
o`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooO`00Aoooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`1Oooooo`030000oooooooooooo01Sooooo00<0003ooooooooo
ool0=Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Gooooo00?oogl0oooooooo
ool01oooool2oomo0005ooooooooO`3oooooooooooooO`000oooool00oooO`3oooooooooo`05oooo
o`04oomo0?oooooooooooomo00Sooooo00?oogl0ooooooooO`006Oooool00oooO`3oooooooooo`0V
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Kooooo0P000?l00ol0
0?ooooooooooo`05ooooo`030000oooooooooooo01Sooooo00<0003oooooooooool0=?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo05Oooooo00?oogl0ooooooooool01Oooool00ooo
O`3ooooooomo0007ooooo`03oomo0?ooooooogl000Kooooo00Googl0oooooooooooooooooomo000C
ooooo`03oomo0?oooooooooo017ooooo00?oogl0ooooooooool04Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`1Eooooo`050000ooooooooooooooooool00?l01oooool0
0`000?ooooooooooo`0Hooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`19ooooo`03oomo0?oooooooooo00?ooooo0_ooO`001?ooooooogl0oooooooo
O`07ooooo`03oomo0?ooooooogl000?ooooo00?oogl0ooooooooool02?ooool01?ooO`3ooooooooo
ooooO`05ooooo`;oogl000?ooooooomo0?ooool03oooool00oooO`3oooooooooo`05ooooo`03oomo
0?ooooooogl000_ooooo00?oogl0ooooooooool03oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`1Eooooo`030000oooooooooooo00;ooooo00?o003oooooooooool01?oo
ool00`000?ooooooooooo`0Iooooo`030000oooooooooooo03;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Booooo`03oomo0?oooooooooo00?ooooo00Googl0oooooooooooooooo
oomo000Aooooo`;oogl00_ooool2oomo00;ooooo00?oogl0ooooooooO`000oooool00oooO`3ooooo
ooooo`07ooooo`03oomo0?oooooooooo02Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0E_ooool00`000?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00<0
003oooooooooool06?ooool00`000?ooooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0Eoooool2oomo00Oooooo00Coogl0oooooooooooooooo0_ooO`000oooooooogl0
ooooo`02ooooo`05oomo0?ooooooogl0ooooooooO`000_ooool01?ooO`3oooooooooooooO`0@oooo
o`03oomo0?oooooooooo00[ooooo00?oogl0ooooooooool07?ooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`1Fooooo`030000oooooooooooo00?ooooo00?o003ooooooooo
ool01?ooool00`000?ooooooooooo`0Hooooo`030000oooooooooooo037ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`16ooooo`03oomo0?oooooooooo00_ooooo00?oogl0oooooooo
ool01_ooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo00;ooooo00?oogl0oooooooo
ool03Oooool00oooO`3oooooooooo`09ooooo`03oomo0?oooooooooo01Gooooo00?oogl0oooooooo
ool05?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Gooooo`030000
oooooooooooo00?ooooo00?o003oooooooooool00oooool00`000?ooooooooooo`0Iooooo`030000
oooooooooooo033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Looooo`Googl0
0_ooool01?ooO`3oooooooooooooO`03ooooo`05oomo0?ooooooooooooooooooO`000oooool00ooo
O`3oooooooooo`06ooooo`03oomo0?oooooooooo01gooooo00?oogl0ooooooooool05?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Hooooo`03o`00oooooooooooo00?o
oooo0_l00?l4ooooo`030000oooooooooooo01Wooooo00?o003oooooooooool0;oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05?ooooo00?oogl0ooooooooool00_ooO`03ooooo`;o
ogl000Cooooooomo0?ooooooogl00_ooool2oomo00Sooooo00Coogl0ooooooooooooogl01?ooool0
1OooO`3ooooooomo0?ooooooogl000;ooooo00?oogl0ooooooooool02_ooool00oooO`3ooooooooo
o`0Vooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Sooooo00<0003o
ooooooooool01Oooool01Ol00?ooooooooooooooool0003o01cooooo00<0003oooooooooool0;_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo0oooO`001Oooooooogl0oooo
ooooooooogl000?ooooo00?oogl0ooooooooool01oooool00oooO`3oooooooooo`04ooooo`03oomo
0?oooooooooo00;ooooo00?oogl0ooooooooO`001?ooool01?ooO`3oooooooooooooO`0[ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Wooooo00<0003oooooooooool0
1Oooool01Ol00?ooooooooooooooool0003o01_ooooo00<0003oooooooooool0;_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo05;ooooo0_ooO`03ooooo`04oomo0?oooooooooooooo
o`?oogl000?ooooooomo0?ooool00_ooool01?ooO`3ooooooomo0?ooool2oomo00Oooooo00?oogl0
ooooooooO`000_ooool00oooO`3oooooooooo`0Dooooo`03oomo0?oooooooooo01[ooooo00?oogl0
ooooooooool01_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Joooo
o`030000oooooooooooo00Cooooo00Go003ooooooooooooooooo0000o`0Looooo`030000oooooooo
oooo02gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Eooooo`04oomo0?oooooo
ooooooooo`Soogl03oooool2oomo00Oooooo00?oogl0ooooooooO`000oooool01OooO`3ooooooooo
ooooooooogl000Cooooo00?oogl0ooooooooool01Oooool00oooO`3oooooooooo`0Oooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05_ooooo00<0003oooooooooool01?oo
ool01Ol00?ooooooooooooooool0003o01cooooo00<0003oooooooooool0;?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo05oooooo0_ooO`02ooooo`03oomo0?oooooooooo00?ooooo
00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooooooo00;ooooo
00?oogl0ooooooooool08_ooool00oooO`3oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo05cooooo00<0003oooooooooool01?ooool01Ol00?oooooooooo
ooooool0003o01cooooo00<0003oooooooooool0:oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo05Gooooo00?oogl0ooooooooO`001_ooool2oomo0004ooooooooO`3ooooooomo00So
oooo00?oogl0ooooooooO`000_ooool01?ooO`3oooooooooooooO`07ooooo`03oomo0?ooooooogl0
01Wooooo0_ooO`0Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05go
oooo00<0003oooooooooool01?ooool01Ol00?ooooooooooooooool0003o01cooooo00<0003ooooo
ooooool0:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo0_ooO`02oooo
o`Coogl00_ooool00oooO`3oooooooooo`03ooooo`;oogl03_ooool00oooO`3oooooooooo`0Roooo
o`03oomo0?oooooooooo00oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooooooo
ool0G_ooool00`000?ooooooooooo`04ooooo`;o003o0_ooool00`000?ooooooooooo`0Jooooo`03
0000oooooooooooo02Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1@ooooo`03
oomo0?oooooooooo00Oooooo1OooO`001?ooooooogl0ooooooooool2oomo0003ooooooooO`3ooooo
00Cooooo00?oogl0ooooooooO`001oooool01?ooO`3oooooooooooooO`0Mooooo`03oomo0?oooooo
oooo00Oooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo05oooooo00<0003oooooooooool01Oooool01?l0
0?ooooooooooo`000?l>ooooo`?o00002oooool00`000?ooooooooooo`0Xooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0HOooool01OooO`3oooooooooooooooooogl000Oooooo00?o
ogl0ooooooooO`002?ooool01OooO`3ooooooomo0?ooooooogl001Wooooo00?oogl0ooooooooool0
6Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Pooooo`030000oooo
oooooooo00Gooooo00Co003ooooooooooooo003o3?ooool5o`0000_ooooo00<0003oooooooooool0
9oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05_ooooo00?oogl0ooooooooool0
0oooool01?ooO`3oooooooooooooool2oomo00;ooooo00?oogl0ooooooooool0A_ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo00Gooooo
00?o003oooooo`000?l03?ooool5o`0000cooooo00<0003oooooooooool09_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo05cooooo00Coogl0oooooooooooooooo1?ooO`03ooooo`;o
ogl01?ooool2oomo0003ooooooooO`3oogl000?ooooo00?oogl0ooooooooool01Oooool2oomo00?o
oooo00?oogl0ooooooooO`002?ooool00oooO`3ooooooomo000Rooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo067ooooo00<0003oooooooooool01_ooool00ol00?oooooo
0000o`0;ooooo`Go00003Oooool00`000?ooooooooooo`0Uooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0HOooool01?ooO`3ooooooomo0?ooool2oomo00;ooooo0_ooO`04ooooo`03
oomo0?oooooooooo00Oooooo00Googl0oooooooooooooooooomo0003ooooo`03oomo0?oooooooooo
013ooooo00?oogl0ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`1Rooooo`030000oooooooooooo00Kooooo00?o003oooooo`000?l02oooool3o`0000oo
oooo00<0003oooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05oo
oooo0_ooO`000oooooooogl0oomo0002ooooo`06oomo0?ooooooooooooooooooO`3ooooo1OooO`00
1Oooooooogl0ooooooooooooogl000?ooooo00?oogl0ooooooooool00_ooool00oooO`3ooooooooo
o`08ooooo`;oogl09oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1S
ooooo`030000oooooooooooo00Kooooo00?o003oooooo`000?l07?ooool00`000?ooooooooooo`0T
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0EOooool00oooO`3oooooooooo`0;
ooooo`;oogl000Gooooooomo0?ooO`3ooooooomo0002ooooo`;oogl00_ooool2oomo00;ooooo00So
ogl0ooooooooooooogl0ooooooooO`3ooooooomo00cooooo00?oogl0ooooooooool09oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Tooooo`030000oooooooooooo00Ko
oooo00?o003oooooo`000?l07?ooool00`000?ooooooooooo`0Sooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0H?ooool2oomo0004ooooooooO`3ooooooomo00;ooooo1?ooO`08oooo
o`;oogl05?ooool00oooO`3oooooooooo`0:ooooo`03oomo0?oooooooooo01Sooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`06ooooo`03
o`00o`000?oooooo01_ooooo00<0003oooooooooool08oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo06Cooooo00?oogl0ooooooooool00_ooool01?ooO`3oooooooooooooO`0Qoooo
o`03oomo0?oooooooooo00;ooooo0_ooO`0Booooo`03oomo0?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0IOooool00ol00?ooooooooooo`07ooooo`03
o`00o`000?oooooo01_ooooo00<0003oooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo06Kooooo0oooO`001?ooooooogl0ooooooooool3oomo0003ooooooooO`3ooooo
01?ooooo00?oogl0ooooooooool04?ooool00oooO`3oooooooooo`0Fooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo06Kooooo00?o003oooooooooool01_ooool00ol00?oo
oooo0000o`0Looooo`030000oooooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1Vooooo`07oomo0?ooooooogl0oomo0?ooooooogl0ooooo`02oomo0003ooooooooO`3o
oooo00;ooooo00?oogl0ooooooooO`000_ooool01?ooO`3oooooooooooooO`03ooooo`03oomo0?oo
oooooooo00kooooo0_ooO`02ooooo`03oomo0?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0Ioooool00ol00?ooooooooooo`06ooooo`03o`00o`000?oo
oooo01_ooooo00<0003oooooooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo06Sooooo0_ooO`000oooooooogl0oomo0005ooooo`05oomo0?ooooooooooooooooooO`005?oo
ool01?ooO`3oooooooooooooO`0Dooooo`03oomo0?oooooooooo00cooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0J?ooool00ol00?ooooooooooo`06ooooo`03o`00o`00
0?oooooo01_ooooo00<0003oooooooooool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo06;ooooo00?oogl0ooooooooool00oooool6oomo0003ooooooooO`3oogl000;oogl02?oo
ool01?ooO`3oooooooooooooO`03ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool0
1?ooool00oooO`3oooooooooo`0Qooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo06Wooooo00?o003oooooooooool01_ooool2o`00o`030000oooooooooooo01Sooooo00<0
003oooooooooool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06Gooooo00?o
ogl0ooooooooool00oooool00oooO`3ooooooomo0003oomo00Sooooo00?oogl0ooooooooool00_oo
ool01?ooO`3oooooooooooooO`05ooooo`;oogl06_ooool00oooO`3oooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06[ooooo00?o003oooooooooool01_oo
ool2o`00o`030000oooooooooooo01Sooooo00<0003oooooooooool07oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo06[ooooo1?ooO`001?ooooooogl0oomo0?ooO`0?ooooo`05oomo
0?ooooooooooooooooooO`00;?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1[ooooo`03o`00oooooooooooo00Oooooo00?o003o0000ooooool06Oooool00`000?oooooo
ooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0J_ooool4oomo0005oooo
ooooO`3oogl0ooooooooO`000_ooool00oooO`3oooooooooo`07ooooo`03oomo0?ooooooogl000Co
oooo00?oogl0ooooooooO`001_ooool00oooO`3oooooooooo`0<ooooo`03oomo0?oooooooooo017o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0K?ooool00ol00?oooooo
ooooo`07ooooo`03o`00o`000?oooooo01Wooooo00<0003oooooooooool07Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo06Sooooo00?oogl0ooooooooool00_ooool4oomo00oooooo
00?oogl0ooooooooool0;oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`1]ooooo`03o`00oooooooooooo00Kooooo00?o003o0000ooooool06Oooool00`000?oooooooooo
o`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0K?ooool5oomo0003oooooooo
O`3ooooo00;oogl000?ooooooomo0?ooool00_ooool2oomo00?ooooo0_ooO`06ooooo`03oomo0?oo
oooooooo01Gooooo00?oogl0ooooooooool03oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1^ooooo`03o`00oooooooooooo00Kooooo00?o003o0000ooooool06Oooool0
0`000?ooooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Poooool0
1?ooO`3oooooooooooooO`0[ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo06oooooo00?o003oooooooooool01_ooool00ol00?l0003oooooo`0Iooooo`030000oooooooo
oooo01_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1/ooooo`03oomo0?oooooo
oooo00;oogl03_ooool01OooO`3ooooooomo0?ooooooogl000;ooooo0_ooO`03ooooo`03oomo0?oo
oooooooo00Gooooo00?oogl0ooooooooool07?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1`ooooo`03o`00oooooooooooo00;ooooo0ol000000ooooooo003o0000o`0I
ooooo`030000oooooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1a
ooooo`05oomo0?ooooooooooooooooooO`003Oooool00oooO`3ooooooomo000Xooooo`05oomo0?oo
ooooooooooooool000002_ooool000Wooooo00?o0000ooooooooool0LOooool00ol00?oooooooooo
o`05o`000004ooooool00?l0003o0000oaSooooo00<0003oooooooooool06_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo06gooooo00?oogl0ooooooooool01?ooool2oomo013ooooo
00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Cooooo`03oomo0?oooooooooo00cooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0LOooool00ol00?oooooooooo
o`05o`0000;ooooo00?o003oooooo`000?l05oooool00`000?ooooooooooo`0Jooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Hoooool00oooO`3oooooooooo`0<ooooo`;oogl000Wo
oooooomo0?ooO`3ooooooomo0?ooooooogl0ooooooooO`001Oooool01?ooO`3oooooooooooooO`06
ooooo`03oomo0?oooooooooo02?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0L_ooool00ol00?ooooooo`000004o`0000?ooooo00?o003oooooo`000?l05oooool00`00
0?ooooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0MOooool00ooo
O`3oooooooooo`0Hooooo`05oomo0?ooooooooooooooooooO`007Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`1cooooo`;o003o0ol00005ooooo`03o`00ooooool0003o
01Kooooo00<0003oooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
07Oooooo00Coogl0ooooooooooooogl06oooool00oooO`3oooooooooo`0Iooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo07Gooooo00?o003oooooooooool01_ooool00ol0
0?oooooo0000o`0Fooooo`030000oooooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1gooooo`03oomo0?oooooooooo01?ooooo00?oogl0ooooooooool01?ooool00ooo
O`3oooooooooo`09ooooo`03oomo0?oooooooooo00kooooo00?oogl0o`000?ooool02Oooool000Wo
oooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`06ooooo`03o`00ooooool0003o01Ko
oooo00<0003oooooooooool06?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07Wo
oooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`08ooooo`04oomo0?oooooooooooomo
00?ooooo00?oogl0ooooooooool01?ooool00oooO`3oooooooooo`0Fooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo07Kooooo00?o003oooooooooool01_ooool01?l00?oo
oooo0000o`000?lEooooo`030000oooooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1`ooooo`03oomo0?ooooooogl000Cooooo00?oogl0ooooooooool01_ooool00ooo
O`3oooooooooo`05ooooo`;oogl03Oooool00oooO`3oooooooooo`0Hooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo07Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`020000oa?ooooo00<0003oooooooooool05oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo07Wooooo00?oogl0ooooooooool07Oooool00oooO`3oooooooooo`04ooooo`03
oomo0?oooooooooo00oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
N?ooool2o`00o`Oooooo0_l00?l2ooooo`030000oooooooooooo017ooooo00?o003oooooooooool0
5_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07;ooooo00Coogl0oooooooooooo
ogl01oooool2oomo00Gooooo00Ooogl0oooooooooooooooooomo0?ooooooogl000Kooooo1?ooO`04
ooooo`03oomo0?oooooooooo00Cooooo0_ooO`04ooooo`03oomo0?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool000Wooooo00?o0000ooooooooool0N_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo0080003o4Oooool00`000?ooooooooooo`0Fooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0NOooool00oooO`3oooooooooo`0Fooooo`05oomo0?oooooooooo
ooooooooO`006oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1joooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool00`000?ooooooooooo`0>oooo
o`030000oooooooooooo01Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1koooo
o`03oomo0?oooooooooo01cooooo0_ooO`0Fooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo07_ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03
0000oooooooooooo00gooooo00<0003oooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo07Gooooo00?oogl0ooooooooool01oooool01OooO`3ooooooomo0?ooooooogl0
00Cooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`02ooooo`04oomo0?ooooooogl0
oomo00?ooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`02ooooo`030000oooooooooooo00gooooo00<0003oooooooooool05Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo08[ooooo00?oogl0ooooooooO`000_ooool00ooo
O`3oooooooooo`07ooooo`03oomo0?oooooooooo00Oooooo00?oogl0ooooooooool00_ooool00ooo
O`3oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo07go
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`030000oooooooooooo00co
oooo00<0003oooooooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo07[o
oooo00Googl0oooooooooooooooooomo0002ooooo`03oomo0?ooooooogl000;ooooo0_ooO`04oooo
o`05oomo0?ooooooogl0ooooooooO`000oooool01OooO`3oooooooooooooooooogl000gooooo00?o
ogl0ooooooooool00_ooO`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo07kooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`00o`000?oo
oooo00_ooooo00<0003oooooooooool05Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo08Kooooo00Coogl0ooooooooooooogl02_ooool00oooO`3oooooooooo`07ooooo`05oomo0?oo
ooooooooooooooooO`003oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`1oooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00oooool00`000?oooooooooo
o`09ooooo`030000oooooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`26ooooo`03oomo0?oooooooooo02Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0P?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00?ooooo0P000?l9
ooooo`030000oooooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1n
ooooo`05oomo0?ooooooooooooooooooO`002_ooool00oooO`3oooooooooo`04ooooo`03oomo0?oo
oooooooo017ooooo00?oogl0ooooooooool01oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`21ooooo`;o003o1oooool00ol00?ooooooooooo`04ooooo`<0003o1Oooool0
0`000?ooooooooooo`0Fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0O_ooool0
1?ooO`3oooooooooooooO`0>ooooo`03oomo0?oooooooooo00Cooooo00?oogl0ooooooooool01ooo
ool00oooO`3oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo08?ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`06ooooo`H0003o6?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Gooooo0_ooO`05ooooo`04oomo0?oooooo
oooooomo00;ooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`08ooooo`03oomo0?oo
oooooooo00Oooooo00?oogl0ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`23ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool09?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Gooooo00?oogl0ooooooooO`001_ooool0
0oooO`3ooooooomo000Aooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
08Cooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Sooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0P_ooool00oooO`3oooooooooo`03ooooo`03oomo0?ooooooogl0
013ooooo00?oogl0ooooooooool00_ooO`000oooooooogl0ooooo`02ooooo`03oomo0?ooooooogl0
00[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0QOooool00ol00?oo
ooooooooo`05ooooo`03o`00oooooooooooo02;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`28ooooo`03oomo0?ooooooogl000Wooooo00?oogl0ooooooooool03_ooool00oooO`3o
ooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo08Kooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Qooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0QOooool01?ooO`3oooooooooooooO`02ooooo`03oomo0?ooooooogl000?o
oooo00Googl0oooooooooooooooooomo000Iooooo`04oomo0?ooooooooooo`0000[ooooo0009oooo
o`03o`000?oooooooooo08Oooooo0_l00?l6ooooo`03o`00oooooooooooo023ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`29ooooo`03oomo0?oooooooooo00Kooooo00?oogl0oooo
ooooool05Oooool00oooO`3oooooooooo`04ooooo`03oomo0?l0003ooooo00Wooooo0009ooooo`03
o`000?oooooooooo08Wooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Pooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Q_ooool00oooO`3oooooooooo`04ooooo`03
oomo0?oooooooooo00?ooooo00?oogl0ooooooooool02_ooool00oooO`3oooooooooo`02ooooo`03
oomo0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
R_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo01oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1nooooo`03oomo0?oooooooooo00Sooooo0_ooO`02ooooo`03oomo
0?ooooooogl000?ooooo00?oogl0ooooooooool00oooool00oooO`3ooooooomo0005ooooo`04oomo
0?ooooooogl0oomo00?ooooo0_ooO`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo08_ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0Nooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0QOooool00oooO`3ooooooomo0003ooooo`03oomo
0?oooooooooo013ooooo00?oogl0ooooooooool00_ooool00oooO`3oooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo08_ooooo00?o003oooooooooool01?oo
ool00ol00?ooooooooooo`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0P_oo
ool00oooO`3oooooooooo`08ooooo`?oogl00_ooool00oooO`3oooooooooo`02ooooo`03oomo0?oo
oooooooo00cooooo00?oogl0ooooooooO`002Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2<ooooo`;o003o1Oooool00ol00?ooooooooooo`0Looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0ROooool2oomo00Cooooo00Koogl0ooooooooooooogl0oooo
ooooO`07ooooo`03oomo0?oooooooooo00?ooooo0_ooO`05ooooo`03oomo0?oooooooooo00Gooooo
00?oogl0o`000?ooool02Oooool000Wooooo00?o0000ooooooooool0S_ooool00ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2Booooo`03oomo0?oooooooooo01Cooooo00?oogl0ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2?ooooo`;o003o0oooool00ol00?ooooooooooo`0K
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0SOooool00oooO`3oooooooooo`02
ooooo`03oomo0?oooooooooo00;ooooo0oooO`02ooooo`03oomo0?oooooooooo00Wooooo00?oogl0
ooooooooool00_ooO`02ooooo`04oomo0?ooooooooooo`0000[ooooo0009ooooo`03o`000?oooooo
oooo097ooooo00Go003oooooooooooooooooo`00o`0Looooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0TOooool2oomo0003ooooooooO`3ooooo00Kooooo00?oogl0ooooooooool01Ooo
ool2oomo0003ooooooooO`3ooooo00Wooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0T_ooool01Ol00?oooooooooooooooooo003o01_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2=ooooo`03oomo0?oooooooooo00?ooooo00?oogl0ooooooooool04Ooo
ool00oooO`3oooooooooo`03ooooo`06oomo0?ooooooooooooooooooO`3o00002_ooool000Wooooo
00?o0000ooooooooool0Toooool00ol00?ooooooo`00o`0Looooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Soooool00oooO`3oooooooooo`02ooooo`03oomo0?oooooooooo00?ooooo
0_ooO`02ooooo`03oomo0?ooooooogl000_ooooo00?oogl0ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2Dooooo`03o`00oooooooooooo01_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2Fooooo`;oogl03?ooool01_ooO`3ooooooooo
ooooO`3ooooooomo00Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Cooooo00Googl0ooooooooO`3o
oooooomo0005ooooo`03oomo0?ooooooogl000;ooooo0_ooO`000oooooooogl0ooooo`05ooooo`03
oomo0?oooooooooo00;oogl000?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Kooooo00?oogl0ooooooooO`00
0oooool01?ooO`3oooooooooooooO`03ooooo`05oomo0?oooooooooooomo0?ooool00_ooO`08oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`26ooooo`03oomo0?oooooooooo00[ooooo00?oogl0oooooooo
ool01?ooO`000oooooooogl0ooooo`02oomo00?ooooo00Coogl0ooooooooooooogl00_ooool00ooo
O`3ooooooomo0007ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`03oomo0?oooooooooo00Co
oooo00?oogl0ooooooooool01?ooool00oooO`3ooooooomo0002oomo00?ooooo00?oogl0oooooooo
ool00oooool2oomo0003o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`03oomo0?oooooooooo00?ooooo
0_ooO`000oooooooogl0ooooo`02oomo00Gooooo00?oogl0ooooooooO`001_ooool01?ooO`3ooooo
ooooool0000:ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0Toooool00oooO`3oooooooooo`02oomo00?ooooo0_ooO`04ooooo`03oomo
0?oooooooooo00Kooooo00?oogl0ooooooooO`000_ooool01?ooO`3ooooooomo0?l0000:ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
U?ooool00oooO`3oooooooooo`03oomo0003ooooooooO`3ooooo00?ooooo00Ooogl0oooooooooooo
oooooomo0?ooooooogl000[ooooo00?oogl0o`000?ooool02Oooool000Wooooo00?o0000oooooooo
ool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09;ooooo00?oogl0oooooooo
ool00_ooool00oooO`3ooooooomo0002ooooo`03oomo0?ooooooogl000;oogl00_ooool01OooO`3o
ooooooooooooooooogl000;ooooo00?oogl0ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Toooool2oomo00Kooooo00Googl0ooooooooooooogl0ooooo`02oomo00Cooooo0oooO`000ooo
ooooogl0oomo0005ooooo`03oomo0?l0003ooooo00Wooooo0009ooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Booooo`03oomo0?ooooooogl000Co
oooo00?oogl0ooooooooool00_ooool2oomo00Gooooo00?oogl0ooooooooO`000_ooO`02ooooo`;o
ogl01?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0U?ooool2oomo00?ooooo00Coogl0ooooooooO`3o
oooo0_ooO`02ooooo`?oogl00_ooool2oomo00Cooooo0_ooO`03ooooo`03oomo0?l0003ooooo00Wo
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2Gooooo`03oomo0?oooooooooo00;oogl000?ooooooomo0?ooool01Oooool01?ooO`3ooooo
ooooooooO`03ooooo`03oomo0?ooooooogl000Cooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09[ooooo
2oooO`02ooooo`03oomo0?oooooooooo00;ooooo00?oogl0ooooooooool00_ooool00oooO`3o0000
ooooo`09ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0VOooool00oooO`3oooooooooo`02ooooo`03oomo0?ooooooogl000?ooooo0_oo
O`02ooooo`03oomo0?oooooooooo00Cooooo00Coogl0oooooooooooo00002_ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09cooooo00?o
ogl0ooooooooO`000_ooO`02ooooo`03oomo0?ooooooogl000;oogl00oooool2oomo00Cooooo00?o
ogl0o`000?ooool02Oooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo09_ooooo00Googl0ooooooooooooogl0ooooo`02oomo0003oooooooo
O`3ooooo00;oogl000Cooooooomo0?ooooooogl01?ooool01?ooO`3oooooooooool0000:ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
V_ooool00oooO`3oooooooooo`04ooooo`03oomo0?ooooooogl000;ooooo00?oogl0ooooooooool0
0_ooO`001?ooooooogl0ooooooooO`03ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Kooooo`03oomo
0?oooooooooo00Kooooo1OooO`001Oooooooogl0ooooooooooooogl000?ooooo00?oogl0o`000?oo
ool02Oooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo09kooooo00?oogl0ooooooooool00oooool00oooO`3oooooooooo`02oomo00Oooooo
00?oogl0ooooool000002_ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo09[ooooo00?oogl0ooooooooool01_ooool00oooO`3ooooooooo
o`02ooooo`03oomo0?ooooooogl000Cooooo00Coogl0oooooooooooo00002_ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:3ooooo00?o
ogl0ooooooooool03oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0X_ooool00oooO`3oooooooooo`0<
ooooo`03oomo0?l0003ooooo00Wooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2Vooooo`03oomo0?ooooooogl000;ooooo00?oogl0oooo
ooooO`001?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0[oooool01?ooO`3oooooooooool0000:oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Xoooool00oooO`3oooooooooo`06ooooo`03oomo0?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0:[ooooo00?oogl0ooooooooool01Oooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Z_oo
ool00oooO`3oooooooooo`04ooooo`03oomo0?l0003ooooo00Wooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Xooooo`03oomo0?oooooo
oooo00;ooooo00Koogl0oooooooooooooooooomo0?l0000:ooooo`002Oooool00ol0003ooooooooo
o`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0[?ooool00oooO`3ooooooomo
0003ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2/ooooo`;oogl00_ooool00oooO`3oooooo`00000:
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0[Oooool00oooO`3oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2_ooooo`?o
ogl000?o0000ooooooooool02?ooool000Wooooo]_l0000Aoooook7o00000oooO`02o`0000[ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-294.432, -294.52, 1.41129, 1.41129}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, d2d1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0179695 0.198496 2.89513e-05 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2035 -0.0125 -6 -9 ]
[.2035 -0.0125 6 0 ]
[.3832 -0.0125 -6 -9 ]
[.3832 -0.0125 6 0 ]
[.56289 -0.0125 -6 -9 ]
[.56289 -0.0125 6 0 ]
[.74259 -0.0125 -6 -9 ]
[.74259 -0.0125 6 0 ]
[.92228 -0.0125 -6 -9 ]
[.92228 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05374 -30 -4.5 ]
[-0.0125 .05374 0 4.5 ]
[-0.0125 .1985 -6 -4.5 ]
[-0.0125 .1985 0 4.5 ]
[-0.0125 .34325 -24 -4.5 ]
[-0.0125 .34325 0 4.5 ]
[-0.0125 .48801 -30 -4.5 ]
[-0.0125 .48801 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.2035 0 m
.2035 .61803 L
s
.3832 0 m
.3832 .61803 L
s
.56289 0 m
.56289 .61803 L
s
.74259 0 m
.74259 .61803 L
s
.92228 0 m
.92228 .61803 L
s
0 .05374 m
1 .05374 L
s
0 .1985 m
1 .1985 L
s
0 .34325 m
1 .34325 L
s
0 .48801 m
1 .48801 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2035 0 m
.2035 .00625 L
s
[(10)] .2035 -0.0125 0 1 Mshowa
.3832 0 m
.3832 .00625 L
s
[(20)] .3832 -0.0125 0 1 Mshowa
.56289 0 m
.56289 .00625 L
s
[(30)] .56289 -0.0125 0 1 Mshowa
.74259 0 m
.74259 .00625 L
s
[(40)] .74259 -0.0125 0 1 Mshowa
.92228 0 m
.92228 .00625 L
s
[(50)] .92228 -0.0125 0 1 Mshowa
.125 Mabswid
.05975 0 m
.05975 .00375 L
s
.09569 0 m
.09569 .00375 L
s
.13163 0 m
.13163 .00375 L
s
.16757 0 m
.16757 .00375 L
s
.23944 0 m
.23944 .00375 L
s
.27538 0 m
.27538 .00375 L
s
.31132 0 m
.31132 .00375 L
s
.34726 0 m
.34726 .00375 L
s
.41914 0 m
.41914 .00375 L
s
.45508 0 m
.45508 .00375 L
s
.49102 0 m
.49102 .00375 L
s
.52695 0 m
.52695 .00375 L
s
.59883 0 m
.59883 .00375 L
s
.63477 0 m
.63477 .00375 L
s
.67071 0 m
.67071 .00375 L
s
.70665 0 m
.70665 .00375 L
s
.77853 0 m
.77853 .00375 L
s
.81447 0 m
.81447 .00375 L
s
.8504 0 m
.8504 .00375 L
s
.88634 0 m
.88634 .00375 L
s
.95822 0 m
.95822 .00375 L
s
.99416 0 m
.99416 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05374 m
.00625 .05374 L
s
[(-5000)] -0.0125 .05374 1 0 Mshowa
0 .1985 m
.00625 .1985 L
s
[(0)] -0.0125 .1985 1 0 Mshowa
0 .34325 m
.00625 .34325 L
s
[(5000)] -0.0125 .34325 1 0 Mshowa
0 .48801 m
.00625 .48801 L
s
[(10000)] -0.0125 .48801 1 0 Mshowa
.125 Mabswid
0 .08269 m
.00375 .08269 L
s
0 .11164 m
.00375 .11164 L
s
0 .14059 m
.00375 .14059 L
s
0 .16954 m
.00375 .16954 L
s
0 .22745 m
.00375 .22745 L
s
0 .2564 m
.00375 .2564 L
s
0 .28535 m
.00375 .28535 L
s
0 .3143 m
.00375 .3143 L
s
0 .3722 m
.00375 .3722 L
s
0 .40116 m
.00375 .40116 L
s
0 .43011 m
.00375 .43011 L
s
0 .45906 m
.00375 .45906 L
s
0 .02479 m
.00375 .02479 L
s
0 .51696 m
.00375 .51696 L
s
0 .54591 m
.00375 .54591 L
s
0 .57486 m
.00375 .57486 L
s
0 .60381 m
.00375 .60381 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2035 .61178 m
.2035 .61803 L
s
.3832 .61178 m
.3832 .61803 L
s
.56289 .61178 m
.56289 .61803 L
s
.74259 .61178 m
.74259 .61803 L
s
.92228 .61178 m
.92228 .61803 L
s
.125 Mabswid
.05975 .61428 m
.05975 .61803 L
s
.09569 .61428 m
.09569 .61803 L
s
.13163 .61428 m
.13163 .61803 L
s
.16757 .61428 m
.16757 .61803 L
s
.23944 .61428 m
.23944 .61803 L
s
.27538 .61428 m
.27538 .61803 L
s
.31132 .61428 m
.31132 .61803 L
s
.34726 .61428 m
.34726 .61803 L
s
.41914 .61428 m
.41914 .61803 L
s
.45508 .61428 m
.45508 .61803 L
s
.49102 .61428 m
.49102 .61803 L
s
.52695 .61428 m
.52695 .61803 L
s
.59883 .61428 m
.59883 .61803 L
s
.63477 .61428 m
.63477 .61803 L
s
.67071 .61428 m
.67071 .61803 L
s
.70665 .61428 m
.70665 .61803 L
s
.77853 .61428 m
.77853 .61803 L
s
.81447 .61428 m
.81447 .61803 L
s
.8504 .61428 m
.8504 .61803 L
s
.88634 .61428 m
.88634 .61803 L
s
.95822 .61428 m
.95822 .61803 L
s
.99416 .61428 m
.99416 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05374 m
1 .05374 L
s
.99375 .1985 m
1 .1985 L
s
.99375 .34325 m
1 .34325 L
s
.99375 .48801 m
1 .48801 L
s
.125 Mabswid
.99625 .08269 m
1 .08269 L
s
.99625 .11164 m
1 .11164 L
s
.99625 .14059 m
1 .14059 L
s
.99625 .16954 m
1 .16954 L
s
.99625 .22745 m
1 .22745 L
s
.99625 .2564 m
1 .2564 L
s
.99625 .28535 m
1 .28535 L
s
.99625 .3143 m
1 .3143 L
s
.99625 .3722 m
1 .3722 L
s
.99625 .40116 m
1 .40116 L
s
.99625 .43011 m
1 .43011 L
s
.99625 .45906 m
1 .45906 L
s
.99625 .02479 m
1 .02479 L
s
.99625 .51696 m
1 .51696 L
s
.99625 .54591 m
1 .54591 L
s
.99625 .57486 m
1 .57486 L
s
.99625 .60381 m
1 .60381 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.04178 .41587 L
.05975 .44986 L
.07772 .49868 L
.09569 .5385 L
.11366 .55229 L
.13163 .55773 L
.1496 .56159 L
.16757 .56535 L
.18553 .56944 L
.2035 .57367 L
.22147 .57745 L
.23944 .58032 L
.25741 .58238 L
.27538 .58393 L
.29335 .58514 L
.31132 .5861 L
.32929 .58686 L
.34726 .58746 L
.36523 .58796 L
.3832 .58841 L
.40117 .58886 L
.41914 .58932 L
.43711 .58982 L
.45508 .59038 L
.47305 .59098 L
.49102 .59164 L
.50898 .59234 L
.52695 .59309 L
.54492 .59385 L
.56289 .59462 L
.58086 .59538 L
.59883 .59611 L
.6168 .5968 L
.63477 .59744 L
.65274 .59804 L
.67071 .59859 L
.68868 .5991 L
.70665 .59956 L
.72462 .59999 L
.74259 .60038 L
.76056 .60073 L
.77853 .60106 L
.7965 .60136 L
.81447 .60164 L
.83243 .6019 L
.8504 .60214 L
.86837 .60235 L
.88634 .60255 L
.90431 .60274 L
Mistroke
.92228 .6029 L
.94025 .60305 L
.95822 .60319 L
.97619 .60332 L
Mfstroke
1 0 0 r
.02 w
.02381 .01472 Mdot
.04178 .41587 Mdot
.05975 .44986 Mdot
.07772 .49868 Mdot
.09569 .5385 Mdot
.11366 .55229 Mdot
.13163 .55773 Mdot
.1496 .56159 Mdot
.16757 .56535 Mdot
.18553 .56944 Mdot
.2035 .57367 Mdot
.22147 .57745 Mdot
.23944 .58032 Mdot
.25741 .58238 Mdot
.27538 .58393 Mdot
.29335 .58514 Mdot
.31132 .5861 Mdot
.32929 .58686 Mdot
.34726 .58746 Mdot
.36523 .58796 Mdot
.3832 .58841 Mdot
.40117 .58886 Mdot
.41914 .58932 Mdot
.43711 .58982 Mdot
.45508 .59038 Mdot
.47305 .59098 Mdot
.49102 .59164 Mdot
.50898 .59234 Mdot
.52695 .59309 Mdot
.54492 .59385 Mdot
.56289 .59462 Mdot
.58086 .59538 Mdot
.59883 .59611 Mdot
.6168 .5968 Mdot
.63477 .59744 Mdot
.65274 .59804 Mdot
.67071 .59859 Mdot
.68868 .5991 Mdot
.70665 .59956 Mdot
.72462 .59999 Mdot
.74259 .60038 Mdot
.76056 .60073 Mdot
.77853 .60106 Mdot
.7965 .60136 Mdot
.81447 .60164 Mdot
.83243 .6019 Mdot
.8504 .60214 Mdot
.86837 .60235 Mdot
.88634 .60255 Mdot
.90431 .60274 Mdot
.92228 .6029 Mdot
.94025 .60305 Mdot
.95822 .60319 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`009_ooool2
o`0002Oooooo0ol00004ooooo`;o00009?ooool5o`0000?ooooo0_l0000Tooooo`?o00001?ooool2
o`0002Kooooo0ol00003ooooo`;o00009Oooool3o`0000Cooooo0_l0000Aooooo`009Oooool01?l0
003oooooooooool0000Wooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0002;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0002Kooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`00013ooooo000Uooooo`04o`000?ooooooooooo`0002Oooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo027ooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`0>ooooo`009Oooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00009_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool08_ooool2o`0000?ooooo00Co0000oooooooooooo00008oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`0>ooooo`009Oooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000;ooooo00Co
0000oooooooooooo00009_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooool000000oooool01?l0003oooooooooool0000Sooooo`Co00000oooool01?l0
003oooooooooool0000@ooooo`009Oooool01?l0003oooooooooool0000Vooooo`;o00001?ooool0
1?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000Rooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000U
ooooo`;o00000oooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00004?ooool002Kooooo0_l0000Xooooo`03o`000?oooooooooo00?ooooo0_l0
000Uooooo`?o00001?ooool2o`0002Cooooo0ol00004ooooo`;o00009oooool00ol0003ooooooooo
o`02ooooo`;o00009?ooool5o`0000?ooooo0_l0000Aooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`008Oooool00`00003o0000o`00003jo`00004000000Ooo
ool0027ooooo00<00000ooooooooool00_ooool30?l000Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`7o00000@000001ooooo`008Oooool01000003oooooooooooooool5
0?l002[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooo
oooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0
027ooooo00@00000oooooooooooooooo1@3o000Zooooo`030000Oooooooooooo02_ooooo00<0001o
ooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001o
ooooooooool04?ooool10000007ooooo000Qooooo`0400000?ooooooooooooooo`D0o`00:_ooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00
003oooooooooo`02ooooo`<0o`00:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo
02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo
013ooooo0@000001ooooo`008Oooool00`00003o0000ooooo`03ooooo`03o`000?oooooooooo02[o
oooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_o
oooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0?ooooo`7o00000@000001ooooo`00
8Oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool00ooo
ool00ol0003oooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_oo
ool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?oo
ool10000007ooooo000Qooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00
003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0@ooooo`4000000Oooool000Oooooo0ol00004ooooo`;o00001?ooool2o`0000Co
oooo0_l00005ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool00`0007oo
ooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`001_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool00ol0003ooooooooo
o`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo0005
o`0000Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o00000000O`030000O`03
o`00000007l0001o0?<0001o0Ol000010000007ooooo000:ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00<00000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`030000Oooooooo
oooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooo
oooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo0006ooooo`Co00000oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool000Kooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool000Kooooo1Ol00003ooooo`;o
00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00Cooooo00?o0000oooooooo
ool0:Oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`00
8Oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool01?oo
ool00ol0003oooooooooo`0Yooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_oo
ool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?oo
ool10000007ooooo000Qooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00
003o0000ooooo`04ooooo`03o`000?oooooooooo02Wooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0?ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`04ooooo`03
o`000?oooooooooo02Wooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`03
0000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`40
00000Oooool0027ooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`030000
Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000
Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qooooo`0300000?oo
oooooooo00Cooooo00?o0000ooooooooool0:Oooool00`0007ooooooooooo`0[ooooo`030000Oooo
oooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooo
oooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`04ooooo`03o`000?oooooo
oooo02Wooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooo
oooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0
027ooooo00<00000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`030000Oooooooooooo
02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo
02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo00Co
oooo00?o0000ooooooooool0:Oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[o
oooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013o
oooo0@000001ooooo`008Oooool00`00003o0000ooooo`04ooooo`03o`000?oooooooooo02Wooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0?ooooo`7o00000@000001ooooo`008Ooo
ool00`00003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00<0001oooooooooool0:ooo
ool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:ooo
ool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool01?ooool0
0ol0003oooooooooo`0Yooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool1
0000007ooooo000Qooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00`00
07ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool01?ooool00ol0003ooooo
ooooo`0Yooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooo
ooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo
000Qooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool0:Oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003o0000ooooo`04
ooooo`03o`000?oooooooooo02Wooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Z
ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0?
ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo
02Wooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo
02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027o
oooo00<00000ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`030000Oooooooooooo02_o
oooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_o
oooo00<0001oooooooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo00Cooooo
00?o0000ooooooooool0:Oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo
0@000001ooooo`008Oooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00<0
001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000
ooooooooool01?ooool00ol0003oooooooooo`0Yooooo`030000Oooooooooooo02_ooooo00<0001o
ooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001o
ooooooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo00Cooooo00?o0000oooo
ooooool0:Oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001oooo
o`008Oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000o`000?ooool0
1Oooool00ol0003oooooooooo`0Xooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
3oooool1o`00004000000Oooool0027ooooo00<00000ooooooooool01Oooool00ol0003ooooooooo
o`0Xooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Q
ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool0:?ooool00`0007ooooooooooo`0[
ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[
ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`05oooo
o`03o`000?oooooooooo02Sooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zoooo
o`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@oooo
o`4000000Oooool0027ooooo00<00000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03
0000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`03
0000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Jooooo`;o0000
1Oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool001Wooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool001Wooooo00Co0000oooooooooooo0000
1?ooool00`00003o00000000O`050000O`03o`00000007l0001o0?40001o0Ol000010000007ooooo
000Iooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01Oooool00ol0003ooooo
ooooo`0Xooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooo
ooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo
000Iooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01Oooool00ol0003ooooo
ooooo`0Xooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooo
ooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo
000Iooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01Oooool00ol0003ooooo
ooooo`0Xooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooo
ooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo
000Jooooo`;o00001Oooool00`00003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00<0
001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000
ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`030000Oooooooooooo02_ooooo00<0001o
ooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001o
ooooooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo00Gooooo00?o0000oooo
ooooool0:?ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001oooo
o`008Oooool00`00003o0000ooooo`05ooooo`03o`000?oooooooooo02Sooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0?ooooo`7o00000@000001ooooo`008Oooool00`00003ooooo
ooooo`05ooooo`03o`000?oooooooooo02Sooooo00<0001oooooooooool0:oooool00`0007oooooo
ooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007oooooo
ooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool01Oooool00ol0003ooooooooo
o`0Xooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Q
ooooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool0:?ooool00`0007ooooooooooo`0[
ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[
ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`05oooo
o`03o`000?oooooooooo02Sooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zoooo
o`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@oooo
o`4000000Oooool0027ooooo00<00000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03
0000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`03
0000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qooooo`030000
0?oooooooooo00Gooooo00?o0000ooooooooool0:?ooool00`0007ooooooooooo`0[ooooo`030000
Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000
Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`05ooooo`03o`000?oo
oooooooo02Sooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooo
oooooooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Ooo
ool0027ooooo00<00000o`000?ooool01Oooool00ol0003oooooooooo`0Xooooo`030000Oooooooo
oooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooo
oooo02_ooooo00<0001oooooooooool03oooool1o`00004000000Oooool0027ooooo00<00000oooo
ooooool01Oooool00ol0003oooooooooo`0Xooooo`030000Oooooooooooo02_ooooo00<0001ooooo
ooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001ooooo
ooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo00Gooooo00?o0000oooooooo
ool0:?ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`00
8Oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool01_oo
ool00ol0003oooooooooo`0Wooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_oo
ool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?oo
ool10000007ooooo000Qooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool09oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00
003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000o`000?ooool01_ooool00ol0003o
ooooooooo`0Wooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oo
ooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool03oooool1o`000040
00000Oooool0027ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`030000
Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000
Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qooooo`0300000?oo
oooooooo00Kooooo00?o0000ooooooooool09oooool00`0007ooooooooooo`0[ooooo`030000Oooo
oooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooo
oooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`06ooooo`03o`000?oooooo
oooo02Oooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooo
oooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0
027ooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`030000Oooooooooooo
02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo
02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo00Ko
oooo00?o0000ooooooooool09oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[o
oooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013o
oooo0@000001ooooo`008Oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<0
0000o`000?ooool01_ooool00ol0003oooooooooo`0Wooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool03oooool1o`00004000000Oooool0027ooooo00<00000ooooooooool01_ooool0
0ol0003oooooooooo`0Wooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool1
0000007ooooo000Qooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00`00
07ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool01_ooool00ol0003ooooo
ooooo`0Wooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooo
ooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo
0007ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003ooooooooo
o`06ooooo`03o`000?oooooooooo02Oooooo00<0001oooooooooool0:oooool00`0007oooooooooo
o`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007oooooooooo
o`0@ooooo`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00`0007ooooooooooo`0[oooo
o`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[oooo
o`030000Oooooooooooo013ooooo0@000001ooooo`002_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`02ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool09oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`002_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`0300000?l00000001o00H0001o00?o00000000O`0007l0l00007l1o`000040
00000Oooool000Kooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Kooooo00?o0000
ooooooooool09oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001o
ooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001
ooooo`001_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Kooooo
00?o0000ooooooooool09oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo
0@000001ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<0
0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo00Kooooo00?o0000
ooooooooool09oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001o
ooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001
ooooo`008Oooool00`00003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000oooooooo
ool01oooool00ol0003oooooooooo`0Vooooo`030000Oooooooooooo02_ooooo00<0001ooooooooo
ool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001ooooooooo
ool04?ooool10000007ooooo000Qooooo`0300000?l0003ooooo00Oooooo00?o0000ooooooooool0
9_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo00oooooo0Ol000010000007ooooo
000Qooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`07
ooooo`03o`000?oooooooooo02Kooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Z
ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@
ooooo`4000000Oooool0027ooooo00<00000ooooooooool01oooool00ol0003oooooooooo`0Voooo
o`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[oooo
o`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qooooo`03
00000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00`0007ooooooooooo`0[ooooo`03
0000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`03
0000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`07ooooo`03o`00
0?oooooooooo02Kooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000
Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`400000
0Oooool0027ooooo00<00000ooooooooool01oooool00ol0003oooooooooo`0Vooooo`030000Oooo
oooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooo
oooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qooooo`0300000?l0003o
oooo00Oooooo00?o0000ooooooooool09_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooo
oooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooo
oooo00oooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo00Oooooo00?o0000oooo
ooooool09_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001oooo
o`008Oooool00`00003oooooooooo`06ooooo`<0o`009oooool00`0007ooooooooooo`0[ooooo`03
0000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`03
0000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`05ooooo`D0o`00
9_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Ooo
ool00`00003oooooooooo`05ooooo`D0o`009_ooool00`0007ooooooooooo`0[ooooo`030000Oooo
oooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooo
oooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`05ooooo`D0o`009_ooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00
003oooooooooo`06ooooo`<0o`009oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo
02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo
013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`08ooooo`03o`000?oooooooooo02Go
oooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_o
oooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo
00<00000o`000?ooool02Oooool00ol0003oooooooooo`0Tooooo`030000Oooooooooooo02_ooooo
00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo
00<0001oooooooooool03oooool1o`00004000000Oooool0027ooooo00<00000ooooooooool02_oo
ool00ol0003oooooooooo`0Sooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_oo
ool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?oo
ool10000007ooooo000Qooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool08oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00
003oooooooooo`0;ooooo`<0o`008_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo
02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo
013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0:ooooo`D0o`008Oooool00`0007oo
ooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003ooooo
ooooo`0:ooooo`D0o`008Oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo
0@000001ooooo`008Oooool00`00003oooooooooo`0:ooooo`D0o`008Oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003o0000ooooo`0;
ooooo`<0o`008_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001o
ooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo00oooooo0Ol00001
0000007ooooo000Qooooo`0300000?oooooooooo00gooooo00?o0000ooooooooool08?ooool00`00
07ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`0=ooooo`03o`000?oooooooooo023ooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007oooooo
ooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo
000Qooooo`0300000?oooooooooo00kooooo00?o0000ooooooooool07oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007oooooooooo
o`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`0000Coooooo`000?l0003o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool03_oo
ool00ol0003oooooooooo`0Oooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_oo
ool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?oo
ool10000007ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00001?ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001ooooo
ooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool000;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00oooooo
00?o0000ooooooooool07_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo
0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00<00000o`00000007l03`0007l30?l00>L0001o0Ol000010000007ooooo0002oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0>ooooo`D0o`007Oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[o
oooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013o
oooo0@000001ooooo`0000?oooooo`000?l000001?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo00kooooo1@3o000Mooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool04?ooool10000007ooooo0002ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00kooooo1@3o000M
ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[
ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qoooo
o`0300000?oooooooooo00oooooo0`3o000Nooooo`030000Oooooooooooo02_ooooo00<0001ooooo
ooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001ooooo
ooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo017ooooo00?o0000oooooooo
ool07?ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`00
8Oooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000o`000?ooool04_oo
ool00ol0003oooooooooo`0Kooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_oo
ool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool03ooo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool04oooool00ol0003oooooooooo`0J
ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`0007ooooooooooo`0[
ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool10000007ooooo000Qoooo
o`0300000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool00`0007ooooooooooo`0[oooo
o`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[oooo
o`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Dooooo`<0
o`006Oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`00
8Oooool00`00003oooooooooo`0Cooooo`D0o`006?ooool00`0007ooooooooooo`0[ooooo`030000
Oooooooooooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000
Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Cooooo`D0o`006?oo
ool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:ooo
ool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool0
0`00003oooooooooo`0Cooooo`D0o`006?ooool00`0007ooooooooooo`0[ooooo`030000Oooooooo
oooo02[ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooo
oooo013ooooo0@000001ooooo`008Oooool00`00003o0000ooooo`0Dooooo`<0o`0000?oooooo`00
003o00000P3o000Dooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:_ooool00`00
07ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool03oooool1o`00
004000000Oooool0027ooooo00<00000ooooooooool06?ooool80?l0013ooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001ooooooooo
ool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool0
6?ooool90?l00004ooooo`3o0000o`000?l000_ooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0:oooool00`0007oo
ooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool06?oooolA0?l000Oooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo
00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<0
0000ooooooooool06OoooolA0?l00004ooooo`3o0000o`000?l000;ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool07Ooo
ool30?l00003ooooo`3o0000o`0000l0o`00;?ooool00`0007ooooooooooo`0Zooooo`030000Oooo
oooooooo02_ooooo00<0001oooooooooool0:oooool00`0007ooooooooooo`0@ooooo`4000000Ooo
ool0027ooooo00<00000ooooooooool08_oooolA0?l00004ooooo`3o0000o`000?l002Oooooo00<0
001oooooooooool0:_ooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo02_ooooo00<0
001oooooooooool04?ooool10000007ooooo000Qooooo`0300000?oooooooooo02Kooooo0`3o0000
0oooool0o`000?l0000?0?l000;ooooo0`3o000Nooooo`030000Oooooooooooo02[ooooo00<0001o
ooooooooool0:oooool00`0007ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001
ooooo`008Oooool00`00003o0000ooooo`0[oooooaH0o`0000Gooooo0?l0003o0000o`00ooooo`03
0?l000;ooooo0`3o000@ooooo`030000Oooooooooooo02[ooooo00<0001oooooooooool0:oooool0
0`0007ooooooooooo`0[ooooo`030000Oooooooooooo00oooooo0Ol000010000007ooooo000Qoooo
o`0300000?oooooooooo02oooooo0`3o00000oooool0o`000?l0000M0?l000;ooooo0`3o00001?oo
ool0o`000?l0003o0002ooooo`<0o`0000Cooooo0?l0003o0000o`000_ooool30?l000;ooooo0`3o
00001?ooool0o`000?l0003o000Iooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0@ooooo`4000000Oooool0027ooooo00<00000ooooooooool0<?oo
ool0100007oooooooooooooooolo0?l00005ooooo`3o0000o`000?l00?ooool00`3o0002ooooo`<0
o`0000Cooooo0?l0003o0000o`000_ooool30?l000;ooooo00<0001oooooooooool0:oooool00`00
07ooooooooooo`0[ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`0`ooooo`030000Oooooooooooo00Gooooo0`3o0002ooooo`<0o`0000?ooooo0?l0003o
0000BP3o0002ooooo`<0o`000_ooool30?l00004ooooo`3o0000o`000?l000;ooooo0`3o00001?oo
ool0o`000?l0003o000Eooooo`030000Oooooooooooo02_ooooo00<0001oooooooooool04?ooool1
0000007ooooo000Qooooo`0300000?oooooooooo033ooooo00<0001oooooooooool03oooool30?l0
0004ooooo`3o0000o`000?l000;oooooFP3o00001Oooool0o`000?l0003o003ooooo00<0o`000_oo
ool30?l000;ooooo0`3o00001?ooool0o`000?l0003o0002ooooo`<0o`0000Cooooo0?l0003o0000
o`000_ooool30?l00004ooooo`3o0000o`000?l000;ooooo0`3o00001?ooool0o`000?l0003o000A
ooooo`030000Oooooooooooo013ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0`oooo
o`030000Oooooooooooo01cooooo0`3o0002ooooo`<0o`0000Cooooo0?l0003o0000o`000_ooool3
0?l00004ooooo`3o0000o`000?l000;ooooo0`3o0002ooooo`<0o`0000Gooooo0?l0003o0000o`00
ooooo`1T0?l00004ooooo`3o0000o`000?l000;ooooo0`3o00001?ooool0o`000?l0003o0002oooo
o`<0o`0000Cooooo0?l0003o0000o`000_ooool30?l00004ooooo`3o0000o`000?l000Cooooo0@00
0001ooooo`008Oooool00`00003oooooooooo`0`ooooo`030000Oooooooooooo02_ooooo00<0001o
ooooooooool04oooool30?l00004ooooo`3o0000o`000?l000;ooooo0`3o00001?ooool0o`000?l0
003o0002ooooog40o`000oooool10000007ooooo000Qooooo`0300000?l0003ooooo033ooooo00<0
001oooooooooool0:oooool00`0007ooooooooooo`0Yooooo`<0o`000_ooool30?l000;ooooo0`3o
00001?ooool0o`000?l0003o0002ooooo`<0o`0000Gooooo0?l0003o0000o`00ooooo`1B0?l000;o
oooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo033ooooo00<0001oooooooooool0
:oooool00`0007ooooooooooo`0Zooooo`030000Oooooooooooo01Sooooo0`3o00001?ooool0o`00
0?l0003o0002ooooo`<0o`000_ooool30?l00004ooooo`3o0000o`000?l000;ooooo0`3o00001?oo
ool0o`000?l0003o0002ooooo`<0o`0000Cooooo0?l0003o0000o`000_ooool30?l00005ooooo`3o
0000o`000?l00?ooool0803o0003ooooo`4000000Oooool0027ooooo00<00000ooooooooool00ooo
ool00`00003oooooooooo`0Zooooo`0300000?oooooooooo02_ooooo00<00000ooooooooool0:_oo
ool00`00003oooooooooo`0[ooooo`0300000?oooooooooo01cooooo0`3o0002ooooo`<0o`0000Co
oooo0?l0003o0000o`000_ooool30?l00004ooooo`3o0000o`000?l000;ooooo0`3o00001?ooool0
o`000?l0003o0004ooooo`4000000Oooool0027ooooo00<00000ooooooooool00oooool00`00003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00`00003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00<00000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool1o`000040
00000Oooool0027ooooooP000001ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.60146, -9055.93, \
0.219352, 136.147}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EM experiment #2: object 2 (Tide car)", "Subsection"],

Cell[CellGroupData[{

Cell["Extract 2d data", "Subsubsection"],

Cell[BoxData[
    \(\(d2d2 = \((\({#[\([which[\([1]\)]]\)], #[\([which[\([2]\)]]\)]} &\) \
/@ \ \((data2/255. )\))\);\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 4;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull[d2d2, k];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[d2d2, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({3.8900000000000006`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsubsection"],

Cell[BoxData[
    \(\(model2 = \ em\  // \ Last;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Final model", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EMAllPlot[model2, g2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
.5 Mabswid
.1 g
.07692 .06071 m
.09615 .06977 L
.11391 .07692 L
.11538 .07762 L
.13462 .08975 L
.14363 .09615 L
.15385 .10317 L
.16888 .11538 L
.17308 .11844 L
.19161 .13462 L
.19231 .13515 L
.21154 .1521 L
.21364 .15385 L
.23077 .16923 L
.23499 .17308 L
.25 .18676 L
.25553 .19231 L
.26923 .20486 L
.27532 .21154 L
.28846 .22379 L
.29435 .23077 L
.30769 .24384 L
.31251 .25 L
.32692 .26551 L
.32959 .26923 L
.3455 .28846 L
.34615 .2896 L
.36021 .30769 L
.36538 .32049 L
.36845 .32692 L
.36538 .33251 L
.34615 .33034 L
.33738 .32692 L
.32692 .32058 L
.30769 .30956 L
.3048 .30769 L
.28846 .29709 L
.27715 .28846 L
.26923 .28294 L
.25296 .26923 L
.25 .26709 L
.23077 .25002 L
.23074 .25 L
.21154 .23311 L
.20874 .23077 L
.19231 .21577 L
.18772 .21154 L
.17308 .1979 L
.16757 .19231 L
.15385 .17924 L
.14828 .17308 L
.13462 .15947 L
.12995 .15385 L
.11538 .13813 L
.11272 .13462 L
.09733 .11538 L
.09615 .11456 L
.08548 .09615 L
.07692 .08704 L
.07289 .07692 L
F
0 g
.07692 .06071 m
.09615 .06977 L
.11391 .07692 L
.11538 .07762 L
.13462 .08975 L
.14363 .09615 L
.15385 .10317 L
.16888 .11538 L
.17308 .11844 L
.19161 .13462 L
.19231 .13515 L
.21154 .1521 L
.21364 .15385 L
.23077 .16923 L
.23499 .17308 L
.25 .18676 L
.25553 .19231 L
.26923 .20486 L
.27532 .21154 L
.28846 .22379 L
.29435 .23077 L
.30769 .24384 L
.31251 .25 L
.32692 .26551 L
.32959 .26923 L
.3455 .28846 L
.34615 .2896 L
.36021 .30769 L
.36538 .32049 L
.36845 .32692 L
.36538 .33251 L
.34615 .33034 L
.33738 .32692 L
.32692 .32058 L
.30769 .30956 L
.3048 .30769 L
.28846 .29709 L
.27715 .28846 L
.26923 .28294 L
.25296 .26923 L
.25 .26709 L
.23077 .25002 L
.23074 .25 L
.21154 .23311 L
.20874 .23077 L
.19231 .21577 L
.18772 .21154 L
.17308 .1979 L
.16757 .19231 L
.15385 .17924 L
Mistroke
.14828 .17308 L
.13462 .15947 L
.12995 .15385 L
.11538 .13813 L
.11272 .13462 L
.09733 .11538 L
.09615 .11456 L
.08548 .09615 L
.07692 .08704 L
.07289 .07692 L
.07692 .06071 L
Mfstroke
.2 g
.09615 .08748 m
.11538 .08751 L
.12889 .09615 L
.13462 .09909 L
.15385 .11236 L
.15795 .11538 L
.17308 .12605 L
.18334 .13462 L
.19231 .14145 L
.20614 .15385 L
.21154 .15825 L
.22737 .17308 L
.23077 .17607 L
.24751 .19231 L
.25 .19834 L
.26674 .21154 L
.26923 .21655 L
.28501 .23077 L
.28846 .2349 L
.30199 .25 L
.30769 .25789 L
.31686 .26923 L
.32692 .28813 L
.3271 .28846 L
.32692 .29641 L
.30769 .29755 L
.29331 .28846 L
.28846 .28603 L
.26923 .27315 L
.26401 .26923 L
.25 .25945 L
.2388 .25 L
.23077 .24395 L
.21612 .23077 L
.21154 .22707 L
.19496 .21154 L
.19231 .20922 L
.17739 .19231 L
.17308 .18833 L
.15811 .17308 L
.15385 .17018 L
.14081 .15385 L
.13462 .15046 L
.1253 .13462 L
.11538 .1275 L
.11051 .11538 L
.09615 .09757 L
.09562 .09615 L
F
0 g
.09615 .08748 m
.11538 .08751 L
.12889 .09615 L
.13462 .09909 L
.15385 .11236 L
.15795 .11538 L
.17308 .12605 L
.18334 .13462 L
.19231 .14145 L
.20614 .15385 L
.21154 .15825 L
.22737 .17308 L
.23077 .17607 L
.24751 .19231 L
.25 .19834 L
.26674 .21154 L
.26923 .21655 L
.28501 .23077 L
.28846 .2349 L
.30199 .25 L
.30769 .25789 L
.31686 .26923 L
.32692 .28813 L
.3271 .28846 L
.32692 .29641 L
.30769 .29755 L
.29331 .28846 L
.28846 .28603 L
.26923 .27315 L
.26401 .26923 L
.25 .25945 L
.2388 .25 L
.23077 .24395 L
.21612 .23077 L
.21154 .22707 L
.19496 .21154 L
.19231 .20922 L
.17739 .19231 L
.17308 .18833 L
.15811 .17308 L
.15385 .17018 L
.14081 .15385 L
.13462 .15046 L
.1253 .13462 L
.11538 .1275 L
.11051 .11538 L
.09615 .09757 L
.09562 .09615 L
.09615 .08748 L
s
.3 g
.11538 .09904 m
.13462 .10505 L
.14965 .11538 L
.15385 .11783 L
.17308 .13177 L
.17664 .13462 L
.19231 .14643 L
.20072 .15385 L
.21154 .16272 L
.22258 .17308 L
.23077 .18037 L
.24292 .19231 L
.25 .20622 L
.26196 .21154 L
.26923 .22203 L
.27958 .23077 L
.28846 .24191 L
.29518 .25 L
.30698 .26923 L
.28846 .27937 L
.27313 .26923 L
.26923 .26704 L
.25 .25359 L
.24551 .25 L
.23077 .23906 L
.22136 .23077 L
.21154 .22282 L
.19946 .21154 L
.19231 .20524 L
.18549 .19231 L
.17308 .18139 L
.16602 .17308 L
.15385 .16679 L
.14823 .15385 L
.13462 .14448 L
.1313 .13462 L
.11538 .11766 L
.11459 .11538 L
F
0 g
.11538 .09904 m
.13462 .10505 L
.14965 .11538 L
.15385 .11783 L
.17308 .13177 L
.17664 .13462 L
.19231 .14643 L
.20072 .15385 L
.21154 .16272 L
.22258 .17308 L
.23077 .18037 L
.24292 .19231 L
.25 .20622 L
.26196 .21154 L
.26923 .22203 L
.27958 .23077 L
.28846 .24191 L
.29518 .25 L
.30698 .26923 L
.28846 .27937 L
.27313 .26923 L
.26923 .26704 L
.25 .25359 L
.24551 .25 L
.23077 .23906 L
.22136 .23077 L
.21154 .22282 L
.19946 .21154 L
.19231 .20524 L
.18549 .19231 L
.17308 .18139 L
.16602 .17308 L
.15385 .16679 L
.14823 .15385 L
.13462 .14448 L
.1313 .13462 L
.11538 .11766 L
.11459 .11538 L
.11538 .09904 L
s
.4 g
.13462 .11127 m
.14147 .11538 L
.15385 .12198 L
.17093 .13462 L
.17308 .13605 L
.19231 .15078 L
.19585 .15385 L
.21154 .16673 L
.21832 .17308 L
.23077 .18429 L
.23884 .19231 L
.25 .20942 L
.25769 .21154 L
.26923 .22446 L
.27466 .23077 L
.28846 .24963 L
.28873 .25 L
.29608 .26923 L
.28846 .27217 L
.28295 .26923 L
.26923 .26249 L
.25165 .25 L
.25 .24893 L
.23077 .23473 L
.22617 .23077 L
.21154 .21898 L
.20353 .21154 L
.19231 .20159 L
.18988 .19231 L
.17308 .17806 L
.17026 .17308 L
.15385 .16549 L
.15165 .15385 L
.13462 .1382 L
.13357 .13462 L
.12332 .11538 L
F
0 g
.13462 .11127 m
.14147 .11538 L
.15385 .12198 L
.17093 .13462 L
.17308 .13605 L
.19231 .15078 L
.19585 .15385 L
.21154 .16673 L
.21832 .17308 L
.23077 .18429 L
.23884 .19231 L
.25 .20942 L
.25769 .21154 L
.26923 .22446 L
.27466 .23077 L
.28846 .24963 L
.28873 .25 L
.29608 .26923 L
.28846 .27217 L
.28295 .26923 L
.26923 .26249 L
.25165 .25 L
.25 .24893 L
.23077 .23473 L
.22617 .23077 L
.21154 .21898 L
.20353 .21154 L
.19231 .20159 L
.18988 .19231 L
.17308 .17806 L
.17026 .17308 L
.15385 .16549 L
.15165 .15385 L
.13462 .1382 L
.13357 .13462 L
.12332 .11538 L
.13462 .11127 L
s
.5 g
.15385 .12619 m
.16578 .13462 L
.17308 .13934 L
.1914 .15385 L
.19231 .15455 L
.21154 .17048 L
.21432 .17308 L
.23077 .18803 L
.23502 .19231 L
.25 .21042 L
.25367 .21154 L
.26923 .2295 L
.26991 .23077 L
.28255 .25 L
.26923 .25781 L
.25748 .25 L
.25 .24541 L
.23084 .23077 L
.23077 .23072 L
.21154 .21535 L
.20742 .21154 L
.19231 .19809 L
.19172 .19231 L
.17308 .17644 L
.17208 .17308 L
.15385 .1613 L
.15304 .15385 L
.13761 .13462 L
F
0 g
.15385 .12619 m
.16578 .13462 L
.17308 .13934 L
.1914 .15385 L
.19231 .15455 L
.21154 .17048 L
.21432 .17308 L
.23077 .18803 L
.23502 .19231 L
.25 .21042 L
.25367 .21154 L
.26923 .2295 L
.26991 .23077 L
.28255 .25 L
.26923 .25781 L
.25748 .25 L
.25 .24541 L
.23084 .23077 L
.23077 .23072 L
.21154 .21535 L
.20742 .21154 L
.19231 .19809 L
.19172 .19231 L
.17308 .17644 L
.17208 .17308 L
.15385 .1613 L
.15304 .15385 L
.13761 .13462 L
.15385 .12619 L
s
.6 g
.15385 .13085 m
.15977 .13462 L
.17308 .14263 L
.18753 .15385 L
.19231 .15748 L
.2106 .17308 L
.21154 .17393 L
.23077 .19175 L
.23131 .19231 L
.24976 .21154 L
.25 .21185 L
.26552 .23077 L
.26923 .23789 L
.27454 .25 L
.26923 .25232 L
.26496 .25 L
.25 .24185 L
.23506 .23077 L
.23077 .22764 L
.21154 .2118 L
.21126 .21154 L
.19231 .19461 L
.19219 .19231 L
.17308 .17466 L
.17276 .17308 L
.15508 .15385 L
.15385 .15175 L
.14451 .13462 L
F
0 g
.15385 .13085 m
.15977 .13462 L
.17308 .14263 L
.18753 .15385 L
.19231 .15748 L
.2106 .17308 L
.21154 .17393 L
.23077 .19175 L
.23131 .19231 L
.24976 .21154 L
.25 .21185 L
.26552 .23077 L
.26923 .23789 L
.27454 .25 L
.26923 .25232 L
.26496 .25 L
.25 .24185 L
.23506 .23077 L
.23077 .22764 L
.21154 .2118 L
.21126 .21154 L
.19231 .19461 L
.19219 .19231 L
.17308 .17466 L
.17276 .17308 L
.15508 .15385 L
.15385 .15175 L
.14451 .13462 L
.15385 .13085 L
s
.7 g
.17308 .14611 m
.18341 .15385 L
.19231 .16044 L
.20727 .17308 L
.21154 .17691 L
.22804 .19231 L
.23077 .19524 L
.24624 .21154 L
.25 .21668 L
.26079 .23077 L
.25 .238 L
.2397 .23077 L
.23077 .22451 L
.21482 .21154 L
.21154 .2087 L
.19348 .19231 L
.19231 .19109 L
.1748 .17308 L
.17308 .17083 L
.15959 .15385 L
F
0 g
.17308 .14611 m
.18341 .15385 L
.19231 .16044 L
.20727 .17308 L
.21154 .17691 L
.22804 .19231 L
.23077 .19524 L
.24624 .21154 L
.25 .21668 L
.26079 .23077 L
.25 .238 L
.2397 .23077 L
.23077 .22451 L
.21482 .21154 L
.21154 .2087 L
.19348 .19231 L
.19231 .19109 L
.1748 .17308 L
.17308 .17083 L
.15959 .15385 L
.17308 .14611 L
s
.8 g
.17308 .15008 m
.17851 .15385 L
.19231 .16356 L
.20376 .17308 L
.21154 .18001 L
.22473 .19231 L
.23077 .19894 L
.24249 .21154 L
.25 .2232 L
.25462 .23077 L
.25 .23334 L
.24571 .23077 L
.23077 .22118 L
.2186 .21154 L
.21154 .20551 L
.1969 .19231 L
.19231 .18745 L
.17854 .17308 L
.17308 .16528 L
.16513 .15385 L
F
0 g
.17308 .15008 m
.17851 .15385 L
.19231 .16356 L
.20376 .17308 L
.21154 .18001 L
.22473 .19231 L
.23077 .19894 L
.24249 .21154 L
.25 .2232 L
.25462 .23077 L
.25 .23334 L
.24571 .23077 L
.23077 .22118 L
.2186 .21154 L
.21154 .20551 L
.1969 .19231 L
.19231 .18745 L
.17854 .17308 L
.17308 .16528 L
.16513 .15385 L
.17308 .15008 L
s
.9 g
.19231 .16705 m
.19979 .17308 L
.21154 .18341 L
.2211 .19231 L
.23077 .20329 L
.23813 .21154 L
.23077 .21736 L
.22303 .21154 L
.21154 .202 L
.20069 .19231 L
.19231 .18324 L
.18284 .17308 L
F
0 g
.19231 .16705 m
.19979 .17308 L
.21154 .18341 L
.2211 .19231 L
.23077 .20329 L
.23813 .21154 L
.23077 .21736 L
.22303 .21154 L
.21154 .202 L
.20069 .19231 L
.19231 .18324 L
.18284 .17308 L
.19231 .16705 L
s
1 g
.19231 .17153 m
.19443 .17308 L
.21154 .18753 L
.2167 .19231 L
.23077 .21062 L
.23137 .21154 L
.23077 .21192 L
.23008 .21154 L
.21154 .19768 L
.20537 .19231 L
.19231 .17706 L
.18903 .17308 L
F
0 g
.19231 .17153 m
.19443 .17308 L
.21154 .18753 L
.2167 .19231 L
.23077 .21062 L
.23137 .21154 L
.23077 .21192 L
.23008 .21154 L
.21154 .19768 L
.20537 .19231 L
.19231 .17706 L
.18903 .17308 L
.19231 .17153 L
s
.1 g
.46154 .28318 m
.48077 .28194 L
.5 .28568 L
.51211 .28846 L
.51923 .29228 L
.53846 .30106 L
.55118 .30769 L
.55769 .31157 L
.57692 .32359 L
.58193 .32692 L
.59615 .33698 L
.60837 .34615 L
.61538 .3517 L
.63187 .36538 L
.63462 .36777 L
.6532 .38462 L
.65385 .38523 L
.67274 .40385 L
.67308 .4042 L
.69069 .42308 L
.69231 .42487 L
.70714 .44231 L
.71154 .44769 L
.72206 .46154 L
.73077 .47368 L
.73539 .48077 L
.74699 .5 L
.75 .50488 L
.7566 .51923 L
.76383 .53846 L
.76769 .55769 L
.76612 .57692 L
.75 .59345 L
.73077 .59535 L
.71154 .59231 L
.69231 .58605 L
.67308 .57753 L
.6718 .57692 L
.65385 .5673 L
.63793 .55769 L
.63462 .55549 L
.61538 .5423 L
.6101 .53846 L
.59615 .52779 L
.58555 .51923 L
.57692 .51194 L
.56343 .5 L
.55769 .49471 L
.54325 .48077 L
.53846 .47597 L
.52474 .46154 L
.51923 .45551 L
.50778 .44231 L
.5 .43291 L
.49232 .42308 L
.48077 .40732 L
.4784 .40385 L
.4661 .38462 L
.46154 .3772 L
.4557 .36538 L
.44735 .34615 L
.44231 .32844 L
.44201 .32692 L
.44116 .30769 L
.44231 .30236 L
.45138 .28846 L
F
0 g
.46154 .28318 m
.48077 .28194 L
.5 .28568 L
.51211 .28846 L
.51923 .29228 L
.53846 .30106 L
.55118 .30769 L
.55769 .31157 L
.57692 .32359 L
.58193 .32692 L
.59615 .33698 L
.60837 .34615 L
.61538 .3517 L
.63187 .36538 L
.63462 .36777 L
.6532 .38462 L
.65385 .38523 L
.67274 .40385 L
.67308 .4042 L
.69069 .42308 L
.69231 .42487 L
.70714 .44231 L
.71154 .44769 L
.72206 .46154 L
.73077 .47368 L
.73539 .48077 L
.74699 .5 L
.75 .50488 L
.7566 .51923 L
.76383 .53846 L
.76769 .55769 L
.76612 .57692 L
.75 .59345 L
.73077 .59535 L
.71154 .59231 L
.69231 .58605 L
.67308 .57753 L
.6718 .57692 L
.65385 .5673 L
.63793 .55769 L
.63462 .55549 L
.61538 .5423 L
.6101 .53846 L
.59615 .52779 L
.58555 .51923 L
.57692 .51194 L
.56343 .5 L
.55769 .49471 L
.54325 .48077 L
.53846 .47597 L
Mistroke
.52474 .46154 L
.51923 .45551 L
.50778 .44231 L
.5 .43291 L
.49232 .42308 L
.48077 .40732 L
.4784 .40385 L
.4661 .38462 L
.46154 .3772 L
.4557 .36538 L
.44735 .34615 L
.44231 .32844 L
.44201 .32692 L
.44116 .30769 L
.44231 .30236 L
.45138 .28846 L
.46154 .28318 L
Mfstroke
.1 g
.82692 .287 m
.84615 .28606 L
.86384 .28846 L
.86538 .28889 L
.88462 .29672 L
.90385 .30727 L
.90461 .30769 L
.92308 .32303 L
.92719 .32692 L
.94231 .34375 L
.94387 .34615 L
.95637 .36538 L
.96154 .37427 L
.96651 .38462 L
.97296 .40385 L
.97616 .42308 L
.97614 .44231 L
.97201 .46154 L
.96163 .48077 L
.96154 .48088 L
.94231 .49683 L
.9355 .5 L
.92308 .5028 L
.90385 .50343 L
.88462 .50084 L
.87783 .5 L
.86538 .49437 L
.84615 .48319 L
.84124 .48077 L
.82692 .46919 L
.81984 .46154 L
.80769 .4495 L
.80129 .44231 L
.79042 .42308 L
.78846 .41979 L
.78201 .40385 L
.77932 .38462 L
.7761 .36538 L
.77684 .34615 L
.78158 .32692 L
.78846 .31185 L
.79176 .30769 L
.80769 .29412 L
.82037 .28846 L
F
0 g
.82692 .287 m
.84615 .28606 L
.86384 .28846 L
.86538 .28889 L
.88462 .29672 L
.90385 .30727 L
.90461 .30769 L
.92308 .32303 L
.92719 .32692 L
.94231 .34375 L
.94387 .34615 L
.95637 .36538 L
.96154 .37427 L
.96651 .38462 L
.97296 .40385 L
.97616 .42308 L
.97614 .44231 L
.97201 .46154 L
.96163 .48077 L
.96154 .48088 L
.94231 .49683 L
.9355 .5 L
.92308 .5028 L
.90385 .50343 L
.88462 .50084 L
.87783 .5 L
.86538 .49437 L
.84615 .48319 L
.84124 .48077 L
.82692 .46919 L
.81984 .46154 L
.80769 .4495 L
.80129 .44231 L
.79042 .42308 L
.78846 .41979 L
.78201 .40385 L
.77932 .38462 L
.7761 .36538 L
.77684 .34615 L
.78158 .32692 L
.78846 .31185 L
.79176 .30769 L
.80769 .29412 L
.82037 .28846 L
.82692 .287 L
s
.1 g
.98077 .94362 m
.96154 .94743 L
.94231 .94633 L
.92998 .94231 L
.92308 .93882 L
.90385 .93077 L
.89147 .92308 L
.88462 .91938 L
.86538 .90553 L
.86319 .90385 L
.84615 .88977 L
.84066 .88462 L
.82692 .86821 L
.82199 .86538 L
.80769 .84711 L
.8067 .84615 L
.79624 .82692 L
.78846 .81225 L
.78771 .80769 L
.78603 .78846 L
.78846 .78149 L
.80769 .77093 L
.82692 .77325 L
.84615 .77768 L
.86538 .78681 L
.86801 .78846 L
.88462 .79766 L
.8983 .80769 L
.90385 .81093 L
.92308 .8267 L
.92334 .82692 L
.94231 .84478 L
.94359 .84615 L
.96018 .86538 L
.96154 .86684 L
.9749 .88462 L
.98077 .89392 L
F
0 g
.98077 .94362 m
.96154 .94743 L
.94231 .94633 L
.92998 .94231 L
.92308 .93882 L
.90385 .93077 L
.89147 .92308 L
.88462 .91938 L
.86538 .90553 L
.86319 .90385 L
.84615 .88977 L
.84066 .88462 L
.82692 .86821 L
.82199 .86538 L
.80769 .84711 L
.8067 .84615 L
.79624 .82692 L
.78846 .81225 L
.78771 .80769 L
.78603 .78846 L
.78846 .78149 L
.80769 .77093 L
.82692 .77325 L
.84615 .77768 L
.86538 .78681 L
.86801 .78846 L
.88462 .79766 L
.8983 .80769 L
.90385 .81093 L
.92308 .8267 L
.92334 .82692 L
.94231 .84478 L
.94359 .84615 L
.96018 .86538 L
.96154 .86684 L
.9749 .88462 L
.98077 .89392 L
s
.2 g
.82692 .31794 m
.84615 .31256 L
.86538 .31429 L
.88462 .32139 L
.89529 .32692 L
.90385 .33351 L
.9178 .34615 L
.92308 .35207 L
.93267 .36538 L
.94231 .38244 L
.94311 .38462 L
.9491 .40385 L
.95145 .42308 L
.9489 .44231 L
.94231 .45746 L
.93891 .46154 L
.92308 .47168 L
.90385 .47526 L
.88462 .47238 L
.86538 .4645 L
.85967 .46154 L
.84615 .4513 L
.83652 .44231 L
.82692 .43125 L
.82158 .42308 L
.81101 .40385 L
.80769 .39911 L
.80507 .38462 L
.80285 .36538 L
.80519 .34615 L
.80769 .33693 L
.81501 .32692 L
F
0 g
.82692 .31794 m
.84615 .31256 L
.86538 .31429 L
.88462 .32139 L
.89529 .32692 L
.90385 .33351 L
.9178 .34615 L
.92308 .35207 L
.93267 .36538 L
.94231 .38244 L
.94311 .38462 L
.9491 .40385 L
.95145 .42308 L
.9489 .44231 L
.94231 .45746 L
.93891 .46154 L
.92308 .47168 L
.90385 .47526 L
.88462 .47238 L
.86538 .4645 L
.85967 .46154 L
.84615 .4513 L
.83652 .44231 L
.82692 .43125 L
.82158 .42308 L
.81101 .40385 L
.80769 .39911 L
.80507 .38462 L
.80285 .36538 L
.80519 .34615 L
.80769 .33693 L
.81501 .32692 L
.82692 .31794 L
s
.2 g
.82692 .79179 m
.84615 .79731 L
.86538 .80587 L
.87462 .80769 L
.88462 .81505 L
.90381 .82692 L
.90385 .82696 L
.92308 .84468 L
.92509 .84615 L
.94231 .86408 L
.94302 .86538 L
.95631 .88462 L
.96154 .89505 L
.96369 .90385 L
.96154 .92175 L
.96045 .92308 L
.94231 .9281 L
.92308 .92382 L
.91649 .92308 L
.90385 .91533 L
.88462 .90528 L
.88289 .90385 L
.86538 .88923 L
.85879 .88462 L
.84615 .87276 L
.8397 .86538 L
.82692 .85139 L
.82452 .84615 L
.81368 .82692 L
.80851 .80769 L
F
0 g
.82692 .79179 m
.84615 .79731 L
.86538 .80587 L
.87462 .80769 L
.88462 .81505 L
.90381 .82692 L
.90385 .82696 L
.92308 .84468 L
.92509 .84615 L
.94231 .86408 L
.94302 .86538 L
.95631 .88462 L
.96154 .89505 L
.96369 .90385 L
.96154 .92175 L
.96045 .92308 L
.94231 .9281 L
.92308 .92382 L
.91649 .92308 L
.90385 .91533 L
.88462 .90528 L
.88289 .90385 L
.86538 .88923 L
.85879 .88462 L
.84615 .87276 L
.8397 .86538 L
.82692 .85139 L
.82452 .84615 L
.81368 .82692 L
.80851 .80769 L
.82692 .79179 L
s
.3 g
.84615 .3323 m
.86538 .33188 L
.88462 .33874 L
.89762 .34615 L
.90385 .35235 L
.91569 .36538 L
.92308 .37594 L
.92703 .38462 L
.9333 .40385 L
.93425 .42308 L
.92714 .44231 L
.92308 .4469 L
.90385 .45572 L
.88462 .4542 L
.86538 .4458 L
.85956 .44231 L
.84615 .43023 L
.84005 .42308 L
.82811 .40385 L
.82692 .40113 L
.82181 .38462 L
.82059 .36538 L
.82692 .34646 L
.82713 .34615 L
F
0 g
.84615 .3323 m
.86538 .33188 L
.88462 .33874 L
.89762 .34615 L
.90385 .35235 L
.91569 .36538 L
.92308 .37594 L
.92703 .38462 L
.9333 .40385 L
.93425 .42308 L
.92714 .44231 L
.92308 .4469 L
.90385 .45572 L
.88462 .4542 L
.86538 .4458 L
.85956 .44231 L
.84615 .43023 L
.84005 .42308 L
.82811 .40385 L
.82692 .40113 L
.82181 .38462 L
.82059 .36538 L
.82692 .34646 L
.82713 .34615 L
.84615 .3323 L
s
.3 g
.84615 .80897 m
.86538 .81365 L
.88462 .82453 L
.89006 .82692 L
.90385 .83752 L
.91439 .84615 L
.92308 .8534 L
.93218 .86538 L
.94231 .8798 L
.94459 .88462 L
.95053 .90385 L
.94231 .91249 L
.92308 .91454 L
.90385 .90616 L
.89664 .90385 L
.88462 .8955 L
.86918 .88462 L
.86538 .88192 L
.84928 .86538 L
.84615 .86171 L
.83496 .84615 L
.82712 .82692 L
F
0 g
.84615 .80897 m
.86538 .81365 L
.88462 .82453 L
.89006 .82692 L
.90385 .83752 L
.91439 .84615 L
.92308 .8534 L
.93218 .86538 L
.94231 .8798 L
.94459 .88462 L
.95053 .90385 L
.94231 .91249 L
.92308 .91454 L
.90385 .90616 L
.89664 .90385 L
.88462 .8955 L
.86918 .88462 L
.86538 .88192 L
.84928 .86538 L
.84615 .86171 L
.83496 .84615 L
.82712 .82692 L
.84615 .80897 L
s
.4 g
.84615 .3538 m
.86538 .34791 L
.88462 .3544 L
.9024 .36538 L
.90385 .36909 L
.91279 .38462 L
.91936 .40385 L
.92088 .42308 L
.90385 .43862 L
.88462 .4382 L
.86538 .42907 L
.85691 .42308 L
.84615 .40937 L
.84345 .40385 L
.83638 .38462 L
.83668 .36538 L
F
0 g
.84615 .3538 m
.86538 .34791 L
.88462 .3544 L
.9024 .36538 L
.90385 .36909 L
.91279 .38462 L
.91936 .40385 L
.92088 .42308 L
.90385 .43862 L
.88462 .4382 L
.86538 .42907 L
.85691 .42308 L
.84615 .40937 L
.84345 .40385 L
.83638 .38462 L
.83668 .36538 L
.84615 .3538 L
s
.4 g
.84615 .8229 m
.86538 .82276 L
.87461 .82692 L
.88462 .832 L
.90385 .84579 L
.90429 .84615 L
.92293 .86538 L
.92308 .86559 L
.93788 .88462 L
.92308 .90261 L
.90385 .89818 L
.88462 .88754 L
.87985 .88462 L
.86538 .87395 L
.8586 .86538 L
.84615 .84813 L
.84503 .84615 L
.8421 .82692 L
F
0 g
.84615 .8229 m
.86538 .82276 L
.87461 .82692 L
.88462 .832 L
.90385 .84579 L
.90429 .84615 L
.92293 .86538 L
.92308 .86559 L
.93788 .88462 L
.92308 .90261 L
.90385 .89818 L
.88462 .88754 L
.87985 .88462 L
.86538 .87395 L
.8586 .86538 L
.84615 .84813 L
.84503 .84615 L
.8421 .82692 L
.84615 .8229 L
s
.5 g
.86538 .36901 m
.88462 .37417 L
.89444 .38462 L
.90026 .40385 L
.88462 .41816 L
.86538 .40805 L
.86188 .40385 L
.85497 .38462 L
F
0 g
.86538 .36901 m
.88462 .37417 L
.89444 .38462 L
.90026 .40385 L
.88462 .41816 L
.86538 .40805 L
.86188 .40385 L
.85497 .38462 L
.86538 .36901 L
s
.5 g
.86538 .83429 m
.88462 .84066 L
.89293 .84615 L
.90385 .85537 L
.91297 .86538 L
.92032 .88462 L
.90385 .88888 L
.89412 .88462 L
.88462 .87884 L
.86886 .86538 L
.86538 .86118 L
.85638 .84615 L
F
0 g
.86538 .83429 m
.88462 .84066 L
.89293 .84615 L
.90385 .85537 L
.91297 .86538 L
.92032 .88462 L
.90385 .88888 L
.89412 .88462 L
.88462 .87884 L
.86886 .86538 L
.86538 .86118 L
.85638 .84615 L
.86538 .83429 L
s
.6 g
.88462 .85472 m
.89772 .86538 L
.88462 .86647 L
.8833 .86538 L
F
0 g
.88462 .85472 m
.89772 .86538 L
.88462 .86647 L
.8833 .86538 L
.88462 .85472 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.664 .741 .908 r
.39902 .59803 .40512 .60371 .41537 .60064 .40929 .59494 Mtetra
.40929 .59494 .41537 .60064 .42565 .59755 .4196 .59183 Mtetra
.4196 .59183 .42565 .59755 .43597 .59446 .42994 .58871 Mtetra
.42994 .58871 .43597 .59446 .44633 .59135 .44033 .58558 Mtetra
.44033 .58558 .44633 .59135 .45674 .58823 .45076 .58244 Mtetra
.45076 .58244 .45674 .58823 .46718 .5851 .46122 .57928 Mtetra
.46122 .57928 .46718 .5851 .47766 .58195 .47173 .57611 Mtetra
.47173 .57611 .47766 .58195 .48818 .57879 .48228 .57294 Mtetra
.48228 .57294 .48818 .57879 .49874 .57563 .49287 .56974 Mtetra
.49287 .56974 .49874 .57563 .50935 .57244 .5035 .56654 Mtetra
.5035 .56654 .50935 .57244 .51999 .56925 .51417 .56332 Mtetra
.51417 .56332 .51999 .56925 .53068 .56605 .52489 .56009 Mtetra
.52489 .56009 .53068 .56605 .54141 .56283 .53564 .55685 Mtetra
.53564 .55685 .54141 .56283 .55218 .5596 .54644 .5536 Mtetra
.54644 .5536 .55218 .5596 .56299 .55635 .55728 .55033 Mtetra
.55728 .55033 .56299 .55635 .57385 .5531 .56816 .54705 Mtetra
.56816 .54705 .57385 .5531 .58474 .54983 .57909 .54376 Mtetra
.57909 .54376 .58474 .54983 .59568 .54654 .59006 .54045 Mtetra
.59006 .54045 .59568 .54654 .60667 .54325 .60107 .53713 Mtetra
.60107 .53713 .60667 .54325 .61769 .53994 .61213 .5338 Mtetra
.61213 .5338 .61769 .53994 .62876 .53662 .62323 .53045 Mtetra
.62323 .53045 .62876 .53662 .63988 .53329 .63437 .5271 Mtetra
.63437 .5271 .63988 .53329 .65104 .52994 .64556 .52372 Mtetra
.64556 .52372 .65104 .52994 .66224 .52658 .65679 .52034 Mtetra
.65679 .52034 .66224 .52658 .67349 .5232 .66807 .51694 Mtetra
.66807 .51694 .67349 .5232 .68478 .51982 .67939 .51353 Mtetra
.67939 .51353 .68478 .51982 .69612 .51641 .69076 .5101 Mtetra
.69076 .5101 .69612 .51641 .7075 .513 .70218 .50666 Mtetra
.70218 .50666 .7075 .513 .71893 .50957 .71364 .5032 Mtetra
.71364 .5032 .71893 .50957 .73041 .50613 .72515 .49974 Mtetra
.72515 .49974 .73041 .50613 .74193 .50267 .7367 .49625 Mtetra
.7367 .49625 .74193 .50267 .7535 .4992 .7483 .49276 Mtetra
.7483 .49276 .7535 .4992 .76511 .49572 .75995 .48925 Mtetra
.663 .741 .908 r
.75995 .48925 .76511 .49572 .77677 .49222 .77165 .48573 Mtetra
.77165 .48573 .77677 .49222 .78848 .48871 .78339 .48219 Mtetra
.78339 .48219 .78848 .48871 .80024 .48518 .79518 .47864 Mtetra
.79518 .47864 .80024 .48518 .81205 .48165 .80702 .47508 Mtetra
.80702 .47508 .81205 .48165 .8239 .47809 .81891 .4715 Mtetra
.663 .742 .908 r
.81891 .4715 .8239 .47809 .8358 .47453 .83085 .46792 Mtetra
.83085 .46792 .8358 .47453 .84776 .47095 .84284 .46432 Mtetra
.663 .742 .909 r
.84284 .46432 .84776 .47095 .85976 .46737 .85488 .46071 Mtetra
.85488 .46071 .85976 .46737 .87181 .46377 .86697 .45709 Mtetra
.662 .742 .909 r
.86697 .45709 .87181 .46377 .88391 .46016 .87911 .45347 Mtetra
.661 .742 .91 r
.87911 .45347 .88391 .46016 .89607 .45654 .8913 .44987 Mtetra
.656 .742 .913 r
.8913 .44987 .89607 .45654 .90827 .45292 .90357 .4464 Mtetra
.641 .741 .922 r
.90357 .4464 .90827 .45292 .92054 .44934 .91594 .44337 Mtetra
.603 .745 .945 r
.91594 .44337 .92054 .44934 .93288 .44591 .92848 .44122 Mtetra
.537 .768 .983 r
.92848 .44122 .93288 .44591 .9453 .44275 .94119 .43986 Mtetra
.473 .82 .998 r
.94119 .43986 .9453 .44275 .95781 .4398 .95392 .43814 Mtetra
.515 .889 .969 r
.95392 .43814 .95781 .4398 .97036 .43664 .96646 .43452 Mtetra
.664 .741 .908 r
.39287 .59231 .39902 .59803 .40929 .59494 .40317 .58919 Mtetra
.40317 .58919 .40929 .59494 .4196 .59183 .4135 .58606 Mtetra
.4135 .58606 .4196 .59183 .42994 .58871 .42387 .58292 Mtetra
.42387 .58292 .42994 .58871 .44033 .58558 .43428 .57977 Mtetra
.43428 .57977 .44033 .58558 .45076 .58244 .44474 .5766 Mtetra
.44474 .5766 .45076 .58244 .46122 .57928 .45523 .57342 Mtetra
.45523 .57342 .46122 .57928 .47173 .57611 .46576 .57024 Mtetra
.46576 .57024 .47173 .57611 .48228 .57294 .47634 .56703 Mtetra
.47634 .56703 .48228 .57294 .49287 .56974 .48695 .56382 Mtetra
.48695 .56382 .49287 .56974 .5035 .56654 .49761 .56059 Mtetra
.49761 .56059 .5035 .56654 .51417 .56332 .50831 .55735 Mtetra
.50831 .55735 .51417 .56332 .52489 .56009 .51905 .5541 Mtetra
.51905 .5541 .52489 .56009 .53564 .55685 .52983 .55083 Mtetra
.52983 .55083 .53564 .55685 .54644 .5536 .54066 .54756 Mtetra
.54066 .54756 .54644 .5536 .55728 .55033 .55153 .54426 Mtetra
.55153 .54426 .55728 .55033 .56816 .54705 .56244 .54096 Mtetra
.56244 .54096 .56816 .54705 .57909 .54376 .57339 .53764 Mtetra
.57339 .53764 .57909 .54376 .59006 .54045 .58439 .53431 Mtetra
.58439 .53431 .59006 .54045 .60107 .53713 .59543 .53097 Mtetra
.59543 .53097 .60107 .53713 .61213 .5338 .60652 .52761 Mtetra
.60652 .52761 .61213 .5338 .62323 .53045 .61765 .52424 Mtetra
.61765 .52424 .62323 .53045 .63437 .5271 .62882 .52086 Mtetra
.62882 .52086 .63437 .5271 .64556 .52372 .64004 .51746 Mtetra
.64004 .51746 .64556 .52372 .65679 .52034 .6513 .51405 Mtetra
.6513 .51405 .65679 .52034 .66807 .51694 .66261 .51063 Mtetra
.66261 .51063 .66807 .51694 .67939 .51353 .67397 .50719 Mtetra
.67397 .50719 .67939 .51353 .69076 .5101 .68537 .50374 Mtetra
.68537 .50374 .69076 .5101 .70218 .50666 .69682 .50027 Mtetra
.69682 .50027 .70218 .50666 .71364 .5032 .70831 .49679 Mtetra
.70831 .49679 .71364 .5032 .72515 .49974 .71985 .4933 Mtetra
.71985 .4933 .72515 .49974 .7367 .49625 .73144 .48979 Mtetra
.663 .741 .908 r
.73144 .48979 .7367 .49625 .7483 .49276 .74307 .48627 Mtetra
.74307 .48627 .7483 .49276 .75995 .48925 .75475 .48273 Mtetra
.75475 .48273 .75995 .48925 .77165 .48573 .76648 .47918 Mtetra
.76648 .47918 .77165 .48573 .78339 .48219 .77826 .47562 Mtetra
.77826 .47562 .78339 .48219 .79518 .47864 .79008 .47205 Mtetra
.79008 .47205 .79518 .47864 .80702 .47508 .80196 .46847 Mtetra
.663 .742 .908 r
.80196 .46847 .80702 .47508 .81891 .4715 .81389 .46487 Mtetra
.663 .742 .909 r
.81389 .46487 .81891 .4715 .83085 .46792 .82586 .46126 Mtetra
.82586 .46126 .83085 .46792 .84284 .46432 .83789 .45765 Mtetra
.662 .742 .909 r
.83789 .45765 .84284 .46432 .85488 .46071 .84996 .45402 Mtetra
.662 .742 .91 r
.84996 .45402 .85488 .46071 .86697 .45709 .86209 .4504 Mtetra
.66 .742 .911 r
.86209 .4504 .86697 .45709 .87911 .45347 .87428 .44683 Mtetra
.649 .741 .916 r
.87428 .44683 .87911 .45347 .8913 .44987 .88655 .44356 Mtetra
.61 .736 .935 r
.88655 .44356 .8913 .44987 .90357 .4464 .899 .44132 Mtetra
.479 .723 .978 r
.899 .44132 .90357 .4464 .91594 .44337 .91176 .44124 Mtetra
.057 .582 .869 r
.91176 .44124 .91594 .44337 .92848 .44122 .9249 .44353 Mtetra
.371 0 0 r
.9249 .44353 .92848 .44122 .94119 .43986 .93811 .44552 Mtetra
.305 0 0 r
.93811 .44552 .94119 .43986 .95392 .43814 .95083 .44302 Mtetra
0 0 0 r
.95083 .44302 .95392 .43814 .96646 .43452 .96287 .43498 Mtetra
.664 .741 .908 r
.38668 .58654 .39287 .59231 .40317 .58919 .397 .5834 Mtetra
.397 .5834 .40317 .58919 .4135 .58606 .40736 .58025 Mtetra
.40736 .58025 .4135 .58606 .42387 .58292 .41776 .57709 Mtetra
.41776 .57709 .42387 .58292 .43428 .57977 .42819 .57391 Mtetra
.42819 .57391 .43428 .57977 .44474 .5766 .43867 .57073 Mtetra
.43867 .57073 .44474 .5766 .45523 .57342 .44919 .56753 Mtetra
.44919 .56753 .45523 .57342 .46576 .57024 .45975 .56431 Mtetra
.45975 .56431 .46576 .57024 .47634 .56703 .47035 .56109 Mtetra
.47035 .56109 .47634 .56703 .48695 .56382 .48099 .55785 Mtetra
.48099 .55785 .48695 .56382 .49761 .56059 .49168 .5546 Mtetra
.49168 .5546 .49761 .56059 .50831 .55735 .5024 .55134 Mtetra
.5024 .55134 .50831 .55735 .51905 .5541 .51317 .54806 Mtetra
.51317 .54806 .51905 .5541 .52983 .55083 .52398 .54477 Mtetra
.52398 .54477 .52983 .55083 .54066 .54756 .53484 .54147 Mtetra
.53484 .54147 .54066 .54756 .55153 .54426 .54573 .53815 Mtetra
.54573 .53815 .55153 .54426 .56244 .54096 .55667 .53483 Mtetra
.55667 .53483 .56244 .54096 .57339 .53764 .56766 .53149 Mtetra
.56766 .53149 .57339 .53764 .58439 .53431 .57868 .52813 Mtetra
.57868 .52813 .58439 .53431 .59543 .53097 .58975 .52476 Mtetra
.58975 .52476 .59543 .53097 .60652 .52761 .60087 .52138 Mtetra
.60087 .52138 .60652 .52761 .61765 .52424 .61203 .51799 Mtetra
.61203 .51799 .61765 .52424 .62882 .52086 .62323 .51458 Mtetra
.62323 .51458 .62882 .52086 .64004 .51746 .63448 .51115 Mtetra
.63448 .51115 .64004 .51746 .6513 .51405 .64578 .50772 Mtetra
.64578 .50772 .6513 .51405 .66261 .51063 .65712 .50427 Mtetra
.65712 .50427 .66261 .51063 .67397 .50719 .6685 .5008 Mtetra
.6685 .5008 .67397 .50719 .68537 .50374 .67993 .49733 Mtetra
.67993 .49733 .68537 .50374 .69682 .50027 .69141 .49384 Mtetra
.69141 .49384 .69682 .50027 .70831 .49679 .70294 .49033 Mtetra
.70294 .49033 .70831 .49679 .71985 .4933 .71451 .48681 Mtetra
.663 .741 .908 r
.71451 .48681 .71985 .4933 .73144 .48979 .72613 .48328 Mtetra
.72613 .48328 .73144 .48979 .74307 .48627 .7378 .47973 Mtetra
.7378 .47973 .74307 .48627 .75475 .48273 .74951 .47617 Mtetra
.74951 .47617 .75475 .48273 .76648 .47918 .76128 .4726 Mtetra
.76128 .4726 .76648 .47918 .77826 .47562 .77309 .46901 Mtetra
.663 .742 .908 r
.77309 .46901 .77826 .47562 .79008 .47205 .78495 .46542 Mtetra
.663 .742 .909 r
.78495 .46542 .79008 .47205 .80196 .46847 .79686 .46181 Mtetra
.79686 .46181 .80196 .46847 .81389 .46487 .80882 .4582 Mtetra
.80882 .4582 .81389 .46487 .82586 .46126 .82083 .45458 Mtetra
.662 .742 .91 r
.82083 .45458 .82586 .46126 .83789 .45765 .83289 .45095 Mtetra
.661 .743 .91 r
.83289 .45095 .83789 .45765 .84996 .45402 .84501 .44733 Mtetra
.658 .742 .912 r
.84501 .44733 .84996 .45402 .86209 .4504 .85719 .4438 Mtetra
.64 .739 .92 r
.85719 .4438 .86209 .4504 .87428 .44683 .86947 .4408 Mtetra
.558 .724 .951 r
.86947 .4408 .87428 .44683 .88655 .44356 .88203 .43968 Mtetra
.162 .587 .935 r
.88203 .43968 .88655 .44356 .899 .44132 .89514 .44288 Mtetra
.621 .067 0 r
.89514 .44288 .899 .44132 .91176 .44124 .909 .45146 Mtetra
.666 .26 .266 r
.909 .45146 .91176 .44124 .9249 .44353 .92309 .4608 Mtetra
.543 .209 .351 r
.92309 .4608 .9249 .44353 .93811 .44552 .93629 .46168 Mtetra
.296 .002 .285 r
.93629 .46168 .93811 .44552 .95083 .44302 .94798 .45017 Mtetra
0 0 0 r
.94798 .45017 .95083 .44302 .96287 .43498 .95887 .43269 Mtetra
.664 .741 .908 r
.38045 .58074 .38668 .58654 .397 .5834 .39079 .57758 Mtetra
.39079 .57758 .397 .5834 .40736 .58025 .40117 .5744 Mtetra
.40117 .5744 .40736 .58025 .41776 .57709 .4116 .57122 Mtetra
.4116 .57122 .41776 .57709 .42819 .57391 .42206 .56802 Mtetra
.42206 .56802 .42819 .57391 .43867 .57073 .43256 .56481 Mtetra
.43256 .56481 .43867 .57073 .44919 .56753 .44311 .56159 Mtetra
.44311 .56159 .44919 .56753 .45975 .56431 .45369 .55835 Mtetra
.45369 .55835 .45975 .56431 .47035 .56109 .46432 .5551 Mtetra
.46432 .5551 .47035 .56109 .48099 .55785 .47499 .55184 Mtetra
.47499 .55184 .48099 .55785 .49168 .5546 .4857 .54857 Mtetra
.4857 .54857 .49168 .5546 .5024 .55134 .49646 .54528 Mtetra
.49646 .54528 .5024 .55134 .51317 .54806 .50725 .54198 Mtetra
.50725 .54198 .51317 .54806 .52398 .54477 .51809 .53867 Mtetra
.51809 .53867 .52398 .54477 .53484 .54147 .52897 .53534 Mtetra
.52897 .53534 .53484 .54147 .54573 .53815 .5399 .532 Mtetra
.5399 .532 .54573 .53815 .55667 .53483 .55087 .52865 Mtetra
.55087 .52865 .55667 .53483 .56766 .53149 .56188 .52528 Mtetra
.56188 .52528 .56766 .53149 .57868 .52813 .57293 .5219 Mtetra
.57293 .5219 .57868 .52813 .58975 .52476 .58403 .51851 Mtetra
.58403 .51851 .58975 .52476 .60087 .52138 .59518 .5151 Mtetra
.59518 .5151 .60087 .52138 .61203 .51799 .60637 .51168 Mtetra
.60637 .51168 .61203 .51799 .62323 .51458 .6176 .50825 Mtetra
.6176 .50825 .62323 .51458 .63448 .51115 .62888 .5048 Mtetra
.62888 .5048 .63448 .51115 .64578 .50772 .64021 .50134 Mtetra
.64021 .50134 .64578 .50772 .65712 .50427 .65158 .49786 Mtetra
.65158 .49786 .65712 .50427 .6685 .5008 .663 .49437 Mtetra
.663 .49437 .6685 .5008 .67993 .49733 .67446 .49087 Mtetra
.67446 .49087 .67993 .49733 .69141 .49384 .68597 .48735 Mtetra
.68597 .48735 .69141 .49384 .70294 .49033 .69753 .48382 Mtetra
.663 .741 .908 r
.69753 .48382 .70294 .49033 .71451 .48681 .70913 .48028 Mtetra
.70913 .48028 .71451 .48681 .72613 .48328 .72078 .47672 Mtetra
.72078 .47672 .72613 .48328 .7378 .47973 .73249 .47315 Mtetra
.73249 .47315 .7378 .47973 .74951 .47617 .74423 .46956 Mtetra
.74423 .46956 .74951 .47617 .76128 .4726 .75603 .46597 Mtetra
.663 .742 .908 r
.75603 .46597 .76128 .4726 .77309 .46901 .76788 .46236 Mtetra
.663 .742 .909 r
.76788 .46236 .77309 .46901 .78495 .46542 .77978 .45875 Mtetra
.77978 .45875 .78495 .46542 .79686 .46181 .79172 .45513 Mtetra
.662 .742 .909 r
.79172 .45513 .79686 .46181 .80882 .4582 .80372 .4515 Mtetra
.662 .742 .91 r
.80372 .4515 .80882 .4582 .82083 .45458 .81577 .44787 Mtetra
.661 .743 .911 r
.81577 .44787 .82083 .45458 .83289 .45095 .82787 .44425 Mtetra
.656 .742 .913 r
.82787 .44425 .83289 .45095 .84501 .44733 .84004 .44076 Mtetra
.63 .737 .924 r
.84004 .44076 .84501 .44733 .85719 .4438 .85233 .43799 Mtetra
.495 .703 .963 r
.85233 .43799 .85719 .4438 .86947 .4408 .86498 .43801 Mtetra
0 .288 .686 r
.86498 .43801 .86947 .4408 .88203 .43968 .87845 .44489 Mtetra
.774 .321 .173 r
.87845 .44489 .88203 .43968 .89514 .44288 .89314 .46146 Mtetra
.73 .38 .388 r
.89314 .46146 .89514 .44288 .909 .45146 .90846 .48153 Mtetra
.611 .314 .441 r
.90846 .48153 .909 .45146 .92309 .4608 .92253 .48918 Mtetra
.386 .133 .404 r
.92253 .48918 .92309 .4608 .93629 .46168 .934 .47472 Mtetra
0 0 .027 r
.934 .47472 .93629 .46168 .94798 .45017 .94379 .4473 Mtetra
.976 .881 .672 r
.94379 .4473 .94798 .45017 .95887 .43269 .95384 .42293 Mtetra
.664 .741 .908 r
.37417 .57489 .38045 .58074 .39079 .57758 .38454 .57171 Mtetra
.38454 .57171 .39079 .57758 .40117 .5744 .39494 .56851 Mtetra
.39494 .56851 .40117 .5744 .4116 .57122 .40539 .5653 Mtetra
.40539 .5653 .4116 .57122 .42206 .56802 .41588 .56208 Mtetra
.41588 .56208 .42206 .56802 .43256 .56481 .42641 .55885 Mtetra
.42641 .55885 .43256 .56481 .44311 .56159 .43698 .5556 Mtetra
.43698 .5556 .44311 .56159 .45369 .55835 .4476 .55234 Mtetra
.4476 .55234 .45369 .55835 .46432 .5551 .45825 .54907 Mtetra
.45825 .54907 .46432 .5551 .47499 .55184 .46895 .54579 Mtetra
.46895 .54579 .47499 .55184 .4857 .54857 .47968 .54249 Mtetra
.47968 .54249 .4857 .54857 .49646 .54528 .49046 .53918 Mtetra
.49046 .53918 .49646 .54528 .50725 .54198 .50129 .53585 Mtetra
.50129 .53585 .50725 .54198 .51809 .53867 .51215 .53251 Mtetra
.51215 .53251 .51809 .53867 .52897 .53534 .52306 .52916 Mtetra
.52306 .52916 .52897 .53534 .5399 .532 .53402 .5258 Mtetra
.53402 .5258 .5399 .532 .55087 .52865 .54501 .52242 Mtetra
.54501 .52242 .55087 .52865 .56188 .52528 .55606 .51903 Mtetra
.55606 .51903 .56188 .52528 .57293 .5219 .56714 .51563 Mtetra
.56714 .51563 .57293 .5219 .58403 .51851 .57827 .51221 Mtetra
.57827 .51221 .58403 .51851 .59518 .5151 .58944 .50878 Mtetra
.58944 .50878 .59518 .5151 .60637 .51168 .60066 .50533 Mtetra
.60066 .50533 .60637 .51168 .6176 .50825 .61193 .50187 Mtetra
.61193 .50187 .6176 .50825 .62888 .5048 .62324 .4984 Mtetra
.62324 .4984 .62888 .5048 .64021 .50134 .6346 .49491 Mtetra
.6346 .49491 .64021 .50134 .65158 .49786 .646 .49141 Mtetra
.646 .49141 .65158 .49786 .663 .49437 .65745 .48789 Mtetra
.65745 .48789 .663 .49437 .67446 .49087 .66894 .48436 Mtetra
.663 .741 .908 r
.66894 .48436 .67446 .49087 .68597 .48735 .68049 .48082 Mtetra
.68049 .48082 .68597 .48735 .69753 .48382 .69208 .47726 Mtetra
.69208 .47726 .69753 .48382 .70913 .48028 .70371 .47369 Mtetra
.70371 .47369 .70913 .48028 .72078 .47672 .7154 .47011 Mtetra
.7154 .47011 .72078 .47672 .73249 .47315 .72713 .46651 Mtetra
.663 .742 .908 r
.72713 .46651 .73249 .47315 .74423 .46956 .73892 .46291 Mtetra
.663 .742 .909 r
.73892 .46291 .74423 .46956 .75603 .46597 .75075 .4593 Mtetra
.75075 .4593 .75603 .46597 .76788 .46236 .76263 .45567 Mtetra
.662 .742 .909 r
.76263 .45567 .76788 .46236 .77978 .45875 .77456 .45205 Mtetra
.662 .742 .91 r
.77456 .45205 .77978 .45875 .79172 .45513 .78655 .44841 Mtetra
.662 .743 .91 r
.78655 .44841 .79172 .45513 .80372 .4515 .79858 .44478 Mtetra
.661 .743 .911 r
.79858 .44478 .80372 .4515 .81577 .44787 .81067 .44116 Mtetra
.656 .742 .914 r
.81067 .44116 .81577 .44787 .82787 .44425 .82282 .43768 Mtetra
.626 .736 .926 r
.82282 .43768 .82787 .44425 .84004 .44076 .83511 .43501 Mtetra
.458 .688 .965 r
.83511 .43501 .84004 .44076 .85233 .43799 .84778 .43562 Mtetra
.47 0 0 r
.84778 .43562 .85233 .43799 .86498 .43801 .86144 .44499 Mtetra
.816 .397 .251 r
.86144 .44499 .86498 .43801 .87845 .44489 .87673 .4681 Mtetra
.765 .429 .417 r
.87673 .4681 .87845 .44489 .89314 .46146 .89313 .49889 Mtetra
.656 .363 .463 r
.89313 .49889 .89314 .46146 .90846 .48153 .90827 .51575 Mtetra
.418 .171 .43 r
.90827 .51575 .90846 .48153 .92253 .48918 .91991 .50131 Mtetra
0 0 0 r
.91991 .50131 .92253 .48918 .934 .47472 .92883 .46493 Mtetra
.937 .753 .627 r
.92883 .46493 .934 .47472 .94379 .4473 .93774 .43012 Mtetra
.811 .649 .682 r
.93774 .43012 .94379 .4473 .95384 .42293 .94822 .40878 Mtetra
.664 .741 .908 r
.36785 .56901 .37417 .57489 .38454 .57171 .37824 .5658 Mtetra
.37824 .5658 .38454 .57171 .39494 .56851 .38867 .56258 Mtetra
.38867 .56258 .39494 .56851 .40539 .5653 .39914 .55935 Mtetra
.39914 .55935 .40539 .5653 .41588 .56208 .40966 .5561 Mtetra
.40966 .5561 .41588 .56208 .42641 .55885 .42022 .55284 Mtetra
.42022 .55284 .42641 .55885 .43698 .5556 .43081 .54957 Mtetra
.43081 .54957 .43698 .5556 .4476 .55234 .44145 .54629 Mtetra
.44145 .54629 .4476 .55234 .45825 .54907 .45213 .543 Mtetra
.45213 .543 .45825 .54907 .46895 .54579 .46286 .53969 Mtetra
.46286 .53969 .46895 .54579 .47968 .54249 .47362 .53636 Mtetra
.47362 .53636 .47968 .54249 .49046 .53918 .48443 .53303 Mtetra
.48443 .53303 .49046 .53918 .50129 .53585 .49528 .52968 Mtetra
.49528 .52968 .50129 .53585 .51215 .53251 .50617 .52632 Mtetra
.50617 .52632 .51215 .53251 .52306 .52916 .51711 .52294 Mtetra
.51711 .52294 .52306 .52916 .53402 .5258 .52809 .51955 Mtetra
.52809 .51955 .53402 .5258 .54501 .52242 .53912 .51615 Mtetra
.53912 .51615 .54501 .52242 .55606 .51903 .55019 .51274 Mtetra
.55019 .51274 .55606 .51903 .56714 .51563 .5613 .50931 Mtetra
.5613 .50931 .56714 .51563 .57827 .51221 .57246 .50586 Mtetra
.57246 .50586 .57827 .51221 .58944 .50878 .58367 .50241 Mtetra
.58367 .50241 .58944 .50878 .60066 .50533 .59492 .49893 Mtetra
.59492 .49893 .60066 .50533 .61193 .50187 .60621 .49545 Mtetra
.60621 .49545 .61193 .50187 .62324 .4984 .61755 .49195 Mtetra
.61755 .49195 .62324 .4984 .6346 .49491 .62894 .48843 Mtetra
.62894 .48843 .6346 .49491 .646 .49141 .64038 .48491 Mtetra
.64038 .48491 .646 .49141 .65745 .48789 .65186 .48137 Mtetra
.663 .741 .908 r
.65186 .48137 .65745 .48789 .66894 .48436 .66338 .47781 Mtetra
.66338 .47781 .66894 .48436 .68049 .48082 .67496 .47424 Mtetra
.67496 .47424 .68049 .48082 .69208 .47726 .68658 .47066 Mtetra
.68658 .47066 .69208 .47726 .70371 .47369 .69825 .46706 Mtetra
.69825 .46706 .70371 .47369 .7154 .47011 .70997 .46346 Mtetra
.663 .742 .908 r
.70997 .46346 .7154 .47011 .72713 .46651 .72174 .45984 Mtetra
.663 .742 .909 r
.72174 .45984 .72713 .46651 .73892 .46291 .73356 .45622 Mtetra
.662 .742 .909 r
.73356 .45622 .73892 .46291 .75075 .4593 .74543 .45259 Mtetra
.74543 .45259 .75075 .4593 .76263 .45567 .75734 .44896 Mtetra
.662 .742 .91 r
.75734 .44896 .76263 .45567 .77456 .45205 .76931 .44532 Mtetra
.661 .743 .911 r
.76931 .44532 .77456 .45205 .78655 .44841 .78133 .44169 Mtetra
.66 .743 .912 r
.78133 .44169 .78655 .44841 .79858 .44478 .79341 .43807 Mtetra
.656 .743 .914 r
.79341 .43807 .79858 .44478 .81067 .44116 .80555 .43457 Mtetra
.629 .738 .925 r
.80555 .43457 .81067 .44116 .82282 .43768 .8178 .43179 Mtetra
.475 .693 .963 r
.8178 .43179 .82282 .43768 .83511 .43501 .83041 .43215 Mtetra
.432 0 0 r
.83041 .43215 .83511 .43501 .84778 .43562 .84398 .44141 Mtetra
.832 .409 .235 r
.84398 .44141 .84778 .43562 .86144 .44499 .85927 .4661 Mtetra
.795 .452 .407 r
.85927 .4661 .86144 .44499 .87673 .4681 .87604 .50213 Mtetra
.699 .393 .454 r
.87604 .50213 .87673 .4681 .89313 .49889 .89191 .52657 Mtetra
.426 .156 .399 r
.89191 .52657 .89313 .49889 .90827 .51575 .90411 .51619 Mtetra
.998 .849 .53 r
.90411 .51619 .90827 .51575 .91991 .50131 .91291 .47686 Mtetra
.849 .635 .613 r
.91291 .47686 .91991 .50131 .92883 .46493 .92125 .43561 Mtetra
.765 .574 .64 r
.92125 .43561 .92883 .46493 .93774 .43012 .9312 .40917 Mtetra
.721 .58 .696 r
.9312 .40917 .93774 .43012 .94822 .40878 .94279 .39629 Mtetra
.664 .741 .908 r
.36148 .56307 .36785 .56901 .37824 .5658 .37189 .55984 Mtetra
.37189 .55984 .37824 .5658 .38867 .56258 .38235 .5566 Mtetra
.38235 .5566 .38867 .56258 .39914 .55935 .39285 .55335 Mtetra
.39285 .55335 .39914 .55935 .40966 .5561 .40339 .55008 Mtetra
.40339 .55008 .40966 .5561 .42022 .55284 .41397 .5468 Mtetra
.41397 .5468 .42022 .55284 .43081 .54957 .4246 .5435 Mtetra
.4246 .5435 .43081 .54957 .44145 .54629 .43526 .5402 Mtetra
.43526 .5402 .44145 .54629 .45213 .543 .44597 .53688 Mtetra
.44597 .53688 .45213 .543 .46286 .53969 .45672 .53354 Mtetra
.45672 .53354 .46286 .53969 .47362 .53636 .46751 .5302 Mtetra
.46751 .5302 .47362 .53636 .48443 .53303 .47835 .52684 Mtetra
.47835 .52684 .48443 .53303 .49528 .52968 .48923 .52346 Mtetra
.48923 .52346 .49528 .52968 .50617 .52632 .50015 .52008 Mtetra
.50015 .52008 .50617 .52632 .51711 .52294 .51112 .51668 Mtetra
.51112 .51668 .51711 .52294 .52809 .51955 .52213 .51326 Mtetra
.52213 .51326 .52809 .51955 .53912 .51615 .53318 .50983 Mtetra
.53318 .50983 .53912 .51615 .55019 .51274 .54428 .50639 Mtetra
.54428 .50639 .55019 .51274 .5613 .50931 .55543 .50294 Mtetra
.55543 .50294 .5613 .50931 .57246 .50586 .56661 .49947 Mtetra
.56661 .49947 .57246 .50586 .58367 .50241 .57785 .49599 Mtetra
.57785 .49599 .58367 .50241 .59492 .49893 .58913 .49249 Mtetra
.58913 .49249 .59492 .49893 .60621 .49545 .60045 .48898 Mtetra
.60045 .48898 .60621 .49545 .61755 .49195 .61183 .48545 Mtetra
.61183 .48545 .61755 .49195 .62894 .48843 .62325 .48191 Mtetra
.62325 .48191 .62894 .48843 .64038 .48491 .63471 .47836 Mtetra
.663 .741 .908 r
.63471 .47836 .64038 .48491 .65186 .48137 .64622 .47479 Mtetra
.64622 .47479 .65186 .48137 .66338 .47781 .65778 .47121 Mtetra
.65778 .47121 .66338 .47781 .67496 .47424 .66939 .46761 Mtetra
.66939 .46761 .67496 .47424 .68658 .47066 .68105 .46401 Mtetra
.68105 .46401 .68658 .47066 .69825 .46706 .69275 .46039 Mtetra
.663 .742 .908 r
.69275 .46039 .69825 .46706 .70997 .46346 .70451 .45677 Mtetra
.663 .742 .909 r
.70451 .45677 .70997 .46346 .72174 .45984 .71631 .45313 Mtetra
.662 .742 .909 r
.71631 .45313 .72174 .45984 .73356 .45622 .72816 .4495 Mtetra
.662 .742 .91 r
.72816 .4495 .73356 .45622 .74543 .45259 .74006 .44586 Mtetra
.661 .743 .91 r
.74006 .44586 .74543 .45259 .75734 .44896 .75202 .44222 Mtetra
.661 .743 .911 r
.75202 .44222 .75734 .44896 .76931 .44532 .76403 .43859 Mtetra
.66 .744 .912 r
.76403 .43859 .76931 .44532 .78133 .44169 .77609 .43497 Mtetra
.656 .744 .914 r
.77609 .43497 .78133 .44169 .79341 .43807 .78821 .43144 Mtetra
.637 .74 .923 r
.78821 .43144 .79341 .43807 .80555 .43457 .80042 .42843 Mtetra
.53 .712 .955 r
.80042 .42843 .80555 .43457 .8178 .43179 .81291 .42782 Mtetra
0 .355 .781 r
.81291 .42782 .8178 .43179 .83041 .43215 .82615 .43448 Mtetra
.818 .353 .115 r
.82615 .43448 .83041 .43215 .84398 .44141 .84085 .45486 Mtetra
.822 .451 .354 r
.84085 .45486 .84398 .44141 .85927 .4661 .85702 .48749 Mtetra
.75 .408 .404 r
.85702 .48749 .85927 .4661 .87604 .50213 .87284 .51338 Mtetra
.372 0 .183 r
.87284 .51338 .87604 .50213 .89191 .52657 .88566 .50895 Mtetra
.867 .673 .637 r
.88566 .50895 .89191 .52657 .90411 .51619 .8952 .47482 Mtetra
.771 .557 .609 r
.8952 .47482 .90411 .51619 .91291 .47686 .90389 .43497 Mtetra
.724 .526 .622 r
.90389 .43497 .91291 .47686 .92125 .43561 .91387 .4077 Mtetra
.697 .538 .667 r
.91387 .4077 .92125 .43561 .9312 .40917 .92538 .3939 Mtetra
.686 .604 .758 r
.92538 .3939 .9312 .40917 .94279 .39629 .93776 .38705 Mtetra
.664 .741 .908 r
.35506 .5571 .36148 .56307 .37189 .55984 .3655 .55385 Mtetra
.3655 .55385 .37189 .55984 .38235 .5566 .37599 .55058 Mtetra
.37599 .55058 .38235 .5566 .39285 .55335 .38651 .5473 Mtetra
.38651 .5473 .39285 .55335 .40339 .55008 .39708 .54401 Mtetra
.39708 .54401 .40339 .55008 .41397 .5468 .40769 .54071 Mtetra
.40769 .54071 .41397 .5468 .4246 .5435 .41834 .53739 Mtetra
.41834 .53739 .4246 .5435 .43526 .5402 .42903 .53406 Mtetra
.42903 .53406 .43526 .5402 .44597 .53688 .43976 .53071 Mtetra
.43976 .53071 .44597 .53688 .45672 .53354 .45054 .52735 Mtetra
.45054 .52735 .45672 .53354 .46751 .5302 .46136 .52398 Mtetra
.46136 .52398 .46751 .5302 .47835 .52684 .47222 .5206 Mtetra
.47222 .5206 .47835 .52684 .48923 .52346 .48313 .5172 Mtetra
.48313 .5172 .48923 .52346 .50015 .52008 .49408 .51379 Mtetra
.49408 .51379 .50015 .52008 .51112 .51668 .50508 .51036 Mtetra
.50508 .51036 .51112 .51668 .52213 .51326 .51612 .50692 Mtetra
.51612 .50692 .52213 .51326 .53318 .50983 .5272 .50347 Mtetra
.5272 .50347 .53318 .50983 .54428 .50639 .53833 .5 Mtetra
.53833 .5 .54428 .50639 .55543 .50294 .5495 .49652 Mtetra
.5495 .49652 .55543 .50294 .56661 .49947 .56072 .49303 Mtetra
.56072 .49303 .56661 .49947 .57785 .49599 .57199 .48952 Mtetra
.57199 .48952 .57785 .49599 .58913 .49249 .5833 .48599 Mtetra
.5833 .48599 .58913 .49249 .60045 .48898 .59465 .48246 Mtetra
.59465 .48246 .60045 .48898 .61183 .48545 .60606 .4789 Mtetra
.60606 .4789 .61183 .48545 .62325 .48191 .61751 .47534 Mtetra
.663 .741 .908 r
.61751 .47534 .62325 .48191 .63471 .47836 .629 .47176 Mtetra
.629 .47176 .63471 .47836 .64622 .47479 .64055 .46816 Mtetra
.64055 .46816 .64622 .47479 .65778 .47121 .65214 .46456 Mtetra
.65214 .46456 .65778 .47121 .66939 .46761 .66378 .46094 Mtetra
.66378 .46094 .66939 .46761 .68105 .46401 .67547 .45731 Mtetra
.663 .742 .909 r
.67547 .45731 .68105 .46401 .69275 .46039 .68721 .45368 Mtetra
.68721 .45368 .69275 .46039 .70451 .45677 .699 .45004 Mtetra
.662 .742 .909 r
.699 .45004 .70451 .45677 .71631 .45313 .71083 .44639 Mtetra
.662 .742 .91 r
.71083 .44639 .71631 .45313 .72816 .4495 .72272 .44275 Mtetra
.661 .743 .911 r
.72272 .44275 .72816 .4495 .74006 .44586 .73466 .43911 Mtetra
.66 .743 .912 r
.73466 .43911 .74006 .44586 .75202 .44222 .74666 .43548 Mtetra
.659 .744 .913 r
.74666 .43548 .75202 .44222 .76403 .43859 .7587 .43187 Mtetra
.657 .745 .915 r
.7587 .43187 .76403 .43859 .77609 .43497 .7708 .42831 Mtetra
.645 .743 .921 r
.7708 .42831 .77609 .43497 .78821 .43144 .78299 .42506 Mtetra
.586 .73 .942 r
.78299 .42506 .78821 .43144 .80042 .42843 .79535 .42329 Mtetra
.255 .602 .953 r
.79535 .42329 .80042 .42843 .81291 .42782 .80819 .42629 Mtetra
.661 .112 0 r
.80819 .42629 .81291 .42782 .82615 .43448 .82203 .43901 Mtetra
.827 .389 .198 r
.82203 .43901 .82615 .43448 .84085 .45486 .83702 .46182 Mtetra
.797 .371 .237 r
.83702 .46182 .84085 .45486 .85702 .48749 .85204 .48239 Mtetra
.464 .729 .984 r
.85204 .48239 .85702 .48749 .87284 .51338 .86519 .48225 Mtetra
.745 .559 .643 r
.86519 .48225 .87284 .51338 .88566 .50895 .87587 .45828 Mtetra
.718 .512 .611 r
.87587 .45828 .88566 .50895 .8952 .47482 .88562 .42687 Mtetra
.693 .498 .62 r
.88562 .42687 .8952 .47482 .90389 .43497 .89614 .40356 Mtetra
.678 .516 .659 r
.89614 .40356 .90389 .43497 .91387 .4077 .90782 .39087 Mtetra
.676 .584 .745 r
.90782 .39087 .91387 .4077 .92538 .3939 .92023 .38417 Mtetra
.676 .684 .849 r
.92023 .38417 .92538 .3939 .93776 .38705 .93293 .37949 Mtetra
.664 .741 .908 r
.3486 .55109 .35506 .5571 .3655 .55385 .35907 .54781 Mtetra
.35907 .54781 .3655 .55385 .37599 .55058 .36958 .54452 Mtetra
.36958 .54452 .37599 .55058 .38651 .5473 .38013 .54122 Mtetra
.38013 .54122 .38651 .5473 .39708 .54401 .39072 .5379 Mtetra
.39072 .5379 .39708 .54401 .40769 .54071 .40135 .53457 Mtetra
.40135 .53457 .40769 .54071 .41834 .53739 .41203 .53123 Mtetra
.41203 .53123 .41834 .53739 .42903 .53406 .42275 .52787 Mtetra
.42275 .52787 .42903 .53406 .43976 .53071 .43351 .5245 Mtetra
.43351 .5245 .43976 .53071 .45054 .52735 .44432 .52112 Mtetra
.44432 .52112 .45054 .52735 .46136 .52398 .45516 .51772 Mtetra
.45516 .51772 .46136 .52398 .47222 .5206 .46605 .51431 Mtetra
.46605 .51431 .47222 .5206 .48313 .5172 .47699 .51089 Mtetra
.47699 .51089 .48313 .5172 .49408 .51379 .48797 .50745 Mtetra
.48797 .50745 .49408 .51379 .50508 .51036 .49899 .504 Mtetra
.49899 .504 .50508 .51036 .51612 .50692 .51006 .50054 Mtetra
.51006 .50054 .51612 .50692 .5272 .50347 .52117 .49706 Mtetra
.52117 .49706 .5272 .50347 .53833 .5 .53233 .49357 Mtetra
.53233 .49357 .53833 .5 .5495 .49652 .54353 .49006 Mtetra
.54353 .49006 .5495 .49652 .56072 .49303 .55478 .48654 Mtetra
.55478 .48654 .56072 .49303 .57199 .48952 .56608 .483 Mtetra
.56608 .483 .57199 .48952 .5833 .48599 .57742 .47945 Mtetra
.57742 .47945 .5833 .48599 .59465 .48246 .58881 .47589 Mtetra
.58881 .47589 .59465 .48246 .60606 .4789 .60024 .47231 Mtetra
.663 .741 .908 r
.60024 .47231 .60606 .4789 .61751 .47534 .61172 .46872 Mtetra
.61172 .46872 .61751 .47534 .629 .47176 .62325 .46511 Mtetra
.62325 .46511 .629 .47176 .64055 .46816 .63483 .46149 Mtetra
.63483 .46149 .64055 .46816 .65214 .46456 .64645 .45786 Mtetra
.64645 .45786 .65214 .46456 .66378 .46094 .65813 .45423 Mtetra
.663 .742 .909 r
.65813 .45423 .66378 .46094 .67547 .45731 .66985 .45058 Mtetra
.662 .742 .909 r
.66985 .45058 .67547 .45731 .68721 .45368 .68162 .44693 Mtetra
.662 .742 .91 r
.68162 .44693 .68721 .45368 .699 .45004 .69345 .44328 Mtetra
.661 .742 .91 r
.69345 .44328 .699 .45004 .71083 .44639 .70532 .43964 Mtetra
.66 .743 .911 r
.70532 .43964 .71083 .44639 .72272 .44275 .71725 .436 Mtetra
.659 .744 .912 r
.71725 .436 .72272 .44275 .73466 .43911 .72922 .43237 Mtetra
.658 .745 .914 r
.72922 .43237 .73466 .43911 .74666 .43548 .74125 .42877 Mtetra
.656 .746 .916 r
.74125 .42877 .74666 .43548 .7587 .43187 .75334 .4252 Mtetra
.65 .746 .919 r
.75334 .4252 .7587 .43187 .7708 .42831 .76549 .42179 Mtetra
.623 .741 .931 r
.76549 .42179 .7708 .42831 .78299 .42506 .77776 .41911 Mtetra
.498 .706 .964 r
.77776 .41911 .78299 .42506 .79535 .42329 .7903 .41896 Mtetra
0 .45 .857 r
.7903 .41896 .79535 .42329 .80819 .42629 .80339 .42433 Mtetra
.615 .058 0 r
.80339 .42433 .80819 .42629 .82203 .43901 .81718 .43619 Mtetra
.566 .015 0 r
.81718 .43619 .82203 .43901 .83702 .46182 .83118 .44825 Mtetra
.545 .549 .809 r
.83118 .44825 .83702 .46182 .85204 .48239 .84427 .44915 Mtetra
.682 .515 .653 r
.84427 .44915 .85204 .48239 .86519 .48225 .85592 .43497 Mtetra
.683 .492 .623 r
.85592 .43497 .86519 .48225 .87587 .45828 .86686 .41431 Mtetra
.671 .489 .63 r
.86686 .41431 .87587 .45828 .88562 .42687 .87815 .3975 Mtetra
.665 .514 .669 r
.87815 .3975 .88562 .42687 .89614 .40356 .89014 .38731 Mtetra
.67 .587 .753 r
.89014 .38731 .89614 .40356 .90782 .39087 .90262 .38123 Mtetra
.674 .686 .853 r
.90262 .38123 .90782 .39087 .92023 .38417 .91532 .37663 Mtetra
.672 .74 .901 r
.91532 .37663 .92023 .38417 .93293 .37949 .92811 .37234 Mtetra
.664 .741 .908 r
.34209 .54503 .3486 .55109 .35907 .54781 .35259 .54172 Mtetra
.35259 .54172 .35907 .54781 .36958 .54452 .36312 .53841 Mtetra
.36312 .53841 .36958 .54452 .38013 .54122 .3737 .53508 Mtetra
.3737 .53508 .38013 .54122 .39072 .5379 .38431 .53174 Mtetra
.38431 .53174 .39072 .5379 .40135 .53457 .39497 .52839 Mtetra
.39497 .52839 .40135 .53457 .41203 .53123 .40568 .52502 Mtetra
.40568 .52502 .41203 .53123 .42275 .52787 .41642 .52164 Mtetra
.41642 .52164 .42275 .52787 .43351 .5245 .42721 .51825 Mtetra
.42721 .51825 .43351 .5245 .44432 .52112 .43804 .51484 Mtetra
.43804 .51484 .44432 .52112 .45516 .51772 .44892 .51142 Mtetra
.44892 .51142 .45516 .51772 .46605 .51431 .45984 .50798 Mtetra
.45984 .50798 .46605 .51431 .47699 .51089 .4708 .50453 Mtetra
.4708 .50453 .47699 .51089 .48797 .50745 .48181 .50107 Mtetra
.48181 .50107 .48797 .50745 .49899 .504 .49286 .49759 Mtetra
.49286 .49759 .49899 .504 .51006 .50054 .50396 .4941 Mtetra
.50396 .4941 .51006 .50054 .52117 .49706 .5151 .4906 Mtetra
.5151 .4906 .52117 .49706 .53233 .49357 .52629 .48708 Mtetra
.52629 .48708 .53233 .49357 .54353 .49006 .53752 .48355 Mtetra
.53752 .48355 .54353 .49006 .55478 .48654 .5488 .48 Mtetra
.5488 .48 .55478 .48654 .56608 .483 .56013 .47643 Mtetra
.56013 .47643 .56608 .483 .57742 .47945 .5715 .47286 Mtetra
.663 .741 .908 r
.5715 .47286 .57742 .47945 .58881 .47589 .58292 .46927 Mtetra
.58292 .46927 .58881 .47589 .60024 .47231 .59438 .46566 Mtetra
.59438 .46566 .60024 .47231 .61172 .46872 .6059 .46205 Mtetra
.6059 .46205 .61172 .46872 .62325 .46511 .61746 .45842 Mtetra
.61746 .45842 .62325 .46511 .63483 .46149 .62907 .45478 Mtetra
.663 .742 .908 r
.62907 .45478 .63483 .46149 .64645 .45786 .64073 .45113 Mtetra
.663 .742 .909 r
.64073 .45113 .64645 .45786 .65813 .45423 .65243 .44747 Mtetra
.662 .742 .909 r
.65243 .44747 .65813 .45423 .66985 .45058 .66419 .44381 Mtetra
.662 .742 .91 r
.66419 .44381 .66985 .45058 .68162 .44693 .676 .44016 Mtetra
.661 .743 .911 r
.676 .44016 .68162 .44693 .69345 .44328 .68785 .43651 Mtetra
.66 .743 .912 r
.68785 .43651 .69345 .44328 .70532 .43964 .69976 .43287 Mtetra
.659 .744 .913 r
.69976 .43287 .70532 .43964 .71725 .436 .71173 .42926 Mtetra
.657 .745 .915 r
.71173 .42926 .71725 .436 .72922 .43237 .72375 .42566 Mtetra
.656 .746 .917 r
.72375 .42566 .72922 .43237 .74125 .42877 .73582 .4221 Mtetra
.652 .747 .919 r
.73582 .4221 .74125 .42877 .75334 .4252 .74795 .41861 Mtetra
.641 .747 .926 r
.74795 .41861 .75334 .4252 .76549 .42179 .76016 .41543 Mtetra
.597 .738 .943 r
.76016 .41543 .76549 .42179 .77776 .41911 .77251 .41334 Mtetra
.457 .695 .969 r
.77251 .41334 .77776 .41911 .7903 .41896 .78513 .41376 Mtetra
.193 .564 .936 r
.78513 .41376 .7903 .41896 .80339 .42433 .79811 .4175 Mtetra
.248 .536 .921 r
.79811 .4175 .80339 .42433 .81718 .43619 .81129 .42203 Mtetra
.572 .555 .797 r
.81129 .42203 .81718 .43619 .83118 .44825 .82414 .4218 Mtetra
.654 .517 .684 r
.82414 .4218 .83118 .44825 .84427 .44915 .83635 .41396 Mtetra
.663 .498 .651 r
.83635 .41396 .84427 .44915 .85592 .43497 .84816 .40195 Mtetra
.66 .501 .657 r
.84816 .40195 .85592 .43497 .86686 .41431 .86009 .39117 Mtetra
.661 .535 .7 r
.86009 .39117 .86686 .41431 .87815 .3975 .87238 .38363 Mtetra
.669 .612 .782 r
.87238 .38363 .87815 .3975 .89014 .38731 .88494 .37832 Mtetra
.673 .701 .867 r
.88494 .37832 .89014 .38731 .90262 .38123 .89765 .37384 Mtetra
.672 .745 .905 r
.89765 .37384 .90262 .38123 .91532 .37663 .91043 .36952 Mtetra
.673 .755 .912 r
.91043 .36952 .91532 .37663 .92811 .37234 .92326 .36516 Mtetra
.664 .741 .908 r
.33554 .53892 .34209 .54503 .35259 .54172 .34605 .5356 Mtetra
.34605 .5356 .35259 .54172 .36312 .53841 .35661 .53226 Mtetra
.35661 .53226 .36312 .53841 .3737 .53508 .36722 .52891 Mtetra
.36722 .52891 .3737 .53508 .38431 .53174 .37786 .52554 Mtetra
.37786 .52554 .38431 .53174 .39497 .52839 .38855 .52216 Mtetra
.38855 .52216 .39497 .52839 .40568 .52502 .39928 .51877 Mtetra
.39928 .51877 .40568 .52502 .41642 .52164 .41005 .51537 Mtetra
.41005 .51537 .41642 .52164 .42721 .51825 .42087 .51195 Mtetra
.42087 .51195 .42721 .51825 .43804 .51484 .43173 .50851 Mtetra
.43173 .50851 .43804 .51484 .44892 .51142 .44263 .50507 Mtetra
.44263 .50507 .44892 .51142 .45984 .50798 .45358 .50161 Mtetra
.45358 .50161 .45984 .50798 .4708 .50453 .46457 .49813 Mtetra
.46457 .49813 .4708 .50453 .48181 .50107 .4756 .49464 Mtetra
.4756 .49464 .48181 .50107 .49286 .49759 .48668 .49114 Mtetra
.48668 .49114 .49286 .49759 .50396 .4941 .49781 .48762 Mtetra
.49781 .48762 .50396 .4941 .5151 .4906 .50898 .48409 Mtetra
.50898 .48409 .5151 .4906 .52629 .48708 .5202 .48054 Mtetra
.5202 .48054 .52629 .48708 .53752 .48355 .53146 .47698 Mtetra
.53146 .47698 .53752 .48355 .5488 .48 .54277 .47341 Mtetra
.54277 .47341 .5488 .48 .56013 .47643 .55413 .46982 Mtetra
.663 .741 .908 r
.55413 .46982 .56013 .47643 .5715 .47286 .56553 .46622 Mtetra
.56553 .46622 .5715 .47286 .58292 .46927 .57698 .4626 Mtetra
.57698 .4626 .58292 .46927 .59438 .46566 .58848 .45897 Mtetra
.58848 .45897 .59438 .46566 .6059 .46205 .60002 .45533 Mtetra
.60002 .45533 .6059 .46205 .61746 .45842 .61162 .45168 Mtetra
.663 .742 .908 r
.61162 .45168 .61746 .45842 .62907 .45478 .62326 .44802 Mtetra
.663 .742 .909 r
.62326 .44802 .62907 .45478 .64073 .45113 .63495 .44435 Mtetra
.662 .742 .909 r
.63495 .44435 .64073 .45113 .65243 .44747 .64669 .44069 Mtetra
.661 .742 .91 r
.64669 .44069 .65243 .44747 .66419 .44381 .65848 .43702 Mtetra
.661 .743 .911 r
.65848 .43702 .66419 .44381 .676 .44016 .67033 .43337 Mtetra
.659 .743 .912 r
.67033 .43337 .676 .44016 .68785 .43651 .68222 .42974 Mtetra
.658 .744 .914 r
.68222 .42974 .68785 .43651 .69976 .43287 .69417 .42613 Mtetra
.657 .745 .915 r
.69417 .42613 .69976 .43287 .71173 .42926 .70617 .42255 Mtetra
.655 .747 .918 r
.70617 .42255 .71173 .42926 .72375 .42566 .71823 .419 Mtetra
.652 .749 .92 r
.71823 .419 .72375 .42566 .73582 .4221 .73034 .4155 Mtetra
.647 .75 .924 r
.73034 .4155 .73582 .4221 .74795 .41861 .74252 .41213 Mtetra
.632 .749 .932 r
.74252 .41213 .74795 .41861 .76016 .41543 .75479 .40914 Mtetra
.592 .74 .946 r
.75479 .40914 .76016 .41543 .77251 .41334 .76718 .40708 Mtetra
.529 .714 .957 r
.76718 .40708 .77251 .41334 .78513 .41376 .77974 .40637 Mtetra
.524 .673 .931 r
.77974 .40637 .78513 .41376 .79811 .4175 .79244 .40622 Mtetra
.604 .617 .838 r
.79244 .40622 .79811 .4175 .81129 .42203 .80507 .40446 Mtetra
.648 .562 .745 r
.80507 .40446 .81129 .42203 .82414 .4218 .8175 .39959 Mtetra
.658 .538 .706 r
.8175 .39959 .82414 .4218 .83635 .41396 .82978 .39264 Mtetra
.659 .543 .712 r
.82978 .39264 .83635 .41396 .84816 .40195 .8421 .38582 Mtetra
.664 .585 .756 r
.8421 .38582 .84816 .40195 .86009 .39117 .85458 .38021 Mtetra
.671 .658 .829 r
.85458 .38021 .86009 .39117 .87238 .38363 .86721 .37551 Mtetra
.673 .724 .888 r
.86721 .37551 .87238 .38363 .88494 .37832 .87992 .37114 Mtetra
.673 .753 .911 r
.87992 .37114 .88494 .37832 .89765 .37384 .89268 .36679 Mtetra
.674 .758 .914 r
.89268 .36679 .89765 .37384 .91043 .36952 .9055 .36237 Mtetra
.676 .757 .912 r
.9055 .36237 .91043 .36952 .92326 .36516 .91836 .35789 Mtetra
.664 .741 .908 r
.32893 .53277 .33554 .53892 .34605 .5356 .33948 .52942 Mtetra
.33948 .52942 .34605 .5356 .35661 .53226 .35006 .52606 Mtetra
.35006 .52606 .35661 .53226 .36722 .52891 .36069 .52268 Mtetra
.36069 .52268 .36722 .52891 .37786 .52554 .37136 .51929 Mtetra
.37136 .51929 .37786 .52554 .38855 .52216 .38207 .51589 Mtetra
.38207 .51589 .38855 .52216 .39928 .51877 .39283 .51247 Mtetra
.39283 .51247 .39928 .51877 .41005 .51537 .40363 .50904 Mtetra
.40363 .50904 .41005 .51537 .42087 .51195 .41447 .5056 Mtetra
.41447 .5056 .42087 .51195 .43173 .50851 .42536 .50214 Mtetra
.42536 .50214 .43173 .50851 .44263 .50507 .43629 .49867 Mtetra
.43629 .49867 .44263 .50507 .45358 .50161 .44727 .49518 Mtetra
.44727 .49518 .45358 .50161 .46457 .49813 .45829 .49168 Mtetra
.45829 .49168 .46457 .49813 .4756 .49464 .46935 .48816 Mtetra
.46935 .48816 .4756 .49464 .48668 .49114 .48046 .48463 Mtetra
.48046 .48463 .48668 .49114 .49781 .48762 .49162 .48109 Mtetra
.49162 .48109 .49781 .48762 .50898 .48409 .50282 .47753 Mtetra
.50282 .47753 .50898 .48409 .5202 .48054 .51406 .47396 Mtetra
.51406 .47396 .5202 .48054 .53146 .47698 .52536 .47037 Mtetra
.52536 .47037 .53146 .47698 .54277 .47341 .5367 .46677 Mtetra
.663 .741 .908 r
.5367 .46677 .54277 .47341 .55413 .46982 .54809 .46315 Mtetra
.54809 .46315 .55413 .46982 .56553 .46622 .55952 .45953 Mtetra
.55952 .45953 .56553 .46622 .57698 .4626 .571 .45588 Mtetra
.571 .45588 .57698 .4626 .58848 .45897 .58253 .45223 Mtetra
.58253 .45223 .58848 .45897 .60002 .45533 .59411 .44857 Mtetra
.663 .742 .909 r
.59411 .44857 .60002 .45533 .61162 .45168 .60573 .44489 Mtetra
.662 .742 .909 r
.60573 .44489 .61162 .45168 .62326 .44802 .61741 .44122 Mtetra
.61741 .44122 .62326 .44802 .63495 .44435 .62913 .43755 Mtetra
.661 .742 .91 r
.62913 .43755 .63495 .44435 .64669 .44069 .64091 .43388 Mtetra
.66 .743 .911 r
.64091 .43388 .64669 .44069 .65848 .43702 .65274 .43023 Mtetra
.659 .744 .913 r
.65274 .43023 .65848 .43702 .67033 .43337 .66462 .4266 Mtetra
.657 .745 .914 r
.66462 .4266 .67033 .43337 .68222 .42974 .67655 .42299 Mtetra
.655 .746 .916 r
.67655 .42299 .68222 .42974 .69417 .42613 .68854 .41943 Mtetra
.653 .747 .919 r
.68854 .41943 .69417 .42613 .70617 .42255 .70058 .4159 Mtetra
.651 .749 .922 r
.70058 .4159 .70617 .42255 .71823 .419 .71268 .41243 Mtetra
.648 .751 .925 r
.71268 .41243 .71823 .419 .73034 .4155 .72484 .40901 Mtetra
.642 .753 .929 r
.72484 .40901 .73034 .4155 .74252 .41213 .73706 .40573 Mtetra
.63 .753 .936 r
.73706 .40573 .74252 .41213 .75479 .40914 .74936 .40274 Mtetra
.613 .746 .941 r
.74936 .40274 .75479 .40914 .76718 .40708 .76176 .40018 Mtetra
.607 .728 .931 r
.76176 .40018 .76718 .40708 .77974 .40637 .77424 .39787 Mtetra
.628 .691 .889 r
.77424 .39787 .77974 .40637 .79244 .40622 .78675 .3951 Mtetra
.652 .645 .83 r
.78675 .3951 .79244 .40622 .80507 .40446 .79923 .39128 Mtetra
.661 .617 .794 r
.79923 .39128 .80507 .40446 .8175 .39959 .81169 .3866 Mtetra
.665 .622 .796 r
.81169 .3866 .8175 .39959 .82978 .39264 .82419 .38176 Mtetra
.668 .658 .831 r
.82419 .38176 .82978 .39264 .8421 .38582 .83676 .37719 Mtetra
.671 .71 .877 r
.83676 .37719 .8421 .38582 .85458 .38021 .84941 .37285 Mtetra
.672 .746 .907 r
.84941 .37285 .85458 .38021 .86721 .37551 .86212 .36853 Mtetra
.673 .76 .916 r
.86212 .36853 .86721 .37551 .87992 .37114 .87488 .36414 Mtetra
.676 .761 .915 r
.87488 .36414 .87992 .37114 .89268 .36679 .88768 .35965 Mtetra
.678 .759 .912 r
.88768 .35965 .89268 .36679 .9055 .36237 .90052 .35509 Mtetra
.678 .756 .91 r
.90052 .35509 .9055 .36237 .91836 .35789 .91341 .35047 Mtetra
.664 .741 .908 r
.32228 .52658 .32893 .53277 .33948 .52942 .33285 .5232 Mtetra
.33285 .5232 .33948 .52942 .35006 .52606 .34346 .51982 Mtetra
.34346 .51982 .35006 .52606 .36069 .52268 .35411 .51641 Mtetra
.35411 .51641 .36069 .52268 .37136 .51929 .36481 .513 Mtetra
.36481 .513 .37136 .51929 .38207 .51589 .37555 .50957 Mtetra
.37555 .50957 .38207 .51589 .39283 .51247 .38633 .50613 Mtetra
.38633 .50613 .39283 .51247 .40363 .50904 .39716 .50267 Mtetra
.39716 .50267 .40363 .50904 .41447 .5056 .40803 .4992 Mtetra
.40803 .4992 .41447 .5056 .42536 .50214 .41895 .49572 Mtetra
.41895 .49572 .42536 .50214 .43629 .49867 .42991 .49222 Mtetra
.42991 .49222 .43629 .49867 .44727 .49518 .44091 .48871 Mtetra
.44091 .48871 .44727 .49518 .45829 .49168 .45196 .48518 Mtetra
.45196 .48518 .45829 .49168 .46935 .48816 .46305 .48164 Mtetra
.46305 .48164 .46935 .48816 .48046 .48463 .47419 .47808 Mtetra
.47419 .47808 .48046 .48463 .49162 .48109 .48538 .47451 Mtetra
.48538 .47451 .49162 .48109 .50282 .47753 .49661 .47092 Mtetra
.49661 .47092 .50282 .47753 .51406 .47396 .50788 .46732 Mtetra
.50788 .46732 .51406 .47396 .52536 .47037 .51921 .46371 Mtetra
.663 .741 .908 r
.51921 .46371 .52536 .47037 .5367 .46677 .53058 .46008 Mtetra
.53058 .46008 .5367 .46677 .54809 .46315 .542 .45644 Mtetra
.542 .45644 .54809 .46315 .55952 .45953 .55346 .45279 Mtetra
.55346 .45279 .55952 .45953 .571 .45588 .56497 .44912 Mtetra
.56497 .44912 .571 .45588 .58253 .45223 .57654 .44544 Mtetra
.663 .742 .909 r
.57654 .44544 .58253 .45223 .59411 .44857 .58815 .44176 Mtetra
.662 .742 .909 r
.58815 .44176 .59411 .44857 .60573 .44489 .5998 .43808 Mtetra
.662 .742 .91 r
.5998 .43808 .60573 .44489 .61741 .44122 .61151 .4344 Mtetra
.661 .742 .91 r
.61151 .4344 .61741 .44122 .62913 .43755 .62327 .43072 Mtetra
.66 .743 .912 r
.62327 .43072 .62913 .43755 .64091 .43388 .63508 .42707 Mtetra
.658 .744 .913 r
.63508 .42707 .64091 .43388 .65274 .43023 .64695 .42344 Mtetra
.657 .745 .915 r
.64695 .42344 .65274 .43023 .66462 .4266 .65886 .41985 Mtetra
.654 .746 .917 r
.65886 .41985 .66462 .4266 .67655 .42299 .67083 .4163 Mtetra
.652 .748 .92 r
.67083 .4163 .67655 .42299 .68854 .41943 .68286 .4128 Mtetra
.649 .75 .923 r
.68286 .4128 .68854 .41943 .70058 .4159 .69495 .40936 Mtetra
.646 .753 .927 r
.69495 .40936 .70058 .4159 .71268 .41243 .70709 .40597 Mtetra
.643 .755 .93 r
.70709 .40597 .71268 .41243 .72484 .40901 .71929 .40265 Mtetra
.638 .758 .935 r
.71929 .40265 .72484 .40901 .73706 .40573 .73156 .39941 Mtetra
.633 .758 .938 r
.73156 .39941 .73706 .40573 .74936 .40274 .7439 .3963 Mtetra
.631 .754 .936 r
.7439 .3963 .74936 .40274 .76176 .40018 .7563 .39325 Mtetra
.637 .741 .924 r
.7563 .39325 .76176 .40018 .77424 .39787 .76875 .39007 Mtetra
.65 .721 .9 r
.76875 .39007 .77424 .39787 .78675 .3951 .78123 .38655 Mtetra
.659 .705 .881 r
.78123 .38655 .78675 .3951 .79923 .39128 .79375 .38268 Mtetra
.664 .706 .879 r
.79375 .38268 .79923 .39128 .81169 .3866 .8063 .37862 Mtetra
.666 .725 .893 r
.8063 .37862 .81169 .3866 .82419 .38176 .81891 .3745 Mtetra
.668 .748 .91 r
.81891 .3745 .82419 .38176 .83676 .37719 .83156 .37032 Mtetra
.671 .762 .919 r
.83156 .37032 .83676 .37719 .84941 .37285 .84426 .36602 Mtetra
.674 .766 .92 r
.84426 .36602 .84941 .37285 .86212 .36853 .85701 .36158 Mtetra
.678 .765 .917 r
.85701 .36158 .86212 .36853 .87488 .36414 .86979 .35702 Mtetra
.68 .761 .913 r
.86979 .35702 .87488 .36414 .88768 .35965 .88262 .35237 Mtetra
.681 .758 .909 r
.88262 .35237 .88768 .35965 .90052 .35509 .89549 .34766 Mtetra
.681 .754 .906 r
.89549 .34766 .90052 .35509 .91341 .35047 .90842 .34292 Mtetra
.664 .741 .908 r
.31558 .52034 .32228 .52658 .33285 .5232 .32617 .51694 Mtetra
.32617 .51694 .33285 .5232 .34346 .51982 .33681 .51353 Mtetra
.33681 .51353 .34346 .51982 .35411 .51641 .34749 .5101 Mtetra
.34749 .5101 .35411 .51641 .36481 .513 .35821 .50666 Mtetra
.35821 .50666 .36481 .513 .37555 .50957 .36898 .5032 Mtetra
.36898 .5032 .37555 .50957 .38633 .50613 .37979 .49974 Mtetra
.37979 .49974 .38633 .50613 .39716 .50267 .39065 .49625 Mtetra
.39065 .49625 .39716 .50267 .40803 .4992 .40154 .49276 Mtetra
.40154 .49276 .40803 .4992 .41895 .49572 .41249 .48925 Mtetra
.41249 .48925 .41895 .49572 .42991 .49222 .42347 .48572 Mtetra
.42347 .48572 .42991 .49222 .44091 .48871 .4345 .48218 Mtetra
.4345 .48218 .44091 .48871 .45196 .48518 .44558 .47863 Mtetra
.44558 .47863 .45196 .48518 .46305 .48164 .4567 .47506 Mtetra
.4567 .47506 .46305 .48164 .47419 .47808 .46787 .47148 Mtetra
.46787 .47148 .47419 .47808 .48538 .47451 .47909 .46788 Mtetra
.47909 .46788 .48538 .47451 .49661 .47092 .49035 .46427 Mtetra
.49035 .46427 .49661 .47092 .50788 .46732 .50166 .46064 Mtetra
.663 .741 .908 r
.50166 .46064 .50788 .46732 .51921 .46371 .51301 .457 Mtetra
.51301 .457 .51921 .46371 .53058 .46008 .52441 .45334 Mtetra
.52441 .45334 .53058 .46008 .542 .45644 .53586 .44968 Mtetra
.53586 .44968 .542 .45644 .55346 .45279 .54736 .446 Mtetra
.54736 .446 .55346 .45279 .56497 .44912 .5589 .44231 Mtetra
.663 .742 .909 r
.5589 .44231 .56497 .44912 .57654 .44544 .57049 .43862 Mtetra
.662 .742 .909 r
.57049 .43862 .57654 .44544 .58815 .44176 .58214 .43492 Mtetra
.662 .742 .91 r
.58214 .43492 .58815 .44176 .5998 .43808 .59383 .43123 Mtetra
.661 .742 .911 r
.59383 .43123 .5998 .43808 .61151 .4344 .60557 .42756 Mtetra
.659 .743 .912 r
.60557 .42756 .61151 .4344 .62327 .43072 .61737 .4239 Mtetra
.658 .744 .913 r
.61737 .4239 .62327 .43072 .63508 .42707 .62921 .42027 Mtetra
.656 .745 .916 r
.62921 .42027 .63508 .42707 .64695 .42344 .64111 .41669 Mtetra
.653 .746 .918 r
.64111 .41669 .64695 .42344 .65886 .41985 .65307 .41316 Mtetra
.65 .748 .921 r
.65307 .41316 .65886 .41985 .67083 .4163 .66508 .40969 Mtetra
.647 .751 .925 r
.66508 .40969 .67083 .4163 .68286 .4128 .67715 .40628 Mtetra
.644 .754 .929 r
.67715 .40628 .68286 .4128 .69495 .40936 .68928 .40294 Mtetra
.641 .757 .933 r
.68928 .40294 .69495 .40936 .70709 .40597 .70147 .39965 Mtetra
.638 .76 .937 r
.70147 .39965 .70709 .40597 .71929 .40265 .71372 .39642 Mtetra
.635 .763 .94 r
.71372 .39642 .71929 .40265 .73156 .39941 .72603 .39322 Mtetra
.634 .765 .942 r
.72603 .39322 .73156 .39941 .7439 .3963 .7384 .39003 Mtetra
.636 .764 .94 r
.7384 .39003 .7439 .3963 .7563 .39325 .75083 .38676 Mtetra
.642 .76 .934 r
.75083 .38676 .7563 .39325 .76875 .39007 .7633 .38336 Mtetra
.649 .756 .928 r
.7633 .38336 .76875 .39007 .78123 .38655 .77582 .37976 Mtetra
.655 .757 .925 r
.77582 .37976 .78123 .38655 .79375 .38268 .78839 .37598 Mtetra
.66 .762 .926 r
.78839 .37598 .79375 .38268 .8063 .37862 .801 .37203 Mtetra
.665 .769 .927 r
.801 .37203 .8063 .37862 .81891 .3745 .81365 .3679 Mtetra
.67 .772 .926 r
.81365 .3679 .81891 .3745 .83156 .37032 .82634 .36359 Mtetra
.675 .771 .922 r
.82634 .36359 .83156 .37032 .84426 .36602 .83907 .35911 Mtetra
.679 .767 .918 r
.83907 .35911 .84426 .36602 .85701 .36158 .85184 .35448 Mtetra
.682 .763 .913 r
.85184 .35448 .85701 .36158 .86979 .35702 .86465 .34974 Mtetra
.684 .759 .909 r
.86465 .34974 .86979 .35702 .88262 .35237 .8775 .34492 Mtetra
.684 .755 .906 r
.8775 .34492 .88262 .35237 .89549 .34766 .89041 .34006 Mtetra
.683 .752 .903 r
.89041 .34006 .89549 .34766 .90842 .34292 .90337 .33521 Mtetra
.664 .741 .908 r
.30883 .51405 .31558 .52034 .32617 .51694 .31945 .51063 Mtetra
.31945 .51063 .32617 .51694 .33681 .51353 .33011 .50719 Mtetra
.33011 .50719 .33681 .51353 .34749 .5101 .34082 .50374 Mtetra
.34082 .50374 .34749 .5101 .35821 .50666 .35157 .50027 Mtetra
.35157 .50027 .35821 .50666 .36898 .5032 .36236 .49679 Mtetra
.36236 .49679 .36898 .5032 .37979 .49974 .3732 .4933 Mtetra
.3732 .4933 .37979 .49974 .39065 .49625 .38408 .48979 Mtetra
.38408 .48979 .39065 .49625 .40154 .49276 .39501 .48626 Mtetra
.39501 .48626 .40154 .49276 .41249 .48925 .40598 .48273 Mtetra
.40598 .48273 .41249 .48925 .42347 .48572 .41699 .47918 Mtetra
.41699 .47918 .42347 .48572 .4345 .48218 .42805 .47561 Mtetra
.42805 .47561 .4345 .48218 .44558 .47863 .43916 .47203 Mtetra
.43916 .47203 .44558 .47863 .4567 .47506 .45031 .46843 Mtetra
.45031 .46843 .4567 .47506 .46787 .47148 .46151 .46482 Mtetra
.46151 .46482 .46787 .47148 .47909 .46788 .47275 .4612 Mtetra
.47275 .4612 .47909 .46788 .49035 .46427 .48404 .45756 Mtetra
.663 .741 .908 r
.48404 .45756 .49035 .46427 .50166 .46064 .49538 .45391 Mtetra
.49538 .45391 .50166 .46064 .51301 .457 .50676 .45024 Mtetra
.50676 .45024 .51301 .457 .52441 .45334 .5182 .44656 Mtetra
.5182 .44656 .52441 .45334 .53586 .44968 .52968 .44287 Mtetra
.52968 .44287 .53586 .44968 .54736 .446 .5412 .43917 Mtetra
.663 .742 .909 r
.5412 .43917 .54736 .446 .5589 .44231 .55278 .43546 Mtetra
.662 .742 .909 r
.55278 .43546 .5589 .44231 .57049 .43862 .56441 .43176 Mtetra
.661 .742 .91 r
.56441 .43176 .57049 .43862 .58214 .43492 .57608 .42806 Mtetra
.66 .742 .911 r
.57608 .42806 .58214 .43492 .59383 .43123 .58781 .42437 Mtetra
.659 .743 .912 r
.58781 .42437 .59383 .43123 .60557 .42756 .59959 .42072 Mtetra
.657 .744 .914 r
.59959 .42072 .60557 .42756 .61737 .4239 .61142 .41709 Mtetra
.655 .745 .916 r
.61142 .41709 .61737 .4239 .62921 .42027 .6233 .41352 Mtetra
.652 .747 .919 r
.6233 .41352 .62921 .42027 .64111 .41669 .63524 .41 Mtetra
.649 .749 .922 r
.63524 .41 .64111 .41669 .65307 .41316 .64723 .40656 Mtetra
.645 .751 .926 r
.64723 .40656 .65307 .41316 .66508 .40969 .65929 .40319 Mtetra
.641 .754 .931 r
.65929 .40319 .66508 .40969 .67715 .40628 .6714 .3999 Mtetra
.638 .758 .935 r
.6714 .3999 .67715 .40628 .68928 .40294 .68357 .39668 Mtetra
.634 .762 .939 r
.68357 .39668 .68928 .40294 .70147 .39965 .69581 .39351 Mtetra
.631 .765 .943 r
.69581 .39351 .70147 .39965 .71372 .39642 .7081 .39036 Mtetra
.63 .769 .946 r
.7081 .39036 .71372 .39642 .72603 .39322 .72046 .38721 Mtetra
.631 .772 .948 r
.72046 .38721 .72603 .39322 .7384 .39003 .73287 .384 Mtetra
.635 .774 .947 r
.73287 .384 .7384 .39003 .75083 .38676 .74534 .38068 Mtetra
.641 .775 .945 r
.74534 .38068 .75083 .38676 .7633 .38336 .75785 .3772 Mtetra
.647 .776 .942 r
.75785 .3772 .7633 .38336 .77582 .37976 .77042 .37354 Mtetra
.655 .778 .939 r
.77042 .37354 .77582 .37976 .78839 .37598 .78302 .36966 Mtetra
.662 .778 .935 r
.78302 .36966 .78839 .37598 .801 .37203 .79566 .36557 Mtetra
.67 .777 .93 r
.79566 .36557 .801 .37203 .81365 .3679 .80834 .36125 Mtetra
.676 .774 .924 r
.80834 .36125 .81365 .3679 .82634 .36359 .82106 .35672 Mtetra
.681 .77 .918 r
.82106 .35672 .82634 .36359 .83907 .35911 .83381 .35202 Mtetra
.685 .765 .913 r
.83381 .35202 .83907 .35911 .85184 .35448 .84661 .34718 Mtetra
.686 .761 .908 r
.84661 .34718 .85184 .35448 .86465 .34974 .85945 .34225 Mtetra
.687 .756 .904 r
.85945 .34225 .86465 .34974 .8775 .34492 .87233 .33727 Mtetra
.686 .752 .902 r
.87233 .33727 .8775 .34492 .89041 .34006 .88527 .33229 Mtetra
.685 .749 .9 r
.88527 .33229 .89041 .34006 .90337 .33521 .89826 .32734 Mtetra
.664 .741 .908 r
.30203 .50772 .30883 .51405 .31945 .51063 .31267 .50427 Mtetra
.31267 .50427 .31945 .51063 .33011 .50719 .32336 .5008 Mtetra
.32336 .5008 .33011 .50719 .34082 .50374 .33409 .49733 Mtetra
.33409 .49733 .34082 .50374 .35157 .50027 .34487 .49383 Mtetra
.34487 .49383 .35157 .50027 .36236 .49679 .35569 .49033 Mtetra
.35569 .49033 .36236 .49679 .3732 .4933 .36656 .48681 Mtetra
.36656 .48681 .3732 .4933 .38408 .48979 .37746 .48327 Mtetra
.37746 .48327 .38408 .48979 .39501 .48626 .38842 .47972 Mtetra
.38842 .47972 .39501 .48626 .40598 .48273 .39942 .47616 Mtetra
.39942 .47616 .40598 .48273 .41699 .47918 .41046 .47258 Mtetra
.41046 .47258 .41699 .47918 .42805 .47561 .42155 .46899 Mtetra
.42155 .46899 .42805 .47561 .43916 .47203 .43268 .46538 Mtetra
.43268 .46538 .43916 .47203 .45031 .46843 .44386 .46176 Mtetra
.44386 .46176 .45031 .46843 .46151 .46482 .45509 .45812 Mtetra
.45509 .45812 .46151 .46482 .47275 .4612 .46637 .45447 Mtetra
.663 .741 .908 r
.46637 .45447 .47275 .4612 .48404 .45756 .47769 .4508 Mtetra
.47769 .4508 .48404 .45756 .49538 .45391 .48905 .44712 Mtetra
.48905 .44712 .49538 .45391 .50676 .45024 .50047 .44343 Mtetra
.50047 .44343 .50676 .45024 .5182 .44656 .51193 .43972 Mtetra
.51193 .43972 .5182 .44656 .52968 .44287 .52344 .43601 Mtetra
.663 .742 .909 r
.52344 .43601 .52968 .44287 .5412 .43917 .535 .4323 Mtetra
.662 .742 .909 r
.535 .4323 .5412 .43917 .55278 .43546 .54661 .42858 Mtetra
.661 .742 .91 r
.54661 .42858 .55278 .43546 .56441 .43176 .55827 .42487 Mtetra
.66 .743 .911 r
.55827 .42487 .56441 .43176 .57608 .42806 .56998 .42118 Mtetra
.659 .743 .912 r
.56998 .42118 .57608 .42806 .58781 .42437 .58174 .41752 Mtetra
.657 .744 .914 r
.58174 .41752 .58781 .42437 .59959 .42072 .59355 .4139 Mtetra
.654 .745 .917 r
.59355 .4139 .59959 .42072 .61142 .41709 .60542 .41033 Mtetra
.651 .747 .92 r
.60542 .41033 .61142 .41709 .6233 .41352 .61734 .40683 Mtetra
.647 .749 .924 r
.61734 .40683 .6233 .41352 .63524 .41 .62932 .40341 Mtetra
.643 .752 .928 r
.62932 .40341 .63524 .41 .64723 .40656 .64135 .40009 Mtetra
.639 .755 .933 r
.64135 .40009 .64723 .40656 .65929 .40319 .65345 .39685 Mtetra
.634 .759 .937 r
.65345 .39685 .65929 .40319 .6714 .3999 .66561 .39369 Mtetra
.63 .763 .942 r
.66561 .39369 .6714 .3999 .68357 .39668 .67783 .3906 Mtetra
.627 .767 .947 r
.67783 .3906 .68357 .39668 .69581 .39351 .69011 .38754 Mtetra
.625 .771 .95 r
.69011 .38754 .69581 .39351 .7081 .39036 .70245 .38448 Mtetra
.626 .775 .953 r
.70245 .38448 .7081 .39036 .72046 .38721 .71485 .38136 Mtetra
.629 .779 .953 r
.71485 .38136 .72046 .38721 .73287 .384 .72731 .37814 Mtetra
.634 .782 .952 r
.72731 .37814 .73287 .384 .74534 .38068 .73982 .37476 Mtetra
.642 .784 .949 r
.73982 .37476 .74534 .38068 .75785 .3772 .75237 .37118 Mtetra
.651 .784 .945 r
.75237 .37118 .75785 .3772 .77042 .37354 .76497 .36736 Mtetra
.66 .783 .94 r
.76497 .36736 .77042 .37354 .78302 .36966 .7776 .36329 Mtetra
.669 .781 .933 r
.7776 .36329 .78302 .36966 .79566 .36557 .79027 .35897 Mtetra
.677 .777 .926 r
.79027 .35897 .79566 .36557 .80834 .36125 .80298 .3544 Mtetra
.683 .772 .919 r
.80298 .3544 .80834 .36125 .82106 .35672 .81572 .34963 Mtetra
.687 .767 .912 r
.81572 .34963 .82106 .35672 .83381 .35202 .8285 .3447 Mtetra
.689 .762 .907 r
.8285 .3447 .83381 .35202 .84661 .34718 .84132 .33965 Mtetra
.69 .757 .903 r
.84132 .33965 .84661 .34718 .85945 .34225 .85419 .33455 Mtetra
.689 .753 .9 r
.85419 .33455 .85945 .34225 .87233 .33727 .8671 .32944 Mtetra
.688 .749 .898 r
.8671 .32944 .87233 .33727 .88527 .33229 .88008 .32435 Mtetra
.686 .746 .898 r
.88008 .32435 .88527 .33229 .89826 .32734 .89311 .31933 Mtetra
.664 .741 .908 r
.29517 .50134 .30203 .50772 .31267 .50427 .30585 .49786 Mtetra
.30585 .49786 .31267 .50427 .32336 .5008 .31656 .49437 Mtetra
.31656 .49437 .32336 .5008 .33409 .49733 .32732 .49087 Mtetra
.32732 .49087 .33409 .49733 .34487 .49383 .33812 .48735 Mtetra
.33812 .48735 .34487 .49383 .35569 .49033 .34897 .48382 Mtetra
.34897 .48382 .35569 .49033 .36656 .48681 .35986 .48027 Mtetra
.35986 .48027 .36656 .48681 .37746 .48327 .3708 .47671 Mtetra
.3708 .47671 .37746 .48327 .38842 .47972 .38178 .47313 Mtetra
.38178 .47313 .38842 .47972 .39942 .47616 .39281 .46954 Mtetra
.39281 .46954 .39942 .47616 .41046 .47258 .40388 .46594 Mtetra
.40388 .46594 .41046 .47258 .42155 .46899 .415 .46231 Mtetra
.415 .46231 .42155 .46899 .43268 .46538 .42616 .45868 Mtetra
.42616 .45868 .43268 .46538 .44386 .46176 .43737 .45503 Mtetra
.43737 .45503 .44386 .46176 .45509 .45812 .44863 .45136 Mtetra
.663 .741 .908 r
.44863 .45136 .45509 .45812 .46637 .45447 .45993 .44768 Mtetra
.45993 .44768 .46637 .45447 .47769 .4508 .47128 .44399 Mtetra
.47128 .44399 .47769 .4508 .48905 .44712 .48268 .44029 Mtetra
.48268 .44029 .48905 .44712 .50047 .44343 .49413 .43657 Mtetra
.49413 .43657 .50047 .44343 .51193 .43972 .50562 .43284 Mtetra
.663 .742 .909 r
.50562 .43284 .51193 .43972 .52344 .43601 .51716 .42912 Mtetra
.662 .742 .909 r
.51716 .42912 .52344 .43601 .535 .4323 .52876 .42539 Mtetra
.661 .742 .91 r
.52876 .42539 .535 .4323 .54661 .42858 .5404 .42167 Mtetra
.66 .743 .911 r
.5404 .42167 .54661 .42858 .55827 .42487 .55209 .41797 Mtetra
.658 .743 .913 r
.55209 .41797 .55827 .42487 .56998 .42118 .56383 .4143 Mtetra
.656 .744 .915 r
.56383 .4143 .56998 .42118 .58174 .41752 .57563 .41068 Mtetra
.653 .745 .917 r
.57563 .41068 .58174 .41752 .59355 .4139 .58747 .40712 Mtetra
.65 .747 .921 r
.58747 .40712 .59355 .4139 .60542 .41033 .59938 .40364 Mtetra
.646 .749 .925 r
.59938 .40364 .60542 .41033 .61734 .40683 .61134 .40025 Mtetra
.641 .752 .929 r
.61134 .40025 .61734 .40683 .62932 .40341 .62336 .39696 Mtetra
.636 .755 .934 r
.62336 .39696 .62932 .40341 .64135 .40009 .63543 .39377 Mtetra
.631 .759 .94 r
.63543 .39377 .64135 .40009 .65345 .39685 .64758 .39068 Mtetra
.626 .763 .945 r
.64758 .39068 .65345 .39685 .66561 .39369 .65978 .38767 Mtetra
.622 .768 .95 r
.65978 .38767 .66561 .39369 .67783 .3906 .67205 .3847 Mtetra
.619 .773 .954 r
.67205 .3847 .67783 .3906 .69011 .38754 .68437 .38174 Mtetra
.619 .777 .957 r
.68437 .38174 .69011 .38754 .70245 .38448 .69676 .37874 Mtetra
.622 .781 .958 r
.69676 .37874 .70245 .38448 .71485 .38136 .70921 .37562 Mtetra
.628 .785 .957 r
.70921 .37562 .71485 .38136 .72731 .37814 .72171 .37235 Mtetra
.637 .787 .954 r
.72171 .37235 .72731 .37814 .73982 .37476 .73425 .36885 Mtetra
.647 .787 .949 r
.73425 .36885 .73982 .37476 .75237 .37118 .74684 .3651 Mtetra
.658 .786 .943 r
.74684 .3651 .75237 .37118 .76497 .36736 .75947 .36106 Mtetra
.668 .784 .935 r
.75947 .36106 .76497 .36736 .7776 .36329 .77213 .35673 Mtetra
.677 .779 .927 r
.77213 .35673 .7776 .36329 .79027 .35897 .78482 .35214 Mtetra
.684 .774 .919 r
.78482 .35214 .79027 .35897 .80298 .3544 .79755 .3473 Mtetra
.689 .768 .912 r
.79755 .3473 .80298 .3544 .81572 .34963 .81032 .34227 Mtetra
.692 .763 .906 r
.81032 .34227 .81572 .34963 .8285 .3447 .82312 .33712 Mtetra
.693 .758 .901 r
.82312 .33712 .8285 .3447 .84132 .33965 .83597 .33188 Mtetra
.693 .753 .898 r
.83597 .33188 .84132 .33965 .85419 .33455 .84887 .32663 Mtetra
.691 .749 .896 r
.84887 .32663 .85419 .33455 .8671 .32944 .86182 .32141 Mtetra
.689 .746 .895 r
.86182 .32141 .8671 .32944 .88008 .32435 .87483 .31625 Mtetra
.686 .744 .895 r
.87483 .31625 .88008 .32435 .89311 .31933 .8879 .31119 Mtetra
.664 .741 .908 r
.28827 .49491 .29517 .50134 .30585 .49786 .29897 .49141 Mtetra
.29897 .49141 .30585 .49786 .31656 .49437 .30971 .48789 Mtetra
.30971 .48789 .31656 .49437 .32732 .49087 .3205 .48436 Mtetra
.3205 .48436 .32732 .49087 .33812 .48735 .33133 .48082 Mtetra
.33133 .48082 .33812 .48735 .34897 .48382 .3422 .47726 Mtetra
.3422 .47726 .34897 .48382 .35986 .48027 .35312 .47368 Mtetra
.35312 .47368 .35986 .48027 .3708 .47671 .36408 .47009 Mtetra
.36408 .47009 .3708 .47671 .38178 .47313 .37509 .46649 Mtetra
.37509 .46649 .38178 .47313 .39281 .46954 .38615 .46287 Mtetra
.38615 .46287 .39281 .46954 .40388 .46594 .39725 .45924 Mtetra
.39725 .45924 .40388 .46594 .415 .46231 .4084 .45559 Mtetra
.4084 .45559 .415 .46231 .42616 .45868 .41959 .45193 Mtetra
.41959 .45193 .42616 .45868 .43737 .45503 .43083 .44825 Mtetra
.663 .741 .908 r
.43083 .44825 .43737 .45503 .44863 .45136 .44211 .44456 Mtetra
.44211 .44456 .44863 .45136 .45993 .44768 .45345 .44085 Mtetra
.45345 .44085 .45993 .44768 .47128 .44399 .46483 .43713 Mtetra
.46483 .43713 .47128 .44399 .48268 .44029 .47626 .4334 Mtetra
.47626 .4334 .48268 .44029 .49413 .43657 .48774 .42967 Mtetra
.663 .742 .909 r
.48774 .42967 .49413 .43657 .50562 .43284 .49926 .42592 Mtetra
.662 .742 .909 r
.49926 .42592 .50562 .43284 .51716 .42912 .51084 .42219 Mtetra
.661 .742 .91 r
.51084 .42219 .51716 .42912 .52876 .42539 .52246 .41846 Mtetra
.66 .743 .911 r
.52246 .41846 .52876 .42539 .5404 .42167 .53413 .41475 Mtetra
.658 .743 .913 r
.53413 .41475 .5404 .42167 .55209 .41797 .54586 .41108 Mtetra
.656 .744 .915 r
.54586 .41108 .55209 .41797 .56383 .4143 .55763 .40745 Mtetra
.653 .745 .918 r
.55763 .40745 .56383 .4143 .57563 .41068 .56946 .4039 Mtetra
.649 .747 .921 r
.56946 .4039 .57563 .41068 .58747 .40712 .58135 .40043 Mtetra
.645 .749 .925 r
.58135 .40043 .58747 .40712 .59938 .40364 .59329 .39706 Mtetra
.639 .752 .93 r
.59329 .39706 .59938 .40364 .61134 .40025 .60529 .3938 Mtetra
.633 .756 .936 r
.60529 .3938 .61134 .40025 .62336 .39696 .61735 .39066 Mtetra
.627 .76 .942 r
.61735 .39066 .62336 .39696 .63543 .39377 .62947 .38764 Mtetra
.621 .764 .948 r
.62947 .38764 .63543 .39377 .64758 .39068 .64166 .3847 Mtetra
.616 .769 .953 r
.64166 .3847 .64758 .39068 .65978 .38767 .65391 .38183 Mtetra
.613 .773 .957 r
.65391 .38183 .65978 .38767 .67205 .3847 .66622 .37898 Mtetra
.613 .778 .96 r
.66622 .37898 .67205 .3847 .68437 .38174 .6786 .37609 Mtetra
.616 .783 .961 r
.6786 .37609 .68437 .38174 .69676 .37874 .69103 .37309 Mtetra
.622 .786 .961 r
.69103 .37309 .69676 .37874 .70921 .37562 .70352 .36992 Mtetra
.631 .789 .958 r
.70352 .36992 .70921 .37562 .72171 .37235 .71605 .36652 Mtetra
.643 .79 .952 r
.71605 .36652 .72171 .37235 .73425 .36885 .72863 .36284 Mtetra
.655 .789 .946 r
.72863 .36284 .73425 .36885 .74684 .3651 .74125 .35884 Mtetra
.667 .786 .937 r
.74125 .35884 .74684 .3651 .75947 .36106 .7539 .35453 Mtetra
.677 .781 .928 r
.7539 .35453 .75947 .36106 .77213 .35673 .76659 .34991 Mtetra
.686 .775 .919 r
.76659 .34991 .77213 .35673 .78482 .35214 .77931 .34501 Mtetra
.691 .769 .911 r
.77931 .34501 .78482 .35214 .79755 .3473 .79206 .3399 Mtetra
.695 .763 .904 r
.79206 .3399 .79755 .3473 .81032 .34227 .80485 .33463 Mtetra
.696 .758 .899 r
.80485 .33463 .81032 .34227 .82312 .33712 .81768 .32927 Mtetra
.696 .753 .895 r
.81768 .32927 .82312 .33712 .83597 .33188 .83056 .32388 Mtetra
.694 .749 .893 r
.83056 .32388 .83597 .33188 .84887 .32663 .84349 .31851 Mtetra
.692 .745 .893 r
.84349 .31851 .84887 .32663 .86182 .32141 .85648 .31322 Mtetra
.688 .743 .893 r
.85648 .31322 .86182 .32141 .87483 .31625 .86953 .30802 Mtetra
.685 .741 .894 r
.86953 .30802 .87483 .31625 .8879 .31119 .88265 .30293 Mtetra
.664 .741 .908 r
.28131 .48843 .28827 .49491 .29897 .49141 .29204 .48491 Mtetra
.29204 .48491 .29897 .49141 .30971 .48789 .30281 .48136 Mtetra
.30281 .48136 .30971 .48789 .3205 .48436 .31362 .47781 Mtetra
.31362 .47781 .3205 .48436 .33133 .48082 .32448 .47423 Mtetra
.32448 .47423 .33133 .48082 .3422 .47726 .33538 .47065 Mtetra
.33538 .47065 .3422 .47726 .35312 .47368 .34633 .46705 Mtetra
.34633 .46705 .35312 .47368 .36408 .47009 .35732 .46343 Mtetra
.35732 .46343 .36408 .47009 .37509 .46649 .36835 .4598 Mtetra
.36835 .4598 .37509 .46649 .38615 .46287 .37944 .45615 Mtetra
.37944 .45615 .38615 .46287 .39725 .45924 .39057 .45249 Mtetra
.39057 .45249 .39725 .45924 .4084 .45559 .40174 .44882 Mtetra
.40174 .44882 .4084 .45559 .41959 .45193 .41296 .44512 Mtetra
.663 .741 .908 r
.41296 .44512 .41959 .45193 .43083 .44825 .42423 .44142 Mtetra
.42423 .44142 .43083 .44825 .44211 .44456 .43555 .4377 Mtetra
.43555 .4377 .44211 .44456 .45345 .44085 .44691 .43397 Mtetra
.44691 .43397 .45345 .44085 .46483 .43713 .45833 .43023 Mtetra
.45833 .43023 .46483 .43713 .47626 .4334 .46978 .42647 Mtetra
.662 .742 .909 r
.46978 .42647 .47626 .4334 .48774 .42967 .48129 .42272 Mtetra
.48129 .42272 .48774 .42967 .49926 .42592 .49285 .41897 Mtetra
.661 .742 .91 r
.49285 .41897 .49926 .42592 .51084 .42219 .50446 .41523 Mtetra
.66 .743 .911 r
.50446 .41523 .51084 .42219 .52246 .41846 .51611 .41151 Mtetra
.658 .743 .913 r
.51611 .41151 .52246 .41846 .53413 .41475 .52782 .40783 Mtetra
.655 .744 .915 r
.52782 .40783 .53413 .41475 .54586 .41108 .53958 .4042 Mtetra
.652 .745 .918 r
.53958 .4042 .54586 .41108 .55763 .40745 .55139 .40065 Mtetra
.648 .747 .922 r
.55139 .40065 .55763 .40745 .56946 .4039 .56325 .39719 Mtetra
.643 .749 .926 r
.56325 .39719 .56946 .4039 .58135 .40043 .57517 .39384 Mtetra
.638 .752 .931 r
.57517 .39384 .58135 .40043 .59329 .39706 .58715 .39061 Mtetra
.631 .756 .937 r
.58715 .39061 .59329 .39706 .60529 .3938 .59919 .38752 Mtetra
.624 .76 .943 r
.59919 .38752 .60529 .3938 .61735 .39066 .6113 .38455 Mtetra
.617 .764 .95 r
.6113 .38455 .61735 .39066 .62947 .38764 .62346 .38169 Mtetra
.611 .769 .955 r
.62346 .38169 .62947 .38764 .64166 .3847 .6357 .37892 Mtetra
.607 .774 .96 r
.6357 .37892 .64166 .3847 .65391 .38183 .64799 .37617 Mtetra
.606 .779 .963 r
.64799 .37617 .65391 .38183 .66622 .37898 .66035 .37339 Mtetra
.609 .783 .965 r
.66035 .37339 .66622 .37898 .6786 .37609 .67277 .37051 Mtetra
.615 .787 .964 r
.67277 .37051 .6786 .37609 .69103 .37309 .68525 .36745 Mtetra
.626 .79 .961 r
.68525 .36745 .69103 .37309 .70352 .36992 .69777 .36415 Mtetra
.638 .791 .956 r
.69777 .36415 .70352 .36992 .71605 .36652 .71034 .36055 Mtetra
.652 .79 .948 r
.71034 .36055 .71605 .36652 .72863 .36284 .72295 .35661 Mtetra
.666 .787 .939 r
.72295 .35661 .72863 .36284 .74125 .35884 .7356 .35232 Mtetra
.677 .782 .929 r
.7356 .35232 .74125 .35884 .7539 .35453 .74827 .34769 Mtetra
.687 .776 .919 r
.74827 .34769 .7539 .35453 .76659 .34991 .76098 .34275 Mtetra
.693 .77 .91 r
.76098 .34275 .76659 .34991 .77931 .34501 .77372 .33755 Mtetra
.697 .763 .903 r
.77372 .33755 .77931 .34501 .79206 .3399 .7865 .33218 Mtetra
.699 .757 .897 r
.7865 .33218 .79206 .3399 .80485 .33463 .79931 .32669 Mtetra
.699 .752 .893 r
.79931 .32669 .80485 .33463 .81768 .32927 .81218 .32116 Mtetra
.697 .748 .89 r
.81218 .32116 .81768 .32927 .83056 .32388 .82509 .31565 Mtetra
.695 .744 .89 r
.82509 .31565 .83056 .32388 .84349 .31851 .83806 .31022 Mtetra
.691 .742 .89 r
.83806 .31022 .84349 .31851 .85648 .31322 .85109 .30489 Mtetra
.687 .741 .892 r
.85109 .30489 .85648 .31322 .86953 .30802 .86419 .29968 Mtetra
.684 .74 .894 r
.86419 .29968 .86953 .30802 .88265 .30293 .87736 .29459 Mtetra
.664 .741 .908 r
.27431 .48191 .28131 .48843 .29204 .48491 .28506 .47835 Mtetra
.28506 .47835 .29204 .48491 .30281 .48136 .29585 .47478 Mtetra
.29585 .47478 .30281 .48136 .31362 .47781 .30669 .4712 Mtetra
.30669 .4712 .31362 .47781 .32448 .47423 .31758 .4676 Mtetra
.31758 .4676 .32448 .47423 .33538 .47065 .3285 .46399 Mtetra
.3285 .46399 .33538 .47065 .34633 .46705 .33948 .46036 Mtetra
.33948 .46036 .34633 .46705 .35732 .46343 .3505 .45671 Mtetra
.3505 .45671 .35732 .46343 .36835 .4598 .36156 .45306 Mtetra
.36156 .45306 .36835 .4598 .37944 .45615 .37268 .44938 Mtetra
.37268 .44938 .37944 .45615 .39057 .45249 .38383 .44569 Mtetra
.38383 .44569 .39057 .45249 .40174 .44882 .39504 .44199 Mtetra
.663 .741 .908 r
.39504 .44199 .40174 .44882 .41296 .44512 .40629 .43827 Mtetra
.40629 .43827 .41296 .44512 .42423 .44142 .41759 .43454 Mtetra
.41759 .43454 .42423 .44142 .43555 .4377 .42893 .43079 Mtetra
.42893 .43079 .43555 .4377 .44691 .43397 .44033 .42704 Mtetra
.44033 .42704 .44691 .43397 .45833 .43023 .45177 .42327 Mtetra
.662 .742 .909 r
.45177 .42327 .45833 .43023 .46978 .42647 .46326 .4195 Mtetra
.46326 .4195 .46978 .42647 .48129 .42272 .4748 .41574 Mtetra
.661 .742 .91 r
.4748 .41574 .48129 .42272 .49285 .41897 .48639 .41199 Mtetra
.66 .742 .911 r
.48639 .41199 .49285 .41897 .50446 .41523 .49803 .40826 Mtetra
.658 .743 .913 r
.49803 .40826 .50446 .41523 .51611 .41151 .50971 .40457 Mtetra
.655 .744 .915 r
.50971 .40457 .51611 .41151 .52782 .40783 .52145 .40094 Mtetra
.652 .745 .918 r
.52145 .40094 .52782 .40783 .53958 .4042 .53324 .39738 Mtetra
.648 .747 .922 r
.53324 .39738 .53958 .4042 .55139 .40065 .54509 .39392 Mtetra
.642 .749 .927 r
.54509 .39392 .55139 .40065 .56325 .39719 .55699 .39059 Mtetra
.636 .752 .932 r
.55699 .39059 .56325 .39719 .57517 .39384 .56895 .38739 Mtetra
.629 .756 .938 r
.56895 .38739 .57517 .39384 .58715 .39061 .58097 .38433 Mtetra
.621 .76 .945 r
.58097 .38433 .58715 .39061 .59919 .38752 .59305 .38142 Mtetra
.613 .764 .952 r
.59305 .38142 .59919 .38752 .6113 .38455 .6052 .37863 Mtetra
.606 .769 .958 r
.6052 .37863 .6113 .38455 .62346 .38169 .61741 .37594 Mtetra
.601 .774 .963 r
.61741 .37594 .62346 .38169 .6357 .37892 .62969 .37329 Mtetra
.599 .779 .966 r
.62969 .37329 .6357 .37892 .64799 .37617 .64203 .37063 Mtetra
.602 .783 .968 r
.64203 .37063 .64799 .37617 .66035 .37339 .65443 .36786 Mtetra
.608 .788 .967 r
.65443 .36786 .66035 .37339 .67277 .37051 .66689 .36492 Mtetra
.619 .791 .964 r
.66689 .36492 .67277 .37051 .68525 .36745 .67941 .36173 Mtetra
.634 .792 .958 r
.67941 .36173 .68525 .36745 .69777 .36415 .69197 .35822 Mtetra
.649 .791 .95 r
.69197 .35822 .69777 .36415 .71034 .36055 .70457 .35435 Mtetra
.664 .788 .94 r
.70457 .35435 .71034 .36055 .72295 .35661 .7172 .35009 Mtetra
.677 .783 .93 r
.7172 .35009 .72295 .35661 .7356 .35232 .72987 .34545 Mtetra
.687 .776 .919 r
.72987 .34545 .7356 .35232 .74827 .34769 .74257 .34048 Mtetra
.695 .769 .909 r
.74257 .34048 .74827 .34769 .76098 .34275 .7553 .33521 Mtetra
.699 .762 .901 r
.7553 .33521 .76098 .34275 .77372 .33755 .76807 .32974 Mtetra
.701 .756 .894 r
.76807 .32974 .77372 .33755 .7865 .33218 .78087 .32413 Mtetra
.702 .751 .89 r
.78087 .32413 .7865 .33218 .79931 .32669 .79372 .31847 Mtetra
.7 .746 .888 r
.79372 .31847 .79931 .32669 .81218 .32116 .80661 .31283 Mtetra
.697 .743 .887 r
.80661 .31283 .81218 .32116 .82509 .31565 .81957 .30727 Mtetra
.694 .742 .888 r
.81957 .30727 .82509 .31565 .83806 .31022 .83258 .30182 Mtetra
.69 .741 .89 r
.83258 .30182 .83806 .31022 .85109 .30489 .84566 .29649 Mtetra
.686 .74 .892 r
.84566 .29649 .85109 .30489 .86419 .29968 .85881 .29129 Mtetra
.682 .74 .895 r
.85881 .29129 .86419 .29968 .87736 .29459 .87202 .28622 Mtetra
.664 .741 .908 r
.26725 .47533 .27431 .48191 .28506 .47835 .27802 .47175 Mtetra
.27802 .47175 .28506 .47835 .29585 .47478 .28884 .46816 Mtetra
.28884 .46816 .29585 .47478 .30669 .4712 .29971 .46454 Mtetra
.29971 .46454 .30669 .4712 .31758 .4676 .31062 .46092 Mtetra
.31062 .46092 .31758 .4676 .3285 .46399 .32158 .45728 Mtetra
.32158 .45728 .3285 .46399 .33948 .46036 .33258 .45362 Mtetra
.33258 .45362 .33948 .46036 .3505 .45671 .34363 .44995 Mtetra
.34363 .44995 .3505 .45671 .36156 .45306 .35472 .44626 Mtetra
.35472 .44626 .36156 .45306 .37268 .44938 .36586 .44256 Mtetra
.36586 .44256 .37268 .44938 .38383 .44569 .37705 .43884 Mtetra
.663 .741 .908 r
.37705 .43884 .38383 .44569 .39504 .44199 .38828 .43511 Mtetra
.38828 .43511 .39504 .44199 .40629 .43827 .39956 .43136 Mtetra
.39956 .43136 .40629 .43827 .41759 .43454 .41089 .4276 Mtetra
.41089 .4276 .41759 .43454 .42893 .43079 .42227 .42383 Mtetra
.42227 .42383 .42893 .43079 .44033 .42704 .43369 .42006 Mtetra
.662 .742 .909 r
.43369 .42006 .44033 .42704 .45177 .42327 .44516 .41628 Mtetra
.44516 .41628 .45177 .42327 .46326 .4195 .45668 .4125 Mtetra
.661 .742 .91 r
.45668 .4125 .46326 .4195 .4748 .41574 .46825 .40873 Mtetra
.66 .742 .911 r
.46825 .40873 .4748 .41574 .48639 .41199 .47987 .40499 Mtetra
.658 .743 .913 r
.47987 .40499 .48639 .41199 .49803 .40826 .49154 .40129 Mtetra
.655 .744 .915 r
.49154 .40129 .49803 .40826 .50971 .40457 .50326 .39765 Mtetra
.652 .745 .918 r
.50326 .39765 .50971 .40457 .52145 .40094 .51504 .39409 Mtetra
.647 .747 .922 r
.51504 .39409 .52145 .40094 .53324 .39738 .52686 .39063 Mtetra
.641 .749 .927 r
.52686 .39063 .53324 .39738 .54509 .39392 .53874 .3873 Mtetra
.635 .752 .933 r
.53874 .3873 .54509 .39392 .55699 .39059 .55068 .38412 Mtetra
.627 .755 .939 r
.55068 .38412 .55699 .39059 .56895 .38739 .56268 .38109 Mtetra
.618 .759 .946 r
.56268 .38109 .56895 .38739 .58097 .38433 .57474 .37823 Mtetra
.61 .763 .953 r
.57474 .37823 .58097 .38433 .59305 .38142 .58686 .3755 Mtetra
.602 .768 .959 r
.58686 .3755 .59305 .38142 .6052 .37863 .59905 .37289 Mtetra
.596 .773 .965 r
.59905 .37289 .6052 .37863 .61741 .37594 .61131 .37034 Mtetra
.593 .778 .968 r
.61131 .37034 .61741 .37594 .62969 .37329 .62363 .36778 Mtetra
.595 .783 .97 r
.62363 .36778 .62969 .37329 .64203 .37063 .63601 .36513 Mtetra
.602 .787 .97 r
.63601 .36513 .64203 .37063 .65443 .36786 .64846 .36231 Mtetra
.613 .79 .966 r
.64846 .36231 .65443 .36786 .66689 .36492 .66096 .35922 Mtetra
.628 .792 .96 r
.66096 .35922 .66689 .36492 .67941 .36173 .6735 .35581 Mtetra
.645 .791 .952 r
.6735 .35581 .67941 .36173 .69197 .35822 .6861 .35201 Mtetra
.662 .788 .942 r
.6861 .35201 .69197 .35822 .70457 .35435 .69872 .3478 Mtetra
.676 .782 .93 r
.69872 .3478 .70457 .35435 .7172 .35009 .71138 .34317 Mtetra
.687 .776 .918 r
.71138 .34317 .7172 .35009 .72987 .34545 .72408 .33817 Mtetra
.696 .768 .908 r
.72408 .33817 .72987 .34545 .74257 .34048 .7368 .33285 Mtetra
.701 .761 .898 r
.7368 .33285 .74257 .34048 .7553 .33521 .74955 .32729 Mtetra
.704 .754 .892 r
.74955 .32729 .7553 .33521 .76807 .32974 .76234 .32157 Mtetra
.704 .749 .887 r
.76234 .32157 .76807 .32974 .78087 .32413 .77518 .31579 Mtetra
.702 .745 .885 r
.77518 .31579 .78087 .32413 .79372 .31847 .78806 .31004 Mtetra
.699 .742 .885 r
.78806 .31004 .79372 .31847 .80661 .31283 .801 .30439 Mtetra
.695 .741 .887 r
.801 .30439 .80661 .31283 .81957 .30727 .814 .29886 Mtetra
.692 .742 .89 r
.814 .29886 .81957 .30727 .83258 .30182 .82707 .29346 Mtetra
.688 .743 .893 r
.82707 .29346 .83258 .30182 .84566 .29649 .8402 .28817 Mtetra
.685 .744 .896 r
.8402 .28817 .84566 .29649 .85881 .29129 .85339 .28298 Mtetra
.682 .744 .898 r
.85339 .28298 .85881 .29129 .87202 .28622 .86665 .27789 Mtetra
.664 .741 .908 r
.26013 .46871 .26725 .47533 .27802 .47175 .27093 .4651 Mtetra
.27093 .4651 .27802 .47175 .28884 .46816 .28178 .46148 Mtetra
.28178 .46148 .28884 .46816 .29971 .46454 .29268 .45784 Mtetra
.29268 .45784 .29971 .46454 .31062 .46092 .30361 .45418 Mtetra
.30361 .45418 .31062 .46092 .32158 .45728 .3146 .45051 Mtetra
.3146 .45051 .32158 .45728 .33258 .45362 .32563 .44683 Mtetra
.32563 .44683 .33258 .45362 .34363 .44995 .3367 .44313 Mtetra
.3367 .44313 .34363 .44995 .35472 .44626 .34783 .43941 Mtetra
.34783 .43941 .35472 .44626 .36586 .44256 .35899 .43568 Mtetra
.663 .741 .908 r
.35899 .43568 .36586 .44256 .37705 .43884 .37021 .43194 Mtetra
.37021 .43194 .37705 .43884 .38828 .43511 .38147 .42818 Mtetra
.38147 .42818 .38828 .43511 .39956 .43136 .39278 .42441 Mtetra
.39278 .42441 .39956 .43136 .41089 .4276 .40414 .42062 Mtetra
.40414 .42062 .41089 .4276 .42227 .42383 .41555 .41683 Mtetra
.662 .742 .909 r
.41555 .41683 .42227 .42383 .43369 .42006 .427 .41304 Mtetra
.427 .41304 .43369 .42006 .44516 .41628 .4385 .40924 Mtetra
.661 .742 .91 r
.4385 .40924 .44516 .41628 .45668 .4125 .45006 .40546 Mtetra
.66 .742 .911 r
.45006 .40546 .45668 .4125 .46825 .40873 .46166 .40171 Mtetra
.658 .743 .913 r
.46166 .40171 .46825 .40873 .47987 .40499 .47331 .39799 Mtetra
.655 .744 .915 r
.47331 .39799 .47987 .40499 .49154 .40129 .48501 .39434 Mtetra
.651 .745 .918 r
.48501 .39434 .49154 .40129 .50326 .39765 .49676 .39077 Mtetra
.647 .747 .922 r
.49676 .39077 .50326 .39765 .51504 .39409 .50857 .38731 Mtetra
.641 .749 .927 r
.50857 .38731 .51504 .39409 .52686 .39063 .52043 .38398 Mtetra
.634 .752 .933 r
.52043 .38398 .52686 .39063 .53874 .3873 .53234 .38081 Mtetra
.626 .755 .94 r
.53234 .38081 .53874 .3873 .55068 .38412 .54432 .37781 Mtetra
.616 .759 .947 r
.54432 .37781 .55068 .38412 .56268 .38109 .55635 .37497 Mtetra
.607 .763 .954 r
.55635 .37497 .56268 .38109 .57474 .37823 .56845 .3723 Mtetra
.598 .767 .96 r
.56845 .3723 .57474 .37823 .58686 .3755 .58062 .36975 Mtetra
.591 .772 .966 r
.58062 .36975 .58686 .3755 .59905 .37289 .59285 .36728 Mtetra
.587 .777 .97 r
.59285 .36728 .59905 .37289 .61131 .37034 .60515 .36482 Mtetra
.588 .781 .972 r
.60515 .36482 .61131 .37034 .62363 .36778 .61751 .36228 Mtetra
.595 .786 .971 r
.61751 .36228 .62363 .36778 .63601 .36513 .62994 .35957 Mtetra
.607 .789 .968 r
.62994 .35957 .63601 .36513 .64846 .36231 .64242 .3566 Mtetra
.623 .791 .962 r
.64242 .3566 .64846 .36231 .66096 .35922 .65496 .35329 Mtetra
.641 .79 .953 r
.65496 .35329 .66096 .35922 .6735 .35581 .66754 .34957 Mtetra
.659 .787 .942 r
.66754 .34957 .6735 .35581 .6861 .35201 .68016 .34542 Mtetra
.675 .781 .93 r
.68016 .34542 .6861 .35201 .69872 .3478 .69281 .34082 Mtetra
.687 .774 .917 r
.69281 .34082 .69872 .3478 .71138 .34317 .70549 .3358 Mtetra
.696 .767 .906 r
.70549 .3358 .71138 .34317 .72408 .33817 .71821 .33044 Mtetra
.702 .759 .896 r
.71821 .33044 .72408 .33817 .7368 .33285 .73095 .3248 Mtetra
.705 .752 .889 r
.73095 .3248 .7368 .33285 .74955 .32729 .74373 .31899 Mtetra
.705 .747 .884 r
.74373 .31899 .74955 .32729 .76234 .32157 .75656 .31311 Mtetra
.703 .743 .882 r
.75656 .31311 .76234 .32157 .77518 .31579 .76943 .30728 Mtetra
.699 .741 .884 r
.76943 .30728 .77518 .31579 .78806 .31004 .78236 .30159 Mtetra
.694 .741 .888 r
.78236 .30159 .78806 .31004 .801 .30439 .79536 .29609 Mtetra
.69 .745 .893 r
.79536 .29609 .801 .30439 .814 .29886 .80843 .29075 Mtetra
.688 .75 .899 r
.80843 .29075 .814 .29886 .82707 .29346 .82155 .28549 Mtetra
.688 .755 .903 r
.82155 .28549 .82707 .29346 .8402 .28817 .83473 .28023 Mtetra
.687 .758 .905 r
.83473 .28023 .8402 .28817 .85339 .28298 .84797 .27497 Mtetra
.686 .756 .905 r
.84797 .27497 .85339 .28298 .86665 .27789 .86127 .26975 Mtetra
.664 .741 .908 r
.25296 .46203 .26013 .46871 .27093 .4651 .26379 .4584 Mtetra
.26379 .4584 .27093 .4651 .28178 .46148 .27467 .45475 Mtetra
.27467 .45475 .28178 .46148 .29268 .45784 .28559 .45108 Mtetra
.28559 .45108 .29268 .45784 .30361 .45418 .29655 .4474 Mtetra
.29655 .4474 .30361 .45418 .3146 .45051 .30756 .4437 Mtetra
.30756 .4437 .3146 .45051 .32563 .44683 .31862 .43998 Mtetra
.31862 .43998 .32563 .44683 .3367 .44313 .32973 .43626 Mtetra
.32973 .43626 .3367 .44313 .34783 .43941 .34088 .43251 Mtetra
.663 .741 .908 r
.34088 .43251 .34783 .43941 .35899 .43568 .35207 .42875 Mtetra
.35207 .42875 .35899 .43568 .37021 .43194 .36332 .42498 Mtetra
.36332 .42498 .37021 .43194 .38147 .42818 .37461 .4212 Mtetra
.37461 .4212 .38147 .42818 .39278 .42441 .38595 .4174 Mtetra
.38595 .4174 .39278 .42441 .40414 .42062 .39734 .41359 Mtetra
.663 .742 .909 r
.39734 .41359 .40414 .42062 .41555 .41683 .40877 .40978 Mtetra
.662 .742 .909 r
.40877 .40978 .41555 .41683 .427 .41304 .42026 .40597 Mtetra
.661 .742 .91 r
.42026 .40597 .427 .41304 .4385 .40924 .43179 .40218 Mtetra
.66 .742 .911 r
.43179 .40218 .4385 .40924 .45006 .40546 .44337 .39841 Mtetra
.658 .743 .913 r
.44337 .39841 .45006 .40546 .46166 .40171 .45501 .39468 Mtetra
.655 .744 .915 r
.45501 .39468 .46166 .40171 .47331 .39799 .46669 .39101 Mtetra
.651 .745 .918 r
.46669 .39101 .47331 .39799 .48501 .39434 .47842 .38743 Mtetra
.647 .747 .922 r
.47842 .38743 .48501 .39434 .49676 .39077 .4902 .38396 Mtetra
.641 .749 .927 r
.4902 .38396 .49676 .39077 .50857 .38731 .50204 .38063 Mtetra
.633 .751 .933 r
.50204 .38063 .50857 .38731 .52043 .38398 .51393 .37746 Mtetra
.625 .754 .94 r
.51393 .37746 .52043 .38398 .53234 .38081 .52589 .37446 Mtetra
.615 .758 .947 r
.52589 .37446 .53234 .38081 .54432 .37781 .5379 .37165 Mtetra
.604 .762 .954 r
.5379 .37165 .54432 .37781 .55635 .37497 .54997 .36902 Mtetra
.595 .766 .961 r
.54997 .36902 .55635 .37497 .56845 .3723 .56211 .36653 Mtetra
.587 .77 .967 r
.56211 .36653 .56845 .3723 .58062 .36975 .57432 .36413 Mtetra
.582 .775 .971 r
.57432 .36413 .58062 .36975 .59285 .36728 .5866 .36175 Mtetra
.583 .779 .973 r
.5866 .36175 .59285 .36728 .60515 .36482 .59894 .35931 Mtetra
.589 .784 .973 r
.59894 .35931 .60515 .36482 .61751 .36228 .61134 .35671 Mtetra
.602 .787 .97 r
.61134 .35671 .61751 .36228 .62994 .35957 .62381 .35384 Mtetra
.618 .789 .963 r
.62381 .35384 .62994 .35957 .64242 .3566 .63632 .35063 Mtetra
.637 .788 .954 r
.63632 .35063 .64242 .3566 .65496 .35329 .64889 .347 Mtetra
.656 .785 .943 r
.64889 .347 .65496 .35329 .66754 .34957 .6615 .34291 Mtetra
.673 .779 .93 r
.6615 .34291 .66754 .34957 .68016 .34542 .67414 .33835 Mtetra
.687 .772 .916 r
.67414 .33835 .68016 .34542 .69281 .34082 .68682 .33334 Mtetra
.697 .764 .904 r
.68682 .33334 .69281 .34082 .70549 .3358 .69953 .32794 Mtetra
.703 .757 .894 r
.69953 .32794 .70549 .3358 .71821 .33044 .71226 .32224 Mtetra
.706 .75 .886 r
.71226 .32224 .71821 .33044 .73095 .3248 .72504 .31635 Mtetra
.706 .744 .881 r
.72504 .31635 .73095 .3248 .74373 .31899 .73785 .31039 Mtetra
.703 .74 .88 r
.73785 .31039 .74373 .31899 .75656 .31311 .75072 .30451 Mtetra
.697 .739 .883 r
.75072 .30451 .75656 .31311 .76943 .30728 .76365 .29886 Mtetra
.689 .741 .891 r
.76365 .29886 .76943 .30728 .78236 .30159 .77666 .29354 Mtetra
.681 .749 .903 r
.77666 .29354 .78236 .30159 .79536 .29609 .78974 .28853 Mtetra
.678 .764 .916 r
.78974 .28853 .79536 .29609 .80843 .29075 .8029 .28364 Mtetra
.682 .78 .925 r
.8029 .28364 .80843 .29075 .82155 .28549 .8161 .2786 Mtetra
.69 .792 .928 r
.8161 .2786 .82155 .28549 .83473 .28023 .82933 .27326 Mtetra
.697 .793 .924 r
.82933 .27326 .83473 .28023 .84797 .27497 .84258 .26766 Mtetra
.698 .783 .917 r
.84258 .26766 .84797 .27497 .86127 .26975 .85589 .26202 Mtetra
.664 .741 .908 r
.24574 .45531 .25296 .46203 .26379 .4584 .25659 .45164 Mtetra
.25659 .45164 .26379 .4584 .27467 .45475 .2675 .44796 Mtetra
.2675 .44796 .27467 .45475 .28559 .45108 .27844 .44427 Mtetra
.27844 .44427 .28559 .45108 .29655 .4474 .28944 .44056 Mtetra
.28944 .44056 .29655 .4474 .30756 .4437 .30048 .43683 Mtetra
.30048 .43683 .30756 .4437 .31862 .43998 .31156 .43309 Mtetra
.31156 .43309 .31862 .43998 .32973 .43626 .32269 .42933 Mtetra
.663 .741 .908 r
.32269 .42933 .32973 .43626 .34088 .43251 .33387 .42556 Mtetra
.33387 .42556 .34088 .43251 .35207 .42875 .3451 .42177 Mtetra
.3451 .42177 .35207 .42875 .36332 .42498 .35637 .41797 Mtetra
.35637 .41797 .36332 .42498 .37461 .4212 .36769 .41416 Mtetra
.36769 .41416 .37461 .4212 .38595 .4174 .37906 .41034 Mtetra
.663 .742 .909 r
.37906 .41034 .38595 .4174 .39734 .41359 .39048 .40652 Mtetra
.662 .742 .909 r
.39048 .40652 .39734 .41359 .40877 .40978 .40195 .40269 Mtetra
.661 .742 .91 r
.40195 .40269 .40877 .40978 .42026 .40597 .41346 .39888 Mtetra
.66 .742 .911 r
.41346 .39888 .42026 .40597 .43179 .40218 .42502 .39509 Mtetra
.658 .743 .913 r
.42502 .39509 .43179 .40218 .44337 .39841 .43664 .39135 Mtetra
.655 .744 .915 r
.43664 .39135 .44337 .39841 .45501 .39468 .4483 .38766 Mtetra
.651 .745 .918 r
.4483 .38766 .45501 .39468 .46669 .39101 .46001 .38406 Mtetra
.647 .746 .922 r
.46001 .38406 .46669 .39101 .47842 .38743 .47177 .38058 Mtetra
.641 .748 .927 r
.47177 .38058 .47842 .38743 .4902 .38396 .48359 .37723 Mtetra
.633 .751 .933 r
.48359 .37723 .4902 .38396 .50204 .38063 .49546 .37406 Mtetra
.624 .754 .939 r
.49546 .37406 .50204 .38063 .51393 .37746 .50739 .37106 Mtetra
.614 .757 .947 r
.50739 .37106 .51393 .37746 .52589 .37446 .51937 .36826 Mtetra
.603 .76 .954 r
.51937 .36826 .52589 .37446 .5379 .37165 .53142 .36565 Mtetra
.592 .764 .961 r
.53142 .36565 .5379 .37165 .54997 .36902 .54354 .3632 Mtetra
.584 .768 .967 r
.54354 .3632 .54997 .36902 .56211 .36653 .55572 .36085 Mtetra
.578 .773 .971 r
.55572 .36085 .56211 .36653 .57432 .36413 .56796 .35855 Mtetra
.578 .777 .973 r
.56796 .35855 .57432 .36413 .5866 .36175 .58028 .35619 Mtetra
.584 .781 .973 r
.58028 .35619 .5866 .36175 .59894 .35931 .59266 .35368 Mtetra
.597 .784 .97 r
.59266 .35368 .59894 .35931 .61134 .35671 .60511 .35092 Mtetra
.614 .786 .964 r
.60511 .35092 .61134 .35671 .62381 .35384 .61761 .34781 Mtetra
.634 .785 .954 r
.61761 .34781 .62381 .35384 .63632 .35063 .63016 .34427 Mtetra
.653 .782 .942 r
.63016 .34427 .63632 .35063 .64889 .347 .64275 .34025 Mtetra
.671 .776 .929 r
.64275 .34025 .64889 .347 .6615 .34291 .65539 .33573 Mtetra
.686 .769 .915 r
.65539 .33573 .6615 .34291 .67414 .33835 .66806 .33074 Mtetra
.696 .761 .902 r
.66806 .33074 .67414 .33835 .68682 .33334 .68076 .32534 Mtetra
.703 .753 .891 r
.68076 .32534 .68682 .33334 .69953 .32794 .69349 .31959 Mtetra
.707 .746 .883 r
.69349 .31959 .69953 .32794 .71226 .32224 .70625 .31363 Mtetra
.707 .741 .878 r
.70625 .31363 .71226 .32224 .72504 .31635 .71906 .30759 Mtetra
.703 .737 .877 r
.71906 .30759 .72504 .31635 .73785 .31039 .73192 .30166 Mtetra
.694 .735 .882 r
.73192 .30166 .73785 .31039 .75072 .30451 .74485 .29609 Mtetra
.679 .739 .895 r
.74485 .29609 .75072 .30451 .76365 .29886 .75788 .29111 Mtetra
.66 .751 .917 r
.75788 .29111 .76365 .29886 .77666 .29354 .77101 .2868 Mtetra
.642 .777 .945 r
.77101 .2868 .77666 .29354 .78974 .28853 .78424 .28289 Mtetra
.639 .815 .968 r
.78424 .28289 .78974 .28853 .8029 .28364 .79753 .27881 Mtetra
.66 .854 .974 r
.79753 .27881 .8029 .28364 .8161 .2786 .81081 .27395 Mtetra
.696 .874 .965 r
.81081 .27395 .8161 .2786 .82933 .27326 .82405 .26809 Mtetra
.723 .865 .948 r
.82405 .26809 .82933 .27326 .84258 .26766 .83727 .26154 Mtetra
.726 .834 .932 r
.83727 .26154 .84258 .26766 .85589 .26202 .85054 .25493 Mtetra
.664 .741 .908 r
.23846 .44853 .24574 .45531 .25659 .45164 .24934 .44484 Mtetra
.24934 .44484 .25659 .45164 .2675 .44796 .26027 .44113 Mtetra
.26027 .44113 .2675 .44796 .27844 .44427 .27124 .4374 Mtetra
.27124 .4374 .27844 .44427 .28944 .44056 .28226 .43366 Mtetra
.28226 .43366 .28944 .44056 .30048 .43683 .29333 .42991 Mtetra
.29333 .42991 .30048 .43683 .31156 .43309 .30445 .42614 Mtetra
.663 .741 .908 r
.30445 .42614 .31156 .43309 .32269 .42933 .31561 .42235 Mtetra
.31561 .42235 .32269 .42933 .33387 .42556 .32681 .41855 Mtetra
.32681 .41855 .33387 .42556 .3451 .42177 .33807 .41474 Mtetra
.33807 .41474 .3451 .42177 .35637 .41797 .34937 .41091 Mtetra
.34937 .41091 .35637 .41797 .36769 .41416 .36072 .40708 Mtetra
.663 .741 .909 r
.36072 .40708 .36769 .41416 .37906 .41034 .37212 .40324 Mtetra
.662 .742 .909 r
.37212 .40324 .37906 .41034 .39048 .40652 .38357 .3994 Mtetra
.661 .742 .91 r
.38357 .3994 .39048 .40652 .40195 .40269 .39506 .39557 Mtetra
.66 .742 .911 r
.39506 .39557 .40195 .40269 .41346 .39888 .40661 .39177 Mtetra
.658 .743 .913 r
.40661 .39177 .41346 .39888 .42502 .39509 .4182 .388 Mtetra
.655 .743 .915 r
.4182 .388 .42502 .39509 .43664 .39135 .42984 .38429 Mtetra
.652 .745 .918 r
.42984 .38429 .43664 .39135 .4483 .38766 .44153 .38068 Mtetra
.647 .746 .922 r
.44153 .38068 .4483 .38766 .46001 .38406 .45328 .37717 Mtetra
.641 .748 .926 r
.45328 .37717 .46001 .38406 .47177 .38058 .46507 .3738 Mtetra
.633 .75 .932 r
.46507 .3738 .47177 .38058 .48359 .37723 .47692 .37061 Mtetra
.624 .753 .939 r
.47692 .37061 .48359 .37723 .49546 .37406 .48882 .3676 Mtetra
.614 .756 .946 r
.48882 .3676 .49546 .37406 .50739 .37106 .50078 .3648 Mtetra
.602 .759 .954 r
.50078 .3648 .50739 .37106 .51937 .36826 .5128 .3622 Mtetra
.591 .763 .961 r
.5128 .3622 .51937 .36826 .53142 .36565 .52489 .35976 Mtetra
.582 .766 .967 r
.52489 .35976 .53142 .36565 .54354 .3632 .53704 .35745 Mtetra
.575 .77 .971 r
.53704 .35745 .54354 .3632 .55572 .36085 .54926 .3552 Mtetra
.575 .774 .973 r
.54926 .3552 .55572 .36085 .56796 .35855 .56155 .35291 Mtetra
.58 .778 .973 r
.56155 .35291 .56796 .35855 .58028 .35619 .5739 .35049 Mtetra
.592 .781 .97 r
.5739 .35049 .58028 .35619 .59266 .35368 .58633 .34782 Mtetra
.61 .782 .964 r
.58633 .34782 .59266 .35368 .60511 .35092 .59881 .3448 Mtetra
.63 .782 .954 r
.59881 .3448 .60511 .35092 .61761 .34781 .61134 .34135 Mtetra
.65 .779 .942 r
.61134 .34135 .61761 .34781 .63016 .34427 .62392 .3374 Mtetra
.669 .773 .928 r
.62392 .3374 .63016 .34427 .64275 .34025 .63654 .33294 Mtetra
.684 .766 .913 r
.63654 .33294 .64275 .34025 .65539 .33573 .6492 .32799 Mtetra
.695 .758 .9 r
.6492 .32799 .65539 .33573 .66806 .33074 .6619 .32259 Mtetra
.703 .75 .888 r
.6619 .32259 .66806 .33074 .68076 .32534 .67462 .31682 Mtetra
.707 .743 .879 r
.67462 .31682 .68076 .32534 .69349 .31959 .68738 .3108 Mtetra
.708 .737 .874 r
.68738 .3108 .69349 .31959 .70625 .31363 .70018 .30468 Mtetra
.704 .733 .873 r
.70018 .30468 .70625 .31363 .71906 .30759 .71303 .29869 Mtetra
.692 .731 .88 r
.71303 .29869 .71906 .30759 .73192 .30166 .72596 .29316 Mtetra
.669 .733 .898 r
.72596 .29316 .73192 .30166 .74485 .29609 .739 .28853 Mtetra
.627 .744 .931 r
.739 .28853 .74485 .29609 .75788 .29111 .75219 .28515 Mtetra
.561 .771 .977 r
.75219 .28515 .75788 .29111 .77101 .2868 .76554 .28293 Mtetra
.475 .81 .999 r
.76554 .28293 .77101 .2868 .78424 .28289 .779 .28102 Mtetra
.43 .849 .958 r
.779 .28102 .78424 .28289 .79753 .27881 .79246 .27805 Mtetra
.504 .906 .911 r
.79246 .27805 .79753 .27881 .81081 .27395 .80579 .2729 Mtetra
.655 .965 .918 r
.80579 .2729 .81081 .27395 .82405 .26809 .81897 .26554 Mtetra
.759 .961 .934 r
.81897 .26554 .82405 .26809 .83727 .26154 .83207 .25698 Mtetra
.775 .902 .93 r
.83207 .25698 .83727 .26154 .85054 .25493 .84522 .24858 Mtetra
.664 .741 .908 r
.23112 .4417 .23846 .44853 .24934 .44484 .24203 .43798 Mtetra
.24203 .43798 .24934 .44484 .26027 .44113 .25299 .43424 Mtetra
.25299 .43424 .26027 .44113 .27124 .4374 .26399 .43049 Mtetra
.26399 .43049 .27124 .4374 .28226 .43366 .27504 .42672 Mtetra
.27504 .42672 .28226 .43366 .29333 .42991 .28613 .42294 Mtetra
.663 .741 .908 r
.28613 .42294 .29333 .42991 .30445 .42614 .29727 .41914 Mtetra
.29727 .41914 .30445 .42614 .31561 .42235 .30846 .41532 Mtetra
.30846 .41532 .31561 .42235 .32681 .41855 .3197 .41149 Mtetra
.3197 .41149 .32681 .41855 .33807 .41474 .33098 .40765 Mtetra
.33098 .40765 .33807 .41474 .34937 .41091 .34232 .4038 Mtetra
.663 .741 .909 r
.34232 .4038 .34937 .41091 .36072 .40708 .3537 .39995 Mtetra
.662 .742 .909 r
.3537 .39995 .36072 .40708 .37212 .40324 .36512 .39609 Mtetra
.661 .742 .91 r
.36512 .39609 .37212 .40324 .38357 .3994 .3766 .39225 Mtetra
.66 .742 .911 r
.3766 .39225 .38357 .3994 .39506 .39557 .38813 .38842 Mtetra
.658 .743 .912 r
.38813 .38842 .39506 .39557 .40661 .39177 .3997 .38464 Mtetra
.656 .743 .914 r
.3997 .38464 .40661 .39177 .4182 .388 .41132 .38091 Mtetra
.652 .744 .917 r
.41132 .38091 .4182 .388 .42984 .38429 .42299 .37726 Mtetra
.647 .746 .921 r
.42299 .37726 .42984 .38429 .44153 .38068 .43471 .37373 Mtetra
.641 .747 .926 r
.43471 .37373 .44153 .38068 .45328 .37717 .44648 .37034 Mtetra
.634 .749 .931 r
.44648 .37034 .45328 .37717 .46507 .3738 .45831 .36712 Mtetra
.625 .752 .938 r
.45831 .36712 .46507 .3738 .47692 .37061 .47018 .36409 Mtetra
.614 .755 .945 r
.47018 .36409 .47692 .37061 .48882 .3676 .48212 .36127 Mtetra
.603 .758 .953 r
.48212 .36127 .48882 .3676 .50078 .3648 .49411 .35865 Mtetra
.591 .761 .96 r
.49411 .35865 .50078 .3648 .5128 .3622 .50617 .35622 Mtetra
.581 .764 .966 r
.50617 .35622 .5128 .3622 .52489 .35976 .51829 .35393 Mtetra
.574 .767 .97 r
.51829 .35393 .52489 .35976 .53704 .35745 .53048 .35171 Mtetra
.572 .771 .972 r
.53048 .35171 .53704 .35745 .54926 .3552 .54274 .34947 Mtetra
.577 .774 .972 r
.54274 .34947 .54926 .3552 .56155 .35291 .55507 .34711 Mtetra
.589 .777 .969 r
.55507 .34711 .56155 .35291 .5739 .35049 .56747 .34452 Mtetra
.606 .778 .963 r
.56747 .34452 .5739 .35049 .58633 .34782 .57992 .34158 Mtetra
.627 .778 .953 r
.57992 .34158 .58633 .34782 .59881 .3448 .59244 .33821 Mtetra
.647 .774 .941 r
.59244 .33821 .59881 .3448 .61134 .34135 .605 .33435 Mtetra
.666 .769 .926 r
.605 .33435 .61134 .34135 .62392 .3374 .61761 .32996 Mtetra
.682 .762 .912 r
.61761 .32996 .62392 .3374 .63654 .33294 .63026 .32505 Mtetra
.694 .754 .898 r
.63026 .32505 .63654 .33294 .6492 .32799 .64295 .31967 Mtetra
.702 .746 .886 r
.64295 .31967 .6492 .32799 .6619 .32259 .65566 .31389 Mtetra
.707 .739 .876 r
.65566 .31389 .6619 .32259 .67462 .31682 .66842 .30784 Mtetra
.708 .733 .871 r
.66842 .30784 .67462 .31682 .68738 .3108 .68121 .30165 Mtetra
.705 .729 .869 r
.68121 .30165 .68738 .3108 .70018 .30468 .69405 .29556 Mtetra
.693 .726 .876 r
.69405 .29556 .70018 .30468 .71303 .29869 .70696 .28995 Mtetra
.664 .726 .895 r
.70696 .28995 .71303 .29869 .72596 .29316 .72 .28547 Mtetra
.598 .729 .936 r
.72 .28547 .72596 .29316 .739 .28853 .73323 .28288 Mtetra
.444 .726 .986 r
.73323 .28288 .739 .28853 .75219 .28515 .74669 .2826 Mtetra
.116 .631 .891 r
.74669 .2826 .75219 .28515 .76554 .28293 .76038 .28398 Mtetra
.17 0 0 r
.76038 .28398 .76554 .28293 .779 .28102 .77416 .28497 Mtetra
.154 0 0 r
.77416 .28497 .779 .28102 .79246 .27805 .78779 .28292 Mtetra
0 0 0 r
.78779 .28292 .79246 .27805 .80579 .2729 .8011 .27628 Mtetra
.482 .842 .588 r
.8011 .27628 .80579 .2729 .81897 .26554 .81409 .26576 Mtetra
.781 .997 .809 r
.81409 .26576 .81897 .26554 .83207 .25698 .82695 .25377 Mtetra
.837 .952 .892 r
.82695 .25377 .83207 .25698 .84522 .24858 .8399 .24268 Mtetra
.664 .741 .908 r
.22373 .43482 .23112 .4417 .24203 .43798 .23467 .43107 Mtetra
.23467 .43107 .24203 .43798 .25299 .43424 .24565 .4273 Mtetra
.24565 .4273 .25299 .43424 .26399 .43049 .25668 .42352 Mtetra
.25668 .42352 .26399 .43049 .27504 .42672 .26775 .41972 Mtetra
.26775 .41972 .27504 .42672 .28613 .42294 .27888 .41591 Mtetra
.663 .741 .908 r
.27888 .41591 .28613 .42294 .29727 .41914 .29005 .41208 Mtetra
.29005 .41208 .29727 .41914 .30846 .41532 .30126 .40824 Mtetra
.30126 .40824 .30846 .41532 .3197 .41149 .31253 .40438 Mtetra
.31253 .40438 .3197 .41149 .33098 .40765 .32384 .40052 Mtetra
.663 .741 .909 r
.32384 .40052 .33098 .40765 .34232 .4038 .3352 .39664 Mtetra
.662 .742 .909 r
.3352 .39664 .34232 .4038 .3537 .39995 .34661 .39277 Mtetra
.661 .742 .91 r
.34661 .39277 .3537 .39995 .36512 .39609 .35807 .38891 Mtetra
.66 .742 .911 r
.35807 .38891 .36512 .39609 .3766 .39225 .36958 .38506 Mtetra
.658 .742 .912 r
.36958 .38506 .3766 .39225 .38813 .38842 .38113 .38125 Mtetra
.656 .743 .914 r
.38113 .38125 .38813 .38842 .3997 .38464 .39273 .3775 Mtetra
.652 .744 .917 r
.39273 .3775 .3997 .38464 .41132 .38091 .40438 .37383 Mtetra
.648 .745 .92 r
.40438 .37383 .41132 .38091 .42299 .37726 .41608 .37026 Mtetra
.642 .747 .925 r
.41608 .37026 .42299 .37726 .43471 .37373 .42783 .36684 Mtetra
.635 .749 .93 r
.42783 .36684 .43471 .37373 .44648 .37034 .43963 .36358 Mtetra
.626 .751 .937 r
.43963 .36358 .44648 .37034 .45831 .36712 .45148 .36052 Mtetra
.615 .753 .944 r
.45148 .36052 .45831 .36712 .47018 .36409 .46339 .35767 Mtetra
.604 .756 .951 r
.46339 .35767 .47018 .36409 .48212 .36127 .47536 .35503 Mtetra
.592 .759 .958 r
.47536 .35503 .48212 .36127 .49411 .35865 .48738 .35258 Mtetra
.582 .762 .964 r
.48738 .35258 .49411 .35865 .50617 .35622 .49948 .35028 Mtetra
.574 .765 .969 r
.49948 .35028 .50617 .35622 .51829 .35393 .51164 .34807 Mtetra
.572 .767 .971 r
.51164 .34807 .51829 .35393 .53048 .35171 .52386 .34586 Mtetra
.576 .77 .971 r
.52386 .34586 .53048 .35171 .54274 .34947 .53616 .34354 Mtetra
.587 .773 .968 r
.53616 .34354 .54274 .34947 .55507 .34711 .54853 .34101 Mtetra
.603 .774 .962 r
.54853 .34101 .55507 .34711 .56747 .34452 .56096 .33815 Mtetra
.624 .773 .952 r
.56096 .33815 .56747 .34452 .57992 .34158 .57345 .33486 Mtetra
.644 .77 .939 r
.57345 .33486 .57992 .34158 .59244 .33821 .586 .33107 Mtetra
.663 .764 .925 r
.586 .33107 .59244 .33821 .605 .33435 .5986 .32675 Mtetra
.68 .757 .91 r
.5986 .32675 .605 .33435 .61761 .32996 .61123 .3219 Mtetra
.692 .749 .896 r
.61123 .3219 .61761 .32996 .63026 .32505 .62391 .31656 Mtetra
.701 .742 .883 r
.62391 .31656 .63026 .32505 .64295 .31967 .63662 .3108 Mtetra
.706 .735 .874 r
.63662 .3108 .64295 .31967 .65566 .31389 .64937 .30473 Mtetra
.708 .73 .867 r
.64937 .30473 .65566 .31389 .66842 .30784 .66215 .29849 Mtetra
.706 .725 .865 r
.66215 .29849 .66842 .30784 .68121 .30165 .67498 .29228 Mtetra
.696 .722 .87 r
.67498 .29228 .68121 .30165 .69405 .29556 .68788 .28648 Mtetra
.668 .719 .888 r
.68788 .28648 .69405 .29556 .70696 .28995 .70089 .28182 Mtetra
.593 .715 .928 r
.70089 .28182 .70696 .28995 .72 .28547 .7141 .27941 Mtetra
.376 .675 .975 r
.7141 .27941 .72 .28547 .73323 .28288 .72761 .28042 Mtetra
0 .397 .726 r
.72761 .28042 .73323 .28288 .74669 .2826 .74148 .28508 Mtetra
.531 0 0 r
.74148 .28508 .74669 .2826 .76038 .28398 .75563 .2915 Mtetra
.523 .039 .047 r
.75563 .2915 .76038 .28398 .77416 .28497 .76976 .29565 Mtetra
.365 0 .083 r
.76976 .29565 .77416 .28497 .78779 .28292 .7835 .29332 Mtetra
.048 0 0 r
.7835 .29332 .78779 .28292 .8011 .27628 .79663 .28312 Mtetra
0 0 0 r
.79663 .28312 .8011 .27628 .81409 .26576 .80928 .26747 Mtetra
.84 .981 .69 r
.80928 .26747 .81409 .26576 .82695 .25377 .82179 .2508 Mtetra
.893 .953 .835 r
.82179 .2508 .82695 .25377 .8399 .24268 .83451 .23656 Mtetra
.664 .741 .908 r
.21628 .42788 .22373 .43482 .23467 .43107 .22724 .4241 Mtetra
.22724 .4241 .23467 .43107 .24565 .4273 .23825 .4203 Mtetra
.23825 .4203 .24565 .4273 .25668 .42352 .24931 .41649 Mtetra
.24931 .41649 .25668 .42352 .26775 .41972 .26041 .41267 Mtetra
.663 .741 .908 r
.26041 .41267 .26775 .41972 .27888 .41591 .27156 .40882 Mtetra
.27156 .40882 .27888 .41591 .29005 .41208 .28276 .40497 Mtetra
.28276 .40497 .29005 .41208 .30126 .40824 .29401 .4011 Mtetra
.29401 .4011 .30126 .40824 .31253 .40438 .3053 .39722 Mtetra
.3053 .39722 .31253 .40438 .32384 .40052 .31664 .39333 Mtetra
.662 .742 .909 r
.31664 .39333 .32384 .40052 .3352 .39664 .32803 .38944 Mtetra
.32803 .38944 .3352 .39664 .34661 .39277 .33947 .38556 Mtetra
.66 .742 .91 r
.33947 .38556 .34661 .39277 .35807 .38891 .35096 .38169 Mtetra
.659 .742 .912 r
.35096 .38169 .35807 .38891 .36958 .38506 .36249 .37786 Mtetra
.656 .743 .914 r
.36249 .37786 .36958 .38506 .38113 .38125 .37407 .37408 Mtetra
.653 .744 .916 r
.37407 .37408 .38113 .38125 .39273 .3775 .3857 .37037 Mtetra
.649 .745 .92 r
.3857 .37037 .39273 .3775 .40438 .37383 .39738 .36677 Mtetra
.643 .746 .924 r
.39738 .36677 .40438 .37383 .41608 .37026 .40911 .36331 Mtetra
.636 .748 .929 r
.40911 .36331 .41608 .37026 .42783 .36684 .42089 .36001 Mtetra
.627 .75 .935 r
.42089 .36001 .42783 .36684 .43963 .36358 .43271 .35691 Mtetra
.617 .752 .942 r
.43271 .35691 .43963 .36358 .45148 .36052 .44459 .35401 Mtetra
.605 .755 .949 r
.44459 .35401 .45148 .36052 .46339 .35767 .45653 .35132 Mtetra
.594 .757 .956 r
.45653 .35132 .46339 .35767 .47536 .35503 .46853 .34884 Mtetra
.583 .759 .962 r
.46853 .34884 .47536 .35503 .48738 .35258 .48059 .34652 Mtetra
.576 .762 .967 r
.48059 .34652 .48738 .35258 .49948 .35028 .49272 .3443 Mtetra
.573 .764 .969 r
.49272 .3443 .49948 .35028 .51164 .34807 .50492 .34209 Mtetra
.576 .766 .969 r
.50492 .34209 .51164 .34807 .52386 .34586 .51718 .33979 Mtetra
.586 .768 .966 r
.51718 .33979 .52386 .34586 .53616 .34354 .52952 .3373 Mtetra
.602 .769 .96 r
.52952 .3373 .53616 .34354 .54853 .34101 .54193 .33449 Mtetra
.621 .768 .95 r
.54193 .33449 .54853 .34101 .56096 .33815 .55439 .33127 Mtetra
.642 .765 .938 r
.55439 .33127 .56096 .33815 .57345 .33486 .56692 .32756 Mtetra
.661 .759 .923 r
.56692 .32756 .57345 .33486 .586 .33107 .5795 .32331 Mtetra
.677 .752 .908 r
.5795 .32331 .586 .33107 .5986 .32675 .59212 .31853 Mtetra
.69 .745 .894 r
.59212 .31853 .5986 .32675 .61123 .3219 .60479 .31324 Mtetra
.699 .738 .881 r
.60479 .31324 .61123 .3219 .62391 .31656 .61749 .30751 Mtetra
.705 .731 .871 r
.61749 .30751 .62391 .31656 .63662 .3108 .63023 .30145 Mtetra
.708 .726 .864 r
.63023 .30145 .63662 .3108 .64937 .30473 .64301 .29518 Mtetra
.707 .722 .861 r
.64301 .29518 .64937 .30473 .66215 .29849 .65583 .28887 Mtetra
.7 .719 .864 r
.65583 .28887 .66215 .29849 .67498 .29228 .66871 .28284 Mtetra
.678 .716 .877 r
.66871 .28284 .67498 .29228 .68788 .28648 .68168 .27774 Mtetra
.615 .708 .911 r
.68168 .27774 .68788 .28648 .70089 .28182 .69483 .27476 Mtetra
.416 .663 .962 r
.69483 .27476 .70089 .28182 .7141 .27941 .70827 .27566 Mtetra
0 .347 .741 r
.70827 .27566 .7141 .27941 .72761 .28042 .72217 .2819 Mtetra
.653 .105 0 r
.72217 .2819 .72761 .28042 .74148 .28508 .73655 .29295 Mtetra
.682 .217 .142 r
.73655 .29295 .74148 .28508 .75563 .2915 .7512 .30483 Mtetra
.58 .165 .219 r
.7512 .30483 .75563 .2915 .76976 .29565 .76561 .31097 Mtetra
.355 0 .181 r
.76561 .31097 .76976 .29565 .7835 .29332 .77929 .30605 Mtetra
0 0 0 r
.77929 .30605 .7835 .29332 .79663 .28312 .79207 .28995 Mtetra
.698 .842 .412 r
.79207 .28995 .79663 .28312 .80928 .26747 .80427 .26786 Mtetra
.943 .96 .679 r
.80427 .26786 .80928 .26747 .82179 .2508 .81643 .2463 Mtetra
.919 .905 .793 r
.81643 .2463 .82179 .2508 .83451 .23656 .82896 .22932 Mtetra
.664 .741 .908 r
.20877 .42089 .21628 .42788 .22724 .4241 .21976 .41708 Mtetra
.21976 .41708 .22724 .4241 .23825 .4203 .2308 .41325 Mtetra
.2308 .41325 .23825 .4203 .24931 .41649 .24188 .40941 Mtetra
.663 .741 .908 r
.24188 .40941 .24931 .41649 .26041 .41267 .25301 .40556 Mtetra
.25301 .40556 .26041 .41267 .27156 .40882 .26419 .40169 Mtetra
.26419 .40169 .27156 .40882 .28276 .40497 .27542 .3978 Mtetra
.27542 .3978 .28276 .40497 .29401 .4011 .28669 .39391 Mtetra
.28669 .39391 .29401 .4011 .3053 .39722 .29802 .39 Mtetra
.662 .742 .909 r
.29802 .39 .3053 .39722 .31664 .39333 .30939 .38609 Mtetra
.30939 .38609 .31664 .39333 .32803 .38944 .32081 .38219 Mtetra
.661 .742 .91 r
.32081 .38219 .32803 .38944 .33947 .38556 .33227 .3783 Mtetra
.659 .742 .911 r
.33227 .3783 .33947 .38556 .35096 .38169 .34379 .37445 Mtetra
.657 .743 .913 r
.34379 .37445 .35096 .38169 .36249 .37786 .35535 .37064 Mtetra
.654 .743 .916 r
.35535 .37064 .36249 .37786 .37407 .37408 .36696 .3669 Mtetra
.65 .744 .919 r
.36696 .3669 .37407 .37408 .3857 .37037 .37862 .36326 Mtetra
.644 .746 .923 r
.37862 .36326 .3857 .37037 .39738 .36677 .39032 .35975 Mtetra
.637 .747 .928 r
.39032 .35975 .39738 .36677 .40911 .36331 .40207 .3564 Mtetra
.629 .749 .934 r
.40207 .3564 .40911 .36331 .42089 .36001 .41388 .35324 Mtetra
.619 .751 .94 r
.41388 .35324 .42089 .36001 .43271 .35691 .42573 .35029 Mtetra
.608 .753 .947 r
.42573 .35029 .43271 .35691 .44459 .35401 .43764 .34755 Mtetra
.596 .755 .954 r
.43764 .34755 .44459 .35401 .45653 .35132 .44961 .34502 Mtetra
.585 .757 .96 r
.44961 .34502 .45653 .35132 .46853 .34884 .46164 .34267 Mtetra
.578 .76 .965 r
.46164 .34267 .46853 .34884 .48059 .34652 .47374 .3404 Mtetra
.575 .762 .967 r
.47374 .3404 .48059 .34652 .49272 .3443 .4859 .33816 Mtetra
.577 .763 .966 r
.4859 .33816 .49272 .3443 .50492 .34209 .49814 .33586 Mtetra
.586 .764 .964 r
.49814 .33586 .50492 .34209 .51718 .33979 .51044 .33338 Mtetra
.601 .764 .958 r
.51044 .33338 .51718 .33979 .52952 .3373 .52282 .33061 Mtetra
.619 .763 .948 r
.52282 .33061 .52952 .3373 .54193 .33449 .53526 .32745 Mtetra
.639 .76 .936 r
.53526 .32745 .54193 .33449 .55439 .33127 .54776 .32381 Mtetra
.658 .754 .921 r
.54776 .32381 .55439 .33127 .56692 .32756 .56032 .31963 Mtetra
.674 .748 .906 r
.56032 .31963 .56692 .32756 .5795 .32331 .57293 .31492 Mtetra
.687 .74 .892 r
.57293 .31492 .5795 .32331 .59212 .31853 .58559 .30969 Mtetra
.696 .733 .879 r
.58559 .30969 .59212 .31853 .60479 .31324 .59828 .30402 Mtetra
.703 .727 .869 r
.59828 .30402 .60479 .31324 .61749 .30751 .61102 .29799 Mtetra
.706 .722 .862 r
.61102 .29799 .61749 .30751 .63023 .30145 .62379 .29172 Mtetra
.707 .719 .858 r
.62379 .29172 .63023 .30145 .64301 .29518 .6366 .28536 Mtetra
.703 .716 .859 r
.6366 .28536 .64301 .29518 .65583 .28887 .64946 .27913 Mtetra
.689 .713 .867 r
.64946 .27913 .65583 .28887 .66871 .28284 .6624 .27351 Mtetra
.647 .707 .891 r
.6624 .27351 .66871 .28284 .68168 .27774 .67546 .26953 Mtetra
.513 .678 .94 r
.67546 .26953 .68168 .27774 .69483 .27476 .68878 .26898 Mtetra
.039 .471 .881 r
.68878 .26898 .69483 .27476 .70827 .27566 .70252 .27421 Mtetra
.631 .07 0 r
.70252 .27421 .70827 .27566 .72217 .2819 .71685 .28652 Mtetra
.761 .282 .101 r
.71685 .28652 .72217 .2819 .73655 .29295 .73172 .30388 Mtetra
.716 .285 .225 r
.73172 .30388 .73655 .29295 .7512 .30483 .74674 .31965 Mtetra
.565 .161 .234 r
.74674 .31965 .7512 .30483 .76561 .31097 .76123 .32502 Mtetra
.166 0 .086 r
.76123 .32502 .76561 .31097 .77929 .30605 .77464 .31484 Mtetra
0 0 0 r
.77464 .31484 .77929 .30605 .79207 .28995 .78698 .29167 Mtetra
.965 .925 .594 r
.78698 .29167 .79207 .28995 .80427 .26786 .79878 .26365 Mtetra
.967 .877 .694 r
.79878 .26365 .80427 .26786 .81643 .2463 .81072 .23867 Mtetra
.9 .828 .767 r
.81072 .23867 .81643 .2463 .82896 .22932 .82319 .22038 Mtetra
.664 .741 .908 r
.2012 .41384 .20877 .42089 .21976 .41708 .21222 .41 Mtetra
.21222 .41 .21976 .41708 .2308 .41325 .22329 .40615 Mtetra
.663 .741 .908 r
.22329 .40615 .2308 .41325 .24188 .40941 .2344 .40228 Mtetra
.2344 .40228 .24188 .40941 .25301 .40556 .24556 .39839 Mtetra
.24556 .39839 .25301 .40556 .26419 .40169 .25676 .39449 Mtetra
.25676 .39449 .26419 .40169 .27542 .3978 .26802 .39058 Mtetra
.26802 .39058 .27542 .3978 .28669 .39391 .27932 .38666 Mtetra
.662 .741 .909 r
.27932 .38666 .28669 .39391 .29802 .39 .29067 .38274 Mtetra
.662 .742 .909 r
.29067 .38274 .29802 .39 .30939 .38609 .30207 .37882 Mtetra
.661 .742 .91 r
.30207 .37882 .30939 .38609 .32081 .38219 .31352 .37491 Mtetra
.659 .742 .911 r
.31352 .37491 .32081 .38219 .33227 .3783 .32501 .37102 Mtetra
.657 .743 .913 r
.32501 .37102 .33227 .3783 .34379 .37445 .33656 .36718 Mtetra
.654 .743 .915 r
.33656 .36718 .34379 .37445 .35535 .37064 .34814 .36341 Mtetra
.651 .744 .918 r
.34814 .36341 .35535 .37064 .36696 .3669 .35978 .35973 Mtetra
.645 .745 .922 r
.35978 .35973 .36696 .3669 .37862 .36326 .37146 .35617 Mtetra
.639 .746 .926 r
.37146 .35617 .37862 .36326 .39032 .35975 .38319 .35277 Mtetra
.631 .748 .932 r
.38319 .35277 .39032 .35975 .40207 .3564 .39497 .34954 Mtetra
.622 .75 .938 r
.39497 .34954 .40207 .3564 .41388 .35324 .4068 .34652 Mtetra
.611 .751 .945 r
.4068 .34652 .41388 .35324 .42573 .35029 .41869 .34371 Mtetra
.598 .753 .952 r
.41869 .34371 .42573 .35029 .43764 .34755 .43063 .34115 Mtetra
.585 .755 .959 r
.43063 .34115 .43764 .34755 .44961 .34502 .44262 .33879 Mtetra
.582 .76 .963 r
.44262 .33879 .44961 .34502 .46164 .34267 .45469 .33644 Mtetra
.581 .761 .964 r
.45469 .33644 .46164 .34267 .47374 .3404 .46682 .33409 Mtetra
.58 .759 .963 r
.46682 .33409 .47374 .3404 .4859 .33816 .47902 .33175 Mtetra
.587 .759 .961 r
.47902 .33175 .4859 .33816 .49814 .33586 .4913 .32927 Mtetra
.6 .759 .955 r
.4913 .32927 .49814 .33586 .51044 .33338 .50364 .32652 Mtetra
.618 .758 .945 r
.50364 .32652 .51044 .33338 .52282 .33061 .51605 .3234 Mtetra
.637 .754 .933 r
.51605 .3234 .52282 .33061 .53526 .32745 .52853 .31981 Mtetra
.655 .749 .919 r
.52853 .31981 .53526 .32745 .54776 .32381 .54107 .31571 Mtetra
.671 .743 .904 r
.54107 .31571 .54776 .32381 .56032 .31963 .55366 .31108 Mtetra
.684 .736 .89 r
.55366 .31108 .56032 .31963 .57293 .31492 .5663 .30593 Mtetra
.694 .729 .878 r
.5663 .30593 .57293 .31492 .58559 .30969 .57899 .30032 Mtetra
.7 .723 .868 r
.57899 .30032 .58559 .30969 .59828 .30402 .59172 .29434 Mtetra
.704 .719 .86 r
.59172 .29434 .59828 .30402 .61102 .29799 .60448 .2881 Mtetra
.706 .715 .856 r
.60448 .2881 .61102 .29799 .62379 .29172 .61729 .28173 Mtetra
.704 .713 .856 r
.61729 .28173 .62379 .29172 .6366 .28536 .63014 .27538 Mtetra
.697 .712 .86 r
.63014 .27538 .6366 .28536 .64946 .27913 .64305 .26937 Mtetra
.673 .708 .875 r
.64305 .26937 .64946 .27913 .6624 .27351 .65605 .26438 Mtetra
.599 .694 .909 r
.65605 .26438 .6624 .27351 .67546 .26953 .66922 .26185 Mtetra
.348 .608 .946 r
.66922 .26185 .67546 .26953 .68878 .26898 .68272 .26411 Mtetra
0 .181 .636 r
.68272 .26411 .68878 .26898 .70252 .27421 .69674 .27372 Mtetra
.754 .236 0 r
.69674 .27372 .70252 .27421 .71685 .28652 .71143 .29122 Mtetra
.796 .331 .133 r
.71143 .29122 .71685 .28652 .73172 .30388 .72662 .31252 Mtetra
.728 .276 .179 r
.72662 .31252 .73172 .30388 .74674 .31965 .74175 .32858 Mtetra
.441 0 .041 r
.74175 .32858 .74674 .31965 .76123 .32502 .75605 .32983 Mtetra
.681 .9 .549 r
.75605 .32983 .76123 .32502 .77464 .31484 .76907 .31308 Mtetra
.984 .893 .646 r
.76907 .31308 .77464 .31484 .78698 .29167 .78104 .2841 Mtetra
.957 .808 .655 r
.78104 .2841 .78698 .29167 .79878 .26365 .79267 .25298 Mtetra
.911 .769 .692 r
.79267 .25298 .79878 .26365 .81072 .23867 .80463 .22742 Mtetra
.854 .754 .752 r
.80463 .22742 .81072 .23867 .82319 .22038 .81723 .20978 Mtetra
.664 .741 .908 r
.19358 .40674 .2012 .41384 .21222 .41 .20462 .40287 Mtetra
.663 .741 .908 r
.20462 .40287 .21222 .41 .22329 .40615 .21571 .39899 Mtetra
.21571 .39899 .22329 .40615 .2344 .40228 .22685 .39509 Mtetra
.22685 .39509 .2344 .40228 .24556 .39839 .23804 .39117 Mtetra
.23804 .39117 .24556 .39839 .25676 .39449 .24928 .38725 Mtetra
.24928 .38725 .25676 .39449 .26802 .39058 .26056 .38331 Mtetra
.663 .741 .909 r
.26056 .38331 .26802 .39058 .27932 .38666 .27189 .37937 Mtetra
.662 .742 .909 r
.27189 .37937 .27932 .38666 .29067 .38274 .28327 .37543 Mtetra
.661 .742 .91 r
.28327 .37543 .29067 .38274 .30207 .37882 .2947 .37149 Mtetra
.66 .742 .911 r
.2947 .37149 .30207 .37882 .31352 .37491 .30617 .36758 Mtetra
.658 .742 .912 r
.30617 .36758 .31352 .37491 .32501 .37102 .31769 .36371 Mtetra
.655 .743 .914 r
.31769 .36371 .32501 .37102 .33656 .36718 .32926 .3599 Mtetra
.652 .744 .917 r
.32926 .3599 .33656 .36718 .34814 .36341 .34088 .35618 Mtetra
.647 .745 .921 r
.34088 .35618 .34814 .36341 .35978 .35973 .35254 .35257 Mtetra
.641 .746 .925 r
.35254 .35257 .35978 .35973 .37146 .35617 .36425 .3491 Mtetra
.633 .747 .93 r
.36425 .3491 .37146 .35617 .38319 .35277 .376 .34581 Mtetra
.624 .749 .936 r
.376 .34581 .38319 .35277 .39497 .34954 .38781 .3427 Mtetra
.613 .75 .942 r
.38781 .3427 .39497 .34954 .4068 .34652 .39967 .33984 Mtetra
.595 .749 .951 r
.39967 .33984 .4068 .34652 .41869 .34371 .41157 .33733 Mtetra
.579 .754 .961 r
.41157 .33733 .41869 .34371 .43063 .34115 .42353 .33508 Mtetra
.588 .769 .966 r
.42353 .33508 .43063 .34115 .44262 .33879 .43557 .33255 Mtetra
.592 .766 .962 r
.43557 .33255 .44262 .33879 .45469 .33644 .44768 .32994 Mtetra
.587 .756 .959 r
.44768 .32994 .45469 .33644 .46682 .33409 .45985 .3275 Mtetra
.59 .755 .957 r
.45985 .3275 .46682 .33409 .47902 .33175 .47209 .32499 Mtetra
.601 .755 .951 r
.47209 .32499 .47902 .33175 .4913 .32927 .4844 .32224 Mtetra
.617 .753 .943 r
.4844 .32224 .4913 .32927 .50364 .32652 .49678 .31914 Mtetra
.635 .749 .931 r
.49678 .31914 .50364 .32652 .51605 .3234 .50923 .3156 Mtetra
.652 .744 .917 r
.50923 .3156 .51605 .3234 .52853 .31981 .52175 .31156 Mtetra
.668 .738 .903 r
.52175 .31156 .52853 .31981 .54107 .31571 .53432 .307 Mtetra
.681 .731 .889 r
.53432 .307 .54107 .31571 .55366 .31108 .54695 .30193 Mtetra
.691 .725 .876 r
.54695 .30193 .55366 .31108 .5663 .30593 .55962 .2964 Mtetra
.698 .72 .866 r
.55962 .2964 .5663 .30593 .57899 .30032 .57234 .29049 Mtetra
.702 .715 .859 r
.57234 .29049 .57899 .30032 .59172 .29434 .58509 .28431 Mtetra
.704 .712 .855 r
.58509 .28431 .59172 .29434 .60448 .2881 .59789 .27796 Mtetra
.704 .711 .854 r
.59789 .27796 .60448 .2881 .61729 .28173 .61074 .27158 Mtetra
.7 .71 .856 r
.61074 .27158 .61729 .28173 .63014 .27538 .62363 .26536 Mtetra
.688 .709 .864 r
.62363 .26536 .63014 .27538 .64305 .26937 .63659 .25967 Mtetra
.652 .703 .884 r
.63659 .25967 .64305 .26937 .65605 .26438 .64965 .25542 Mtetra
.541 .673 .923 r
.64965 .25542 .65605 .26438 .66922 .26185 .66293 .25434 Mtetra
.178 .511 .914 r
.66293 .25434 .66922 .26185 .68272 .26411 .67658 .25902 Mtetra
.492 0 0 r
.67658 .25902 .68272 .26411 .69674 .27372 .6908 .27165 Mtetra
.766 .258 0 r
.6908 .27165 .69674 .27372 .71143 .29122 .70566 .29147 Mtetra
.793 .297 0 r
.70566 .29147 .71143 .29122 .72662 .31252 .72087 .31248 Mtetra
.642 .081 0 r
.72087 .31248 .72662 .31252 .74175 .32858 .73579 .32464 Mtetra
.621 .884 .989 r
.73579 .32464 .74175 .32858 .75605 .32983 .74971 .31976 Mtetra
.894 .778 .726 r
.74971 .31976 .75605 .32983 .76907 .31308 .76239 .29775 Mtetra
.89 .713 .656 r
.76239 .29775 .76907 .31308 .78104 .2841 .77425 .26669 Mtetra
.87 .69 .655 r
.77425 .26669 .78104 .2841 .79267 .25298 .78603 .23661 Mtetra
.843 .688 .69 r
.78603 .23661 .79267 .25298 .80463 .22742 .79826 .21351 Mtetra
.804 .701 .75 r
.79826 .21351 .80463 .22742 .81723 .20978 .81113 .19819 Mtetra
.663 .741 .908 r
.18589 .39959 .19358 .40674 .20462 .40287 .19696 .39569 Mtetra
.19696 .39569 .20462 .40287 .21571 .39899 .20808 .39177 Mtetra
.20808 .39177 .21571 .39899 .22685 .39509 .21925 .38784 Mtetra
.21925 .38784 .22685 .39509 .23804 .39117 .23046 .3839 Mtetra
.23046 .3839 .23804 .39117 .24928 .38725 .24173 .37995 Mtetra
.663 .741 .909 r
.24173 .37995 .24928 .38725 .26056 .38331 .25304 .37599 Mtetra
.662 .742 .909 r
.25304 .37599 .26056 .38331 .27189 .37937 .2644 .37202 Mtetra
.661 .742 .91 r
.2644 .37202 .27189 .37937 .28327 .37543 .2758 .36807 Mtetra
.66 .742 .91 r
.2758 .36807 .28327 .37543 .2947 .37149 .28726 .36413 Mtetra
.658 .742 .912 r
.28726 .36413 .2947 .37149 .30617 .36758 .29876 .36023 Mtetra
.656 .743 .914 r
.29876 .36023 .30617 .36758 .31769 .36371 .31031 .35639 Mtetra
.653 .743 .916 r
.31031 .35639 .31769 .36371 .32926 .3599 .3219 .35262 Mtetra
.648 .744 .919 r
.3219 .35262 .32926 .3599 .34088 .35618 .33355 .34895 Mtetra
.643 .745 .923 r
.33355 .34895 .34088 .35618 .35254 .35257 .34523 .34542 Mtetra
.636 .746 .928 r
.34523 .34542 .35254 .35257 .36425 .3491 .35697 .34204 Mtetra
.627 .747 .934 r
.35697 .34204 .36425 .3491 .376 .34581 .36875 .33886 Mtetra
.614 .747 .941 r
.36875 .33886 .376 .34581 .38781 .3427 .38058 .33598 Mtetra
.58 .743 .954 r
.38058 .33598 .38781 .3427 .39967 .33984 .39244 .33379 Mtetra
.549 .756 .973 r
.39244 .33379 .39967 .33984 .41157 .33733 .40435 .33197 Mtetra
.597 .797 .976 r
.40435 .33197 .41157 .33733 .42353 .33508 .41637 .32904 Mtetra
.619 .782 .96 r
.41637 .32904 .42353 .33508 .43557 .33255 .42847 .32579 Mtetra
.599 .753 .952 r
.42847 .32579 .43557 .33255 .44768 .32994 .44061 .32312 Mtetra
.594 .75 .952 r
.44061 .32312 .44768 .32994 .45985 .3275 .45282 .32055 Mtetra
.603 .75 .948 r
.45282 .32055 .45985 .3275 .47209 .32499 .4651 .31778 Mtetra
.617 .748 .94 r
.4651 .31778 .47209 .32499 .4844 .32224 .47745 .31468 Mtetra
.634 .745 .928 r
.47745 .31468 .4844 .32224 .49678 .31914 .48987 .31117 Mtetra
.65 .74 .915 r
.48987 .31117 .49678 .31914 .50923 .3156 .50236 .30719 Mtetra
.665 .734 .901 r
.50236 .30719 .50923 .3156 .52175 .31156 .51491 .3027 Mtetra
.678 .728 .887 r
.51491 .3027 .52175 .31156 .53432 .307 .52752 .29772 Mtetra
.688 .722 .875 r
.52752 .29772 .53432 .307 .54695 .30193 .54018 .29228 Mtetra
.695 .716 .866 r
.54018 .29228 .54695 .30193 .55962 .2964 .55288 .28645 Mtetra
.699 .712 .858 r
.55288 .28645 .55962 .2964 .57234 .29049 .56563 .28034 Mtetra
.702 .71 .854 r
.56563 .28034 .57234 .29049 .58509 .28431 .57842 .27405 Mtetra
.703 .709 .853 r
.57842 .27405 .58509 .28431 .59789 .27796 .59126 .2677 Mtetra
.701 .709 .854 r
.59126 .2677 .59789 .27796 .61074 .27158 .60414 .2614 Mtetra
.695 .709 .859 r
.60414 .2614 .61074 .27158 .62363 .26536 .61707 .25536 Mtetra
.679 .708 .87 r
.61707 .25536 .62363 .26536 .63659 .25967 .63008 .25003 Mtetra
.632 .698 .893 r
.63008 .25003 .63659 .25967 .64965 .25542 .64321 .24643 Mtetra
.495 .652 .929 r
.64321 .24643 .64965 .25542 .66293 .25434 .65656 .24638 Mtetra
.116 .458 .887 r
.65656 .24638 .66293 .25434 .67658 .25902 .6703 .25224 Mtetra
0 .071 .581 r
.6703 .25224 .67658 .25902 .6908 .27165 .68456 .26535 Mtetra
.619 .127 0 r
.68456 .26535 .6908 .27165 .70566 .29147 .69934 .28356 Mtetra
0 0 .525 r
.69934 .28356 .70566 .29147 .72087 .31248 .71428 .30001 Mtetra
.311 .47 .857 r
.71428 .30001 .72087 .31248 .73579 .32464 .72878 .30567 Mtetra
.707 .605 .739 r
.72878 .30567 .73579 .32464 .74971 .31976 .74231 .29529 Mtetra
.786 .611 .663 r
.74231 .29529 .74971 .31976 .76239 .29775 .75488 .27156 Mtetra
.803 .612 .643 r
.75488 .27156 .76239 .29775 .77425 .26669 .76695 .24289 Mtetra
.802 .621 .657 r
.76695 .24289 .77425 .26669 .78603 .23661 .77913 .21738 Mtetra
.788 .641 .699 r
.77913 .21738 .78603 .23661 .79826 .21351 .79179 .19873 Mtetra
.762 .673 .764 r
.79179 .19873 .79826 .21351 .81113 .19819 .80498 .18648 Mtetra
.663 .741 .908 r
.17814 .39237 .18589 .39959 .19696 .39569 .18924 .38844 Mtetra
.18924 .38844 .19696 .39569 .20808 .39177 .20039 .3845 Mtetra
.20039 .3845 .20808 .39177 .21925 .38784 .21158 .38054 Mtetra
.21158 .38054 .21925 .38784 .23046 .3839 .22283 .37657 Mtetra
.22283 .37657 .23046 .3839 .24173 .37995 .23412 .37259 Mtetra
.662 .741 .909 r
.23412 .37259 .24173 .37995 .25304 .37599 .24546 .36861 Mtetra
.662 .742 .909 r
.24546 .36861 .25304 .37599 .2644 .37202 .25684 .36463 Mtetra
.661 .742 .91 r
.25684 .36463 .2644 .37202 .2758 .36807 .26828 .36067 Mtetra
.659 .742 .911 r
.26828 .36067 .2758 .36807 .28726 .36413 .27976 .35674 Mtetra
.657 .742 .913 r
.27976 .35674 .28726 .36413 .29876 .36023 .29129 .35285 Mtetra
.654 .743 .915 r
.29129 .35285 .29876 .36023 .31031 .35639 .30286 .34904 Mtetra
.65 .744 .918 r
.30286 .34904 .31031 .35639 .3219 .35262 .31448 .34532 Mtetra
.645 .745 .922 r
.31448 .34532 .3219 .35262 .33355 .34895 .32615 .34172 Mtetra
.638 .745 .926 r
.32615 .34172 .33355 .34895 .34523 .34542 .33786 .33826 Mtetra
.63 .746 .931 r
.33786 .33826 .34523 .34542 .35697 .34204 .34962 .335 Mtetra
.609 .744 .941 r
.34962 .335 .35697 .34204 .36875 .33886 .36141 .33222 Mtetra
.524 .726 .966 r
.36141 .33222 .36875 .33886 .38058 .33598 .37319 .33104 Mtetra
.431 .745 .993 r
.37319 .33104 .38058 .33598 .39244 .33379 .38501 .33048 Mtetra
.61 .871 .991 r
.38501 .33048 .39244 .33379 .40435 .33197 .39705 .32656 Mtetra
.677 .82 .952 r
.39705 .32656 .40435 .33197 .41637 .32904 .40918 .32179 Mtetra
.621 .747 .936 r
.40918 .32179 .41637 .32904 .42847 .32579 .42131 .31865 Mtetra
.6 .743 .945 r
.42131 .31865 .42847 .32579 .44061 .32312 .43348 .31598 Mtetra
.605 .746 .944 r
.43348 .31598 .44061 .32312 .45282 .32055 .44573 .31316 Mtetra
.618 .744 .936 r
.44573 .31316 .45282 .32055 .4651 .31778 .45805 .31006 Mtetra
.633 .741 .926 r
.45805 .31006 .4651 .31778 .47745 .31468 .47044 .30657 Mtetra
.648 .736 .913 r
.47044 .30657 .47745 .31468 .48987 .31117 .48291 .30263 Mtetra
.662 .73 .9 r
.48291 .30263 .48987 .31117 .50236 .30719 .49543 .29821 Mtetra
.675 .724 .887 r
.49543 .29821 .50236 .30719 .51491 .3027 .50802 .29331 Mtetra
.684 .718 .875 r
.50802 .29331 .51491 .3027 .52752 .29772 .52066 .28796 Mtetra
.692 .714 .865 r
.52066 .28796 .52752 .29772 .54018 .29228 .53335 .28223 Mtetra
.697 .71 .858 r
.53335 .28223 .54018 .29228 .55288 .28645 .54609 .27621 Mtetra
.7 .708 .854 r
.54609 .27621 .55288 .28645 .56563 .28034 .55887 .27 Mtetra
.701 .707 .852 r
.55887 .27 .56563 .28034 .57842 .27405 .5717 .26369 Mtetra
.7 .707 .853 r
.5717 .26369 .57842 .27405 .59126 .2677 .58457 .2574 Mtetra
.697 .708 .856 r
.58457 .2574 .59126 .2677 .60414 .2614 .59749 .25124 Mtetra
.69 .71 .863 r
.59749 .25124 .60414 .2614 .61707 .25536 .61047 .24542 Mtetra
.671 .708 .875 r
.61047 .24542 .61707 .25536 .63008 .25003 .62353 .2404 Mtetra
.619 .695 .898 r
.62353 .2404 .63008 .25003 .64321 .24643 .63671 .23718 Mtetra
.485 .641 .925 r
.63671 .23718 .64321 .24643 .65656 .24638 .6501 .23738 Mtetra
.197 .481 .895 r
.6501 .23738 .65656 .24638 .6703 .25224 .66384 .24275 Mtetra
0 .251 .762 r
.66384 .24275 .6703 .25224 .68456 .26535 .678 .2536 Mtetra
0 .198 .728 r
.678 .2536 .68456 .26535 .69934 .28356 .6925 .26697 Mtetra
.247 .358 .78 r
.6925 .26697 .69934 .28356 .71428 .30001 .70701 .27656 Mtetra
.556 .483 .729 r
.70701 .27656 .71428 .30001 .72878 .30567 .72106 .27584 Mtetra
.683 .528 .67 r
.72106 .27584 .72878 .30567 .74231 .29529 .73437 .26267 Mtetra
.731 .549 .645 r
.73437 .26267 .74231 .29529 .75488 .27156 .74706 .24103 Mtetra
.75 .566 .646 r
.74706 .24103 .75488 .27156 .76695 .24289 .75955 .21786 Mtetra
.754 .589 .672 r
.75955 .21786 .76695 .24289 .77913 .21738 .77225 .19851 Mtetra
.747 .625 .723 r
.77225 .19851 .77913 .21738 .79179 .19873 .78535 .18465 Mtetra
.728 .668 .791 r
.78535 .18465 .79179 .19873 .80498 .18648 .79884 .17526 Mtetra
.663 .741 .908 r
.17033 .3851 .17814 .39237 .18924 .38844 .18146 .38114 Mtetra
.18146 .38114 .18924 .38844 .20039 .3845 .19263 .37717 Mtetra
.19263 .37717 .20039 .3845 .21158 .38054 .20386 .37318 Mtetra
.20386 .37318 .21158 .38054 .22283 .37657 .21513 .36919 Mtetra
.662 .741 .909 r
.21513 .36919 .22283 .37657 .23412 .37259 .22644 .36519 Mtetra
.662 .742 .909 r
.22644 .36519 .23412 .37259 .24546 .36861 .23781 .36119 Mtetra
.661 .742 .91 r
.23781 .36119 .24546 .36861 .25684 .36463 .24923 .3572 Mtetra
.66 .742 .911 r
.24923 .3572 .25684 .36463 .26828 .36067 .26069 .35324 Mtetra
.658 .742 .912 r
.26069 .35324 .26828 .36067 .27976 .35674 .2722 .34931 Mtetra
.655 .743 .914 r
.2722 .34931 .27976 .35674 .29129 .35285 .28375 .34545 Mtetra
.651 .743 .917 r
.28375 .34545 .29129 .35285 .30286 .34904 .29535 .34167 Mtetra
.647 .744 .92 r
.29535 .34167 .30286 .34904 .31448 .34532 .307 .338 Mtetra
.641 .745 .924 r
.307 .338 .31448 .34532 .32615 .34172 .31869 .33447 Mtetra
.632 .745 .929 r
.31869 .33447 .32615 .34172 .33786 .33826 .33042 .33114 Mtetra
.591 .736 .944 r
.33042 .33114 .33786 .33826 .34962 .335 .34216 .32876 Mtetra
.329 .649 .969 r
.34216 .32876 .34962 .335 .36141 .33222 .35376 .33007 Mtetra
0 .488 .754 r
.35376 .33007 .36141 .33222 .37319 .33104 .3654 .33242 Mtetra
.543 .928 .861 r
.3654 .33242 .37319 .33104 .38501 .33048 .37755 .32626 Mtetra
.779 .871 .916 r
.37755 .32626 .38501 .33048 .39705 .32656 .38981 .31821 Mtetra
.655 .727 .902 r
.38981 .31821 .39705 .32656 .40918 .32179 .40195 .31412 Mtetra
.608 .731 .932 r
.40195 .31412 .40918 .32179 .42131 .31865 .41409 .3113 Mtetra
.608 .742 .94 r
.41409 .3113 .42131 .31865 .43348 .31598 .42631 .30843 Mtetra
.619 .741 .933 r
.42631 .30843 .43348 .31598 .44573 .31316 .4386 .30529 Mtetra
.632 .737 .923 r
.4386 .30529 .44573 .31316 .45805 .31006 .45096 .3018 Mtetra
.647 .732 .911 r
.45096 .3018 .45805 .31006 .47044 .30657 .46339 .29789 Mtetra
.66 .727 .899 r
.46339 .29789 .47044 .30657 .48291 .30263 .47589 .29353 Mtetra
.672 .721 .886 r
.47589 .29353 .48291 .30263 .49543 .29821 .48846 .28871 Mtetra
.681 .716 .875 r
.48846 .28871 .49543 .29821 .50802 .29331 .50108 .28346 Mtetra
.689 .711 .866 r
.50108 .28346 .50802 .29331 .52066 .28796 .51376 .27784 Mtetra
.694 .708 .859 r
.51376 .27784 .52066 .28796 .53335 .28223 .52648 .27192 Mtetra
.697 .706 .854 r
.52648 .27192 .53335 .28223 .54609 .27621 .53925 .2658 Mtetra
.698 .705 .853 r
.53925 .2658 .54609 .27621 .55887 .27 .55207 .25957 Mtetra
.698 .706 .853 r
.55207 .25957 .55887 .27 .5717 .26369 .56493 .25333 Mtetra
.697 .707 .856 r
.56493 .25333 .5717 .26369 .58457 .2574 .57784 .24717 Mtetra
.693 .71 .861 r
.57784 .24717 .58457 .2574 .59749 .25124 .5908 .24119 Mtetra
.685 .711 .868 r
.5908 .24119 .59749 .25124 .61047 .24542 .60383 .23557 Mtetra
.665 .709 .881 r
.60383 .23557 .61047 .24542 .62353 .2404 .61692 .23074 Mtetra
.618 .695 .899 r
.61692 .23074 .62353 .2404 .63671 .23718 .63014 .22752 Mtetra
.513 .647 .917 r
.63014 .22752 .63671 .23718 .6501 .23738 .64354 .22715 Mtetra
.345 .54 .901 r
.64354 .22715 .6501 .23738 .66384 .24275 .65721 .2306 Mtetra
.234 .426 .846 r
.65721 .2306 .66384 .24275 .678 .2536 .67118 .23743 Mtetra
.315 .406 .796 r
.67118 .23743 .678 .2536 .6925 .26697 .68534 .24471 Mtetra
.485 .447 .74 r
.68534 .24471 .6925 .26697 .70701 .27656 .69943 .24772 Mtetra
.605 .484 .688 r
.69943 .24772 .70701 .27656 .72106 .27584 .71317 .24275 Mtetra
.669 .508 .658 r
.71317 .24275 .72106 .27584 .73437 .26267 .72645 .22978 Mtetra
.702 .529 .651 r
.72645 .22978 .73437 .26267 .74706 .24103 .73942 .21251 Mtetra
.718 .553 .666 r
.73942 .21251 .74706 .24103 .75955 .21786 .75237 .19562 Mtetra
.723 .588 .704 r
.75237 .19562 .75955 .21786 .77225 .19851 .76554 .18199 Mtetra
.718 .633 .762 r
.76554 .18199 .77225 .19851 .78535 .18465 .77901 .17204 Mtetra
.702 .681 .827 r
.77901 .17204 .78535 .18465 .79884 .17526 .79273 .16474 Mtetra
.663 .741 .908 r
.16246 .37777 .17033 .3851 .18146 .38114 .17361 .37379 Mtetra
.17361 .37379 .18146 .38114 .19263 .37717 .18481 .36978 Mtetra
.18481 .36978 .19263 .37717 .20386 .37318 .19607 .36577 Mtetra
.663 .741 .909 r
.19607 .36577 .20386 .37318 .21513 .36919 .20736 .36175 Mtetra
.662 .742 .909 r
.20736 .36175 .21513 .36919 .22644 .36519 .21871 .35773 Mtetra
.661 .742 .91 r
.21871 .35773 .22644 .36519 .23781 .36119 .2301 .35372 Mtetra
.66 .742 .911 r
.2301 .35372 .23781 .36119 .24923 .3572 .24155 .34972 Mtetra
.658 .742 .912 r
.24155 .34972 .24923 .3572 .26069 .35324 .25303 .34576 Mtetra
.656 .742 .914 r
.25303 .34576 .26069 .35324 .2722 .34931 .26457 .34185 Mtetra
.653 .743 .916 r
.26457 .34185 .2722 .34931 .28375 .34545 .27615 .33802 Mtetra
.649 .743 .919 r
.27615 .33802 .28375 .34545 .29535 .34167 .28777 .33428 Mtetra
.643 .744 .922 r
.28777 .33428 .29535 .34167 .307 .338 .29944 .33067 Mtetra
.633 .744 .928 r
.29944 .33067 .307 .338 .31869 .33447 .31115 .32731 Mtetra
.542 .718 .954 r
.31115 .32731 .31869 .33447 .33042 .33114 .32279 .32589 Mtetra
0 .245 .674 r
.32279 .32589 .33042 .33114 .34216 .32876 .33403 .33242 Mtetra
.651 .152 .05 r
.33403 .33242 .34216 .32876 .35376 .33007 .3453 .34055 Mtetra
0 0 0 r
.3453 .34055 .35376 .33007 .3654 .33242 .35772 .32974 Mtetra
.888 .89 .826 r
.35772 .32974 .3654 .33242 .37755 .32626 .37033 .31535 Mtetra
.688 .682 .838 r
.37033 .31535 .37755 .32626 .38981 .31821 .38252 .30959 Mtetra
.619 .71 .91 r
.38252 .30959 .38981 .31821 .40195 .31412 .39464 .30655 Mtetra
.612 .737 .935 r
.39464 .30655 .40195 .31412 .41409 .3113 .40682 .3036 Mtetra
.621 .737 .93 r
.40682 .3036 .41409 .3113 .42631 .30843 .41908 .30041 Mtetra
.633 .734 .921 r
.41908 .30041 .42631 .30843 .4386 .30529 .43141 .29691 Mtetra
.645 .729 .91 r
.43141 .29691 .4386 .30529 .45096 .3018 .44382 .29302 Mtetra
.658 .724 .898 r
.44382 .29302 .45096 .3018 .46339 .29789 .45629 .28871 Mtetra
.669 .719 .886 r
.45629 .28871 .46339 .29789 .47589 .29353 .46883 .28397 Mtetra
.678 .714 .875 r
.46883 .28397 .47589 .29353 .48846 .28871 .48143 .27881 Mtetra
.685 .71 .866 r
.48143 .27881 .48846 .28871 .50108 .28346 .49409 .27329 Mtetra
.691 .706 .86 r
.49409 .27329 .50108 .28346 .51376 .27784 .5068 .26748 Mtetra
.694 .705 .855 r
.5068 .26748 .51376 .27784 .52648 .27192 .51956 .26146 Mtetra
.696 .704 .854 r
.51956 .26146 .52648 .27192 .53925 .2658 .53236 .25533 Mtetra
.696 .705 .854 r
.53236 .25533 .53925 .2658 .55207 .25957 .54521 .24917 Mtetra
.695 .707 .857 r
.54521 .24917 .55207 .25957 .56493 .25333 .55811 .24306 Mtetra
.693 .709 .861 r
.55811 .24306 .56493 .25333 .57784 .24717 .57106 .23706 Mtetra
.689 .712 .866 r
.57106 .23706 .57784 .24717 .5908 .24119 .58407 .23126 Mtetra
.681 .714 .874 r
.58407 .23126 .5908 .24119 .60383 .23557 .59713 .2258 Mtetra
.663 .712 .885 r
.59713 .2258 .60383 .23557 .61692 .23074 .61027 .22102 Mtetra
.626 .699 .898 r
.61027 .22102 .61692 .23074 .63014 .22752 .62351 .21751 Mtetra
.558 .661 .906 r
.62351 .21751 .63014 .22752 .64354 .22715 .6369 .21601 Mtetra
.475 .593 .891 r
.6369 .21601 .64354 .22715 .65721 .2306 .65048 .21691 Mtetra
.443 .523 .845 r
.65048 .21691 .65721 .2306 .67118 .23743 .66425 .21944 Mtetra
.492 .491 .784 r
.66425 .21944 .67118 .23743 .68534 .24471 .67812 .22133 Mtetra
.567 .489 .727 r
.67812 .22133 .68534 .24471 .69943 .24772 .69193 .21972 Mtetra
.626 .5 .689 r
.69193 .21972 .69943 .24772 .71317 .24275 .70552 .213 Mtetra
.663 .516 .673 r
.70552 .213 .71317 .24275 .72645 .22978 .7189 .20201 Mtetra
.686 .537 .679 r
.7189 .20201 .72645 .22978 .73942 .21251 .73217 .18938 Mtetra
.698 .569 .705 r
.73217 .18938 .73942 .21251 .75237 .19562 .74551 .17771 Mtetra
.702 .611 .752 r
.74551 .17771 .75237 .19562 .76554 .18199 .75903 .16823 Mtetra
.697 .661 .811 r
.75903 .16823 .76554 .18199 .77901 .17204 .77275 .16083 Mtetra
.684 .702 .861 r
.77275 .16083 .77901 .17204 .79273 .16474 .78662 .15477 Mtetra
.663 .741 .908 r
.15452 .37039 .16246 .37777 .17361 .37379 .1657 .36637 Mtetra
.1657 .36637 .17361 .37379 .18481 .36978 .17693 .36234 Mtetra
.17693 .36234 .18481 .36978 .19607 .36577 .18821 .3583 Mtetra
.662 .741 .909 r
.18821 .3583 .19607 .36577 .20736 .36175 .19954 .35426 Mtetra
.662 .742 .909 r
.19954 .35426 .20736 .36175 .21871 .35773 .21091 .35022 Mtetra
.661 .742 .91 r
.21091 .35022 .21871 .35773 .2301 .35372 .22233 .3462 Mtetra
.659 .742 .911 r
.22233 .3462 .2301 .35372 .24155 .34972 .2338 .3422 Mtetra
.657 .742 .913 r
.2338 .3422 .24155 .34972 .25303 .34576 .24531 .33825 Mtetra
.654 .743 .915 r
.24531 .33825 .25303 .34576 .26457 .34185 .25687 .33436 Mtetra
.651 .743 .917 r
.25687 .33436 .26457 .34185 .27615 .33802 .26848 .33055 Mtetra
.646 .744 .92 r
.26848 .33055 .27615 .33802 .28777 .33428 .28013 .32686 Mtetra
.631 .741 .927 r
.28013 .32686 .28777 .33428 .29944 .33067 .29181 .32353 Mtetra
.422 .668 .963 r
.29181 .32353 .29944 .33067 .31115 .32731 .30328 .32399 Mtetra
.809 .321 .009 r
.30328 .32399 .31115 .32731 .32279 .32589 .31379 .33998 Mtetra
.735 .362 .346 r
.31379 .33998 .32279 .32589 .33403 .33242 .32439 .35799 Mtetra
0 0 .078 r
.32439 .35799 .33403 .33242 .3453 .34055 .33742 .3386 Mtetra
.943 .845 .717 r
.33742 .3386 .3453 .34055 .35772 .32974 .35071 .31351 Mtetra
.7 .613 .755 r
.35071 .31351 .35772 .32974 .37033 .31535 .36303 .3051 Mtetra
.628 .674 .874 r
.36303 .3051 .37033 .31535 .38252 .30959 .37513 .30176 Mtetra
.616 .732 .929 r
.37513 .30176 .38252 .30959 .39464 .30655 .38728 .2987 Mtetra
.623 .735 .927 r
.38728 .2987 .39464 .30655 .40682 .3036 .39951 .29545 Mtetra
.633 .731 .919 r
.39951 .29545 .40682 .3036 .41908 .30041 .41181 .29192 Mtetra
.645 .727 .908 r
.41181 .29192 .41908 .30041 .43141 .29691 .42418 .28804 Mtetra
.656 .722 .897 r
.42418 .28804 .43141 .29691 .44382 .29302 .43663 .28377 Mtetra
.666 .717 .886 r
.43663 .28377 .44382 .29302 .45629 .28871 .44914 .27909 Mtetra
.675 .712 .876 r
.44914 .27909 .45629 .28871 .46883 .28397 .46172 .27403 Mtetra
.682 .708 .868 r
.46172 .27403 .46883 .28397 .48143 .27881 .47436 .26861 Mtetra
.688 .706 .861 r
.47436 .26861 .48143 .27881 .49409 .27329 .48705 .26292 Mtetra
.691 .704 .857 r
.48705 .26292 .49409 .27329 .5068 .26748 .49979 .25701 Mtetra
.693 .704 .855 r
.49979 .25701 .5068 .26748 .51956 .26146 .51258 .25098 Mtetra
.694 .704 .855 r
.51258 .25098 .51956 .26146 .53236 .25533 .52542 .24491 Mtetra
.693 .706 .858 r
.52542 .24491 .53236 .25533 .54521 .24917 .53831 .23887 Mtetra
.692 .709 .862 r
.53831 .23887 .54521 .24917 .55811 .24306 .55125 .23292 Mtetra
.689 .713 .867 r
.55125 .23292 .55811 .24306 .57106 .23706 .56424 .2271 Mtetra
.685 .716 .873 r
.56424 .2271 .57106 .23706 .58407 .23126 .57728 .22147 Mtetra
.678 .718 .88 r
.57728 .22147 .58407 .23126 .59713 .2258 .59038 .21614 Mtetra
.664 .717 .888 r
.59038 .21614 .59713 .2258 .61027 .22102 .60356 .21131 Mtetra
.638 .706 .896 r
.60356 .21131 .61027 .22102 .62351 .21751 .61682 .20735 Mtetra
.599 .679 .897 r
.61682 .20735 .62351 .21751 .6369 .21601 .6302 .20461 Mtetra
.561 .633 .88 r
.6302 .20461 .6369 .21601 .65048 .21691 .64371 .20314 Mtetra
.55 .583 .84 r
.64371 .20314 .65048 .21691 .66425 .21944 .65734 .20222 Mtetra
.574 .548 .788 r
.65734 .20222 .66425 .21944 .67812 .22133 .67103 .20044 Mtetra
.609 .533 .743 r
.67103 .20044 .67812 .22133 .69193 .21972 .68469 .19638 Mtetra
.641 .534 .717 r
.68469 .19638 .69193 .21972 .70552 .213 .69827 .18959 Mtetra
.664 .547 .712 r
.69827 .18959 .70552 .213 .7189 .20201 .71178 .18092 Mtetra
.679 .572 .727 r
.71178 .18092 .7189 .20201 .73217 .18938 .7253 .17187 Mtetra
.687 .608 .762 r
.7253 .17187 .73217 .18938 .74551 .17771 .73891 .16365 Mtetra
.688 .652 .81 r
.73891 .16365 .74551 .17771 .75903 .16823 .75265 .15663 Mtetra
.681 .693 .855 r
.75265 .15663 .75903 .16823 .77275 .16083 .76652 .15059 Mtetra
.673 .721 .885 r
.76652 .15059 .77275 .16083 .78662 .15477 .7805 .14513 Mtetra
.663 .741 .908 r
.14652 .36295 .15452 .37039 .1657 .36637 .15773 .3589 Mtetra
.15773 .3589 .1657 .36637 .17693 .36234 .16899 .35484 Mtetra
.662 .741 .909 r
.16899 .35484 .17693 .36234 .18821 .3583 .18029 .35078 Mtetra
.662 .742 .909 r
.18029 .35078 .18821 .3583 .19954 .35426 .19165 .34671 Mtetra
.661 .742 .91 r
.19165 .34671 .19954 .35426 .21091 .35022 .20305 .34266 Mtetra
.66 .742 .911 r
.20305 .34266 .21091 .35022 .22233 .3462 .21449 .33863 Mtetra
.658 .742 .912 r
.21449 .33863 .22233 .3462 .2338 .3422 .22599 .33463 Mtetra
.655 .742 .914 r
.22599 .33463 .2338 .3422 .24531 .33825 .23753 .33069 Mtetra
.652 .743 .916 r
.23753 .33069 .24531 .33825 .25687 .33436 .24912 .32682 Mtetra
.648 .743 .919 r
.24912 .32682 .25687 .33436 .26848 .33055 .26074 .32306 Mtetra
.626 .739 .928 r
.26074 .32306 .26848 .33055 .28013 .32686 .27238 .31985 Mtetra
.141 .518 .915 r
.27238 .31985 .28013 .32686 .29181 .32353 .28356 .32337 Mtetra
.89 .505 .295 r
.28356 .32337 .29181 .32353 .30328 .32399 .29287 .35411 Mtetra
.744 .423 .44 r
.29287 .35411 .30328 .32399 .31379 .33998 .30235 .3867 Mtetra
.001 0 .199 r
.30235 .3867 .31379 .33998 .32439 .35799 .31648 .3535 Mtetra
.942 .773 .642 r
.31648 .3535 .32439 .35799 .33742 .3386 .33092 .31272 Mtetra
.69 .543 .682 r
.33092 .31272 .33742 .3386 .35071 .31351 .34347 .30065 Mtetra
.631 .626 .826 r
.34347 .30065 .35071 .31351 .36303 .3051 .35556 .29694 Mtetra
.62 .725 .922 r
.35556 .29694 .36303 .3051 .37513 .30176 .36768 .29378 Mtetra
.625 .733 .924 r
.36768 .29378 .37513 .30176 .38728 .2987 .37988 .29045 Mtetra
.634 .73 .917 r
.37988 .29045 .38728 .2987 .39951 .29545 .39214 .28687 Mtetra
.644 .725 .907 r
.39214 .28687 .39951 .29545 .41181 .29192 .40449 .28299 Mtetra
.655 .721 .897 r
.40449 .28299 .41181 .29192 .42418 .28804 .41691 .27874 Mtetra
.664 .716 .887 r
.41691 .27874 .42418 .28804 .43663 .28377 .42939 .27413 Mtetra
.673 .712 .877 r
.42939 .27413 .43663 .28377 .44914 .27909 .44195 .26915 Mtetra
.679 .708 .869 r
.44195 .26915 .44914 .27909 .46172 .27403 .45456 .26383 Mtetra
.685 .705 .863 r
.45456 .26383 .46172 .27403 .47436 .26861 .46723 .25825 Mtetra
.688 .704 .859 r
.46723 .25825 .47436 .26861 .48705 .26292 .47996 .25246 Mtetra
.691 .704 .857 r
.47996 .25246 .48705 .26292 .49979 .25701 .49273 .24654 Mtetra
.49273 .24654 .49979 .25701 .51258 .25098 .50556 .24057 Mtetra
.691 .706 .859 r
.50556 .24057 .51258 .25098 .52542 .24491 .51843 .23461 Mtetra
.69 .709 .863 r
.51843 .23461 .52542 .24491 .53831 .23887 .53135 .22872 Mtetra
.688 .713 .868 r
.53135 .22872 .53831 .23887 .55125 .23292 .54433 .22294 Mtetra
.685 .716 .873 r
.54433 .22294 .55125 .23292 .56424 .2271 .55736 .2173 Mtetra
.681 .72 .879 r
.55736 .2173 .56424 .2271 .57728 .22147 .57044 .21182 Mtetra
.675 .722 .885 r
.57044 .21182 .57728 .22147 .59038 .21614 .58359 .20657 Mtetra
.665 .722 .891 r
.58359 .20657 .59038 .21614 .60356 .21131 .5968 .20167 Mtetra
.65 .715 .895 r
.5968 .20167 .60356 .21131 .61682 .20735 .61009 .19727 Mtetra
.63 .697 .893 r
.61009 .19727 .61682 .20735 .6302 .20461 .62347 .19353 Mtetra
.613 .667 .878 r
.62347 .19353 .6302 .20461 .64371 .20314 .63694 .19033 Mtetra
.609 .631 .848 r
.63694 .19033 .64371 .20314 .65734 .20222 .6505 .1872 Mtetra
.619 .602 .811 r
.6505 .1872 .65734 .20222 .67103 .20044 .66411 .18342 Mtetra
.637 .586 .781 r
.66411 .18342 .67103 .20044 .68469 .19638 .67773 .17843 Mtetra
.654 .585 .766 r
.67773 .17843 .68469 .19638 .69827 .18959 .69135 .17221 Mtetra
.667 .599 .77 r
.69135 .17221 .69827 .18959 .71178 .18092 .70499 .16533 Mtetra
.676 .625 .791 r
.70499 .16533 .71178 .18092 .7253 .17187 .71868 .15848 Mtetra
.679 .66 .824 r
.71868 .15848 .7253 .17187 .73891 .16365 .73246 .15211 Mtetra
.676 .693 .859 r
.73246 .15211 .73891 .16365 .75265 .15663 .74633 .14629 Mtetra
.671 .718 .884 r
.74633 .14629 .75265 .15663 .76652 .15059 .76029 .14085 Mtetra
.667 .732 .899 r
.76029 .14085 .76652 .15059 .7805 .14513 .77434 .13562 Mtetra
.663 .741 .908 r
.13846 .35544 .14652 .36295 .15773 .3589 .14969 .35137 Mtetra
.663 .741 .909 r
.14969 .35137 .15773 .3589 .16899 .35484 .16098 .34728 Mtetra
.662 .741 .909 r
.16098 .34728 .16899 .35484 .18029 .35078 .17231 .3432 Mtetra
.661 .742 .909 r
.17231 .3432 .18029 .35078 .19165 .34671 .18369 .33912 Mtetra
.66 .742 .91 r
.18369 .33912 .19165 .34671 .20305 .34266 .19512 .33505 Mtetra
.659 .742 .911 r
.19512 .33505 .20305 .34266 .21449 .33863 .20659 .33102 Mtetra
.657 .742 .913 r
.20659 .33102 .21449 .33863 .22599 .33463 .21811 .32702 Mtetra
.654 .742 .915 r
.21811 .32702 .22599 .33463 .23753 .33069 .22968 .32309 Mtetra
.65 .743 .917 r
.22968 .32309 .23753 .33069 .24912 .32682 .24129 .31926 Mtetra
.617 .735 .93 r
.24129 .31926 .24912 .32682 .26074 .32306 .25288 .31625 Mtetra
0 .172 .646 r
.25288 .31625 .26074 .32306 .27238 .31985 .26363 .32403 Mtetra
.899 .561 .398 r
.26363 .32403 .27238 .31985 .28356 .32337 .27115 .37439 Mtetra
.743 .445 .477 r
.27115 .37439 .28356 .32337 .29287 .35411 .27909 .4252 Mtetra
0 0 .225 r
.27909 .4252 .29287 .35411 .30235 .3867 .29491 .37286 Mtetra
.911 .7 .605 r
.29491 .37286 .30235 .3867 .31648 .3535 .31097 .31257 Mtetra
.671 .489 .63 r
.31097 .31257 .31648 .3535 .33092 .31272 .32384 .29624 Mtetra
.627 .575 .776 r
.32384 .29624 .33092 .31272 .34347 .30065 .33592 .29212 Mtetra
.625 .718 .913 r
.33592 .29212 .34347 .30065 .35556 .29694 .34802 .28884 Mtetra
.628 .732 .922 r
.34802 .28884 .35556 .29694 .36768 .29378 .36018 .28543 Mtetra
.636 .728 .915 r
.36018 .28543 .36768 .29378 .37988 .29045 .37242 .2818 Mtetra
.644 .724 .906 r
.37242 .2818 .37988 .29045 .39214 .28687 .38474 .27789 Mtetra
.654 .72 .897 r
.38474 .27789 .39214 .28687 .40449 .28299 .39712 .27366 Mtetra
.662 .715 .888 r
.39712 .27366 .40449 .28299 .41691 .27874 .40958 .26909 Mtetra
.67 .711 .879 r
.40958 .26909 .41691 .27874 .42939 .27413 .42211 .26419 Mtetra
.677 .708 .871 r
.42211 .26419 .42939 .27413 .44195 .26915 .4347 .25898 Mtetra
.682 .706 .865 r
.4347 .25898 .44195 .26915 .45456 .26383 .44735 .2535 Mtetra
.686 .704 .862 r
.44735 .2535 .45456 .26383 .46723 .25825 .46005 .24782 Mtetra
.688 .704 .86 r
.46005 .24782 .46723 .25825 .47996 .25246 .47281 .24202 Mtetra
.689 .705 .86 r
.47281 .24202 .47996 .25246 .49273 .24654 .48562 .23615 Mtetra
.689 .707 .862 r
.48562 .23615 .49273 .24654 .50556 .24057 .49848 .23028 Mtetra
.688 .71 .865 r
.49848 .23028 .50556 .24057 .51843 .23461 .51139 .22447 Mtetra
.686 .713 .869 r
.51139 .22447 .51843 .23461 .53135 .22872 .52435 .21874 Mtetra
.684 .717 .874 r
.52435 .21874 .53135 .22872 .54433 .22294 .53736 .21313 Mtetra
.681 .721 .88 r
.53736 .21313 .54433 .22294 .55736 .2173 .55043 .20765 Mtetra
.677 .724 .885 r
.55043 .20765 .55736 .2173 .57044 .21182 .56355 .2023 Mtetra
.673 .727 .89 r
.56355 .2023 .57044 .21182 .58359 .20657 .57674 .19711 Mtetra
.667 .727 .894 r
.57674 .19711 .58359 .20657 .5968 .20167 .58999 .19213 Mtetra
.658 .723 .897 r
.58999 .19213 .5968 .20167 .61009 .19727 .60331 .18743 Mtetra
.649 .712 .894 r
.60331 .18743 .61009 .19727 .62347 .19353 .61671 .18301 Mtetra
.641 .695 .884 r
.61671 .18301 .62347 .19353 .63694 .19033 .63018 .1788 Mtetra
.64 .673 .865 r
.63018 .1788 .63694 .19033 .6505 .1872 .64372 .17452 Mtetra
.646 .654 .844 r
.64372 .17452 .6505 .1872 .66411 .18342 .65732 .16987 Mtetra
.654 .644 .827 r
.65732 .16987 .66411 .18342 .67773 .17843 .67096 .16467 Mtetra
.663 .645 .822 r
.67096 .16467 .67773 .17843 .69135 .17221 .68464 .15902 Mtetra
.669 .658 .831 r
.68464 .15902 .69135 .17221 .70499 .16533 .69837 .15317 Mtetra
.672 .679 .849 r
.69837 .15317 .70499 .16533 .71868 .15848 .71217 .14741 Mtetra
.671 .702 .87 r
.71217 .14741 .71868 .15848 .73246 .15211 .72604 .14187 Mtetra
.669 .721 .888 r
.72604 .14187 .73246 .15211 .74633 .14629 .74 .13652 Mtetra
.666 .732 .899 r
.74 .13652 .74633 .14629 .76029 .14085 .75403 .13129 Mtetra
.664 .738 .905 r
.75403 .13129 .76029 .14085 .77434 .13562 .76814 .12611 Mtetra
.663 .741 .908 r
.13033 .34788 .13846 .35544 .14969 .35137 .14159 .34378 Mtetra
.662 .741 .909 r
.14159 .34378 .14969 .35137 .16098 .34728 .1529 .33967 Mtetra
.1529 .33967 .16098 .34728 .17231 .3432 .16426 .33557 Mtetra
.661 .742 .91 r
.16426 .33557 .17231 .3432 .18369 .33912 .17567 .33147 Mtetra
.659 .742 .911 r
.17567 .33147 .18369 .33912 .19512 .33505 .18712 .32739 Mtetra
.658 .742 .912 r
.18712 .32739 .19512 .33505 .20659 .33102 .19862 .32335 Mtetra
.655 .742 .914 r
.19862 .32335 .20659 .33102 .21811 .32702 .21017 .31936 Mtetra
.651 .742 .916 r
.21017 .31936 .21811 .32702 .22968 .32309 .22176 .31546 Mtetra
.605 .73 .933 r
.22176 .31546 .22968 .32309 .24129 .31926 .23329 .31273 Mtetra
.693 .177 0 r
.23329 .31273 .24129 .31926 .25288 .31625 .24351 .32541 Mtetra
.898 .583 .442 r
.24351 .32541 .25288 .31625 .26363 .32403 .24882 .39741 Mtetra
.739 .452 .494 r
.24882 .39741 .26363 .32403 .27115 .37439 .25496 .46665 Mtetra
0 0 .198 r
.25496 .46665 .27115 .37439 .27909 .4252 .27297 .39224 Mtetra
.868 .637 .586 r
.27297 .39224 .27909 .4252 .29491 .37286 .29093 .31214 Mtetra
.651 .45 .599 r
.29093 .31214 .29491 .37286 .31097 .31257 .30414 .29181 Mtetra
.619 .531 .732 r
.30414 .29181 .31097 .31257 .32384 .29624 .31622 .28733 Mtetra
.629 .71 .905 r
.31622 .28733 .32384 .29624 .33592 .29212 .32829 .28392 Mtetra
.631 .731 .919 r
.32829 .28392 .33592 .29212 .34802 .28884 .34043 .28042 Mtetra
.637 .728 .914 r
.34043 .28042 .34802 .28884 .36018 .28543 .35264 .27672 Mtetra
.645 .724 .906 r
.35264 .27672 .36018 .28543 .37242 .2818 .36492 .27278 Mtetra
.653 .72 .897 r
.36492 .27278 .37242 .2818 .38474 .27789 .37728 .26856 Mtetra
.661 .715 .889 r
.37728 .26856 .38474 .27789 .39712 .27366 .38971 .26403 Mtetra
.668 .712 .881 r
.38971 .26403 .39712 .27366 .40958 .26909 .40221 .25919 Mtetra
.674 .709 .874 r
.40221 .25919 .40958 .26909 .42211 .26419 .41477 .25406 Mtetra
.679 .706 .868 r
.41477 .25406 .42211 .26419 .4347 .25898 .4274 .24869 Mtetra
.683 .705 .864 r
.4274 .24869 .4347 .25898 .44735 .2535 .44008 .24313 Mtetra
.685 .705 .862 r
.44008 .24313 .44735 .2535 .46005 .24782 .45282 .23744 Mtetra
.686 .706 .862 r
.45282 .23744 .46005 .24782 .47281 .24202 .46561 .23167 Mtetra
.687 .708 .864 r
.46561 .23167 .47281 .24202 .48562 .23615 .47845 .2259 Mtetra
.686 .711 .867 r
.47845 .2259 .48562 .23615 .49848 .23028 .49134 .22017 Mtetra
.684 .714 .871 r
.49134 .22017 .49848 .23028 .51139 .22447 .50429 .2145 Mtetra
.682 .717 .876 r
.50429 .2145 .51139 .22447 .52435 .21874 .51728 .20894 Mtetra
.68 .721 .881 r
.51728 .20894 .52435 .21874 .53736 .21313 .53033 .20348 Mtetra
.677 .725 .886 r
.53033 .20348 .53736 .21313 .55043 .20765 .54344 .19812 Mtetra
.674 .728 .89 r
.54344 .19812 .55043 .20765 .56355 .2023 .55661 .19288 Mtetra
.671 .73 .894 r
.55661 .19288 .56355 .2023 .57674 .19711 .56983 .18774 Mtetra
.667 .731 .898 r
.56983 .18774 .57674 .19711 .58999 .19213 .58313 .18272 Mtetra
.663 .73 .899 r
.58313 .18272 .58999 .19213 .60331 .18743 .59648 .17782 Mtetra
.658 .724 .898 r
.59648 .17782 .60331 .18743 .61671 .18301 .60991 .17305 Mtetra
.656 .715 .892 r
.60991 .17305 .61671 .18301 .63018 .1788 .6234 .16833 Mtetra
.656 .704 .883 r
.6234 .16833 .63018 .1788 .64372 .17452 .63696 .16354 Mtetra
.658 .695 .873 r
.63696 .16354 .64372 .17452 .65732 .16987 .65059 .15858 Mtetra
.662 .691 .867 r
.65059 .15858 .65732 .16987 .67096 .16467 .66427 .15341 Mtetra
.665 .694 .867 r
.66427 .15341 .67096 .16467 .68464 .15902 .678 .14809 Mtetra
.667 .703 .874 r
.678 .14809 .68464 .15902 .69837 .15317 .69181 .14273 Mtetra
.668 .715 .884 r
.69181 .14273 .69837 .15317 .71217 .14741 .70568 .1374 Mtetra
.666 .726 .894 r
.70568 .1374 .71217 .14741 .72604 .14187 .71962 .13214 Mtetra
.665 .734 .901 r
.71962 .13214 .72604 .14187 .74 .13652 .73363 .12693 Mtetra
.664 .738 .905 r
.73363 .12693 .74 .13652 .75403 .13129 .74772 .12174 Mtetra
.664 .74 .907 r
.74772 .12174 .75403 .13129 .76814 .12611 .76188 .11655 Mtetra
.663 .741 .909 r
.12213 .34026 .13033 .34788 .14159 .34378 .13342 .33613 Mtetra
.662 .741 .909 r
.13342 .33613 .14159 .34378 .1529 .33967 .14476 .332 Mtetra
.661 .742 .91 r
.14476 .332 .1529 .33967 .16426 .33557 .15614 .32788 Mtetra
.66 .742 .91 r
.15614 .32788 .16426 .33557 .17567 .33147 .16758 .32376 Mtetra
.659 .742 .911 r
.16758 .32376 .17567 .33147 .18712 .32739 .17906 .31968 Mtetra
.657 .742 .913 r
.17906 .31968 .18712 .32739 .19862 .32335 .19058 .31563 Mtetra
.653 .742 .915 r
.19058 .31563 .19862 .32335 .21017 .31936 .20215 .31168 Mtetra
.593 .725 .936 r
.20215 .31168 .21017 .31936 .22176 .31546 .21363 .30921 Mtetra
.825 .351 0 r
.21363 .30921 .22176 .31546 .23329 .31273 .22329 .32634 Mtetra
.896 .592 .463 r
.22329 .32634 .23329 .31273 .24351 .32541 .2264 .41682 Mtetra
.735 .453 .502 r
.2264 .41682 .24351 .32541 .24882 .39741 .23094 .49945 Mtetra
0 0 .121 r
.23094 .49945 .24882 .39741 .25496 .46665 .25118 .40527 Mtetra
.824 .584 .576 r
.25118 .40527 .25496 .46665 .27297 .39224 .27088 .3103 Mtetra
.634 .423 .58 r
.27088 .3103 .27297 .39224 .29093 .31214 .28438 .28732 Mtetra
.611 .5 .702 r
.28438 .28732 .29093 .31214 .30414 .29181 .29646 .28257 Mtetra
.632 .704 .898 r
.29646 .28257 .30414 .29181 .31622 .28733 .3085 .27904 Mtetra
.634 .73 .917 r
.3085 .27904 .31622 .28733 .32829 .28392 .32061 .27544 Mtetra
.639 .727 .912 r
.32061 .27544 .32829 .28392 .34043 .28042 .33279 .27167 Mtetra
.645 .724 .905 r
.33279 .27167 .34043 .28042 .35264 .27672 .34505 .26769 Mtetra
.653 .72 .898 r
.34505 .26769 .35264 .27672 .36492 .27278 .35738 .26346 Mtetra
.66 .716 .89 r
.35738 .26346 .36492 .27278 .37728 .26856 .36978 .25895 Mtetra
.666 .713 .883 r
.36978 .25895 .37728 .26856 .38971 .26403 .38225 .25417 Mtetra
.672 .71 .876 r
.38225 .25417 .38971 .26403 .40221 .25919 .39479 .24912 Mtetra
.677 .708 .871 r
.39479 .24912 .40221 .25919 .41477 .25406 .40739 .24385 Mtetra
.68 .706 .867 r
.40739 .24385 .41477 .25406 .4274 .24869 .42005 .2384 Mtetra
.683 .706 .866 r
.42005 .2384 .4274 .24869 .44008 .24313 .43276 .23281 Mtetra
.684 .707 .865 r
.43276 .23281 .44008 .24313 .45282 .23744 .44553 .22715 Mtetra
.684 .709 .867 r
.44553 .22715 .45282 .23744 .46561 .23167 .45835 .22147 Mtetra
.684 .712 .87 r
.45835 .22147 .46561 .23167 .47845 .2259 .47122 .21582 Mtetra
.682 .715 .873 r
.47122 .21582 .47845 .2259 .49134 .22017 .48415 .21023 Mtetra
.681 .718 .878 r
.48415 .21023 .49134 .22017 .50429 .2145 .49712 .20471 Mtetra
.678 .722 .882 r
.49712 .20471 .50429 .2145 .51728 .20894 .51016 .19928 Mtetra
.676 .725 .887 r
.51016 .19928 .51728 .20894 .53033 .20348 .52325 .19395 Mtetra
.674 .729 .891 r
.52325 .19395 .53033 .20348 .54344 .19812 .53639 .1887 Mtetra
.671 .731 .895 r
.53639 .1887 .54344 .19812 .55661 .19288 .5496 .18353 Mtetra
.669 .733 .898 r
.5496 .18353 .55661 .19288 .56983 .18774 .56287 .17842 Mtetra
.667 .735 .901 r
.56287 .17842 .56983 .18774 .58313 .18272 .57621 .17338 Mtetra
.665 .734 .902 r
.57621 .17338 .58313 .18272 .59648 .17782 .5896 .16839 Mtetra
.663 .732 .901 r
.5896 .16839 .59648 .17782 .60991 .17305 .60307 .16345 Mtetra
.661 .729 .899 r
.60307 .16345 .60991 .17305 .6234 .16833 .6166 .1585 Mtetra
.662 .724 .896 r
.6166 .1585 .6234 .16833 .63696 .16354 .63019 .15352 Mtetra
.663 .721 .892 r
.63019 .15352 .63696 .16354 .65059 .15858 .64386 .14847 Mtetra
.664 .72 .891 r
.64386 .14847 .65059 .15858 .66427 .15341 .65758 .14334 Mtetra
.665 .723 .892 r
.65758 .14334 .66427 .15341 .678 .14809 .67137 .13815 Mtetra
.665 .727 .896 r
.67137 .13815 .678 .14809 .69181 .14273 .68523 .13295 Mtetra
.665 .732 .9 r
.68523 .13295 .69181 .14273 .70568 .1374 .69915 .12775 Mtetra
.664 .737 .904 r
.69915 .12775 .70568 .1374 .71962 .13214 .71315 .12255 Mtetra
.664 .739 .906 r
.71315 .12255 .71962 .13214 .73363 .12693 .72722 .11735 Mtetra
.664 .74 .907 r
.72722 .11735 .73363 .12693 .74772 .12174 .74135 .11214 Mtetra
.664 .741 .908 r
.74135 .11214 .74772 .12174 .76188 .11655 .75556 .1069 Mtetra
.662 .741 .909 r
.11386 .33259 .12213 .34026 .13342 .33613 .12518 .32843 Mtetra
.12518 .32843 .13342 .33613 .14476 .332 .13655 .32428 Mtetra
.661 .742 .91 r
.13655 .32428 .14476 .332 .15614 .32788 .14796 .32013 Mtetra
.659 .742 .911 r
.14796 .32013 .15614 .32788 .16758 .32376 .15942 .316 Mtetra
.658 .742 .912 r
.15942 .316 .16758 .32376 .17906 .31968 .17092 .31191 Mtetra
.654 .741 .914 r
.17092 .31191 .17906 .31968 .19058 .31563 .18247 .3079 Mtetra
.585 .722 .938 r
.18247 .3079 .19058 .31563 .20215 .31168 .19389 .3056 Mtetra
.865 .416 .074 r
.19389 .3056 .20215 .31168 .21363 .30921 .20311 .32546 Mtetra
.894 .594 .473 r
.20311 .32546 .21363 .30921 .22329 .32634 .20465 .42548 Mtetra
.73 .45 .503 r
.20465 .42548 .22329 .32634 .2264 .41682 .20834 .51153 Mtetra
0 0 0 r
.20834 .51153 .2264 .41682 .23094 .49945 .2302 .40629 Mtetra
.783 .541 .57 r
.2302 .40629 .23094 .49945 .25118 .40527 .25092 .30623 Mtetra
.619 .404 .569 r
.25092 .30623 .25118 .40527 .27088 .3103 .26456 .28274 Mtetra
.605 .482 .686 r
.26456 .28274 .27088 .3103 .28438 .28732 .27662 .27787 Mtetra
.635 .7 .893 r
.27662 .27787 .28438 .28732 .29646 .28257 .28864 .27422 Mtetra
.637 .73 .916 r
.28864 .27422 .29646 .28257 .3085 .27904 .30073 .27051 Mtetra
.641 .728 .911 r
.30073 .27051 .3085 .27904 .32061 .27544 .31288 .26666 Mtetra
.646 .724 .905 r
.31288 .26666 .32061 .27544 .33279 .27167 .32511 .26263 Mtetra
.653 .721 .898 r
.32511 .26263 .33279 .27167 .34505 .26769 .33741 .25838 Mtetra
.659 .717 .892 r
.33741 .25838 .34505 .26769 .35738 .26346 .34978 .25389 Mtetra
.665 .714 .885 r
.34978 .25389 .35738 .26346 .36978 .25895 .36222 .24915 Mtetra
.67 .711 .879 r
.36222 .24915 .36978 .25895 .38225 .25417 .37473 .24418 Mtetra
.674 .709 .874 r
.37473 .24418 .38225 .25417 .39479 .24912 .3873 .239 Mtetra
.678 .708 .871 r
.3873 .239 .39479 .24912 .40739 .24385 .39994 .23364 Mtetra
.68 .708 .869 r
.39994 .23364 .40739 .24385 .42005 .2384 .41263 .22816 Mtetra
.682 .709 .869 r
.41263 .22816 .42005 .2384 .43276 .23281 .42538 .2226 Mtetra
.682 .711 .87 r
.42538 .2226 .43276 .23281 .44553 .22715 .43818 .21702 Mtetra
.682 .713 .872 r
.43818 .21702 .44553 .22715 .45835 .22147 .45103 .21144 Mtetra
.681 .716 .876 r
.45103 .21144 .45835 .22147 .47122 .21582 .46393 .20591 Mtetra
.679 .719 .88 r
.46393 .20591 .47122 .21582 .48415 .21023 .47689 .20045 Mtetra
.677 .723 .884 r
.47689 .20045 .48415 .21023 .49712 .20471 .4899 .19506 Mtetra
.675 .726 .888 r
.4899 .19506 .49712 .20471 .51016 .19928 .50297 .18975 Mtetra
.673 .729 .892 r
.50297 .18975 .51016 .19928 .52325 .19395 .5161 .18451 Mtetra
.671 .732 .896 r
.5161 .18451 .52325 .19395 .53639 .1887 .52929 .17934 Mtetra
.669 .734 .899 r
.52929 .17934 .53639 .1887 .5496 .18353 .54254 .17421 Mtetra
.667 .736 .901 r
.54254 .17421 .5496 .18353 .56287 .17842 .55585 .16913 Mtetra
.666 .737 .903 r
.55585 .16913 .56287 .17842 .57621 .17338 .56923 .16408 Mtetra
.665 .737 .904 r
.56923 .16408 .57621 .17338 .5896 .16839 .58267 .15904 Mtetra
.664 .737 .904 r
.58267 .15904 .5896 .16839 .60307 .16345 .59617 .15402 Mtetra
.663 .736 .904 r
.59617 .15402 .60307 .16345 .6166 .1585 .60975 .14898 Mtetra
.663 .735 .903 r
.60975 .14898 .6166 .1585 .63019 .15352 .62338 .14392 Mtetra
.664 .734 .902 r
.62338 .14392 .63019 .15352 .64386 .14847 .63709 .13882 Mtetra
.63709 .13882 .64386 .14847 .65758 .14334 .65086 .13369 Mtetra
.664 .735 .903 r
.65086 .13369 .65758 .14334 .67137 .13815 .6647 .12853 Mtetra
.664 .737 .904 r
.6647 .12853 .67137 .13815 .68523 .13295 .6786 .12335 Mtetra
.664 .739 .906 r
.6786 .12335 .68523 .13295 .69915 .12775 .69258 .11816 Mtetra
.664 .74 .907 r
.69258 .11816 .69915 .12775 .71315 .12255 .70663 .11294 Mtetra
.664 .741 .907 r
.70663 .11294 .71315 .12255 .72722 .11735 .72074 .10771 Mtetra
.664 .741 .908 r
.72074 .10771 .72722 .11735 .74135 .11214 .73493 .10245 Mtetra
.73493 .10245 .74135 .11214 .75556 .1069 .74918 .09717 Mtetra
.662 .741 .909 r
.10553 .32485 .11386 .33259 .12518 .32843 .11687 .32067 Mtetra
.661 .741 .909 r
.11687 .32067 .12518 .32843 .13655 .32428 .12826 .31649 Mtetra
.66 .742 .91 r
.12826 .31649 .13655 .32428 .14796 .32013 .1397 .31232 Mtetra
.659 .742 .911 r
.1397 .31232 .14796 .32013 .15942 .316 .15119 .30818 Mtetra
.656 .741 .913 r
.15119 .30818 .15942 .316 .17092 .31191 .16272 .30412 Mtetra
.584 .721 .938 r
.16272 .30412 .17092 .31191 .18247 .3079 .1741 .30181 Mtetra
.868 .422 .086 r
.1741 .30181 .18247 .3079 .19389 .3056 .18313 .32176 Mtetra
.892 .593 .473 r
.18313 .32176 .19389 .3056 .20311 .32546 .18426 .41901 Mtetra
.725 .443 .5 r
.18426 .41901 .20311 .32546 .20465 .42548 .18815 .49692 Mtetra
.799 .755 .237 r
.18815 .49692 .20465 .42548 .20834 .51153 .21043 .39343 Mtetra
.747 .505 .566 r
.21043 .39343 .20834 .51153 .2302 .40629 .23111 .2998 Mtetra
.606 .391 .563 r
.23111 .2998 .2302 .40629 .25092 .30623 .24468 .27807 Mtetra
.602 .478 .683 r
.24468 .27807 .25092 .30623 .26456 .28274 .25672 .27322 Mtetra
.638 .701 .891 r
.25672 .27322 .26456 .28274 .27662 .27787 .26871 .26945 Mtetra
.64 .731 .914 r
.26871 .26945 .27662 .27787 .28864 .27422 .28077 .26564 Mtetra
.643 .728 .91 r
.28077 .26564 .28864 .27422 .30073 .27051 .2929 .26171 Mtetra
.648 .725 .905 r
.2929 .26171 .30073 .27051 .31288 .26666 .3051 .25763 Mtetra
.653 .722 .899 r
.3051 .25763 .31288 .26666 .32511 .26263 .31737 .25336 Mtetra
.658 .718 .893 r
.31737 .25336 .32511 .26263 .33741 .25838 .32971 .24887 Mtetra
.663 .715 .887 r
.32971 .24887 .33741 .25838 .34978 .25389 .34213 .24417 Mtetra
.668 .713 .882 r
.34213 .24417 .34978 .25389 .36222 .24915 .35461 .23925 Mtetra
.672 .711 .877 r
.35461 .23925 .36222 .24915 .37473 .24418 .36715 .23415 Mtetra
.676 .71 .874 r
.36715 .23415 .37473 .24418 .3873 .239 .37976 .22888 Mtetra
.678 .71 .873 r
.37976 .22888 .3873 .239 .39994 .23364 .39243 .22349 Mtetra
.679 .711 .872 r
.39243 .22349 .39994 .23364 .41263 .22816 .40515 .21803 Mtetra
.68 .713 .873 r
.40515 .21803 .41263 .22816 .42538 .2226 .41793 .21254 Mtetra
.68 .715 .875 r
.41793 .21254 .42538 .2226 .43818 .21702 .43076 .20704 Mtetra
.679 .718 .878 r
.43076 .20704 .43818 .21702 .45103 .21144 .44364 .20158 Mtetra
.677 .721 .882 r
.44364 .20158 .45103 .21144 .46393 .20591 .45658 .19617 Mtetra
.676 .724 .886 r
.45658 .19617 .46393 .20591 .47689 .20045 .46957 .19082 Mtetra
.674 .727 .89 r
.46957 .19082 .47689 .20045 .4899 .19506 .48262 .18553 Mtetra
.672 .73 .893 r
.48262 .18553 .4899 .19506 .50297 .18975 .49573 .18031 Mtetra
.67 .732 .896 r
.49573 .18031 .50297 .18975 .5161 .18451 .50889 .17514 Mtetra
.669 .735 .899 r
.50889 .17514 .5161 .18451 .52929 .17934 .52212 .17001 Mtetra
.667 .736 .902 r
.52212 .17001 .52929 .17934 .54254 .17421 .53541 .16491 Mtetra
.666 .738 .903 r
.53541 .16491 .54254 .17421 .55585 .16913 .54877 .15983 Mtetra
.665 .739 .905 r
.54877 .15983 .55585 .16913 .56923 .16408 .56219 .15476 Mtetra
.665 .739 .906 r
.56219 .15476 .56923 .16408 .58267 .15904 .57567 .1497 Mtetra
.664 .739 .906 r
.57567 .1497 .58267 .15904 .59617 .15402 .58922 .14463 Mtetra
.58922 .14463 .59617 .15402 .60975 .14898 .60284 .13954 Mtetra
.60284 .13954 .60975 .14898 .62338 .14392 .61652 .13443 Mtetra
.61652 .13443 .62338 .14392 .63709 .13882 .63027 .12929 Mtetra
.63027 .12929 .63709 .13882 .65086 .13369 .64409 .12414 Mtetra
.664 .74 .906 r
.64409 .12414 .65086 .13369 .6647 .12853 .65797 .11895 Mtetra
.664 .74 .907 r
.65797 .11895 .6647 .12853 .6786 .12335 .67193 .11375 Mtetra
.664 .741 .907 r
.67193 .11375 .6786 .12335 .69258 .11816 .68595 .10852 Mtetra
.664 .741 .908 r
.68595 .10852 .69258 .11816 .70663 .11294 .70004 .10326 Mtetra
.70004 .10326 .70663 .11294 .72074 .10771 .71421 .09798 Mtetra
.71421 .09798 .72074 .10771 .73493 .10245 .72844 .09268 Mtetra
.72844 .09268 .73493 .10245 .74918 .09717 .74275 .08735 Mtetra
.662 .741 .909 r
.09713 .31705 .10553 .32485 .11687 .32067 .1085 .31284 Mtetra
.661 .741 .91 r
.1085 .31284 .11687 .32067 .12826 .31649 .11991 .30864 Mtetra
.66 .742 .91 r
.11991 .30864 .12826 .31649 .1397 .31232 .13138 .30446 Mtetra
.657 .741 .912 r
.13138 .30446 .1397 .31232 .15119 .30818 .14289 .30034 Mtetra
.592 .724 .935 r
.14289 .30034 .15119 .30818 .16272 .30412 .15426 .29783 Mtetra
.839 .372 .015 r
.15426 .29783 .16272 .30412 .1741 .30181 .1634 .31517 Mtetra
.89 .586 .466 r
.1634 .31517 .1741 .30181 .18313 .32176 .16542 .39825 Mtetra
.719 .433 .49 r
.16542 .39825 .18313 .32176 .18426 .41901 .17047 .4595 Mtetra
.976 .848 .451 r
.17047 .4595 .18426 .41901 .18815 .49692 .19183 .36968 Mtetra
.715 .477 .564 r
.19183 .36968 .18815 .49692 .21043 .39343 .21142 .29168 Mtetra
.597 .385 .564 r
.21142 .29168 .21043 .39343 .23111 .2998 .22474 .27336 Mtetra
.604 .487 .693 r
.22474 .27336 .23111 .2998 .24468 .27807 .23674 .26864 Mtetra
.641 .705 .893 r
.23674 .26864 .24468 .27807 .25672 .27322 .24871 .26477 Mtetra
.643 .731 .913 r
.24871 .26477 .25672 .27322 .26871 .26945 .26075 .26085 Mtetra
.645 .729 .91 r
.26075 .26085 .26871 .26945 .28077 .26564 .27285 .25684 Mtetra
.649 .726 .905 r
.27285 .25684 .28077 .26564 .2929 .26171 .28502 .2527 Mtetra
.653 .723 .9 r
.28502 .2527 .2929 .26171 .3051 .25763 .29726 .24839 Mtetra
.658 .72 .895 r
.29726 .24839 .3051 .25763 .31737 .25336 .30958 .24391 Mtetra
.662 .717 .889 r
.30958 .24391 .31737 .25336 .32971 .24887 .32196 .23923 Mtetra
.667 .715 .885 r
.32196 .23923 .32971 .24887 .34213 .24417 .33441 .23436 Mtetra
.67 .714 .881 r
.33441 .23436 .34213 .24417 .35461 .23925 .34693 .22932 Mtetra
.673 .713 .878 r
.34693 .22932 .35461 .23925 .36715 .23415 .35951 .22413 Mtetra
.676 .713 .876 r
.35951 .22413 .36715 .23415 .37976 .22888 .37215 .21883 Mtetra
.677 .713 .876 r
.37215 .21883 .37976 .22888 .39243 .22349 .38485 .21346 Mtetra
.678 .715 .877 r
.38485 .21346 .39243 .22349 .40515 .21803 .3976 .20804 Mtetra
.678 .717 .878 r
.3976 .20804 .40515 .21803 .41793 .21254 .41041 .20262 Mtetra
.677 .719 .881 r
.41041 .20262 .41793 .21254 .43076 .20704 .42327 .19722 Mtetra
.676 .722 .884 r
.42327 .19722 .43076 .20704 .44364 .20158 .43619 .19186 Mtetra
.674 .725 .888 r
.43619 .19186 .44364 .20158 .45658 .19617 .44916 .18655 Mtetra
.673 .728 .891 r
.44916 .18655 .45658 .19617 .46957 .19082 .46219 .18129 Mtetra
.671 .73 .894 r
.46219 .18129 .46957 .19082 .48262 .18553 .47527 .17608 Mtetra
.67 .733 .897 r
.47527 .17608 .48262 .18553 .49573 .18031 .48842 .17091 Mtetra
.668 .735 .9 r
.48842 .17091 .49573 .18031 .50889 .17514 .50162 .16578 Mtetra
.667 .737 .902 r
.50162 .16578 .50889 .17514 .52212 .17001 .51489 .16068 Mtetra
.666 .738 .904 r
.51489 .16068 .52212 .17001 .53541 .16491 .52823 .15559 Mtetra
.665 .739 .905 r
.52823 .15559 .53541 .16491 .54877 .15983 .54162 .1505 Mtetra
.665 .74 .906 r
.54162 .1505 .54877 .15983 .56219 .15476 .55508 .14541 Mtetra
.664 .74 .906 r
.55508 .14541 .56219 .15476 .57567 .1497 .56861 .14031 Mtetra
.664 .74 .907 r
.56861 .14031 .57567 .1497 .58922 .14463 .5822 .1352 Mtetra
.5822 .1352 .58922 .14463 .60284 .13954 .59587 .13007 Mtetra
.59587 .13007 .60284 .13954 .61652 .13443 .60959 .12492 Mtetra
.664 .741 .907 r
.60959 .12492 .61652 .13443 .63027 .12929 .62339 .11975 Mtetra
.62339 .11975 .63027 .12929 .64409 .12414 .63725 .11455 Mtetra
.664 .741 .908 r
.63725 .11455 .64409 .12414 .65797 .11895 .65119 .10932 Mtetra
.65119 .10932 .65797 .11895 .67193 .11375 .66519 .10407 Mtetra
.66519 .10407 .67193 .11375 .68595 .10852 .67926 .0988 Mtetra
.67926 .0988 .68595 .10852 .70004 .10326 .6934 .0935 Mtetra
.6934 .0935 .70004 .10326 .71421 .09798 .70762 .08817 Mtetra
.70762 .08817 .71421 .09798 .72844 .09268 .7219 .08282 Mtetra
.7219 .08282 .72844 .09268 .74275 .08735 .73626 .07744 Mtetra
.661 .741 .909 r
.08865 .30919 .09713 .31705 .1085 .31284 .10005 .30495 Mtetra
.66 .741 .91 r
.10005 .30495 .1085 .31284 .11991 .30864 .11149 .30073 Mtetra
.658 .741 .911 r
.11149 .30073 .11991 .30864 .13138 .30446 .12298 .29656 Mtetra
.607 .728 .931 r
.12298 .29656 .13138 .30446 .14289 .30034 .13436 .2937 Mtetra
.735 .224 0 r
.13436 .2937 .14289 .30034 .15426 .29783 .14388 .30656 Mtetra
.888 .572 .444 r
.14388 .30656 .15426 .29783 .1634 .31517 .14773 .36886 Mtetra
.713 .414 .47 r
.14773 .36886 .1634 .31517 .16542 .39825 .15448 .41055 Mtetra
.989 .815 .578 r
.15448 .41055 .16542 .39825 .17047 .4595 .17393 .3412 Mtetra
.689 .456 .565 r
.17393 .3412 .17047 .4595 .19183 .36968 .19177 .28299 Mtetra
.591 .385 .57 r
.19177 .28299 .19183 .36968 .21142 .29168 .20472 .26869 Mtetra
.611 .511 .716 r
.20472 .26869 .21142 .29168 .22474 .27336 .21668 .26413 Mtetra
.644 .712 .897 r
.21668 .26413 .22474 .27336 .23674 .26864 .22863 .26015 Mtetra
.646 .732 .912 r
.22863 .26015 .23674 .26864 .24871 .26477 .24064 .25614 Mtetra
.648 .73 .909 r
.24064 .25614 .24871 .26477 .26075 .26085 .25272 .25205 Mtetra
.65 .727 .905 r
.25272 .25205 .26075 .26085 .27285 .25684 .26487 .24784 Mtetra
.654 .725 .901 r
.26487 .24784 .27285 .25684 .28502 .2527 .27709 .2435 Mtetra
.658 .722 .896 r
.27709 .2435 .28502 .2527 .29726 .24839 .28937 .239 Mtetra
.662 .72 .892 r
.28937 .239 .29726 .24839 .30958 .24391 .30173 .23434 Mtetra
.666 .717 .887 r
.30173 .23434 .30958 .24391 .32196 .23923 .31415 .22951 Mtetra
.669 .716 .884 r
.31415 .22951 .32196 .23923 .33441 .23436 .32664 .22452 Mtetra
.672 .715 .881 r
.32664 .22452 .33441 .23436 .34693 .22932 .33919 .21941 Mtetra
.674 .715 .88 r
.33919 .21941 .34693 .22932 .35951 .22413 .3518 .21418 Mtetra
.675 .716 .879 r
.3518 .21418 .35951 .22413 .37215 .21883 .36447 .20889 Mtetra
.676 .717 .88 r
.36447 .20889 .37215 .21883 .38485 .21346 .3772 .20355 Mtetra
.676 .719 .881 r
.3772 .20355 .38485 .21346 .3976 .20804 .38998 .1982 Mtetra
.675 .721 .884 r
.38998 .1982 .3976 .20804 .41041 .20262 .40282 .19286 Mtetra
.674 .724 .886 r
.40282 .19286 .41041 .20262 .42327 .19722 .41571 .18754 Mtetra
.673 .726 .889 r
.41571 .18754 .42327 .19722 .43619 .19186 .42866 .18227 Mtetra
.672 .729 .893 r
.42866 .18227 .43619 .19186 .44916 .18655 .44167 .17703 Mtetra
.67 .731 .896 r
.44167 .17703 .44916 .18655 .46219 .18129 .45473 .17183 Mtetra
.669 .733 .898 r
.45473 .17183 .46219 .18129 .47527 .17608 .46786 .16667 Mtetra
.668 .735 .901 r
.46786 .16667 .47527 .17608 .48842 .17091 .48104 .16154 Mtetra
.667 .737 .902 r
.48104 .16154 .48842 .17091 .50162 .16578 .49429 .15643 Mtetra
.666 .738 .904 r
.49429 .15643 .50162 .16578 .51489 .16068 .5076 .15132 Mtetra
.665 .739 .905 r
.5076 .15132 .51489 .16068 .52823 .15559 .52097 .14622 Mtetra
.665 .74 .906 r
.52097 .14622 .52823 .15559 .54162 .1505 .53441 .14112 Mtetra
.664 .74 .907 r
.53441 .14112 .54162 .1505 .55508 .14541 .54792 .136 Mtetra
.664 .741 .907 r
.54792 .136 .55508 .14541 .56861 .14031 .56149 .13087 Mtetra
.56149 .13087 .56861 .14031 .5822 .1352 .57513 .12571 Mtetra
.664 .741 .908 r
.57513 .12571 .5822 .1352 .59587 .13007 .58883 .12054 Mtetra
.58883 .12054 .59587 .13007 .60959 .12492 .60261 .11535 Mtetra
.60261 .11535 .60959 .12492 .62339 .11975 .61645 .11013 Mtetra
.61645 .11013 .62339 .11975 .63725 .11455 .63036 .10488 Mtetra
.63036 .10488 .63725 .11455 .65119 .10932 .64434 .09961 Mtetra
.64434 .09961 .65119 .10932 .66519 .10407 .65839 .09432 Mtetra
.65839 .09432 .66519 .10407 .67926 .0988 .67251 .08899 Mtetra
.67251 .08899 .67926 .0988 .6934 .0935 .6867 .08364 Mtetra
.6867 .08364 .6934 .0935 .70762 .08817 .70096 .07827 Mtetra
.70096 .07827 .70762 .08817 .7219 .08282 .71529 .07286 Mtetra
.71529 .07286 .7219 .08282 .73626 .07744 .7297 .06743 Mtetra
.661 .741 .91 r
.08011 .30126 .08865 .30919 .10005 .30495 .09153 .297 Mtetra
.659 .741 .91 r
.09153 .297 .10005 .30495 .11149 .30073 .103 .29278 Mtetra
.623 .732 .925 r
.103 .29278 .11149 .30073 .12298 .29656 .11439 .28951 Mtetra
0 .114 .582 r
.11439 .28951 .12298 .29656 .13436 .2937 .12443 .29729 Mtetra
.885 .542 .393 r
.12443 .29729 .13436 .2937 .14388 .30656 .13048 .33806 Mtetra
.701 .376 .424 r
.13048 .33806 .14388 .30656 .14773 .36886 .13891 .36231 Mtetra
.925 .742 .636 r
.13891 .36231 .14773 .36886 .15448 .41055 .15612 .3141 Mtetra
.668 .444 .571 r
.15612 .3141 .15448 .41055 .17393 .3412 .17206 .27475 Mtetra
.59 .396 .586 r
.17206 .27475 .17393 .3412 .19177 .28299 .18463 .26413 Mtetra
.621 .55 .753 r
.18463 .26413 .19177 .28299 .20472 .26869 .19654 .25969 Mtetra
.647 .719 .901 r
.19654 .25969 .20472 .26869 .21668 .26413 .20847 .25562 Mtetra
.648 .733 .911 r
.20847 .25562 .21668 .26413 .22863 .26015 .22047 .25151 Mtetra
.65 .731 .909 r
.22047 .25151 .22863 .26015 .24064 .25614 .23252 .24734 Mtetra
.652 .729 .905 r
.23252 .24734 .24064 .25614 .25272 .25205 .24464 .24308 Mtetra
.655 .726 .902 r
.24464 .24308 .25272 .25205 .26487 .24784 .25683 .23869 Mtetra
.658 .724 .898 r
.25683 .23869 .26487 .24784 .27709 .2435 .26909 .23418 Mtetra
.661 .722 .894 r
.26909 .23418 .27709 .2435 .28937 .239 .28142 .22952 Mtetra
.665 .72 .89 r
.28142 .22952 .28937 .239 .30173 .23434 .29381 .22472 Mtetra
.668 .719 .887 r
.29381 .22472 .30173 .23434 .31415 .22951 .30627 .21977 Mtetra
.67 .718 .885 r
.30627 .21977 .31415 .22951 .32664 .22452 .31879 .21472 Mtetra
.672 .718 .883 r
.31879 .21472 .32664 .22452 .33919 .21941 .33138 .20956 Mtetra
.673 .718 .883 r
.33138 .20956 .33919 .21941 .3518 .21418 .34402 .20433 Mtetra
.674 .719 .883 r
.34402 .20433 .3518 .21418 .36447 .20889 .35672 .19906 Mtetra
.674 .721 .884 r
.35672 .19906 .36447 .20889 .3772 .20355 .36948 .19377 Mtetra
.674 .723 .886 r
.36948 .19377 .3772 .20355 .38998 .1982 .38229 .18848 Mtetra
.673 .725 .889 r
.38229 .18848 .38998 .1982 .40282 .19286 .39516 .18321 Mtetra
.672 .728 .891 r
.39516 .18321 .40282 .19286 .41571 .18754 .40809 .17797 Mtetra
.671 .73 .894 r
.40809 .17797 .41571 .18754 .42866 .18227 .42107 .17275 Mtetra
.67 .732 .897 r
.42107 .17275 .42866 .18227 .44167 .17703 .43411 .16757 Mtetra
.668 .734 .899 r
.43411 .16757 .44167 .17703 .45473 .17183 .44721 .16242 Mtetra
.667 .736 .901 r
.44721 .16242 .45473 .17183 .46786 .16667 .46038 .15728 Mtetra
.666 .737 .903 r
.46038 .15728 .46786 .16667 .48104 .16154 .4736 .15216 Mtetra
.666 .738 .904 r
.4736 .15216 .48104 .16154 .49429 .15643 .48689 .14704 Mtetra
.665 .739 .905 r
.48689 .14704 .49429 .15643 .5076 .15132 .50024 .14193 Mtetra
.665 .74 .906 r
.50024 .14193 .5076 .15132 .52097 .14622 .51366 .1368 Mtetra
.664 .74 .907 r
.51366 .1368 .52097 .14622 .53441 .14112 .52714 .13167 Mtetra
.664 .741 .907 r
.52714 .13167 .53441 .14112 .54792 .136 .54069 .12652 Mtetra
.54069 .12652 .54792 .136 .56149 .13087 .5543 .12134 Mtetra
.664 .741 .908 r
.5543 .12134 .56149 .13087 .57513 .12571 .56798 .11615 Mtetra
.56798 .11615 .57513 .12571 .58883 .12054 .58173 .11093 Mtetra
.58173 .11093 .58883 .12054 .60261 .11535 .59555 .10569 Mtetra
.59555 .10569 .60261 .11535 .61645 .11013 .60944 .10042 Mtetra
.60944 .10042 .61645 .11013 .63036 .10488 .6234 .09513 Mtetra
.6234 .09513 .63036 .10488 .64434 .09961 .63742 .08981 Mtetra
.63742 .08981 .64434 .09961 .65839 .09432 .65152 .08447 Mtetra
.65152 .08447 .65839 .09432 .67251 .08899 .66569 .0791 Mtetra
.66569 .0791 .67251 .08899 .6867 .08364 .67993 .0737 Mtetra
.67993 .0737 .6867 .08364 .70096 .07827 .69424 .06827 Mtetra
.69424 .06827 .70096 .07827 .71529 .07286 .70863 .06282 Mtetra
.70863 .06282 .71529 .07286 .7297 .06743 .72309 .05734 Mtetra
.66 .741 .91 r
.07149 .29327 .08011 .30126 .09153 .297 .08294 .289 Mtetra
.638 .736 .919 r
.08294 .289 .09153 .297 .103 .29278 .09435 .28534 Mtetra
.119 .508 .909 r
.09435 .28534 .103 .29278 .11439 .28951 .10489 .2886 Mtetra
.866 .46 .259 r
.10489 .2886 .11439 .28951 .12443 .29729 .11296 .31142 Mtetra
.666 .276 .297 r
.11296 .31142 .12443 .29729 .13048 .33806 .12273 .32285 Mtetra
.853 .682 .67 r
.12273 .32285 .13048 .33806 .13891 .36231 .1379 .29213 Mtetra
.653 .443 .586 r
.1379 .29213 .13891 .36231 .15612 .3141 .1522 .26754 Mtetra
.595 .422 .617 r
.1522 .26754 .15612 .3141 .17206 .27475 .16445 .25968 Mtetra
.634 .6 .798 r
.16445 .25968 .17206 .27475 .18463 .26413 .17633 .25533 Mtetra
.65 .726 .905 r
.17633 .25533 .18463 .26413 .19654 .25969 .18824 .25116 Mtetra
.651 .734 .91 r
.18824 .25116 .19654 .25969 .20847 .25562 .20021 .24697 Mtetra
.652 .732 .908 r
.20021 .24697 .20847 .25562 .22047 .25151 .21224 .24272 Mtetra
.653 .73 .906 r
.21224 .24272 .22047 .25151 .23252 .24734 .22434 .23839 Mtetra
.656 .728 .903 r
.22434 .23839 .23252 .24734 .24464 .24308 .2365 .23397 Mtetra
.658 .726 .899 r
.2365 .23397 .24464 .24308 .25683 .23869 .24873 .22943 Mtetra
.661 .724 .896 r
.24873 .22943 .25683 .23869 .26909 .23418 .26103 .22477 Mtetra
.664 .722 .893 r
.26103 .22477 .26909 .23418 .28142 .22952 .27339 .21998 Mtetra
.666 .721 .89 r
.27339 .21998 .28142 .22952 .29381 .22472 .28582 .21508 Mtetra
.669 .72 .888 r
.28582 .21508 .29381 .22472 .30627 .21977 .29832 .21006 Mtetra
.67 .72 .886 r
.29832 .21006 .30627 .21977 .31879 .21472 .31087 .20496 Mtetra
.672 .721 .886 r
.31087 .20496 .31879 .21472 .33138 .20956 .32349 .1998 Mtetra
.672 .722 .886 r
.32349 .1998 .33138 .20956 .34402 .20433 .33616 .19458 Mtetra
.672 .723 .887 r
.33616 .19458 .34402 .20433 .35672 .19906 .3489 .18935 Mtetra
.672 .725 .889 r
.3489 .18935 .35672 .19906 .36948 .19377 .36168 .18411 Mtetra
.672 .727 .891 r
.36168 .18411 .36948 .19377 .38229 .18848 .37453 .17887 Mtetra
.671 .729 .893 r
.37453 .17887 .38229 .18848 .39516 .18321 .38743 .17366 Mtetra
.67 .731 .896 r
.38743 .17366 .39516 .18321 .40809 .17797 .40039 .16847 Mtetra
.669 .733 .898 r
.40039 .16847 .40809 .17797 .42107 .17275 .41341 .16329 Mtetra
.668 .735 .9 r
.41341 .16329 .42107 .17275 .43411 .16757 .42649 .15814 Mtetra
.667 .736 .902 r
.42649 .15814 .43411 .16757 .44721 .16242 .43963 .153 Mtetra
.666 .738 .903 r
.43963 .153 .44721 .16242 .46038 .15728 .45283 .14788 Mtetra
.665 .739 .905 r
.45283 .14788 .46038 .15728 .4736 .15216 .46609 .14275 Mtetra
.665 .739 .906 r
.46609 .14275 .4736 .15216 .48689 .14704 .47942 .13762 Mtetra
.664 .74 .906 r
.47942 .13762 .48689 .14704 .50024 .14193 .49281 .13247 Mtetra
.664 .74 .907 r
.49281 .13247 .50024 .14193 .51366 .1368 .50627 .12732 Mtetra
.664 .741 .907 r
.50627 .12732 .51366 .1368 .52714 .13167 .5198 .12215 Mtetra
.5198 .12215 .52714 .13167 .54069 .12652 .53339 .11695 Mtetra
.664 .741 .908 r
.53339 .11695 .54069 .12652 .5543 .12134 .54705 .11174 Mtetra
.54705 .11174 .5543 .12134 .56798 .11615 .56078 .1065 Mtetra
.56078 .1065 .56798 .11615 .58173 .11093 .57457 .10124 Mtetra
.57457 .10124 .58173 .11093 .59555 .10569 .58844 .09595 Mtetra
.58844 .09595 .59555 .10569 .60944 .10042 .60237 .09063 Mtetra
.60237 .09063 .60944 .10042 .6234 .09513 .61637 .08529 Mtetra
.61637 .08529 .6234 .09513 .63742 .08981 .63045 .07992 Mtetra
.63045 .07992 .63742 .08981 .65152 .08447 .64459 .07453 Mtetra
.64459 .07453 .65152 .08447 .66569 .0791 .65881 .06911 Mtetra
.65881 .06911 .66569 .0791 .67993 .0737 .6731 .06366 Mtetra
.6731 .06366 .67993 .0737 .69424 .06827 .68746 .05818 Mtetra
.68746 .05818 .69424 .06827 .70863 .06282 .7019 .05267 Mtetra
.7019 .05267 .70863 .06282 .72309 .05734 .71641 .04714 Mtetra
.648 .738 .915 r
.0628 .28522 .07149 .29327 .08294 .289 .07423 .28126 Mtetra
.444 .675 .962 r
.07423 .28126 .08294 .289 .09435 .28534 .08516 .28114 Mtetra
.695 .153 0 r
.08516 .28114 .09435 .28534 .10489 .2886 .09475 .29135 Mtetra
.45 0 0 r
.09475 .29135 .10489 .2886 .11296 .31142 .10542 .29473 Mtetra
.792 .652 .708 r
.10542 .29473 .11296 .31142 .12273 .32285 .11905 .27623 Mtetra
.646 .459 .617 r
.11905 .27623 .12273 .32285 .1379 .29213 .13217 .26145 Mtetra
.608 .471 .669 r
.13217 .26145 .1379 .29213 .1522 .26754 .14418 .25536 Mtetra
.644 .651 .842 r
.14418 .25536 .1522 .26754 .16445 .25968 .15603 .25102 Mtetra
.652 .731 .907 r
.15603 .25102 .16445 .25968 .17633 .25533 .16792 .24677 Mtetra
.653 .735 .91 r
.16792 .24677 .17633 .25533 .18824 .25116 .17987 .2425 Mtetra
.653 .734 .908 r
.17987 .2425 .18824 .25116 .20021 .24697 .19188 .23818 Mtetra
.655 .732 .906 r
.19188 .23818 .20021 .24697 .21224 .24272 .20395 .23379 Mtetra
.657 .73 .903 r
.20395 .23379 .21224 .24272 .22434 .23839 .21609 .22933 Mtetra
.659 .728 .9 r
.21609 .22933 .22434 .23839 .2365 .23397 .22829 .22476 Mtetra
.661 .726 .898 r
.22829 .22476 .2365 .23397 .24873 .22943 .24056 .22009 Mtetra
.663 .725 .895 r
.24056 .22009 .24873 .22943 .26103 .22477 .2529 .21532 Mtetra
.666 .724 .892 r
.2529 .21532 .26103 .22477 .27339 .21998 .2653 .21043 Mtetra
.667 .723 .891 r
.2653 .21043 .27339 .21998 .28582 .21508 .27777 .20546 Mtetra
.669 .723 .89 r
.27777 .20546 .28582 .21508 .29832 .21006 .29029 .2004 Mtetra
.67 .723 .889 r
.29029 .2004 .29832 .21006 .31087 .20496 .30288 .19528 Mtetra
.671 .724 .889 r
.30288 .19528 .31087 .20496 .32349 .1998 .31553 .19012 Mtetra
.671 .725 .89 r
.31553 .19012 .32349 .1998 .33616 .19458 .32823 .18493 Mtetra
.671 .727 .891 r
.32823 .18493 .33616 .19458 .3489 .18935 .34099 .17973 Mtetra
.67 .728 .893 r
.34099 .17973 .3489 .18935 .36168 .18411 .35381 .17453 Mtetra
.67 .73 .895 r
.35381 .17453 .36168 .18411 .37453 .17887 .36669 .16934 Mtetra
.669 .732 .897 r
.36669 .16934 .37453 .17887 .38743 .17366 .37963 .16417 Mtetra
.668 .734 .899 r
.37963 .16417 .38743 .17366 .40039 .16847 .39262 .159 Mtetra
.667 .735 .901 r
.39262 .159 .40039 .16847 .41341 .16329 .40567 .15385 Mtetra
.666 .737 .903 r
.40567 .15385 .41341 .16329 .42649 .15814 .41879 .14871 Mtetra
.666 .738 .904 r
.41879 .14871 .42649 .15814 .43963 .153 .43197 .14357 Mtetra
.665 .739 .905 r
.43197 .14357 .43963 .153 .45283 .14788 .44521 .13843 Mtetra
.665 .74 .906 r
.44521 .13843 .45283 .14788 .46609 .14275 .45851 .13329 Mtetra
.664 .74 .906 r
.45851 .13329 .46609 .14275 .47942 .13762 .47188 .12813 Mtetra
.664 .74 .907 r
.47188 .12813 .47942 .13762 .49281 .13247 .48532 .12295 Mtetra
.664 .741 .907 r
.48532 .12295 .49281 .13247 .50627 .12732 .49882 .11776 Mtetra
.664 .741 .908 r
.49882 .11776 .50627 .12732 .5198 .12215 .51239 .11255 Mtetra
.51239 .11255 .5198 .12215 .53339 .11695 .52603 .10731 Mtetra
.52603 .10731 .53339 .11695 .54705 .11174 .53973 .10205 Mtetra
.53973 .10205 .54705 .11174 .56078 .1065 .5535 .09676 Mtetra
.5535 .09676 .56078 .1065 .57457 .10124 .56734 .09145 Mtetra
.56734 .09145 .57457 .10124 .58844 .09595 .58125 .08612 Mtetra
.58125 .08612 .58844 .09595 .60237 .09063 .59523 .08075 Mtetra
.59523 .08075 .60237 .09063 .61637 .08529 .60929 .07536 Mtetra
.60929 .07536 .61637 .08529 .63045 .07992 .62341 .06994 Mtetra
.62341 .06994 .63045 .07992 .64459 .07453 .6376 .0645 Mtetra
.6376 .0645 .64459 .07453 .65881 .06911 .65187 .05902 Mtetra
.65187 .05902 .65881 .06911 .6731 .06366 .66621 .05352 Mtetra
.66621 .05352 .6731 .06366 .68746 .05818 .68062 .04799 Mtetra
.68062 .04799 .68746 .05818 .7019 .05267 .6951 .04244 Mtetra
.6951 .04244 .7019 .05267 .71641 .04714 .70966 .03685 Mtetra
.575 .721 .942 r
.05401 .27726 .0628 .28522 .07423 .28126 .06521 .27499 Mtetra
.112 .545 .916 r
.06521 .27499 .07423 .28126 .08516 .28114 .07577 .27757 Mtetra
.371 .773 .985 r
.07577 .27757 .08516 .28114 .09475 .29135 .08694 .27656 Mtetra
.744 .651 .757 r
.08694 .27656 .09475 .29135 .10542 .29473 .09958 .26542 Mtetra
.647 .502 .672 r
.09958 .26542 .10542 .29473 .11905 .27623 .11196 .25627 Mtetra
.628 .545 .741 r
.11196 .25627 .11905 .27623 .13217 .26145 .12383 .25113 Mtetra
.651 .692 .875 r
.12383 .25113 .13217 .26145 .14418 .25536 .13565 .24677 Mtetra
.654 .735 .909 r
.13565 .24677 .14418 .25536 .15603 .25102 .14752 .24245 Mtetra
.655 .736 .909 r
.14752 .24245 .15603 .25102 .16792 .24677 .15944 .2381 Mtetra
.655 .735 .908 r
.15944 .2381 .16792 .24677 .17987 .2425 .17143 .23372 Mtetra
.656 .733 .906 r
.17143 .23372 .17987 .2425 .19188 .23818 .18348 .22927 Mtetra
.657 .731 .904 r
.18348 .22927 .19188 .23818 .20395 .23379 .19559 .22476 Mtetra
.659 .73 .902 r
.19559 .22476 .20395 .23379 .21609 .22933 .20777 .22017 Mtetra
.661 .728 .899 r
.20777 .22017 .21609 .22933 .22829 .22476 .22002 .21549 Mtetra
.663 .727 .897 r
.22002 .21549 .22829 .22476 .24056 .22009 .23232 .21071 Mtetra
.665 .726 .895 r
.23232 .21071 .24056 .22009 .2529 .21532 .2447 .20585 Mtetra
.666 .725 .893 r
.2447 .20585 .2529 .21532 .2653 .21043 .25713 .2009 Mtetra
.668 .725 .892 r
.25713 .2009 .2653 .21043 .27777 .20546 .26963 .19588 Mtetra
.669 .726 .892 r
.26963 .19588 .27777 .20546 .29029 .2004 .28219 .1908 Mtetra
.28219 .1908 .29029 .2004 .30288 .19528 .29481 .18567 Mtetra
.67 .727 .893 r
.29481 .18567 .30288 .19528 .31553 .19012 .30749 .18052 Mtetra
.67 .729 .894 r
.30749 .18052 .31553 .19012 .32823 .18493 .32022 .17536 Mtetra
.669 .73 .895 r
.32022 .17536 .32823 .18493 .34099 .17973 .33301 .17019 Mtetra
.669 .732 .897 r
.33301 .17019 .34099 .17973 .35381 .17453 .34587 .16502 Mtetra
.668 .733 .899 r
.34587 .16502 .35381 .17453 .36669 .16934 .35878 .15985 Mtetra
.667 .735 .9 r
.35878 .15985 .36669 .16934 .37963 .16417 .37175 .1547 Mtetra
.667 .736 .902 r
.37175 .1547 .37963 .16417 .39262 .159 .38478 .14955 Mtetra
.666 .737 .903 r
.38478 .14955 .39262 .159 .40567 .15385 .39787 .1444 Mtetra
.665 .738 .904 r
.39787 .1444 .40567 .15385 .41879 .14871 .41102 .13925 Mtetra
.665 .739 .905 r
.41102 .13925 .41879 .14871 .43197 .14357 .42424 .1341 Mtetra
.665 .74 .906 r
.42424 .1341 .43197 .14357 .44521 .13843 .43752 .12894 Mtetra
.664 .74 .907 r
.43752 .12894 .44521 .13843 .45851 .13329 .45087 .12376 Mtetra
.664 .741 .907 r
.45087 .12376 .45851 .13329 .47188 .12813 .46428 .11857 Mtetra
.46428 .11857 .47188 .12813 .48532 .12295 .47776 .11336 Mtetra
.664 .741 .908 r
.47776 .11336 .48532 .12295 .49882 .11776 .4913 .10812 Mtetra
.4913 .10812 .49882 .11776 .51239 .11255 .50491 .10286 Mtetra
.50491 .10286 .51239 .11255 .52603 .10731 .51859 .09758 Mtetra
.51859 .09758 .52603 .10731 .53973 .10205 .53234 .09227 Mtetra
.53234 .09227 .53973 .10205 .5535 .09676 .54616 .08694 Mtetra
.54616 .08694 .5535 .09676 .56734 .09145 .56005 .08158 Mtetra
.56005 .08158 .56734 .09145 .58125 .08612 .574 .07619 Mtetra
.574 .07619 .58125 .08612 .59523 .08075 .58803 .07078 Mtetra
.58803 .07078 .59523 .08075 .60929 .07536 .60213 .06534 Mtetra
.60213 .06534 .60929 .07536 .62341 .06994 .6163 .05987 Mtetra
.6163 .05987 .62341 .06994 .6376 .0645 .63054 .05437 Mtetra
.63054 .05437 .6376 .0645 .65187 .05902 .64486 .04885 Mtetra
.64486 .04885 .65187 .05902 .66621 .05352 .65925 .04329 Mtetra
.65925 .04329 .66621 .05352 .68062 .04799 .67371 .03771 Mtetra
.67371 .03771 .68062 .04799 .6951 .04244 .68825 .0321 Mtetra
.68825 .0321 .6951 .04244 .70966 .03685 .70286 .02646 Mtetra
.521 .72 .964 r
.04505 .26987 .05401 .27726 .06521 .27499 .05614 .26843 Mtetra
.604 .774 .961 r
.05614 .26843 .06521 .27499 .07577 .27757 .06755 .26532 Mtetra
.708 .672 .813 r
.06755 .26532 .07577 .27757 .08694 .27656 .07963 .25803 Mtetra
.655 .572 .75 r
.07963 .25803 .08694 .27656 .09958 .26542 .0916 .25168 Mtetra
.646 .626 .816 r
.0916 .25168 .09958 .26542 .11196 .25627 .10339 .24697 Mtetra
.655 .717 .894 r
.10339 .24697 .11196 .25627 .12383 .25113 .11518 .24258 Mtetra
.656 .737 .909 r
.11518 .24258 .12383 .25113 .13565 .24677 .12703 .23818 Mtetra
.12703 .23818 .13565 .24677 .14752 .24245 .13894 .23377 Mtetra
.657 .736 .908 r
.13894 .23377 .14752 .24245 .15944 .2381 .1509 .22932 Mtetra
.657 .734 .906 r
.1509 .22932 .15944 .2381 .17143 .23372 .16293 .22483 Mtetra
.658 .733 .905 r
.16293 .22483 .17143 .23372 .18348 .22927 .17502 .22027 Mtetra
.66 .732 .903 r
.17502 .22027 .18348 .22927 .19559 .22476 .18717 .21565 Mtetra
.661 .73 .901 r
.18717 .21565 .19559 .22476 .20777 .22017 .19939 .21095 Mtetra
.663 .729 .899 r
.19939 .21095 .20777 .22017 .22002 .21549 .21167 .20617 Mtetra
.664 .728 .897 r
.21167 .20617 .22002 .21549 .23232 .21071 .22401 .20132 Mtetra
.666 .728 .896 r
.22401 .20132 .23232 .21071 .2447 .20585 .23642 .19638 Mtetra
.667 .728 .895 r
.23642 .19638 .2447 .20585 .25713 .2009 .24889 .19139 Mtetra
.668 .728 .894 r
.24889 .19139 .25713 .2009 .26963 .19588 .26142 .18634 Mtetra
.668 .728 .895 r
.26142 .18634 .26963 .19588 .28219 .1908 .27401 .18125 Mtetra
.669 .729 .895 r
.27401 .18125 .28219 .1908 .29481 .18567 .28666 .17613 Mtetra
.669 .73 .896 r
.28666 .17613 .29481 .18567 .30749 .18052 .29936 .17099 Mtetra
.668 .732 .897 r
.29936 .17099 .30749 .18052 .32022 .17536 .31213 .16584 Mtetra
.668 .733 .898 r
.31213 .16584 .32022 .17536 .33301 .17019 .32496 .16069 Mtetra
.667 .734 .9 r
.32496 .16069 .33301 .17019 .34587 .16502 .33784 .15553 Mtetra
.667 .736 .901 r
.33784 .15553 .34587 .16502 .35878 .15985 .35079 .15038 Mtetra
.666 .737 .903 r
.35079 .15038 .35878 .15985 .37175 .1547 .36379 .14523 Mtetra
.666 .738 .904 r
.36379 .14523 .37175 .1547 .38478 .14955 .37686 .14008 Mtetra
.665 .739 .905 r
.37686 .14008 .38478 .14955 .39787 .1444 .38999 .13492 Mtetra
.665 .739 .906 r
.38999 .13492 .39787 .1444 .41102 .13925 .40318 .12975 Mtetra
.664 .74 .906 r
.40318 .12975 .41102 .13925 .42424 .1341 .41644 .12457 Mtetra
.664 .74 .907 r
.41644 .12457 .42424 .1341 .43752 .12894 .42976 .11938 Mtetra
.664 .741 .907 r
.42976 .11938 .43752 .12894 .45087 .12376 .44315 .11416 Mtetra
.44315 .11416 .45087 .12376 .46428 .11857 .4566 .10893 Mtetra
.664 .741 .908 r
.4566 .10893 .46428 .11857 .47776 .11336 .47012 .10368 Mtetra
.47012 .10368 .47776 .11336 .4913 .10812 .48371 .0984 Mtetra
.48371 .0984 .4913 .10812 .50491 .10286 .49737 .09309 Mtetra
.49737 .09309 .50491 .10286 .51859 .09758 .51109 .08776 Mtetra
.51109 .08776 .51859 .09758 .53234 .09227 .52489 .08241 Mtetra
.52489 .08241 .53234 .09227 .54616 .08694 .53875 .07702 Mtetra
.53875 .07702 .54616 .08694 .56005 .08158 .55268 .07161 Mtetra
.55268 .07161 .56005 .08158 .574 .07619 .56669 .06618 Mtetra
.56669 .06618 .574 .07619 .58803 .07078 .58076 .06071 Mtetra
.58076 .06071 .58803 .07078 .60213 .06534 .59491 .05522 Mtetra
.59491 .05522 .60213 .06534 .6163 .05987 .60913 .0497 Mtetra
.60913 .0497 .6163 .05987 .63054 .05437 .62342 .04415 Mtetra
.62342 .04415 .63054 .05437 .64486 .04885 .63778 .03857 Mtetra
.63778 .03857 .64486 .04885 .65925 .04329 .65222 .03297 Mtetra
.65222 .03297 .65925 .04329 .67371 .03771 .66673 .02733 Mtetra
.66673 .02733 .67371 .03771 .68825 .0321 .68132 .02167 Mtetra
.68132 .02167 .68825 .0321 .70286 .02646 .69599 .01598 Mtetra
.646 .751 .926 r
.03606 .2621 .04505 .26987 .05614 .26843 .04756 .2581 Mtetra
.683 .7 .86 r
.04756 .2581 .05614 .26843 .06755 .26532 .05935 .25257 Mtetra
.661 .648 .827 r
.05935 .25257 .06755 .26532 .07963 .25803 .07112 .24742 Mtetra
.655 .687 .868 r
.07112 .24742 .07963 .25803 .0916 .25168 .08286 .24287 Mtetra
.658 .731 .903 r
.08286 .24287 .0916 .25168 .10339 .24697 .09463 .23842 Mtetra
.658 .738 .909 r
.09463 .23842 .10339 .24697 .11518 .24258 .10646 .23397 Mtetra
.10646 .23397 .11518 .24258 .12703 .23818 .11834 .22949 Mtetra
.658 .737 .908 r
.11834 .22949 .12703 .23818 .13894 .23377 .13029 .22499 Mtetra
.658 .736 .907 r
.13029 .22499 .13894 .23377 .1509 .22932 .14229 .22044 Mtetra
.659 .734 .905 r
.14229 .22044 .1509 .22932 .16293 .22483 .15435 .21585 Mtetra
.66 .733 .904 r
.15435 .21585 .16293 .22483 .17502 .22027 .16648 .21119 Mtetra
.661 .732 .902 r
.16648 .21119 .17502 .22027 .18717 .21565 .17867 .20648 Mtetra
.663 .731 .9 r
.17867 .20648 .18717 .21565 .19939 .21095 .19092 .20169 Mtetra
.664 .73 .899 r
.19092 .20169 .19939 .21095 .21167 .20617 .20324 .19683 Mtetra
.665 .73 .898 r
.20324 .19683 .21167 .20617 .22401 .20132 .21562 .19191 Mtetra
.666 .73 .897 r
.21562 .19191 .22401 .20132 .23642 .19638 .22806 .18694 Mtetra
.667 .73 .897 r
.22806 .18694 .23642 .19638 .24889 .19139 .24056 .18191 Mtetra
.24056 .18191 .24889 .19139 .26142 .18634 .25312 .17684 Mtetra
.668 .731 .897 r
.25312 .17684 .26142 .18634 .27401 .18125 .26574 .17174 Mtetra
.668 .732 .898 r
.26574 .17174 .27401 .18125 .28666 .17613 .27842 .16662 Mtetra
.667 .733 .899 r
.27842 .16662 .28666 .17613 .29936 .17099 .29117 .16149 Mtetra
.667 .734 .9 r
.29117 .16149 .29936 .17099 .31213 .16584 .30396 .15635 Mtetra
.667 .735 .901 r
.30396 .15635 .31213 .16584 .32496 .16069 .31682 .1512 Mtetra
.666 .736 .902 r
.31682 .1512 .32496 .16069 .33784 .15553 .32974 .14605 Mtetra
.666 .737 .903 r
.32974 .14605 .33784 .15553 .35079 .15038 .34272 .1409 Mtetra
.665 .738 .904 r
.34272 .1409 .35079 .15038 .36379 .14523 .35577 .13574 Mtetra
.665 .739 .905 r
.35577 .13574 .36379 .14523 .37686 .14008 .36887 .13057 Mtetra
.665 .74 .906 r
.36887 .13057 .37686 .14008 .38999 .13492 .38204 .12539 Mtetra
.664 .74 .907 r
.38204 .12539 .38999 .13492 .40318 .12975 .39527 .12019 Mtetra
.39527 .12019 .40318 .12975 .41644 .12457 .40857 .11498 Mtetra
.664 .741 .907 r
.40857 .11498 .41644 .12457 .42976 .11938 .42193 .10974 Mtetra
.42193 .10974 .42976 .11938 .44315 .11416 .43536 .10449 Mtetra
.664 .741 .908 r
.43536 .10449 .44315 .11416 .4566 .10893 .44886 .09921 Mtetra
.44886 .09921 .4566 .10893 .47012 .10368 .46242 .09391 Mtetra
.46242 .09391 .47012 .10368 .48371 .0984 .47605 .08858 Mtetra
.47605 .08858 .48371 .0984 .49737 .09309 .48975 .08323 Mtetra
.48975 .08323 .49737 .09309 .51109 .08776 .50352 .07785 Mtetra
.50352 .07785 .51109 .08776 .52489 .08241 .51736 .07245 Mtetra
.51736 .07245 .52489 .08241 .53875 .07702 .53127 .06701 Mtetra
.53127 .06701 .53875 .07702 .55268 .07161 .54525 .06155 Mtetra
.54525 .06155 .55268 .07161 .56669 .06618 .5593 .05607 Mtetra
.5593 .05607 .56669 .06618 .58076 .06071 .57342 .05055 Mtetra
.57342 .05055 .58076 .06071 .59491 .05522 .58762 .04501 Mtetra
.58762 .04501 .59491 .05522 .60913 .0497 .60188 .03943 Mtetra
.60188 .03943 .60913 .0497 .62342 .04415 .61623 .03383 Mtetra
.61623 .03383 .62342 .04415 .63778 .03857 .63064 .0282 Mtetra
.63064 .0282 .63778 .03857 .65222 .03297 .64513 .02254 Mtetra
.64513 .02254 .65222 .03297 .66673 .02733 .65969 .01685 Mtetra
.65969 .01685 .66673 .02733 .68132 .02167 .67433 .01113 Mtetra
.67433 .01113 .68132 .02167 .69599 .01598 .68905 .00539 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.980392 0.00980392 0.980392 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 1 r
.005 w
.8612 .33442 m
.887 .33974 L
.89631 .3452 L
.9128 .35599 L
.9244 .371 L
.93403 .3968 L
.93454 .4226 L
.9128 .44527 L
.887 .4452 L
.8612 .42715 L
.85637 .4226 L
.84045 .3968 L
.8354 .37941 L
.83461 .371 L
.8354 .36247 L
.8435 .3452 L
.8612 .33442 L
s
.1646 .13656 m
.16791 .1388 L
.1904 .15602 L
.20049 .1646 L
.2162 .17893 L
.22792 .1904 L
.242 .20535 L
.25123 .2162 L
.242 .2322 L
.2202 .2162 L
.2162 .21296 L
.19062 .1904 L
.1904 .1902 L
.16516 .1646 L
.1646 .16399 L
.14484 .1388 L
.1646 .13656 L
s
.4226 .24597 m
.4484 .24354 L
.4742 .24745 L
.5 .25606 L
.52561 .2678 L
.5258 .26795 L
.5516 .28209 L
.57017 .2936 L
.5774 .29854 L
.6032 .31702 L
.60637 .3194 L
.629 .33732 L
.6384 .3452 L
.6548 .35961 L
.66712 .371 L
.6806 .38402 L
.69316 .3968 L
.7064 .41085 L
.71686 .4226 L
.7322 .44068 L
.73833 .4484 L
.75759 .4742 L
.758 .47474 L
.77466 .5 L
.7838 .51514 L
.78899 .5258 L
.80035 .5516 L
.8073 .5774 L
.80757 .6032 L
.7838 .62882 L
.78264 .629 L
.758 .63066 L
.74705 .629 L
.7322 .62549 L
.7064 .61608 L
.6806 .60354 L
.67993 .6032 L
.6548 .58884 L
.63688 .5774 L
.629 .5719 L
.6032 .55294 L
.60146 .5516 L
.5774 .53216 L
.56995 .5258 L
.5516 .50938 L
.54165 .5 L
.5258 .48441 L
.51595 .4742 L
.5 .45691 L
.49258 .4484 L
Mistroke
.4742 .42616 L
.47144 .4226 L
.45243 .3968 L
.4484 .39125 L
.43577 .371 L
.4226 .34677 L
.4219 .3452 L
.41103 .3194 L
.40467 .2936 L
.40556 .2678 L
.4226 .24597 L
Mfstroke
.8612 .82654 m
.887 .83482 L
.88776 .8354 L
.9128 .85255 L
.92222 .8612 L
.9386 .88138 L
.9431 .887 L
.9386 .9115 L
.9128 .90776 L
.887 .89275 L
.87967 .887 L
.8612 .86864 L
.8531 .8612 L
.84635 .8354 L
.8612 .82654 L
s
0 g
.03 w
.88529 .39101 Mdot
.20267 .18396 Mdot
.60634 .43737 Mdot
.89588 .86948 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.90588 .90588 Mdot
.49412 .4902 Mdot
.8 .8 Mdot
.17647 .16471 Mdot
.18039 .18431 Mdot
.13333 .11373 Mdot
.32157 .29412 Mdot
.36863 .37255 Mdot
.20784 .19216 Mdot
.28627 .25098 Mdot
.24314 .23922 Mdot
.21569 .2 Mdot
.26275 .21961 Mdot
.23529 .22353 Mdot
.17255 .16078 Mdot
.20392 .16863 Mdot
.3098 .27843 Mdot
.83922 .83922 Mdot
.2902 .2549 Mdot
.23922 .20392 Mdot
.2902 .27451 Mdot
1 .96471 Mdot
.79608 .7451 Mdot
.27451 .23137 Mdot
.26667 .22353 Mdot
.27059 .24314 Mdot
.9098 .81961 Mdot
.83529 .73333 Mdot
.72549 .51765 Mdot
.1451 .09412 Mdot
.18431 .14118 Mdot
.24706 .21176 Mdot
.16863 .15686 Mdot
.41569 .41569 Mdot
.55686 .55686 Mdot
.53725 .30196 Mdot
.64314 .4549 Mdot
.62353 .24706 Mdot
.15686 .08235 Mdot
.21569 .17647 Mdot
.27843 .25098 Mdot
.17647 .1451 Mdot
.90196 .85098 Mdot
.67451 .68235 Mdot
.11765 .11373 Mdot
.39216 .4 Mdot
.61176 .28627 Mdot
.60392 .40392 Mdot
.78431 .30196 Mdot
.25882 .09412 Mdot
.16863 .12941 Mdot
.25098 .22353 Mdot
.19216 .16078 Mdot
.34902 .23529 Mdot
.53725 .46275 Mdot
.85882 .76863 Mdot
.94902 .94902 Mdot
.1098 .10588 Mdot
.09412 .09804 Mdot
.83922 .83922 Mdot
.61176 .23922 Mdot
.67843 .42745 Mdot
.80784 .30588 Mdot
.21176 .0549 Mdot
.18824 .1451 Mdot
.24314 .22353 Mdot
.18824 .13333 Mdot
.47843 .30196 Mdot
.34902 .2 Mdot
.40392 .18431 Mdot
.55294 .43529 Mdot
.85098 .75294 Mdot
.99608 .95294 Mdot
.12549 .12157 Mdot
.22353 .22353 Mdot
.07059 .0902 Mdot
.71373 .27451 Mdot
.72549 .49804 Mdot
.74902 .30588 Mdot
.73725 .25098 Mdot
.22745 .12549 Mdot
.2 .15686 Mdot
.16078 .12941 Mdot
.22353 .02353 Mdot
.45882 .29412 Mdot
.43529 .2 Mdot
.35294 .16471 Mdot
.32941 .16863 Mdot
.37647 .27059 Mdot
.61176 .52941 Mdot
.89804 .81569 Mdot
1 1 Mdot
.10196 .10588 Mdot
.21961 .2 Mdot
.20392 .20392 Mdot
.31373 .32157 Mdot
.82353 .27451 Mdot
.56471 .2902 Mdot
.81961 .2902 Mdot
.83529 .36471 Mdot
.21961 .12157 Mdot
.20392 .16078 Mdot
.19216 .13725 Mdot
.54118 .27451 Mdot
.59608 .43922 Mdot
.55294 .24314 Mdot
.52157 .39216 Mdot
.32157 .17255 Mdot
.29804 .16078 Mdot
.31373 .16078 Mdot
.4902 .28627 Mdot
.61569 .59608 Mdot
.11373 .11765 Mdot
.26275 .25098 Mdot
.19216 .17255 Mdot
.0902 .09412 Mdot
.86275 .62745 Mdot
.69412 .22353 Mdot
.81961 .41569 Mdot
.86667 .30588 Mdot
.72941 .27059 Mdot
.25098 .12157 Mdot
.22745 .15686 Mdot
.27843 .08235 Mdot
.68235 .46275 Mdot
.53725 .37255 Mdot
.58431 .30196 Mdot
.72157 .57255 Mdot
.59216 .45882 Mdot
.4902 .32941 Mdot
.41176 .18431 Mdot
.40784 .18039 Mdot
.36471 .35294 Mdot
.12157 .12549 Mdot
.16078 .14902 Mdot
.16863 .14902 Mdot
.1098 .1098 Mdot
.82745 .28627 Mdot
.99216 .54118 Mdot
.80392 .26667 Mdot
.86667 .28627 Mdot
.69412 .2549 Mdot
.28627 .09804 Mdot
.2549 .09804 Mdot
.47843 .06667 Mdot
.51373 .31765 Mdot
.47843 .28627 Mdot
.42353 .23922 Mdot
.35686 .20392 Mdot
.71373 .55294 Mdot
.62745 .50196 Mdot
.48235 .15294 Mdot
.53333 .39216 Mdot
.39608 .39216 Mdot
.12549 .11373 Mdot
.13725 .11765 Mdot
.13725 .11765 Mdot
.09412 .10196 Mdot
.83922 .25098 Mdot
.84706 .32157 Mdot
.84706 .26667 Mdot
.8549 .2549 Mdot
.79608 .31373 Mdot
.34902 .07059 Mdot
.32157 .03137 Mdot
.77255 .27059 Mdot
.64706 .42745 Mdot
.49804 .26667 Mdot
.78431 .63922 Mdot
.30196 .16863 Mdot
.55294 .33725 Mdot
.64706 .54118 Mdot
.61961 .23529 Mdot
.55294 .44314 Mdot
.0549 .0549 Mdot
.12549 .11373 Mdot
.34902 .32941 Mdot
.1451 .12549 Mdot
.12549 .13333 Mdot
.86275 .27451 Mdot
.87059 .29804 Mdot
.85098 .2549 Mdot
.85098 .24706 Mdot
.87059 .32157 Mdot
.51373 .0902 Mdot
.50588 .08235 Mdot
.81176 .27451 Mdot
.64314 .38039 Mdot
.63922 .38039 Mdot
.68627 .54118 Mdot
.4 .25882 Mdot
.46667 .19216 Mdot
.67451 .56078 Mdot
.61176 .24706 Mdot
.55686 .45098 Mdot
.08627 .07843 Mdot
.12941 .12549 Mdot
.34118 .32157 Mdot
.11765 .10588 Mdot
.0902 .09804 Mdot
.86275 .27451 Mdot
.88627 .28235 Mdot
.85098 .24706 Mdot
.86667 .26275 Mdot
.93333 .35686 Mdot
.88235 .36863 Mdot
.85098 .34118 Mdot
.84314 .28627 Mdot
.60784 .34902 Mdot
.58431 .33725 Mdot
.67843 .54118 Mdot
.52549 .38431 Mdot
.51373 .2 Mdot
.72549 .61176 Mdot
.6 .28235 Mdot
.59216 .4902 Mdot
.12157 .11373 Mdot
.1451 .14118 Mdot
.29804 .28627 Mdot
.11373 .10196 Mdot
.07451 .07451 Mdot
.83922 .2902 Mdot
.8902 .28627 Mdot
.8902 .28627 Mdot
.88235 .27843 Mdot
.90196 .3098 Mdot
.92157 .36078 Mdot
.87059 .33333 Mdot
.89804 .30196 Mdot
.63922 .38431 Mdot
.59608 .37647 Mdot
.66275 .53333 Mdot
.38431 .23137 Mdot
.73333 .46275 Mdot
.67059 .52549 Mdot
.52941 .32941 Mdot
.58824 .44706 Mdot
.59608 .57255 Mdot
.14118 .13725 Mdot
.14118 .14118 Mdot
.09804 .09804 Mdot
.12941 .12549 Mdot
.81961 .82745 Mdot
.86275 .28235 Mdot
.87059 .27451 Mdot
.87843 .28235 Mdot
.88235 .28627 Mdot
.87059 .31765 Mdot
.91373 .36863 Mdot
.92157 .36863 Mdot
.86667 .27451 Mdot
.53725 .3098 Mdot
.54118 .36471 Mdot
.74902 .62745 Mdot
.53725 .41569 Mdot
.51373 .16863 Mdot
.69412 .56471 Mdot
.39608 .19608 Mdot
.35686 .23922 Mdot
.72941 .7098 Mdot
.12941 .12549 Mdot
.22745 .21569 Mdot
.21961 .21569 Mdot
.11373 .1098 Mdot
.52157 .52549 Mdot
.81961 .30196 Mdot
.86667 .28627 Mdot
.88235 .30588 Mdot
.87451 .29412 Mdot
.83137 .30196 Mdot
.89412 .40784 Mdot
.92549 .38039 Mdot
.90588 .31373 Mdot
.54118 .20392 Mdot
.50588 .32549 Mdot
.34902 .24706 Mdot
.38824 .24706 Mdot
.81569 .55686 Mdot
.68627 .52549 Mdot
.46275 .23137 Mdot
.52549 .36078 Mdot
.45882 .38824 Mdot
.12157 .12549 Mdot
.12157 .11765 Mdot
.20392 .20392 Mdot
.14902 .14118 Mdot
.43529 .43922 Mdot
.73725 .74118 Mdot
.81961 .28627 Mdot
.90196 .32941 Mdot
.92157 .36471 Mdot
.89804 .33333 Mdot
.87059 .38824 Mdot
.89412 .46667 Mdot
.90588 .4 Mdot
.87451 .29412 Mdot
.67843 .28235 Mdot
.63137 .41961 Mdot
.41176 .31373 Mdot
.31373 .17647 Mdot
.65098 .39216 Mdot
.79608 .64706 Mdot
.55686 .28235 Mdot
.7098 .50196 Mdot
.57647 .47843 Mdot
.08235 .08235 Mdot
.11373 .1098 Mdot
.13725 .13725 Mdot
.12157 .11373 Mdot
.47843 .47843 Mdot
.44706 .4549 Mdot
.61176 .38824 Mdot
.92157 .33333 Mdot
.98824 .4902 Mdot
.96078 .41961 Mdot
.91373 .37647 Mdot
.95294 .56863 Mdot
.86275 .48627 Mdot
.82353 .32549 Mdot
.84706 .28235 Mdot
.79216 .40784 Mdot
.52941 .40784 Mdot
.73333 .56863 Mdot
.78039 .65882 Mdot
.53725 .30196 Mdot
.84706 .61569 Mdot
.64706 .35686 Mdot
.6 .35686 Mdot
.95294 .9451 Mdot
.19608 .18039 Mdot
.13333 .12941 Mdot
.13333 .13333 Mdot
.05098 .0549 Mdot
.50588 .5098 Mdot
.41961 .42745 Mdot
.69412 .28627 Mdot
.89804 .3098 Mdot
.97647 .45882 Mdot
.95686 .41569 Mdot
.95294 .43137 Mdot
.96863 .56863 Mdot
.91765 .54118 Mdot
.99216 .50196 Mdot
.86275 .29804 Mdot
.80784 .37647 Mdot
.78431 .64706 Mdot
.44314 .26667 Mdot
.85098 .71765 Mdot
.38039 .23137 Mdot
.46667 .13333 Mdot
.64314 .32941 Mdot
.63529 .38824 Mdot
.89412 .8902 Mdot
.09412 .0902 Mdot
.13725 .13333 Mdot
.12941 .12941 Mdot
.51373 .51373 Mdot
.53333 .53333 Mdot
.47451 .48235 Mdot
.96078 .96078 Mdot
.93725 .34902 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.94902 .39216 Mdot
.92157 .42745 Mdot
.94118 .5098 Mdot
.91765 .44706 Mdot
.87059 .2902 Mdot
.8902 .33725 Mdot
.65098 .38039 Mdot
.89412 .71765 Mdot
.82353 .70588 Mdot
.45098 .30196 Mdot
.8549 .67059 Mdot
.70196 .33725 Mdot
.68627 .37255 Mdot
.7451 .67843 Mdot
.34902 .33725 Mdot
.08235 .06667 Mdot
.11765 .12157 Mdot
.18824 .18824 Mdot
.54118 .54118 Mdot
.51373 .51373 Mdot
.47843 .48627 Mdot
1 .97647 Mdot
.94902 .36078 Mdot
.95294 .38039 Mdot
.88235 .34902 Mdot
.93333 .38431 Mdot
.93333 .39608 Mdot
.89412 .40784 Mdot
.93725 .43529 Mdot
.88235 .31765 Mdot
.88627 .30588 Mdot
.62353 .28235 Mdot
.99608 .74902 Mdot
.88235 .72549 Mdot
.78431 .65098 Mdot
.95294 .72941 Mdot
.77255 .38431 Mdot
.72549 .39216 Mdot
.76863 .69804 Mdot
.2549 .24314 Mdot
.3451 .33725 Mdot
.11373 .12941 Mdot
.21569 .22353 Mdot
.56078 .55294 Mdot
.35686 .35294 Mdot
.47451 .48235 Mdot
.55294 .54902 Mdot
.85882 .29804 Mdot
.93333 .3451 Mdot
.97255 .4549 Mdot
.91373 .38039 Mdot
.92941 .38039 Mdot
.94902 .41176 Mdot
.91373 .39608 Mdot
.96863 .43529 Mdot
.90196 .3451 Mdot
.84706 .33725 Mdot
.73725 .38431 Mdot
.82353 .52157 Mdot
.91765 .71373 Mdot
.92157 .72941 Mdot
.78824 .3098 Mdot
.80392 .43922 Mdot
.71765 .5451 Mdot
.35294 .34902 Mdot
.21961 .21176 Mdot
.28235 .3098 Mdot
.17255 .17647 Mdot
.63137 .62745 Mdot
.33333 .33725 Mdot
.36471 .36863 Mdot
.49804 .48627 Mdot
.6549 .31765 Mdot
.91765 .32941 Mdot
.93725 .37647 Mdot
.94902 .43922 Mdot
.9451 .42353 Mdot
.91373 .36471 Mdot
.94902 .40392 Mdot
.94902 .41176 Mdot
.95686 .41569 Mdot
.90196 .3451 Mdot
.76078 .29412 Mdot
.74902 .31765 Mdot
.6902 .37255 Mdot
.82745 .56863 Mdot
.76078 .27059 Mdot
.82745 .37647 Mdot
.7098 .39608 Mdot
.81176 .80392 Mdot
.27451 .26667 Mdot
.42745 .43137 Mdot
.21569 .23529 Mdot
.09804 .10588 Mdot
.63529 .63529 Mdot
.54118 .5451 Mdot
.54902 .54902 Mdot
.76471 .7451 Mdot
.94902 .36078 Mdot
.95294 .36078 Mdot
.93725 .4 Mdot
.92157 .41569 Mdot
.95294 .43529 Mdot
.89804 .36078 Mdot
.92549 .37647 Mdot
.93725 .39608 Mdot
.9451 .41176 Mdot
.88235 .32549 Mdot
.83137 .37647 Mdot
.76863 .33725 Mdot
.67451 .28235 Mdot
.69804 .26275 Mdot
.83922 .30196 Mdot
.85882 .41961 Mdot
.75294 .67843 Mdot
.15294 .15294 Mdot
.83922 .82353 Mdot
.15686 .19216 Mdot
.14902 .16863 Mdot
.6902 .67843 Mdot
.38431 .38824 Mdot
.60392 .58824 Mdot
.57255 .49412 Mdot
.80392 .3098 Mdot
.91765 .34118 Mdot
.9451 .38431 Mdot
.87843 .41176 Mdot
.88235 .41961 Mdot
.94902 .42745 Mdot
.94118 .38431 Mdot
.90588 .35686 Mdot
.93333 .39216 Mdot
.96863 .44314 Mdot
.85882 .38431 Mdot
.8549 .40784 Mdot
.82745 .38039 Mdot
.79608 .3451 Mdot
.8549 .3098 Mdot
.86667 .32549 Mdot
.83529 .64314 Mdot
.85098 .8549 Mdot
.50196 .4902 Mdot
.89804 .90196 Mdot
.51765 .52941 Mdot
.12941 .12549 Mdot
.66275 .66667 Mdot
.31765 .31373 Mdot
.60392 .55686 Mdot
.97647 .92157 Mdot
.93725 .34118 Mdot
.93725 .35686 Mdot
.88235 .40784 Mdot
.83922 .47843 Mdot
.87059 .45098 Mdot
.93333 .39608 Mdot
.95294 .40392 Mdot
.91765 .37647 Mdot
.8902 .39608 Mdot
.92549 .35294 Mdot
.70588 .38824 Mdot
.87059 .47059 Mdot
.8549 .44314 Mdot
.87059 .39216 Mdot
.86667 .34118 Mdot
.82745 .34118 Mdot
.81961 .77647 Mdot
.60392 .6 Mdot
.34118 .33333 Mdot
.96078 .97647 Mdot
.5098 .50588 Mdot
.7451 .72941 Mdot
.61961 .61961 Mdot
.30588 .30196 Mdot
.93725 .70196 Mdot
.75294 .31765 Mdot
.91765 .33725 Mdot
.90196 .39216 Mdot
.81176 .49412 Mdot
.77647 .4902 Mdot
.81176 .40784 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.95294 .42745 Mdot
.84314 .37647 Mdot
.81176 .37647 Mdot
.47843 .21961 Mdot
.66275 .3451 Mdot
.82353 .45098 Mdot
.86667 .43922 Mdot
.87843 .32549 Mdot
.72941 .48235 Mdot
.84314 .82745 Mdot
.27843 .26667 Mdot
.94902 .94118 Mdot
.25098 .24314 Mdot
.66667 .65882 Mdot
.71765 .71373 Mdot
.66275 .66275 Mdot
.59216 .51765 Mdot
.54118 .3098 Mdot
.94902 .36863 Mdot
.90196 .34902 Mdot
.8 .47843 Mdot
.76863 .58431 Mdot
.91765 .69412 Mdot
.87451 .43922 Mdot
.9451 .39216 Mdot
.9451 .38824 Mdot
.83529 .45098 Mdot
.92941 .39216 Mdot
.33725 .14902 Mdot
.36863 .18039 Mdot
.4549 .24706 Mdot
.58039 .2902 Mdot
.71373 .34118 Mdot
.79216 .32941 Mdot
.86667 .78039 Mdot
.67451 .67451 Mdot
.96078 .93725 Mdot
.88235 .88235 Mdot
.91373 .90196 Mdot
.79216 .78824 Mdot
.72941 .71765 Mdot
.63922 .63529 Mdot
.67059 .31373 Mdot
.90588 .78431 Mdot
.93333 .35294 Mdot
.87843 .41176 Mdot
.82745 .67843 Mdot
.82353 .70588 Mdot
.69804 .53333 Mdot
.90196 .45098 Mdot
.93725 .38039 Mdot
.92941 .38039 Mdot
.58039 .32549 Mdot
.89804 .37255 Mdot
.22745 .12941 Mdot
.25882 .16078 Mdot
.3098 .17255 Mdot
.40392 .21176 Mdot
.57647 .16863 Mdot
.57647 .2902 Mdot
.5451 .51373 Mdot
.23922 .23529 Mdot
.76471 .74118 Mdot
.9451 .95686 Mdot
.84706 .83922 Mdot
.82353 .80784 Mdot
.76863 .75294 Mdot
.73333 .71373 Mdot
.78431 .31373 Mdot
.76471 .31765 Mdot
.93333 .37255 Mdot
.82353 .53725 Mdot
.7451 .67843 Mdot
.42745 .3451 Mdot
.36863 .22353 Mdot
.90588 .46275 Mdot
.9451 .39216 Mdot
.8902 .40784 Mdot
.43922 .21176 Mdot
.88235 .40392 Mdot
.18039 .11765 Mdot
.2 .12941 Mdot
.22745 .1451 Mdot
.28235 .16471 Mdot
.79216 .35294 Mdot
.27059 .16471 Mdot
.23529 .23529 Mdot
.19216 .19608 Mdot
.4549 .44314 Mdot
.49412 .49804 Mdot
.8549 .8549 Mdot
.83137 .82745 Mdot
.77255 .76863 Mdot
.75686 .67059 Mdot
.71765 .36471 Mdot
.92941 .36863 Mdot
.85882 .39216 Mdot
.85882 .71765 Mdot
.9098 .86275 Mdot
.34118 .2902 Mdot
1 .8549 Mdot
.92549 .4549 Mdot
.95294 .4 Mdot
.63529 .3451 Mdot
.34118 .06667 Mdot
.79608 .38039 Mdot
.15294 .12157 Mdot
.18039 .14118 Mdot
.2 .16078 Mdot
.27843 .16471 Mdot
.78431 .39608 Mdot
.21176 .18039 Mdot
.19608 .19216 Mdot
.10196 .11373 Mdot
.27451 .25882 Mdot
.81961 .81961 Mdot
.87059 .87059 Mdot
.85882 .85098 Mdot
.81176 .80784 Mdot
.89804 .65882 Mdot
.62745 .52157 Mdot
.90588 .33333 Mdot
.84314 .47843 Mdot
.83529 .74902 Mdot
.39216 .36078 Mdot
.37255 .33725 Mdot
.92549 .7098 Mdot
.92941 .46667 Mdot
.9451 .38824 Mdot
.32549 .15686 Mdot
.32157 .08235 Mdot
.79608 .38039 Mdot
.14118 .1098 Mdot
.20784 .17647 Mdot
.15686 .13725 Mdot
.21569 .05098 Mdot
.70588 .38039 Mdot
.14118 .13725 Mdot
.13725 .12941 Mdot
.2902 .29412 Mdot
.51765 .50588 Mdot
.88627 .87843 Mdot
.87843 .87843 Mdot
.87451 .87451 Mdot
.85098 .85098 Mdot
.7451 .41961 Mdot
1 .96471 Mdot
.88235 .32941 Mdot
.83922 .55686 Mdot
.85882 .81176 Mdot
.2549 .23922 Mdot
.81961 .78824 Mdot
.94902 .6902 Mdot
.93725 .47059 Mdot
.93725 .4 Mdot
.23922 .16078 Mdot
.32157 .10196 Mdot
.80784 .39216 Mdot
.15294 .13333 Mdot
.1451 .12549 Mdot
.13333 .11373 Mdot
.34118 .08235 Mdot
.56863 .34118 Mdot
.12157 .12157 Mdot
.1451 .12157 Mdot
.72157 .72941 Mdot
.86275 .85882 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.88235 .88235 Mdot
.87451 .87451 Mdot
.52157 .13333 Mdot
1 .96863 Mdot
.89412 .35686 Mdot
.86275 .61176 Mdot
.86667 .82745 Mdot
.25098 .23922 Mdot
.48627 .4549 Mdot
.80784 .47843 Mdot
.90196 .48235 Mdot
.92157 .38824 Mdot
.21961 .16078 Mdot
.55686 .40784 Mdot
.86275 .40784 Mdot
.1451 .10588 Mdot
.1451 .13333 Mdot
.1451 .12549 Mdot
.35294 .07451 Mdot
.54902 .32549 Mdot
.12549 .12549 Mdot
.1098 .07059 Mdot
.84706 .84706 Mdot
.87059 .86667 Mdot
.85098 .85098 Mdot
.87451 .87451 Mdot
.87059 .87059 Mdot
.87059 .87059 Mdot
.69804 .32549 Mdot
1 .96863 Mdot
.85882 .35294 Mdot
.89804 .65882 Mdot
.8902 .8549 Mdot
.30196 .28235 Mdot
.34118 .30196 Mdot
.73725 .41569 Mdot
.89804 .51373 Mdot
.9098 .39608 Mdot
.19216 .14902 Mdot
.75686 .66275 Mdot
.88235 .42353 Mdot
.16471 .07059 Mdot
.17255 .14118 Mdot
.14118 .12157 Mdot
.37647 .0902 Mdot
.54118 .31765 Mdot
.12549 .1098 Mdot
.29412 .24706 Mdot
.86667 .86275 Mdot
.91373 .91373 Mdot
.69412 .6902 Mdot
.87451 .87451 Mdot
.85882 .85882 Mdot
.86275 .86275 Mdot
.86275 .49804 Mdot
1 .97255 Mdot
.86667 .39216 Mdot
.97255 .73333 Mdot
.86275 .81961 Mdot
.26667 .23922 Mdot
.21176 .16078 Mdot
.83529 .58824 Mdot
.86275 .52157 Mdot
.87843 .38824 Mdot
.17255 .12941 Mdot
.43922 .36471 Mdot
.86275 .44314 Mdot
.23529 .03529 Mdot
.20784 .14902 Mdot
.15686 .12549 Mdot
.37255 .07059 Mdot
.52941 .30588 Mdot
.13725 .09804 Mdot
.8 .75686 Mdot
.87059 .86667 Mdot
.7451 .74902 Mdot
.4549 .45098 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.85882 .86667 Mdot
.79608 .43137 Mdot
1 .97255 Mdot
.83137 .39608 Mdot
.97647 .74118 Mdot
.79216 .7451 Mdot
.31765 .28627 Mdot
.50588 .45098 Mdot
1 .81569 Mdot
.87059 .56471 Mdot
.8902 .41961 Mdot
.17647 .14118 Mdot
.26667 .20784 Mdot
.72549 .37255 Mdot
.40392 .0902 Mdot
.27843 .12157 Mdot
.20392 .09412 Mdot
.38824 .0549 Mdot
.52941 .27059 Mdot
.2 .08627 Mdot
.56471 .52549 Mdot
.88627 .87843 Mdot
.27451 .28235 Mdot
.30588 .29412 Mdot
.87451 .85882 Mdot
.88627 .88627 Mdot
.87059 .87843 Mdot
.76471 .4 Mdot
1 .96471 Mdot
.81176 .41176 Mdot
.94118 .69804 Mdot
.76863 .71765 Mdot
.78824 .75294 Mdot
.80784 .75686 Mdot
.58039 .45098 Mdot
.94902 .67843 Mdot
.87059 .43137 Mdot
.19608 .16078 Mdot
.24314 .2 Mdot
.64706 .36863 Mdot
.73725 .29804 Mdot
.42745 .09804 Mdot
.31373 .06667 Mdot
.43137 .04314 Mdot
.56078 .23922 Mdot
.29412 .05882 Mdot
.57647 .54118 Mdot
.90588 .88627 Mdot
.26275 .28235 Mdot
.20392 .17255 Mdot
.90196 .87843 Mdot
.87843 .87843 Mdot
.86667 .87451 Mdot
.72941 .37255 Mdot
1 .96471 Mdot
.76863 .40392 Mdot
.86667 .61569 Mdot
.83922 .79608 Mdot
.51765 .4902 Mdot
.47843 .43922 Mdot
.4902 .40392 Mdot
.99608 .73725 Mdot
.86667 .44706 Mdot
.18431 .15686 Mdot
.20392 .17647 Mdot
.80784 .59216 Mdot
.81961 .35686 Mdot
.65098 .21961 Mdot
.47451 .12157 Mdot
.46667 .02353 Mdot
.60392 .20392 Mdot
.47451 .12549 Mdot
.64314 .61176 Mdot
.51373 .50196 Mdot
.26667 .28627 Mdot
.16863 .12549 Mdot
.96078 .93725 Mdot
.88235 .87843 Mdot
.87059 .87843 Mdot
.68627 .33333 Mdot
1 .95686 Mdot
.75294 .41176 Mdot
.77647 .52941 Mdot
.94902 .92549 Mdot
.35294 .3451 Mdot
.43529 .42353 Mdot
.74118 .67843 Mdot
1 .75686 Mdot
.84314 .44706 Mdot
.18039 .14902 Mdot
.17647 .1451 Mdot
.62353 .44706 Mdot
.8902 .5098 Mdot
.82745 .36471 Mdot
.73725 .2902 Mdot
.61176 .13333 Mdot
.7451 .26667 Mdot
.74902 .3098 Mdot
.84314 .80784 Mdot
.27059 .26667 Mdot
.22353 .23529 Mdot
.15294 .09804 Mdot
.8902 .87451 Mdot
.91373 .8902 Mdot
.87451 .88235 Mdot
.66275 .32549 Mdot
1 .95294 Mdot
.75294 .41569 Mdot
.66667 .43922 Mdot
.92549 .91373 Mdot
.19216 .18431 Mdot
.21569 .22353 Mdot
.91765 .87451 Mdot
.98039 .72941 Mdot
.83922 .46667 Mdot
.16471 .1451 Mdot
.18039 .14902 Mdot
.36863 .20392 Mdot
1 .68627 Mdot
.83529 .39216 Mdot
.88235 .41961 Mdot
.81176 .35294 Mdot
.85098 .32549 Mdot
.83922 .36863 Mdot
.68627 .64706 Mdot
.25882 .2549 Mdot
.15294 .15686 Mdot
.13725 .08235 Mdot
.63137 .61569 Mdot
.87451 .83922 Mdot
.86667 .87059 Mdot
.60392 .28627 Mdot
1 .9451 Mdot
.77255 .43529 Mdot
.61569 .42745 Mdot
.70196 .68627 Mdot
.56078 .5451 Mdot
.66275 .6549 Mdot
.9451 .91373 Mdot
.91765 .67059 Mdot
.80784 .46275 Mdot
.24706 .21961 Mdot
.18824 .15686 Mdot
.35294 .18824 Mdot
.99608 .58039 Mdot
1 .61961 Mdot
.86275 .45882 Mdot
.91373 .52157 Mdot
.90588 .36863 Mdot
.83922 .40392 Mdot
.30588 .28627 Mdot
.20392 .19608 Mdot
.16078 .16078 Mdot
.16471 .1098 Mdot
.57255 .55686 Mdot
.3451 .32157 Mdot
.86667 .87451 Mdot
.54118 .23922 Mdot
1 .9451 Mdot
.76078 .41176 Mdot
.66667 .52941 Mdot
.49412 .47059 Mdot
.90196 .87843 Mdot
.97255 .95294 Mdot
.93725 .90588 Mdot
.83529 .58824 Mdot
.80392 .46275 Mdot
.52157 .48627 Mdot
.18431 .15294 Mdot
.34118 .14902 Mdot
.9098 .44706 Mdot
.96078 .57255 Mdot
.98431 .58824 Mdot
1 .60784 Mdot
.92549 .38824 Mdot
.74902 .38431 Mdot
.26275 .24706 Mdot
.15294 .1451 Mdot
.14902 .1451 Mdot
.17255 .11765 Mdot
.59216 .56863 Mdot
.73333 .7098 Mdot
.87059 .87843 Mdot
.52157 .21961 Mdot
1 .94902 Mdot
.81176 .43529 Mdot
.82745 .73333 Mdot
.36863 .33725 Mdot
.52157 .49412 Mdot
.92941 .90588 Mdot
.95294 .9098 Mdot
.76863 .51765 Mdot
.80784 .46667 Mdot
.47059 .42745 Mdot
.15294 .13333 Mdot
.33333 .1098 Mdot
.93725 .42745 Mdot
.92549 .4549 Mdot
.94902 .49804 Mdot
.97647 .53725 Mdot
.95294 .41176 Mdot
.52941 .24706 Mdot
.19216 .18824 Mdot
.14902 .14902 Mdot
.15294 .14902 Mdot
.16471 .1098 Mdot
.62745 .60392 Mdot
.6902 .65882 Mdot
.86667 .87451 Mdot
.51373 .21176 Mdot
1 .96863 Mdot
.83137 .42353 Mdot
.86275 .8 Mdot
.34902 .30196 Mdot
.38431 .35686 Mdot
.91765 .89412 Mdot
.93725 .89412 Mdot
.72941 .47843 Mdot
.81569 .48235 Mdot
.29804 .24314 Mdot
.23137 .2 Mdot
.32941 .07451 Mdot
.95294 .41176 Mdot
.94902 .43137 Mdot
.91373 .41569 Mdot
.92157 .43529 Mdot
.95294 .4 Mdot
.43137 .19608 Mdot
.15294 .14902 Mdot
.16078 .16863 Mdot
.16078 .15294 Mdot
.17647 .12157 Mdot
.58431 .56863 Mdot
.20392 .17255 Mdot
.87059 .87059 Mdot
.5098 .21176 Mdot
.85098 .72157 Mdot
.85882 .49412 Mdot
.89804 .8549 Mdot
.31373 .26667 Mdot
.25882 .21569 Mdot
.93725 .90196 Mdot
.59216 .53725 Mdot
.95294 .72941 Mdot
.57255 .32941 Mdot
.27843 .23529 Mdot
.39608 .36863 Mdot
.47059 .09412 Mdot
.93725 .39608 Mdot
.93725 .40392 Mdot
.94118 .40784 Mdot
.93725 .4 Mdot
.92157 .35686 Mdot
.23922 .09412 Mdot
.12941 .13725 Mdot
.22353 .23137 Mdot
.14902 .14902 Mdot
.59608 .54902 Mdot
.35294 .32941 Mdot
.45882 .43922 Mdot
.86275 .87059 Mdot
.83137 .45098 Mdot
.62353 .34902 Mdot
.79608 .48235 Mdot
.77647 .71373 Mdot
.7098 .65882 Mdot
.73725 .6902 Mdot
.95294 .91765 Mdot
.58039 .51373 Mdot
1 .75686 Mdot
.29412 .14902 Mdot
.25098 .21176 Mdot
.54902 .5098 Mdot
.85098 .37255 Mdot
.93725 .38431 Mdot
.9451 .39216 Mdot
.9451 .39216 Mdot
.94118 .38039 Mdot
.92941 .36471 Mdot
.21176 .14118 Mdot
.15294 .17647 Mdot
.24314 .26275 Mdot
.12941 .12549 Mdot
.95686 .92941 Mdot
.55294 .52941 Mdot
.73725 .71373 Mdot
.86667 .85882 Mdot
.60392 .21176 Mdot
.88627 .40392 Mdot
.80392 .6549 Mdot
.81176 .71765 Mdot
.6 .55294 Mdot
.94902 .90196 Mdot
.78824 .77647 Mdot
1 .84314 Mdot
.8549 .50196 Mdot
.24706 .20392 Mdot
.27059 .23922 Mdot
.59216 .49804 Mdot
.9451 .39216 Mdot
.95294 .39216 Mdot
.9451 .38431 Mdot
.9451 .38431 Mdot
.93725 .36078 Mdot
.87451 .37255 Mdot
.18039 .17647 Mdot
.27059 .28627 Mdot
.13333 .14118 Mdot
.24314 .21569 Mdot
.88627 .88627 Mdot
.64314 .61961 Mdot
.83922 .80784 Mdot
.9098 .85098 Mdot
.5451 .33333 Mdot
.87059 .37255 Mdot
.87843 .80784 Mdot
.36078 .28627 Mdot
.28627 .23529 Mdot
.38039 .32549 Mdot
.4 .38039 Mdot
.7451 .46667 Mdot
.77255 .4549 Mdot
.24706 .22745 Mdot
.25098 .22353 Mdot
.66667 .41569 Mdot
.94118 .38431 Mdot
.90588 .40392 Mdot
.93333 .38824 Mdot
.93333 .38824 Mdot
.93333 .37255 Mdot
.79216 .45098 Mdot
.18824 .18824 Mdot
.20392 .21569 Mdot
.25882 .24706 Mdot
.39216 .34118 Mdot
.48627 .48235 Mdot
.37255 .32549 Mdot
.88235 .87451 Mdot
.81569 .62353 Mdot
1 .95686 Mdot
.86275 .49412 Mdot
.81176 .7451 Mdot
.44706 .4 Mdot
.3098 .2549 Mdot
.4549 .42745 Mdot
.83922 .77255 Mdot
1 .76471 Mdot
.39216 .23529 Mdot
.27843 .24706 Mdot
.25098 .21176 Mdot
.83137 .38039 Mdot
.92941 .39608 Mdot
.69804 .31765 Mdot
.88235 .37255 Mdot
.90196 .37647 Mdot
.90588 .36078 Mdot
.23922 .10196 Mdot
.14118 .14118 Mdot
.2902 .28235 Mdot
.42353 .40392 Mdot
.71373 .68627 Mdot
.35686 .34902 Mdot
.81961 .76078 Mdot
.86667 .87451 Mdot
.75686 .42745 Mdot
.67843 .38824 Mdot
.8902 .7098 Mdot
.90588 .86275 Mdot
.87059 .82745 Mdot
.89804 .85882 Mdot
.53333 .51765 Mdot
.98431 .78824 Mdot
.85098 .47843 Mdot
.26667 .20784 Mdot
.27059 .23529 Mdot
.27843 .18431 Mdot
.93725 .40392 Mdot
.88627 .47451 Mdot
.77255 .40784 Mdot
.63922 .25882 Mdot
.71373 .30196 Mdot
.84314 .35294 Mdot
.15294 .12941 Mdot
.36471 .35686 Mdot
.38039 .36078 Mdot
.18039 .15686 Mdot
.88627 .88627 Mdot
.89412 .8902 Mdot
.43137 .39216 Mdot
.88235 .86667 Mdot
.56863 .36078 Mdot
.92549 .52941 Mdot
.52157 .47059 Mdot
.48627 .47059 Mdot
.47843 .44314 Mdot
.56078 .53333 Mdot
.23529 .16078 Mdot
.84706 .59608 Mdot
.78824 .49412 Mdot
.23529 .19608 Mdot
.24314 .21569 Mdot
.44706 .09804 Mdot
.92157 .38824 Mdot
1 .87059 Mdot
.5451 .26275 Mdot
.74902 .54902 Mdot
.58824 .3451 Mdot
.77255 .43922 Mdot
.42745 .43922 Mdot
.26275 .25098 Mdot
.16471 .14902 Mdot
.14902 .12549 Mdot
.88235 .88235 Mdot
.8 .7451 Mdot
.87451 .87451 Mdot
.72549 .50588 Mdot
.91373 .78431 Mdot
.96863 .81961 Mdot
.43137 .4 Mdot
.37647 .34118 Mdot
.38039 .35294 Mdot
.40392 .38431 Mdot
.86667 .60392 Mdot
.83137 .46667 Mdot
.29412 .21176 Mdot
.25098 .22353 Mdot
.25098 .19216 Mdot
.92157 .38431 Mdot
.80392 .47059 Mdot
1 .85098 Mdot
.97255 .87451 Mdot
.96863 .85098 Mdot
1 .74118 Mdot
.42353 .35294 Mdot
.23922 .24314 Mdot
.18824 .17647 Mdot
.18431 .16863 Mdot
.9098 .9098 Mdot
.92941 .92549 Mdot
.51373 .46667 Mdot
.87843 .87059 Mdot
.61961 .36863 Mdot
.86667 .50196 Mdot
.37255 .32157 Mdot
.34902 .31765 Mdot
.35686 .32549 Mdot
.3451 .33725 Mdot
.90588 .72549 Mdot
.98039 .72157 Mdot
.80392 .52157 Mdot
.27059 .23137 Mdot
.23529 .21569 Mdot
.48627 .11765 Mdot
.90588 .41176 Mdot
.9451 .8549 Mdot
.87451 .75294 Mdot
.94902 .76078 Mdot
.96078 .85098 Mdot
.79608 .45098 Mdot
.21961 .23137 Mdot
.23529 .22745 Mdot
.18039 .16078 Mdot
.12941 .10588 Mdot
.87843 .88627 Mdot
.66667 .60392 Mdot
.87451 .87451 Mdot
.57647 .3451 Mdot
.63137 .46275 Mdot
.61961 .44706 Mdot
.3098 .21176 Mdot
.29412 .2 Mdot
.28235 .20392 Mdot
.40392 .32941 Mdot
.78431 .49412 Mdot
.92549 .47843 Mdot
.25098 .19608 Mdot
.23922 .21961 Mdot
.27059 .16078 Mdot
.93725 .39608 Mdot
.50588 .36863 Mdot
.54902 .36471 Mdot
1 .8549 Mdot
.9098 .81961 Mdot
.60392 .20392 Mdot
.24706 .22353 Mdot
.25882 .26667 Mdot
.17255 .15686 Mdot
.16863 .1451 Mdot
.88627 .88627 Mdot
.89804 .88235 Mdot
.69412 .67059 Mdot
.90196 .8549 Mdot
.58824 .50196 Mdot
.73333 .33333 Mdot
.88627 .6549 Mdot
.77647 .63922 Mdot
.83137 .62353 Mdot
.55686 .52549 Mdot
.7451 .47451 Mdot
.9451 .55686 Mdot
.68235 .50588 Mdot
.25098 .20784 Mdot
.23922 .2 Mdot
.85882 .40784 Mdot
.81176 .47059 Mdot
.99216 .88235 Mdot
.94118 .85882 Mdot
.78824 .47451 Mdot
.99608 .84706 Mdot
.48235 .24314 Mdot
.21176 .22353 Mdot
.17255 .16471 Mdot
.15686 .15294 Mdot
.50588 .4902 Mdot
.88627 .88627 Mdot
.41569 .37647 Mdot
.87059 .87843 Mdot
.70588 .47451 Mdot
.81176 .43529 Mdot
.87843 .51373 Mdot
.91765 .68235 Mdot
.82745 .55686 Mdot
.95294 .88235 Mdot
.60392 .39216 Mdot
.9451 .55686 Mdot
.77255 .50588 Mdot
.21176 .16863 Mdot
.28235 .25098 Mdot
.62353 .24314 Mdot
.83137 .44706 Mdot
.96078 .86667 Mdot
.93725 .87059 Mdot
.8549 .46275 Mdot
.96471 .83137 Mdot
.77647 .45098 Mdot
.20392 .21176 Mdot
.14902 .14118 Mdot
.14902 .1451 Mdot
.15294 .11765 Mdot
.8902 .8902 Mdot
.52549 .48627 Mdot
.87843 .87843 Mdot
.45098 .25098 Mdot
.72941 .41569 Mdot
.90588 .43137 Mdot
.85882 .52549 Mdot
.78824 .50588 Mdot
.77255 .69412 Mdot
.81176 .60784 Mdot
.95294 .51765 Mdot
.78824 .52157 Mdot
.43922 .39608 Mdot
.27451 .23922 Mdot
.67059 .28627 Mdot
.82353 .47059 Mdot
.98824 .87843 Mdot
.93333 .86667 Mdot
.83137 .4549 Mdot
1 .83137 Mdot
.73725 .43529 Mdot
.22353 .22353 Mdot
.14902 .13333 Mdot
.14902 .13333 Mdot
.17647 .13333 Mdot
.88627 .88627 Mdot
.45098 .39608 Mdot
.87843 .87843 Mdot
.44706 .26275 Mdot
.6 .35686 Mdot
.96078 .42745 Mdot
.8902 .48235 Mdot
1 .72157 Mdot
.54118 .45882 Mdot
.97647 .74118 Mdot
.93725 .4549 Mdot
.77647 .5098 Mdot
.53333 .4902 Mdot
.25882 .22353 Mdot
.69412 .29804 Mdot
.81569 .50588 Mdot
1 .87451 Mdot
.94902 .86667 Mdot
.84706 .49412 Mdot
1 .83529 Mdot
.72157 .43922 Mdot
.23137 .22353 Mdot
.14902 .13333 Mdot
.15294 .13333 Mdot
.21961 .17647 Mdot
.88627 .88627 Mdot
.62745 .56863 Mdot
.87451 .87451 Mdot
.58039 .41176 Mdot
.63137 .3451 Mdot
.97255 .42353 Mdot
.89412 .46667 Mdot
.96471 .67059 Mdot
.32549 .22745 Mdot
.9098 .56863 Mdot
.94118 .42353 Mdot
.51373 .3451 Mdot
.37255 .33725 Mdot
.21176 .17255 Mdot
.9098 .43529 Mdot
.40784 .23529 Mdot
.49804 .32941 Mdot
.97647 .85098 Mdot
.47451 .2549 Mdot
.63922 .27843 Mdot
.36863 .18431 Mdot
.23137 .21961 Mdot
.16078 .14902 Mdot
.1451 .1098 Mdot
.88235 .84706 Mdot
.8902 .8902 Mdot
.58824 .53333 Mdot
.87451 .87451 Mdot
.51765 .38431 Mdot
.9098 .42353 Mdot
.95686 .42353 Mdot
.90196 .48627 Mdot
.8549 .63529 Mdot
.98039 .75294 Mdot
.93725 .46275 Mdot
.92157 .40392 Mdot
.26667 .23922 Mdot
.47451 .43529 Mdot
.27059 .12941 Mdot
.87059 .43529 Mdot
.9451 .87059 Mdot
.98039 .90588 Mdot
.83922 .40392 Mdot
.9451 .8549 Mdot
.88235 .38039 Mdot
.21569 .17647 Mdot
.16078 .15294 Mdot
.17647 .15294 Mdot
.19216 .14902 Mdot
.88627 .88627 Mdot
.93333 .92941 Mdot
.51765 .49412 Mdot
.96078 .88235 Mdot
1 .96863 Mdot
.89412 .36863 Mdot
.95294 .41961 Mdot
.9098 .47059 Mdot
.94118 .65882 Mdot
.93333 .48235 Mdot
.9451 .40784 Mdot
.80784 .52157 Mdot
.26667 .24706 Mdot
.52549 .49412 Mdot
.75294 .33725 Mdot
.36078 .22745 Mdot
.45882 .28627 Mdot
.98431 .84314 Mdot
.47451 .26275 Mdot
.65882 .31765 Mdot
.53725 .31373 Mdot
.22745 .21569 Mdot
.14902 .14118 Mdot
.16471 .12549 Mdot
.45098 .43137 Mdot
.88627 .88627 Mdot
.85098 .81176 Mdot
.88235 .87451 Mdot
.7098 .61569 Mdot
.77255 .42745 Mdot
.92157 .39608 Mdot
.94902 .44314 Mdot
.8902 .49412 Mdot
.9098 .4549 Mdot
.9451 .40784 Mdot
.87451 .39608 Mdot
.28235 .24314 Mdot
.2549 .23137 Mdot
.63529 .39216 Mdot
.45882 .23922 Mdot
1 .87451 Mdot
.94118 .86667 Mdot
.83529 .48627 Mdot
1 .83529 Mdot
.83137 .42745 Mdot
.19608 .18431 Mdot
.15686 .15294 Mdot
.12157 .09804 Mdot
.44706 .41961 Mdot
.8902 .8902 Mdot
.86667 .85098 Mdot
.89412 .8902 Mdot
.5451 .45098 Mdot
.69804 .56471 Mdot
.86275 .43137 Mdot
.91765 .39608 Mdot
.95686 .46275 Mdot
.9451 .4549 Mdot
.94902 .40784 Mdot
.94902 .41569 Mdot
.30588 .22353 Mdot
.25882 .24314 Mdot
.46667 .30588 Mdot
.48235 .24706 Mdot
1 .88235 Mdot
.93725 .87843 Mdot
.80784 .45882 Mdot
.97255 .83922 Mdot
.87843 .40784 Mdot
.16078 .14902 Mdot
.15686 .1451 Mdot
.2549 .24314 Mdot
.33725 .31373 Mdot
.88627 .88627 Mdot
.91373 .91373 Mdot
.8902 .87451 Mdot
.94118 .87059 Mdot
.96471 .89804 Mdot
.76863 .42353 Mdot
.90196 .41176 Mdot
.94902 .42745 Mdot
.96471 .43137 Mdot
.95686 .40784 Mdot
.9098 .41176 Mdot
.30588 .23529 Mdot
.27059 .24706 Mdot
.38431 .13725 Mdot
.95686 .79216 Mdot
.65098 .43529 Mdot
.94118 .86275 Mdot
.45882 .2549 Mdot
.85882 .6 Mdot
.81176 .46275 Mdot
.16471 .16078 Mdot
.20784 .2 Mdot
.45882 .45098 Mdot
.15294 .12549 Mdot
.88627 .88627 Mdot
.69804 .68235 Mdot
.88235 .87843 Mdot
.36863 .29804 Mdot
.84706 .71373 Mdot
.81569 .43529 Mdot
.91765 .38431 Mdot
.95686 .40784 Mdot
.95686 .40784 Mdot
.94118 .40784 Mdot
.3098 .17255 Mdot
.27059 .23529 Mdot
.34902 .19608 Mdot
.7098 .41176 Mdot
.89412 .6549 Mdot
.9451 .87059 Mdot
.58824 .45098 Mdot
1 .79608 Mdot
.82353 .42353 Mdot
.18039 .17255 Mdot
.47843 .46275 Mdot
.21961 .21176 Mdot
.18039 .14118 Mdot
.88627 .88627 Mdot
.90196 .89412 Mdot
.90196 .89804 Mdot
.57647 .50588 Mdot
.93725 .81961 Mdot
.78824 .42745 Mdot
.96078 .41569 Mdot
.92941 .38039 Mdot
.9451 .40784 Mdot
.91765 .43922 Mdot
.21569 .15686 Mdot
.26275 .22745 Mdot
.75686 .37255 Mdot
.82353 .51373 Mdot
.64706 .36863 Mdot
.99216 .85098 Mdot
.98431 .87059 Mdot
.93333 .38431 Mdot
.39608 .2902 Mdot
.48627 .47059 Mdot
.16471 .14902 Mdot
.16471 .16078 Mdot
.95686 .94902 Mdot
.8902 .8902 Mdot
.32941 .30588 Mdot
.8902 .87451 Mdot
.74118 .73725 Mdot
.70588 .50196 Mdot
.92157 .40392 Mdot
.93333 .38039 Mdot
.92157 .37255 Mdot
.9451 .43529 Mdot
.22745 .12157 Mdot
.23137 .19608 Mdot
.74902 .37255 Mdot
.87451 .45098 Mdot
.74902 .36471 Mdot
.9098 .63922 Mdot
1 .78039 Mdot
.92941 .37647 Mdot
.43137 .35294 Mdot
.20392 .2 Mdot
.17255 .15686 Mdot
.16863 .15294 Mdot
.93333 .92549 Mdot
.8902 .8902 Mdot
.40784 .37255 Mdot
.8902 .87451 Mdot
.92157 .91765 Mdot
.83922 .42353 Mdot
.94118 .41569 Mdot
.9451 .42353 Mdot
.89804 .37647 Mdot
.43137 .14902 Mdot
.18824 .1098 Mdot
.34902 .13333 Mdot
.93725 .42745 Mdot
.91373 .41569 Mdot
.78824 .39608 Mdot
.78824 .4549 Mdot
.91765 .4 Mdot
.61569 .43137 Mdot
.16471 .14902 Mdot
.15294 .14902 Mdot
.17255 .15294 Mdot
.38039 .35294 Mdot
.8902 .8902 Mdot
.47843 .43922 Mdot
.88235 .87843 Mdot
.73725 .72157 Mdot
.80392 .45098 Mdot
.94118 .43529 Mdot
.90196 .44314 Mdot
.9098 .43529 Mdot
.55686 .20784 Mdot
.22745 .10588 Mdot
.38431 .07451 Mdot
.93725 .41961 Mdot
.93333 .41961 Mdot
.92157 .4549 Mdot
.88235 .42745 Mdot
.93725 .38431 Mdot
.26275 .18431 Mdot
.16078 .1451 Mdot
.15686 .1451 Mdot
.16078 .14118 Mdot
.96078 .95294 Mdot
.89412 .89412 Mdot
.81569 .76078 Mdot
.89412 .87843 Mdot
.91373 .91765 Mdot
.75686 .43529 Mdot
.84706 .43137 Mdot
.76471 .43922 Mdot
.81569 .4549 Mdot
.65098 .33333 Mdot
.24314 .06667 Mdot
.9098 .44314 Mdot
.94902 .41569 Mdot
.93725 .41961 Mdot
.94118 .42745 Mdot
.93333 .40392 Mdot
.90196 .4 Mdot
.20392 .2 Mdot
.16863 .14902 Mdot
.14902 .13725 Mdot
.15686 .13333 Mdot
.88627 .88627 Mdot
.90588 .8902 Mdot
.56078 .54118 Mdot
.94902 .92941 Mdot
.76471 .69804 Mdot
.6902 .43922 Mdot
.7451 .58039 Mdot
.65098 .47059 Mdot
.65882 .43137 Mdot
.53725 .25098 Mdot
.42745 .0549 Mdot
.95686 .44314 Mdot
.92941 .41176 Mdot
.92941 .41176 Mdot
.95294 .41569 Mdot
.93725 .38431 Mdot
.30196 .18431 Mdot
.16863 .15294 Mdot
.17255 .14118 Mdot
.1451 .12941 Mdot
.89804 .8902 Mdot
.8902 .8902 Mdot
.62353 .58039 Mdot
.88235 .87843 Mdot
.84314 .86275 Mdot
.73725 .60784 Mdot
1 .96471 Mdot
.91765 .8549 Mdot
.58431 .47451 Mdot
.6549 .40784 Mdot
.67059 .30196 Mdot
.93333 .44314 Mdot
.94902 .43922 Mdot
.94118 .41961 Mdot
.94902 .41176 Mdot
.94902 .4 Mdot
.3098 .16471 Mdot
.18039 .16078 Mdot
.17255 .13725 Mdot
.14902 .13333 Mdot
.95294 .9451 Mdot
.89412 .89412 Mdot
.49412 .46275 Mdot
.88235 .87843 Mdot
.96471 .98431 Mdot
.99216 .96471 Mdot
.70588 .63137 Mdot
.67059 .45098 Mdot
.81569 .41176 Mdot
.89412 .41176 Mdot
.95686 .45098 Mdot
.96471 .44314 Mdot
.95686 .4 Mdot
.8 .46275 Mdot
.18431 .13333 Mdot
.14902 .1451 Mdot
.16863 .1451 Mdot
.24314 .22353 Mdot
.89412 .8902 Mdot
.89804 .89412 Mdot
.88627 .88627 Mdot
.39216 .41569 Mdot
.8902 .78824 Mdot
.76078 .49804 Mdot
.78039 .41569 Mdot
.84314 .40784 Mdot
.8902 .41961 Mdot
.92549 .41569 Mdot
.86275 .43137 Mdot
.21176 .11373 Mdot
.05098 .04314 Mdot
.07059 .04706 Mdot
.24314 .23922 Mdot
.90588 .89804 Mdot
.88627 .88627 Mdot
.87451 .87451 Mdot
.39216 .39216 Mdot
1 .95294 Mdot
.85098 .70196 Mdot
.70588 .45882 Mdot
.76078 .41961 Mdot
.80392 .38824 Mdot
.84314 .38431 Mdot
.53725 .30196 Mdot
.4902 .48235 Mdot
.42745 .41961 Mdot
.44706 .44706 Mdot
.56078 .58039 Mdot
.89412 .8902 Mdot
.88627 .8902 Mdot
.9451 .91765 Mdot
1 .96471 Mdot
.93333 .77647 Mdot
.83529 .60392 Mdot
.77255 .46667 Mdot
.72941 .39216 Mdot
.77255 .6549 Mdot
.91765 .90196 Mdot
.90588 .89804 Mdot
.21569 .25098 Mdot
.31765 .33725 Mdot
.89804 .89412 Mdot
.88627 .89804 Mdot
.28235 .27059 Mdot
1 .94902 Mdot
.95686 .83529 Mdot
.81961 .67059 Mdot
.81961 .78431 Mdot
.87451 .86667 Mdot
.60392 .59608 Mdot
.27059 .32157 Mdot
.28627 .32941 Mdot
.8 .80784 Mdot
.78431 .80392 Mdot
.82745 .82353 Mdot
.62353 .60392 Mdot
.2549 .26275 Mdot
.61176 .61569 Mdot
.53725 .58039 Mdot
.6902 .73333 Mdot
.87451 .87843 Mdot
.89804 .9098 Mdot
.95686 .96863 Mdot
.39608 .44314 Mdot
.23922 .28627 Mdot
.9098 .93725 Mdot
.62353 .66667 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
00000=7ooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0coooool000Wo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00003ooooo
ooooo`2booooo`0300000?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<0
0000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oooooo
ooooooooo`/0000000<06ATI000000000000W`000004ooooo`0300000?oooooooooo0<oooooo0009
ooooo`0400000?ooooooooooooooo`X00000100I6AVO000000Cooooo00<00000ooooooooool0cooo
ool000Wooooo00@00000oooooooooooooooo2P00000701TI6I`000001?ooool00`00003ooooooooo
o`3?ooooo`002Oooool01000003oooooooooooooool:000000T06ATIVP000004ooooo`0300000?oo
oooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo`/000000`0I6AT4o`0000806ATIV@00
0004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooo``000000P0I
6AT01Ol00000<c<c03<c<`0c<c?o000000806ATIV0000004ooooo`0300000?oooooooooo08_ooooo
0_l00012ooooo`002Oooool01000003oooooooooooooool=000000;o00000P0c<c<5o`0009L00000
1?ooool00`00003oooooooooo`28ooooo`?o000000?oooooo`000?ooool0@Oooool000Wooooo00@0
0000oooooooooooooooo3@0000001@0I6AWo000003<c<`0c<c?o00000080C4a<1?l0002E000000Co
oooo00<00000ooooooooool0Q_ooool2o`0000?ooooo00?oZKgXo`000?l00000@Oooool000Wooooo
00@00000oooooooooooooooo3P0000001@0I6AWo000003<c<ol00000C4a<00Co000000<0<c<co`00
000I6AT0T`000004ooooo`0300000?oooooooooo08?ooooo0ol00002ooooo`CoZKgX00?o0000oooo
ool00000@?ooool000Wooooo00@00000oooooooooooooooo3`000000100I6AWo0000o`000?l00003
06IVIPCo000000<06ATIo`0000000000T0000004ooooo`0300000?oooooooooo083ooooo0ol00002
ooooo`OoZKgX00?o0000ooooool00000@?ooool000Wooooo00@00000oooooooooooooooo3`000000
100I6AWo000003<c<ol0000506IVIP?o0000TP000004ooooo`0300000?oooooooooo07kooooo0_l0
0003ooooo`WoZKgX00Co0000ojVmj?oooooo0000?oooool000Wooooo00@00000oooooooooooooooo
40000000100I6AWo0000o`000?l0000306IVIP<000000ol0002@000000Cooooo00<00000oooooooo
ool0Noooool3o`0000;ooooo3?nY_NP01Ol0003oZKgXoooooooooooo000003kooooo0009ooooo`04
00000?oooooooooooooooa4000000P0I6AT2o`0000D000001?l000000`0I6AWo00000000002<0000
00Cooooo00<00000ooooooooool0NOooool2o`0000?ooooo3_nY_NP01Ol0003oZKgXojVmj?oooooo
000003kooooo0009ooooo`0400000?oooooooooooooooa40000000Co000001TI6Ol0003o00000P00
000309VIV@<000000_l0002>000000Cooooo00<00000ooooooooool0M_ooool3o`0000;ooooo4OnY
_NP01_l0003oZKgXojVmj?nY_NSoooooo`0003gooooo0009ooooo`0400000?oooooooooooooooa<0
000000<06ATIo`000?l000000P00000309VIV@<000000_l0002=000000Cooooo00<00000oooooooo
ool0M?ooool2o`0000;ooooo5?nY_NP00ol0003oZKgXojVmj002ojVmj003o`000?oooooooooo03_o
oooo0009ooooo`0400000?oooooooooooooooa@000000ol000000`000000VIVI09VIV@03o`000080
00000_l0002<000000Cooooo00<00000ooooooooool0LOooool3o`0000;ooooo5_nY_NP00ol0003o
ZKgXojVmj003ojVmj003o`000?oooooooooo03[ooooo0009ooooo`0400000?oooooooooooooooaD0
000000@06ATIo`000?l0000000000_l000001@3<c<co0000o`000?l00000000000?o0000RP000004
ooooo`0300000?oooooooooo06kooooo0ol00002oooooaWoZKgX00?o0000ojVmj?nY_NP00onY_NP0
0ooooooo0000ooooo`0jooooo`002Oooool01000003ooooooooooooooolD00000003o`000000003o
000000Co00000`3<c<`6o`0008T000001?ooool00`00003oooooooooo`1/ooooo`;o00000ooooolL
ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000ooooooooool0>Oooool000Wooooo00@00000oooo
oooooooooooo5`000005o`000080c<c<1ol00028000000Cooooo00<00000ooooooooool0JOooool3
o`0000;ooooo7onY_NP00ol0003oZKgXojVmj003ojVmj003ooooool0003ooooo03Wooooo0009oooo
o`0400000?oooooooooooooooaP000002ol000001000003o0000o`000?l00026000000Cooooo00<0
0000ooooooooool0Ioooool2o`0000?ooooo8OnY_NP00ol0003oZKgXojVmj004ojVmj003ooooool0
003ooooo03Sooooo0009ooooo`0400000?oooooooooooooooaP0000000<06ATIo`000?l000002?l0
0002000000;o0000QP000004ooooo`0300000?oooooooooo06Cooooo0ol00002ooooobCoZKgX00?o
0000ojVmj?nY_NP01?nY_NP00ooooooo0000ooooo`0hooooo`002Oooool01000003ooooooooooooo
oolI0000000301TI6Ol0003o000000Co000000@0ooooo`000?l0003o00000P000002o`0008D00000
1?ooool00`00003oooooooooo`1Rooooo`;o00000ooooolVojVmj003o`000?nY_NSoZKgX00GoZKgX
00?oooooo`000?ooool0=oooool000Wooooo00@00000oooooooooooooooo6P0000000`0I6AWo0000
03<c<`04o`0000050?ooool0003o0000o`00000000001?l00023000000Cooooo00<00000oooooooo
ool0Goooool3o`0000;ooooo:OnY_NP00ol0003oZKgXojVmj006ojVmj003ooooool0003ooooo03Ko
oooo0009ooooo`0400000?oooooooooooooooa/0000000<06ATIo`00000c<c<01?l000000`3ooooo
0000o`000002o`00000300000?l0003o000008<000001?ooool00`00003oooooooooo`1Mooooo`;o
00000oooool[ojVmj003o`000?nY_NSoZKgX00OoZKgX00?o0000ooooooooool0=Oooool000Wooooo
00@00000oooooooooooooooo6`0000000ol000000000o`00000=o`00000301TI6@000000000007l0
00001?ooool00`00003oooooooooo`1Jooooo`?o00000_ooool^ojVmj003o`000?nY_NSoZKgX00So
ZKgX00?o0000ooooooooool0=?ooool000Wooooo00@00000oooooooooooooooo7P00000>o`000003
01TI6Ol00000000007h000001?ooool00`00003oooooooooo`1Gooooo`?o00000oooool`ojVmj003
o`000?nY_NSoZKgX00SoZKgX00?oooooo`000?ooool0=?ooool000Wooooo00@00000oooooooooooo
oooo7`00000;o`00000400000?l0003o000001TI6Gl000001?ooool00`00003oooooooooo`1Eoooo
o`;o00000ooooolcojVmj003o`000?nY_NSoZKgX00WoZKgX00?o0000ooooooooool0<oooool000Wo
oooo00@00000oooooooooooooooo7`000004o`00000500000?l0003o0000o`00003<c<`00_l00000
1000003o0000o`000?l0001o000000Cooooo00<00000ooooooooool0D_ooool3o`0000?ooooo<onY
_NP2ojVmi`03o`000?nY_NSoZKgX00;oZKgX00?oZKgWojVmj?nY_NP01?nY_NP00ooooooo0000oooo
o`0cooooo`002Oooool01000003ooooooooooooooolQ000000?o000000H00000o`000?l0003o0000
0<c<c?l00002000000?o0000OP000004ooooo`0300000?oooooooooo053ooooo0_l00004oooooboo
ZKgX0_nY_NL2ojVmj007ojVlionY_NOoZKgWojVmiol0003oZKgXojVli`04ojVmi`03ojVmj?nY_>Oo
ZKgX00?oZKgX00?o0000ooooooooool0<_ooool000Wooooo00@00000oooooooooooooooo8P000003
o`00000300000?l00000/k>c00?o00000P000004o`0007`000001?ooool00`00003oooooooooo`1=
ooooo`?o00000oooool2ojZmi`CoZKgX0onY_NL00onY_NSoZ[gWojZmi`04ojVmj0;oZKgW7_nY_NP3
ojVmi`GoZKcW0_nY_NL01?l0003oZKcWojVlionY_>L2ojVmi`04ojZki_nY_>OoZKcWojVli`;oZKgX
00?oZKcWooooool00000<oooool000Wooooo00@00000oooooooooooooooo8`000003o`0000030000
0?l0003o000000Co000000@00000o`000?l0003o0000O0000004ooooo`0300000?oooooooooo04_o
oooo0_l00004ooooo`GoZ[gW00?oZKgXojZmionZ_NL00_nY_NL5ojZmi`03ojVmj?nZ_NOoZKgW00?o
ZKgW00?oZKgXojVmionY_NL05OnY_NP6ojVmi`03ojVki_nY_>OoZKcW00?oZKcW00OoZ[[UojZki_nZ
^nKo0000ojZki_nY_>OoZ[WT00CoZ[_V00?oZKcWojZki_nZ^nH00onY_>L00ooooooo0000ooooo`0a
ooooo`002Oooool01000003ooooooooooooooolU000000?o000000<00000o`00002IVIT00P2IVIT0
0`00003o0000o`000002o`00000301TI6@000000000007P000001?ooool00`00003oooooooooo`18
ooooo`?o00000oooool3ojZli`03ojZmionZ_>OoZ[cW00CoZ[gW0_nZ_>L9ojZmi`;oZKgW00?oZ[gW
ojVmionY_NL00_nY_NL00onY_NSoZ[gWojVmj00>ojVmj0KoZKgW1OnY^nH00onY_>OoZ[WTojZii003
ojZji@03ojZki_l0003oZkOR00?oZ[WT0_nZ^nH00on[^>?oZ[_VojZkiP02ojZkiP04ojVlionZ^nKo
Z[_Vo`0003;ooooo0009ooooo`0400000?ooooooooooooooobH000000ol000030000000309VIV@00
0000000000;o000000@0<c<co`00000I6AWo0000N0000004ooooo`0300000?oooooooooo04Gooooo
0ol00004ooooo`WoZ[cW00?oZ[gWojZlionZ_>L00onZ_>L00onZ_NOoZ[cWojZli`09ojZmi`;oZKgW
1?nZ_NL2ojVmj0;oZ[gW00?oZKgXojZmionZ_NL00onY_NL2ojVmj0KoZKgW00?oZKcWojVki_nY^nH0
0onY^nH00onY^>CoZ[WTojZii002ojZii004ojZjiOnZ/mooZkORo`0000;oZkOR00?oZ[WToj^cg_n[
/mh00on[^><2ojZkiP;oZkOR00CoZ[_Vojbhh_oooooo0000<Oooool000Wooooo00@00000oooooooo
oooooooo9`000004o`000080000000<0VIVIo`00000000000_l000000`0c<c?o000001TI6@1h0000
00Cooooo00<00000ooooooooool0@oooool2o`0000;ooooo1OnZ_>H00onZ_>OoZ[cVojZliP05ojZl
i`03ojZli_nZ_>OoZ[cW00SoZ[cW00?oZ[gWojZlionZ_NL01?nZ_NL2ojZli`;oZ[gW00?oZ[cWojZm
ionZ_NL02?nZ_NL00onY_NOoZ[gWojVmi`04ojVmi`GoZKcW0_nY^nH4ojVhi0;oZ[WT00OoZ[7MojZc
gonZ/mooZ[?Oo`000?n[]n;o[:gI00CoZk?N00?oZkSSojfafon]/M/00_n[]n801_n^/M[o[;SRojbh
h_n/^>;oooooo`00033ooooo0009ooooo`0400000?ooooooooooooooobP000001?l000001000003o
00000000001VIVH2o`00000303<c<ol000006ATI07P000001?ooool00`00003oooooooooo`10oooo
o`?o00000_ooool00onZ^nKoZ[cVojZliP03ojZliP;oZ[_V0onZ_>H00onZ_>OoZ[cVojZliP03ojZl
iP03ojZlionZ_>KoZ[cV00GoZ[cW00CoZ[cVojZlionZ_>OoZ[cW0_nZ_NL3ojZli`;oZ[cV0onZ_>L2
ojZmi`03ojZlionZ_NOoZ[gW00OoZ[gW0_nY_NL6ojVli`03ojViiOnY^>CoZKST00?oZKST00?oZK3M
ojZagOnZ/Md00_nZ/Md00onZ/mooZjSDo`000003ojb]f@;oZk?N00Co[JSBojfafon]/M_o[K7K1?n^
/MX01?n/^>;o[k?Looooool0000`ooooo`002Oooool01000003ooooooooooooooolY000000Co0000
00@0000006IVIP1VIVH0IVIV0_l000000`0c<c?o000001TI6@1g000000Cooooo00<00000oooooooo
ool0?_ooool2o`0000?ooooo1?nZ^nH2ojZliP03oj^kiOnZ^nKoZ[_V00;oZ[_V00?oZ[cVoj^ki_nZ
_>H01?nZ_>H00on[^nKoZ[cVojZliP02ojZliP04ojZlion[_>KoZkcVoj^liP;oZ[cV00KoZ[cWojZl
i_nZ_>KoZ[cVojZlion[_>H4ojZliP03ojZlionZ_>KoZ[cW00?oZ[cW00?oZ[gWojZlionZ_>L01?nZ
_NL2ojZli`GoZKcW00CoZK[VojViiOnY^NGoZKWU0_nY^>@01?nX/MooZK3MojV`gOnY/=d2ojZag@07
ojVUd_n[Z=CoZjSDo`000?n[Z=Co[:gIojfObP04ojfXdP03ojfafon`Y/oo/:K?00;o[[7J00Ko/ZW?
ojncg?n_/mco[k?Looooool0000_ooooo`002Oooool01000003ooooooooooooooolZ0000000301TI
6Ol00000<c<c00;o00000P1VIVH01?l00000C4a<o`000?l0000201TI6@03o`0000000000000007<0
00001?ooool00`00003oooooooooo`0kooooo`?o00000_ooool2oj^ki@CoZ[_V1On[^nD2ojZkiP04
oj^kiOn[^nKoZk_Voj^kiP;oZ[cV00CoZk_Uoj^ki_n[^nKoZk_V0_nZ_>H2oj^ki@;oZkcV00CoZk_U
oj^ki_n[^nKoZk_V0_nZ_>H01?n[^nGoZkcVoj^li_n[_>H2ojZliP04oj^li_nZ_>KoZ[cVojZliP;o
Z[cW00?oZ[cVojZlionZ_>L00_nZ_>L00onZ_NOoZ[cWojZli`03ojZli`03ojVlionY^nKoZK_V00?o
ZK[V00?oZKWUojNdh_nX/Ml00onX/Ml00onY/=goYjCCojNTd`03ojVUdP03oj^Xe?l0003oZYW500?o
[Io:0_n]Z=801On_Vl?o/:K?ok2Vcon`Y/oo[[7J00?o/ZW?00Go[k?Lok>^donc[]?oooooo`00000^
ooooo`002Oooool01000003ooooooooooooooolZ00000003o`000000003o000000Wo00000P0I6AUe
000000Cooooo00<00000ooooooooool0>Oooool2o`0000?ooooo1On[^nD00onZ^nKoZk[Uoj^ji@04
oj^ki@;oZk[U0on[^nD01?n[^nKoZk[Uoj^jiOn[^^D2oj^ki@03oj^ki_n[^nGoZk_U00;oZk_U0_n[
^^@3oj^ki@03oj^ki_n[^nGoZk_U00?oZk_U00?oZkcVoj^kiOn[^nD00on[_>H00onZ_>KoZkcVoj^l
iP03ojZliP;oZ[cW0_nZ_>H00onZ_>OoZ[cVojZliP03ojZkiP03ojVki_nX^NGoZ;WU00?oYkOT0_nW
]>82ojRag`03ojFWf?nWY=?oYjCC00;oYjCC00CoZJGBojNEa?nZVLGo00000_nZVLD2ojfObPCo[i_3
00?o/:K?ok>L`?ncW<000onbZLl4ok>^d`03o`000?oooooooooo02cooooo0009ooooo`0400000?oo
ooooooooooooobd000000ol000000`1<C4co0000o`00000203<c<`04o`00000I6AT06ATI01TI6G@0
00001?ooool00`00003oooooooooo`0fooooo`?o00000oooool00onZ^^GoZk_Uoj^ki@03oj^ki@Go
Zk[U00?oZk_Uoj^ji?n[^^D00on[^^D00on[^nGoZk[Toj^ji002oj^ji@03ojbji?n[^^CoZk[T00;o
Zk[T00?oZk_Uojbji?n[^^@00on[^^@00on[^nGo[;[Toj^ki@04oj^ki@03oj^ji?n[^nGoZk_U00;o
Zk_U00?oZkcVoj^kiOn[_>H00on[_>H00onZ_>KoZk_Voj^kiP02ojZliP03oj^kiOnZ_>KoZ[cV00;o
Z[cV00?oZ[_VojVji_nX^ND00onX^ND00onW]nCoY;7Roj>/g@02oj>/g@?oYJOH0_nWY=<01OnSU/Oo
YiG4ojNEa?nWULCo000000;oZYW500?o[Io:ojfB^_n]T[X00_n_Vl<00onbTKCo/ic0ok>L`002ok>L
`003ok:YcongX/?o]j;300;o/jkC00?o^Z_:ooooool00000;Oooool000Wooooo00@00000oooooooo
oooooooo;P0000000`0I6AWo0000o`00000503<c<`04o`00000I6AT06ATI01TI6G<000001?ooool0
0`00003oooooooooo`0cooooo`?o00001?ooool4ojZji@;oZk_U1_n[^^D4oj^ji0;oZk[U0on[^^@2
ojbih`?o[;[T0_n[^^@01?n/^N?o[;[Tojbji?n/^^@2oj^ji004ojbihon/^^Co[;[Tojbji0;oZk_U
00Co[;[Toj^ji?n[^^CoZk[T0_n[^nD2ojbji0;oZk_U0_n[_>H2oj^ki@03oj^ki_n[^nGoZk_U00?o
Zk_U0_nZ_>H01?nZ^nGoZK[VojVji_nY^^H2ojRii@04ojJfi?nT/N;oY;7RojBahP?oXjcM00?oYJOH
oijJconSU/L00_nSU/L3ojNEa003o`000?nZVLGoZHbf00?o[I:j00?o[i_3ok:A]?nbTK@01?ncW<03
okNR``05ok>^donjZl[o^Z_:okZ[b_l00000;Oooool000Wooooo00@00000oooooooooooooooo;P00
00000ol000006ATIo`000002o`0000@0<c<c00Co000001TI6@0I6AT06ATI5000000701TI6@<00000
00?o0000000000000000<`00000;o`0001<000001?ooool00`00003oooooooooo`0aooooo`;o0000
1?ooool6ojZji@;oZk[T1?n[^^D3oj^ii0?oZk[T0on[^N<00on[^^Co[;WSojbih`03ojbih`03ojbj
i?n/^N;o[;WR00?o[;WS00?o[;[Tojbih_n/^N800on/^N<00on/^^Co[;WSojbih`03ojbji006oj^j
i?n/^^?o[;[Sojbjhon/^^Co[;WS1?n/^^@00on[^nGo[;[Toj^ki@04oj^ki@03oj^ji?nZ^nGoZ[_U
00;oZ[_U00?oZK[VojRiiOnV]^@00onV]^@2ojBahP;oXjcM00CoVj7IoijJconNV/ooWY[?0onSU/L2
ojNEa003ojV<]_l0003oZHbf00?o[I:j1?nbTK@2ok>L`0;o^IJd0_ngX/<3okZ[bP03ol>/`ooooooo
000002cooooo0009ooooo`0400000?oooooooooooooooc0000000`0I6AT01Ol00000<c<c03<c<`0c
<c?o000000<06ATI5000000;01TI6C@0000000?o000001TI6@0I6AT02@0I6AT2o`00014000001?oo
ool00`00003oooooooooo`0^ooooo`?o00001?ooool9ojZji@;oZk[T00?oZk[Uoj^ii?n[^N@00_n[
^N@6oj^ih`03ojbhh_n/^N?o[;WS00?o[;WS00?o[;SRojbih_n/^N800_n/^N800on/^N?o[;SRojbi
hP03ojbihP03ojbihon]^>;o[;WS00?o[;WS00?o[;[Tojfih_n]^N800_n/^^<01?n]^N;o[;WSojbi
hon/^N<2ojbji004ojfihon/^^Co[;[Tojbji0;oZk_U00Co[;[Soj^ji?n[^^CoZk[T0_nZ^nD01?nZ
^^CoZ;WUojRiiOnX^ND2ojJfi003oj6bi?nLZ^3oW:[P00CoVj7I0_nNV/l3oj>Fa`04ojNEa?nTR;Oo
Y8Rgo`0000;oZHbf0_n]T[X01On_RJgo/Y6dok:A]?nbTKCo/ic000?o^IJd00Co]j;3oknO^OnoWkWo
^Z_:0oo3[<<00ooooooo0000ooooo`0Zooooo`002Oooool01000003ooooooooooooooolb00000080
6ATI1?l0000401TI6A8000003P0I6ATa00000003o`00000I6AT06ATI00`06ATI0_l0000?000000Co
oooo00<00000ooooooooool0;?ooool2o`0000Gooooo0_nY^^H8ojZji@03ojZii?n[^NCoZkWT00?o
ZkWT1_n[^N<4ojbhhP;o[;WS1?n/^>82ojbihP04ojfhhOn/^>;o[;SRojbhhP;o[;WR00Co[KSQojfh
h_n]^>;o[KSR0_n/^N<2ojfhh@03ojfih_n]^>7o[KSQ00?o[KWR00?o[;WSojfhhOn]^>400on]^N<0
0on/^^Co[KWRojfihP03ojbjh`04oj^ji?n/^^?o[;[Sojbjh`;oZ[[T00?oZ;WUojJgiOnV]nD00onQ
/^@2oibZh0?oVj7I00?oWY[?oi:<bOnKR;h00_nKR;h3ojB8]`04o`000?nYS;KoZHbfojfB^P;o[hV]
0onbTK@4okVF]0?o_ini1?o3[<<00ooooooo0000ooooo`0Zooooo`002Oooool01000003ooooooooo
oooooolc000000T06ATI4@00000@01TI6Bl0000000?o000001TI6@0I6AT03`0I6AT00ol000000000
0000000<000000Cooooo00<00000ooooooooool0:Oooool3o`0000;ooooo1OnY^nH3ojVjiP?oZK[U
00?oZ[[UojZiiOnZ^ND00onZ^N@00on[^NCoZ[WTojZii004oj^ih`;oZkSR1?n/^>82ojbghPCo[;SR
0_n]]n43ojfhh@03ojbhh_n]]n3o[KOP00?o[KSQ00Ko[KSRojfgh?n]]n3o[KOPojfhhOn^]n04ojfh
h@03ojfih_n^]n3o[KSQ00?o[KSQ00?o[KWSojjhhOn]^N800on]^N800on/^^?o[KWRojfihP02ojbj
h`04ojbhh_nZ^>CoZ[STojZhi0?oY[OU00?oXK;ToiV]iOn?X^400_n?X^42ohbEe`?oTXc90_nKR;h3
ojB8]`03o`000?nYS;KoZHbf00?o[hV]0onbTK@4okVF]004ol6F[?noWkWo_iniolVT/P;o`jc30_o=
/kl00ooooooo0000ooooo`0Yooooo`002Oooool01000003ooooooooooooooold00000003o`000000
00006ATI00H06ATI3`0000000ol000006ATI01TI6@0A01TI6@03o`0000000000000002P0000000?o
000001TI6@0I6AT04@0I6AT2o`0000`000001?ooool00`00003oooooooooo`0Wooooo`;o00000ooo
ool2ojRki`CoZK_V1OnY^^H3ojVji@?oZ[WU1_nZ^N@00on[^N?oZkSSoj^hhP03oj^hhP03ojbhh_n/
]n;o[;OR00?o[;OR00?o[;SRojbghOn]]n400on]]n400on]^>7o[KOPojfgh003ojfgh003ojfhhOn^
]moo[[OO00;o[KOP00Co[[KOojjgh?n^]n3o[[OP0_n]^>401?n^]moo[[OPojjgh?n^]n02ojfhh@04
ojjgh?n^^>7o[[SQojjhh@;o[KWR0_n^^>400on]^N;o[[SQojbhhP03ojbhhP03ojZhi?nY]n?oXkCU
00?oXkCU0_nI[ND3ohnRh@;oS9GG0_nBS<T3oi^8_P;oY8Rg00?o0000ojV<]_nYQ:`01?n_RJd00onb
TKCo]hfZokN=ZP02okVF]0;o`IJ/00Co_iniolVT/_o9Y;;o`jc30oo=/kl2ooooo`03o`000?oooooo
oooo02Oooooo0009ooooo`0400000?ooooooooooooooocL000001P0I6AT@000001D06ATI:@000000
0ol000006ATI01TI6@0601TI6@Oo00001P0I6AT00ol00000000000000009000000Cooooo00<00000
ooooooooool09?ooool3o`0000?ooooo1OnX^nL00onY^nKoZ;_WojVjiP05ojVjiPCoZK[U00?oZ[WU
ojViiOnZ^N@01?nZ^N@01?nZ^>?oZkSSoj^hhon[^><2oj^hhP03oj^gh_n/]n;o[;OR00?o[;OR1?n/
]n42ojfgh@03ojffh?n]]n3o[KOP00?o[KOP0_n^]]l00on^]moo[[KNojjfgP03ojjfg`03ojjgh?n_
]]ko[kKN00?o[[OO00?o[[OPojnfg_n_]]h00on^]n000on^^>7o[kOOojngg`02ojjhh@04ojnggon^
^>7o[[SQojjhh@;o[;SR00Co[KOQojVghonY]n?oZKOS0_nS]>D00onP/^GoSZWWohjYi`03ogVGi0;o
LHGH0onBS<T2oi^8_P;oY8Rg00Co0000ojV4[?nYQ:coZHB/0on_RJd3okN=ZP04okVF]?o1UZco`IJ/
ol6F[0?obJBb00Ooek2`olfc_oo=/koocK>oom[1`?oooooo000002Wooooo0009ooooo`0400000?oo
ooooooooooooocT000001@0I6AT00ol0000000000000000<000001H06ATI9`0000000ol000006ATI
01TI6@0401TI6@?o00001`0c<c<3o`0000@06ATI00?o000000000000000020000004ooooo`030000
0?oooooooooo02;ooooo0_l00004ooooo`03ojRlj?nX^nOoZ;_W00OoZ;_W0_nY^^H01?nX^^KoZK[V
ojVji_nY^^H2ojVji@CoZKWU00?oZ[WTojVhi?nY^>@00onZ^><3oj^hh`?oZkOR00?o[;ORojbghOn/
]n401?n/]n45ojffh006ojfgh?n]]]oo[KKOojffgon^]]oo[[GN1?n^]]h00on^]]oo[kGMojnfgP03
ojnfgP03ojjggon_]]go[kKN00?o[kKN00Co[[OPojnfg_n_]]ko[kOO0_n`]]h3ojngg`03ojjhhOn_
]moo[kOO00?o[KOQ00?oZKOSojVfh_nY]^800onP/^D2ohjYi`?oNIOT00CoLHGHogemb?mmOLSoOGg8
0_nAOKX2oj1o/004o`000?nYQ:coZHB/ojV4[0;o[hV]00Co/hNVokN=Z_ngSJ[o]hfZ1?o1UZ`3olVT
/P;oek2`00?ocK>oom[1`?oJ`L000_ooool00ol0003oooooooooo`0Vooooo`002Oooool01000003o
oooooooooooooolk000000@06ATI00?o00000000000000002`00000G01TI6@03o`00000000000000
0280000000?o000001TI6@0I6AT00`0I6AT2o`0000d0<c<c00?o000001TI6@0I6AT00P0I6AT2o`00
00P000001?ooool00`00003oooooooooo`0Oooooo`?o00001?ooool4ojRlj0[oZ;_W0_nX^^H01?nY
^^KoZ;[VojRji_nX^^H6ojVii@;oZKST0onZ^><3oj^hh`?oZkOR1?n/]n42ojbfh0Co[KKP0_n]]Ml2
ojffg`Co[[GN0_n^]]h01?n_]=go[kGMojnegOn_]Md2ojnfgP04ojnegOn_]]go[kKMojnfg@;o[kKN
00Co/;GMojnfg_n_]]ko[kKN1?n`]]h00on_]moo/;KMojngg`03ojngg`03ojfghOn^]]ooZKKR00?o
ZKKR00?oX;;Uoijai_n3YNX00_n3YNX2oeR:iP;oLHGH0_mmOLP3oi5m^P03oj1o/?l0003oX7n`00;o
ZHB/00Co[hV]ok>7Y_ncQjKo/hNV0_ngSJX00onoT:Go`IJ/ol6F[002olfNZ004olVT/_oG/;3oek2`
omN`/0?of/7000Coi]?4oooooooooooo00009oooool000Wooooo00@00000ooooooooooooooooC@00
000J01TI6B80000000?o000001TI6@0I6AT00`0I6AT00ol00000<c<c03<c<`0303<c<`Ko0000100c
<c<00ol000006ATI01TI6@0201TI6@03o`0000000000000000H000001?ooool00`00003ooooooooo
o`0Looooo`?o00000_ooool6ojRlj0;oYkcX0onX_>P00onX^nOoYkcXojNlj003ojNki`03ojRkionW
^nOoZ;[W00?oZ;[W00?oZ;[VojNjionX^NH00_nX^NH2ojVii@04ojRiiOnY^>CoZKSTojVhi0?oZ[SS
00?oZkSSojZghonZ]n<00on[]n800on/]n7oZkKQoj^fh@03ojbfh0Co[KGO0_n]]Mh4ojjegP;o[[CM
0on_]=d00on_]Mgo[kCLojndg003ojneg@03ojnfgOn`]=co/;GM00?o/;GM00?o[kKNok2eg?n`]M`0
0_n`]]h01?na]Mco/;KMok2fgOn`]]d2ojngg`04ok2fgOn^]]oo[[KOojjfg`;oZKKR00CoZ[GQoija
i_nN/NKoW[7V0on3YNX00omHR^Ko>fgHoc]]f003ogemb0;oTGfj00?oX7n`o`000?nPOk000_nYQ:`4
ok>7YP03okN=Z_noT:Go_i2U00;o`IJ/0_o=WZP01_o9Y;;oek2`omN`/?oG/;3ojLBaom[1`0;oi]?4
00?ojnO;ooooool000009oooool000Wooooo00@00000ooooooooooooooooC@00000K01TI6B400000
00?o000001TI6@0I6AT00P0I6AT00ol00000<c<c03<c<`0303<c<`03o`00001<C4`0C4a<00@0C4a<
0_l0000303<c<`03o`00000I6AT06ATI00806ATI00?o00000000000000001@000004ooooo`030000
0?oooooooooo01[ooooo0_l00003ooooo`;oZ;_W1?nX_>P5ojNlj003ojRlj?nW_>SoYkcX00?oYkcX
00?oYk_WojNkj?nW^nL00_nW^nL2ojRji`CoYk[W00?oZ;WVojNii_nW^NH00onX^ND00onY^>CoZ;SU
ojRhi@03ojVhi003ojZghonY]n?oZKOS00?oZ[OR0on[]^43ojbfh003ojfegon/]Moo[KGN00?o[KGN
00?o[[GNojjdgOn^]=d00on^]=d00on_]=go[kCLojndg003ojndg003ojnegOn`]=co/;CL00;o/;CL
0_n`]Md2ok2df`03ok2eg?na]=_o/KCK00?o/KGL00?o/;KMok6eg?na]M`00on`]]d00on^]]oo[kKN
ojZeh@03ojZeh@03oijai_nN/NGoO:C/00;oO:C/0_lbNnD01?lkKMSoD6O;oe1Wbom@Il/2oi5m^P04
oj1o/?l0003oX7n`ojV4[0;oZh:X0oncQjH01OngSJ[o_i2Uokn@YOnoT:Go`IJ/00;ocIjX0ooG/;02
onW4/@?oi]?400CojnO;onCceOoooooo00009_ooool000Wooooo00@00000ooooooooooooooooCP00
000K01TI6Al0000000?o000001TI6@0I6AT00`0I6AT00ol00000<c<c03<c<`0203<c<`03o`00001<
C4`0C4a<00L0C4a<00Go000003<c<`0c<c<0<c<co`00000401TI6@03o`0000000000000000@00000
1?ooool00`00003oooooooooo`0Gooooo`?o00000oooool2ojN_gP?oZ;_W00?oZ;cXojNgi?nW_>P0
2onW_>P3ojNkj003ojNkionV^nSoY[_X00CoYk[W0_nV^^L3ojNiiP03ojRiiOnW^NKoYkWV00?oZ;SU
00?oZKSTojRhiOnY]n<00onY]n<00onZ]n;oZKOSoj^fh@03oj^fh@03ojbfh?n[]^7o[;GO00;o[;GO
0on]]Mh6ojjdg@Go[kCL1On`]=`5ok2df`Co/KCK00?o/KGLok6dfona]M`00ona]M`00on`]]go/KGL
ojnfgP02ojnfgP;oZ[GQ0_n[]Ml2oijai@?oO:C/00?o<W_Uo`10`ol0@<<00_m@Il/2ogab_@;o0000
00CoVW^`oj^2Z?n[PZSoZh:X0oncQjH4okn@Y@?ocIjX00?og[2WomN`/?oYa;400_oYa;400oogh;7o
i]?4on_Wb`02onCce@03omKci?oooooo000002Gooooo0009ooooo`0400000?ooooooooooooooodh0
0000700I6AT00ol0000000000000000K00000003o`00000I6AT06ATI00<06ATI00Go000003<c<`0c
<c<0<c<co`00000404a<C0Co00000`1<C4`01Ol00000<c<c03<c<`0c<c?o000000@06ATI00?o0000
0000000000000`000004ooooo`0300000?oooooooooo01Kooooo0_l00003ooooo`03ojVUdonW[mko
YjoN00;oYjoN00?oZ;_WojFPd?nUX=000_nW]n@2ojNlj0;oY[7O0onW_>P3ojJkj0;oYkcX00?oYk_X
ojJkj?nV^nP00onV^nP01?nW^^OoY[_XojJkj?nV^nP2ojJji`03ojNii_nV^^OoYkWV00?oYkWV00?o
Z;SUojNii_nX^>D00_nX^>D2ojVgh`04ojRgi?nY]n?oZKOSojVgh`;oZkKQ00GoZ[KRoj^fhOn[]^7o
ZkKQojbeg`02ojbeh0?o[KGN00?o[[CMojfdg_n]]=h00on^]=d3ojndg0Co/;CL1_n`]=/2ok6dfP;o
/KCK00Co/[CJok6dfona]=_o/KCK0_na]M`01Onb]=_o/KGLok6eg?na]Mco[kKN00?o/;GL00?oZkGO
ojfeg_nQ/^@00onQ/^@2ogjVk@03oaeehol0@<?o043300?o000000?oO7:mo`000?nJNk000on[PZP3
ok>7YP04ok^<YOnoT:Go_i2Uokn@Y@;ocIjX0_oN/:L00ooG/;3ojLBaonW4/@02ooOP/@03oo7e[OoG
nk3oi??E00;oe_?T00?oa^K^o`000?ooool09?ooool000Wooooo00@00000ooooooooooooooooCP00
000M01TI6Ad0000000?o000001TI6@0I6AT00`0I6AT01Ol00000<c<c03<c<`0c<c?o00000080C4a<
0_l0000406IVIP?o000000<0C4a<o`000?l000000P0c<c<01Ol000006ATI01TI6@0I6AWo000000D0
00001?ooool00`00003oooooooooo`0Fooooo`04o`000?oooooo0000ojjcg0?oZJGC0_nW[mh01?nW
T[ooYJ3@ojFPd?nUX=04oj2;_@03ojJagonKN:_oY:KG00?oY:KG00?oY[_Xoj:Ic?nV^NL00onV^NL0
0onV^nSoYKSVojFkj@02ojFkj@;oY[_X00CoYK_YojFjj?nU^^SoYK[X0_nV^^L2ojNiiP;oY[WW0_nW
^NH00onX^>GoYkSVojNhiP03ojRgi003ojVghonX]nCoZ;OT00?oZ[KR00?oZkKQojZfh_nZ]^800on/
]N000on]]Mko[;GOojfdgP03ojfdgP;o[[CM1?n_]=`00on`]=co/;CKok2df`04ok2df`?o/KCJ1Onb
]=X00ona]=_o/[CJok:df`03ok:df`03ok6eg?nb]M_o/[GK00;o/;GL00Co/KGKojfeg_n]]Mko[KGN
0_nQ/^@00onV/n;oRZc/ohZ/k003o`000006o`0b^_m@Il_oO7:mogab_OnJNk3o00001?n[PZP00onc
QjKo^hbUok^<Y@02okn@Y@;ocIbT00CocIjXomj`YooN/:Oom<jW0_oYa;42ooOP/@08oo7e[Oo7oloo
aoo?omKci?o6i^ko^MG^ooooool0000Tooooo`002Oooool01000003ooooooooooooooom?000001h0
6ATI6`0000000ol000006ATI01TI6@0201TI6@05o`00000c<c<0<c<c03<c<ol000000P1<C4`00ol0
0000IVIV06IVIP0706IVIP04o`00001<C4`0C4a<o`000080<c<c00Go000001TI6@0I6AT06ATIo`00
0004000000Cooooo00<00000ooooooooool05_ooool00ol0003oYL3]ojjcg002ojjcg003ojVUdone
[=3oYi:o00?oYi:o00?oYJ3@ojF0[?nUP:`00onPRkd3oi]hZ`?oY:KG0onRVL`2ojJii`05oij<`?nU
^>KoYKSVojFhi_nU^nT00_nT]^D3ojFkj@03ojFjj?nT^nWoY;_Y00?oYK[X00?oY[WWojBjj?nU^NL0
0onU^NL2ojNhiP03ojRgi?nW^>GoZ;OT00?oZ;OT00?oZ[KRojRghonZ]^800onZ]^800on/]N3oZkKQ
ojbeg`02ojbeg`;o[KCN00Co[KGNojjdgOn^]=go[[CM0on_]=`6ok2df`?o/KCJ2Onb]=X2ok:df`05
ok>df_nb]M_o/[GKok:efonc]MX00ona]M/01?n]]Mko/;GMojJch_nV/n83o`000005oiVaj?mIVo;o
FI_boeVKl_l0<[X00omlL[d00onJNk3o0000oj^2Z002oj^2Z003ok>7Y_nkS:Go^hbU00;o_i2U0_o=
W:@00oo=WZSog[2Womj`Y`02ooC>Y`03onW4/Oogh;7olOF]00;oaoo?00?o`_K_okWEk_nieNh00_ni
eNh00ol0003oooooooooo`0Rooooo`002Oooool01000003ooooooooooooooom?000001l06ATI00?o
00000000000000005`0000000ol000006ATI01TI6@0201TI6@04o`00000c<c<0<c<co`000080C4a<
00?o000006IVIP1VIVH02@1VIVH01?l00000C4a<04a<C?l0000203<c<`05o`00000I6AT06ATI01TI
6Ol000000`000004ooooo`0300000?oooooooooo01Kooooo00Co0000ojG0kOnU`>go[[?L0_nJa_H2
okF/d0?oYi:o0onUP:`3oj2;_@CoVgR[00?oY:KGoiQ/WOnHK9d00_nRVL`4oij<`003ojFhi_nLP[Oo
W8:g00?oY;KU00?oYK_YojBdi?nT^nT00onT^nT00onU^^SoXk_YojBjj002ojBjj0;oYKWW00CoY;[Y
ojFiionU^NOoYKWW0_nW^>D2ojRgi0;oYkSU0_nX]n<2ojZfhP05ojVghon[]^7oZkKQoj^fhOn/]Ml0
0_n[]^43ojfegP03ojjdgOn]]Mko[KGN00?o[kCL00?o/;CKok2dg?n`]=/00on`]=/3ok6dfPOo/[CJ
1Onc]=X01onb]M_o/kGJok>ef_nc]M[o/KGKok>efon`]Md00ol000000onV/n;o[;GOoiVaj002oiVa
j0?oFI_b0_loFlL01_mlL[goVW^`oiYk/?l0003oZh:Xojj7Z`Co^hbU00?o_i2UolfLY?o=W:@00_oN
/:L3ooC>Y`05ooO/V?ogh;7oYoO[ojOgjoo2m^l00_nigO82okWEkP;o//SZ00?o0000ooooooooool0
8Oooool000Wooooo00@00000ooooooooooooooooD000000O01TI6AT0000000?o000001TI6@0I6AT0
0P0I6AT01?l00000<c<c03<c<ol0000204a<C003o`00001VIVH0IVIV0080IVIV0ol0000406IVIP04
o`00001<C4`0C4a<o`000080<c<c00Go000001TI6@0I6AT06ATIo`000003000000Cooooo00<00000
ooooooooool05Oooool01?l0003oooooooooooooool2ohFhmP;oV/Kf0_ne[=000onWT[oo_ZK1ojF0
[003ojF0[003oj2;_OnUMIgoVgR[00?oVgR[0onHK9d00onRVLcoUfFFoiMUUP03oij<`0CoW8:g00?o
Y;KUoiYl/OnJO;400_nT]>@2ojBkj@;oXk?T0_nS^nT00onT^^SoXk[Zoj>jjP03ojBjj@03ojFiionS
^^WoXk[Y00?oYKWW00?oYkSUojFiionW^>D00onW^>D2ojVgh`03oj^fhOnY]n?oZkKQ00?oZkKQ00?o
[KGNojbfh?n]]Mh00on]]Mh00on_]=co[[GNok2dg002ok2dg0;o/;CK0_n`]=`00ona]=[o/KGKok6e
f`04ok:dfP03ok>ef_nc]=[o/kCJ00?o/kCJ1?nc]MX01Ond]][o0000o`000?l0003o/;GM00;o/[KL
0on/]Ml00onI/NSoYKCTojFdi002oh>]l003oihP0?loFlOo?e_700;oVW^`00?o0000ojj7Zon^Qj/0
1?nkS:D3olfLY0;og[2W0oodcZL00oogk9SoPNOYojOgj`02ok;Om`03okWMl_nbbnco//_/00;o//SZ
0_n_`NL00ol0003oooooooooo`0Pooooo`002Oooool01000003ooooooooooooooomA000001l06ATI
600000000ol000006ATI01TI6@0201TI6@04o`00000c<c<0<c<co`000080C4a<00?o000006IVIP1V
IVH00P1VIVH00ol00000Ogmo07moO`02o`000080IVIV00Go000004a<C01<C4`0C4a<o`00000203<c
<`05o`00000I6AT06ATI01TI6Ol000000P000004ooooo`0300000?oooooooooo01Gooooo00Co0000
oooooooooooooooo0onC^?42oab;jP04oek5o?nnY/7o_ZK1okjV`@?oYH2/0onUMId3oi]hZ`?oV6bM
1?nGIIH00onNS<3oUf:Aoib2]`03oib2]`?oVWba1?nJNZh00onS/nCoVW^_oj:ci003oj:ci0;oXk[Z
00?oY;[Yoj:jj_nR^^X00onS^^T00onU^NOoXk[YojFii`02ojFii`;oYkSU00CoY;WWojNhiOnW^>Go
YkSU0_nY]n<2oj^fh@;oZKOS0_n/]^02ojfegP;o[;KP0_n^]Mh01_n`]=co[kGMojnegOn_]Mgo/;CL
ok2fg@Co/KGK00?o/[CJok:efonc]MX00_nc]MX2ok>dfPCo/kGJ0ol000000ond]][o/kGKokBff`04
ok:fg005ojbegon`]]go/;KMojFdi?n]]n000onM]NT01onN803o?e_7ohik^_n>Nk[o[XN[o`000?n^
Qj/01?nkS:D2olfLY0;ohkJW00?og[2WooC>YoodcZL00_ogk9P2ojSJn@04ok;Omon`b^go/<[]ok;;
k0;o[l;W0_n_`NL00on^_^Go0000ooooo`0Qooooo`002Oooool01000003ooooooooooooooomA0000
02006ATI600000000ol000006ATI01TI6@0201TI6@06o`00000c<c<0<c<co`00001<C4co00000`1V
IVH00ol00000Ogmo07moO`0307moO`04o`00001VIVH0IVIVo`000080C4a<00Co000003<c<`0c<c?o
00000`0I6AT00ol00000000000000004ooooo`0300000?oooooooooo01Gooooo00?o0000oooooooo
ool00_ooool01_nC^?7oYKcZojFlj_nU_>[oLJcfoek5o0;o_ZK10_nUP:`01?o:Y[GoYGFMojEeWOnU
MId2oi]hZ`04ojMaU_nHK9goV6bMoiQ/W@CoUfFF0onGHY42oib2]`04oiQRT?nJO;7oVWbaoiYl/@Co
VWZ^0onJNjl2oj:ci005oiao/onQ]>GoXKCUoj6diOnR^^X00_nQ]NL3oj6kj`;oXk[Y00?oYKWWoj:j
j_nR^^X00onT^NL00onW^>GoY;WXojBij003ojNhi@03ojVghonW^>GoZ[OR00?oZ[OR00?o[;KPoj^h
h_n]]]l00_n]]]l2ojneg@04ojjggon`]]go/;KMok2fg@;o/KGK00Go/KKMok:efonb]M_o/[GKok>e
fP02ok:ff`;o/kGJ0ol00003okBffP04okBgfond]]_o];KKokBff`;o/[KL0_nc]m/00on`]]go/kSM
ojfgh002ojfgh0;oWKGY00?oZkSSocmKaon>NkX00_n>NkX00on^Qj_o0000ojj7Z`02ok^<Y@;obIbY
00?ocIbTon>fYooS]ZL00_odcZL2ooO/V0Co[/O/00Go/<[]ok31ion``NOo[l;Wojnni@04ojjni@03
o`000?oooooooooo01oooooo0009ooooo`0400000?oooooooooooooooe4000008@0I6ATG00000003
o`00000I6AT06ATI00806ATI00Ko000003<c<`0c<c?o000004a<C?l0000306IVIP03o`00001oOgl0
Ogmo00@0Ogmo00Co000006IVIP1VIVKo00000P1<C4`01?l00000<c<c03<c<ol0000301TI6@03o`00
0000003ooooo00?ooooo00<00000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`04ojFl
j_nX_NSoZ;gXoj>lj`;o_ZK100?oYH2/olZV]Oo:Y[D00onUMId00onKN:_oYg6FojMaUP02oiQ/W@03
oj]aT_nGIIKoUfFF00;oUfFF0onGHY401_nLP[OoV6:@oiQRT?nHHY3oVWbaoi]TT0CoVWZ^0onJNjl4
oiao/`03oj6diOnNQk_oWXNk00?oXKGW00?oXK_[oingjOnP^n`00onP^n`2oj:jjP03ojBiionR^^[o
Y;WX00?oY;WX00?oYkSUojFjj?nW^>D00_nW^>D2ojZghP05ojRiiOn[^>;oZkSRoj^hh_n]]]l00_n/
^>83ojjgg`03ok2fgOn_]moo/KKM00?o/KKM00Co/[GKok6ggOnb]]_o/[KK0ol00002ok>gf`03okBf
f_nd^=co];SL00?o];OK00?o];KKokBhfonc]m/00_nc]m/01Ond^=co/kSMok>hgOnc^=go[KOP00;o
/[SN0on[^><00oloFlOoSW^johik^P02ojj7Z`03o`000?nkS:GobIbY00;obIbY00KocIbTon>fYooS
]ZOonnBUooC>Yoogk9P2ojg3jP;o[/O/0_n`_nH00on``NOo/;kTojnni@02ojnni@;o[[kU0_n^_ND0
0ol0003oooooooooo`0Nooooo`002Oooool01000003ooooooooooooooomB000002806ATI5@000000
0ol000006ATI01TI6@0201TI6@06o`00000c<c<0<c<co`00001<C4co00000`1VIVH00ol00000Ogmo
07moO`0407moO`04o`00001VIVH0IVIVo`000080C4a<00Co000003<c<`0c<c?o00000`0I6AT00ol0
00000000ooooo`03ooooo`0300000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool4ojRm
j003oj>ljonX_NSobZJe00;obZJe0onUMId3ojMaUP;oV6bM00GoZg6BoiMUU_nGIIKoUfFFok1dT003
oiMRT@CoV6:@00?oVWbaoi]TT?nKI9000_nJNZh2oiiWT@;oVW^_00CoXVbDoiao/onLOk?oW7nc1?nN
Qk/00onQ]NOoX9?6oingj@02oingj@;oX;_/00CoW[W/oinkk?nO^ncoWk_/0_nR^^X2ojBij0;oX[_[
0_nU^^P00onW^>GoYK[XojFjj003ojRii@03oj^hh_nX^^Ko[;SR00?o[;SR00?o[[OOojbihon_]ml0
0_n_]ml2ok6fg@03ok2hgona]mgo/KOM00;o000000Go/[KKok:hgOnb^=go/kOKok>igP04okBhg003
okBgfond^=co];SK00;o];SK00Ko/kOKokBhg?nd^=co];SLok>hgOnd^Md4ok:hgP03oj^hhona^N3o
002600;oSW^j0_n^Qj/00ol0003o^hbUolVLZ@02olVLZ@?ohkJW00ConnBUo`000?n^_nOo[L?Z0_n`
_^@2ok2oiP05ok6mhon`_^Co/;kTok2ni?n__^D00_n__N@2ojjmi@03ojnmi?l0003ooooo01oooooo
0009ooooo`0400000?oooooooooooooooe<000008P0I6ATD00000003o`00000I6AT06ATI00806ATI
00Oo000003<c<`0c<c<0<c<co`00001<C4co000000<0IVIV00?o000007moO`1oOgl0101oOgl01?l0
0000IVIV06IVI_l0000204a<C004o`00000c<c<0<c<co`0000<06ATI00?o0000ooooooooool00_oo
ool00`00003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo0_nX_NP2ojVmj0;oZ;gX0_o:
Y[D3ojEeW@?oYg6F00?oV6bMoj]aT_n[LI800onGIIH01?n`M93oUf:AoiMRTOnGHY44oiQRT0?oVfB@
00GoVWZ^oiiWTOnNIi7oWVNAoiYk[`02oj9/U0?oW7nc1?nNQk/3oj2CaP04oingjOnQX=?oXJ3Coj6P
d`;oW[W/00?oWk_/oifkkOnO_>d00onO_>d00onR^n_oW[c^oj:kj`02oj:kj`?oYK[X00?oZ;WUojFk
jOnX^^H00_nX^^H2ojbhhP05ojVji_n/^N?o[;WSojbihon_]ml00_n]^^<01?n`^=oo0000o`000?l0
0002ok2ih0;o/[SM00Co/K[Pok>ig_nc^Mko/kWN0_nd^=`01Onc^]ko];SLokBhg?nd^=co];SK00;o
]KWM0_nd^=`01?ne^]go];WMokBigOnd^Md2ok:hgP;o];[N00?o/KWPokBkgom?N=/00_m?N=/00on^
Qj_o]9Zmo`000003olVLZ@;ohkJW0_oki:D01?n^_nOo/KgSok6mhon`_^@5ok6mh`03ok2ni?n`_N?o
/;gS00Ko[kgT00?o0000ooooooooool07Oooool000Wooooo00@00000ooooooooooooooooE000000R
01TI6A<0000000?o000001TI6@0I6AT00`0I6AT01?l00000<c<c03<c<ol0000204a<C004o`00001V
IVH0IVIVo`0000H0Ogmo00Co000006IVIP1VIVKo00000P1<C4`01?l00000<c<c03<c<ol0000301TI
6@03o`000?oooooooooo00;ooooo00<00000ooooooooool05?ooool00ol0003oooooooooo`08oooo
o`?oZKgX00?oZ;gXolZV]Oo:Y[D00_nUMId01OoJ[Z_oYg6FojMaU_nWLIKoV6bM00;oZg6B0onGIIH0
1?n`M93oUf:AoiMRTOnGHY44oiQRT0?oVfB@00GoVWZ^oiiWTOnNIi7oWVNAoiYk[`02oj9/U0;oW7nc
0_nVLiT2oij7^`;oZgfQ0_nPTlH3oj6Pd`04ok>L`OnP[=ooX:cOoj2/g`;oWK_]0_nO_>d2oiblk`;o
W[c^00?oX[_[oijmk_nN_Nh00onQ_>`2ojFkj@04ojRji_nU_>WoYKcYojFlj@;oZK[V00?o[;WSojZk
i_nZ^nH00ol000001?n`^=oo[[_Sojjkhon`^N02ojnlh`?o/K[P00?o/kWNok:khOnc^]h00onc^]h0
1?nd^=co];_NokBkg_ne^Md2okBlg`?o]K[M00?o];WMokFkg_ne^mh00_nd^]h01?ne_=oo];_OokBk
gol008H2odmhf`?o]9Zm00Ko0000olVLZOo9W:Woi<Nion>fYooki:D2ok:mhP03ok6mhonb_N;o/KgS
00Ko/KgS0_n`_N<7ojnmi003o`000?oooooooooo01cooooo0009ooooo`0400000?oooooooooooooo
oe<0000000?o000001TI6@0I6AT0800I6ATC00000003o`00000I6AT06ATI00<06ATI00Co000003<c
<`0c<c?o00000P1<C4`00ol00000IVIV06IVIP02o`0000@0Ogmo00Go000006IVIP1VIVH0IVIVo`00
000204a<C004o`00000c<c<0<c<co`0000<06ATI00?o0000ooooooooool00_ooool00`00003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00[ooooo0_nY_NP2olZV]@;oYGFM00GofZj[ojMaU_nWLIKo
Yg6FoiQ/W@02oj]aTP;oUfFF0_n`M902oiMRT@03okMjT?nHHY3oV6:@00;oV6:@0onKI904oiiWT@Co
XVbD00CoW7ncojIcVOnVLiWoWXNk0on[OJ401?nPTlKo/8^^ok2;[_nQX=<3ok>L`@03oj2/gon`[]Ko
/:kF00?oW[GX00?oW;c_oi^kk_nK_O000_nK_O03oijmkP03oj6lk?nN_^ooX[g]00;oX[g]0_nU_>T0
0onR_^goY[gZojJmjP03o`000006ojJnj_n[_>OoZkcWoj^lion^^n?oZkkW1?n__><00ona^^3o[kgT
ok:kh@02ok:kh@;o/k[N0_nb_>400ond^mko/kgRokBlg`03okBlg`05okFjgOnd_N3o];gPokFkg_nd
_^401?ne_=l01?nd^moo];gPodmhfom?N=/3okBJ_@08olVLZOl0003oi<NionC7^OoS]ZOonnBUok:m
h_nc_^83ok:mhP03ok6mhonb_^?o/[kS00;o/KgS00Go/KkSok2mhon`_N?o/;gSojnmi002ok2ni0;o
[kgT00?o[kkUo`000?ooool07Oooool000Wooooo00@00000ooooooooooooooooE000000S01TI6A<0
000000?o000001TI6@0I6AT00`0I6AT01_l00000<c<c03<c<ol00000C4a<o`0000@0IVIV0_l00000
0`1oOgoo000006IVIP0306IVIP04o`00001<C4`0C4a<o`000080<c<c00Go000001TI6@0I6AT06ATI
o`000004ooooo`0300000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool3ojVmj004olZV
]OnUMIgofZj[omZ^Z`?oYg6F0on[LI82oiMUUP;o/7B@0_nGHY401OngNY3oV6:@oiQRT?nHHY3o_h6@
00?oVfB@1?nNIi44oj9/U0?oYW>I1?n[OJ43ok2;[PCo/ic11?n`[]H00onN]NSoYk[VojNjiP02oi^k
kP03oi^ml?nI__7oVKka00?oV[ka0_nN_^l01?nR_NgoWKo`oifol?nM_o03o`000003oj:ok_nV_^[o
Y[kZ00;oY[kZ00?oZkcWojNojon[_^L00_n[_^L2ojnlh`05ojboion__NCo[kgTojnmi?nb^n400on`
_^@00onb_>7o/KoUok>mhP02ok>mhP;o];cO0_nc_^800ond_N3o/koSokBnh@02okBnh@;o]KcO0_nd
_^801?nd_N3o];oRokBnhOm?N=/3okBJ_@04o`000?oTakWoi<NiojkVS0Co/kkR00Go/[gRok>nhonc
_^?o/[kSok:oh`04ok6nh`05ok2mhona_^Co/KkTok2ni?n`_^D01?n__^D00ol0003oooooooooo`0K
ooooo`002Oooool01000003ooooooooooooooomE000002<06ATI4`0000000ol000006ATI01TI6@02
01TI6@04o`00000c<c<0<c<co`000080C4a<00?o000006IVIP1VIVH00`1VIVH00ol00000IVIV06IV
IP0406IVIP03o`00001<C4co00000080<c<c00?o000001TI6@0I6AT00P0I6AT01Ol0003ooooooooo
ooooool0000001Kooooo00?o0000ooooooooool02oooool3ojVmj003ojEeWOoJ[Z_ofZj[00?oYg6F
0on[LI82oiMUUP;o/7B@0_nGHY401OngNY3oV6:@oiQRT?nHHY3o_h6@00?oVfB@1?nNIi44oj9/U0?o
YW>I1?n[OJ43ok2;[P05oo7H]oncW<7o/ic1ok>L`OoShm<00_n`[]H2olONjP03ojNji_n]dO?oW[o_
00?oW[o_0_nI__400onJ__7oV;ocoiRol`02oiZolP?o00000onM`?42oj:okP;oY[kZ0_nS`Nh2ojNo
j`04oj^nionX`N_oZ<7[ojS1j`;o[;oW00?o[kgTojg0j?n]`>P00_n`_^@01On^`NSo/KoUok6oiOna
_nGo/kgR00;o/L7U0_nc_^801Ona`^Ko/koSok>ohonc_n?o];kQ00?o/l3T00?o];kRok?1i?nd_n80
0_nd_n801ond_^7o]9ZmokBJ_OnNh_goi<Nio`000?oTakT00_nd_n<2ok>nhP;o/l3S00?o/kkSok;0
i?nb_n<00_nb_n<2ok6nh`;o/KoT00?o/KkTok2oiOn`_^D00_n`_^D4ojnni@03o`000?oooooooooo
01[ooooo0009ooooo`0400000?oooooooooooooooeH000008`0I6ATB00000003o`00000I6AT06ATI
00<06ATI00Co000003<c<`0c<c?o00000P1<C4`00ol00000IVIV06IVIP0806IVIP;o000000D0C4a<
o`00000c<c<0<c<co`00000401TI6@05o`000?ooooooooooooooo`0000005_ooool00ol0003ooooo
ooooo`0=ooooo`;oZKgX0_oJ[Z/2ojMaUP05onbmX_n[LI;oZg6Boj]aT_nGIIH00on`M902oiMRT@05
okMjT?nHHY3oV6:@oiQRT?noPI000onKI903oiiWT@03om:ETonRK9CoXVbD00;oXVbD0onVLiT3oj]m
X@;olLFT00Ko/8^^oo7H]ooaf;OolMRgok>L`OoShm<3oh_]g003olONj_nLg_goW=km00;o[M7c0_nN
_nl2oik8m@;oVL3c00CoV;oco`000?l0003o00000_nG`O@2oiW1l`03oig0lOnI`_CoVL;d00?oW/;a
00?oXl7^oik3l_nS`^l00_nS`^l2ojS1j`06ojC3l?nY`^coZL;/ojW2k?n]`>SoZL?/1?n^`NP01?na
_nGo[/?Yojk3jOna`ND2ojo4j@?o/L;V00?o/koSok;2i_nb`^H00_nc`>@01Onb`nOo/l7Tok?1i?nc
`NCo];oR00;o/l;U00Oo]<3SoikRoOnNh_goW^;monC7^Ol0003o];oS00;o/l7T0_nc`><01Onb`NGo
//3Tok;0i?nb`>Co/[oS00;o//3U0_na_n@01Ona`>Go/;oUok2oiOn`_nGo/;kU00;o/;oU0_n__^D0
0on__nKo0000ooooo`0Kooooo`002Oooool01000003ooooooooooooooomF00000003o`00000I6AT0
6ATI02406ATI4@0000000ol000006ATI01TI6@0401TI6@04o`00000c<c<0<c<co`000080C4a<0ol0
000506IVIP;o00000`1<C4`01?l00000<c<c03<c<ol0000401TI6@05o`000?ooooooooooooooo`00
00005_ooool00ol0003oooooooooo`0=ooooo`?oZKgX00CofZj[ojMaU_nWLIKok;fR0on[LI801?nG
IIKo/7B@ok1dT?n`M902oiMRT@05okMjT?nHHY3oV6:@oiQRT?noPI000_nKI9001Oo8RY7oWVNAoiiW
TOnNIi7odYFC00?oXVbD00?ogZ>FojIcVOnVLiT00_oY/iX2oj]mX@;olLFT00?o/8^^oo7H]ooaf;L0
0onK__02ohJim`;oK[kn00?oW=kmohc1nOn<`OT00onHc?T00onNb?GoU/Cgo`000002o`0000;oU/7e
0_nG`O@2oiC2mP;oU/;f00?oVL;doiK3m_nF`oH00onI`oD2oik3lP04oj?2konNa??oW/Ccoik4l`;o
Y<?`00?oZL;/ojC5l?nTaO000_nY`n`2ojk1j0;oZ/C]00?o[/?Yoj_5kOn_a>T00on_a>T01Ona`^Ko
[lCZojo4j_nb`^Ko[lGZ00Co//?W00Go/l7Tok;4ionba>Oo/l;Uok;4j004ok?2i@05okC1i?l0003o
//?Vok?1i?nb`nL01?nb`ND01Onb`>Co//;Vok;2i_nb`>Go/L;V00Co/L3U00Go/;oUok30i_n``>Ko
/;oUojo0iP03ojnoiP03ooooool0003ooooo01[ooooo0009ooooo`0400000?oooooooooooooooeP0
00008`0I6ATA00000003o`00000I6AT06ATI00<06ATI00Go000003<c<`0c<c<0<c<co`00000404a<
C0Go0000101<C4`01Ol00000<c<c03<c<`0c<c?o000000@06ATI00Go0000oooooooooooooooo0000
000Eooooo`03o`000?oooooooooo00oooooo0_nY_NP01?oJ[Z_oYg6FojMaU_o/_J83oj]aTP05oiMU
U_n`M93o/7B@ok1dT?nGHY400_ngNY02oiQRT0;o_h6@0_nKI9001Oo8RY7oWVNAoiiWTOnNIi7odYFC
00?oXVbD00?ogZ>FojIcVOnVLiT00_oY/iX01_n[OJ7olLFToo75Y?oaaJCoXKk^oo7H]`;oXKk^00?o
Vkk`oj2okonM_o000_nM_o02oiBnm004ohc1nOnH_o?oV;ocoiRol`?o000000?oUL7eoiC2m_nD`_H0
1OnD`_H4oi?3m`?oU/?f00?oVL?eoiK4monFa?L00_nJa?D2oik4l`;oV/Kf0_nOaO<00onTaO3oX<Oc
ojG6l003ojG6l003oj[4kOnVao7oY/Oa00;oZlG]0_n_a>T2oj_6k@03ojo4j_n/anko[lGZ00;o[lGZ
0_nb`nL2ojo6jP03ok;4ion_a^_o//CX00;o//CX0_nc`^D2ok74j003ok;3i_l0003o//?W00;o//?W
0_nb`ND2ok73i`03ok;2i_na`nOo/L?W00;o/L;V0_na`>D2ok31i`03ok30i_n_`NOo[l3V00;o[l3V
00Co[koVojk0ion^`>Oo00006oooool000Wooooo00@00000ooooooooooooooooF@00000S01TI6@03
o`0000000000000000h0000000?o000001TI6@0I6AT00`0I6AT01Ol00000<c<c03<c<`0c<c?o0000
00`0C4a<00Go000003<c<`0c<c<0<c<co`00000401TI6@05o`000?ooooooooooooooo`0000005Ooo
ool00ol0003oooooooooo`0Aooooo`04omZ^ZonWLIKok;fRonbmXP?oZg6B1?n`M9000onGHY7o]gZ@
okMjT002oiQRT0;o_h6@0_nKI9001Oo8RY7oWVNAoiiWTOnNIi7odYFC00?oXVbD00?ogZ>FojIcVOnV
LiT00_oY/iX01On[OJ7olLFToo75Y?oaaJCoXkk]00;oXKk^0_nR_^d2oj2ok`03oifol?nO_nooWko_
00?oW;oa0_l000000onL`?7oVL3coiW0l`02oiG1m@;oU<;f0_nE`OD2oi?2m`?oTl?g0onB`oP2oi?4
n003oiK4monCaOSoTlGh00;oU/Gg0_nJa_H01?nFa_SoVlOfoi_7m_nKaoH2oj37l`;oYLK`0_nQb?@0
0onVao7oX/SdojO8l@02ojO8l@;oZlK]0_nWb?42ojc7kP03ojo5j_n/anko[<O^00;o[lKZ0_n]b>h2
ojo6j`03ok;4j?n_a^_o[lK[00;o/LCX0_n_a^/00onaaNSo0000ok;3i`02ok34j@;o/L?W0_n`a>T0
0ona`nOo[lCYok33j002ok33j0;o/<7W00Go[l;Xojo1ion_`NOo[l7Wojo0iP02ojo1i`04ojk0ion^
`NOoooooo`0001[ooooo0009ooooo`0400000?oooooooooooooooeX000008`0I6ATA00000003o`00
000I6AT06ATI00<06ATI00Co000003<c<`0c<c<0<c<c0ol0000604a<C0?o0000100c<c<00ol00000
6ATI01TI6@0201TI6@05o`000?ooooooooooooooo`0000005Oooool00ol0003oooooooooo`0Boooo
o`03ojMaU_o/_J;ok;fR00?oZg6B1?n`M9000onGHY7o]gZ@okMjT002oiQRT0;o_h6@0_nKI9000oo8
RY7oWVNAoiiWT@02om:ET`;oXVbD0_oNXiH01OnVLiWojK>JonVcV_oY/i[oZgfQ00;olLFT00KoYKk[
ojBnk?nT_^coY;k/oj:nkOnT_^`3oj:okP03oinokonQ_nko000000;o000000?oWko`oic0lOnN`?00
0onK`?83oiS1m003oiG1mOnH`OCoV<7d00;oUL;f00?oTl?goiC3m_nD`oH00onB`oP2oi;4n003oi?5
n?nBaOSoT/Gh00?oTlKh0_nFa_P00onKaoKoUlOhoiO7n002oic8mP;oXLSd0_nMbOH2oj;8m005ojO8
lOnSbOCoXlWdoj?9m?nWb?400_nTb_<2ojS9l@03ojc7k_nYbO7oZLWa00;o[LS^00GoZLW`ojg8k_n]
b>ko[LS^ojo6j`02ojg8k@;o[lK[00Go[LO]ojo6jon_a^_o0000ok34j@02ojo6j`;o/<CY00Go[/G[
ojo4jOn_a>Wo[lCYok33j002ojo3j@03ojo2j?n^`nWo[l;X00?o[l;X00?o[l7Wojk2j?n^`^P00_n^
`NL00ooooooo0000ooooo`0Hooooo`002Oooool01000003ooooooooooooooomK000002806ATI4@00
00000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00<0<c<c1_l0000603<c<`03o`00000I
6AT06ATI00<06ATI00Go0000oooooooooooooooo0000000Eooooo`03o`000?oooooooooo01;ooooo
00?oYg6FonbmX_o/_J800on[LI84ok1dT003oiMRTOngNY3o]gZ@00;oV6:@0_noPI02oi]TT003olR:
TOnNIi7oWVNA00;odYFC0_nRK9@2omjSUP04ojIcVOoY/i[ojK>JonVcVP;oYkkZ00ColLFTojFnjonU
_^_oY;k/0_nU_^/2ojBnk004oj:ok_l0003o0000o`0000;oXKo^00?oWko`oj6okonQ_nl00_nN`?00
1?nK`?;oWL3aoig0lOnM`?42oi[1lP03oiS1m?nJ`O?oV/7c00;oUl;e0onD`oH00onB`oSoU<?goiC3
m`02oi;4n004oi;5n?nCaOSoTlGhoi?5n0;oTlKi0_nDaoT00onGaoSoULOioiG7n@03oiS8n003oig9
m_nJbOSoV/Wh00;oW/Wf0_nSbO@2oio:mP03ojC:lonPb_GoYL[c00;oYL[c00CoZLWaojK:lonVb_?o
Y/[c0_nYbO001?n]b>koZ/W`oj[9l?n]b>d2oj[9k`?o[LO]00Co[lK[o`000?n]ango[lK[0_n]a^d3
ojk5j`05ojo4jOn^aN_o[/G[ojo3jOn]a>/00on^`nT2ojo2j0;o[/;Y00?o[/;Xojg2jOn]`NP00_n]
`NP00ol0003oooooooooo`0Gooooo`002Oooool01000003ooooooooooooooomK000002<06ATI4@00
00000ol000006ATI01TI6@0401TI6@03o`00000c<c<0<c<c00d0<c<c00?o000001TI6@0I6AT00`0I
6AT00ol0003oooooooooo`02ooooo`0300000?oooooooooo01?ooooo00?o0000ooooooooool04_oo
ool3onbmXP;oZg6B00?ooM2Cok1dT?n`M9000_n`M9000onGHY7o]gZ@okMjT002oiQRT0;o_h6@0_nK
I9000oo8RY7oWVNAoiiWT@02om:ET`;oXVbD0_oNXiH01?nVLiWojK>JonVcV_oY/iX2ojNnjP06ojNn
jOnV_^[oY[kZojJnj_nU_^_oY[k[0ol000001?nU_^coXkk]ojBnk?nT_^`2oj>ok@03oj6okonR_ngo
X[o]00?oX;o_00?oWL3aoj30konM`?400_nM`?400onJ`O?oWL7aoi[2l`03oi[2l`;oUl;e00?oU<?g
oiO3m_nG`oH00_nDa?L2oi?5n0;oULCg0_nCaOP2oi?6n@?oULOi0onFb?T00onJbOSoV<WhoiS9n002
oi_9m`;oWl[f0_nLb_L2oj3:m@03ojG:lonRb_GoX/[e00;oY/[c0_nSb_@2ojK:lP05oj[9l?nWbO;o
YlWboj[9konXbO401?n[b>l01On]ango0000oj_7k_n]a^goZlK^00Co[LK/00?o[/G[ojc5k?n/aN`0
0_n]a>/00on^`nWo[L?Zojg3jP02ojk2j@;o[L;Z0_n]`^T01?n]`NSo[L7Yojg1jOl0000Hooooo`00
2Oooool01000003ooooooooooooooomL000002<06ATI4@000002o`0000D06ATI0ol0000;03<c<`;o
00001@0I6AT00ol0003oooooooooo`02ooooo`0300000?oooooooooo01?ooooo00?o0000oooooooo
ool05?ooool01?o/_J;oZg6Boj]aT_omd9<4ok1dT0?o]gZ@00GoV6:@okn1T?noPI3o_h6@oi]TT002
olR:T@;oWVNA0_oBUI<2oj9/U0;ogZ>F00?oYW>IonVcV_oY/iX00onX_NT2ojNnj@05ojJnj_l0003o
0000o`000?nV_^/00_nU_^`2ojJnj`03ojBnk?nV_^_oY;k/00;oY;k/00?oX[o]ojBok?nT_n`00onR
_nh2oj30k`03oig0lOnO`?3oWl3`00;oWL7a0_nJ`_<2oig1lP;oV/;d00?oUl?foi[2m?nJ`_@00onG
`oH00onEa?OoV<CfoiS4mP02oiK5m`;oU<Kh00CoULOioiK6n?nFa_SoU/Kh0_nFaoP00onHbOSoV<Sh
oiS8n002oi[9n0;oW<[g0_nKbOL2oik:mP03oj;:mOnPb_KoX<[f00;oXl[d0_nQbOD2ojC:l`03ojO9
l_nUbO;oYLWb00;oZ<Wa0_n[b>l2ojS8l003oj_7k_l0003oZLO_00;oZlK^0_n]a^`01?n[aNgo[<G/
ojc5k?n[`n/3ojc4j`03ojg3j_n/`^[o[<;Z00;o[L;Z00Go[<3Yojc2jOn/`^Wo[<;Yojg1j@02ojc1
j@03o`000?oooooooooo01Gooooo0009ooooo`0400000?oooooooooooooooed000008P0I6ATC0000
0003o`00000I6AT06ATI00D06ATI0_l0000503<c<`Co00001`0I6AT00ol0003oooooooooo`02oooo
o`0300000?oooooooooo01;ooooo00?o0000ooooooooool05Oooool01?o/_J;oZg6Boj]aT_omd9<4
ok1dT0?o]gZ@00GoV6:@okn1T?noPI3o_h6@oi]TT002olR:T@;oWVNA0_oBUI<01?nRK9CogZ>FomjS
U_oNXiH3onVcVP?oZ;gY0ol000001?nW_^[oZ;kYojRnjOnX_^T2ojNnjP03ojJnjonW_^[oYkkZ00;o
Y[k[00CoY;k/ojFnjonU_^_oYKk[0_nT_n`00onR_nkoY;o]ojBok@02oj:okP04oio0l?nR_nkoX[o^
oj:okP;oWl3`00?oWL7boio1l?nO`O000_nM`O800onJ`_CoWL;boig2lP03oi[3m003oiS4m_nK`oCo
VLCe00;oVLCe0_nGaOL2oiK6n0;oV<Gg0_nGaoL00onHb?SoVLOgoiW7m`02oi[8m`;oVlWg0_nKb?L2
oig9mP03oj3:m_nObOKoWlWf00;oXLWe00GoX<Sdoj?9m?nSbOCoXlWdojG9lP02ojC8lP;oY/Sa0_nX
b?02ojO7l003ojW7kol0003oZ/C]00;oZ/C]00?oZlG]oj^oj?n[_nP00on[`n/01On/a>_o[;kXojbn
j?n/`^[o[;WS00?o[<3Y0_n/`^T2ojbni`03ojc1jOn/_NKo000001Oooooo0009ooooo`0400000?oo
oooooooooooooeh000008P0I6AT00ol0000000000000000@00000003o`00000I6AT06ATI00H06ATI
1Ol0000:01TI6@03o`000000003ooooo00?ooooo00<00000ooooooooool04_ooool00ol0003ooooo
ooooo`0Eooooo`04onbmX_n[LI;oZg6Boog@T`Co/7B@0ongNY001OnHHY3o_h6@okn1T?noPI3oVfB@
00;ob8ZA00GoWVNAom:ETooBUI?odYFCoj9/U003omjSUP03ojVmj?oY/i[ojK>J00?o000000?oZ;gY
ojRnjOnX_NT00_nX_NT00onX_^WoZ;gYojNnj@02ojNnj@03ojNnj_nW_^WoY[kZ00;oY[kZ0_nU_^/0
1_nV_^[oYKk[ojFnjonU_^_oY;o]ojFnk0?oY;o]0_nR_nh01_nT_ngoX/3^oj;0k_nR`>koWl7`oj;0
kP?oWl7`00?oWL;boj31l?nP`O000onM`_82oi_3m003oiW4mOnL`o?oW<?c00?oV/Ce00?oV<Ggoi_4
mOnKa?D00_nIa_H00onIaoOoVlKeoi_6m@03oi_7mP03oi_8monLaoGoW<Oe00;oWLSf00?oWlWfoio7
mOnOaoD00onPb?@01?nSbOCoX/Scoj;8lonTb?82ojC6l@;oYLKa0_nWao02ojO1k003o`000?nX`ngo
Z/C]00;oZ[WT00?oZkoXoj^Xe?n[]N000on[]N000on/_^SoZjSDojbih`02ojbih`03ojc0jOn//mgo
[;?M00;o[;kW00Go[:oJojbmi_n/_NKo[;gVo`00000Fooooo`002Oooool01000003ooooooooooooo
oomN00000003o`00000I6AT06ATI02006ATI4`000003o`0001806ATI0_l00002000000Cooooo00<0
0000ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`04onbmX_n[LI;ooM2Coog@T`Co/7B@
0ongNY001OnHHY3o_h6@okn1T?noPI3oVfB@00;ob8ZA00GoWVNAom:ETooBUI?odYFCoj9/U003omjS
UP?o00001OnY_NP2ojRmj@;oZ;gX0_nX_NT00onW_^WoZ;gYojRmj@02ojNnj@04ojJnj_nW_^WoYkkY
ojNnj@;oY[kZ00?oYKk[ojJnjonV_^/00_nU_^`01?nT_ngoYKk/ojFnk?nU_^`2ojBok@03oj;0k_nT
_ngoY;o]00;oX/3^00?oWl7`oj;0k_nR`>h00onP`O000onM`_;oX<7`oj31l002oik2lP03oic3lonN
`_7oW/;a00?oW<?c00?oVlCeoig3lonM`o<00_nLa?@00onKa_GoWLCcoig4l`03oic5m003oic7mOnN
aOCoW/Gd00;oW/Kd00?oWlOeoj36lonPa_<00onQao<01OnRb??oX/Kboj;6l_nTa_7oY<;_00?oY/7]
0_nW`N`01_nX]>7oZKCQo`000?nY]>7oZ[WTojZOb`?oZjSD0_n[]N001OnYUL7oZjSDoj^Xe?n[Z=Co
[;WS00;oZic800?o[;?Moj^F`?n/[mX00on/[mX01?n/_NKo[JoIojf_fOl0000Eooooo`002Oooool0
1000003ooooooooooooooomP000002406ATI5P0000000ol000006ATI01TI6@0>01TI6@03o`000000
00000000008000001?ooool00`00003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o
Zg6Boog@Toomd9<00on`M9001?oifG?o]gZ@okMjT?ngNY04okn1T004oi]TT?o8RY7ob8ZAoiiWT@?o
dYFC0_oNXiH2o`0000[oZKgX00?oZ;gXojVmj?nX_NT01?nX_NT4ojRnj@03ojNnjOnX_^WoYkkZ00;o
YkkZ00?oY[k[ojNnj_nV_^/00_nV_^/2ojFnk0;oY[k[0_nU_n`00onT_ngoYKo/ojFok002ojBok@04
oj;0k_nT_ngoY;o]ojBok@;oX/3^00?oX<7`oj;0k_nR`>h00_nQ`O001?nN`_7oXL7_oj71konQ`Nl2
oio2l@03oig3lonP`_7oX<;a00;oW/?b00?oWLCcoj33lOnP`o400onOa?<00onNaOCoX<Cboj34lP02
oio5l`03oj36lonQa?;oXLCb00?oXLGb00?oX/Kboj;3l?nR`o000_nT`^l00onV`NgoY[SVojRdh@03
ojRdh@03ojVdhOl0003oZYo;00;oZYo;00?oZjSDojR;]_nYUL400onYUL400on[Z=CoZHRcoj^Lb002
oj^Lb0?oZiK00_n/[mX01On]UKko[JoIojf_fOn_V/;o000001Gooooo0009ooooo`0400000?oooooo
ooooooooof4000008@0I6ATF000000?o0000300I6AT00ol00000000000000003000000Cooooo00<0
0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03oj]aT_omd9?ooM2C00?o/7B@00Co
nMUcokMjT?ngNY3o]gZ@1?noPI001?nKI93ob8ZAolR:TOnNIi42om:ET`?o000000?ogZ>FojVmj?nY
_NP03?nY_NP00onX_NWoZKgXojVmj002ojRmj@;oZ;kY0_nX_NT2ojRnj@03ojNnj_nX_^WoZ;kY00;o
YkkZ00KoY[k[ojNnj_nW_^[oYkkZojJnjonW_^X3ojJnj`03ojFok?nV_^_oYKo/00;oYKo/0_nT_nd0
1_nU_ncoY;o]ojBokOnT_ngoX/3^ojBok@?oXl3^0_nQ`Nl01_nS`>koX/7_oj;1konR`NooX<;aoj;1
k`?oXL;`00?oX<?aoj;2konR`^l00onQ`o400onPa?;oX/?`oj;3l002oj73l@03oj74l_nR`o3oX/?`
00?oX/?a00?oX/?`oj71konS_N`00_nS_N`2ojJhiP;oZ;CQ00KoYZGDojVMbonYWL_o0000ojZObonX
RK@3ojR;]P;oZIG100GoZ82XojV8/onYR;?oZHRcoj^Lb002ojZ3Z`;oZiK00on]UKh4ojnJ`P03o`00
0?oooooooooo01;ooooo0009ooooo`0400000?ooooooooooooooof80000000?o000001TI6@0I6AT0
7P0I6AT00ol0000000000000000E00000003o`00000I6AT06ATI00H06ATI0ol00006000000Cooooo
00<00000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03oj]aT_omd9?ooM2C00?o/7B@
00ConMUcokMjT?ngNY3o]gZ@1?noPI03olR:T@?o000000CodYFCojVmj?oNXiKogZ>F5OnY_NP00onX
_NWoZKgXojRmj@02ojRmj@03ojRnjOnX_NWoZ;gY00?oZ;kY00?oYkkZojRnjOnX_^T00_nW_^X00onV
_^_oYkkZojNnjP02ojJnj`04ojFok?nV_^_oY[k[ojJnj`;oYKo/00?oY;o]ojFok?nU_n`00_nT_nd0
0onS`>koYKo/ojFok003oj?0kP03oj;1konT`>goY<3]00;oX/7_00CoXL;`oj?1k_nS`NkoX/;_0_nT
`Nh3oj?2k`03oj;3l?nT`NkoXl;_00;oXl;_00?oX/?`oj?2konR`_000onR`_02oj71k`04oj>mk?nK
^^koX;3Soj2`h`CoYZGD00CoZIg;o`000?nXRKCoZ8Vd0onXRkH00onYUL7oZ82XojR0Z003ojV8/`?o
ZX>[00?oZiK0ojf4Z?n]Q:P00_n]UKh01OnbRJ[o[i[2ojnJ`_nhU;;o000001Cooooo0009ooooo`04
00000?ooooooooooooooof<000008@0I6ATH000000So00002@000004ooooo`0300000?oooooooooo
01;ooooo00?o0000ooooooooool05_ooool00oomd9?ooooooog@T`03ok1dT004ooWILongNY3o]gZ@
okMjT0Co_h6@0ol00004om:ET`03ojVmj?oNXiKogZ>F01SoZKgX00CoZ;gYojVmj?nY_NSoZ;gY0_nY
_NP3ojRmj@03ojRnjOnX_NWoZ;kY00;oZ;kY00?oYkkZojRnjOnW_^X00onW_^X00onV_^_oYkkZojNn
jP02ojJnj`03ojFok?nW_^_oYkk[00;oY[o[00CoYKo/ojJojonV_n_oY[o[0_nU_n`00onT`>goYKo/
ojFok002ojC0k@03oj?1k_nU`>goYL3]00?oY<7^00?oXl;_ojC1kOnT`Nd00_nT`Nh00onS`^ooY<7^
ojC1kP02oj?2k`;oX/;`0_nQ`>l2oibnl0;oVk[^0_nP/><2ojJUe004oiZMe_nUSkkoYHnno`0000;o
Z8Vd0_nXRkH4ojR0Z0;oZHRc0onZPj/3ojf4Z004ojfE__nbRJ[o/XVZojnJ`P?o^9Bb00?o0000oooo
ooooool04Oooool000Wooooo00@00000ooooooooooooooooI000000P01TI6BT000001?ooool00`00
003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?ooM2Cok1dT?n`M9000_oifG<2okMj
T003olc1??noPI3o000000;o00000oo8RY43om:ET`;oZKgX0_oNXiHOojVmj003ojRmjOnY_NSoZKgX
00;oZ;gY00?oZ;kYojRmjOnX_NT00_nX_^T2ojNnjP;oZ;kY00?oYkkZojRnjOnW_^X00_nW_^X00onW
_^_oYkkZojNnjP02ojNnjP;oY[o[00KoYkkZojJojonV_n_oY[o[ojFok?nV_n/3ojJok003ojG0kOnV
_n_oY[o[00?oYL3/00?oY<7]ojJok?nV_n`00_nU`>d00onT`NkoYL3/ojG0k002ojC0k@;oXL3_0_nQ
_nh2oiNmlP;oQkKd00?oQZc^oiZMe_nJWMH00_nJWMH2ojF?_P03o`000?nXRKCoZ8^f00;oZGnV0onX
P:P00onYR;?oZgfQoj]mX@02ojZ3Z`03ok5oW_n]Q:So[HBX00?o/XVZ1?nhU;800ooooooo0000oooo
o`0Aooooo`002Oooool01000003ooooooooooooooomV000001l06ATI:0000004ooooo`0300000?oo
oooooooo017ooooo00?o0000ooooooooool06Oooool00oomd9?o/7B@ok1dT002ooWIL`04okMjT?l0
003o0000o`0000?o_h6@0oo8RY43om:ET`?oZKgX00?ogZ>FojVmj?nY_NP08onY_NP00onX_NWoZKgX
ojRnj@08ojRnj@03ojNnj_nX_^WoZ;kY00?oYkkZ0_nX_^T3ojNnjP03ojJojonW_^[oYkkZ00;oY[o[
00GoY[o/ojNnjonW_^_oY[o[ojNnjP04ojJoj`03ojJok?nW_n_oY[o/00;oY[o/00?oYL3/ojJojonV
_n/00_nU_n`2oj6okP;oY;o]0_nH_?42ogBan004oc6@konJWMKoVYgFoiZMeP;oYHnn00?oZ8Vdo`00
0?nYOjH00_nYOjH3ojR0Z0?oZgfQ00?oZX>[ok5oW_naOih00_n]Q:P01?niQYoo/XVZok:9Z_o3TZ<3
okRD/P03olnV[_l0003ooooo017ooooo0009ooooo`0400000?ooooooooooooooofL000007P0I6ATX
000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Iooooo`03oog@Ton`M93o
/7B@00?o000000?o]gZ@olc1??noPI000onoPI03olR:T@?odYFC;?nY_NP2ojRnj@;oZKgX00?oZ;kY
ojVmj?nX_^T03OnX_^T00onW_^[oZ;kYojRnj@02ojNnjP03ojNnjonX_^[oZ;kZ00;oYkkZ0_nV_n/2
ojNnjP;oYko[00GoY[o/ojNojonW_n_oY[o[ojNnjP03ojJoj`;oY;o]00CoY[k[oinmk_nO_NkoWkg^
0_mo]?H00ol0Lm_o?hW[ocn9j`02oi:>c003ojN4[ol0003oYhB_00;oZGnV0onXP:P3oj]mX@03ojZ3
ZonaOiko/GnN00;o[HBX00Co^HJOok:9Z_nbRJ[o`i:S0_nhU;82olnV[P03ooooool0003ooooo013o
oooo0009ooooo`0400000?ooooooooooooooofP000007@0I6ATX000000Cooooo00<00000oooooooo
ool04Oooool00ol0003oooooooooo`0Iooooo`?o00000_oifG<2okMjT005olc1??noPI3o_h6@okn1
T?l000000_o8RY401?nY_NSodYFCom:ETooBUI<cojVmj003ojRnjOnY_NSoZKgX00?oZ;kY0_nX_NT2
ojRnj@03ojVmjOnX_^WoZ;kY00KoZ;kY00?oZ;kZojRnjOnX_^T00_nX_^T2ojNnjP;oZ;kY0_nX_^X0
0onW_n_oZ;kZojRnjP02ojNnjP03ojJojonW_^[oYkkZ00;oY[k[0_nO_Nh2ojFnj`;oU[[a0_m1V_<0
1OloRN_oTXk<ojN4[onWQ:oo000000?oZGnV00?oZ82XojimWon[OJ400_n[OJ44ok5oWP;o^HJO00Go
/XVZol>BXoo3TZ?o`i:SokRD/P02olnV[P?o00004?ooool000Wooooo00@00000oooooooooooooooo
JP00000L01TI6BL000001?ooool00`00003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo
0ol000000ooooooo/7B@ooWIL`02ooWIL`;o]gZ@00Goc<4lokn1T?noPI3o_h6@o`000002olR:T@04
ojVmj?oBUI?odYFCom:ETcWoZKgX00CoZ;gYojVmj?nY_NSoZKgX0_nY_NT00onX_^WoZKgXojVmj00@
ojRnj@03ojRnj_nX_^WoZ;kY00;oZ;kY00?oYkkZojRnjOnX_^T00_nX_^X2ojFnj`;oYkkY0_nS_N`0
1?n7]_CoXKc/oi:>c?nBS/`2ojN4[`05o`000?nYOjKoZGnVojR0Z?n^OIl00on[OJ44ok5oWP?o^HJO
0oo3TZ<3olnV[P03o`000?oooooo0000013ooooo0009ooooo`0400000?ooooooooooooooof/00000
6`0I6ATW000000Cooooo00<00000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`;o0000
1?ooool00on`M93oooooooWIL`02okMjT0;oc<4l0onoPI000ol0003ob8ZAolR:T@02ojVmj003om:E
TonY_NSoZKgX04CoZKgX00?oZ;kYojVmj?nY_NP00_nY_^T00onX_^WoZKkYojVnj@0<ojRnj@04ojVn
jOnX_^WoZ;kYojRnj@;oYkkY00OoZ;kYojNnjOnW_^WoYkkYoj6lk?nW_NWoTXk<00?oYhB_00?o0000
ojUoY_n^OIl00_n^OIl00on[OJ7o]h>LokN3W003ok5oWP?o^HJO0oo3TZ<00oo_`:3ocjJ^ooWQ[002
oh?Sn003o`000?oooooooooo00kooooo0009ooooo`0400000?ooooooooooooooof/0000000?o0000
0000000I6AT0600I6ATW000000Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0B
ooooo`?o00001_ooool00on`M93oooooooWIL`02okMjT003ooooooo<`Cco_h6@00;o_h6@00?o0000
olR:TOo8RY400_nY_NP00ooBUI?oZKgXojVmj01:ojVmj003ojVnjOnY_NSoZKgX00?oZKgX00?oZ;kY
ojVmj?nY_NP00_nY_^T00onX_^WoZKkXojVnj002ojVnj@03ojRnjOnY_^WoZKkY00;oZ;kY0_nW_^T2
ojVnj@03ojNmjOn@0`3oYhB_00;oYhB_00?o0000ojj3Yon^OIl00_n^OIl00on[OJ7o]h>LokN3W003
ok5oWP?o^HJO0_o3TZ<2ono0X005olnV[_oihJcoooooooooool000004?ooool000Wooooo00@00000
ooooooooooooooooKP00000H01TI6BL000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo0ol00009ooooo`03ok1dT?oooooonMUc00;o]gZ@00?oooooolc1??noPI000_no
PI000ol0003ob8ZAolR:T@02ojVmj003om:ETonY_NSoZKgX05KoZKgX00?oZKkXojVmj?nY_NP00_nY
_NP00onY_^WoZKgXojVmj002ojVnj0;oZKkY0_nY_NP01onY_^WoRhc?oh^<con;S<oo[X>Wo`000?n^
PjL00_n^OIl00on[OJ7o]h>LokN3W003ok5oWP?o^HJO00GofJ:Lol>BXoo_`:3okl2Po`001P04oooo
o`03o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooofl00000600I6ATV0000
00Cooooo00<00000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`?o00003_ooool01Ooi
fG?o]gZ@okMjT?ooooooc<4l00;o_h6@00?oooooo`000?o8RY400_ooool00onY_NSodYFCojVmj01V
ojVmj003oi030?n;S<ooRhc?00;o[X>W00?o0000ojimWon^OIl00ongPi`2ok5oWP;oaHjK00Co^HJO
omVRW?oIXYco`i:S0_o_`:05ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?oooooo
ooooooooog4000005P0I6ATV000000Cooooo00<00000ooooooooool04?ooool00ol0003ooooooooo
o`09ooooo`?o00004_ooool2okMjT004ooooooo<`Cco_h6@okn1T0;ooooo00Gob8ZAoooooooooooo
ooooom:ET`1XojVmj0;oRhc?0_n^PjL00ol0003o[WfOojimW`03okN3W0;o/GnN0_o5SY/00oniQYoo
fJ:LomVRW002ono0X0Kooooo00?o0000ooooooooool03Oooool000Wooooo00@00000oooooooooooo
ooooLP00000E01TI6BH000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Ko
oooo0ol0000Eooooo`04okMjT?ooooooooooolc1?0;o_h6@0_ooool00oo8RY7oooooooooo`02oooo
ofWoZKgX0_n;S<l2ojj3Y`03o`000?n^OIoo]h>L00?o]h>L00Co/GnNolF>Voo5SY_o^HJO0_oIXY`2
ono0X0Kooooo00?o0000ooooooooool03Oooool000Wooooo00@00000ooooooooooooooooM@00000B
01TI6BH000001?ooool00`00003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo0ol0000H
ooooo`04okMjT?ooooooooooooooo`;o_h6@0_ooool00oo8RY7oooooooooo`03ooooofSoZKgX00?o
oooooh^<con^PjL00_n^PjL00ol0003o_XnTokN3W002okN3W0?oaHjK0ooIXY`00ol0003okl2Poooo
o`05ooooo`03o`000?oooooooooo00gooooo0009ooooo`0400000?ooooooooooooooogL00000400I
6ATV000000Cooooo00<00000ooooooooool03oooool01?l0003oooooooooooooool3o`0001_ooooo
00Co]gZ@oooooooooooooooo0_noPI02ooooo`03olR:TOoooooooooo00GoooooI?nY_NP4ooooo`?o
[X>W00?o_XnTo`000?ngPi`00_ngPi`3olF>V`?ofJ:L00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0=ooooo`002Oooool01000003ooooooooooooooomf00000003o`0000000000000000d0
6ATI9`000004ooooo`0300000?oooooooooo00oooooo1?l0000Nooooo`05okMjT?oooooooooooooo
oonoPI000oooool00oo8RY7oooooooooo`06oooooeooZKgX2Oooool2ogJjn`03okj?Y?l0003o]h>L
00;o]h>L0oo5SY/2omVRW0;o00001oooool00ol0003oooooooooo`0=ooooo`002Oooool01000003o
ooooooooooooooml000000T06ATI:0000004ooooo`0300000?oooooooooo00oooooo0_l0000Poooo
o`05okMjT?oooooooooooooooonoPI003?oooomMojVmj0_ooooo0_mf^_/2okj?Y004o`000?ngPico
gJbSomf/X`;oaHjK00?oomV7omVRW?l000002Oooool00ol0003oooooooooo`0<ooooo`002Oooool0
1000003ooooooooooooooon0000000806ATI:`000004ooooo`0300000?oooooooooo017ooooo00?o
0000ooooooooool08Oooool00onoPI3oooooooooo`0;oooooeSoZKgX4?ooool01Omf^__o_XnTokj?
Y?ngPico000000;ogJbS0_o5SY/00ooofHOofJ:Looooo`09ooooo`03o`000?oooooooooo00cooooo
0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0Booooo`03o`00
0?oooooooooo023ooooo00?o_h6@ooooooooool03?oooomBojVmj1Kooooo00KoM[[kokj?Y?nnSjCo
]h>Lo`000?oM[:<2olF>V`03oooIQol0003ooooo00Wooooo00?o0000ooooooooool03?ooool000Wo
oooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo01?ooooo00?o0000oooo
ooooool07oooool00onoPI3oooooooooo`0>ooooodkoZKgX6?ooool01omf^__o_XnTokj?Y?oM[:?o
0000omf/Xoo5SY/00_oofHL;ooooo`03o`000?oooooooooo00cooooo0009ooooo`0400000?oooooo
ooooooooojd000001?ooool00`00003oooooooooo`0Dooooo`;o0000<Ooooom9ojVmj1gooooo00Oo
_XnToooooooM[:?ogJbSo`000?oM[:?oomV700cooooo00?o0000ooooooooool03?ooool000Wooooo
00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo01Kooooo00?o0000oooooooo
ool0;ooooom6ojVmj27ooooo00CoG`0^omf/XooM[:?o00003Oooool00ol0003oooooooooo`0<oooo
o`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool05oooool00ol0
003oooooooooo`0_oooood7oZKgX9_ooool2omf/X`03ooooool0003ooooo00_ooooo00?o0000oooo
ooooool03?ooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
01Sooooo00?o0000ooooooooool0;ooooollojVmj2gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooo
ooooool06Oooool2o`00033ooooo>OnY_NP`ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
01_ooooo00?o0000ooooooooool0;_ooooldojVmj3Gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000oooo
ooooool07?ooool00ol0003oooooooooo`0^ooooobooZKgX>_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`0Mooooo`03o`000?oooooooooo02kooooo;?nY_NPlooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02oooool000Wooooo00@00000oooooooooooooooo[@000004oooo
o`0300000?oooooooooo01kooooo0_l0000_ooooobOoZKgX@Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00_ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00
003oooooooooo`0Pooooo`03o`000?oooooooooo02gooooo8_nY_NQ6ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooooooooooo[@000004oooo
o`0300000?oooooooooo027ooooo00?o0000ooooooooool0;_oooolNojVmj4Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0:ooooo`002Oooool01000003ooooooooooooooon]0000
00Cooooo00<00000ooooooooool08_ooool00ol0003oooooooooo`0^oooooaWoZKgXCOooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooo
ojd000001?ooool00`00003oooooooooo`0Sooooo`03o`000?oooooooooo02kooooo5?nY_NQBoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooo
oooooooo[@000004ooooo`0300000?oooooooooo02Cooooo0_l0000_oooooa3oZKgXE_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo0009ooooo`0400000?oooooooooooooo
ojd000001?ooool00`00003oooooooooo`0Vooooo`03o`000?oooooooooo02gooooo3OnY_NQHoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool000Wooooo00@00000oooooooo
oooooooo[@000004ooooo`0300000?oooooooooo02Oooooo00?o0000ooooooooool0;Oooool8ojVm
j5gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`002Oooool01000003o
oooooooooooooon]000000Cooooo00<00000ooooooooool0:?ooool00ol0003oooooooooo`0]oooo
o`?oZKgXH_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo0009ooooo`04
00000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0Yooooo`;o0000;Oooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool000Wo
oooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo02_ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooooooo
02cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Tooooo`05o`000?oooooooooo
ooooool000002oooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`0300000?oooooo
oooo02gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1Uooooo`04o`000?oooooo
ooooo`0000_ooooo0009ooooo`0400000?ooooooooooooooojd000001?ooool00`00003ooooooooo
o`0^ooooo`;o0000:?ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000_ooooo0009
ooooo`0400000?ooooooooooooooojd000001?ooool00`00003oooooooooo`0`ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00000;ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0<Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo06Oooooo00?o0000ooooool000002_ooool000Wooooo00@00000
oooooooooooooooo[@000004ooooo`0300000?oooooooooo03;ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`1Xooooo`;o00002_ooool000Wooooo00@00000oooooooooooooooo[@00
0004ooooo`0300000?oooooooooo03?ooooo0_l0000Sooooo`03o`000?oooooooooo06Oooooo0ol0
000:ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06?ooooo1?l0000=ooooo`002Oooool0
1000003ooooooooooooooon]000000Cooooo00<00000ooooooooool0=_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo063ooooo0ol0000Aooooo`002Oooool01000003ooooooooooooo
oon]000000Cooooo00<00000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo05cooooo1?l0000Dooooo`002Oooool01000003ooooooooooooooon=000000Co00007000
0004ooooo`0300000?oooooooooo03Sooooo0_l0000Nooooo`03o`000?oooooooooo05Sooooo1?l0
000Hooooo`002Oooool01000003ooooooooooooooon<00000003o`00000I6AT06ATI00806ATI1?l0
000H000000Cooooo00<00000ooooooooool0>_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo05Cooooo1?l0000Looooo`002Oooool01000003ooooooooooooooon;00000003o`00000I
6AT06ATI00L06ATI0ol0000E000000Cooooo00<00000ooooooooool0>oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo057ooooo0ol0000Pooooo`002Oooool01000003ooooooooooooo
oon;00000003o`00000I6AT06ATI00X06ATI00?o00000000000000004P000004ooooo`0300000?oo
oooooooo03cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1=ooooo`Co00008ooo
ool000Wooooo00@00000ooooooooooooooooRP0000000ol000006ATI01TI6@0401TI6@Co0000100I
6AT3o`00014000001?ooool00`00003oooooooooo`0mooooo`;o00006Oooool00ol0003ooooooooo
o`19ooooo`Co00009oooool000Wooooo00@00000ooooooooooooooooRP0000000ol000006ATI01TI
6@0301TI6@03o`00000c<c<0<c<c0080<c<c0_l0000501TI6@03o`0000000000000000h000001?oo
ool00`00003oooooooooo`0oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0AOoo
ool4o`0002_ooooo0009ooooo`0400000?ooooooooooooooohX0000000?o000001TI6@0I6AT00P0I
6AT00ol00000<c<c03<c<`0503<c<`03o`00000I6AT06ATI00<06ATI00?o00000000000000003@00
0004ooooo`0300000?oooooooooo043ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`13ooooo`?o0000;oooool000Wooooo00@00000ooooooooooooooooRP0000001Ol000006ATI01TI
6@0I6AWo000000H0<c<c1ol0000201TI6@03o`0000000000000000`000001?ooool00`00003ooooo
ooooo`11ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?oooool4o`0003;ooooo
0009ooooo`0400000?oooooooooooooooh/0000000Co000001TI6@0I6AWo00001P0c<c<00ol00000
C4a<04a<C002o`000080<c<c00?o000001TI6@0I6AT00_l0000<000000Cooooo00<00000oooooooo
ool0@_ooool2o`0001?ooooo00?o0000ooooooooool0>oooool4o`0003Kooooo0009ooooo`040000
0?oooooooooooooooh/0000000Co000001TI6@0I6AWo00001@0c<c<00ol00000C4a<04a<C00304a<
C0;o000000<0<c<co`00000I6AT00P0I6AT00ol00000000000000009000000Cooooo00<00000oooo
ooooool0A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Oooooo1?l0000joooo
o`002Oooool01000003ooooooooooooooon<00000004o`00000I6AT06ATIo`0000<0<c<c00?o0000
04a<C?l000001000000204a<C003o`00000c<c?o000000<06ATI00?o000000000000000020000004
ooooo`0300000?oooooooooo04Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0c
ooooo`Co0000?_ooool000Wooooo00@00000ooooooooooooooooS00000001?l000006ATI01TI6Ol0
000203<c<`03o`00001<C4co000000D0IVIV0`000004o`0000806ATI00?o00000000000000001`00
0004ooooo`0300000?oooooooooo04Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0`ooooo`?o0000@_ooool000Wooooo00@00000ooooooooooooooooS00000001?l000006ATI01TI
6Ol0000203<c<`03o`00001<C4`0000000<0IVIV0ol0000206IVIP050000001<C4co000003<c<ol0
00000P0I6AT00ol00000000000000006000000Cooooo00<00000ooooooooool0Aoooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02cooooo1?l00015ooooo`002Oooool01000003ooooo
oooooooooon=00000004o`00000I6AT06ATIo`000080<c<c00?o000004a<C00000000P1VIVH00ol0
0000Ogmo07moO`02o`00000606IVIP000000C4a<o`00000c<c?o00000P0I6AT00ol0000000000000
0005000000Cooooo00<00000ooooooooool0B?ooool2o`0000gooooo00?o0000ooooooooool0:?oo
ool4o`0004Wooooo0009ooooo`0400000?ooooooooooooooohh0000000[o000001TI6@0I6AWo0000
03<c<ol00000C4a<0000001VIVKo00001@1oOgl01?l00000IVIVo`0000000003o`0000806ATI0_l0
0005000000Cooooo00<00000ooooooooool0B_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Cooooo1?l0001=ooooo`002Oooool01000003ooooooooooooooon>00000004o`00000I
6AT06ATI01TI6@;o000000@0C4a<0000001VIVKo00001P1oOgl00ol00000IVIV0000000204a<C0;o
00000P0I6AT00ol00000000000000003000000Cooooo00<00000ooooooooool0Boooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo027ooooo0ol0001Aooooo`002Oooool01000003ooooo
oooooooooon?0000000:o`00000I6AT06ATIo`00000c<c?o000004a<C0000000IVIVo`0000<0Ogmo
00[o000007moO`1oOgoo000006IVIP000000C4a<o`00000c<c?o00000P0I6AT00ol0000000000000
0002000000Cooooo00<00000ooooooooool0C?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01gooooo1?l0001Dooooo`002Oooool01000003ooooooooooooooon@00000009o`00000I
6AT06ATIo`00000c<c?o00000000001VIVKo000000<0Ogmo0_l0000207moO`07o`00001VIVH00000
00000?l00000<c<co`00000201TI6@04o`00000000000000000000Cooooo00<00000ooooooooool0
COooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`0005Sooooo0009ooooo`0400000?oo
oooooooooooooi4000000_l000001P0I6AWo000003<c<ol00000000006IVIP;o000000@0Ogmoo`00
0?l0003o00000P1oOgl01ol00000IVIV0000001<C4co000003<c<ol000000P0I6AT00ol000000000
00000004ooooo`0300000?oooooooooo04oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Eooooo`Co0000G?ooool000Wooooo00@00000ooooooooooooooooTP0000000ol000006ATI
01TI6@02o`00000504a<C?l00000000006IVI_l000001@1oOgl01ol00000IVIV06IVIP00003o0000
03<c<ol000000P0I6AT00ol00000000000000004ooooo`0300000?oooooooooo053ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Booooo`?o0000H?ooool000Wooooo00@00000oooo
ooooooooooooT`0000000ol000006ATI01TI6@02o`000080C4a<00@0000006IVI_l0003o0000101o
Ogl01ol00000IVIV06IVIP00003o000003<c<ol000000P0I6AT00ol000000000ooooo`03ooooo`03
00000?oooooooooo057ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co
0000Hoooool000Wooooo00@00000ooooooooooooooooU00000000ol000006ATI01TI6@04o`000004
0000001VIVH0IVIVo`000080Ogmo0_l0000306IVIP0400000?l00000<c<co`0000806ATI00?o0000
ooooooooool00_ooool00`00003oooooooooo`1Booooo`;o00000oooool00ol0003oooooooooo`0:
ooooo`Co0000Ioooool000Wooooo00@00000ooooooooooooooooU@000002o`00000401TI6Ol0003o
000003<c<`;o00000P000002o`0000@0IVIV00D0000004a<C?l00000<c<co`00000201TI6@03o`00
0?oooooooooo00;ooooo00<00000ooooooooool0E?ooool01?l0003oooooooooool00008ooooo`Co
0000Joooool000Wooooo00@00000ooooooooooooooooU`0000000ol000006ATI01TI6@04o`000004
04a<C0000000000000000080IVIV00L0000004a<C01<C4`0C4a<o`00000c<c?o000000806ATI00Go
0000oooooooooooooooo0000001Gooooo`03o`000?oooooo000000Gooooo0ol0001_ooooo`002Ooo
ool01000003ooooooooooooooonH00000007o`00000I6AT06ATI01TI6Ol00000<c<co`00000304a<
C0800000101<C4`00ol00000<c<co`00000201TI6@Cooooo00<00000ooooooooool0E_ooool2o`00
0003ooooool0003o000000;o0000L_ooool000Wooooo00@00000ooooooooooooooooV0000002o`00
00806ATI0_l00000100c<c?o0000o`000?l0000504a<C004o`00000c<c<0<c<co`0000806ATI1?oo
ool00`00003oooooooooo`1Gooooo`;o0000M_ooool000Wooooo00@00000ooooooooooooooooVP00
0002o`0000806ATI00Co000003<c<`0c<c<0<c<c1Ol0000303<c<`03o`00000I6AT06ATI00Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooW00000000ol000006ATI
01TI6@03o`0000P0<c<c00?o000001TI6@0I6AT01?ooool00`00003oooooooooo`3?ooooo`002Ooo
ool01000003ooooooooooooooonM000000;o00000`0I6AT4o`000080<c<c0ol0000201TI6@Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000ooooooooooooooooW`000002o`0000D06ATI
0_l0000501TI6@Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
X@000002o`0000X06ATI1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
oooooonS000000?o00001`0I6AT4ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooojH000002?l00003ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?oo
ooooooooooooojd000001?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooo
oooooon]000000Cooooo00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo
[@000004ooooo`0300000?oooooooooo0<oooooo0009ooooo`0400000?ooooooooooooooojd00000
1?ooool00`00003oooooooooo`3?ooooo`002Oooool01000003ooooooooooooooon]000000Cooooo
00<00000ooooooooool0coooool000Wooooo00@00000oooooooooooooooo[@000004ooooo`030000
0?oooooooooo0<oooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool0cooo
ool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`3?ooooo`002Oooool00`00
003oooooooooo`2booooo`0300000?oooooooooo0<oooooo0009oooookH00000dOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool000Wooooo]_l0000AoooookKo00002_ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo00?oX23`ooooooooool0:Oooool0
0onP8?3oooooooooo`1Nooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0gooooo`03oj0Pl?oooooooooo
07Sooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00?oX23`ooooooooool0R?ooool00ol0003o
ooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01_ooool00onP8?3oooooooooo`12ooooo`03oj0Pl?oooooooooo06Cooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00[ooooo00?oX23`ooooooooool0YOooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01_ooool2oj0Pl1_ooooo0_nP8?0Nooooo`03oj0Pl?oooooooooo00Cooooo00?oX23`
ooooooooool0IOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool00onP8?3oooooooooo`1moooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03oj0P
l?oooooooooo00;ooooo00?oX23`ooooooooool01oooool00onP8?3oooooooooo`0;ooooo`03oj0P
l?oooooooooo00Wooooo00?oX23`ooooooooool00_ooool00onP8?3ooooooj0Pl003ooooo`03oj0P
l?oooooooooo013ooooo00?oX23`ooooooooool0G?ooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_oo
ool00onP8?3oooooooooo`0[ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool00_oo
ool00onP8?3oooooooooo`1]ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03oj0Pl?oooooo
oooo00Oooooo00CoX23`ooooooooooooX23`5Oooool00onP8?3oooooooooo`05ooooo`04oj0Pl?oo
oooooooooj0Pl1gooooo00?oX23`ooooooooool0Eoooool00ol0003oooooooooo`08ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Ooo
ool00onP8?3oooooooooo`2>ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`05oj0Pl?oooooo
oooooooooonP8?00<_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo017ooooo00?o
X23`ooooooooool0EOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool2oj0Pl0Cooooo00?oX23`
ooooooooool00onP8?09ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool00_nP8?03
ooooo`03oj0Pl?oooooooooo01Oooooo00GoX23`oooooooooooooooooj0Pl003ooooo`03oj0Pl?oo
oooooooo05gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00CoX23`ooooooooooooX23`5_oo
ool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo07Sooooo00?o0000ooooooooool02?oo
ool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00kooooo0_nP8?000oooooooX23`oj0Pl002oj0Pl003oooooonP8?3oX23`00?ooooo00GoX23`
oooooooooooooooooj0Pl006ooooo`03oj0Pl?oooooooooo013ooooo00?oX23`ooooooooool0M_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03oooool00onP8?3oooooooooo`02oj0Pl003oooooonP8?3o
oooo00cooooo00?oX23`ooooooooool0S?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool00onP
8?3ooooooj0Pl002ooooo`03oj0Pl?ooooooX23`00?ooooo0_nP8?0gooooo`03oj0Pl?oooooooooo
05[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo0onP8?000oooooooX23`oj0Pl002oj0Pl004
oooooonP8?3ooooooj0Pl0Kooooo00?oX23`oooooonP8?000oooool00onP8?3oooooooooo`02oooo
o`03oj0Pl?oooooooooo023ooooo00?oX23`ooooooooool0GOooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04Oooool00onP8?3oooooooooo`05oj0Pl004oooooonP8?3oX23`oj0Pl0Cooooo00?oX23`oooo
ooooool00_ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo087ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool05oooool6o`00oiGooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Cooooo`OoX23`0_ooool4oj0Pl1cooooo00?oX23`oooooooo
ool00oooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`oooooooo
ool03Oooool00onP8?3oooooooooo`14ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo01Oooooo00?o003oooooooooool00oooool2o`00oi?ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Eooooo`CoX23`00?ooooooj0Pl?ooool00onP8?04ooooo`03oj0P
l?oooooooooo08cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool06?oo
ool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo093ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Hooooo`CoX23`00Cooooooj0Pl?ooooooX23`0_ooool01OnP8?3ooooo
ooooooooooooX23`00_ooooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`0>ooooo`03
oj0Pl?oooooooooo06Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo08oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Hooooo`OoX23`=Oooool00onP8?3oooooooooo`1Kooooo`03o`00
0?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01[ooooo00?o003oooooooooool00ooo
ool00ol00?ooooooooooo`2?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?oo
ool00onP8?3oooooooooo`05oj0Pl007oooooonP8?3ooooooooooonP8?3ooooooj0Pl00Aooooo`03
oj0Pl?oooooooooo07Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0
6oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo08kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Jooooo`CoX23`00?ooooooj0Pl?nP8?001?nP8?02ooooo`;oX23`
0oooool00onP8?3ooooooj0Pl002oj0Pl0;ooooo00?oX23`oooooonP8?001oooool00onP8?3ooooo
ooooo`1booooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo01cooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`2=ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06?ooool00onP8?3ooooooj0Pl003ooooo`04oj0Pl?ooooooooooooooo`;oX23`
3oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo01oooooo00?oX23`ooooooooool0
2?ooool00onP8?3oooooooooo`1:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo01gooooo00Co003ooooooooooooooooo0ol0002>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool06?ooool01?nP8?3oooooooooooooool2oj0Pl004oooooonP8?3ooooooooo
o`?oX23`4?ooool00onP8?3ooooooj0Pl01jooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo01kooooo00?o003oooooool000001?l0002=ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool08?ooool01?nP8?3ooooooooooonP8?0Kooooo`03oj0Pl?oooooooooo
00Cooooo00?oX23`ooooooooool0JOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`0Oooooo`03o`00ool0003o000000?o000000?o003oooooooooool0R_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01gooooo00CoX23`oooooonP8?3oX23`2oooool01?nP
8?3ooooooooooonP8?03ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool01?ooool2
oj0Pl6[ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool08?ooool5o`00
0003ooooool00?oo003o08[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Ioooo
o`03oj0Pl?oooooooooo00?ooooo0_nP8?000oooooooX23`ooooo`06ooooo`03oj0Pl?oooooooooo
013ooooo00?oX23`ooooooooool04Oooool00onP8?3oooooooooo`1Nooooo`03o`000?oooooooooo
00Sooooo0009ooooo`03o`000?oooooooooo027ooooo0ol00004ooooo`03o`00oooooooooooo08Oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`04oj0Pl?oooooooooooj0P
l0Cooooo00CoX23`ooooooooooooX23`4Oooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooo
oooo00Cooooo00?oX23`ooooooooool0I?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`0Rooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0Q_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo00?oX23`oooooonP8?000_ooool3oj0P
l0Kooooo00?oX23`oooooonP8?002Oooool2oj0Pl003oooooonP8?3ooooo00[ooooo00?oX23`oooo
ooooool03?ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`oooo
ooooool0AOooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`0Sooooo`03
o`00oooooooooooo00Cooooo00?o003oooooooooool0QOooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02[ooooo00CoX23`ooooooooooooX23`<oooool00onP8?3oooooooooo`1>oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Cooooo0ol00?l4ooooo`03
o`00oooooooooooo08Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03
oj0Pl?ooooooX23`00Cooooo0_nP8?07ooooo`04oj0Pl?oooooooooooj0Pl13ooooo00?oX23`oooo
ooooool00oooool00onP8?3oooooooooo`0:ooooo`;oX23`3oooool00onP8?3oooooooooo`15oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Oooooo00Go003ooooooooo
ooooooooo`00o`26ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool01?nP
8?3ooooooj0Pl?ooool4oj0Pl0;ooooo00?oX23`ooooooooool09?ooool00onP8?3oooooooooo`05
ooooo`03oj0Pl?oooooooooo01Cooooo00?oX23`ooooooooool0?Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`0Xooooo`03o`00oooooooo003o08Oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Sooooo`?oX23`00?ooooooj0Pl?ooool00_nP8?000ooo
ooooX23`oj0Pl006ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`ooooooooool0>?ooool00onP
8?3oooooooooo`0eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo02Wo
oooo00?o003oooooooooool0Q_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Co
oooo0_nP8?001OooooooX23`oooooonP8?3ooooo00;oX23`00?ooooooj0Pl?ooool02?ooool00onP
8?3oooooooooo`03ooooo`03oj0Pl?oooooooooo00;oX23`3Oooool00onP8?3oooooooooo`1Ooooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Tooooo`;oX23`00?ooooooj0Pl?nP8?001Oooool3oj0Pl0?o
oooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`05ooooo`03oj0Pl?ooooooX23`02Ko
oooo00?oX23`ooooooooool0@_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1<ooooo`H0003oH?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo
1onP8?001OooooooX23`ooooooooooooX23`00Wooooo00?oX23`ooooooooool02Oooool00onP8?3o
ooooooooo`04ooooo`05oj0Pl?oooooooooooooooonP8?002_ooool01?nP8?3ooooooj0Pl?nP8?08
ooooo`03oj0Pl?ooooooX23`04Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0BOooool30000o`Kooooo10000?mLooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0;?ooool4oj0Pl0;ooooo00?oX23`ooooooooool01oooool00onP8?3oooooooooo`04oooo
o`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`05oooo
o`03oj0Pl?oooooooooo00cooooo00?oX23`oooooonP8?00:Oooool00onP8?3oooooooooo`0Hoooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Wooooo00<0003ooooooooo
ool02_ooool30000oeWooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03
oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool00_nP8?0Mooooo`03oj0Pl?oooooooooo00go
oooo00?oX23`ooooooooool08Oooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?oooooooooo01_o
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0B?ooool00`000?oooooo
ooooo`0>ooooo`80003oEoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02cooooo
00?oX23`oooooonP8?000_ooool01OnP8?3oooooooooooooooooX23`00oooooo00?oX23`oooooooo
ool02?ooool00onP8?3ooooooj0Pl00Mooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`oooooooo
ool06_ooool00onP8?3oooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo04Oooooo00<0003oooooooooool04Oooool00`000?ooooooooooo`1Dooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00onP8?3ooooooj0Pl00Rooooo`05oj0P
l?oooooooooooooooonP8?003?ooool00onP8?3oooooooooo`0Iooooo`03oj0Pl?oooooooooo01_o
oooo00?oX23`ooooooooool05_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`16ooooo`030000oooooooooooo01?ooooo0P000?mDooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0;?ooool00onP8?3ooooooj0Pl002oj0Pl0Cooooo00?oX23`ooooooooool0
2Oooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool0
0_ooool00onP8?3oooooooooo`0Rooooo`03oj0Pl?ooooooX23`00;ooooo00?oX23`oooooonP8?00
1Oooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo01Wooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0A_ooool00`000?ooooooooooo`0Eooooo`<0003oDOoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo037ooooo00?oX23`ooooooooool0:ooo
ool00onP8?3oooooooooo`0Looooo`03oj0Pl?oooooooooo00kooooo00CoX23`ooooooooooooX23`
1_ooool2oj0Pl1Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A_oo
ool00`000?ooooooooooo`0Hooooo`80003oCoooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Gooooo00?oX23`ooooooooool0>?ooool00onP8?3oooooooooo`0Yooooo`03oj0Pl?oo
oooooooo01?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A_ooool0
0`000?ooooooooooo`0Jooooo`030000oooooooooooo04cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Xooooo`04oj0Pl?ooooooooooooooo`?oX23`0_ooool01_nP8?3ooooooj0P
l?nP8?3ooooooj0Pl0Oooooo00?oX23`ooooooooool03oooool01_nP8?3ooooooooooonP8?3ooooo
oj0Pl0_ooooo00?oX23`ooooooooool01Oooool3oj0Pl003oooooonP8?3ooooo00Oooooo0_nP8?02
ooooo`03oj0Pl?oooooooooo01Cooooo0_nP8?02ooooo`;oX23`0_ooool00onP8?3ooooooj0Pl003
oj0Pl1?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0A_ooool00`00
0?ooooooooooo`0Kooooo`03o`00oooooooooooo04_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0jooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool07?ooool01?nP
8?3ooooooj0Pl?nP8?0Kooooo`03oj0Pl?oooooooooo00cooooo00CoX23`ooooooooooooX23`1Ooo
ool00onP8?3oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo04Kooooo00<0003oooooooooool07?ooool20000od_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0aooooo`04oj0Pl?oooooooooooj0Pl0;ooooo00?oX23`ooooooooool01Ooo
ool00onP8?3oooooooooo`0>ooooo`03oj0Pl?oooooooooo02Oooooo00?oX23`ooooooooool01Ooo
ool01OnP8?3oooooooooooooooooX23`017ooooo1?nP8?0Fooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo04Kooooo00<0003oooooooooool07_ooool20000odWooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03oj0Pl?oooooooooo00?ooooo00?o
X23`oooooonP8?004Oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00Sooooo00?o
X23`ooooooooool01Oooool00onP8?3oooooooooo`0=ooooo`03oj0Pl?oooooooooo00Gooooo00?o
X23`ooooooooool02Oooool00onP8?3oooooooooo`04ooooo`04oj0Pl?ooooooX23`oj0Pl0[ooooo
00?oX23`ooooooooool04?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooooooo
o`17ooooo`030000oooooooooooo01oooooo00<0003oooooooooool0A_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo03Sooooo00?oX23`ooooooooool05_ooool00onP8?3ooooooooo
o`08ooooo`03oj0Pl?oooooooooo02Gooooo00?oX23`ooooooooool02?ooool00onP8?3ooooooooo
o`07ooooo`03oj0Pl?oooooooooo00;oX23`5?ooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`17ooooo`030000oooooooooooo023ooooo00?o003oooooooooool0AOooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo00?oX23`ooooooooool00oooool0
1OnP8?3oooooooooooooooooX23`00cooooo00?oX23`ooooooooool05?ooool2oj0Pl1Kooooo00?o
X23`ooooooooool02oooool00onP8?3oooooooooo`03ooooo`;oX23`00?ooooooj0Pl?nP8?002?oo
ool00onP8?3oooooooooo`05ooooo`;oX23`4Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`17ooooo`030000oooooooooooo027ooooo0P000?m5ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0??ooool00onP8?3oooooooooo`0Kooooo`03oj0Pl?oooooo
oooo00;ooooo00?oX23`ooooooooool04Oooool2oj0Pl0Kooooo00?oX23`ooooooooool01_ooool2
oj0Pl003oooooonP8?3ooooo017ooooo00?oX23`oooooonP8?005Oooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`17ooooo`030000oooooooooooo02?ooooo00<0003ooooo
ooooool0@_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02kooooo00?oX23`oooo
ooooool01?ooool00onP8?3oooooooooo`02ooooo`;oX23`00Cooooooj0Pl?oooooooooo0_nP8?0F
ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`0<
ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool05?ooool01?nP8?3ooooooooooooo
ool2oj0Pl003oooooonP8?3oX23`00;oX23`5Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`18ooooo`030000oooooooooooo02?ooooo00<0003oooooooooool0@Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo00?oX23`ooooooooool02Oooool2
oj0Pl0Sooooo00?oX23`ooooooooool03?ooool00onP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooo
oooo00Gooooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`0Hooooo`03oj0Pl?oooooo
oooo00gooooo00GoX23`oooooooooooooooooj0Pl002ooooo`03oj0Pl?oooooooooo00cooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0B?ooool00`000?ooooooooooo`0T
ooooo`030000oooooooooooo02Kooooo1?l00?lFooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0=_ooool00onP8?3oooooooooo`04oj0Pl0;ooooo0_nP8?0Nooooo`03oj0Pl?oooooo
X23`00Cooooo00?oX23`ooooooooool02Oooool00onP8?3oooooooooo`04ooooo`04oj0Pl?oooooo
oooooj0Pl0Cooooo00GoX23`oooooooooooooooooj0Pl002ooooo`03oj0Pl?oooooooooo00_ooooo
00GoX23`oooooooooooooooooj0Pl003ooooo`?oX23`0_ooool00onP8?3oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Sooooo00<0003oooooooooool0
9?ooool00`000?ooooooooooo`0Uooooo`03o`00oooooooooooo00;ooooo0ol00?lCooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0@Oooool01?nP8?3ooooooooooonP8?0Nooooo`03
oj0Pl?oooooooooo01Sooooo00?oX23`ooooooooool04Oooool00onP8?3oooooooooo`02ooooo`03
oj0Pl?ooooooX23`00Wooooo00CoX23`ooooooooooooX23`2oooool00ol0003oooooooooo`08oooo
o`002Oooool00ol0003oooooooooo`19ooooo`030000oooooooooooo02Cooooo0P000?lTooooo`03
o`00oooooooooooo00Kooooo0_l00?lAooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0?Oooool00onP8?3oooooooooo`0:ooooo`03oj0Pl?oooooooooo00gooooo00?oX23`oooooooo
ool02?ooool00onP8?3ooooooj0Pl007ooooo`;oX23`1?ooool00onP8?3oooooooooo`0Eooooo`03
oj0Pl?oooooooooo013ooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo04Wooooo00<0003oooooooooool0
9_ooool00`000?ooooooooooo`0Qooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo00GoX23`oooooonP8?3o
oooooj0Pl007ooooo`03oj0Pl?ooooooX23`01oooooo00?oX23`oooooonP8?007_ooool01?nP8?3o
oooooooooonP8?05ooooo`04oj0Pl?oooooooooooj0Pl0?ooooo00GoX23`oooooooooooooooooj0P
l003ooooo`?oX23`2oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1:
ooooo`030000oooooooooooo02Kooooo0P000?lPooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo00CoX23`
ooooooooooooX23`9_ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo01cooooo00?o
X23`ooooooooool02_ooool00onP8?3ooooooj0Pl002ooooo`04oj0Pl?ooooooX23`oj0Pl0_ooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Boooool00`000?oooooooooo
o`0Wooooo`030000oooooooooooo01cooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@Oooool01?nP8?3ooooooooo
oonP8?07ooooo`03oj0Pl?oooooooooo00gooooo00?oX23`ooooooooool00_nP8?02ooooo`03oj0P
l?oooooooooo01Sooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`0;ooooo`03oj0P
l?ooooooX23`00[ooooo0_nP8?001?ooooooX23`oj0Pl?ooool2oj0Pl003oooooonP8?3oX23`00So
oooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0C?ooool00`000?oooooo
ooooo`0Wooooo`030000oooooooooooo01_ooooo00?o003oooooooooool03Oooool00ol00?oooooo
ooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0?oooool00onP8?3ooooo
ooooo`02ooooo`03oj0Pl?oooooooooo017ooooo00?oX23`ooooooooool04_ooool00onP8?3ooooo
ooooo`02ooooo`03oj0Pl?oooooooooo01oooooo00?oX23`ooooooooool01Oooool01_nP8?3ooooo
oj0Pl?ooooooX23`ooooo`;oX23`00Gooooooj0Pl?oooooooooooj0Pl009ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo04cooooo00<0003oooooooooool09oooool00`00
0?ooooooooooo`0Kooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool02oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03oooooo00?oX23`ooooooooool01?ooool00onP
8?3oooooooooo`0Eooooo`03oj0Pl?oooooooooo01Sooooo00?oX23`ooooooooool01?ooool2oj0P
l0;ooooo00?oX23`oooooonP8?004?ooool00onP8?3oooooooooo`03oj0Pl0;ooooo00OoX23`oooo
oooooooooooooj0Pl?ooooooX23`00cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0COooool00`000?ooooooooooo`0Wooooo`030000oooooooooooo01[ooooo00?o003o
ooooooooool01Oooool3o`0000Kooooo00?o003oooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo04Gooooo00CoX23`ooooooooooooX23`7oooool00onP8?3ooooooooo
o`05ooooo`?oX23`2Oooool00onP8?3oooooooooo`0>ooooo`03oj0Pl?ooooooX23`00;ooooo0_nP
8?000oooooooX23`ooooo`05ooooo`03oj0Pl?oooooooooo00;oX23`00?ooooooj0Pl?nP8?001?nP
8?000oooooooX23`ooooo`07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooo
oooo04gooooo00<0003oooooooooool0:?ooool00`000?ooooooooooo`0Iooooo`03o`00oooooooo
oooo00Cooooo1Ol00005ooooo`03o`00oooooooooooo00[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`16ooooo`03oj0Pl?oooooooooo017ooooo00?oX23`oooooonP8?004oooool0
0onP8?3oooooooooo`0?ooooo`03oj0Pl?ooooooX23`00?ooooo00?oX23`ooooooooool02_ooool0
1?nP8?3ooooooooooonP8?0:ooooo`03oj0Pl?ooooooX23`00?oX23`2Oooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`1>ooooo`030000oooooooooooo02Sooooo00<0003o
ooooooooool06Oooool00ol00?ooooooooooo`03ooooo`Go00001Oooool00ol00?ooooooooooo`0:
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@_ooool00onP8?3ooooooj0Pl006
ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool02?ooool00onP8?3ooooooj0Pl00<
ooooo`;oX23`1?ooool00onP8?3ooooooj0Pl004ooooo`03oj0Pl?oooooooooo00;ooooo00CoX23`
oooooooooooooooo0_nP8?0<ooooo`;oX23`1?ooool01?nP8?3oooooooooooooool4oj0Pl0Cooooo
00?oX23`ooooooooool00onP8?001?ooooooX23`oj0Pl?nP8?08ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo04oooooo00?o003oooooooooool0:?ooool20000oaWooooo
00?o003oooooooooool00oooool5o`0000Kooooo00?o003oooooooooool02Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04cooooo00?oX23`oooooonP8?00;_ooool00onP8?3ooooo
ooooo`0:ooooo`;oX23`1oooool00onP8?3oooooooooo`05ooooo`04oj0Pl?oooooooooooj0Pl0;o
oooo0onP8?000oooooooX23`oj0Pl00;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo04oooooo00<0003oooooooooool0:_ooool00`000?ooooooooooo`0Fooooo`03o`00
oooooooooooo00Cooooo0ol00007ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`14ooooo`03oj0Pl?oooooooooo00Cooooo00CoX23`oooooooooooo
X23`>?ooool00onP8?3oooooooooo`0Fooooo`04oj0Pl?oooooooooooj0Pl0;ooooo00?oX23`oooo
oonP8?000_nP8?07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo053o
oooo00<0003oooooooooool0:_ooool00`000?ooooooooooo`0Fooooo`03o`00oooooooooooo00go
oooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wo
oooo00?oX23`ooooooooool02Oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00;o
oooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo01;o
oooo00GoX23`oooooooooooooooooj0Pl002ooooo`03oj0Pl?oooooooooo00;ooooo0_nP8?001Ooo
ooooX23`oj0Pl?nP8?3ooooo00CoX23`00Kooooooj0Pl?oooooooooooj0Pl?ooool6oj0Pl0Oooooo
00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0DOooool00`000?oooooooooo
o`0Yooooo`030000oooooooooooo01Oooooo00?o003oooooooooool03?ooool00ol00?oooooooooo
o`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0I_ooool00onP8?3ooooooooo
o`0Dooooo`03oj0Pl?oooooooooo00Gooooo0_nP8?08ooooo`;oX23`2_ooool01OnP8?3ooooooooo
oonP8?3ooooo00;oX23`0oooool00onP8?3oooooooooo`02oj0Pl0Sooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0DOooool00`000?ooooooooooo`0Zooooo`030000oooo
oooooooo01Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`09ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0A?ooool01onP8?3oooooooooooooooooX23`oooooonP
8?000oooool00onP8?3oooooooooo`0=ooooo`03oj0Pl?oooooooooo00kooooo00?oX23`oooooooo
ool00oooool00onP8?3oooooooooo`09ooooo`?oX23`00?ooooooj0Pl?nP8?000oooool00onP8?3o
ooooooooo`04ooooo`03oj0Pl?oooooooooo00Cooooo00OoX23`oooooooooooooooooj0Pl?oooooo
X23`00?ooooo2OnP8?07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05;ooooo00<0003oo`00ooooool05?ooool3o`0001?ooooo00<0003oooooooooool05_ooool2o`00
o`cooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
04_ooooo00?oX23`ooooooooool0>_ooool00onP8?3oooooooooo`07ooooo`?oX23`1oooool00onP
8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00?ooooo0_nP8?001?ooooooX23`oooooonP8?05
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05?ooooo00<0003ooooo
ooooool04_ooool5o`0001;ooooo00<0003oooooooooool06?ooool00ol00?ooooooooooo`08oooo
o`03o`00oooooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19oooo
o`03oj0Pl?oooooooooo00?ooooo00CoX23`ooooooooooooX23`6Oooool00onP8?3oooooooooo`03
ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool03?ooool00onP8?3ooooooj0Pl002
ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`04
ooooo`03oj0Pl?oooooooooo00GoX23`1oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0
003oooooooooo`1Dooooo`030000oooooooooooo017ooooo1Ol0000Cooooo`030000oooooooooooo
01Sooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0B_ooool01OnP8?3oooooooooooooooooX23`00?ooooo00?oX23`
ooooooooool03?ooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`
oooooonP8?003Oooool01onP8?3oooooooooooooooooX23`oooooonP8?001?ooool01?nP8?3ooooo
oj0Pl?nP8?05ooooo`03oj0Pl?oooooooooo00;oX23`1Oooool2oj0Pl004oooooonP8?3ooooooooo
o`CoX23`00?ooooooj0Pl?nP8?001Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`1Eooooo`030000oooooooooooo013ooooo1Ol0000Dooooo`80003o6Oooool00ol00?oo
ooooooooo`04ooooo`03o`00oooooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1:ooooo`;oX23`1?ooool01?nP8?3ooooooooooonP8?0Dooooo`03oj0Pl?oooooooooo
00[ooooo00GoX23`oooooooooooooooooj0Pl005ooooo`03oj0Pl?oooooooooo00Gooooo0_nP8?05
ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`oooooonP8?001oooool00onP8?3oooooooooo`02
ooooo`03oj0Pl?oooooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0E_ooool00`000?ooooooooooo`0@ooooo`?o00005oooool00`000?ooooooooooo`0Goooo
o`Ko003o3oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo00?oX23`oooo
ooooool01oooool2oj0Pl0?ooooo00?oX23`ooooooooool02oooool00onP8?3oooooooooo`03oooo
o`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool08oooool01onP8?3ooooooj0Pl?oooooo
X23`oooooonP8?001_ooool2oj0Pl004oooooonP8?3ooooooj0Pl0;ooooo00?oX23`oooooonP8?00
0_nP8?05ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo05Kooooo00<0
003oooooooooool0:_ooool00`000?ooooooooooo`0/ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0Coooool2oj0Pl0Oooooo00?oX23`ooooooooool01?ooool00onP8?3ooooooj0P
l004ooooo`;oX23`3_ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo00?oX23`0ooo
ool3oj0Pl0Gooooo0_nP8?04ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Gooooo`030000oooooooo
oooo02[ooooo00<0003oooooooooool0:oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04kooooo00?oX23`ooooooooool01?ooool00onP8?3oooooooooo`07ooooo`03oj0Pl?oooooo
oooo00Kooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooo
oooo00Wooooo00CoX23`ooooooooooooX23`0oooool2oj0Pl0;ooooo00?oX23`ooooooooool00ooo
ool00onP8?3oooooooooo`05ooooo`08oj0Pl?ooooooX23`oj0Pl?ooooooX23`oooooonP8?03oooo
o`;oX23`1?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1Hooooo`03
0000oooooooooooo02[ooooo00<0003oooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo05?ooooo00CoX23`ooooooooooooX23`1oooool00onP8?3oooooooooo`0>oooo
o`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`09oooo
o`?oX23`1oooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo00?ooooo00GoX23`oooo
oooooooooooooj0Pl007ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05Wooooo00<0003oooooooooool0:Oooool00`000?ooooooooooo`0Zooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0F_ooool00onP8?3oooooooooo`0Vooooo`03oj0Pl?oooooooooo
00;ooooo00?oX23`ooooooooool01?ooool01?nP8?3oooooooooooooool2oj0Pl0Wooooo00?oX23`
ooooooooool01?ooool00onP8?3oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo05[ooooo00<0003oooooooooool0:Oooool00`000?ooooooooooo`0Yoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0EOooool2oj0Pl0Cooooo00?oX23`oooo
ooooool02?ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00Oooooo00?oX23`oooo
ooooool01?ooool00onP8?3oooooooooo`05ooooo`03oj0Pl?oooooooooo00;oX23`0_ooool00onP
8?3oooooooooo`05ooooo`04oj0Pl?oooooooooooj0Pl0?ooooo00?oX23`ooooooooool00_ooool0
0onP8?3oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05_ooooo00<0003oooooooooool0:?ooool00`000?ooooooooooo`0Yooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0Doooool00onP8?3oooooooooo`0?ooooo`03oj0Pl?oooooooooo
01Wooooo00?oX23`ooooooooool02Oooool00onP8?3ooooooj0Pl004ooooo`;oX23`00?ooooooj0P
l?ooool02oooool00onP8?3oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo05cooooo00<0003oooooooooool0:?ooool00`000?ooooooooooo`0Xooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0D_ooool2oj0Pl004oooooonP8?3ooooooj0P
l0?ooooo0_nP8?0Tooooo`03oj0Pl?oooooooooo00Wooooo00CoX23`ooooooooooooX23`0oooool0
0onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00;ooooo00?oX23`oooooonP8?001?ooool0
0onP8?3oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
05gooooo00<0003oooooooooool0:?ooool00`000?ooooooooooo`0Wooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0E_ooool3oj0Pl005oooooonP8?3ooooooooooonP8?002_ooool0
0onP8?3oooooooooo`0Nooooo`03oj0Pl?oooooooooo02?ooooo00CoX23`oooooooooooo00002_oo
ool000Wooooo00?o0000ooooooooool0G_ooool00`000?ooooooooooo`0Wooooo`030000oooooooo
oooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Jooooo`?oX23`1oooool0
0onP8?3oooooooooo`0Sooooo`;oX23`0oooool00onP8?3oooooooooo`04ooooo`04oj0Pl?oooooo
X23`oj0Pl0Cooooo00?oX23`ooooooooool04Oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`1Oooooo`80003o:?ooool00`000?ooooooooooo`0Vooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0E_ooool01OnP8?3oooooooooooooooooX23`00cooooo0_nP
8?05ooooo`03oj0Pl?oooooooooo00_ooooo0_nP8?02ooooo`03oj0Pl?oooooooooo00?ooooo00?o
X23`ooooooooool03_ooool00onP8?3ooooooj0Pl00>ooooo`03oj0Pl?oooooooooo00Gooooo00?o
X23`ooooool000002_ooool000Wooooo00?o0000ooooooooool0HOooool00`000?ooooooooooo`0V
ooooo`030000oooooooooooo02Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1I
ooooo`;oX23`2_ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`
ooooooooool01Oooool01?nP8?3ooooooooooonP8?04ooooo`03oj0Pl?oooooooooo01oooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0H_ooool00`000?ooooooooooo`0V
ooooo`030000oooooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1H
ooooo`03oj0Pl?ooooooX23`00Cooooo0_nP8?05ooooo`03oj0Pl?oooooooooo023ooooo00?oX23`
ooooooooool01_ooool00onP8?3oooooooooo`06ooooo`03oj0Pl?oooooooooo00;oX23`1oooool0
0onP8?3oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
06?ooooo00<0003oooooooooool09Oooool00`000?ooooooooooo`0Tooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0GOooool00onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo
01Gooooo00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`0Nooooo`03oj0Pl?oooooooooo
00Kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0I?ooool00`000?oo
ooooooooo`0Uooooo`030000oooooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1^ooooo`03oj0Pl?oooooooooo01[ooooo00?oX23`ooooooooool00_nP8?02ooooo`03
oj0Pl?oooooooooo00Cooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`0=ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06Gooooo00?o003o0000ooooool0
9?ooool00`000?ooooooooooo`0Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
F_ooool2oj0Pl0Gooooo00?oX23`oooooonP8?001oooool00onP8?3oooooooooo`07ooooo`;oX23`
0_ooool00onP8?3oooooooooo`0=ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool0
2Oooool00onP8?3oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oo
oooooooo06Oooooo00<0003oooooooooool08oooool00`000?ooooooooooo`0Rooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0GOooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oo
oooooooo00;ooooo00?oX23`ooooooooool02oooool00onP8?3oooooooooo`03ooooo`03oj0Pl?oo
oooooooo03Cooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0J?ooool0
0`000?ooooooooooo`0Rooooo`030000oooooooooooo02;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1Oooooo`04oj0Pl?oooooooooooj0Pl0;ooooo00CoX23`ooooooooooooX23`
2Oooool00onP8?3oooooooooo`02ooooo`03oj0Pl?ooooooX23`01Sooooo00?oX23`ooooooooool0
3_ooool00onP8?3oooooooooo`07ooooo`06oj0Pl?oooooooooooj0Pl?oooooo00002_ooool000Wo
oooo00?o0000ooooooooool0JOooool00`000?ooooooooooo`0Qooooo`030000oooooooooooo02;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1Oooooo`04oj0Pl?oooooooooooj0P
l1_ooooo00?oX23`ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`1Zooooo`80003o8_ooool00`000?ooooooooooo`0Qooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0H?ooool3oj0Pl0Gooooo0_nP8?0Dooooo`03oj0Pl?oooooooooo00?o
oooo00?oX23`ooooooooool0:oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003ooooo
ooooo`1/ooooo`030000oooooooooooo01oooooo00<0003oooooooooool08Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo067ooooo00CoX23`ooooooooooooX23`1Oooool00onP8?3o
ooooooooo`0Sooooo`05oj0Pl?ooooooX23`oooooonP8?004oooool00onP8?3oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo06gooooo00<0003ooooooooo
ool07_ooool00`000?ooooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0Moooool00onP8?3oooooooooo`0hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`00
0?oooooooooo06kooooo00<0003oooooooooool07_ooool00`000?ooooooooooo`0Pooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0I_ooool00onP8?3ooooooj0Pl005ooooo`03oj0P
l?oooooooooo00Wooooo0_nP8?05ooooo`03oj0Pl?oooooooooo00kooooo00?oX23`ooooooooool0
1Oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo00Gooooo00CoX23`oooooooooooo
X23`1Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1_ooooo`030000
oooooooooooo01gooooo00<0003oooooooooool08?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo06Sooooo00?oX23`ooooooooool05?ooool00onP8?3oooooooooo`0Xooooo`03oj0P
l?oooooooooo00Gooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0L?oo
ool00ol00?l0003oooooo`0Looooo`030000oooooooooooo023ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Nooooo`05oj0Pl?oooooooooooooooonP8?002_ooool00onP8?3ooooo
ooooo`0Cooooo`03oj0Pl?oooooooooo02_ooooo00?oX23`o`000?ooool02Oooool000Wooooo00?o
0000ooooooooool0L_ooool00`000?ooooooooooo`0Jooooo`030000oooooooooooo023ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`28ooooo`03oj0Pl?oooooooooo02Oooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Loooool20000oa[ooooo00<0003o
ooooooooool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06[ooooo00?oX23`
ooooooooool09oooool00onP8?3oooooooooo`0Hooooo`04oj0Pl?ooooooooooo`0000[ooooo0009
ooooo`03o`000?oooooooooo07Gooooo0`000?lGooooo`030000oooooooooooo023ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Zooooo`03oj0Pl?ooooooX23`02;ooooo00?oX23`
ooooooooool01?ooool00onP8?3oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo07Sooooo0P000?lEooooo`030000oooooooooooo023ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Zooooo`03oj0Pl?oooooooooo02_ooooo00?oX23`oooo
ooooool05oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1jooooo`80
003o4oooool00`000?ooooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0KOooool2oj0Pl0Kooooo00?oX23`ooooooooool02_ooool00onP8?3oooooooooo`0:ooooo`03
oj0Pl?oooooooooo00;ooooo00?oX23`ooooooooool00_ooool00onP8?3oooooooooo`0Eooooo`03
oj0Pl?l0003ooooo00Wooooo0009ooooo`03o`000?oooooooooo07cooooo00<0003oooooooooool0
3oooool00`000?ooooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
LOooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo01Kooooo00?oX23`ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`1mooooo`<0003o3Ooo
ool00`000?ooooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Jooo
ool01OnP8?3oooooooooooooooooX23`00gooooo00?oX23`ooooooooool05_ooool01?nP8?3ooooo
oooooonP8?0Hooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo083ooooo
10000?l8ooooo`030000oooooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1]ooooo`05oj0Pl?oooooooooooooooonP8?007_ooool01?nP8?3ooooooooooonP8?0Moooo
o`03oj0Pl?l0003ooooo00Wooooo0009ooooo`03o`000?oooooooooo08Cooooo20000?lVooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Koooool00onP8?3oooooooooo`0Booooo`03
oj0Pl?oooooooooo01;ooooo00?oX23`ooooooooool05_ooool00ol0003oooooooooo`08ooooo`00
2Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
L?ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo01Sooooo00?oX23`ooooooooool0
6?ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0ROooool2oj0Pl1Kooooo00?oX23`ooooooooool03_oo
ool00ol0003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0NOooool00onP8?3oooooooooo`0>ooooo`04oj0Pl?oooooo
oooooj0Pl0Kooooo00?oX23`ooooooooool06oooool00ol0003oooooooooo`08ooooo`002Oooool0
0ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0R_ooool0
0onP8?3oooooooooo`0Uooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1eooooo`03oj0Pl?oooooooooo
013ooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`0<ooooo`;oX23`4oooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0MOooool01OnP8?3oooooooooooooooooX23`00?ooooo00?oX23`oooo
ooooool01_ooool01OnP8?3oooooooooooooooooX23`01Cooooo00?oX23`ooooooooool01Oooool0
0onP8?3oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1]ooooo`03oj0Pl?oooooooooo
00Gooooo00?oX23`ooooooooool0>_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Moooool01?nP8?3o
oooooooooonP8?0;ooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`ooooooooool00oooool00onP
8?3oooooooooo`09ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool01?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0NOooool00onP8?3oooooooooo`07ooooo`03oj0Pl?ooooooX23`00co
oooo00?oX23`ooooooooool04oooool00onP8?3oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1gooooo`05oj0Pl?oooooooooooooooonP8?009oooool00onP8?3oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1jooooo`05oj0Pl?ooooooX23`oooooonP8?000oooool00onP8?3o
ooooooooo`0Sooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`o`000?ooool02Oooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Sooooo
00?oX23`ooooooooool06?ooool00onP8?3oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo
0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`27ooooo`;oX23`3_ooool00onP8?3oooooooooo`0<ooooo`;oX23`2_ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0T_ooool00onP8?3oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo0009oooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`21oooo
o`03oj0Pl?oooooooooo01[ooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`1nooooo`03oj0Pl?oooooooooo00;oX23`1Oooool2oj0Pl0Go
oooo00?oX23`ooooooooool01?ooool3oj0Pl0Gooooo00?oX23`ooooooooool00_ooool00onP8?3o
ooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`22ooooo`03oj0Pl?oooooooooo01;ooooo
00?oX23`ooooooooool05?ooool01OnP8?3ooooooooooonP8?3o000000[ooooo0009ooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1oooooo`05oj0P
l?oooooooooooooooonP8?006?ooool01OnP8?3oooooooooooooooooX23`00;ooooo00?oX23`oooo
ooooool00oooool00onP8?3oooooooooo`02ooooo`05oj0Pl?ooooooooooooooool000002_ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
07Wooooo00?oX23`ooooooooool05_ooool00onP8?3ooooooj0Pl00Gooooo`03oj0Pl?oooooooooo
00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo08;ooooo0_nP8?03ooooo`03oj0Pl?oooooooooo02?o
oooo00KoX23`oooooooooooooooooj0Pl?l0000:ooooo`002Oooool00ol0003oooooooooo`2boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Qoooool00onP8?3oooooooooo`02oooo
o`;oX23`00?ooooooj0Pl?ooool08Oooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Poooool00onP8?3o
ooooooooo`0>ooooo`03oj0Pl?oooooooooo01[ooooo00?oX23`o`000?ooool02Oooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Sooooo
00SoX23`ooooooooooooX23`oooooonP8?3ooooooj0Pl0Oooooo00GoX23`oooooooooooooooooj0P
l00Booooo`05oj0Pl?oooooooooooj0Pl?l000002_ooool000Wooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo093ooooo0_nP8?0Fooooo`03oj0Pl?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Sooooo00?oX23`ooooooooool03Oooool0
0onP8?3oooooooooo`0Fooooo`03oj0Pl?l0003ooooo00Wooooo0009ooooo`03o`000?oooooooooo
0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`03oj0Pl?oooooooooo
01_ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo08_ooooo00?oX23`ooooooooool00oooool00onP8?3o
ooooooooo`0Aooooo`03oj0Pl?oooooooooo00[ooooo00?o0000ooooooooool02?ooool000Wooooo
00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo097ooooo
00?oX23`ooooooooool01Oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?ooooooX23`00kooooo
00?oX23`o`000?ooool02Oooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo08cooooo00?oX23`ooooooooool00_ooool00onP8?3ooooooooo
o`0:ooooo`03oj0Pl?oooooooooo00kooooo00CoX23`oooooooooooo00002_ooool000Wooooo00?o
0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Cooooo00?o
X23`ooooooooool04oooool00onP8?3oooooooooo`04ooooo`03oj0Pl?l0003ooooo00Wooooo0009
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2=
ooooo`03oj0Pl?oooooooooo00Wooooo00?oX23`ooooooooool05_ooool00ol0003oooooooooo`08
ooooo`002Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0R_ooool00onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo023ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo08gooooo00?oX23`oooooonP8?000_ooool01OnP8?3ooooooj0Pl?nP8?3ooooo
00;oX23`0_ooool00onP8?3oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo0009ooooo`03
o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Oooooo`03
oj0Pl?oooooooooo00oooooo00?oX23`o`000?ooool02Oooool000Wooooo00?o0000ooooooooool0
/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo097ooooo0_nP8?000oooooooX23`
ooooo`03ooooo`03oj0Pl?oooooooooo00Gooooo00?oX23`ooooooooool00_ooool00onP8?3ooooo
ooooo`03ooooo`03oj0Pl?oooooooooo00?ooooo00?o0000ooooooooool02?ooool000Wooooo00?o
0000ooooooooool0V?ooool4o`00oaKooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`2Aooooo`05oj0Pl?ooooooX23`oooooonP8?000oooool2oj0Pl1Oooooo00?o0000ooooooooool0
2?ooool000Wooooo00?o0000ooooooooool0U_ooool2o`00o`Cooooo1?l00?lBooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Z_ooool2oj0Pl0Gooooo00?oX23`o`000?ooool02Ooo
ool000Wooooo00?o0000ooooooooool0U_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`03oj0Pl?oooooo
X23`00Cooooo00?oX23`ooooooooool03_ooool00onP8?3oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo0009ooooo`03o`000?oooooooooo09Kooooo00?o003oooooooooool02?ooool00ol0
0?ooooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0[oooool01?nP
8?3ooooooj0Pl?l0000:ooooo`002Oooool00ol0003oooooooooo`2Gooooo`03o`00oooooooooooo
00Sooooo00?o003oooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
09Kooooo1?nP8?02ooooo`04oj0Pl?ooooooooooooooo`;oX23`2?ooool01?nP8?3ooooooj0Pl?nP
8?02ooooo`;oX23`00?o0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0Uoooool0
0ol00?ooooooooooo`04ooooo`?o00000_ooool00ol00?ooooooooooo`0<ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Uoooool00onP8?3oooooooooo`04ooooo`?oX23`0_ooool0
0onP8?3oooooooooo`02ooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`o`000?ooool02Oooool0
00Wooooo00?o0000ooooooooool0Uoooool2o`00o`Cooooo1Ol00002ooooo`03o`00oooooooooooo
00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Eooooo`03oj0Pl?oooooooooo
00;oX23`00?ooooooj0Pl?ooool00_ooool3oj0Pl0Gooooo00?oX23`ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`002Oooool00ol0003oooooooooo`2Iooooo`04o`00oooooooooooooooo
o`Go00000oooool00ol00?ooooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0V?ooool00onP8?3ooooooj0Pl002oj0Pl0Sooooo00KoX23`oooooonP8?3oX23`oooooonP
8?07ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo09[ooooo00?o003o
ooooooooool01Ol00004ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2Iooooo`?oX23`2_ooool3oj0Pl0Kooooo00CoX23`oooooonP8?3o00002_oo
ool000Wooooo00?o0000ooooooooool0Voooool00ol00?ooooooooooo`03o`0000Kooooo00?o003o
ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Wooooo1_nP8?00
1OooooooX23`ooooooooooooX23`00;ooooo00?oX23`ooooooooool00oooool01onP8?3ooooooooo
oonP8?3ooooooj0Pl?l000002_ooool000Wooooo00?o0000ooooooooool0W?ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2Kooooo`;oX23`00?ooooooj0Pl?nP8?002Oooool2oj0Pl0Gooooo0_nP8?000ol0003ooooo
ooooo`08ooooo`002Oooool00ol0003oooooooooo`2Mooooo`;o003o2Oooool00ol00?oooooooooo
o`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Voooool00onP8?3ooooooj0P
l003oj0Pl003oooooonP8?3ooooo00kooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000
ooooooooool0Woooool2o`00o`Oooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo09kooooo0onP8?02ooooo`04oj0Pl?oooooooooooj0Pl0_ooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0XOooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2M
ooooo`04oj0Pl?oooooooooooj0Pl0[ooooo00?oX23`ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`002Oooool00ol0003oooooooooo`2Rooooo`Co003o00?oooooo`00ooooool02Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09oooooo0_nP8?001?ooooooX23`oj0Pl?oo
ool2oj0Pl003oooooonP8?3ooooo00Cooooo00GoX23`ooooooooooooooooo`00000:ooooo`002Ooo
ool00ol0003oooooooooo`2Vooooo`;o003o2_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo09oooooo00?oX23`oooooonP8?001oooool00onP8?3oooooooooo`06ooooo`03o`000?oo
oooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2Rooooo`?oX23`0oooool2oj0Pl0Sooooo00?o0000ooooooooool02?ooool0
00Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:gooooo00?oX23`ooooooooool00_ooool00ol0003oooooooooo`08ooooo`002Oooool00ol0003o
ooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0YOooool01_nP8?3o
oooooooooonP8?3ooooooj0Pl0Oooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo0:7ooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`05ooooo`03
o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`2Xooooo`;oX23`1oooool00onP8?3o0000ooooo`09ooooo`002Ooo
ool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Z?oo
ool00onP8?3ooooooj0Pl006ooooo`03oj0Pl?l0003ooooo00Wooooo0009ooooo`03o`000?oooooo
oooo0;;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Xooooo`05oj0Pl?oooooo
X23`oooooonP8?001?ooool00onP8?3o0000ooooo`09ooooo`002Oooool00ol0003oooooooooo`2b
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Z_ooool00onP8?3oooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2`ooooo`;oX23`00?o0000ooooooooool02?ooool000Wo
oooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:[o
oooo00?oX23`ooooooooool01?ooool00onP8?3o0000ooooo`09ooooo`002Oooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Z_ooool00onP8?3ooooo
ooooo`04ooooo`03oj0Pl?l0003ooooo00Wooooo0009ooooo`03o`000?oooooooooo0;;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`2[ooooo`03oj0Pl?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool000Wooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool02?ooool000Wooooo00?o0000oooo
ooooool0/_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ooooool02?ooool000Wooooo]_l0000AoooookCo000000?oX23`o`000?ooool02Oooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.09771, -0.0754011, 0.0052648, 0.0052648}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-0.0643398, -1.18808, 0.00564516, 0.00564516}, {{208.5, 389.438}, \
{190.438, 9.5}} -> {-294.432, -294.52, 1.41129, 1.41129}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, d2d2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0414079 0.130031 3.11749e-05 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23085 -0.0125 -3 -9 ]
[.23085 -0.0125 3 0 ]
[.43789 -0.0125 -6 -9 ]
[.43789 -0.0125 6 0 ]
[.64493 -0.0125 -6 -9 ]
[.64493 -0.0125 6 0 ]
[.85197 -0.0125 -6 -9 ]
[.85197 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05209 -30 -4.5 ]
[-0.0125 .05209 0 4.5 ]
[-0.0125 .13003 -6 -4.5 ]
[-0.0125 .13003 0 4.5 ]
[-0.0125 .20797 -24 -4.5 ]
[-0.0125 .20797 0 4.5 ]
[-0.0125 .28591 -24 -4.5 ]
[-0.0125 .28591 0 4.5 ]
[-0.0125 .36384 -24 -4.5 ]
[-0.0125 .36384 0 4.5 ]
[-0.0125 .44178 -30 -4.5 ]
[-0.0125 .44178 0 4.5 ]
[-0.0125 .51972 -30 -4.5 ]
[-0.0125 .51972 0 4.5 ]
[-0.0125 .59765 -30 -4.5 ]
[-0.0125 .59765 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.23085 0 m
.23085 .61803 L
s
.43789 0 m
.43789 .61803 L
s
.64493 0 m
.64493 .61803 L
s
.85197 0 m
.85197 .61803 L
s
0 .05209 m
1 .05209 L
s
0 .13003 m
1 .13003 L
s
0 .20797 m
1 .20797 L
s
0 .28591 m
1 .28591 L
s
0 .36384 m
1 .36384 L
s
0 .44178 m
1 .44178 L
s
0 .51972 m
1 .51972 L
s
0 .59765 m
1 .59765 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23085 0 m
.23085 .00625 L
s
[(5)] .23085 -0.0125 0 1 Mshowa
.43789 0 m
.43789 .00625 L
s
[(10)] .43789 -0.0125 0 1 Mshowa
.64493 0 m
.64493 .00625 L
s
[(15)] .64493 -0.0125 0 1 Mshowa
.85197 0 m
.85197 .00625 L
s
[(20)] .85197 -0.0125 0 1 Mshowa
.125 Mabswid
.06522 0 m
.06522 .00375 L
s
.10663 0 m
.10663 .00375 L
s
.14803 0 m
.14803 .00375 L
s
.18944 0 m
.18944 .00375 L
s
.27226 0 m
.27226 .00375 L
s
.31366 0 m
.31366 .00375 L
s
.35507 0 m
.35507 .00375 L
s
.39648 0 m
.39648 .00375 L
s
.4793 0 m
.4793 .00375 L
s
.5207 0 m
.5207 .00375 L
s
.56211 0 m
.56211 .00375 L
s
.60352 0 m
.60352 .00375 L
s
.68634 0 m
.68634 .00375 L
s
.72774 0 m
.72774 .00375 L
s
.76915 0 m
.76915 .00375 L
s
.81056 0 m
.81056 .00375 L
s
.89337 0 m
.89337 .00375 L
s
.93478 0 m
.93478 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05209 m
.00625 .05209 L
s
[(-2500)] -0.0125 .05209 1 0 Mshowa
0 .13003 m
.00625 .13003 L
s
[(0)] -0.0125 .13003 1 0 Mshowa
0 .20797 m
.00625 .20797 L
s
[(2500)] -0.0125 .20797 1 0 Mshowa
0 .28591 m
.00625 .28591 L
s
[(5000)] -0.0125 .28591 1 0 Mshowa
0 .36384 m
.00625 .36384 L
s
[(7500)] -0.0125 .36384 1 0 Mshowa
0 .44178 m
.00625 .44178 L
s
[(10000)] -0.0125 .44178 1 0 Mshowa
0 .51972 m
.00625 .51972 L
s
[(12500)] -0.0125 .51972 1 0 Mshowa
0 .59765 m
.00625 .59765 L
s
[(15000)] -0.0125 .59765 1 0 Mshowa
.125 Mabswid
0 .06768 m
.00375 .06768 L
s
0 .08327 m
.00375 .08327 L
s
0 .09886 m
.00375 .09886 L
s
0 .11444 m
.00375 .11444 L
s
0 .14562 m
.00375 .14562 L
s
0 .16121 m
.00375 .16121 L
s
0 .17679 m
.00375 .17679 L
s
0 .19238 m
.00375 .19238 L
s
0 .22356 m
.00375 .22356 L
s
0 .23914 m
.00375 .23914 L
s
0 .25473 m
.00375 .25473 L
s
0 .27032 m
.00375 .27032 L
s
0 .30149 m
.00375 .30149 L
s
0 .31708 m
.00375 .31708 L
s
0 .33267 m
.00375 .33267 L
s
0 .34825 m
.00375 .34825 L
s
0 .37943 m
.00375 .37943 L
s
0 .39502 m
.00375 .39502 L
s
0 .4106 m
.00375 .4106 L
s
0 .42619 m
.00375 .42619 L
s
0 .45737 m
.00375 .45737 L
s
0 .47295 m
.00375 .47295 L
s
0 .48854 m
.00375 .48854 L
s
0 .50413 m
.00375 .50413 L
s
0 .5353 m
.00375 .5353 L
s
0 .55089 m
.00375 .55089 L
s
0 .56648 m
.00375 .56648 L
s
0 .58207 m
.00375 .58207 L
s
0 .03651 m
.00375 .03651 L
s
0 .02092 m
.00375 .02092 L
s
0 .00533 m
.00375 .00533 L
s
0 .61324 m
.00375 .61324 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.23085 .61178 m
.23085 .61803 L
s
.43789 .61178 m
.43789 .61803 L
s
.64493 .61178 m
.64493 .61803 L
s
.85197 .61178 m
.85197 .61803 L
s
.125 Mabswid
.06522 .61428 m
.06522 .61803 L
s
.10663 .61428 m
.10663 .61803 L
s
.14803 .61428 m
.14803 .61803 L
s
.18944 .61428 m
.18944 .61803 L
s
.27226 .61428 m
.27226 .61803 L
s
.31366 .61428 m
.31366 .61803 L
s
.35507 .61428 m
.35507 .61803 L
s
.39648 .61428 m
.39648 .61803 L
s
.4793 .61428 m
.4793 .61803 L
s
.5207 .61428 m
.5207 .61803 L
s
.56211 .61428 m
.56211 .61803 L
s
.60352 .61428 m
.60352 .61803 L
s
.68634 .61428 m
.68634 .61803 L
s
.72774 .61428 m
.72774 .61803 L
s
.76915 .61428 m
.76915 .61803 L
s
.81056 .61428 m
.81056 .61803 L
s
.89337 .61428 m
.89337 .61803 L
s
.93478 .61428 m
.93478 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05209 m
1 .05209 L
s
.99375 .13003 m
1 .13003 L
s
.99375 .20797 m
1 .20797 L
s
.99375 .28591 m
1 .28591 L
s
.99375 .36384 m
1 .36384 L
s
.99375 .44178 m
1 .44178 L
s
.99375 .51972 m
1 .51972 L
s
.99375 .59765 m
1 .59765 L
s
.125 Mabswid
.99625 .06768 m
1 .06768 L
s
.99625 .08327 m
1 .08327 L
s
.99625 .09886 m
1 .09886 L
s
.99625 .11444 m
1 .11444 L
s
.99625 .14562 m
1 .14562 L
s
.99625 .16121 m
1 .16121 L
s
.99625 .17679 m
1 .17679 L
s
.99625 .19238 m
1 .19238 L
s
.99625 .22356 m
1 .22356 L
s
.99625 .23914 m
1 .23914 L
s
.99625 .25473 m
1 .25473 L
s
.99625 .27032 m
1 .27032 L
s
.99625 .30149 m
1 .30149 L
s
.99625 .31708 m
1 .31708 L
s
.99625 .33267 m
1 .33267 L
s
.99625 .34825 m
1 .34825 L
s
.99625 .37943 m
1 .37943 L
s
.99625 .39502 m
1 .39502 L
s
.99625 .4106 m
1 .4106 L
s
.99625 .42619 m
1 .42619 L
s
.99625 .45737 m
1 .45737 L
s
.99625 .47295 m
1 .47295 L
s
.99625 .48854 m
1 .48854 L
s
.99625 .50413 m
1 .50413 L
s
.99625 .5353 m
1 .5353 L
s
.99625 .55089 m
1 .55089 L
s
.99625 .56648 m
1 .56648 L
s
.99625 .58207 m
1 .58207 L
s
.99625 .03651 m
1 .03651 L
s
.99625 .02092 m
1 .02092 L
s
.99625 .00533 m
1 .00533 L
s
.99625 .61324 m
1 .61324 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06522 .29926 L
.10663 .36776 L
.14803 .41612 L
.18944 .45662 L
.23085 .48612 L
.27226 .51051 L
.31366 .5299 L
.35507 .54078 L
.39648 .54851 L
.43789 .55578 L
.4793 .5631 L
.5207 .56972 L
.56211 .57573 L
.60352 .58188 L
.64493 .58828 L
.68634 .59391 L
.72774 .59777 L
.76915 .60008 L
.81056 .60144 L
.85197 .60226 L
.89337 .60278 L
.93478 .6031 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.06522 .29926 Mdot
.10663 .36776 Mdot
.14803 .41612 Mdot
.18944 .45662 Mdot
.23085 .48612 Mdot
.27226 .51051 Mdot
.31366 .5299 Mdot
.35507 .54078 Mdot
.39648 .54851 Mdot
.43789 .55578 Mdot
.4793 .5631 Mdot
.5207 .56972 Mdot
.56211 .57573 Mdot
.60352 .58188 Mdot
.64493 .58828 Mdot
.68634 .59391 Mdot
.72774 .59777 Mdot
.76915 .60008 Mdot
.81056 .60144 Mdot
.85197 .60226 Mdot
.89337 .60278 Mdot
.93478 .6031 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`009_ooool2
o`00037ooooo0ol0000_ooooo`?o00001?ooool2o`0002_ooooo0ol00003ooooo`?o0000:oooool5
o`0000?ooooo0_l0000Sooooo`009Oooool01?l0003oooooooooool0000_ooooo`05o`000?oooooo
ooooooooool00000;oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002_ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0000Rooooo`009Oooool01?l0003oooooooooool0000c
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002;ooooo000Uooooo`04o`000?ooooooooooo`0003?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0[ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`0Pooooo`009Oooool01?l0003oooooooooool0000_oooo
o`Co0000<?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002_ooooo00Co0000
oooooooooooooooo1?l0000[ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool0000Rooooo`009Oooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo033o
oooo0_l00004ooooo`04o`000?ooooooooooo`0002[ooooo0_l00003ooooo`03o`000?oooooooooo
02cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0002;ooooo000V
ooooo`;o0000<?ooool5o`0002oooooo00?o0000ooooooooool00oooool2o`0002cooooo00Co0000
oooooooooooooooo1Ol0000[ooooo`?o00001?ooool2o`0002?ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo000Qooooo`0300000?l0003o00000?[o00000@00
0001ooooo`008Oooool00`00003o0000ooooo`02ooooo`<0o`002?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo0Ol000010000007ooooo000Qooooo`0400000?oooooooooo
ooooo`D0o`00<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001o
ooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0027ooooo00@00000oooo
oooooooooooo1@3o000aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool0
0`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool01000
003oooooooooooooool50?l0037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0a
ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qoooo
o`0300000?l0003ooooo00;ooooo0`3o000booooo`030000Oooooooooooo03;ooooo00<0001ooooo
ooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo027ooooo0Ol000010000
007ooooo000Qooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0<Oooool00`0007oo
ooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0Rooooo`4000000Oooool0027ooooo00<00000ooooooooool00oooool00`00003ooooo
ooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oooooo
ooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo033ooooo00<0001oooooooooool0<_ooool00`0007oooooooooo
o`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Q
ooooo`0300000?l0003ooooo00Cooooo00<00000ooooooooool0<?ooool00`0007ooooooooooo`0b
ooooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Q
ooooo`7o00000@000001ooooo`001_ooool5o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`00
00Gooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0`ooooo`030000Oooooooooooo
03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo
02;ooooo0@000001ooooo`001oooool01_l0003oooooooooool0003oooooo`0000?ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00<00000ooooooooool01?ooool00`00003oooooooooo`0`ooooo`030000Oooooooooooo03;ooooo
00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo
0@000001ooooo`001Ol00003ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000oooooooo
ool01?ooool00`00003oooooooooo`0`ooooo`030000Oooooooooooo03;ooooo00<0001ooooooooo
ool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`00
2Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o00@0001o00<000000000
O`0007l0lP0007l1o`00004000000Oooool000Kooooo00Ko0000ooooooooooooooooo`000?ooool4
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo00Cooooo00<00000ooooooooool0<?ooool00`0007ooooooooooo`0booooo`030000
Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`400000
0Oooool000Kooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00Gooooo00<00000
ooooooooool0;oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001o
ooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool000Oooooo0ol00002oooo
o`Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00Gooooo00<00000oooo
ooooool0;oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001ooooo
ooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0027ooooo00<00000o`000?oo
ool01Oooool00`00003oooooooooo`0_ooooo`030000Oooooooooooo03;ooooo00<0001ooooooooo
ool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo027ooooo0Ol000010000007o
oooo000Qooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0;oooool00`0007oooooo
ooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oooooo
ooooo`0Rooooo`4000000Oooool0027ooooo00<00000ooooooooool01Oooool00`00003ooooooooo
o`0_ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oooooooooo
o`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo02oooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0a
ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qoooo
o`0300000?l0003ooooo00Gooooo00<00000ooooooooool0;oooool00`0007ooooooooooo`0boooo
o`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Qoooo
o`7o00000@000001ooooo`008Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo02ko
oooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;o
oooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?oooooooooo00Kooooo
00<00000ooooooooool0;_ooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo
00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0027ooooo00<0
0000ooooooooool01_ooool00`00003oooooooooo`0^ooooo`030000Oooooooooooo03;ooooo00<0
001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@00
0001ooooo`008Oooool00`00003o0000ooooo`06ooooo`0300000?oooooooooo02kooooo00<0001o
ooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001o
ooooooooool08Oooool1o`00004000000Oooool0027ooooo00<00000ooooooooool01_ooool00`00
003oooooooooo`0^ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`00
07ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`06ooooo`0300000?oooooooooo02kooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007o
oooo000Qooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0;_ooool00`0007oooooo
ooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oooooo
ooooo`0Rooooo`4000000Oooool0027ooooo00<00000o`000?ooool01_ooool00`00003ooooooooo
o`0^ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oooooooooo
o`0booooo`030000Oooooooooooo027ooooo0Ol000010000007ooooo000Jooooo`;o00001Oooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo02gooooo00<0001oooooooooool0<_ooool0
0`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool1
0000007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01oooool0
0`00003oooooooooo`0]ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool0
0`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`006Oooool01?l0
003oooooooooool00004ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0;Oooool0
0`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool0
0`0007ooooooooooo`0Rooooo`4000000Oooool001Wooooo00Co0000oooooooooooo00001?ooool0
0`00003o00000000O`070000O`030000000007l0001o0>l0001o0Ol000010000007ooooo000Ioooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool01oooool00`00003oooooooooo`0]
ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0b
ooooo`030000Oooooooooooo02;ooooo0@000001ooooo`006Oooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0;Oooool00`0007ooooooooooo`0b
ooooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0R
ooooo`4000000Oooool001[ooooo0_l00005ooooo`0300000?oooooooooo00Oooooo00<00000oooo
ooooool0;Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001ooooo
ooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0027ooooo00<00000o`000?oo
ool02?ooool00`00003oooooooooo`0/ooooo`030000Oooooooooooo03;ooooo00<0001ooooooooo
ool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo027ooooo0Ol000010000007o
oooo000Qooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0;?ooool00`0007oooooo
ooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oooooo
ooooo`0Rooooo`4000000Oooool0027ooooo00<00000ooooooooool02?ooool00`00003ooooooooo
o`0/ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oooooooooo
o`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003oooooooooo`08
ooooo`0300000?oooooooooo02cooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0a
ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qoooo
o`0300000?l0003ooooo00Sooooo00<00000ooooooooool0;?ooool00`0007ooooooooooo`0boooo
o`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Qoooo
o`7o00000@000001ooooo`008Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo02co
oooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;o
oooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?oooooooooo00Sooooo
00<00000ooooooooool0;?ooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo
00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0027ooooo00<0
0000ooooooooool02Oooool00`00003oooooooooo`0[ooooo`030000Oooooooooooo03;ooooo00<0
001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@00
0001ooooo`008Oooool00`00003o0000ooooo`09ooooo`0300000?oooooooooo02_ooooo00<0001o
ooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001o
ooooooooool08Oooool1o`00004000000Oooool0027ooooo00<00000ooooooooool02Oooool00`00
003oooooooooo`0[ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`00
07ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`09ooooo`0300000?oooooooooo02_ooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007o
oooo000Qooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0:oooool00`0007oooooo
ooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oooooo
ooooo`0Rooooo`4000000Oooool0027ooooo00<00000o`000?ooool02Oooool00`00003ooooooooo
o`0[ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oooooooooo
o`0booooo`030000Oooooooooooo027ooooo0Ol000010000007ooooo0006ooooo`Go00000_ooool3
o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`09ooooo`0300000?oooooo
oooo02_ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooo
oooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo0007ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo02[o
oooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;o
oooo00<0001oooooooooool08_ooool10000007ooooo0008ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00<00000o`00000007l02P0007l00`000000001o0000O`3/0000O`7o00000@000001oooo
o`002Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00[ooooo00<00000
ooooooooool0:_ooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001o
ooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool000Kooooo00Ko0000oooo
ooooooooooooo`000?ooool4o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool0:_ooool00`0007oo
ooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0Rooooo`4000000Oooool000Kooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00Kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0booooo`030000Oooo
oooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Ooo
ool000Oooooo0ol00002ooooo`Go00000oooool2o`0000Cooooo0_l00005ooooo`0300000?l0003o
oooo00[ooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0booooo`030000Oooooooo
oooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Qooooo`7o00000@000001
ooooo`008Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo02[ooooo00<0001ooooo
ooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001ooooo
ooooool08_ooool10000007ooooo000Qooooo`0300000?oooooooooo00[ooooo00<00000oooooooo
ool0:_ooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001ooooooooo
ool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0027ooooo00<00000ooooooooool0
2oooool00`00003oooooooooo`0Yooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0
<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Ooo
ool00`00003o0000ooooo`0;ooooo`0300000?oooooooooo02Wooooo00<0001oooooooooool0<_oo
ool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08Ooo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool02oooool00`00003oooooooooo`0Y
ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0b
ooooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0;oooo
o`0300000?oooooooooo02Wooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aoooo
o`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`03
00000?oooooooooo00_ooooo00<00000ooooooooool0:Oooool00`0007ooooooooooo`0booooo`03
0000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`40
00000Oooool0027ooooo00<00000o`000?ooool02oooool00`00003oooooooooo`0Yooooo`030000
Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000
Oooooooooooo027ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo00_ooooo00<0
0000ooooooooool0:Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0
001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0027ooooo00<00000
ooooooooool03?ooool00`00003oooooooooo`0Xooooo`030000Oooooooooooo03;ooooo00<0001o
ooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001
ooooo`008Oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo02Sooooo00<0001ooooo
ooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001ooooo
ooooool08_ooool10000007ooooo000Qooooo`0300000?l0003ooooo00cooooo00<00000oooooooo
ool0:?ooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001ooooooooo
ool0<_ooool00`0007ooooooooooo`0Qooooo`7o00000@000001ooooo`008Oooool00`00003ooooo
ooooo`0<ooooo`0300000?oooooooooo02Sooooo00<0001oooooooooool0<_ooool00`0007oooooo
ooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo
0007ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo02Sooooo00<0001oooooooooool0<_ooool00`0007oooooooooo
o`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo0006
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0<oooo
o`0300000?oooooooooo02Sooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aoooo
o`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000:ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00<00000o`00000007l0300007l00`000000001o0000
O`3Z0000O`7o00000@000001ooooo`002_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
00000?oooooooooo00gooooo00<00000ooooooooool09oooool00`0007ooooooooooo`0booooo`03
0000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`40
00000Oooool000Kooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00cooooo0`3o000X
ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0b
ooooo`030000Oooooooooooo02;ooooo0@000001ooooo`001_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo00_ooooo1@3o000Wooooo`030000Oooooooooooo03;ooooo
00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo
0@000001ooooo`001_ooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<0
0000o`000?ooool02oooool50?l002Oooooo00<0001oooooooooool0<_ooool00`0007oooooooooo
o`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08Oooool1o`00004000000Ooo
ool0027ooooo00<00000ooooooooool02oooool50?l002Oooooo00<0001oooooooooool0<_ooool0
0`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool1
0000007ooooo000Qooooo`0300000?oooooooooo00cooooo0`3o000Xooooo`030000Oooooooooooo
03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo
02;ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02Go
oooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;o
oooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?l0003ooooo00oooooo
00<00000ooooooooool09Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo
00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Qooooo`7o00000@000001ooooo`008Ooo
ool00`00003oooooooooo`0@ooooo`0300000?oooooooooo02Cooooo00<0001oooooooooool0<_oo
ool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_oo
ool10000007ooooo000Qooooo`0300000?oooooooooo017ooooo00<00000ooooooooool08oooool0
0`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool0
0`0007ooooooooooo`0Rooooo`4000000Oooool0027ooooo00<00000ooooooooool04Oooool00`00
003oooooooooo`0Sooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`00
07ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003o
0000ooooo`0Booooo`0300000?oooooooooo02;ooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08Oooool1o`000040
00000Oooool0027ooooo00<00000ooooooooool04oooool00`00003oooooooooo`0Qooooo`030000
Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000
Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Cooooo`0300000?oo
oooooooo027ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooo
oooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?oooooo
oooo01Cooooo00<00000ooooooooool08?ooool00`0007ooooooooooo`0booooo`030000Oooooooo
oooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0
027ooooo00<00000o`000?ooool05?ooool00`00003oooooooooo`0Pooooo`030000Oooooooooooo
03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo
027ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo01Gooooo00<00000oooooooo
ool07oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001ooooooooo
ool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool000Sooooo00?o0000ooooooooool0
0_ooool3o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0Fooooo`030000
0?oooooooooo01kooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000
Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo0008ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0Fooooo`040000003o0000o`00
0?l001gooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooo
oooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo0009ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00<00000o`00000007l05P0007l50?l00=h0001o0Ol000010000007ooooo0009
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool05_ooool50?l001cooooo
00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo
00<0001oooooooooool08_ooool10000007ooooo000:ooooo`03o`000?oooooo000000?o00000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool05_ooool50?l001cooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`03
0000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo0006ooooo`07o`00
0?ooooooooooooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`0Gooooo`<0o`007Oooool00`0007oooooooooo
o`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oooooooooo
o`0Rooooo`4000000Oooool000Kooooo1Ol000000ooooooo0000o`000003o`0000?ooooo0_l00004
ooooo`;o00001Oooool00`00003o0000ooooo`0Jooooo`0300000?oooooooooo01[ooooo00<0001o
ooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001o
ooooooooool08Oooool1o`00004000000Oooool0027ooooo00<00000ooooooooool06oooool00`00
003oooooooooo`0Iooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`00
07ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003o
ooooooooo`0Looooo`0300000?oooooooooo01Sooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007o
oooo000Qooooo`0300000?oooooooooo01gooooo00<00000ooooooooool05oooool00`0007oooooo
ooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oooooo
ooooo`0Rooooo`4000000Oooool0027ooooo00<00000o`000?ooool07Oooool00`00003ooooooooo
o`0Gooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oooooooooo
o`0booooo`030000Oooooooooooo027ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooo
oooo01kooooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0booooo`030000Oooooooo
oooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0
027ooooo00<00000ooooooooool07oooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo
03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo
02;ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Pooooo`040000003o0000o`000?l0
01?ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo
03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?l0003ooooo023o
oooo1@3o000Booooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oo
ooooooooo`0booooo`030000Oooooooooooo027ooooo0Ol000010000007ooooo000Qooooo`030000
0?oooooooooo023ooooo1@3o000Booooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0
<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Ooo
ool00`00003oooooooooo`0Pooooo`D0o`004_ooool00`0007ooooooooooo`0booooo`030000Oooo
oooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Ooo
ool0027ooooo00<00000ooooooooool08Oooool30?l0000300000?oooooooooo013ooooo00<0001o
ooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001o
ooooooooool08_ooool10000007ooooo000Qooooo`0300000?l0003ooooo02Gooooo00<00000oooo
ooooool03oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001ooooo
ooooool0<_ooool00`0007ooooooooooo`0Qooooo`7o00000@000001ooooo`0000Coooooo`000?l0
003o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000oooo
ooooool09_ooool00`00003oooooooooo`0>ooooo`030000Oooooooooooo03;ooooo00<0001ooooo
ooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001oooo
o`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool09oooool00`00003oooooooooo`0=ooooo`030000Oooooooooooo03;ooooo
00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo
0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000Cooooo00<00000ooooooooool0:?ooool00`00003oooooooooo`0<ooooo`030000Oooooooo
oooo03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooo
oooo02;ooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000o`00000007l0:@0007l00`000000001o0000O`3=0000O`7o
00000@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000Cooooo00<00000ooooooooool0:_ooool00`00003oooooooooo`0:ooooo`030000Oooo
oooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooo
oooooooo02;ooooo0@000001ooooo`0000?oooooo`000?l000001?ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00004ooooo`0300000?oooooooooo02_ooooo00@000000?l0003o0000o`002?ooool0
0`0007ooooooooooo`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool0
0`0007ooooooooooo`0Rooooo`4000000Oooool000;ooooo00?o0000ooooooooool00oooool2o`00
00Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool0:oooool50?l0
00Oooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo
03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?l0003ooooo02_o
oooo1@3o0007ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oo
ooooooooo`0booooo`030000Oooooooooooo027ooooo0Ol000010000007ooooo000Qooooo`030000
0?oooooooooo02_ooooo1@3o0007ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0
<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Ooo
ool00`00003oooooooooo`0/ooooo`<0o`0000?ooooo0000000000001Oooool00`0007oooooooooo
o`0booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oooooooooo
o`0Rooooo`4000000Oooool0027ooooo00<00000ooooooooool0<_ooool00`00003oooooooooo`02
ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0b
ooooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003o0000ooooo`0coooo
o`0500000?ooooooooooooooo`0007l0=?ooool00`0007ooooooooooo`0aooooo`030000Oooooooo
oooo03;ooooo00<0001oooooooooool08Oooool1o`00004000000Oooool0027ooooo00<00000oooo
ooooool0=?ooool2000000<0o`00<oooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo
03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?oooooooooo03Go
oooo1@3o000booooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0Rooooo`4000000Oooool0027ooooo00<00000ooooooooool0=Oooool50?l003;ooooo
00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo
0@000001ooooo`008Oooool00`00003o0000ooooo`0eooooo`D0o`0000<00000ooooooooool0;ooo
ool00`0007ooooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08Ooo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool0=_ooool30?l000;ooooo0P00000_
ooooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0R
ooooo`4000000Oooool0027ooooo00<00000ooooooooool0=oooool00`0007ooooooooooo`03oooo
o`0300000?oooooooooo02cooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0boooo
o`030000Oooooooooooo02;ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0gooooo`03
0000Oooooooooooo00Cooooo0P0000001?ooool0o`000?l0003o000Xooooo`030000Oooooooooooo
037ooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool0027o
oooo00<00000o`000?ooool0=oooool00`0007ooooooooooo`06ooooo`D0o`009oooool00`0007oo
ooooooooo`0aooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08Oooool1o`000040
00000Oooool00004ooooool0003o0000o`0000;ooooo1Ol00002ooooo`?o00001?ooool2o`0000Co
oooo0_l00005ooooo`0300000?oooooooooo03Oooooo00<0001oooooooooool01_ooool50?l002Oo
oooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;o
oooo0@000001ooooo`000_ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00_ooool00`00003oooooooooo`0gooooo`030000Oooooooooooo00Kooooo1@3o
00000`00003oooooooooo`0Tooooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_oo
ool00`0007ooooooooooo`0Rooooo`4000000Oooool000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo03Oooooo00<0001oooooooooool0
1oooool30?l000;ooooo0P00000Tooooo`030000Oooooooooooo037ooooo00<0001oooooooooool0
<_ooool00`0007ooooooooooo`0Rooooo`4000000Oooool000;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o04P0001o0P000000100007l0
o`000?l0003o002[0000O`7o00000@000001ooooo`000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000000ol00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00001?ooool00`00003oooooooooo`0gooooo`030000Oooooooooooo013ooooo1@3o
000Mooooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oooooooooo
o`0Rooooo`4000000Oooool00003ooooool0003o000000?ooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo03Oooooo00<0001oooooooooool04?ooool50?l001gooooo00<0001ooooo
ooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001oooo
o`000_ooool00ol0003oooooooooo`02ooooo`?o00000_ooool5o`0000?ooooo0_l00004ooooo`;o
00001Oooool00`00003oooooooooo`0gooooo`030000Oooooooooooo013ooooo1@3o0004000000?o
oooo0`3o000Cooooo`030000Oooooooooooo037ooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0Rooooo`4000000Oooool0027ooooo00<00000o`000?ooool0=oooool00`0007oooooo
ooooo`0Aooooo`<0o`001Oooool2000000D0o`004_ooool00`0007ooooooooooo`0aooooo`030000
Oooooooooooo03;ooooo00<0001oooooooooool08Oooool1o`00004000000Oooool0027ooooo00<0
0000ooooooooool0=oooool00`0007ooooooooooo`0Kooooo`D0o`0000<00000ooooooooool00ooo
ool30?l000Wooooo00<0001oooooooooool0<Oooool00`0007ooooooooooo`0booooo`030000Oooo
oooooooo02;ooooo0@000001ooooo`008Oooool00`00003oooooooooo`0gooooo`030000Oooooooo
oooo01_ooooo1@3o00000oooool0000000000002000000D0o`002?ooool00`0007ooooooooooo`0a
ooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qoooo
o`0300000?l0003ooooo03Oooooo00<0001oooooooooool07?ooool30?l000Kooooo1@3o00000`00
003oooooooooo`04ooooo`<0o`00<_ooool00`0007ooooooooooo`0booooo`030000Oooooooooooo
027ooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo03Oooooo00<0001ooooooooo
ool09Oooool50?l00003ooooo`000000000000<000001@3o000aooooo`030000Oooooooooooo03;o
oooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?oooooooooo03Oooooo
00<0001oooooooooool09_ooool30?l000Oooooo1@3o00000`00003oooooooooo`03ooooo`<0o`00
:?ooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;ooooo0@000001ooooo`008Ooo
ool00`00003oooooooooo`0gooooo`030000Oooooooooooo033ooooo1@3o00000oooool000000000
0002000000D0o`001oooool30?l001gooooo00<0001oooooooooool0<_ooool00`0007oooooooooo
o`0Rooooo`4000000Oooool0027ooooo00<00000o`000?ooool0=oooool00`0007ooooooooooo`0a
ooooo`<0o`001_ooool50?l000@000000_ooool50?l001cooooo00<0001oooooooooool0<_ooool0
0`0007ooooooooooo`0Qooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0goooo
o`030000Oooooooooooo03;ooooo00<0001oooooooooool01Oooool50?l000Cooooo0P0000050?l0
000300000?oooooooooo00?ooooo0`3o000Cooooo`030000Oooooooooooo03;ooooo00<0001ooooo
ooooool08_ooool10000007ooooo000Qooooo`0300000?oooooooooo03Oooooo00<0001ooooooooo
ool0<_ooool00`0007ooooooooooo`06ooooo`<0o`001oooool50?l00003ooooo`00000000000080
00001@3o0007ooooo`<0o`002?ooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02;o
oooo0@000001ooooo`008Oooool00`00003oooooooooo`0gooooo`030000Oooooooooooo03;ooooo
00<0001oooooooooool04Oooool30?l000Kooooo1@3o0004000000;ooooo1@3o0007ooooo`030000
Oooooooooooo03;ooooo00<0001oooooooooool08_ooool10000007ooooo000Qooooo`0300000?l0
003ooooo03Oooooo00<0001oooooooooool0<_ooool00`0007ooooooooooo`0Jooooo`D0o`001?oo
ool2000000D0o`0000<00000ooooooooool00oooool30?l003?ooooo00<0001oooooooooool08Ooo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool0=oooool00`0007ooooooooooo`0b
ooooo`030000Oooooooooooo01_ooooo0`3o0007ooooo`D0o`0000?ooooo0000000000000P000005
0?l000Oooooo0`3o000Xooooo`030000Oooooooooooo02;ooooo0@000001ooooo`0000Coooooo`00
0?l0003o00000oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000
ooooooooool0=oooool00`0007ooooooooooo`0booooo`030000Oooooooooooo02Kooooo0`3o0006
ooooo`D0o`0010000002ooooo`D0o`001_ooool30?l001kooooo00<0001oooooooooool08_ooool1
0000007ooooo0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`0300000?oooooooooo03Oooooo00<0001oooooooooool0<_ooool00`0007oo
ooooooooo`0_ooooo`D0o`001?ooool2000000D0o`000`000002ooooo`D0o`001oooool30?l000Oo
oooo0`3o0009ooooo`030000Oooooooooooo02;ooooo0@000001ooooo`000_ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`00000007l0W`0007l3
0?l000L0001o1@3o00030000O`8000001@3o000400000080001o1@3o00050000O`D0o`001`0007l3
0?l000L0001o0`3o00080000O`<0o`001`0007l30?l000<0001o0Ol000010000007ooooo0002oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003ooooo
ooooo`0gooooo`030000Oooooooooooo03;ooooo00<0001oooooooooool0<Oooool00`0007oooooo
ooooo`07ooooo`<0o`001_ooool50?l000Cooooo0P0000050?l000D000001@3o0004000000;ooooo
1@3o0005ooooo`D0o`001_ooool50?l000Gooooo1@3o0003ooooo`4000000Oooool000;ooooo00Co
0000oooooooooooooooo1?l00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo03Oooooo00<0001o
ooooooooool0<_ooool00`0007ooooooooooo`0aooooo`030000Oooooooooooo017ooooo0`3o0007
ooooo`D0o`001Oooool50?l000Cooooo0P0000050?l000D000001@3o0006000000D0o`001@000005
0?l000?ooooo0@000001ooooo`0000?oooooo`000?l000000oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo03Oooooo00<0001oooooooooool0<_ooool00`0007oooooo
ooooo`0aooooo`030000Oooooooooooo01cooooo0`3o0007ooooo`<0o`001oooool50?l000Gooooo
1@3o0006ooooo`D0o`001Oooool50?l000?ooooo0@000001ooooo`000_ooool01?l0003ooooooooo
ooooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000o`000?ooool0
0oooool00`00003oooooooooo`0aooooo`0300000?oooooooooo03;ooooo00<00000ooooooooool0
<Oooool00`00003oooooooooo`0aooooo`<0o`001oooool30?l000Sooooo0`3o0007ooooo`<0o`00
0oooool1o`00004000000Oooool0027ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00<00000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00`00003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00<00000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool10000007ooooo000Q
ooooooh000000Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.73272, -6213.84, \
0.0951907, 126.437}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resulting classification of 2d space", "Subsection"],

Cell[BoxData[{
    \(\(pts\  = \ 150;\)\), "\n", 
    \(\(reg1\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model1];\)\), "\n", 
    \(\(reg2\  = 
        MixtureLikelihoodMatrix[{0. , 1. , 0. , 1. }, pts, 
          model2];\)\), "\[IndentingNewLine]", 
    \(\(class\  = 
        Partition[\(If[#[\([1]\)]\  < \ #[\([2]\)], \ 1, 
                0] &\)\  /@ \ \(({Flatten[reg1], \ Flatten[reg2]}\  // \ 
                Transpose)\), pts + 1];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\n\)\(classPlot1\  = 
      ListDensityPlot[class, \ 
        ColorFunction -> \((If[# \[Equal] 0, pointStyle1[\([1]\)], \ 
                White] &)\), \ Mesh -> False, \ 
        MeshRange -> {{0, 1}, {0, 1}}, FrameTicks \[Rule] None, nS]; 
    classPlot2\  = 
      ListDensityPlot[class, \ 
        ColorFunction -> \((If[# == 1, pointStyle2[\([1]\)], White] &)\), \ 
        Mesh -> False, \ MeshRange -> {{0, 1}, {0, 1}}, 
        FrameTicks \[Rule] None, nS];\[IndentingNewLine]
    \(Show[GraphicsArray[{{g1, g2}, {classPlot1, classPlot2}}], imSize, 
        yS];\)\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 400 400 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0238095 0.477324 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8000FF8000FF8000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0238095 0.97619 0.477324 MathSubStart
%% DensityGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.961538 0.0192308 0.961538 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
453 string
151 151 8 [151 0 0 151 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.522676 0.477324 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 .5 0 r
.01 w
.96078 .96078 Mdot
.71373 .72157 Mdot
.52941 .52549 Mdot
.13725 .14902 Mdot
.87843 .88235 Mdot
.11373 .1098 Mdot
.1098 .11373 Mdot
.77647 .78039 Mdot
.15294 .14902 Mdot
.13725 .12549 Mdot
.13333 .1451 Mdot
.1451 .13333 Mdot
.20784 .18824 Mdot
.17255 .15686 Mdot
.4902 .49804 Mdot
.1451 .13333 Mdot
.26275 .23137 Mdot
.23529 .21569 Mdot
.47451 .48235 Mdot
.89804 .82745 Mdot
1 .96863 Mdot
.13333 .12941 Mdot
.20784 .18824 Mdot
.24706 .20784 Mdot
.11373 .11765 Mdot
.3451 .16863 Mdot
.49804 .32941 Mdot
.65098 .53725 Mdot
.84314 .74902 Mdot
.94902 .89412 Mdot
.1451 .14118 Mdot
.18431 .16863 Mdot
.20392 .17647 Mdot
.20784 .20784 Mdot
.55294 .39216 Mdot
.41176 .14118 Mdot
.42353 .22745 Mdot
.36078 .2 Mdot
.38824 .25882 Mdot
.21569 .19608 Mdot
.21569 .20392 Mdot
.18824 .16863 Mdot
.22353 .20784 Mdot
.25098 .25098 Mdot
.52941 .17647 Mdot
.47843 .16863 Mdot
.41961 .19608 Mdot
.44706 .25882 Mdot
.33725 .17647 Mdot
.1451 .12941 Mdot
.14902 .11765 Mdot
.17647 .1451 Mdot
.24706 .23529 Mdot
1 .93725 Mdot
.58824 .18824 Mdot
.51373 .18039 Mdot
.45882 .22353 Mdot
.43137 .21569 Mdot
.43529 .26667 Mdot
.15686 .13725 Mdot
.21961 .19216 Mdot
.18039 .14902 Mdot
.26667 .26667 Mdot
1 .96471 Mdot
.77647 .36078 Mdot
.61176 .25882 Mdot
.45098 .2 Mdot
.4549 .25882 Mdot
.42745 .18824 Mdot
.18039 .14902 Mdot
.25098 .20784 Mdot
.14902 .11765 Mdot
.21961 .2 Mdot
.50196 .50196 Mdot
.73725 .32157 Mdot
.58039 .21176 Mdot
.4549 .18431 Mdot
.51765 .32157 Mdot
.46275 .18431 Mdot
.21176 .11765 Mdot
.18824 .15294 Mdot
.19608 .16471 Mdot
.18431 .16471 Mdot
.16471 .16078 Mdot
.82353 .72549 Mdot
.65882 .25098 Mdot
.53725 .16863 Mdot
.54118 .28627 Mdot
.54118 .34118 Mdot
.50588 .18824 Mdot
.23137 .07059 Mdot
.16471 .13725 Mdot
.23922 .21176 Mdot
.25882 .24706 Mdot
.14118 .13725 Mdot
.52941 .44314 Mdot
.37255 .12549 Mdot
.57647 .18824 Mdot
.5451 .17255 Mdot
.77255 .5451 Mdot
.64706 .43922 Mdot
.52549 .17255 Mdot
.28235 .09804 Mdot
.16863 .14118 Mdot
.27843 .25098 Mdot
.18431 .18039 Mdot
.15294 .10588 Mdot
.2902 .17255 Mdot
.96078 .92549 Mdot
.63922 .23922 Mdot
.54902 .16471 Mdot
.55686 .2 Mdot
.58039 .38039 Mdot
.49804 .2549 Mdot
.67059 .27059 Mdot
.23529 .11765 Mdot
.17255 .14118 Mdot
.22353 .21176 Mdot
.16863 .14902 Mdot
.29804 .12157 Mdot
.33725 .22353 Mdot
.8902 .82353 Mdot
.62353 .22353 Mdot
.56471 .16471 Mdot
.58824 .15686 Mdot
.55294 .33725 Mdot
.71373 .49412 Mdot
.53725 .2 Mdot
.5098 .2549 Mdot
.2 .13725 Mdot
.18431 .1451 Mdot
.18039 .14902 Mdot
.20392 .01961 Mdot
.67059 .51373 Mdot
.35294 .24706 Mdot
.88627 .83529 Mdot
.63137 .21961 Mdot
.59216 .16078 Mdot
.64706 .18039 Mdot
.78431 .55294 Mdot
.83137 .61569 Mdot
.67059 .41176 Mdot
.47451 .24706 Mdot
.27059 .15686 Mdot
.2 .13725 Mdot
.19216 .1098 Mdot
.33725 .10196 Mdot
.63529 .47843 Mdot
.61569 .50196 Mdot
.34902 .23529 Mdot
1 .97255 Mdot
.63137 .19216 Mdot
.64314 .17647 Mdot
.67059 .2 Mdot
.80392 .57255 Mdot
.41961 .21176 Mdot
.68627 .47059 Mdot
.8 .62745 Mdot
.25098 .12549 Mdot
.21961 .11765 Mdot
.26275 .08235 Mdot
.42745 .18039 Mdot
.66275 .52549 Mdot
.61569 .5098 Mdot
.41569 .29412 Mdot
.76078 .7098 Mdot
.53333 .19608 Mdot
.72549 .25882 Mdot
.66275 .19216 Mdot
.64314 .19216 Mdot
.83529 .63922 Mdot
.67059 .43922 Mdot
.58431 .40392 Mdot
.52157 .39608 Mdot
.37647 .18431 Mdot
.28235 .09412 Mdot
.49412 .18039 Mdot
.46667 .27451 Mdot
.56471 .47451 Mdot
.6 .49412 Mdot
.50588 .40392 Mdot
.63137 .56078 Mdot
.44706 .16863 Mdot
.67451 .23137 Mdot
.90196 .44706 Mdot
.76471 .27451 Mdot
.90588 .65098 Mdot
.48235 .26667 Mdot
.93333 .76078 Mdot
.61569 .50588 Mdot
.59216 .40784 Mdot
.38431 .20392 Mdot
.61176 .2549 Mdot
.63922 .44314 Mdot
.72549 .60392 Mdot
.58824 .48627 Mdot
.64706 .54118 Mdot
.39608 .29412 Mdot
.78824 .74902 Mdot
.60784 .21569 Mdot
.73725 .38039 Mdot
.83922 .38824 Mdot
.83922 .34902 Mdot
.9451 .69412 Mdot
.57647 .35294 Mdot
.76471 .61569 Mdot
.66275 .54902 Mdot
.39608 .2549 Mdot
.56471 .38824 Mdot
.6549 .29804 Mdot
.62745 .41569 Mdot
.72549 .6 Mdot
.54902 .38824 Mdot
.61961 .51765 Mdot
.62745 .52941 Mdot
.34118 .23922 Mdot
.98039 .9098 Mdot
.71373 .2549 Mdot
.92157 .57255 Mdot
.67843 .25098 Mdot
.8549 .38824 Mdot
.98431 .74902 Mdot
.54118 .27843 Mdot
.72941 .60784 Mdot
1 .88627 Mdot
1 .89804 Mdot
.84706 .64314 Mdot
.63922 .32157 Mdot
.67059 .44314 Mdot
.68627 .5451 Mdot
.49804 .32941 Mdot
.61569 .51373 Mdot
.65882 .55294 Mdot
.27059 .17255 Mdot
.91373 .87843 Mdot
.64314 .18431 Mdot
.85098 .54902 Mdot
.8902 .59216 Mdot
.67059 .25882 Mdot
.82745 .41961 Mdot
1 .85098 Mdot
.95294 .78431 Mdot
.85098 .73333 Mdot
.83529 .71765 Mdot
.81961 .67059 Mdot
.53333 .22353 Mdot
.67451 .37647 Mdot
.47843 .2549 Mdot
.51373 .32549 Mdot
.53333 .35686 Mdot
.64314 .56078 Mdot
.63922 .5451 Mdot
.23922 .13333 Mdot
.92941 .89412 Mdot
.5451 .54118 Mdot
.38431 .38824 Mdot
.56078 .18824 Mdot
.69412 .26667 Mdot
.56863 .29412 Mdot
.84314 .56471 Mdot
.74118 .29412 Mdot
.77647 .43137 Mdot
.67451 .38431 Mdot
.75294 .63529 Mdot
.95686 .75686 Mdot
.50588 .3451 Mdot
.86275 .6549 Mdot
.47451 .16471 Mdot
.66667 .33725 Mdot
.64314 .4902 Mdot
.52157 .3098 Mdot
.63529 .4902 Mdot
.63137 .58431 Mdot
.63529 .54118 Mdot
.20784 .12549 Mdot
.93725 .90196 Mdot
.18431 .16863 Mdot
.21569 .20392 Mdot
.83137 .83137 Mdot
.74902 .25098 Mdot
.93725 .70196 Mdot
1 .86667 Mdot
.83529 .53333 Mdot
.77647 .3451 Mdot
.57647 .2549 Mdot
.69804 .38824 Mdot
.89804 .74118 Mdot
.91765 .58431 Mdot
.98431 .79216 Mdot
.90196 .66667 Mdot
.48235 .18039 Mdot
.53333 .21569 Mdot
.55686 .43529 Mdot
.5098 .2902 Mdot
.61961 .47059 Mdot
.60392 .58824 Mdot
.61569 .5451 Mdot
.31373 .22353 Mdot
.66275 .60392 Mdot
.11373 .1098 Mdot
.24706 .21569 Mdot
.23137 .21961 Mdot
.86275 .76863 Mdot
.73333 .23529 Mdot
.98431 .84314 Mdot
.95686 .84706 Mdot
.66667 .3098 Mdot
.94902 .49412 Mdot
.61176 .26667 Mdot
.81569 .4902 Mdot
.86667 .68627 Mdot
.7451 .33333 Mdot
.9098 .67059 Mdot
.77647 .53725 Mdot
.56078 .25882 Mdot
.48235 .17255 Mdot
.58431 .47843 Mdot
.50196 .23529 Mdot
.56471 .41176 Mdot
.47843 .48235 Mdot
.61961 .56863 Mdot
.52941 .41176 Mdot
.22745 .15294 Mdot
.71373 .71765 Mdot
.27059 .25098 Mdot
.30196 .26667 Mdot
.1098 .1098 Mdot
.66275 .23529 Mdot
.6 .27059 Mdot
.98431 .85098 Mdot
.72157 .59608 Mdot
.8 .28627 Mdot
.95294 .48627 Mdot
.71373 .29804 Mdot
.80784 .52941 Mdot
.78039 .43922 Mdot
.86667 .49804 Mdot
.92157 .62745 Mdot
.82745 .56863 Mdot
.69412 .30196 Mdot
.81569 .63922 Mdot
.47451 .27059 Mdot
.5451 .22353 Mdot
.65098 .60784 Mdot
.42353 .41961 Mdot
.58039 .52157 Mdot
.51373 .38039 Mdot
.19216 .12157 Mdot
.12157 .12157 Mdot
.21176 .18039 Mdot
.21961 .17647 Mdot
.15294 .14118 Mdot
.59608 .21176 Mdot
.65882 .35294 Mdot
.83922 .68627 Mdot
.78431 .67059 Mdot
.80784 .32157 Mdot
.83137 .32549 Mdot
.9451 .51373 Mdot
.63922 .34902 Mdot
1 .78431 Mdot
.79608 .38824 Mdot
.64314 .29412 Mdot
.58431 .27843 Mdot
.60392 .25098 Mdot
.41176 .11765 Mdot
.41176 .24314 Mdot
.55294 .18824 Mdot
.40784 .27059 Mdot
.40392 .41569 Mdot
.52549 .46667 Mdot
.46667 .33725 Mdot
.4549 .3451 Mdot
.1098 .09804 Mdot
.22353 .20392 Mdot
.27843 .23529 Mdot
.27059 .2549 Mdot
.46667 .27843 Mdot
.6 .22353 Mdot
.76863 .60392 Mdot
.94902 .79216 Mdot
.64314 .4 Mdot
.81569 .30196 Mdot
.81569 .32157 Mdot
.74118 .47843 Mdot
.69804 .46667 Mdot
.75686 .29804 Mdot
.6902 .42353 Mdot
.69412 .34118 Mdot
1 .75686 Mdot
.59608 .16078 Mdot
.70588 .56471 Mdot
.54118 .19608 Mdot
.53333 .22353 Mdot
.49804 .50196 Mdot
.52549 .41569 Mdot
.4902 .40784 Mdot
.43922 .31765 Mdot
.34118 .30196 Mdot
.13333 .10196 Mdot
.21176 .18431 Mdot
.21961 .18431 Mdot
.35686 .36471 Mdot
.73333 .24706 Mdot
.83529 .65098 Mdot
.86275 .66667 Mdot
.8902 .77255 Mdot
.73333 .42353 Mdot
.83137 .28627 Mdot
.64706 .32941 Mdot
.70196 .60392 Mdot
.76078 .36471 Mdot
.70588 .41176 Mdot
.74118 .46275 Mdot
.61961 .38431 Mdot
.62353 .20784 Mdot
.47843 .13333 Mdot
.64706 .45098 Mdot
.55686 .18431 Mdot
.3451 .18824 Mdot
.43137 .38824 Mdot
.4549 .33725 Mdot
.49412 .40784 Mdot
.38039 .2902 Mdot
.18039 .15294 Mdot
.18431 .16471 Mdot
.20392 .17255 Mdot
.28627 .27451 Mdot
.56078 .41176 Mdot
.7451 .26275 Mdot
.90196 .73333 Mdot
.82353 .67451 Mdot
.83922 .70588 Mdot
.94118 .55686 Mdot
.78431 .33333 Mdot
.73333 .61569 Mdot
.63137 .53333 Mdot
.74118 .28235 Mdot
.63137 .4549 Mdot
.68627 .4902 Mdot
.57647 .34118 Mdot
.66275 .18824 Mdot
.52941 .26275 Mdot
.41569 .16863 Mdot
.4902 .18431 Mdot
.5451 .47843 Mdot
.6902 .58431 Mdot
.38431 .26275 Mdot
.43922 .35686 Mdot
.50588 .45098 Mdot
.17647 .14118 Mdot
.15294 .12549 Mdot
.15686 .12157 Mdot
.14118 .1451 Mdot
.63529 .24706 Mdot
.50196 .19216 Mdot
.6902 .5098 Mdot
.94118 .8 Mdot
.8 .68627 Mdot
.8 .28627 Mdot
.59216 .37647 Mdot
.63137 .58039 Mdot
.6902 .53333 Mdot
.74118 .28627 Mdot
.54902 .45882 Mdot
.58824 .46275 Mdot
.72157 .40784 Mdot
.66275 .21176 Mdot
.9098 .72157 Mdot
.5098 .21961 Mdot
.47451 .22353 Mdot
.67843 .64706 Mdot
.38039 .21176 Mdot
.52157 .38431 Mdot
.36471 .26667 Mdot
.13333 .09412 Mdot
.15294 .11765 Mdot
.22353 .19608 Mdot
.21961 .20392 Mdot
.81176 .80784 Mdot
.69412 .21176 Mdot
.9098 .74118 Mdot
.95294 .78824 Mdot
.82745 .67843 Mdot
1 .83922 Mdot
.72941 .31373 Mdot
.63529 .56863 Mdot
.61569 .57255 Mdot
.81961 .56471 Mdot
.66667 .28235 Mdot
.53725 .46667 Mdot
.52941 .45098 Mdot
.70196 .3098 Mdot
.63529 .25882 Mdot
.75294 .61961 Mdot
.5451 .24314 Mdot
.57647 .35686 Mdot
.54902 .53725 Mdot
.59608 .37647 Mdot
.49804 .32157 Mdot
.52549 .40392 Mdot
.1451 .11765 Mdot
.16471 .12941 Mdot
.19608 .16863 Mdot
.18824 .18431 Mdot
.44314 .21569 Mdot
.63137 .24706 Mdot
.96471 .79216 Mdot
.83922 .67451 Mdot
.83529 .70196 Mdot
.67451 .3098 Mdot
.65098 .45882 Mdot
.59216 .54902 Mdot
.60784 .56471 Mdot
.76471 .40392 Mdot
.56863 .29804 Mdot
.52941 .4902 Mdot
.61176 .4549 Mdot
.61176 .27843 Mdot
.60784 .31765 Mdot
.74118 .61176 Mdot
.49412 .2 Mdot
.58824 .38039 Mdot
.23922 .19608 Mdot
.5451 .31373 Mdot
.55294 .36471 Mdot
.38824 .28235 Mdot
.19216 .16471 Mdot
.15686 .12157 Mdot
.24314 .22353 Mdot
.12549 .10588 Mdot
.57647 .4549 Mdot
.7451 .25882 Mdot
.83922 .67451 Mdot
.61176 .43922 Mdot
.80392 .6549 Mdot
.89412 .70588 Mdot
.66667 .47059 Mdot
.63137 .58039 Mdot
.59608 .55294 Mdot
.81176 .59608 Mdot
.69804 .31373 Mdot
.54902 .50588 Mdot
.56078 .46275 Mdot
.54118 .24314 Mdot
.63137 .43529 Mdot
.83922 .7451 Mdot
.40392 .18431 Mdot
.4902 .19608 Mdot
.69412 .64706 Mdot
.54902 .37647 Mdot
.53725 .31373 Mdot
.59608 .48235 Mdot
.1451 .10588 Mdot
.26667 .23137 Mdot
.15294 .13333 Mdot
.17255 .14118 Mdot
.85882 .79216 Mdot
.68235 .23137 Mdot
.5451 .21569 Mdot
.70588 .51765 Mdot
.71373 .52941 Mdot
.92549 .8 Mdot
.64706 .33333 Mdot
.65882 .60392 Mdot
.61961 .57647 Mdot
.61961 .56078 Mdot
.72941 .37255 Mdot
.63137 .43529 Mdot
.52941 .4902 Mdot
.67451 .38824 Mdot
.57647 .45882 Mdot
.49804 .4 Mdot
.79216 .69804 Mdot
.43529 .20392 Mdot
.37647 .18431 Mdot
.24314 .2 Mdot
.59608 .42745 Mdot
.36863 .19216 Mdot
.77647 .70588 Mdot
.18039 .14902 Mdot
.24314 .2 Mdot
.15686 .12157 Mdot
.15686 .08627 Mdot
.8549 .79608 Mdot
.67843 .20784 Mdot
.65882 .27843 Mdot
.77255 .58431 Mdot
.76471 .58431 Mdot
.7451 .62353 Mdot
.58431 .32157 Mdot
.60392 .55294 Mdot
.68235 .63137 Mdot
.62353 .56863 Mdot
.76863 .4902 Mdot
.57255 .32549 Mdot
.54118 .49412 Mdot
.61176 .31765 Mdot
.54902 .46667 Mdot
.53333 .46275 Mdot
.74902 .67451 Mdot
.72941 .58824 Mdot
.36863 .20784 Mdot
.37255 .34902 Mdot
.47843 .36471 Mdot
.51765 .38039 Mdot
.79216 .72549 Mdot
.18824 .15294 Mdot
.32941 .27843 Mdot
.21569 .17647 Mdot
.18824 .11765 Mdot
.55686 .43922 Mdot
.84314 .73333 Mdot
.77255 .23529 Mdot
.38431 .17647 Mdot
.76471 .57647 Mdot
.75294 .58824 Mdot
.93725 .77647 Mdot
.68627 .56471 Mdot
.63922 .58824 Mdot
.67059 .63137 Mdot
.61569 .55686 Mdot
.7098 .36863 Mdot
.65098 .48235 Mdot
.57255 .47451 Mdot
.49412 .25098 Mdot
.52157 .47843 Mdot
.53333 .47843 Mdot
.67843 .60784 Mdot
.80392 .70196 Mdot
.2549 .16863 Mdot
.42353 .4 Mdot
.39216 .30196 Mdot
.64706 .54118 Mdot
.85882 .81961 Mdot
.17255 .13333 Mdot
.24706 .19216 Mdot
.2 .14902 Mdot
.62353 .53725 Mdot
.55686 .41569 Mdot
1 .96863 Mdot
.75294 .22745 Mdot
.56471 .22353 Mdot
.87059 .68235 Mdot
.6902 .53333 Mdot
.85882 .72549 Mdot
.68235 .51765 Mdot
.60784 .56471 Mdot
.78431 .7451 Mdot
.63137 .58824 Mdot
.76078 .56078 Mdot
.59608 .2902 Mdot
.56863 .48235 Mdot
.55686 .2902 Mdot
.54118 .49412 Mdot
.50588 .45882 Mdot
.54118 .48627 Mdot
.72549 .6549 Mdot
.77255 .6902 Mdot
.56078 .57647 Mdot
.48627 .38039 Mdot
.34902 .2549 Mdot
.8549 .81569 Mdot
.43137 .40784 Mdot
.20784 .15294 Mdot
.19216 .13333 Mdot
.46275 .40392 Mdot
.57255 .43137 Mdot
.5451 .43922 Mdot
.68627 .53725 Mdot
.75686 .21961 Mdot
.77647 .47059 Mdot
.87843 .68235 Mdot
.9098 .76863 Mdot
1 .87451 Mdot
.37647 .29412 Mdot
.59608 .55294 Mdot
.7098 .67059 Mdot
.61961 .58431 Mdot
.78824 .57255 Mdot
.59216 .30196 Mdot
.62745 .46667 Mdot
.57647 .4 Mdot
.52157 .47451 Mdot
.52157 .47451 Mdot
.52549 .47059 Mdot
.56863 .51373 Mdot
.83137 .76863 Mdot
.36863 .37647 Mdot
.57255 .45882 Mdot
.53725 .44706 Mdot
.87451 .84706 Mdot
.73725 .71765 Mdot
.18431 .13725 Mdot
.21961 .16863 Mdot
.42353 .35686 Mdot
.64314 .50196 Mdot
.56471 .46667 Mdot
.99216 .98039 Mdot
.68627 .18824 Mdot
.78039 .25098 Mdot
.84706 .51765 Mdot
.71373 .57647 Mdot
.93725 .67059 Mdot
.72549 .56471 Mdot
.61569 .57647 Mdot
.61961 .57647 Mdot
.82353 .78431 Mdot
.63529 .57647 Mdot
.73725 .34118 Mdot
.63137 .49412 Mdot
.56471 .28235 Mdot
.52941 .48235 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.53333 .48235 Mdot
.57647 .51765 Mdot
.77647 .78039 Mdot
.66667 .54902 Mdot
.5451 .46667 Mdot
.74118 .68627 Mdot
.8902 .89804 Mdot
.71373 .69804 Mdot
.56471 .52549 Mdot
.64314 .58039 Mdot
.49804 .38824 Mdot
.54902 .47451 Mdot
.3451 .26667 Mdot
.53333 .23529 Mdot
.77647 .25098 Mdot
.6902 .17647 Mdot
.93333 .7451 Mdot
.75686 .59608 Mdot
.75686 .45098 Mdot
.49804 .4549 Mdot
.61961 .56863 Mdot
.62745 .58431 Mdot
.6902 .6549 Mdot
.73725 .57647 Mdot
.6 .2549 Mdot
.76078 .47843 Mdot
.57647 .48235 Mdot
.52157 .48235 Mdot
.52941 .48235 Mdot
.52549 .47843 Mdot
.52157 .47843 Mdot
.58824 .52941 Mdot
.42353 .44314 Mdot
.8902 .74118 Mdot
.76471 .70196 Mdot
.86667 .8549 Mdot
.91765 .92549 Mdot
.8549 .8549 Mdot
.83529 .78431 Mdot
.35294 .24314 Mdot
.51373 .42745 Mdot
.6 .53333 Mdot
.4549 .43137 Mdot
.67451 .2 Mdot
.69804 .21176 Mdot
.78824 .27843 Mdot
.99216 .82353 Mdot
.70588 .38039 Mdot
.69804 .4902 Mdot
.44706 .40392 Mdot
.62745 .58431 Mdot
.61961 .57647 Mdot
.71373 .67451 Mdot
.80392 .55686 Mdot
.63922 .32549 Mdot
.62745 .31373 Mdot
.52549 .48627 Mdot
.5451 .50588 Mdot
.52549 .48627 Mdot
.52157 .47451 Mdot
.54902 .49412 Mdot
.58039 .53725 Mdot
.47451 .44314 Mdot
.83137 .76078 Mdot
.78431 .7451 Mdot
.9098 .9098 Mdot
.88235 .88627 Mdot
.90588 .90196 Mdot
.75686 .69804 Mdot
.47843 .33725 Mdot
.40784 .37647 Mdot
.6 .54902 Mdot
.81569 .72157 Mdot
.74118 .24706 Mdot
.78824 .2549 Mdot
.7451 .2902 Mdot
.52941 .2549 Mdot
.79216 .28627 Mdot
.61569 .54118 Mdot
.41569 .37255 Mdot
.61569 .57647 Mdot
.63922 .6 Mdot
.75686 .70588 Mdot
.7098 .36863 Mdot
.69804 .34118 Mdot
.67843 .46275 Mdot
.55686 .50196 Mdot
.52941 .4902 Mdot
.53725 .4902 Mdot
.53333 .4902 Mdot
.56471 .50196 Mdot
.76471 .77255 Mdot
.93333 .83922 Mdot
.85882 .82745 Mdot
.82353 .8 Mdot
.88627 .8902 Mdot
.87451 .8902 Mdot
.8549 .83137 Mdot
.49412 .40392 Mdot
.45882 .31765 Mdot
.41569 .39216 Mdot
.67451 .64706 Mdot
.56471 .23529 Mdot
.67843 .22745 Mdot
.78431 .24706 Mdot
.6549 .23922 Mdot
1 .65098 Mdot
.63529 .27843 Mdot
.60392 .56078 Mdot
.41176 .36863 Mdot
.61569 .57255 Mdot
.62353 .58039 Mdot
.80784 .72549 Mdot
.77255 .39608 Mdot
.71765 .31373 Mdot
.66275 .47451 Mdot
.56863 .49804 Mdot
.54118 .49804 Mdot
.53725 .49804 Mdot
.56078 .50588 Mdot
.57255 .5098 Mdot
.87843 .87843 Mdot
.66667 .54118 Mdot
.91765 .87843 Mdot
.8549 .85098 Mdot
.87059 .88235 Mdot
.88235 .89804 Mdot
.82353 .78039 Mdot
.50588 .38824 Mdot
.49804 .38824 Mdot
.43922 .41176 Mdot
.66275 .67451 Mdot
.66275 .23529 Mdot
.83529 .44314 Mdot
.7451 .25098 Mdot
.73725 .27843 Mdot
.83137 .35686 Mdot
.68235 .45098 Mdot
.60392 .56078 Mdot
.53725 .49804 Mdot
.63137 .58824 Mdot
.63922 .59608 Mdot
.92157 .76863 Mdot
.85882 .50196 Mdot
.75294 .34902 Mdot
.68627 .44706 Mdot
.63137 .51765 Mdot
.57647 .50588 Mdot
.55686 .50196 Mdot
.59608 .52549 Mdot
.78039 .74118 Mdot
.61176 .58431 Mdot
.64706 .53725 Mdot
.94118 .87059 Mdot
.8902 .87451 Mdot
.88235 .8902 Mdot
.87451 .88235 Mdot
.8 .74902 Mdot
.51373 .41569 Mdot
.4549 .35294 Mdot
.46275 .42353 Mdot
.97255 .97647 Mdot
.66667 .2 Mdot
.6902 .32941 Mdot
.69412 .27059 Mdot
.76863 .27059 Mdot
.81569 .28627 Mdot
.67451 .5451 Mdot
.60392 .56078 Mdot
.61569 .58824 Mdot
.63922 .58431 Mdot
.63529 .59216 Mdot
.95686 .70196 Mdot
.98039 .62353 Mdot
.82745 .44314 Mdot
.62353 .29412 Mdot
.67843 .47843 Mdot
.60784 .50588 Mdot
.61176 .54902 Mdot
.58039 .51373 Mdot
.84706 .81569 Mdot
.62745 .60392 Mdot
.41961 .27451 Mdot
.95686 .83529 Mdot
.95294 .9098 Mdot
.86275 .87843 Mdot
.86275 .87059 Mdot
.82745 .77647 Mdot
.61176 .54902 Mdot
.46275 .38431 Mdot
.45882 .40392 Mdot
.89804 .84314 Mdot
.72157 .25098 Mdot
.70588 .39216 Mdot
.56078 .23137 Mdot
.77647 .26667 Mdot
.78431 .27059 Mdot
.61961 .5451 Mdot
.61961 .56471 Mdot
.62745 .6 Mdot
.5451 .4902 Mdot
.64314 .58824 Mdot
.78431 .40392 Mdot
.83137 .45882 Mdot
.90588 .50588 Mdot
.64706 .2549 Mdot
.69804 .40784 Mdot
.65882 .50196 Mdot
.60392 .53333 Mdot
.77255 .73725 Mdot
.63137 .60784 Mdot
.63137 .6 Mdot
.44314 .27843 Mdot
.78824 .6549 Mdot
.94118 .86275 Mdot
.8902 .86275 Mdot
.8549 .84706 Mdot
.82353 .78431 Mdot
.66275 .61961 Mdot
.64314 .58824 Mdot
.47059 .43529 Mdot
.45098 .32157 Mdot
.72549 .25882 Mdot
.58824 .36471 Mdot
.67451 .47059 Mdot
.77647 .26667 Mdot
.7451 .29804 Mdot
.58824 .5451 Mdot
.6 .55686 Mdot
.61569 .58039 Mdot
.39608 .34118 Mdot
.65882 .56471 Mdot
.85882 .37255 Mdot
.66275 .24706 Mdot
.9098 .5098 Mdot
.77255 .36471 Mdot
.65098 .26667 Mdot
.71373 .47843 Mdot
.62745 .56471 Mdot
.77647 .75686 Mdot
.62745 .60784 Mdot
.62353 .59216 Mdot
.22745 .11765 Mdot
.62745 .49804 Mdot
.91765 .77255 Mdot
.92549 .8549 Mdot
.87451 .85098 Mdot
.83529 .81176 Mdot
.77255 .7451 Mdot
.82745 .79216 Mdot
.73333 .72157 Mdot
.49804 .26667 Mdot
.7098 .26667 Mdot
.8902 .73333 Mdot
.90196 .76078 Mdot
.79216 .26667 Mdot
.61961 .2902 Mdot
.60392 .56078 Mdot
.61961 .57647 Mdot
.61961 .58431 Mdot
.29412 .25098 Mdot
.71765 .53725 Mdot
.83922 .30196 Mdot
.65098 .19608 Mdot
.87843 .46275 Mdot
.8902 .43922 Mdot
.70196 .27451 Mdot
.58039 .33333 Mdot
.80784 .76471 Mdot
.63137 .61569 Mdot
.62745 .60392 Mdot
.66667 .62745 Mdot
.29412 .23922 Mdot
.87451 .76471 Mdot
.73333 .58431 Mdot
.92549 .81569 Mdot
.93725 .86667 Mdot
.85098 .81569 Mdot
.77255 .74902 Mdot
.8 .77647 Mdot
.69412 .70196 Mdot
.57647 .26667 Mdot
.65882 .24706 Mdot
.94118 .81569 Mdot
.63529 .47451 Mdot
.78431 .25098 Mdot
.71765 .50196 Mdot
.60392 .56078 Mdot
.62745 .58431 Mdot
.61176 .56863 Mdot
.36863 .32549 Mdot
.86275 .56078 Mdot
.8549 .30588 Mdot
.79608 .2902 Mdot
.75686 .31765 Mdot
.8549 .40784 Mdot
.82745 .41961 Mdot
.66275 .4549 Mdot
.72941 .68627 Mdot
.64314 .61961 Mdot
.63529 .60784 Mdot
.72157 .68627 Mdot
.84706 .82745 Mdot
.94902 .90588 Mdot
.69804 .60392 Mdot
.78824 .61569 Mdot
1 .8549 Mdot
.89412 .83137 Mdot
.80784 .77647 Mdot
.89804 .87059 Mdot
.64706 .65882 Mdot
.62745 .21569 Mdot
.69412 .38039 Mdot
.21569 .10196 Mdot
.57255 .30588 Mdot
.76471 .26667 Mdot
.61569 .54118 Mdot
.6 .55686 Mdot
.61176 .57647 Mdot
.6 .56471 Mdot
.43529 .37255 Mdot
.78824 .31373 Mdot
.83529 .29412 Mdot
.81961 .29804 Mdot
.67451 .21961 Mdot
.81569 .36863 Mdot
.87451 .46667 Mdot
.92549 .83922 Mdot
.63137 .6 Mdot
.64314 .61961 Mdot
.61569 .59216 Mdot
.17255 .14902 Mdot
.90196 .89804 Mdot
.93333 .89412 Mdot
.91765 .82745 Mdot
.58431 .39608 Mdot
.89412 .73725 Mdot
.93725 .84314 Mdot
.8 .76471 Mdot
.94902 .92157 Mdot
.90588 .86275 Mdot
.74118 .28235 Mdot
.55294 .34118 Mdot
.97647 .87059 Mdot
.65882 .29804 Mdot
.65882 .28627 Mdot
.6 .55686 Mdot
.60784 .56471 Mdot
.59608 .55294 Mdot
.60784 .57255 Mdot
.54902 .36471 Mdot
.72549 .27059 Mdot
.81961 .29412 Mdot
.83922 .30588 Mdot
.68235 .18824 Mdot
.80784 .39608 Mdot
.72941 .35686 Mdot
.64706 .59608 Mdot
.62353 .6 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.15686 .14118 Mdot
.92549 .89412 Mdot
.94118 .89804 Mdot
.96078 .9098 Mdot
.7451 .61569 Mdot
.67059 .45098 Mdot
.92549 .76471 Mdot
.87843 .80784 Mdot
.51765 .51373 Mdot
.60392 .41176 Mdot
.69804 .2902 Mdot
.82353 .68627 Mdot
.6549 .45098 Mdot
.70196 .23922 Mdot
.58039 .46667 Mdot
.60784 .56471 Mdot
.6 .55686 Mdot
.60784 .57255 Mdot
.61961 .57647 Mdot
.75686 .30588 Mdot
.60392 .23922 Mdot
.81176 .30196 Mdot
.82745 .28627 Mdot
.74902 .2549 Mdot
.81176 .38039 Mdot
.56471 .38039 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.61961 .59216 Mdot
.59608 .57647 Mdot
.96471 .9451 Mdot
.92157 .82353 Mdot
.93333 .90588 Mdot
.94902 .91765 Mdot
.92157 .78431 Mdot
.51765 .28235 Mdot
.8902 .81176 Mdot
.58039 .51373 Mdot
.97255 .98039 Mdot
.6902 .28235 Mdot
.68627 .41176 Mdot
.84314 .68627 Mdot
.90196 .60392 Mdot
.64706 .29412 Mdot
.6 .55686 Mdot
.61961 .56863 Mdot
.60784 .56471 Mdot
.61176 .56863 Mdot
.80392 .55686 Mdot
.62353 .2902 Mdot
.57647 .27451 Mdot
.8 .3098 Mdot
.83529 .28627 Mdot
.78039 .25882 Mdot
.68627 .26275 Mdot
.63137 .58431 Mdot
.61569 .59216 Mdot
.60784 .58824 Mdot
.61961 .60784 Mdot
.16471 .14118 Mdot
.97647 .87451 Mdot
.91373 .78431 Mdot
.92549 .91765 Mdot
.95686 .91373 Mdot
.97255 .8902 Mdot
.48627 .32941 Mdot
.64314 .5451 Mdot
.48627 .4902 Mdot
.33333 .25882 Mdot
.70196 .28627 Mdot
.55294 .28627 Mdot
.90588 .67451 Mdot
.63529 .16471 Mdot
.62745 .51373 Mdot
.60784 .55294 Mdot
.61569 .57255 Mdot
.61569 .57255 Mdot
.64706 .57647 Mdot
.80784 .30196 Mdot
.94118 .80392 Mdot
.58431 .29412 Mdot
.8 .32157 Mdot
.85098 .28235 Mdot
.81961 .28235 Mdot
.56863 .35294 Mdot
.60392 .58039 Mdot
.61176 .59216 Mdot
.62353 .60392 Mdot
.56863 .54118 Mdot
.98824 .92549 Mdot
.69804 .50588 Mdot
.96471 .89804 Mdot
.38431 .36471 Mdot
.91765 .89804 Mdot
.97255 .87059 Mdot
.90196 .81176 Mdot
.88235 .82745 Mdot
.97647 .98431 Mdot
.61176 .25882 Mdot
.58824 .23529 Mdot
.52157 .16471 Mdot
.55686 .16471 Mdot
.61961 .34118 Mdot
.31765 .26275 Mdot
.61961 .56471 Mdot
.60784 .57255 Mdot
.61961 .56471 Mdot
.7451 .32157 Mdot
.63137 .36471 Mdot
.9451 .84314 Mdot
.57255 .29804 Mdot
.83529 .30196 Mdot
.8549 .26667 Mdot
.74902 .34118 Mdot
.60784 .58431 Mdot
.62353 .60392 Mdot
.60392 .59216 Mdot
.6549 .63529 Mdot
.1098 .06275 Mdot
.56471 .36471 Mdot
.81176 .69412 Mdot
.59608 .57647 Mdot
.65882 .62745 Mdot
.9098 .8902 Mdot
.72549 .60392 Mdot
.57647 .52157 Mdot
.66667 .68627 Mdot
.41569 .3098 Mdot
.62353 .23529 Mdot
.59216 .16471 Mdot
.52549 .15294 Mdot
.74118 .28627 Mdot
.63922 .56863 Mdot
.6 .5451 Mdot
.61961 .57647 Mdot
.61569 .57255 Mdot
.78431 .53725 Mdot
.81176 .31373 Mdot
.95294 .81569 Mdot
.93725 .82745 Mdot
.66667 .29804 Mdot
.86275 .27451 Mdot
.82353 .27451 Mdot
.65098 .57255 Mdot
.62353 .60392 Mdot
.62745 .60392 Mdot
.61569 .60392 Mdot
.20392 .16471 Mdot
.51373 .34118 Mdot
.94902 .76471 Mdot
.10588 .06667 Mdot
.87451 .8549 Mdot
.52941 .5098 Mdot
.99608 .88627 Mdot
.52941 .48235 Mdot
.8549 .84706 Mdot
.77647 .76471 Mdot
.61961 .30196 Mdot
.73725 .26275 Mdot
.76078 .30196 Mdot
.79216 .28235 Mdot
.61961 .52549 Mdot
.29412 .23922 Mdot
.62353 .58039 Mdot
.60784 .57255 Mdot
.69412 .51765 Mdot
.83922 .27843 Mdot
.78431 .44706 Mdot
.94902 .83137 Mdot
.95294 .76471 Mdot
.86275 .27843 Mdot
.83529 .26667 Mdot
.69804 .57647 Mdot
.62353 .59608 Mdot
.60392 .59216 Mdot
.64314 .62353 Mdot
.16863 .12941 Mdot
.77255 .66275 Mdot
.70588 .47059 Mdot
.90196 .86667 Mdot
.87843 .85098 Mdot
.8 .76078 Mdot
.96078 .86667 Mdot
.87451 .83529 Mdot
.88627 .88627 Mdot
.97647 .97255 Mdot
.58039 .2902 Mdot
.74118 .25098 Mdot
.76863 .27059 Mdot
.77647 .28627 Mdot
.62745 .56078 Mdot
.40392 .34902 Mdot
.63137 .58824 Mdot
.61176 .57647 Mdot
.83922 .55686 Mdot
.83137 .27059 Mdot
.60392 .22353 Mdot
.95294 .82745 Mdot
1 .81961 Mdot
.8549 .27843 Mdot
.81176 .26667 Mdot
.63922 .57647 Mdot
.62745 .60784 Mdot
.61569 .60392 Mdot
.52549 .50588 Mdot
.21176 .14902 Mdot
.93333 .8 Mdot
.80392 .57647 Mdot
.58824 .5451 Mdot
.52157 .4902 Mdot
.66275 .63137 Mdot
1 .89804 Mdot
.75294 .72549 Mdot
.88627 .88235 Mdot
.82353 .75294 Mdot
.67451 .31765 Mdot
.77647 .25098 Mdot
.81569 .27843 Mdot
.73725 .52941 Mdot
.60392 .56078 Mdot
.4 .35686 Mdot
.61961 .58431 Mdot
.69804 .5451 Mdot
.82745 .28235 Mdot
.78824 .3098 Mdot
.57255 .27843 Mdot
.9098 .85098 Mdot
.82745 .30588 Mdot
.8549 .27843 Mdot
.61569 .42353 Mdot
.57255 .5451 Mdot
.43137 .41961 Mdot
.27843 .26667 Mdot
.21961 .17647 Mdot
.76078 .62745 Mdot
.92157 .72549 Mdot
.9098 .87843 Mdot
.68627 .66667 Mdot
.63137 .6 Mdot
.94118 .88235 Mdot
.93333 .83137 Mdot
.86275 .85882 Mdot
.96863 .97647 Mdot
.55686 .3098 Mdot
.64706 .18824 Mdot
.81569 .27843 Mdot
.74118 .4902 Mdot
.60392 .56078 Mdot
.34902 .30588 Mdot
.63137 .59608 Mdot
.7098 .53333 Mdot
.82745 .28235 Mdot
.75294 .34118 Mdot
.49804 .23137 Mdot
.90196 .8549 Mdot
.82353 .31765 Mdot
.83922 .26275 Mdot
.63529 .44706 Mdot
.27843 .25098 Mdot
.30196 .27843 Mdot
.4549 .44314 Mdot
.20784 .16471 Mdot
.36471 .23137 Mdot
.93333 .73725 Mdot
.8902 .87059 Mdot
.94118 .92157 Mdot
.97255 .95294 Mdot
.92549 .88235 Mdot
.96863 .84706 Mdot
.87451 .86667 Mdot
.96863 .97647 Mdot
.53725 .3451 Mdot
.72549 .22745 Mdot
.8 .29412 Mdot
.57647 .48627 Mdot
.6 .55686 Mdot
.25882 .21569 Mdot
.63922 .58431 Mdot
.72157 .28235 Mdot
.80392 .30196 Mdot
.76078 .61569 Mdot
.48235 .41176 Mdot
.99216 .83922 Mdot
.84706 .27451 Mdot
.75686 .28627 Mdot
.45882 .43529 Mdot
.55294 .53333 Mdot
.61176 .58824 Mdot
.59216 .56863 Mdot
.19608 .12549 Mdot
1 .8902 Mdot
.78431 .67451 Mdot
.24706 .21961 Mdot
.22745 .20784 Mdot
.6902 .67843 Mdot
.98824 .89412 Mdot
.90196 .84314 Mdot
.4 .43137 Mdot
.69412 .63529 Mdot
.69412 .31373 Mdot
.77647 .24706 Mdot
.70588 .49804 Mdot
.59608 .55294 Mdot
.62353 .58039 Mdot
.62745 .58431 Mdot
.82353 .42353 Mdot
.80784 .28235 Mdot
.94118 .86667 Mdot
.91765 .85882 Mdot
.91373 .83922 Mdot
.84706 .2902 Mdot
.81176 .28235 Mdot
.63529 .59608 Mdot
.61569 .59216 Mdot
.61176 .59216 Mdot
.59216 .56863 Mdot
.15294 .11373 Mdot
.87843 .74118 Mdot
.55686 .42745 Mdot
.81176 .78431 Mdot
.28627 .2549 Mdot
.2902 .27059 Mdot
.92157 .87843 Mdot
.81569 .69804 Mdot
.89412 .90588 Mdot
.73333 .69804 Mdot
.71765 .31373 Mdot
.76471 .25882 Mdot
.60392 .46667 Mdot
.59608 .55294 Mdot
.61961 .58039 Mdot
.63922 .54118 Mdot
.82353 .29804 Mdot
.70588 .3451 Mdot
.88235 .85882 Mdot
.91373 .83529 Mdot
.98824 .79608 Mdot
.84706 .26275 Mdot
.65882 .31765 Mdot
.58431 .56471 Mdot
.6 .57255 Mdot
.6 .58039 Mdot
.67451 .65098 Mdot
.98431 .90588 Mdot
.91373 .70588 Mdot
.95686 .91373 Mdot
.34902 .32157 Mdot
.97647 .94118 Mdot
.9451 .94118 Mdot
.93333 .87059 Mdot
.21176 .1451 Mdot
.46275 .5098 Mdot
.54118 .38039 Mdot
.76078 .30196 Mdot
.68235 .32549 Mdot
.54902 .4902 Mdot
.61176 .56863 Mdot
.37255 .32941 Mdot
.77255 .33333 Mdot
.81176 .30196 Mdot
.89412 .86667 Mdot
.93725 .83922 Mdot
.97255 .79216 Mdot
.83529 .29412 Mdot
.79608 .29412 Mdot
.62353 .58824 Mdot
.59608 .57255 Mdot
.59216 .57255 Mdot
.58431 .56078 Mdot
.13333 .07843 Mdot
.91765 .69412 Mdot
.67059 .56471 Mdot
.81961 .8 Mdot
.33725 .28627 Mdot
.5098 .4902 Mdot
.89412 .89412 Mdot
.36078 .25098 Mdot
.87059 .8902 Mdot
.92157 .85882 Mdot
.64706 .27843 Mdot
.68235 .2549 Mdot
.54902 .47451 Mdot
.59608 .56078 Mdot
.61176 .57255 Mdot
.77255 .31373 Mdot
.81176 .28627 Mdot
.87843 .84314 Mdot
.94902 .77647 Mdot
.85098 .51373 Mdot
.83529 .2902 Mdot
.79216 .29804 Mdot
.61569 .57255 Mdot
.61176 .59216 Mdot
.58431 .56471 Mdot
.59216 .57647 Mdot
.20392 .12941 Mdot
.74118 .49412 Mdot
.96471 .86667 Mdot
.59216 .56078 Mdot
.82353 .78039 Mdot
.50196 .48627 Mdot
.8902 .8902 Mdot
.32941 .22745 Mdot
.86667 .89412 Mdot
.88235 .78431 Mdot
.67451 .24706 Mdot
.70588 .45098 Mdot
.55686 .50588 Mdot
.60392 .57647 Mdot
.65098 .46667 Mdot
.82745 .27059 Mdot
.47451 .16078 Mdot
.89804 .86275 Mdot
.66667 .2549 Mdot
.72941 .3098 Mdot
.84706 .27843 Mdot
.61176 .40784 Mdot
.62745 .60392 Mdot
.60784 .58824 Mdot
.59608 .57647 Mdot
.16471 .12549 Mdot
.85882 .70196 Mdot
.67451 .44706 Mdot
.93725 .91765 Mdot
.48235 .44706 Mdot
.44314 .41569 Mdot
.89804 .89804 Mdot
.93725 .87451 Mdot
.53333 .4902 Mdot
.4902 .5451 Mdot
.62353 .30196 Mdot
.61176 .32157 Mdot
.56078 .47843 Mdot
.58824 .56078 Mdot
.7098 .52549 Mdot
.82353 .26667 Mdot
.63922 .25098 Mdot
.89804 .87059 Mdot
.75294 .36078 Mdot
.72941 .22353 Mdot
.83137 .27059 Mdot
.64706 .4549 Mdot
.61176 .58431 Mdot
.60392 .58039 Mdot
.6 .57647 Mdot
.17647 .13725 Mdot
.49412 .33725 Mdot
1 .80392 Mdot
.39216 .37255 Mdot
.9098 .86667 Mdot
.84706 .81961 Mdot
.90196 .90196 Mdot
.94118 .87843 Mdot
.54902 .51373 Mdot
.73725 .77647 Mdot
.83137 .55686 Mdot
.72157 .4902 Mdot
.56078 .44706 Mdot
.56863 .53333 Mdot
.8 .52549 Mdot
.81961 .26667 Mdot
.54118 .18431 Mdot
.88627 .84314 Mdot
.69412 .31765 Mdot
.81961 .30588 Mdot
.80784 .27843 Mdot
.67059 .57255 Mdot
.60392 .57647 Mdot
.59608 .57647 Mdot
.59608 .57255 Mdot
.21569 .16863 Mdot
.72941 .59608 Mdot
.60392 .42745 Mdot
.20784 .17647 Mdot
.40784 .36863 Mdot
.48235 .46275 Mdot
.89412 .89412 Mdot
.94902 .86667 Mdot
.88627 .87451 Mdot
.75686 .72941 Mdot
.63922 .38039 Mdot
.54118 .33725 Mdot
.56078 .46275 Mdot
.61569 .55686 Mdot
.78824 .29804 Mdot
.82353 .27059 Mdot
.94118 .73725 Mdot
.96471 .88235 Mdot
.63529 .28627 Mdot
.81176 .30196 Mdot
.62745 .32157 Mdot
.60392 .57647 Mdot
.62353 .58431 Mdot
.59216 .56863 Mdot
.52941 .51373 Mdot
.9451 .90588 Mdot
.6 .43922 Mdot
.96863 .9098 Mdot
.15294 .13725 Mdot
.54902 .51373 Mdot
.94902 .9451 Mdot
.90196 .88627 Mdot
.2549 .16471 Mdot
.33333 .37255 Mdot
.78431 .69412 Mdot
.72941 .53333 Mdot
.60392 .40784 Mdot
.56863 .49412 Mdot
.79216 .48235 Mdot
.82353 .27059 Mdot
.77255 .31373 Mdot
.92549 .82353 Mdot
.83137 .67059 Mdot
.59216 .23529 Mdot
.76078 .31373 Mdot
.61176 .58431 Mdot
.60784 .58039 Mdot
.61569 .59216 Mdot
.6 .56471 Mdot
.36078 .34118 Mdot
.97647 .88235 Mdot
.96078 .83922 Mdot
.44314 .42745 Mdot
.83922 .8 Mdot
.52157 .50588 Mdot
.89804 .89804 Mdot
.4 .30588 Mdot
.87451 .90196 Mdot
.38824 .39216 Mdot
.84706 .67843 Mdot
.70196 .47843 Mdot
.62745 .45098 Mdot
.63922 .48235 Mdot
.79608 .28235 Mdot
.81961 .27451 Mdot
.7098 .36471 Mdot
.92941 .83922 Mdot
.85098 .72157 Mdot
.79608 .32157 Mdot
.65098 .59608 Mdot
.59216 .57255 Mdot
.58039 .56078 Mdot
.56863 .55294 Mdot
.20392 .17255 Mdot
.94118 .88627 Mdot
.85098 .66275 Mdot
.78039 .73725 Mdot
.15686 .13333 Mdot
.55294 .52157 Mdot
.89412 .90196 Mdot
.97647 .91373 Mdot
.78431 .78431 Mdot
.83529 .83922 Mdot
.81569 .69804 Mdot
.86275 .67059 Mdot
.49412 .30196 Mdot
.62745 .46667 Mdot
.78824 .29804 Mdot
.82745 .28235 Mdot
.63137 .18431 Mdot
.97255 .81176 Mdot
.93725 .8549 Mdot
.77647 .33725 Mdot
.61961 .58039 Mdot
.61569 .59608 Mdot
.59216 .57255 Mdot
.56471 .5451 Mdot
.18824 .15686 Mdot
.93725 .87451 Mdot
.74902 .52941 Mdot
.98824 .94902 Mdot
.78039 .76471 Mdot
.26667 .24314 Mdot
.8902 .89804 Mdot
.99216 .92157 Mdot
.85098 .85882 Mdot
.73725 .73725 Mdot
.72157 .61569 Mdot
.8 .65098 Mdot
.43922 .31373 Mdot
.76078 .4549 Mdot
.77647 .28627 Mdot
.81961 .28627 Mdot
.68235 .22353 Mdot
.97647 .72941 Mdot
.97647 .80392 Mdot
.68627 .35686 Mdot
.61961 .59608 Mdot
.57255 .5451 Mdot
.47059 .45098 Mdot
.45882 .44314 Mdot
.93333 .91765 Mdot
.79216 .63529 Mdot
.55294 .40784 Mdot
.90196 .90196 Mdot
.91765 .9098 Mdot
.85882 .8549 Mdot
.89804 .8902 Mdot
.28627 .2 Mdot
.90196 .93333 Mdot
.63137 .58039 Mdot
.88235 .79216 Mdot
.86275 .76471 Mdot
.68627 .47059 Mdot
.70196 .27059 Mdot
.8 .29412 Mdot
.83529 .31373 Mdot
.60392 .20784 Mdot
.95294 .70196 Mdot
.71373 .36471 Mdot
.49412 .47059 Mdot
.2902 .26275 Mdot
.3451 .32549 Mdot
.47843 .47059 Mdot
.56863 .5451 Mdot
.94902 .82745 Mdot
.61961 .43529 Mdot
.92157 .8902 Mdot
.90588 .8902 Mdot
.78039 .78039 Mdot
.89804 .89804 Mdot
.43137 .34118 Mdot
.89412 .92157 Mdot
.66667 .63922 Mdot
.93725 .89804 Mdot
.55294 .42353 Mdot
.63529 .25098 Mdot
.77255 .30588 Mdot
.80784 .30196 Mdot
.76078 .27843 Mdot
.63137 .22353 Mdot
.71373 .37255 Mdot
.36471 .34118 Mdot
.41176 .37255 Mdot
.53725 .5098 Mdot
.67451 .65882 Mdot
.83529 .81961 Mdot
.93725 .81961 Mdot
.97647 .82353 Mdot
.96863 .87843 Mdot
.92549 .8902 Mdot
.61569 .61569 Mdot
.90196 .89412 Mdot
.2902 .19216 Mdot
.92157 .95294 Mdot
.98039 .97647 Mdot
.58039 .37255 Mdot
.61569 .23137 Mdot
.74118 .28627 Mdot
.80784 .30196 Mdot
.80392 .29412 Mdot
.71373 .28627 Mdot
.58039 .53333 Mdot
.59608 .56078 Mdot
.61176 .58824 Mdot
.57255 .55686 Mdot
.08627 .07059 Mdot
.94118 .87843 Mdot
.86667 .69412 Mdot
1 .88627 Mdot
.8902 .73725 Mdot
.9098 .90588 Mdot
.8902 .89804 Mdot
.96863 .87843 Mdot
.83922 .87059 Mdot
.79216 .69412 Mdot
.57255 .24706 Mdot
.69804 .26667 Mdot
.78824 .31765 Mdot
.81569 .30196 Mdot
.72549 .36471 Mdot
.57647 .55294 Mdot
.58431 .56078 Mdot
.57255 .55686 Mdot
.63529 .61569 Mdot
.64706 .63137 Mdot
.96078 .85882 Mdot
.77255 .59608 Mdot
.89804 .68627 Mdot
.62353 .44314 Mdot
.9098 .9098 Mdot
.89412 .88627 Mdot
.26275 .18039 Mdot
.9451 .96863 Mdot
.66275 .48627 Mdot
.60784 .26275 Mdot
.70588 .28235 Mdot
.79608 .29804 Mdot
.73725 .34118 Mdot
.58039 .5451 Mdot
.57647 .55294 Mdot
.56863 .5451 Mdot
.56078 .54118 Mdot
.23137 .20784 Mdot
.97255 .88627 Mdot
.63137 .45098 Mdot
.94902 .71373 Mdot
.56471 .33725 Mdot
.93725 .9451 Mdot
.8902 .89412 Mdot
.5098 .43529 Mdot
.91373 .93725 Mdot
.71373 .58431 Mdot
.58431 .27451 Mdot
.71373 .27451 Mdot
.76078 .30196 Mdot
.64314 .52549 Mdot
.56471 .54118 Mdot
.56471 .52941 Mdot
.55294 .52941 Mdot
.19216 .16078 Mdot
.9451 .87059 Mdot
.76078 .61176 Mdot
.86275 .69412 Mdot
.74902 .42353 Mdot
.52157 .52157 Mdot
.87451 .91765 Mdot
.93333 .87059 Mdot
.83529 .84314 Mdot
.98824 .92941 Mdot
.54902 .3098 Mdot
.62745 .23529 Mdot
.70196 .29804 Mdot
.57647 .52157 Mdot
.56078 .52549 Mdot
.57647 .53333 Mdot
.54902 .52941 Mdot
.19608 .16078 Mdot
.65882 .5451 Mdot
.58824 .4549 Mdot
.48627 .2 Mdot
.62353 .45882 Mdot
.54902 .54902 Mdot
.71765 .76863 Mdot
.89412 .83529 Mdot
.86667 .89412 Mdot
.90588 .82353 Mdot
.53333 .27843 Mdot
.63529 .25882 Mdot
.60392 .54118 Mdot
.55686 .52549 Mdot
.56471 .52941 Mdot
.54118 .50588 Mdot
.20784 .16471 Mdot
.94118 .85882 Mdot
.82353 .68627 Mdot
.82353 .6549 Mdot
.56078 .35294 Mdot
.47059 .41961 Mdot
.40392 .46275 Mdot
.6 .52157 Mdot
.83137 .86667 Mdot
.93725 .82353 Mdot
.57255 .29412 Mdot
.59608 .52941 Mdot
.54902 .52941 Mdot
.53333 .51373 Mdot
.55294 .51765 Mdot
.22745 .18824 Mdot
.92157 .87843 Mdot
.77647 .65882 Mdot
.97647 .87843 Mdot
.63922 .36471 Mdot
.44314 .38039 Mdot
.57647 .58431 Mdot
.41961 .34902 Mdot
.83922 .86667 Mdot
.98431 .90196 Mdot
.90588 .84314 Mdot
.55686 .55294 Mdot
.52157 .5098 Mdot
.55686 .50588 Mdot
.22353 .17255 Mdot
.90196 .89804 Mdot
.5098 .43529 Mdot
.96078 .90196 Mdot
.73725 .33725 Mdot
.51765 .4902 Mdot
.61569 .54118 Mdot
.48627 .43137 Mdot
.83922 .8549 Mdot
.97647 .98824 Mdot
.75686 .76078 Mdot
.59608 .6 Mdot
.49804 .47451 Mdot
.53333 .46667 Mdot
.80392 .77647 Mdot
.92157 .8902 Mdot
.91765 .90196 Mdot
.41961 .23922 Mdot
.54902 .4 Mdot
.63137 .53725 Mdot
.4549 .40392 Mdot
.83137 .80392 Mdot
.87451 .90196 Mdot
.83137 .84706 Mdot
.63529 .65882 Mdot
.8 .6902 Mdot
.30588 .22353 Mdot
.94118 .91373 Mdot
.93725 .9098 Mdot
.91373 .8902 Mdot
.6902 .42353 Mdot
.57255 .55686 Mdot
.53725 .47451 Mdot
.70196 .63137 Mdot
.84314 .87843 Mdot
.98039 .99608 Mdot
.65098 .67059 Mdot
.63529 .52941 Mdot
.4902 .42353 Mdot
.94902 .89412 Mdot
.94118 .89804 Mdot
.92549 .8902 Mdot
.49412 .33333 Mdot
.69804 .68235 Mdot
.87059 .80784 Mdot
.81176 .77647 Mdot
.87059 .9098 Mdot
.86667 .83529 Mdot
.87059 .84314 Mdot
.72549 .66275 Mdot
.88235 .8 Mdot
.96863 .89804 Mdot
1 .91373 Mdot
.91765 .90588 Mdot
.7451 .69804 Mdot
.61961 .53725 Mdot
.83922 .87451 Mdot
1 .99216 Mdot
.84706 .84706 Mdot
.81961 .74902 Mdot
.62745 .53725 Mdot
.86667 .79216 Mdot
.97255 .9098 Mdot
.92941 .89804 Mdot
.48627 .42745 Mdot
.83529 .78431 Mdot
.87059 .92549 Mdot
.98824 .99216 Mdot
.85098 .84706 Mdot
.91765 .86275 Mdot
.66667 .59608 Mdot
.73725 .63529 Mdot
.95294 .87059 Mdot
.98824 .90588 Mdot
.79608 .71765 Mdot
.82745 .87059 Mdot
.99216 1 Mdot
.80784 .78039 Mdot
.92157 .87451 Mdot
.8549 .77647 Mdot
.61569 .5451 Mdot
.77255 .67059 Mdot
.49804 .43922 Mdot
.82353 .85882 Mdot
.98824 1 Mdot
.78824 .77255 Mdot
.82745 .79608 Mdot
.88235 .85098 Mdot
.82353 .78824 Mdot
.63922 .56863 Mdot
.85882 .83137 Mdot
.76078 .83529 Mdot
.62353 .62745 Mdot
.8 .79216 Mdot
.75294 .74902 Mdot
.75686 .76078 Mdot
.87451 .83922 Mdot
.84706 .83137 Mdot
.56863 .63137 Mdot
.96078 .96471 Mdot
.75294 .77255 Mdot
.8 .80392 Mdot
.87451 .87843 Mdot
.9451 .92941 Mdot
.92549 .92157 Mdot
.85098 .88235 Mdot
.8902 .90588 Mdot
.93725 .9451 Mdot
.99216 1 Mdot
.99216 .99216 Mdot
.98824 .99608 Mdot
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.522676 0.97619 0.97619 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00392157 0 0.00392157 [
[ 0 0 -0.125 0 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
1 0 L
s
0 0 m
0 1 L
s
0 1 m
1 1 L
s
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.628 .126 .941 r
.01 w
.90588 .90588 Mdot
.49412 .4902 Mdot
.8 .8 Mdot
.17647 .16471 Mdot
.18039 .18431 Mdot
.13333 .11373 Mdot
.32157 .29412 Mdot
.36863 .37255 Mdot
.20784 .19216 Mdot
.28627 .25098 Mdot
.24314 .23922 Mdot
.21569 .2 Mdot
.26275 .21961 Mdot
.23529 .22353 Mdot
.17255 .16078 Mdot
.20392 .16863 Mdot
.3098 .27843 Mdot
.83922 .83922 Mdot
.2902 .2549 Mdot
.23922 .20392 Mdot
.2902 .27451 Mdot
1 .96471 Mdot
.79608 .7451 Mdot
.27451 .23137 Mdot
.26667 .22353 Mdot
.27059 .24314 Mdot
.9098 .81961 Mdot
.83529 .73333 Mdot
.72549 .51765 Mdot
.1451 .09412 Mdot
.18431 .14118 Mdot
.24706 .21176 Mdot
.16863 .15686 Mdot
.41569 .41569 Mdot
.55686 .55686 Mdot
.53725 .30196 Mdot
.64314 .4549 Mdot
.62353 .24706 Mdot
.15686 .08235 Mdot
.21569 .17647 Mdot
.27843 .25098 Mdot
.17647 .1451 Mdot
.90196 .85098 Mdot
.67451 .68235 Mdot
.11765 .11373 Mdot
.39216 .4 Mdot
.61176 .28627 Mdot
.60392 .40392 Mdot
.78431 .30196 Mdot
.25882 .09412 Mdot
.16863 .12941 Mdot
.25098 .22353 Mdot
.19216 .16078 Mdot
.34902 .23529 Mdot
.53725 .46275 Mdot
.85882 .76863 Mdot
.94902 .94902 Mdot
.1098 .10588 Mdot
.09412 .09804 Mdot
.83922 .83922 Mdot
.61176 .23922 Mdot
.67843 .42745 Mdot
.80784 .30588 Mdot
.21176 .0549 Mdot
.18824 .1451 Mdot
.24314 .22353 Mdot
.18824 .13333 Mdot
.47843 .30196 Mdot
.34902 .2 Mdot
.40392 .18431 Mdot
.55294 .43529 Mdot
.85098 .75294 Mdot
.99608 .95294 Mdot
.12549 .12157 Mdot
.22353 .22353 Mdot
.07059 .0902 Mdot
.71373 .27451 Mdot
.72549 .49804 Mdot
.74902 .30588 Mdot
.73725 .25098 Mdot
.22745 .12549 Mdot
.2 .15686 Mdot
.16078 .12941 Mdot
.22353 .02353 Mdot
.45882 .29412 Mdot
.43529 .2 Mdot
.35294 .16471 Mdot
.32941 .16863 Mdot
.37647 .27059 Mdot
.61176 .52941 Mdot
.89804 .81569 Mdot
1 1 Mdot
.10196 .10588 Mdot
.21961 .2 Mdot
.20392 .20392 Mdot
.31373 .32157 Mdot
.82353 .27451 Mdot
.56471 .2902 Mdot
.81961 .2902 Mdot
.83529 .36471 Mdot
.21961 .12157 Mdot
.20392 .16078 Mdot
.19216 .13725 Mdot
.54118 .27451 Mdot
.59608 .43922 Mdot
.55294 .24314 Mdot
.52157 .39216 Mdot
.32157 .17255 Mdot
.29804 .16078 Mdot
.31373 .16078 Mdot
.4902 .28627 Mdot
.61569 .59608 Mdot
.11373 .11765 Mdot
.26275 .25098 Mdot
.19216 .17255 Mdot
.0902 .09412 Mdot
.86275 .62745 Mdot
.69412 .22353 Mdot
.81961 .41569 Mdot
.86667 .30588 Mdot
.72941 .27059 Mdot
.25098 .12157 Mdot
.22745 .15686 Mdot
.27843 .08235 Mdot
.68235 .46275 Mdot
.53725 .37255 Mdot
.58431 .30196 Mdot
.72157 .57255 Mdot
.59216 .45882 Mdot
.4902 .32941 Mdot
.41176 .18431 Mdot
.40784 .18039 Mdot
.36471 .35294 Mdot
.12157 .12549 Mdot
.16078 .14902 Mdot
.16863 .14902 Mdot
.1098 .1098 Mdot
.82745 .28627 Mdot
.99216 .54118 Mdot
.80392 .26667 Mdot
.86667 .28627 Mdot
.69412 .2549 Mdot
.28627 .09804 Mdot
.2549 .09804 Mdot
.47843 .06667 Mdot
.51373 .31765 Mdot
.47843 .28627 Mdot
.42353 .23922 Mdot
.35686 .20392 Mdot
.71373 .55294 Mdot
.62745 .50196 Mdot
.48235 .15294 Mdot
.53333 .39216 Mdot
.39608 .39216 Mdot
.12549 .11373 Mdot
.13725 .11765 Mdot
.13725 .11765 Mdot
.09412 .10196 Mdot
.83922 .25098 Mdot
.84706 .32157 Mdot
.84706 .26667 Mdot
.8549 .2549 Mdot
.79608 .31373 Mdot
.34902 .07059 Mdot
.32157 .03137 Mdot
.77255 .27059 Mdot
.64706 .42745 Mdot
.49804 .26667 Mdot
.78431 .63922 Mdot
.30196 .16863 Mdot
.55294 .33725 Mdot
.64706 .54118 Mdot
.61961 .23529 Mdot
.55294 .44314 Mdot
.0549 .0549 Mdot
.12549 .11373 Mdot
.34902 .32941 Mdot
.1451 .12549 Mdot
.12549 .13333 Mdot
.86275 .27451 Mdot
.87059 .29804 Mdot
.85098 .2549 Mdot
.85098 .24706 Mdot
.87059 .32157 Mdot
.51373 .0902 Mdot
.50588 .08235 Mdot
.81176 .27451 Mdot
.64314 .38039 Mdot
.63922 .38039 Mdot
.68627 .54118 Mdot
.4 .25882 Mdot
.46667 .19216 Mdot
.67451 .56078 Mdot
.61176 .24706 Mdot
.55686 .45098 Mdot
.08627 .07843 Mdot
.12941 .12549 Mdot
.34118 .32157 Mdot
.11765 .10588 Mdot
.0902 .09804 Mdot
.86275 .27451 Mdot
.88627 .28235 Mdot
.85098 .24706 Mdot
.86667 .26275 Mdot
.93333 .35686 Mdot
.88235 .36863 Mdot
.85098 .34118 Mdot
.84314 .28627 Mdot
.60784 .34902 Mdot
.58431 .33725 Mdot
.67843 .54118 Mdot
.52549 .38431 Mdot
.51373 .2 Mdot
.72549 .61176 Mdot
.6 .28235 Mdot
.59216 .4902 Mdot
.12157 .11373 Mdot
.1451 .14118 Mdot
.29804 .28627 Mdot
.11373 .10196 Mdot
.07451 .07451 Mdot
.83922 .2902 Mdot
.8902 .28627 Mdot
.8902 .28627 Mdot
.88235 .27843 Mdot
.90196 .3098 Mdot
.92157 .36078 Mdot
.87059 .33333 Mdot
.89804 .30196 Mdot
.63922 .38431 Mdot
.59608 .37647 Mdot
.66275 .53333 Mdot
.38431 .23137 Mdot
.73333 .46275 Mdot
.67059 .52549 Mdot
.52941 .32941 Mdot
.58824 .44706 Mdot
.59608 .57255 Mdot
.14118 .13725 Mdot
.14118 .14118 Mdot
.09804 .09804 Mdot
.12941 .12549 Mdot
.81961 .82745 Mdot
.86275 .28235 Mdot
.87059 .27451 Mdot
.87843 .28235 Mdot
.88235 .28627 Mdot
.87059 .31765 Mdot
.91373 .36863 Mdot
.92157 .36863 Mdot
.86667 .27451 Mdot
.53725 .3098 Mdot
.54118 .36471 Mdot
.74902 .62745 Mdot
.53725 .41569 Mdot
.51373 .16863 Mdot
.69412 .56471 Mdot
.39608 .19608 Mdot
.35686 .23922 Mdot
.72941 .7098 Mdot
.12941 .12549 Mdot
.22745 .21569 Mdot
.21961 .21569 Mdot
.11373 .1098 Mdot
.52157 .52549 Mdot
.81961 .30196 Mdot
.86667 .28627 Mdot
.88235 .30588 Mdot
.87451 .29412 Mdot
.83137 .30196 Mdot
.89412 .40784 Mdot
.92549 .38039 Mdot
.90588 .31373 Mdot
.54118 .20392 Mdot
.50588 .32549 Mdot
.34902 .24706 Mdot
.38824 .24706 Mdot
.81569 .55686 Mdot
.68627 .52549 Mdot
.46275 .23137 Mdot
.52549 .36078 Mdot
.45882 .38824 Mdot
.12157 .12549 Mdot
.12157 .11765 Mdot
.20392 .20392 Mdot
.14902 .14118 Mdot
.43529 .43922 Mdot
.73725 .74118 Mdot
.81961 .28627 Mdot
.90196 .32941 Mdot
.92157 .36471 Mdot
.89804 .33333 Mdot
.87059 .38824 Mdot
.89412 .46667 Mdot
.90588 .4 Mdot
.87451 .29412 Mdot
.67843 .28235 Mdot
.63137 .41961 Mdot
.41176 .31373 Mdot
.31373 .17647 Mdot
.65098 .39216 Mdot
.79608 .64706 Mdot
.55686 .28235 Mdot
.7098 .50196 Mdot
.57647 .47843 Mdot
.08235 .08235 Mdot
.11373 .1098 Mdot
.13725 .13725 Mdot
.12157 .11373 Mdot
.47843 .47843 Mdot
.44706 .4549 Mdot
.61176 .38824 Mdot
.92157 .33333 Mdot
.98824 .4902 Mdot
.96078 .41961 Mdot
.91373 .37647 Mdot
.95294 .56863 Mdot
.86275 .48627 Mdot
.82353 .32549 Mdot
.84706 .28235 Mdot
.79216 .40784 Mdot
.52941 .40784 Mdot
.73333 .56863 Mdot
.78039 .65882 Mdot
.53725 .30196 Mdot
.84706 .61569 Mdot
.64706 .35686 Mdot
.6 .35686 Mdot
.95294 .9451 Mdot
.19608 .18039 Mdot
.13333 .12941 Mdot
.13333 .13333 Mdot
.05098 .0549 Mdot
.50588 .5098 Mdot
.41961 .42745 Mdot
.69412 .28627 Mdot
.89804 .3098 Mdot
.97647 .45882 Mdot
.95686 .41569 Mdot
.95294 .43137 Mdot
.96863 .56863 Mdot
.91765 .54118 Mdot
.99216 .50196 Mdot
.86275 .29804 Mdot
.80784 .37647 Mdot
.78431 .64706 Mdot
.44314 .26667 Mdot
.85098 .71765 Mdot
.38039 .23137 Mdot
.46667 .13333 Mdot
.64314 .32941 Mdot
.63529 .38824 Mdot
.89412 .8902 Mdot
.09412 .0902 Mdot
.13725 .13333 Mdot
.12941 .12941 Mdot
.51373 .51373 Mdot
.53333 .53333 Mdot
.47451 .48235 Mdot
.96078 .96078 Mdot
.93725 .34902 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.94902 .39216 Mdot
.92157 .42745 Mdot
.94118 .5098 Mdot
.91765 .44706 Mdot
.87059 .2902 Mdot
.8902 .33725 Mdot
.65098 .38039 Mdot
.89412 .71765 Mdot
.82353 .70588 Mdot
.45098 .30196 Mdot
.8549 .67059 Mdot
.70196 .33725 Mdot
.68627 .37255 Mdot
.7451 .67843 Mdot
.34902 .33725 Mdot
.08235 .06667 Mdot
.11765 .12157 Mdot
.18824 .18824 Mdot
.54118 .54118 Mdot
.51373 .51373 Mdot
.47843 .48627 Mdot
1 .97647 Mdot
.94902 .36078 Mdot
.95294 .38039 Mdot
.88235 .34902 Mdot
.93333 .38431 Mdot
.93333 .39608 Mdot
.89412 .40784 Mdot
.93725 .43529 Mdot
.88235 .31765 Mdot
.88627 .30588 Mdot
.62353 .28235 Mdot
.99608 .74902 Mdot
.88235 .72549 Mdot
.78431 .65098 Mdot
.95294 .72941 Mdot
.77255 .38431 Mdot
.72549 .39216 Mdot
.76863 .69804 Mdot
.2549 .24314 Mdot
.3451 .33725 Mdot
.11373 .12941 Mdot
.21569 .22353 Mdot
.56078 .55294 Mdot
.35686 .35294 Mdot
.47451 .48235 Mdot
.55294 .54902 Mdot
.85882 .29804 Mdot
.93333 .3451 Mdot
.97255 .4549 Mdot
.91373 .38039 Mdot
.92941 .38039 Mdot
.94902 .41176 Mdot
.91373 .39608 Mdot
.96863 .43529 Mdot
.90196 .3451 Mdot
.84706 .33725 Mdot
.73725 .38431 Mdot
.82353 .52157 Mdot
.91765 .71373 Mdot
.92157 .72941 Mdot
.78824 .3098 Mdot
.80392 .43922 Mdot
.71765 .5451 Mdot
.35294 .34902 Mdot
.21961 .21176 Mdot
.28235 .3098 Mdot
.17255 .17647 Mdot
.63137 .62745 Mdot
.33333 .33725 Mdot
.36471 .36863 Mdot
.49804 .48627 Mdot
.6549 .31765 Mdot
.91765 .32941 Mdot
.93725 .37647 Mdot
.94902 .43922 Mdot
.9451 .42353 Mdot
.91373 .36471 Mdot
.94902 .40392 Mdot
.94902 .41176 Mdot
.95686 .41569 Mdot
.90196 .3451 Mdot
.76078 .29412 Mdot
.74902 .31765 Mdot
.6902 .37255 Mdot
.82745 .56863 Mdot
.76078 .27059 Mdot
.82745 .37647 Mdot
.7098 .39608 Mdot
.81176 .80392 Mdot
.27451 .26667 Mdot
.42745 .43137 Mdot
.21569 .23529 Mdot
.09804 .10588 Mdot
.63529 .63529 Mdot
.54118 .5451 Mdot
.54902 .54902 Mdot
.76471 .7451 Mdot
.94902 .36078 Mdot
.95294 .36078 Mdot
.93725 .4 Mdot
.92157 .41569 Mdot
.95294 .43529 Mdot
.89804 .36078 Mdot
.92549 .37647 Mdot
.93725 .39608 Mdot
.9451 .41176 Mdot
.88235 .32549 Mdot
.83137 .37647 Mdot
.76863 .33725 Mdot
.67451 .28235 Mdot
.69804 .26275 Mdot
.83922 .30196 Mdot
.85882 .41961 Mdot
.75294 .67843 Mdot
.15294 .15294 Mdot
.83922 .82353 Mdot
.15686 .19216 Mdot
.14902 .16863 Mdot
.6902 .67843 Mdot
.38431 .38824 Mdot
.60392 .58824 Mdot
.57255 .49412 Mdot
.80392 .3098 Mdot
.91765 .34118 Mdot
.9451 .38431 Mdot
.87843 .41176 Mdot
.88235 .41961 Mdot
.94902 .42745 Mdot
.94118 .38431 Mdot
.90588 .35686 Mdot
.93333 .39216 Mdot
.96863 .44314 Mdot
.85882 .38431 Mdot
.8549 .40784 Mdot
.82745 .38039 Mdot
.79608 .3451 Mdot
.8549 .3098 Mdot
.86667 .32549 Mdot
.83529 .64314 Mdot
.85098 .8549 Mdot
.50196 .4902 Mdot
.89804 .90196 Mdot
.51765 .52941 Mdot
.12941 .12549 Mdot
.66275 .66667 Mdot
.31765 .31373 Mdot
.60392 .55686 Mdot
.97647 .92157 Mdot
.93725 .34118 Mdot
.93725 .35686 Mdot
.88235 .40784 Mdot
.83922 .47843 Mdot
.87059 .45098 Mdot
.93333 .39608 Mdot
.95294 .40392 Mdot
.91765 .37647 Mdot
.8902 .39608 Mdot
.92549 .35294 Mdot
.70588 .38824 Mdot
.87059 .47059 Mdot
.8549 .44314 Mdot
.87059 .39216 Mdot
.86667 .34118 Mdot
.82745 .34118 Mdot
.81961 .77647 Mdot
.60392 .6 Mdot
.34118 .33333 Mdot
.96078 .97647 Mdot
.5098 .50588 Mdot
.7451 .72941 Mdot
.61961 .61961 Mdot
.30588 .30196 Mdot
.93725 .70196 Mdot
.75294 .31765 Mdot
.91765 .33725 Mdot
.90196 .39216 Mdot
.81176 .49412 Mdot
.77647 .4902 Mdot
.81176 .40784 Mdot
.92941 .37647 Mdot
.94118 .39216 Mdot
.95294 .42745 Mdot
.84314 .37647 Mdot
.81176 .37647 Mdot
.47843 .21961 Mdot
.66275 .3451 Mdot
.82353 .45098 Mdot
.86667 .43922 Mdot
.87843 .32549 Mdot
.72941 .48235 Mdot
.84314 .82745 Mdot
.27843 .26667 Mdot
.94902 .94118 Mdot
.25098 .24314 Mdot
.66667 .65882 Mdot
.71765 .71373 Mdot
.66275 .66275 Mdot
.59216 .51765 Mdot
.54118 .3098 Mdot
.94902 .36863 Mdot
.90196 .34902 Mdot
.8 .47843 Mdot
.76863 .58431 Mdot
.91765 .69412 Mdot
.87451 .43922 Mdot
.9451 .39216 Mdot
.9451 .38824 Mdot
.83529 .45098 Mdot
.92941 .39216 Mdot
.33725 .14902 Mdot
.36863 .18039 Mdot
.4549 .24706 Mdot
.58039 .2902 Mdot
.71373 .34118 Mdot
.79216 .32941 Mdot
.86667 .78039 Mdot
.67451 .67451 Mdot
.96078 .93725 Mdot
.88235 .88235 Mdot
.91373 .90196 Mdot
.79216 .78824 Mdot
.72941 .71765 Mdot
.63922 .63529 Mdot
.67059 .31373 Mdot
.90588 .78431 Mdot
.93333 .35294 Mdot
.87843 .41176 Mdot
.82745 .67843 Mdot
.82353 .70588 Mdot
.69804 .53333 Mdot
.90196 .45098 Mdot
.93725 .38039 Mdot
.92941 .38039 Mdot
.58039 .32549 Mdot
.89804 .37255 Mdot
.22745 .12941 Mdot
.25882 .16078 Mdot
.3098 .17255 Mdot
.40392 .21176 Mdot
.57647 .16863 Mdot
.57647 .2902 Mdot
.5451 .51373 Mdot
.23922 .23529 Mdot
.76471 .74118 Mdot
.9451 .95686 Mdot
.84706 .83922 Mdot
.82353 .80784 Mdot
.76863 .75294 Mdot
.73333 .71373 Mdot
.78431 .31373 Mdot
.76471 .31765 Mdot
.93333 .37255 Mdot
.82353 .53725 Mdot
.7451 .67843 Mdot
.42745 .3451 Mdot
.36863 .22353 Mdot
.90588 .46275 Mdot
.9451 .39216 Mdot
.8902 .40784 Mdot
.43922 .21176 Mdot
.88235 .40392 Mdot
.18039 .11765 Mdot
.2 .12941 Mdot
.22745 .1451 Mdot
.28235 .16471 Mdot
.79216 .35294 Mdot
.27059 .16471 Mdot
.23529 .23529 Mdot
.19216 .19608 Mdot
.4549 .44314 Mdot
.49412 .49804 Mdot
.8549 .8549 Mdot
.83137 .82745 Mdot
.77255 .76863 Mdot
.75686 .67059 Mdot
.71765 .36471 Mdot
.92941 .36863 Mdot
.85882 .39216 Mdot
.85882 .71765 Mdot
.9098 .86275 Mdot
.34118 .2902 Mdot
1 .8549 Mdot
.92549 .4549 Mdot
.95294 .4 Mdot
.63529 .3451 Mdot
.34118 .06667 Mdot
.79608 .38039 Mdot
.15294 .12157 Mdot
.18039 .14118 Mdot
.2 .16078 Mdot
.27843 .16471 Mdot
.78431 .39608 Mdot
.21176 .18039 Mdot
.19608 .19216 Mdot
.10196 .11373 Mdot
.27451 .25882 Mdot
.81961 .81961 Mdot
.87059 .87059 Mdot
.85882 .85098 Mdot
.81176 .80784 Mdot
.89804 .65882 Mdot
.62745 .52157 Mdot
.90588 .33333 Mdot
.84314 .47843 Mdot
.83529 .74902 Mdot
.39216 .36078 Mdot
.37255 .33725 Mdot
.92549 .7098 Mdot
.92941 .46667 Mdot
.9451 .38824 Mdot
.32549 .15686 Mdot
.32157 .08235 Mdot
.79608 .38039 Mdot
.14118 .1098 Mdot
.20784 .17647 Mdot
.15686 .13725 Mdot
.21569 .05098 Mdot
.70588 .38039 Mdot
.14118 .13725 Mdot
.13725 .12941 Mdot
.2902 .29412 Mdot
.51765 .50588 Mdot
.88627 .87843 Mdot
.87843 .87843 Mdot
.87451 .87451 Mdot
.85098 .85098 Mdot
.7451 .41961 Mdot
1 .96471 Mdot
.88235 .32941 Mdot
.83922 .55686 Mdot
.85882 .81176 Mdot
.2549 .23922 Mdot
.81961 .78824 Mdot
.94902 .6902 Mdot
.93725 .47059 Mdot
.93725 .4 Mdot
.23922 .16078 Mdot
.32157 .10196 Mdot
.80784 .39216 Mdot
.15294 .13333 Mdot
.1451 .12549 Mdot
.13333 .11373 Mdot
.34118 .08235 Mdot
.56863 .34118 Mdot
.12157 .12157 Mdot
.1451 .12157 Mdot
.72157 .72941 Mdot
.86275 .85882 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.88235 .88235 Mdot
.87451 .87451 Mdot
.52157 .13333 Mdot
1 .96863 Mdot
.89412 .35686 Mdot
.86275 .61176 Mdot
.86667 .82745 Mdot
.25098 .23922 Mdot
.48627 .4549 Mdot
.80784 .47843 Mdot
.90196 .48235 Mdot
.92157 .38824 Mdot
.21961 .16078 Mdot
.55686 .40784 Mdot
.86275 .40784 Mdot
.1451 .10588 Mdot
.1451 .13333 Mdot
.1451 .12549 Mdot
.35294 .07451 Mdot
.54902 .32549 Mdot
.12549 .12549 Mdot
.1098 .07059 Mdot
.84706 .84706 Mdot
.87059 .86667 Mdot
.85098 .85098 Mdot
.87451 .87451 Mdot
.87059 .87059 Mdot
.87059 .87059 Mdot
.69804 .32549 Mdot
1 .96863 Mdot
.85882 .35294 Mdot
.89804 .65882 Mdot
.8902 .8549 Mdot
.30196 .28235 Mdot
.34118 .30196 Mdot
.73725 .41569 Mdot
.89804 .51373 Mdot
.9098 .39608 Mdot
.19216 .14902 Mdot
.75686 .66275 Mdot
.88235 .42353 Mdot
.16471 .07059 Mdot
.17255 .14118 Mdot
.14118 .12157 Mdot
.37647 .0902 Mdot
.54118 .31765 Mdot
.12549 .1098 Mdot
.29412 .24706 Mdot
.86667 .86275 Mdot
.91373 .91373 Mdot
.69412 .6902 Mdot
.87451 .87451 Mdot
.85882 .85882 Mdot
.86275 .86275 Mdot
.86275 .49804 Mdot
1 .97255 Mdot
.86667 .39216 Mdot
.97255 .73333 Mdot
.86275 .81961 Mdot
.26667 .23922 Mdot
.21176 .16078 Mdot
.83529 .58824 Mdot
.86275 .52157 Mdot
.87843 .38824 Mdot
.17255 .12941 Mdot
.43922 .36471 Mdot
.86275 .44314 Mdot
.23529 .03529 Mdot
.20784 .14902 Mdot
.15686 .12549 Mdot
.37255 .07059 Mdot
.52941 .30588 Mdot
.13725 .09804 Mdot
.8 .75686 Mdot
.87059 .86667 Mdot
.7451 .74902 Mdot
.4549 .45098 Mdot
.8902 .88235 Mdot
.88627 .88627 Mdot
.85882 .86667 Mdot
.79608 .43137 Mdot
1 .97255 Mdot
.83137 .39608 Mdot
.97647 .74118 Mdot
.79216 .7451 Mdot
.31765 .28627 Mdot
.50588 .45098 Mdot
1 .81569 Mdot
.87059 .56471 Mdot
.8902 .41961 Mdot
.17647 .14118 Mdot
.26667 .20784 Mdot
.72549 .37255 Mdot
.40392 .0902 Mdot
.27843 .12157 Mdot
.20392 .09412 Mdot
.38824 .0549 Mdot
.52941 .27059 Mdot
.2 .08627 Mdot
.56471 .52549 Mdot
.88627 .87843 Mdot
.27451 .28235 Mdot
.30588 .29412 Mdot
.87451 .85882 Mdot
.88627 .88627 Mdot
.87059 .87843 Mdot
.76471 .4 Mdot
1 .96471 Mdot
.81176 .41176 Mdot
.94118 .69804 Mdot
.76863 .71765 Mdot
.78824 .75294 Mdot
.80784 .75686 Mdot
.58039 .45098 Mdot
.94902 .67843 Mdot
.87059 .43137 Mdot
.19608 .16078 Mdot
.24314 .2 Mdot
.64706 .36863 Mdot
.73725 .29804 Mdot
.42745 .09804 Mdot
.31373 .06667 Mdot
.43137 .04314 Mdot
.56078 .23922 Mdot
.29412 .05882 Mdot
.57647 .54118 Mdot
.90588 .88627 Mdot
.26275 .28235 Mdot
.20392 .17255 Mdot
.90196 .87843 Mdot
.87843 .87843 Mdot
.86667 .87451 Mdot
.72941 .37255 Mdot
1 .96471 Mdot
.76863 .40392 Mdot
.86667 .61569 Mdot
.83922 .79608 Mdot
.51765 .4902 Mdot
.47843 .43922 Mdot
.4902 .40392 Mdot
.99608 .73725 Mdot
.86667 .44706 Mdot
.18431 .15686 Mdot
.20392 .17647 Mdot
.80784 .59216 Mdot
.81961 .35686 Mdot
.65098 .21961 Mdot
.47451 .12157 Mdot
.46667 .02353 Mdot
.60392 .20392 Mdot
.47451 .12549 Mdot
.64314 .61176 Mdot
.51373 .50196 Mdot
.26667 .28627 Mdot
.16863 .12549 Mdot
.96078 .93725 Mdot
.88235 .87843 Mdot
.87059 .87843 Mdot
.68627 .33333 Mdot
1 .95686 Mdot
.75294 .41176 Mdot
.77647 .52941 Mdot
.94902 .92549 Mdot
.35294 .3451 Mdot
.43529 .42353 Mdot
.74118 .67843 Mdot
1 .75686 Mdot
.84314 .44706 Mdot
.18039 .14902 Mdot
.17647 .1451 Mdot
.62353 .44706 Mdot
.8902 .5098 Mdot
.82745 .36471 Mdot
.73725 .2902 Mdot
.61176 .13333 Mdot
.7451 .26667 Mdot
.74902 .3098 Mdot
.84314 .80784 Mdot
.27059 .26667 Mdot
.22353 .23529 Mdot
.15294 .09804 Mdot
.8902 .87451 Mdot
.91373 .8902 Mdot
.87451 .88235 Mdot
.66275 .32549 Mdot
1 .95294 Mdot
.75294 .41569 Mdot
.66667 .43922 Mdot
.92549 .91373 Mdot
.19216 .18431 Mdot
.21569 .22353 Mdot
.91765 .87451 Mdot
.98039 .72941 Mdot
.83922 .46667 Mdot
.16471 .1451 Mdot
.18039 .14902 Mdot
.36863 .20392 Mdot
1 .68627 Mdot
.83529 .39216 Mdot
.88235 .41961 Mdot
.81176 .35294 Mdot
.85098 .32549 Mdot
.83922 .36863 Mdot
.68627 .64706 Mdot
.25882 .2549 Mdot
.15294 .15686 Mdot
.13725 .08235 Mdot
.63137 .61569 Mdot
.87451 .83922 Mdot
.86667 .87059 Mdot
.60392 .28627 Mdot
1 .9451 Mdot
.77255 .43529 Mdot
.61569 .42745 Mdot
.70196 .68627 Mdot
.56078 .5451 Mdot
.66275 .6549 Mdot
.9451 .91373 Mdot
.91765 .67059 Mdot
.80784 .46275 Mdot
.24706 .21961 Mdot
.18824 .15686 Mdot
.35294 .18824 Mdot
.99608 .58039 Mdot
1 .61961 Mdot
.86275 .45882 Mdot
.91373 .52157 Mdot
.90588 .36863 Mdot
.83922 .40392 Mdot
.30588 .28627 Mdot
.20392 .19608 Mdot
.16078 .16078 Mdot
.16471 .1098 Mdot
.57255 .55686 Mdot
.3451 .32157 Mdot
.86667 .87451 Mdot
.54118 .23922 Mdot
1 .9451 Mdot
.76078 .41176 Mdot
.66667 .52941 Mdot
.49412 .47059 Mdot
.90196 .87843 Mdot
.97255 .95294 Mdot
.93725 .90588 Mdot
.83529 .58824 Mdot
.80392 .46275 Mdot
.52157 .48627 Mdot
.18431 .15294 Mdot
.34118 .14902 Mdot
.9098 .44706 Mdot
.96078 .57255 Mdot
.98431 .58824 Mdot
1 .60784 Mdot
.92549 .38824 Mdot
.74902 .38431 Mdot
.26275 .24706 Mdot
.15294 .1451 Mdot
.14902 .1451 Mdot
.17255 .11765 Mdot
.59216 .56863 Mdot
.73333 .7098 Mdot
.87059 .87843 Mdot
.52157 .21961 Mdot
1 .94902 Mdot
.81176 .43529 Mdot
.82745 .73333 Mdot
.36863 .33725 Mdot
.52157 .49412 Mdot
.92941 .90588 Mdot
.95294 .9098 Mdot
.76863 .51765 Mdot
.80784 .46667 Mdot
.47059 .42745 Mdot
.15294 .13333 Mdot
.33333 .1098 Mdot
.93725 .42745 Mdot
.92549 .4549 Mdot
.94902 .49804 Mdot
.97647 .53725 Mdot
.95294 .41176 Mdot
.52941 .24706 Mdot
.19216 .18824 Mdot
.14902 .14902 Mdot
.15294 .14902 Mdot
.16471 .1098 Mdot
.62745 .60392 Mdot
.6902 .65882 Mdot
.86667 .87451 Mdot
.51373 .21176 Mdot
1 .96863 Mdot
.83137 .42353 Mdot
.86275 .8 Mdot
.34902 .30196 Mdot
.38431 .35686 Mdot
.91765 .89412 Mdot
.93725 .89412 Mdot
.72941 .47843 Mdot
.81569 .48235 Mdot
.29804 .24314 Mdot
.23137 .2 Mdot
.32941 .07451 Mdot
.95294 .41176 Mdot
.94902 .43137 Mdot
.91373 .41569 Mdot
.92157 .43529 Mdot
.95294 .4 Mdot
.43137 .19608 Mdot
.15294 .14902 Mdot
.16078 .16863 Mdot
.16078 .15294 Mdot
.17647 .12157 Mdot
.58431 .56863 Mdot
.20392 .17255 Mdot
.87059 .87059 Mdot
.5098 .21176 Mdot
.85098 .72157 Mdot
.85882 .49412 Mdot
.89804 .8549 Mdot
.31373 .26667 Mdot
.25882 .21569 Mdot
.93725 .90196 Mdot
.59216 .53725 Mdot
.95294 .72941 Mdot
.57255 .32941 Mdot
.27843 .23529 Mdot
.39608 .36863 Mdot
.47059 .09412 Mdot
.93725 .39608 Mdot
.93725 .40392 Mdot
.94118 .40784 Mdot
.93725 .4 Mdot
.92157 .35686 Mdot
.23922 .09412 Mdot
.12941 .13725 Mdot
.22353 .23137 Mdot
.14902 .14902 Mdot
.59608 .54902 Mdot
.35294 .32941 Mdot
.45882 .43922 Mdot
.86275 .87059 Mdot
.83137 .45098 Mdot
.62353 .34902 Mdot
.79608 .48235 Mdot
.77647 .71373 Mdot
.7098 .65882 Mdot
.73725 .6902 Mdot
.95294 .91765 Mdot
.58039 .51373 Mdot
1 .75686 Mdot
.29412 .14902 Mdot
.25098 .21176 Mdot
.54902 .5098 Mdot
.85098 .37255 Mdot
.93725 .38431 Mdot
.9451 .39216 Mdot
.9451 .39216 Mdot
.94118 .38039 Mdot
.92941 .36471 Mdot
.21176 .14118 Mdot
.15294 .17647 Mdot
.24314 .26275 Mdot
.12941 .12549 Mdot
.95686 .92941 Mdot
.55294 .52941 Mdot
.73725 .71373 Mdot
.86667 .85882 Mdot
.60392 .21176 Mdot
.88627 .40392 Mdot
.80392 .6549 Mdot
.81176 .71765 Mdot
.6 .55294 Mdot
.94902 .90196 Mdot
.78824 .77647 Mdot
1 .84314 Mdot
.8549 .50196 Mdot
.24706 .20392 Mdot
.27059 .23922 Mdot
.59216 .49804 Mdot
.9451 .39216 Mdot
.95294 .39216 Mdot
.9451 .38431 Mdot
.9451 .38431 Mdot
.93725 .36078 Mdot
.87451 .37255 Mdot
.18039 .17647 Mdot
.27059 .28627 Mdot
.13333 .14118 Mdot
.24314 .21569 Mdot
.88627 .88627 Mdot
.64314 .61961 Mdot
.83922 .80784 Mdot
.9098 .85098 Mdot
.5451 .33333 Mdot
.87059 .37255 Mdot
.87843 .80784 Mdot
.36078 .28627 Mdot
.28627 .23529 Mdot
.38039 .32549 Mdot
.4 .38039 Mdot
.7451 .46667 Mdot
.77255 .4549 Mdot
.24706 .22745 Mdot
.25098 .22353 Mdot
.66667 .41569 Mdot
.94118 .38431 Mdot
.90588 .40392 Mdot
.93333 .38824 Mdot
.93333 .38824 Mdot
.93333 .37255 Mdot
.79216 .45098 Mdot
.18824 .18824 Mdot
.20392 .21569 Mdot
.25882 .24706 Mdot
.39216 .34118 Mdot
.48627 .48235 Mdot
.37255 .32549 Mdot
.88235 .87451 Mdot
.81569 .62353 Mdot
1 .95686 Mdot
.86275 .49412 Mdot
.81176 .7451 Mdot
.44706 .4 Mdot
.3098 .2549 Mdot
.4549 .42745 Mdot
.83922 .77255 Mdot
1 .76471 Mdot
.39216 .23529 Mdot
.27843 .24706 Mdot
.25098 .21176 Mdot
.83137 .38039 Mdot
.92941 .39608 Mdot
.69804 .31765 Mdot
.88235 .37255 Mdot
.90196 .37647 Mdot
.90588 .36078 Mdot
.23922 .10196 Mdot
.14118 .14118 Mdot
.2902 .28235 Mdot
.42353 .40392 Mdot
.71373 .68627 Mdot
.35686 .34902 Mdot
.81961 .76078 Mdot
.86667 .87451 Mdot
.75686 .42745 Mdot
.67843 .38824 Mdot
.8902 .7098 Mdot
.90588 .86275 Mdot
.87059 .82745 Mdot
.89804 .85882 Mdot
.53333 .51765 Mdot
.98431 .78824 Mdot
.85098 .47843 Mdot
.26667 .20784 Mdot
.27059 .23529 Mdot
.27843 .18431 Mdot
.93725 .40392 Mdot
.88627 .47451 Mdot
.77255 .40784 Mdot
.63922 .25882 Mdot
.71373 .30196 Mdot
.84314 .35294 Mdot
.15294 .12941 Mdot
.36471 .35686 Mdot
.38039 .36078 Mdot
.18039 .15686 Mdot
.88627 .88627 Mdot
.89412 .8902 Mdot
.43137 .39216 Mdot
.88235 .86667 Mdot
.56863 .36078 Mdot
.92549 .52941 Mdot
.52157 .47059 Mdot
.48627 .47059 Mdot
.47843 .44314 Mdot
.56078 .53333 Mdot
.23529 .16078 Mdot
.84706 .59608 Mdot
.78824 .49412 Mdot
.23529 .19608 Mdot
.24314 .21569 Mdot
.44706 .09804 Mdot
.92157 .38824 Mdot
1 .87059 Mdot
.5451 .26275 Mdot
.74902 .54902 Mdot
.58824 .3451 Mdot
.77255 .43922 Mdot
.42745 .43922 Mdot
.26275 .25098 Mdot
.16471 .14902 Mdot
.14902 .12549 Mdot
.88235 .88235 Mdot
.8 .7451 Mdot
.87451 .87451 Mdot
.72549 .50588 Mdot
.91373 .78431 Mdot
.96863 .81961 Mdot
.43137 .4 Mdot
.37647 .34118 Mdot
.38039 .35294 Mdot
.40392 .38431 Mdot
.86667 .60392 Mdot
.83137 .46667 Mdot
.29412 .21176 Mdot
.25098 .22353 Mdot
.25098 .19216 Mdot
.92157 .38431 Mdot
.80392 .47059 Mdot
1 .85098 Mdot
.97255 .87451 Mdot
.96863 .85098 Mdot
1 .74118 Mdot
.42353 .35294 Mdot
.23922 .24314 Mdot
.18824 .17647 Mdot
.18431 .16863 Mdot
.9098 .9098 Mdot
.92941 .92549 Mdot
.51373 .46667 Mdot
.87843 .87059 Mdot
.61961 .36863 Mdot
.86667 .50196 Mdot
.37255 .32157 Mdot
.34902 .31765 Mdot
.35686 .32549 Mdot
.3451 .33725 Mdot
.90588 .72549 Mdot
.98039 .72157 Mdot
.80392 .52157 Mdot
.27059 .23137 Mdot
.23529 .21569 Mdot
.48627 .11765 Mdot
.90588 .41176 Mdot
.9451 .8549 Mdot
.87451 .75294 Mdot
.94902 .76078 Mdot
.96078 .85098 Mdot
.79608 .45098 Mdot
.21961 .23137 Mdot
.23529 .22745 Mdot
.18039 .16078 Mdot
.12941 .10588 Mdot
.87843 .88627 Mdot
.66667 .60392 Mdot
.87451 .87451 Mdot
.57647 .3451 Mdot
.63137 .46275 Mdot
.61961 .44706 Mdot
.3098 .21176 Mdot
.29412 .2 Mdot
.28235 .20392 Mdot
.40392 .32941 Mdot
.78431 .49412 Mdot
.92549 .47843 Mdot
.25098 .19608 Mdot
.23922 .21961 Mdot
.27059 .16078 Mdot
.93725 .39608 Mdot
.50588 .36863 Mdot
.54902 .36471 Mdot
1 .8549 Mdot
.9098 .81961 Mdot
.60392 .20392 Mdot
.24706 .22353 Mdot
.25882 .26667 Mdot
.17255 .15686 Mdot
.16863 .1451 Mdot
.88627 .88627 Mdot
.89804 .88235 Mdot
.69412 .67059 Mdot
.90196 .8549 Mdot
.58824 .50196 Mdot
.73333 .33333 Mdot
.88627 .6549 Mdot
.77647 .63922 Mdot
.83137 .62353 Mdot
.55686 .52549 Mdot
.7451 .47451 Mdot
.9451 .55686 Mdot
.68235 .50588 Mdot
.25098 .20784 Mdot
.23922 .2 Mdot
.85882 .40784 Mdot
.81176 .47059 Mdot
.99216 .88235 Mdot
.94118 .85882 Mdot
.78824 .47451 Mdot
.99608 .84706 Mdot
.48235 .24314 Mdot
.21176 .22353 Mdot
.17255 .16471 Mdot
.15686 .15294 Mdot
.50588 .4902 Mdot
.88627 .88627 Mdot
.41569 .37647 Mdot
.87059 .87843 Mdot
.70588 .47451 Mdot
.81176 .43529 Mdot
.87843 .51373 Mdot
.91765 .68235 Mdot
.82745 .55686 Mdot
.95294 .88235 Mdot
.60392 .39216 Mdot
.9451 .55686 Mdot
.77255 .50588 Mdot
.21176 .16863 Mdot
.28235 .25098 Mdot
.62353 .24314 Mdot
.83137 .44706 Mdot
.96078 .86667 Mdot
.93725 .87059 Mdot
.8549 .46275 Mdot
.96471 .83137 Mdot
.77647 .45098 Mdot
.20392 .21176 Mdot
.14902 .14118 Mdot
.14902 .1451 Mdot
.15294 .11765 Mdot
.8902 .8902 Mdot
.52549 .48627 Mdot
.87843 .87843 Mdot
.45098 .25098 Mdot
.72941 .41569 Mdot
.90588 .43137 Mdot
.85882 .52549 Mdot
.78824 .50588 Mdot
.77255 .69412 Mdot
.81176 .60784 Mdot
.95294 .51765 Mdot
.78824 .52157 Mdot
.43922 .39608 Mdot
.27451 .23922 Mdot
.67059 .28627 Mdot
.82353 .47059 Mdot
.98824 .87843 Mdot
.93333 .86667 Mdot
.83137 .4549 Mdot
1 .83137 Mdot
.73725 .43529 Mdot
.22353 .22353 Mdot
.14902 .13333 Mdot
.14902 .13333 Mdot
.17647 .13333 Mdot
.88627 .88627 Mdot
.45098 .39608 Mdot
.87843 .87843 Mdot
.44706 .26275 Mdot
.6 .35686 Mdot
.96078 .42745 Mdot
.8902 .48235 Mdot
1 .72157 Mdot
.54118 .45882 Mdot
.97647 .74118 Mdot
.93725 .4549 Mdot
.77647 .5098 Mdot
.53333 .4902 Mdot
.25882 .22353 Mdot
.69412 .29804 Mdot
.81569 .50588 Mdot
1 .87451 Mdot
.94902 .86667 Mdot
.84706 .49412 Mdot
1 .83529 Mdot
.72157 .43922 Mdot
.23137 .22353 Mdot
.14902 .13333 Mdot
.15294 .13333 Mdot
.21961 .17647 Mdot
.88627 .88627 Mdot
.62745 .56863 Mdot
.87451 .87451 Mdot
.58039 .41176 Mdot
.63137 .3451 Mdot
.97255 .42353 Mdot
.89412 .46667 Mdot
.96471 .67059 Mdot
.32549 .22745 Mdot
.9098 .56863 Mdot
.94118 .42353 Mdot
.51373 .3451 Mdot
.37255 .33725 Mdot
.21176 .17255 Mdot
.9098 .43529 Mdot
.40784 .23529 Mdot
.49804 .32941 Mdot
.97647 .85098 Mdot
.47451 .2549 Mdot
.63922 .27843 Mdot
.36863 .18431 Mdot
.23137 .21961 Mdot
.16078 .14902 Mdot
.1451 .1098 Mdot
.88235 .84706 Mdot
.8902 .8902 Mdot
.58824 .53333 Mdot
.87451 .87451 Mdot
.51765 .38431 Mdot
.9098 .42353 Mdot
.95686 .42353 Mdot
.90196 .48627 Mdot
.8549 .63529 Mdot
.98039 .75294 Mdot
.93725 .46275 Mdot
.92157 .40392 Mdot
.26667 .23922 Mdot
.47451 .43529 Mdot
.27059 .12941 Mdot
.87059 .43529 Mdot
.9451 .87059 Mdot
.98039 .90588 Mdot
.83922 .40392 Mdot
.9451 .8549 Mdot
.88235 .38039 Mdot
.21569 .17647 Mdot
.16078 .15294 Mdot
.17647 .15294 Mdot
.19216 .14902 Mdot
.88627 .88627 Mdot
.93333 .92941 Mdot
.51765 .49412 Mdot
.96078 .88235 Mdot
1 .96863 Mdot
.89412 .36863 Mdot
.95294 .41961 Mdot
.9098 .47059 Mdot
.94118 .65882 Mdot
.93333 .48235 Mdot
.9451 .40784 Mdot
.80784 .52157 Mdot
.26667 .24706 Mdot
.52549 .49412 Mdot
.75294 .33725 Mdot
.36078 .22745 Mdot
.45882 .28627 Mdot
.98431 .84314 Mdot
.47451 .26275 Mdot
.65882 .31765 Mdot
.53725 .31373 Mdot
.22745 .21569 Mdot
.14902 .14118 Mdot
.16471 .12549 Mdot
.45098 .43137 Mdot
.88627 .88627 Mdot
.85098 .81176 Mdot
.88235 .87451 Mdot
.7098 .61569 Mdot
.77255 .42745 Mdot
.92157 .39608 Mdot
.94902 .44314 Mdot
.8902 .49412 Mdot
.9098 .4549 Mdot
.9451 .40784 Mdot
.87451 .39608 Mdot
.28235 .24314 Mdot
.2549 .23137 Mdot
.63529 .39216 Mdot
.45882 .23922 Mdot
1 .87451 Mdot
.94118 .86667 Mdot
.83529 .48627 Mdot
1 .83529 Mdot
.83137 .42745 Mdot
.19608 .18431 Mdot
.15686 .15294 Mdot
.12157 .09804 Mdot
.44706 .41961 Mdot
.8902 .8902 Mdot
.86667 .85098 Mdot
.89412 .8902 Mdot
.5451 .45098 Mdot
.69804 .56471 Mdot
.86275 .43137 Mdot
.91765 .39608 Mdot
.95686 .46275 Mdot
.9451 .4549 Mdot
.94902 .40784 Mdot
.94902 .41569 Mdot
.30588 .22353 Mdot
.25882 .24314 Mdot
.46667 .30588 Mdot
.48235 .24706 Mdot
1 .88235 Mdot
.93725 .87843 Mdot
.80784 .45882 Mdot
.97255 .83922 Mdot
.87843 .40784 Mdot
.16078 .14902 Mdot
.15686 .1451 Mdot
.2549 .24314 Mdot
.33725 .31373 Mdot
.88627 .88627 Mdot
.91373 .91373 Mdot
.8902 .87451 Mdot
.94118 .87059 Mdot
.96471 .89804 Mdot
.76863 .42353 Mdot
.90196 .41176 Mdot
.94902 .42745 Mdot
.96471 .43137 Mdot
.95686 .40784 Mdot
.9098 .41176 Mdot
.30588 .23529 Mdot
.27059 .24706 Mdot
.38431 .13725 Mdot
.95686 .79216 Mdot
.65098 .43529 Mdot
.94118 .86275 Mdot
.45882 .2549 Mdot
.85882 .6 Mdot
.81176 .46275 Mdot
.16471 .16078 Mdot
.20784 .2 Mdot
.45882 .45098 Mdot
.15294 .12549 Mdot
.88627 .88627 Mdot
.69804 .68235 Mdot
.88235 .87843 Mdot
.36863 .29804 Mdot
.84706 .71373 Mdot
.81569 .43529 Mdot
.91765 .38431 Mdot
.95686 .40784 Mdot
.95686 .40784 Mdot
.94118 .40784 Mdot
.3098 .17255 Mdot
.27059 .23529 Mdot
.34902 .19608 Mdot
.7098 .41176 Mdot
.89412 .6549 Mdot
.9451 .87059 Mdot
.58824 .45098 Mdot
1 .79608 Mdot
.82353 .42353 Mdot
.18039 .17255 Mdot
.47843 .46275 Mdot
.21961 .21176 Mdot
.18039 .14118 Mdot
.88627 .88627 Mdot
.90196 .89412 Mdot
.90196 .89804 Mdot
.57647 .50588 Mdot
.93725 .81961 Mdot
.78824 .42745 Mdot
.96078 .41569 Mdot
.92941 .38039 Mdot
.9451 .40784 Mdot
.91765 .43922 Mdot
.21569 .15686 Mdot
.26275 .22745 Mdot
.75686 .37255 Mdot
.82353 .51373 Mdot
.64706 .36863 Mdot
.99216 .85098 Mdot
.98431 .87059 Mdot
.93333 .38431 Mdot
.39608 .2902 Mdot
.48627 .47059 Mdot
.16471 .14902 Mdot
.16471 .16078 Mdot
.95686 .94902 Mdot
.8902 .8902 Mdot
.32941 .30588 Mdot
.8902 .87451 Mdot
.74118 .73725 Mdot
.70588 .50196 Mdot
.92157 .40392 Mdot
.93333 .38039 Mdot
.92157 .37255 Mdot
.9451 .43529 Mdot
.22745 .12157 Mdot
.23137 .19608 Mdot
.74902 .37255 Mdot
.87451 .45098 Mdot
.74902 .36471 Mdot
.9098 .63922 Mdot
1 .78039 Mdot
.92941 .37647 Mdot
.43137 .35294 Mdot
.20392 .2 Mdot
.17255 .15686 Mdot
.16863 .15294 Mdot
.93333 .92549 Mdot
.8902 .8902 Mdot
.40784 .37255 Mdot
.8902 .87451 Mdot
.92157 .91765 Mdot
.83922 .42353 Mdot
.94118 .41569 Mdot
.9451 .42353 Mdot
.89804 .37647 Mdot
.43137 .14902 Mdot
.18824 .1098 Mdot
.34902 .13333 Mdot
.93725 .42745 Mdot
.91373 .41569 Mdot
.78824 .39608 Mdot
.78824 .4549 Mdot
.91765 .4 Mdot
.61569 .43137 Mdot
.16471 .14902 Mdot
.15294 .14902 Mdot
.17255 .15294 Mdot
.38039 .35294 Mdot
.8902 .8902 Mdot
.47843 .43922 Mdot
.88235 .87843 Mdot
.73725 .72157 Mdot
.80392 .45098 Mdot
.94118 .43529 Mdot
.90196 .44314 Mdot
.9098 .43529 Mdot
.55686 .20784 Mdot
.22745 .10588 Mdot
.38431 .07451 Mdot
.93725 .41961 Mdot
.93333 .41961 Mdot
.92157 .4549 Mdot
.88235 .42745 Mdot
.93725 .38431 Mdot
.26275 .18431 Mdot
.16078 .1451 Mdot
.15686 .1451 Mdot
.16078 .14118 Mdot
.96078 .95294 Mdot
.89412 .89412 Mdot
.81569 .76078 Mdot
.89412 .87843 Mdot
.91373 .91765 Mdot
.75686 .43529 Mdot
.84706 .43137 Mdot
.76471 .43922 Mdot
.81569 .4549 Mdot
.65098 .33333 Mdot
.24314 .06667 Mdot
.9098 .44314 Mdot
.94902 .41569 Mdot
.93725 .41961 Mdot
.94118 .42745 Mdot
.93333 .40392 Mdot
.90196 .4 Mdot
.20392 .2 Mdot
.16863 .14902 Mdot
.14902 .13725 Mdot
.15686 .13333 Mdot
.88627 .88627 Mdot
.90588 .8902 Mdot
.56078 .54118 Mdot
.94902 .92941 Mdot
.76471 .69804 Mdot
.6902 .43922 Mdot
.7451 .58039 Mdot
.65098 .47059 Mdot
.65882 .43137 Mdot
.53725 .25098 Mdot
.42745 .0549 Mdot
.95686 .44314 Mdot
.92941 .41176 Mdot
.92941 .41176 Mdot
.95294 .41569 Mdot
.93725 .38431 Mdot
.30196 .18431 Mdot
.16863 .15294 Mdot
.17255 .14118 Mdot
.1451 .12941 Mdot
.89804 .8902 Mdot
.8902 .8902 Mdot
.62353 .58039 Mdot
.88235 .87843 Mdot
.84314 .86275 Mdot
.73725 .60784 Mdot
1 .96471 Mdot
.91765 .8549 Mdot
.58431 .47451 Mdot
.6549 .40784 Mdot
.67059 .30196 Mdot
.93333 .44314 Mdot
.94902 .43922 Mdot
.94118 .41961 Mdot
.94902 .41176 Mdot
.94902 .4 Mdot
.3098 .16471 Mdot
.18039 .16078 Mdot
.17255 .13725 Mdot
.14902 .13333 Mdot
.95294 .9451 Mdot
.89412 .89412 Mdot
.49412 .46275 Mdot
.88235 .87843 Mdot
.96471 .98431 Mdot
.99216 .96471 Mdot
.70588 .63137 Mdot
.67059 .45098 Mdot
.81569 .41176 Mdot
.89412 .41176 Mdot
.95686 .45098 Mdot
.96471 .44314 Mdot
.95686 .4 Mdot
.8 .46275 Mdot
.18431 .13333 Mdot
.14902 .1451 Mdot
.16863 .1451 Mdot
.24314 .22353 Mdot
.89412 .8902 Mdot
.89804 .89412 Mdot
.88627 .88627 Mdot
.39216 .41569 Mdot
.8902 .78824 Mdot
.76078 .49804 Mdot
.78039 .41569 Mdot
.84314 .40784 Mdot
.8902 .41961 Mdot
.92549 .41569 Mdot
.86275 .43137 Mdot
.21176 .11373 Mdot
.05098 .04314 Mdot
.07059 .04706 Mdot
.24314 .23922 Mdot
.90588 .89804 Mdot
.88627 .88627 Mdot
.87451 .87451 Mdot
.39216 .39216 Mdot
1 .95294 Mdot
.85098 .70196 Mdot
.70588 .45882 Mdot
.76078 .41961 Mdot
.80392 .38824 Mdot
.84314 .38431 Mdot
.53725 .30196 Mdot
.4902 .48235 Mdot
.42745 .41961 Mdot
.44706 .44706 Mdot
.56078 .58039 Mdot
.89412 .8902 Mdot
.88627 .8902 Mdot
.9451 .91765 Mdot
1 .96471 Mdot
.93333 .77647 Mdot
.83529 .60392 Mdot
.77255 .46667 Mdot
.72941 .39216 Mdot
.77255 .6549 Mdot
.91765 .90196 Mdot
.90588 .89804 Mdot
.21569 .25098 Mdot
.31765 .33725 Mdot
.89804 .89412 Mdot
.88627 .89804 Mdot
.28235 .27059 Mdot
1 .94902 Mdot
.95686 .83529 Mdot
.81961 .67059 Mdot
.81961 .78431 Mdot
.87451 .86667 Mdot
.60392 .59608 Mdot
.27059 .32157 Mdot
.28627 .32941 Mdot
.8 .80784 Mdot
.78431 .80392 Mdot
.82745 .82353 Mdot
.62353 .60392 Mdot
.2549 .26275 Mdot
.61176 .61569 Mdot
.53725 .58039 Mdot
.6902 .73333 Mdot
.87451 .87843 Mdot
.89804 .9098 Mdot
.95686 .96863 Mdot
.39608 .44314 Mdot
.23922 .28627 Mdot
.9098 .93725 Mdot
.62353 .66667 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 400},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001T2000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`002Ooooonf
0000017ooooo]P00000:ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo
00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooooooo
o`2booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`08ooooo`002Oooool01000003ooooooooooooooon]0?ooo`Cooooo00<00000ooooooooool03ooo
ool01000003ooooooooooooooon]0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@0
0000oooooooooooooooo[@3oool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooo
oooo[@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooojd0
oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooojd0X23`1?ooool00`00
003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooon]0?ooo`Cooooo00<00000oooo
ooooool03oooool01000003ooooooooooooooon]0:0Pl0Cooooo00<00000ooooooooool02?ooool0
00Wooooo00@00000oooooooooooooooo[@3oool4ooooo`0300000?oooooooooo00oooooo00@00000
oooooooooooooooo[@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooo
ooooooooojd0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooojd0X23`
1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooon]0?ooo`Cooooo
00<00000ooooooooool03oooool01000003ooooooooooooooon]0:0Pl0Cooooo00<00000oooooooo
ool02?ooool000Wooooo00@00000oooooooooooooooo[@3oool4ooooo`0300000?oooooooooo00oo
oooo00@00000oooooooooooooooo[@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`04
00000?ooooooooooooooojd0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooo
ooooojd0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooolF
0?ooo`030?n0003oool0oooo09@0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooo
oooooooooaH0X23`00<0oooo0:0Pl02P8?00U02P8?04ooooo`0300000?oooooooooo00Sooooo0009
ooooo`0400000?oooooooooooooooaL0oooo00<0oh000?ooo`3oool0T`3oool4ooooo`0300000?oo
oooooooo00oooooo00@00000oooooooooooooooo5`2P8?000`3oool0X23`0:0Pl02C0:0Pl0Cooooo
00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo5`3oool30?n009<0oooo
1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooaL0X23`0`3ooonC0:0Pl0Co
oooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo5`3oool30?n009<0
oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooaL0X23`0`3ooonC0:0P
l0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo603oool30?n0
0980oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooaP0X23`0`3ooonB
0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo6@3oool4
0?n00900oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooaT0X23`103o
oon@0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo6P3o
ool40?n008l0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooaX0X23`
103ooon?0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo
6`3oool40?n008h0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooa/0
X23`103ooon>0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooo
oooo6`3oool50?n008d0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooo
oa/0X23`1@3ooon=0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooo
oooooooo7@3oool40?n008`0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooo
oooooad0X23`103ooon<0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooo
oooooooooooo7P3oool40?n008/0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooo
oooooooooah0X23`103ooon;0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000
oooooooooooooooo7P3oool40?n008/0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oo
oooooooooooooah0X23`103ooon;0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@0
0000oooooooooooooooo7`3oool60?n00400oooo6P3oP00^0?ooo`Cooooo00<00000ooooooooool0
3oooool01000003ooooooooooooooolO0:0Pl0H0oooo@02P8?0J0?ooobh0X23`1?ooool00`00003o
ooooooooo`08ooooo`002Oooool01000003ooooooooooooooolP0?ooo`H0oh00>@3ooolW0?n002L0
oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooob00X23`1P3oooli0:0P
l2L0oooo9`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooo
ob40oooo1P3oP00e0?ooobd0oh00903oool4ooooo`0300000?oooooooooo00oooooo00@00000oooo
oooooooooooo8@2P8?060?ooocD0X23`;@3ooolT0:0Pl0Cooooo00<00000ooooooooool02?ooool0
00Wooooo00@00000oooooooooooooooo903oool40?n00300oooo=03oP00Q0?ooo`Cooooo00<00000
ooooooooool03oooool01000003ooooooooooooooolT0:0Pl0@0oooo<02P8?0d0?ooob40X23`1?oo
ool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooolU0?ooo`@0oh00;@3o
oolh0?n001l0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooobD0X23`
103oool]0:0Pl3P0oooo7`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oo
ooooooooooooobH0oooo103oP00[0?ooocX0oh007P3oool4ooooo`0300000?oooooooooo00oooooo
00@00000oooooooooooooooo9P2P8?040?ooob/0X23`>P3ooolN0:0Pl0Cooooo00<00000oooooooo
ool02?ooool000Wooooo00@00000oooooooooooooooo9`3oool50?n002P0oooo?03oP00M0?ooo`Co
oooo00<00000ooooooooool03oooool01000003ooooooooooooooolW0:0Pl0D0oooo:02P8?0l0?oo
oad0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooolW0?oo
o`D0oh00:03oooll0?n001d0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooo
ooooobL0X23`1@3ooolX0:0Pl3`0oooo7@2P8?04ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0400000?ooooooooooooooobT0oooo103oP00U0?oood00oh006`3oool4ooooo`0300000?oooooo
oooo00oooooo00@00000oooooooooooooooo:@2P8?040?ooobD0X23`@03ooolK0:0Pl0Cooooo00<0
0000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo:P3oool40?n002@0oooo@03o
P00K0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooolZ0:0Pl0@0oooo
902P8?100?oooa/0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooo
ooooool/0?ooo`<0oh008P3ooom20?n001X0oooo1?ooool00`00003oooooooooo`0?ooooo`040000
0?ooooooooooooooob`0X23`0`3ooolR0:0Pl480oooo6P2P8?04ooooo`0300000?oooooooooo00So
oooo0009ooooo`0400000?ooooooooooooooobd0oooo0`3oP00Q0?oood80oh006P3oool4ooooo`03
00000?oooooooooo00oooooo00@00000oooooooooooooooo;@2P8?030?ooob40X23`@P3ooolJ0:0P
l0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo;P3oool30?n0
0200oooo@P3oP00J0?ooo`Cooooo00<00000ooooooooool03oooool01000003oooooooooooooool^
0:0Pl0<0oooo802P8?120?oooaX0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000
003oooooooooooooool_0?ooo`<0oh007`3ooom30?n001T0oooo1?ooool00`00003oooooooooo`0?
ooooo`0400000?ooooooooooooooobl0X23`0`3ooolO0:0Pl4<0oooo6@2P8?04ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0400000?ooooooooooooooobl0oooo0`3oP00O0?oood<0oh006@3o
ool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooooooo;`2P8?030?oooal0X23`
@`3ooolI0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo
<03oool40?n001d0oooo@`3oP00I0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooo
ooooooooool`0:0Pl0@0oooo7@2P8?130?oooaT0X23`1?ooool00`00003oooooooooo`08ooooo`00
2Oooool01000003ooooooooooooooola0?ooo`D0oh00703ooom20?n001T0oooo1?ooool00`00003o
ooooooooo`0?ooooo`0400000?oooooooooooooooc40X23`1@3ooolL0:0Pl480oooo6@2P8?04oooo
o`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooc40oooo1P3oP00K0?oo
od80oh006@3oool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooooooo<@2P8?06
0?oooa/0X23`@P3ooolI0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooo
oooooooooooo<P3oool60?n001`0oooo@03oP00I0?ooo`Cooooo00<00000ooooooooool03oooool0
1000003ooooooooooooooolb0:0Pl0H0oooo702P8?100?oooaT0X23`1?ooool00`00003ooooooooo
o`08ooooo`002Oooool01000003ooooooooooooooold0?ooo`D0oh006`3ooom00?n001T0oooo1?oo
ool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooc@0X23`1@3ooolK0:0Pl400oooo
6@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooocD0oooo
1@3oP00K0?oooch0oh006P3oool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooo
oooo=@2P8?050?oooa/0X23`?P3ooolJ0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo
00@00000oooooooooooooooo=P3oool60?n001X0oooo?@3oP00J0?ooo`Cooooo00<00000oooooooo
ool03oooool01000003ooooooooooooooolf0:0Pl0H0oooo6P2P8?0m0?oooaX0X23`1?ooool00`00
003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooolf0?ooo`H0oh006P3ooolm0?n0
01X0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooocH0X23`1P3ooolJ
0:0Pl3d0oooo6P2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooo
ooooocL0oooo1P3oP00I0?ooocd0oh006P3oool4ooooo`0300000?oooooooooo00oooooo00@00000
oooooooooooooooo=`2P8?060?oooaT0X23`?@3ooolJ0:0Pl0Cooooo00<00000ooooooooool02?oo
ool000Wooooo00@00000oooooooooooooooo=`3oool70?n001T0oooo?03oP00J0?ooo`Cooooo00<0
0000ooooooooool03oooool01000003ooooooooooooooolg0:0Pl0L0oooo6@2P8?0l0?oooaX0X23`
1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooolh0?ooo`L0oh00
6@3ooolj0?n001/0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooocP0
X23`1`3ooolI0:0Pl3X0oooo6`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`040000
0?ooooooooooooooocT0oooo1`3oP00I0?ooocT0oh006`3oool4ooooo`0300000?oooooooooo00oo
oooo00@00000oooooooooooooooo>@2P8?070?oooaT0X23`>@3ooolK0:0Pl0Cooooo00<00000oooo
ooooool02?ooool000Wooooo00@00000oooooooooooooooo>@3oool80?n001X0oooo=@3oP00M0?oo
o`Cooooo00<00000ooooooooool03oooool01000003oooooooooooooooli0:0Pl0P0oooo6P2P8?0e
0?oooad0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooolj
0?ooo`P0oh006P3ooold0?n001d0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooo
ooooooooocX0X23`203ooolJ0:0Pl3@0oooo7@2P8?04ooooo`0300000?oooooooooo00Sooooo0009
ooooo`0400000?ooooooooooooooocX0oooo2P3oP00I0?oooc80oh007P3oool4ooooo`0300000?oo
oooooooo00oooooo00@00000oooooooooooooooo>P2P8?0:0?oooaT0X23`<P3ooolN0:0Pl0Cooooo
00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo>P3oool:0?n001T0oooo
<P3oP00N0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooolj0:0Pl0X0
oooo6@2P8?0b0?oooah0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooo
ooooooooooll0?ooo`T0oh006@3ooola0?n001h0oooo1?ooool00`00003oooooooooo`0?ooooo`04
00000?oooooooooooooooc`0X23`2@3ooolI0:0Pl340oooo7P2P8?04ooooo`0300000?oooooooooo
00Sooooo0009ooooo`0400000?oooooooooooooooc`0oooo2P3oP00I0?ooobl0oh007`3oool4oooo
o`0300000?oooooooooo00oooooo00@00000oooooooooooooooo?02P8?0:0?oooaT0X23`;`3ooolO
0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo?@3oool;
0?n001P0oooo;P3oP00O0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooo
oolm0:0Pl0/0oooo602P8?0^0?oooal0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool0
1000003ooooooooooooooolm0?ooo``0oh006P3ooolZ0?n00200oooo1?ooool00`00003ooooooooo
o`0?ooooo`0400000?ooooooooooooooocd0X23`303ooolJ0:0Pl2X0oooo802P8?04ooooo`030000
0?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooch0oooo303oP00J0?ooobP0oh00
8@3oool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooooooo?P2P8?0<0?oooaX0
X23`:03ooolQ0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooo
oooo?P3oool>0?n001X0oooo9P3oP00Q0?ooo`Cooooo00<00000ooooooooool03oooool01000003o
ooooooooooooooln0:0Pl0h0oooo6P2P8?0V0?ooob40X23`1?ooool00`00003oooooooooo`08oooo
o`002Oooool01000003oooooooooooooooln0?ooo`l0oh00703ooolR0?n00280oooo1?ooool00`00
003oooooooooo`0?ooooo`0400000?oooooooooooooooch0X23`3`3ooolL0:0Pl280oooo8P2P8?04
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooch0oooo3`3oP00L
0?ooob80oh008P3oool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooooooo?P2P
8?0?0?oooa`0X23`8P3ooolR0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000
oooooooooooooooo?`3oool?0?n00200oooo6`3oP00T0?ooo`Cooooo00<00000ooooooooool03ooo
ool01000003ooooooooooooooolo0:0Pl0l0oooo802P8?0K0?ooob@0X23`1?ooool00`00003ooooo
ooooo`08ooooo`002Oooool01000003ooooooooooooooolo0?oooa00oh008P3ooolG0?n002D0oooo
1?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooocl0X23`403ooolR0:0Pl1L0
oooo9@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooood00
oooo403oP00A0?ooo`H0oh003`3ooolA0?n002H0oooo1?ooool00`00003oooooooooo`0?ooooo`04
00000?oooooooooooooood00X23`403ooolA0:0Pl0H0oooo3`2P8?0A0?ooobH0X23`1?ooool00`00
003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooom00?oooa40oh00403oool70?n0
0140oooo3@3oP00W0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom0
0:0Pl140oooo402P8?070?oooa40X23`3@3ooolW0:0Pl0Cooooo00<00000ooooooooool02?ooool0
00Wooooo00@00000oooooooooooooooo@@3ooolA0?n000h0oooo2`3oP00C0?ooo`H0oh00:@3oool4
ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooooooo@@2P8?0A0?ooo`h0X23`2`3o
oolC0:0Pl0H0oooo:@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooo
oooooooood80oooo4P3oP00<0?ooo``0oh00@@3oool4ooooo`0300000?oooooooooo00oooooo00@0
0000oooooooooooooooo@P2P8?0B0?ooo``0X23`303ooom10:0Pl0Cooooo00<00000ooooooooool0
2?ooool000Wooooo00@00000ooooooooooooooooA03ooolB0?n000X0oooo3P3oP00o0?ooo`Cooooo
00<00000ooooooooool03oooool01000003ooooooooooooooom40:0Pl180oooo2P2P8?0>0?ooocl0
X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooom40?oooa80
oh002P3oool>0?n003l0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooo
od@0X23`4P3oool:0:0Pl0h0oooo?`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`04
00000?ooooooooooooooodD0oooo4P3oP0090?ooo`l0oh00?P3oool4ooooo`0300000?oooooooooo
00oooooo00@00000ooooooooooooooooA@2P8?0B0?ooo`T0X23`3`3oooln0:0Pl0Cooooo00<00000
ooooooooool02?ooool000Wooooo00@00000ooooooooooooooooA@3ooolC0?n000P0oooo403oP00m
0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom50:0Pl1<0oooo202P
8?0@0?ooocd0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooo
oom60?oooa<0oh00203oool@0?n003`0oooo1?ooool00`00003oooooooooo`0?ooooo`0400000?oo
ooooooooooooodH0X23`4`3oool80:0Pl100oooo?02P8?04ooooo`0300000?oooooooooo00Sooooo
0009ooooo`0400000?ooooooooooooooodL0oooo503oP0060?oooa80oh00>P3oool4ooooo`030000
0?oooooooooo00oooooo00@00000ooooooooooooooooA`2P8?0D0?ooo`H0X23`4P3ooolj0:0Pl0Co
oooo00<00000ooooooooool02?ooool000Wooooo00@00000ooooooooooooooooB03ooolE0?n000@0
oooo503oP00h0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom80:0P
l1D0oooo102P8?0D0?ooocP0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003o
oooooooooooooom90?oooaD0oh000`3ooolE0?n003L0oooo1?ooool00`00003oooooooooo`0?oooo
o`0400000?ooooooooooooooodT0X23`5@3oool30:0Pl1D0oooo=`2P8?04ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0400000?ooooooooooooooodX0oooo;@3oP00f0?ooo`Cooooo00<00000
ooooooooool03oooool01000003ooooooooooooooom:0:0Pl2d0oooo=P2P8?04ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0400000?ooooooooooooooodX0oooo;@3oP00f0?ooo`Cooooo00<0
0000ooooooooool03oooool01000003ooooooooooooooom:0:0Pl2d0oooo=P2P8?04ooooo`030000
0?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooood`0oooo;03oP00e0?ooo`Cooooo
00<00000ooooooooool03oooool01000003ooooooooooooooom<0:0Pl2`0oooo=@2P8?04ooooo`03
00000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooood`0oooo;@3oP00d0?ooo`Co
oooo00<00000ooooooooool03oooool01000003ooooooooooooooom<0:0Pl2d0oooo=02P8?04oooo
o`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooodd0oooo;P3oP00b0?oo
o`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom=0:0Pl2h0oooo<P2P8?04
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooodh0oooo;`3oP00`
0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom>0:0Pl2l0oooo<02P
8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooodl0oooo;`3o
P00_0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom?0:0Pl2l0oooo
;`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooe00oooo
;`3oP00^0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom@0:0Pl2l0
oooo;P2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooe40
oooo;`3oP00]0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomA0:0P
l2l0oooo;@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooo
oe40oooo;`3oP00]0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomA
0:0Pl2l0oooo;@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooo
oooooe80oooo;`3oP00/0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooo
oomB0:0Pl2l0oooo;02P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooo
oooooooooe80oooo<@3oP00Z0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooo
oooooomB0:0Pl340oooo:P2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oo
oooooooooooooe@0oooo<03oP00Y0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooo
oooooooooomD0:0Pl300oooo:@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`040000
0?oooooooooooooooeD0oooo<03oP00X0?ooo`Cooooo00<00000ooooooooool03oooool01000003o
oooooooooooooomE0:0Pl300oooo:02P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`04
00000?oooooooooooooooeH0oooo<03oP00W0?ooo`Cooooo00<00000ooooooooool03oooool01000
003ooooooooooooooomF0:0Pl300oooo9`2P8?04ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0400000?oooooooooooooooeL0oooo<03oP00V0?ooo`Cooooo00<00000ooooooooool03oooool0
1000003ooooooooooooooomG0:0Pl300oooo9P2P8?04ooooo`0300000?oooooooooo00Sooooo0009
ooooo`0400000?oooooooooooooooeL0oooo<03oP00V0?ooo`Cooooo00<00000ooooooooool03ooo
ool01000003ooooooooooooooomG0:0Pl300oooo9P2P8?04ooooo`0300000?oooooooooo00Sooooo
0009ooooo`0400000?oooooooooooooooeP0oooo<03oP00U0?ooo`Cooooo00<00000ooooooooool0
3oooool01000003ooooooooooooooomH0:0Pl300oooo9@2P8?04ooooo`0300000?oooooooooo00So
oooo0009ooooo`0400000?oooooooooooooooeT0oooo<03oP00T0?ooo`Cooooo00<00000oooooooo
ool03oooool01000003ooooooooooooooomI0:0Pl300oooo902P8?04ooooo`0300000?oooooooooo
00Sooooo0009ooooo`0400000?oooooooooooooooe/0oooo<@3oP00Q0?ooo`Cooooo00<00000oooo
ooooool03oooool01000003ooooooooooooooomK0:0Pl340oooo8@2P8?04ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0400000?oooooooooooooooe/0oooo<P3oP00P0?ooo`Cooooo00<00000
ooooooooool03oooool01000003ooooooooooooooomK0:0Pl380oooo802P8?04ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0400000?oooooooooooooooe`0oooo<P3oP00O0?ooo`Cooooo00<0
0000ooooooooool03oooool01000003ooooooooooooooomL0:0Pl380oooo7`2P8?04ooooo`030000
0?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooed0oooo<P3oP00N0?ooo`Cooooo
00<00000ooooooooool03oooool01000003ooooooooooooooomM0:0Pl380oooo7P2P8?04ooooo`03
00000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooeh0oooo<P3oP00M0?ooo`Co
oooo00<00000ooooooooool03oooool01000003ooooooooooooooomN0:0Pl380oooo7@2P8?04oooo
o`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooeh0oooo<P3oP00M0?oo
o`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomN0:0Pl380oooo7@2P8?04
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooel0oooo<`3oP00K
0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomO0:0Pl3<0oooo6`2P
8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooof00oooo<`3o
P00J0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomP0:0Pl3<0oooo
6P2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooof00oooo
=03oP00I0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomP0:0Pl3@0
oooo6@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooof40
oooo=03oP00H0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomQ0:0P
l3@0oooo602P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooo
of<0oooo<`3oP00G0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomS
0:0Pl3<0oooo5`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooo
ooooof@0oooo<`3oP00F0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooo
oomT0:0Pl3<0oooo5P2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooo
ooooooooofD0oooo<`3oP00E0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooo
oooooomU0:0Pl3<0oooo5@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oo
ooooooooooooofD0oooo<`3oP00E0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooo
oooooooooomU0:0Pl3<0oooo5@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`040000
0?ooooooooooooooofH0oooo=03oP00C0?ooo`Cooooo00<00000ooooooooool03oooool01000003o
oooooooooooooomV0:0Pl3@0oooo4`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`04
00000?ooooooooooooooofL0oooo=03oP00B0?ooo`Cooooo00<00000ooooooooool03oooool01000
003ooooooooooooooomW0:0Pl3@0oooo4P2P8?04ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0400000?ooooooooooooooofL0oooo=@3oP00A0?ooo`Cooooo00<00000ooooooooool03oooool0
1000003ooooooooooooooomW0:0Pl3D0oooo4@2P8?04ooooo`0300000?oooooooooo00Sooooo0009
ooooo`0400000?ooooooooooooooofP0oooo=@3oP00@0?ooo`Cooooo00<00000ooooooooool03ooo
ool01000003ooooooooooooooomX0:0Pl3D0oooo402P8?04ooooo`0300000?oooooooooo00Sooooo
0009ooooo`0400000?ooooooooooooooofT0oooo=@3oP00?0?ooo`Cooooo00<00000ooooooooool0
3oooool01000003ooooooooooooooomY0:0Pl3D0oooo3`2P8?04ooooo`0300000?oooooooooo00So
oooo0009ooooo`0400000?ooooooooooooooof/0oooo=03oP00>0?ooo`Cooooo00<00000oooooooo
ool03oooool01000003ooooooooooooooom[0:0Pl3@0oooo3P2P8?04ooooo`0300000?oooooooooo
00Sooooo0009ooooo`0400000?ooooooooooooooof`0oooo=03oP00=0?ooo`Cooooo00<00000oooo
ooooool03oooool01000003ooooooooooooooom/0:0Pl3@0oooo3@2P8?04ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0400000?ooooooooooooooof`0oooo=03oP00=0?ooo`Cooooo00<00000
ooooooooool03oooool01000003ooooooooooooooom/0:0Pl3@0oooo3@2P8?04ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0400000?ooooooooooooooofd0oooo=@3oP00;0?ooo`Cooooo00<0
0000ooooooooool03oooool01000003ooooooooooooooom]0:0Pl3D0oooo2`2P8?04ooooo`030000
0?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooofd0oooo=P3oP00:0?ooo`Cooooo
00<00000ooooooooool03oooool01000003ooooooooooooooom]0:0Pl3H0oooo2P2P8?04ooooo`03
00000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooofh0oooo=P3oP0090?ooo`Co
oooo00<00000ooooooooool03oooool01000003ooooooooooooooom^0:0Pl3H0oooo2@2P8?04oooo
o`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooofl0oooo=P3oP0080?oo
o`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom_0:0Pl3H0oooo202P8?04
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooog00oooo=P3oP007
0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooom`0:0Pl3H0oooo1`2P
8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooog40oooo=P3o
P0060?ooo`Cooooo00<00000ooooooooool03oooool01000003oooooooooooooooma0:0Pl3H0oooo
1P2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooog<0oooo
=@3oP0050?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomc0:0Pl3D0
oooo1@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooog<0
oooo=@3oP0050?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomc0:0P
l3D0oooo1@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooo
og<0oooo=`3oP0030?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooomc
0:0Pl3L0oooo0`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooo
ooooog@0oooo=`3oP0020?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooo
oomd0:0Pl3L0oooo0P2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooo
ooooooooogD0oooo=`3oP0000`3oooooooooooooo`02ooooo`0300000?oooooooooo00oooooo00@0
0000ooooooooooooooooM@2P8?0g0?ooo`030:0Pl?oooooooooo00;ooooo00<00000ooooooooool0
2?ooool000Wooooo00@00000ooooooooooooooooMP3ooolg0?n000Cooooo00<00000ooooooooool0
3oooool01000003ooooooooooooooomf0:0Pl3L0oooo1?ooool00`00003oooooooooo`08ooooo`00
2Oooool01000003ooooooooooooooomg0?ooocH0oh001?ooool00`00003oooooooooo`0?ooooo`04
00000?ooooooooooooooogL0X23`=P3oool4ooooo`0300000?oooooooooo00Sooooo0009ooooo`04
00000?ooooooooooooooogL0oooo=P3oP004ooooo`0300000?oooooooooo00oooooo00@00000oooo
ooooooooooooM`2P8?0f0?ooo`Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooo
ooooooooooooN03ooole0?n000Cooooo00<00000ooooooooool03oooool01000003ooooooooooooo
oomh0:0Pl3D0oooo1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooo
oomh0?ooocD0oh001?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooogP0X23`
=@3oool4ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooogT0oooo
=03oP004ooooo`0300000?oooooooooo00oooooo00@00000ooooooooooooooooN@2P8?0d0?ooo`Co
oooo00<00000ooooooooool02?ooool000Wooooo00@00000ooooooooooooooooN`3ooolb0?n000Co
oooo00<00000ooooooooool03oooool01000003ooooooooooooooomk0:0Pl380oooo1?ooool00`00
003oooooooooo`08ooooo`002Oooool01000003oooooooooooooooml0?oooc40oh001?ooool00`00
003oooooooooo`0?ooooo`0400000?ooooooooooooooog`0X23`<@3oool4ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0400000?ooooooooooooooogd0oooo<03oP004ooooo`0300000?oooooo
oooo00oooooo00@00000ooooooooooooooooO@2P8?0`0?ooo`Cooooo00<00000ooooooooool02?oo
ool000Wooooo00@00000ooooooooooooooooOP3oool_0?n000Cooooo00<00000ooooooooool03ooo
ool01000003ooooooooooooooomn0:0Pl2l0oooo1?ooool00`00003oooooooooo`08ooooo`002Ooo
ool01000003ooooooooooooooomo0?ooobh0oh001?ooool00`00003oooooooooo`0?ooooo`040000
0?ooooooooooooooogl0X23`;P3oool4ooooo`0300000?oooooooooo00Sooooo0009ooooo`040000
0?oooooooooooooooh00oooo;@3oP004ooooo`0300000?oooooooooo00oooooo00@00000oooooooo
ooooooooP02P8?0]0?ooo`Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooo
ooooooooP03oool]0?n000Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooon0
0:0Pl2d0oooo1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooon3
0?oooa@0oh00103ooolB0?n000Cooooo00<00000ooooooooool03oooool01000003ooooooooooooo
oon30:0Pl1@0oooo102P8?0B0?ooo`Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000
ooooooooooooooooQP3oool@0?n000L0oooo403oP004ooooo`0300000?oooooooooo00oooooo00@0
0000ooooooooooooooooQP2P8?0@0?ooo`L0X23`403oool4ooooo`0300000?oooooooooo00Sooooo
0009ooooo`0400000?ooooooooooooooohT0oooo303oP00:0?ooo`h0oh001?ooool00`00003ooooo
ooooo`0?ooooo`0400000?ooooooooooooooohT0X23`303oool:0:0Pl0h0oooo1?ooool00`00003o
ooooooooo`08ooooo`002Oooool01000003ooooooooooooooon>0?ooo`@0oh00403oool;0?n000Co
oooo00<00000ooooooooool03oooool01000003ooooooooooooooon>0:0Pl0@0oooo402P8?0;0?oo
o`Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000ooooooooooooooooX`3oool:0?n0
00Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooonS0:0Pl0X0oooo1?ooool0
0`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooonT0?ooo`T0oh001?ooool0
0`00003oooooooooo`0?ooooo`0400000?oooooooooooooooj@0X23`2@3oool4ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0400000?oooooooooooooooj@0oooo2@3oP004ooooo`0300000?oo
oooooooo00oooooo00@00000ooooooooooooooooY02P8?090?ooo`Cooooo00<00000ooooooooool0
2?ooool000Wooooo00@00000ooooooooooooooooY@3oool80?n000Cooooo00<00000ooooooooool0
3oooool01000003ooooooooooooooonU0:0Pl0P0oooo1?ooool00`00003oooooooooo`08ooooo`00
2Oooool01000003ooooooooooooooonW0?ooo`H0oh001?ooool00`00003oooooooooo`0?ooooo`04
00000?ooooooooooooooojL0X23`1P3oool4ooooo`0300000?oooooooooo00Sooooo0009ooooo`04
00000?ooooooooooooooojP0oooo1@3oP004ooooo`0300000?oooooooooo00oooooo00@00000oooo
ooooooooooooZ02P8?050?ooo`Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooo
ooooooooooooZP3oool30?n000Cooooo00<00000ooooooooool03oooool01000003ooooooooooooo
oonZ0:0Pl0<0oooo1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooo
oon[0?ooo`80oh001?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooj/0X23`
0P3oool4ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooj`0oooo
00<0oh00ooooooooool00_ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooj`0
X23`00<0ooooooooooooool00_ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooo
oooooooooon]0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooon]0:0P
l0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo[@3oool4oooo
o`0300000?oooooooooo00oooooo00@00000oooooooooooooooo[@2P8?04ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0400000?ooooooooooooooojd0oooo1?ooool00`00003oooooooooo`0?
ooooo`0400000?ooooooooooooooojd0X23`1?ooool00`00003oooooooooo`08ooooo`002Oooool0
1000003ooooooooooooooon]0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooo
oooooon]0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooooooooooo
[@3oool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooooooo[@2P8?04ooooo`03
00000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooojd0oooo1?ooool00`00003o
ooooooooo`0?ooooo`0400000?ooooooooooooooojd0X23`1?ooool00`00003oooooooooo`08oooo
o`002Oooool01000003ooooooooooooooon]0?ooo`Cooooo00<00000ooooooooool03oooool01000
003ooooooooooooooon]0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooo
oooooooooooo[@3oool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooooooooooo[@2P
8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooojd0oooo1?oo
ool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooojd0X23`1?ooool00`00003ooooo
ooooo`08ooooo`002Oooool01000003ooooooooooooooon]0?ooo`Cooooo00<00000ooooooooool0
3oooool01000003ooooooooooooooon]0:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo
00@00000oooooooooooooooo[@3oool4ooooo`0300000?oooooooooo00oooooo00@00000oooooooo
oooooooo[@2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooo
ohh0oooo103oP00K0?ooo`Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooon>
0:0Pl0@0oooo6`2P8?04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooo
ooooohl0oooo1@3oP00B0?ooo`@0oh000`3oool4ooooo`0300000?oooooooooo00oooooo00@00000
ooooooooooooooooS`2P8?050?oooa80X23`103oool30:0Pl0Cooooo00<00000ooooooooool02?oo
ool000Wooooo00@00000ooooooooooooooooS`3oool70?n000h0oooo2@3oP004ooooo`0300000?oo
oooooooo00oooooo00@00000ooooooooooooooooS`2P8?070?ooo`h0X23`2@3oool4ooooo`030000
0?oooooooooo00Sooooo0009ooooo`0400000?ooooooooooooooohl0oooo2@3oP00;0?ooo`X0oh00
1?ooool00`00003oooooooooo`0?ooooo`0400000?ooooooooooooooohl0X23`2@3oool;0:0Pl0X0
oooo1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooooooooon@0?ooo`/0
oh001`3oool;0?n000Cooooo00<00000ooooooooool03oooool01000003ooooooooooooooon@0:0P
l0/0oooo1`2P8?0;0?ooo`Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000oooooooo
ooooooooTP3oool<0?n000030?ooo`3oP000oh0000`0oh001?ooool00`00003oooooooooo`0?oooo
o`0400000?oooooooooooooooi80X23`303oool00`2P8?00oooo0?ooo`0<0?ooo`Cooooo00<00000
ooooooooool02?ooool000Wooooo00@00000ooooooooooooooooTP3oool<0?n000030?ooo`3oP000
oh0000`0oh001?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooi80X23`303o
ool00`2P8?00oooo0?ooo`0<0?ooo`Cooooo00<00000ooooooooool02?ooool000Wooooo00@00000
ooooooooooooooooTP3ooolK0?n000Cooooo00<00000ooooooooool03oooool01000003ooooooooo
oooooonB0:0Pl1/0oooo1?ooool00`00003oooooooooo`08ooooo`002Oooool01000003ooooooooo
oooooonC0?oooaX0oh001?ooool00`00003oooooooooo`0?ooooo`0400000?oooooooooooooooi<0
X23`6P3oool4ooooo`0300000?oooooooooo00Sooooo0009ooooo`0400000?oooooooooooooooi<0
oooo6P3oP004ooooo`0300000?oooooooooo00oooooo00@00000ooooooooooooooooT`2P8?0J0?oo
o`Cooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo]P00000A
oooookH000002_ooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOoo
ool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool000Wooooo]P00000AoooookH00000
2_ooool000Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
0;;ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool08_ooool00`3oO`3o
ooooooooo`2=ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0/_ooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo
00<00000ooooooooool09Oooool00`2P8?3oooooooooo`0Yooooo`030:0Pl?oooooooooo05kooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0/_ooool00`00003ooooooooo
o`0?ooooo`0300000?oooooooooo03Oooooo00<0X23`ooooooooool0N?ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000
ooooooooool09oooool00`2P8?3oooooooooo`28ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`06oooo
o`030:0Pl?oooooooooo04;ooooo00<0X23`ooooooooool0I?ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool02_ooool00`2P8?3oooooooooo`2Uooooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo0;;ooooo00<00000ooooooooool03oooool00`00003oooooooooo`06ooooo`80X23`
6oooool20:0Pl1kooooo00<0X23`ooooooooool01?ooool00`2P8?3oooooooooo`1Uooooo`030000
0?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo0;;ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`0booooo`030:0Pl?oooooooooo07gooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool04Oooool00`3oO`3oooooooooo`2Nooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0<ooooo`050?mo0?ooooooooooooooo`3oO`005_ooool00`3oO`3oooooooooo`28
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool03?ooool00`2P8?3oooooooooo`02
ooooo`030:0Pl?oooooooooo00Oooooo00<0X23`ooooooooool02oooool00`2P8?3oooooooooo`09
ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooo`2P8?000oooool00`2P8?3oooooooooo`0@
ooooo`030:0Pl?oooooooooo05cooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool0/_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo00[ooooo00<0X23`oooo
ooooool0:oooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`oooo
ooooool0KOooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Eooooo`03
0?mo0?oooooooooo01Cooooo00<0ogl0ooooooooool0Poooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo00cooooo00<0X23`ooooooooool01oooool0102P8?3oooooooooo`2P8?0Eoooo
o`030:0Pl?oooooooooo00Gooooo00@0X23`ooooooooool0X23`7Oooool00`2P8?3oooooooooo`1G
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01Wooooo00<0ogl0oooo
ooooool0U_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo027ooooo00<0X23`oooo
ooooool0S_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2booooo`03
00000?oooooooooo00oooooo00<00000ooooooooool02_ooool01@2P8?3oooooooooooooool0X23`
03;ooooo00<0X23`ooooooooool00_ooool00`2P8?3oooooooooo`0Aooooo`030:0Pl?oooooooooo
05Gooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool04Oooool01@3oO`3o
ooooooooooooool0ogl001[ooooo00<0ogl0ooooooooool0Ooooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo00gooooo0P2P8?04ooooo`030:0Pl?oooooooooo00<0X23`2Oooool00`2P
8?3oooooooooo`03ooooo`030:0Pl?oooooooooo0080X23`0oooool00`2P8?3oooooooooo`0Goooo
o`050:0Pl?ooooooooooooooo`2P8?000oooool00`2P8?3oooooooooo`1Mooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo01Gooooo00<0ogl0ooooooooool03?ooool00`3o
O`3oooooooooo`0Cooooo`030?mo0?oooooooooo07Gooooo00<00000ooooooooool03oooool00`00
003oooooooooo`0>ooooo`040:0Pl?oooooooooo0:0Pl1Kooooo00<0X23`ooooooooool03?ooool0
0`2P8?3oooooooooo`1hooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
017ooooo00<0ogl0ooooo`3oO`000oooool20?mo00Kooooo00<0ogl0ooooooooool0T?ooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo00kooooo0P2P8?000oooool0X23`0:0Pl0020:0P
l003ooooo`2P8?00X23`00?ooooo00D0X23`oooooooooooooooo0:0Pl006ooooo`030:0Pl?oooooo
oooo013ooooo00<0X23`ooooooooool0M_ooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`0Aooooo`030?mo0?oooooooooo00Cooooo00<0ogl0ooooooooool0Uoooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo00oooooo00<0X23`ooooooooool00P2P8?000ooo
ool0X23`ooooo`0<ooooo`030:0Pl?oooooooooo08cooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool04Oooool00`3oO`3oooooooooo`03ooooo`80ogl01_ooool0103oO`3o
ooooooooooooool20?mo0003ooooo`3oO`00ogl001oooooo00<0ogl0ooooooooool0J?ooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo017ooooo00<0X23`ooooo`2P8?000_ooool00`2P
8?3ooooo0:0Pl003ooooo`80X23`=oooool00`2P8?3oooooooooo`1Jooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo01?ooooo00D0ogl0ooooooooool0ogl0ooooo`020?mo
0003ooooo`3oO`3ooooo00;ooooo0P3oO`000oooool0ogl0ooooo`06ooooo`030?mo0?oooooooooo
00Kooooo00<0ogl0ooooooooool02_ooool00`3oO`3oooooooooo`1_ooooo`0300000?oooooooooo
00oooooo00<00000ooooooooool04_ooool30:0Pl003ooooo`2P8?00X23`0080X23`00Cooooo0:0P
l?ooool0X23`1_ooool00`2P8?3ooooo0:0Pl003ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`
ooooooooool08?ooool00`2P8?3oooooooooo`1Mooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo01Gooooo00<0ogl0ooooo`3oO`000oooool00`3oO`3oooooooooo`04oooo
o`030?mo0?oooooooooo08gooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Aoooo
o`030:0Pl?oooooooooo00D0X23`00Cooooo0:0Pl02P8?00X23`1?ooool00`2P8?3oooooooooo`02
ooooo`030:0Pl?oooooooooo00Gooooo00<0X23`ooooooooool0POooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`0Fooooo`@0ogl000?ooooo0?mo003oO`000`3oO`000ooo
ool0ogl0ooooo`05ooooo`030?mo0?oooooooooo02Sooooo00<0ogl0ooooooooool0G?ooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo01?ooooo1`2P8?02ooooo`@0X23`7?ooool00`2P
8?3oooooooooo`03ooooo`030:0Pl?oooooooooo00cooooo00<0X23`ooooooooool01oooool00`2P
8?3oooooooooo`0=ooooo`030:0Pl?oooooooooo04Cooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool05oooool30?mo0004ooooo`3oO`00ogl00?mo02Wooooo00<0ogl0oooo
ooooool0J?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Gooooo102P8?000ooo
ool0X23`ooooo`030:0Pl0Cooooo00<0X23`ooooooooool0S?ooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`0Eooooo`80ogl000Cooooo0?mo0?oooooooooo103oO`02oooo
o`030?mo0?ooool0ogl008kooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Hoooo
o`@0X23`00Cooooo0:0Pl?ooool0X23`0_ooool01@2P8?3oooooooooooooool0X23`00_ooooo00<0
X23`ooooooooool01Oooool00`2P8?3oooooooooo`0>ooooo`030:0Pl?oooooooooo06Cooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool07Oooool00`3oO`3ooooo0?mo0002
ooooo`050?mo0?ooooooooooooooo`3oO`00=Oooool00`3oO`3oooooooooo`1Cooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool06?ooool70:0Pl3Gooooo00<0X23`ooooooooool0Fooo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0Looooo`040?mo0?oooooo
oooo0?mo00kooooo00<0ogl0ooooooooool0=_ooool00`3oO`3oooooooooo`18ooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool06?ooool00`2P8?3oooooooooo`050:0Pl007ooooo`2P
8?3oooooooooo`2P8?3ooooo0:0Pl00Aooooo`030:0Pl?oooooooooo07Oooooo00<00000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool06oooool00`3oO`3oooooooooo`030?mo0003oooo
o`3oO`3ooooo00Oooooo00<0ogl0ooooooooool09?ooool00`3oO`3oooooooooo`06ooooo`030?mo
0?oooooooooo00;ooooo0P3oO`000oooool0ogl0ooooo`03ooooo`030?mo0?oooooooooo00Gooooo
00<0ogl0ooooooooool0?oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01[ooooo
102P8?000oooool0X23`0:0Pl0040:0Pl0;ooooo0P2P8?03ooooo`030:0Pl?ooool0X23`0080X23`
0_ooool00`2P8?3ooooo0:0Pl007ooooo`030:0Pl?oooooooooo07;ooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool07_ooool30?mo00?ooooo00<0ogl0ooooooooool01?oo
ool00`3oO`3oooooooooo`0=ooooo`030?mo0?oooooooooo00[ooooo00<0ogl0ooooooooool00ooo
ool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00Sooooo00<0ogl0ooooooooool0DOoo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo01Sooooo00<0X23`ooooo`2P8?000ooo
ool0102P8?3oooooooooooooool20:0Pl0oooooo00<0X23`ooooooooool00_ooool00`2P8?3ooooo
ooooo`0Oooooo`030:0Pl?oooooooooo00Sooooo00<0X23`ooooooooool0B_ooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`0Rooooo`040?mo0?ooool0ogl00?mo00Sooooo
00@0ogl0ooooooooool0ogl02?ooool00`3oO`3oooooooooo`05ooooo`030?mo0?oooooooooo00oo
oooo00<0ogl0ooooooooool01Oooool0103oO`3oooooooooo`3oO`0Aooooo`030?mo0?oooooooooo
00Gooooo00<0ogl0ooooooooool0=_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
01Sooooo00@0X23`oooooooooooooooo0P2P8?001?ooool0X23`ooooooooool30:0Pl13ooooo00<0
X23`ooooo`2P8?00N_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0N
ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool01_ooool00`3oO`3oooooooooo`0K
ooooo`030?mo0?oooooooooo00Oooooo00<0ogl0ooooo`3oO`000oooool00`3oO`3oooooooooo`0E
ooooo`030?mo0?oooooooooo03gooooo00<00000ooooooooool03oooool00`00003oooooooooo`0P
ooooo`040:0Pl?oooooooooo0:0Pl1_ooooo00<0X23`ooooooooool01?ooool00`2P8?3ooooooooo
o`1Yooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo01oooooo00@0ogl0
oooooooooooooooo0P3oO`0Looooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool01_oo
ool20?mo00Cooooo00<0ogl0ooooooooool01oooool00`3oO`3ooooo0?mo000=ooooo`030?mo0?oo
ool0ogl0043ooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Mooooo`040:0Pl?oo
ool0X23`0:0Pl0_ooooo00@0X23`ooooooooool0X23`0oooool00`2P8?3oooooooooo`09ooooo`03
0:0Pl?oooooooooo00Cooooo0P2P8?1Zooooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo02;ooooo00D0ogl0ooooo`3oO`3ooooo0?mo0002ooooo`030?mo0?oooooooooo00Go
oooo00<0ogl0ooooooooool01oooool01@3oO`3oooooooooooooool0ogl000[ooooo00<0ogl0oooo
ooooool02_ooool20?mo00Sooooo0P3oO`02ooooo`030?mo0?ooool0ogl000Oooooo00@0ogl0oooo
o`3oO`00ogl00_ooool00`3oO`3oooooooooo`020?mo03Sooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`0Iooooo`030:0Pl?oooooooooo00?ooooo0P2P8?000oooool0X23`ooooo`06
ooooo`030:0Pl?oooooooooo013ooooo00<0X23`ooooooooool04Oooool00`2P8?3oooooooooo`1N
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02Cooooo0P3oO`02oooo
o`030?mo0?oooooooooo01kooooo00<0ogl0ooooooooool02Oooool00`3oO`3oooooooooo`05oooo
o`030?mo0?ooool0ogl001;ooooo00<0ogl0ooooooooool0?Oooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo01oooooo00@0X23`ooooooooool0X23`1?ooool0102P8?3oooooooooo`2P
8?0Aooooo`030:0Pl?oooooooooo00Gooooo00<0X23`ooooooooool01?ooool00`2P8?3ooooooooo
o`1Tooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02Cooooo0P3oO`03
ooooo`030?mo0?oooooooooo00Cooooo00<0ogl0ooooooooool02oooool01@3oO`3ooooooooooooo
ool0ogl000Sooooo00@0ogl0ooooooooool0ogl01_ooool20?mo00Oooooo00@0ogl0ooooooooool0
ogl04oooool30?mo03[ooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Rooooo`03
0:0Pl?ooool0X23`00;ooooo0`2P8?06ooooo`030:0Pl?ooool0X23`00Wooooo0P2P8?000oooool0
X23`ooooo`0:ooooo`030:0Pl?oooooooooo00cooooo00<0X23`ooooooooool00_ooool00`2P8?3o
ooooooooo`08ooooo`030:0Pl?oooooooooo04Gooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool08_ooool00`3oO`3oooooooooo`030?mo0003ooooo`3oO`00ogl001Cooooo
00<0ogl0ooooooooool0:?ooool0103oO`3oooooooooo`3oO`09ooooo`030?mo0?oooooooooo03So
oooo00<00000ooooooooool03oooool00`00003oooooooooo`0Zooooo`040:0Pl?oooooooooo0:0P
l3?ooooo00<0X23`ooooooooool0C_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`0Uooooo`040?mo0?oooooooooo0?mo01Sooooo00<0ogl0ooooooooool01Oooool00`3o
O`3oooooooooo`0Jooooo`030?mo0?ooool0ogl000cooooo00<0ogl0ooooooooool00_ooool20?mo
03Kooooo00<00000ooooooooool03oooool00`00003oooooooooo`0Rooooo`030:0Pl?ooool0X23`
00Cooooo0P2P8?07ooooo`040:0Pl?oooooooooo0:0Pl13ooooo00<0X23`ooooooooool00oooool0
0`2P8?3oooooooooo`0:ooooo`80X23`3oooool00`2P8?3oooooooooo`15ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo02Oooooo00<0ogl0ooooo`3oO`000_ooool00`3o
O`3oooooooooo`0Looooo`030?mo0?ooool0ogl000_ooooo00L0ogl0oooooooooooooooo0?mo0?oo
ool0ogl000_ooooo00<0ogl0ooooooooool00P3oO`07ooooo`030?mo0?oooooooooo00cooooo00<0
ogl0ooooooooool0:Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo02;ooooo00@0
X23`ooooo`2P8?3ooooo102P8?02ooooo`030:0Pl?oooooooooo02Cooooo00<0X23`ooooooooool0
1Oooool00`2P8?3oooooooooo`0Dooooo`030:0Pl?oooooooooo03gooooo00<00000ooooooooool0
2?ooool000Wooooo00<00000ooooooooool0:Oooool00`3oO`3oooooooooo`08ooooo`80ogl01?oo
ool00`3oO`3oooooooooo`0Cooooo`030?mo0?ooool0ogl000[ooooo00<0ogl0ooooo`3oO`000ooo
ool00`3oO`3oooooooooo`03ooooo`80ogl00_ooool00`3oO`3ooooo0?mo0008ooooo`030?mo0?oo
oooooooo00Kooooo00<0ogl0ooooooooool0;_ooool00`00003oooooooooo`0?ooooo`0300000?oo
oooooooo02?ooooo0`2P8?000oooool0X23`ooooo`020:0Pl003ooooo`2P8?00X23`00Kooooo00<0
X23`ooooooooool02?ooool00`2P8?3oooooooooo`0hooooo`030:0Pl?oooooooooo03Gooooo00<0
0000ooooooooool02?ooool000Wooooo00<00000ooooooooool0;?ooool20?mo00[ooooo00<0ogl0
ooooooooool01?ooool00`3oO`3oooooooooo`07ooooo`030?mo0?oooooooooo00_ooooo00<0ogl0
ooooooooool02?ooool00`3oO`3oooooooooo`07ooooo`030?mo0?oooooooooo00Sooooo0P3oO`07
ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool0:_ooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo02Cooooo0P2P8?001Oooool0X23`ooooo`2P8?3ooooo0080X23`00?o
oooo0:0Pl?ooool02?ooool00`2P8?3oooooooooo`03ooooo`030:0Pl?oooooooooo0080X23`3Ooo
ool00`2P8?3oooooooooo`1Oooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo02Wooooo00<0ogl0ooooooooool00oooool00`3oO`3oooooooooo`0:ooooo`030?mo0?oooooo
oooo01Sooooo00<0ogl0ooooooooool00oooool00`3oO`3oooooooooo`03ooooo`040?mo0?oooooo
ooooooooo`80ogl01?ooool20?mo00Kooooo00<0ogl0ooooooooool02Oooool00`3oO`3ooooooooo
o`04ooooo`030?mo0?oooooooooo02Oooooo00<00000ooooooooool03oooool00`00003ooooooooo
o`0Tooooo`80X23`00?ooooo0:0Pl02P8?001Oooool30:0Pl0?ooooo00<0X23`ooooooooool01Ooo
ool00`2P8?3oooooooooo`05ooooo`030:0Pl?ooool0X23`02Kooooo00<0X23`ooooooooool0@_oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`0]ooooo`030?mo0?oooooo
oooo00;ooooo00<0ogl0ooooooooool01Oooool0103oO`3oooooooooo`3oO`09ooooo`030?mo0?oo
ool0ogl001Gooooo00<0ogl0ooooooooool02?ooool00`3oO`3oooooooooo`03ooooo`040?mo0?oo
oooooooo0?mo00Sooooo00<0ogl0ooooooooool0<oooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo02Sooooo1`2P8?001Oooool0X23`ooooooooool0X23`00Wooooo00<0X23`oooooooo
ool02Oooool00`2P8?3oooooooooo`04ooooo`050:0Pl?ooooooooooooooo`2P8?002_ooool0102P
8?3ooooo0:0Pl02P8?08ooooo`030:0Pl?ooool0X23`04Cooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0;?ooool00`3oO`3oooooooooo`0>ooooo`030?mo0?oooooooooo
01;ooooo00<0ogl0ooooooooool03oooool00`3oO`3oooooooooo`08ooooo`80ogl00oooool20?mo
0003ooooo`3oO`3ooooo00Sooooo00<0ogl0ooooo`3oO`001Oooool20?mo02Oooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`0/ooooo`@0X23`0_ooool00`2P8?3oooooooooo`07oooo
o`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooool02Oooool00`2P8?3oooooooooo`02oooo
o`030:0Pl?oooooooooo00Gooooo00<0X23`ooooooooool03?ooool00`2P8?3ooooo0:0Pl00Yoooo
o`030:0Pl?oooooooooo01Sooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0:_ooool0103oO`3oooooooooooooool20?mo00;ooooo00<0ogl0ooooooooool02Oooool00`3o
O`3oooooooooo`0Eooooo`030?mo0?oooooooooo017ooooo00<0ogl0ooooooooool00oooool01@3o
O`3oooooooooooooool0ogl000;ooooo00<0ogl0ooooooooool01Oooool0103oO`3ooooooooooooo
ool20?mo00Cooooo0P3oO`0Wooooo`0300000?oooooooooo00oooooo00<00000ooooooooool09?oo
ool00`2P8?3oooooooooo`05ooooo`030:0Pl?oooooooooo0080X23`7Oooool00`2P8?3ooooooooo
o`0=ooooo`030:0Pl?oooooooooo027ooooo00<0X23`ooooooooool03oooool00`2P8?3ooooooooo
o`0Kooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo02kooooo00<0ogl0
ooooo`3oO`002?ooool0103oO`3oooooooooo`3oO`06ooooo`80ogl02Oooool20?mo00?ooooo00L0
ogl0oooooooooooooooo0?mo0?ooool0ogl000;ooooo00<0ogl0ooooooooool00oooool0103oO`3o
ooooooooo`3oO`03ooooo`030?mo0?ooool0ogl000Cooooo00<0ogl0ooooo`3oO`000_ooool20?mo
0003ooooo`3oO`3ooooo00Cooooo00<0ogl0ooooo`3oO`000_ooool20?mo00;ooooo00<0ogl0oooo
ooooool00P3oO`0Vooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0;?ooool00`2P
8?3ooooo0:0Pl002ooooo`050:0Pl?ooooooooooooooo`2P8?003oooool00`2P8?3oooooooooo`08
ooooo`030:0Pl?ooool0X23`01gooooo00<0X23`ooooooooool01oooool00`2P8?3oooooooooo`0J
ooooo`030:0Pl?oooooooooo01Sooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooo
ooooool0<Oooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00Wooooo00<0ogl0oooo
ooooool05oooool00`3oO`3oooooooooo`0<ooooo`030?mo0?oooooooooo00_ooooo00<0ogl0oooo
ooooool01_ooool20?mo013ooooo00<0ogl0ooooo`3oO`006oooool00`00003oooooooooo`0?oooo
o`0300000?oooooooooo02Wooooo00<0X23`ooooo`2P8?008_ooool01@2P8?3oooooooooooooool0
X23`00cooooo00<0X23`ooooooooool06Oooool00`2P8?3oooooooooo`0Kooooo`030:0Pl?oooooo
oooo01Kooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0;Oooool01`3o
O`3ooooo0?mo0?ooool0ogl0ooooo`3oO`001oooool01@3oO`3oooooooooooooool0ogl000Kooooo
00<0ogl0ooooooooool00_ooool00`3oO`3oooooooooo`04ooooo`030?mo0?ooool0ogl000;ooooo
00<0ogl0ooooooooool02oooool01`3oO`3oooooooooooooool0ogl0ooooo`3oO`001_ooool01@3o
O`3oooooooooooooool0ogl000?ooooo103oO`02ooooo`030?mo0?oooooooooo00Cooooo103oO`00
1_ooool0ogl0ooooooooool0ogl0ooooo`@0ogl00_ooool00`3oO`3oooooooooo`0Hooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0;?ooool00`2P8?3ooooo0:0Pl0020:0Pl0Cooooo
00<0X23`ooooooooool02Oooool00`2P8?3oooooooooo`09ooooo`030:0Pl?oooooooooo00Oooooo
00<0X23`ooooooooool00_ooool00`2P8?3oooooooooo`0Rooooo`030:0Pl?ooool0X23`00;ooooo
00<0X23`ooooo`2P8?001Oooool00`2P8?3oooooooooo`05ooooo`030:0Pl?oooooooooo01Wooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0<?ooool00`3oO`3ooooooooo
o`0Fooooo`030?mo0?oooooooooo00Gooooo00<0ogl0ooooooooool04Oooool20?mo01Gooooo00<0
ogl0ooooo`3oO`002?ooool00`3oO`3oooooooooo`07ooooo`80ogl00oooool0103oO`3ooooooooo
o`3oO`0Hooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0<Oooool00`2P8?3ooooo
ooooo`0[ooooo`030:0Pl?oooooooooo01cooooo00<0X23`ooooooooool03_ooool0102P8?3ooooo
ooooo`2P8?06ooooo`80X23`5oooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0cooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool04_ooool01@3oO`3ooooo
ooooooooool0ogl000_ooooo00<0ogl0ooooo`3oO`001?ooool00`3oO`3ooooo0?mo0004ooooo`03
0?mo0?oooooooooo00;ooooo00D0ogl0ooooo`3oO`3ooooo0?mo000=ooooo`050?mo0?oooooooooo
ooooo`3oO`001?ooool0103oO`3oooooooooooooool20?mo00?ooooo00H0ogl0ooooo`3oO`00ogl0
ooooo`3oO`0Hooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0=Oooool00`2P8?3o
ooooooooo`0hooooo`030:0Pl?oooooooooo02Wooooo00<0X23`ooooooooool04oooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`0jooooo`030?mo0?oooooooooo00Kooooo
00<0ogl0ooooooooool05?ooool00`3oO`3oooooooooo`02ooooo`050?mo0?ooool0ogl0ooooo`3o
O`003?ooool0103oO`3oooooooooooooool20?mo00?ooooo00D0ogl0ooooooooool0ogl0ooooo`02
0?mo00?ooooo00@0ogl0ooooooooool0ogl00_ooool00`3oO`3oooooooooo`020?mo0003ooooo`3o
O`00ogl000@0ogl00_ooool00`3oO`3oooooooooo`0Hooooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0:?ooool0102P8?3oooooooooooooool30:0Pl0;ooooo00H0X23`ooooo`2P8?00
X23`ooooo`2P8?07ooooo`030:0Pl?oooooooooo00oooooo00H0X23`ooooooooool0X23`ooooo`2P
8?0;ooooo`030:0Pl?oooooooooo00Gooooo0`2P8?000oooool0X23`ooooo`07ooooo`80X23`0_oo
ool00`2P8?3oooooooooo`0Dooooo`80X23`0_ooool20:0Pl0;ooooo00<0X23`ooooo`2P8?000`2P
8?0Cooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo047ooooo00<0ogl0
ooooooooool05Oooool00`3oO`3oooooooooo`05ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0
ooooo`3oO`001?ooool00`3oO`3oooooooooo`0;ooooo`030?mo0?oooooooooo00Gooooo00<0ogl0
ooooooooool01oooool00`3oO`3oooooooooo`04ooooo`030?mo0?ooool0ogl001_ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`0jooooo`030:0Pl?oooooooooo00Oooooo00<0X23`
ooooooooool07?ooool0102P8?3ooooo0:0Pl02P8?0Kooooo`030:0Pl?oooooooooo00cooooo00@0
X23`ooooooooool0X23`1Oooool00`2P8?3oooooooooo`0Eooooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo047ooooo00@0ogl0ooooooooool0ogl00oooool00`3oO`3ooooo
ooooo`0Hooooo`80ogl000?ooooo0?mo0?ooool01Oooool0103oO`3oooooooooooooool50?mo00Ko
oooo00<0ogl0ooooo`3oO`001?ooool0103oO`3oooooooooo`3oO`04ooooo`@0ogl00_ooool20?mo
0003ooooo`3oO`3ooooo01cooooo00<00000ooooooooool03oooool00`00003oooooooooo`0aoooo
o`040:0Pl?oooooooooo0:0Pl0;ooooo00<0X23`ooooooooool01Oooool00`2P8?3oooooooooo`0>
ooooo`030:0Pl?oooooooooo02Oooooo00<0X23`ooooooooool01Oooool01@2P8?3ooooooooooooo
ool0X23`017ooooo102P8?0Fooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo03[ooooo00<0ogl0ooooooooool01oooool00`3oO`3oooooooooo`0?ooooo`030?mo0?oooooo
oooo00oooooo00<0ogl0ooooooooool00_ooool00`3oO`3oooooooooo`0:ooooo`030?mo0?oooooo
oooo00Wooooo00<0ogl0ooooooooool01Oooool30?mo00?ooooo00<0ogl0ooooooooool06oooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo03Cooooo00<0X23`ooooooooool00oooool0
0`2P8?3ooooo0:0Pl00Aooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool02?ooool0
0`2P8?3oooooooooo`05ooooo`030:0Pl?oooooooooo00gooooo00<0X23`ooooooooool01Oooool0
0`2P8?3oooooooooo`09ooooo`030:0Pl?oooooooooo00Cooooo00@0X23`ooooo`2P8?00X23`2_oo
ool00`2P8?3oooooooooo`0@ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo03cooooo00<0ogl0ooooooooool01_ooool00`3oO`3oooooooooo`0Looooo`030?mo0?oooooo
oooo01oooooo00<0ogl0ooooo`3oO`002?ooool20?mo0005ooooo`3oO`3oooooooooo`3oO`006_oo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo03Sooooo00<0X23`ooooooooool05_oo
ool00`2P8?3oooooooooo`08ooooo`030:0Pl?oooooooooo02Gooooo00<0X23`ooooooooool02?oo
ool00`2P8?3oooooooooo`07ooooo`030:0Pl?oooooooooo0080X23`5?ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`18ooooo`050?mo0?ooooooooooooooo`3oO`003_oo
ool00`3oO`3oooooooooo`040?mo00cooooo00<0ogl0ooooooooool01?ooool00`3oO`3ooooo0?mo
0002ooooo`<0ogl000Gooooo0?mo0?oooooooooo0?mo0004ooooo`030?mo0?ooool0ogl000;ooooo
00D0ogl0ooooo`3oO`3ooooo0?mo0004ooooo`030?mo0?oooooooooo01_ooooo00<00000oooooooo
ool03oooool00`00003oooooooooo`0`ooooo`030:0Pl?oooooooooo00?ooooo00D0X23`oooooooo
oooooooo0:0Pl00<ooooo`030:0Pl?oooooooooo01Cooooo0P2P8?0Fooooo`030:0Pl?oooooooooo
00_ooooo00<0X23`ooooooooool00oooool20:0Pl003ooooo`2P8?00X23`00Sooooo00<0X23`oooo
ooooool01Oooool20:0Pl17ooooo00<00000ooooooooool02?ooool000Wooooo00<00000oooooooo
ool0C?ooool01@3oO`3oooooooooooooool0ogl001[ooooo00<0ogl0ooooooooool01_ooool0103o
O`3oooooooooo`3oO`02ooooo`030?mo0?oooooooooo00Wooooo00<0ogl0ooooooooool00_ooool0
0`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo01gooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`0looooo`030:0Pl?oooooooooo01_ooooo00<0X23`ooooooooool00_ooool0
0`2P8?3oooooooooo`0Aooooo`80X23`1_ooool00`2P8?3oooooooooo`06ooooo`80X23`00?ooooo
0:0Pl?ooool04Oooool00`2P8?3ooooo0:0Pl00Eooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo03_ooooo0P3oO`02ooooo`030?mo0?oooooooooo00cooooo00<0ogl0oooo
ooooool01_ooool0103oO`3oooooooooo`3oO`09ooooo`030?mo0?ooool0ogl000Cooooo00H0ogl0
ooooooooool0ogl0ooooo`3oO`07ooooo`030?mo0?oooooooooo00Oooooo0P3oO`09ooooo`040?mo
0?ooool0ogl00?mo00;ooooo00<0ogl0ooooooooool07?ooool00`00003oooooooooo`0?ooooo`03
00000?oooooooooo02kooooo00<0X23`ooooooooool01?ooool00`2P8?3oooooooooo`02ooooo`80
X23`00Cooooo0:0Pl?oooooooooo0P2P8?0Fooooo`030:0Pl?oooooooooo00Gooooo00<0X23`oooo
ooooool00oooool00`2P8?3oooooooooo`0<ooooo`030:0Pl?oooooooooo00?ooooo00<0X23`oooo
ooooool05?ooool0102P8?3oooooooooooooool20:0Pl003ooooo`2P8?00X23`0080X23`5Oooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`10ooooo`030?mo0?oooooooooo
01;ooooo00<0ogl0ooooo`3oO`006_ooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo
03Kooooo00<00000ooooooooool03oooool00`00003oooooooooo`0`ooooo`030:0Pl?oooooooooo
00Wooooo0P2P8?08ooooo`030:0Pl?oooooooooo00cooooo00<0X23`ooooo`2P8?001?ooool00`2P
8?3oooooooooo`05ooooo`030:0Pl?oooooooooo00[ooooo00<0X23`ooooooooool06?ooool00`2P
8?3oooooooooo`0=ooooo`050:0Pl?ooooooooooooooo`2P8?000_ooool00`2P8?3oooooooooo`0<
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo04oooooo00D0ogl0oooo
o`3oO`3ooooo0?mo0002ooooo`030?mo0?oooooooooo00Kooooo00D0ogl0ooooo`3oO`3ooooo0?mo
0002ooooo`030?mo0?oooooooooo00Wooooo00@0ogl0ooooooooool0ogl03?ooool20?mo00Cooooo
0`3oO`0Wooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0=_ooool00`2P8?3ooooo
ooooo`040:0Pl0;ooooo0P2P8?0Nooooo`030:0Pl?ooool0X23`00Cooooo00<0X23`ooooooooool0
2Oooool00`2P8?3oooooooooo`04ooooo`040:0Pl?oooooooooo0:0Pl0Cooooo00D0X23`oooooooo
oooooooo0:0Pl002ooooo`030:0Pl?oooooooooo00_ooooo00D0X23`oooooooooooooooo0:0Pl003
ooooo`<0X23`0_ooool00`2P8?3oooooooooo`0<ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo03kooooo0P3oO`04ooooo`030?mo0?oooooooooo00Cooooo00<0ogl0oooo
ooooool03?ooool00`3oO`3oooooooooo`02ooooo`030?mo0?ooool0ogl000?ooooo00<0ogl0oooo
ooooool01Oooool00`3oO`3oooooooooo`0:ooooo`80ogl01_ooool0103oO`3ooooo0?mo003oO`0/
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0@Oooool0102P8?3oooooooooo`2P
8?0Nooooo`030:0Pl?oooooooooo01Sooooo00<0X23`ooooooooool04Oooool00`2P8?3ooooooooo
o`02ooooo`030:0Pl?ooool0X23`00Wooooo00@0X23`ooooooooool0X23`2oooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`1?ooooo`030?mo0?oooooooooo00Kooooo00<0
ogl0ooooooooool00oooool00`3oO`3oooooooooo`0Kooooo`030?mo0?oooooooooo00[ooooo00<0
ogl0ooooooooool09_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo03gooooo00<0
X23`ooooooooool02_ooool00`2P8?3oooooooooo`0=ooooo`030:0Pl?oooooooooo00Sooooo00<0
X23`ooooo`2P8?001oooool20:0Pl0Cooooo00<0X23`ooooooooool05Oooool00`2P8?3ooooooooo
o`0@ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool02_ooool00`00003ooooooooo
o`08ooooo`002Oooool00`00003oooooooooo`10ooooo`030?mo0?oooooooooo00?ooooo00@0ogl0
ooooooooool0ogl01Oooool00`3oO`3oooooooooo`0@ooooo`80ogl000?ooooo0?mo0?ooool02Ooo
ool01@3oO`3oooooooooooooool0ogl0013ooooo00<0ogl0ooooooooool03?ooool00`3oO`3ooooo
ooooo`0Kooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0?Oooool01@2P8?3ooooo
0:0Pl?ooool0X23`00Oooooo00<0X23`ooooo`2P8?007oooool00`2P8?3ooooo0:0Pl00Nooooo`04
0:0Pl?oooooooooo0:0Pl0Gooooo00@0X23`ooooooooool0X23`0oooool01@2P8?3ooooooooooooo
ool0X23`00?ooooo0`2P8?0;ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo04Gooooo00D0ogl0oooooooooooooooo0?mo0002ooooo`030?mo0?oooooooooo00kooooo00<0
ogl0ooooooooool01Oooool00`3oO`3oooooooooo`0Aooooo`030?mo0?oooooooooo00Gooooo00<0
ogl0ooooooooool03oooool00`3oO`3oooooooooo`0Looooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0?oooool0102P8?3oooooooooo`2P8?0Vooooo`030:0Pl?oooooooooo00Kooooo
00<0X23`ooooooooool07?ooool00`2P8?3oooooooooo`0:ooooo`030:0Pl?ooool0X23`00;ooooo
00@0X23`ooooo`2P8?00X23`2oooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`0mooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool03_ooool00`3oO`3ooooo
ooooo`0:ooooo`80ogl000?ooooo0?mo0?ooool00_ooool00`3oO`3oooooooooo`05ooooo`80ogl0
3?ooool20?mo0003ooooo`3oO`3ooooo00?ooooo0P3oO`000oooool0ogl00?mo000Xooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0@Oooool0102P8?3oooooooooo`2P8?07ooooo`03
0:0Pl?oooooooooo00gooooo00<0X23`ooooooooool00P2P8?02ooooo`030:0Pl?oooooooooo01So
oooo00<0X23`ooooooooool00oooool00`2P8?3oooooooooo`0;ooooo`030:0Pl?ooool0X23`00[o
oooo0P2P8?001?ooool0X23`0:0Pl?ooool20:0Pl003ooooo`2P8?00X23`00Sooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0A_ooool20?mo03Gooooo00<0ogl0oooooooo
ool04?ooool00`3oO`3oooooooooo`0Oooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0?oooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo017ooooo00<0X23`oooooooo
ool04_ooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo01oooooo00<0X23`oooooooo
ool01Oooool01P2P8?3ooooo0:0Pl?ooool0X23`ooooo`80X23`00Gooooo0:0Pl?oooooooooo0:0P
l009ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo03Wooooo00<0ogl0
ooooooooool02?ooool00`3oO`3oooooooooo`020?mo00;ooooo00<0ogl0ooooooooool06?ooool0
0`3oO`3oooooooooo`0Eooooo`040?mo0?oooooooooo0?mo01Kooooo00<0ogl0ooooooooool05ooo
ool00`00003oooooooooo`0?ooooo`0300000?oooooooooo03oooooo00<0X23`ooooooooool01?oo
ool00`2P8?3oooooooooo`0Eooooo`030:0Pl?oooooooooo01Sooooo00<0X23`ooooooooool01?oo
ool20:0Pl0;ooooo00<0X23`ooooo`2P8?004?ooool00`2P8?3oooooooooo`030:0Pl0;ooooo00L0
X23`oooooooooooooooo0:0Pl?ooool0X23`00cooooo00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0?oooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo00Cooooo
00<0ogl0ooooooooool01Oooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00;ooooo
0P3oO`02ooooo`030?mo0?oooooooooo00<0ogl01oooool00`3oO`3oooooooooo`04ooooo`060?mo
0?oooooooooo0?mo0?ooool0ogl01Oooool00`3oO`3oooooooooo`0:ooooo`030?mo0?oooooooooo
023ooooo00<00000ooooooooool03oooool00`00003oooooooooo`15ooooo`040:0Pl?oooooooooo
0:0Pl1oooooo00<0X23`ooooooooool01Oooool30:0Pl0Wooooo00<0X23`ooooooooool03_ooool0
0`2P8?3ooooo0:0Pl002ooooo`80X23`00?ooooo0:0Pl?ooool01Oooool00`2P8?3oooooooooo`02
0:0Pl003ooooo`2P8?00X23`00@0X23`00?ooooo0:0Pl?ooool01oooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`1@ooooo`030?mo0?oooooooooo00Sooooo00<0ogl0oooo
ooooool03oooool00`3oO`3oooooooooo`07ooooo`030?mo0?oooooooooo03Sooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`16ooooo`030:0Pl?oooooooooo017ooooo00<0X23`oooo
o`2P8?004oooool00`2P8?3oooooooooo`0?ooooo`030:0Pl?ooool0X23`00?ooooo00<0X23`oooo
ooooool02_ooool0102P8?3oooooooooo`2P8?0:ooooo`030:0Pl?ooool0X23`00<0X23`2Oooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`12ooooo`80ogl01?ooool0103o
O`3oooooooooo`3oO`0;ooooo`80ogl01oooool20?mo0003ooooo`3oO`3ooooo01;ooooo00@0ogl0
oooooooooooooooo0P3oO`0@ooooo`030?mo0?oooooooooo00Cooooo00@0ogl0ooooooooool0ogl0
6_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo04;ooooo00<0X23`ooooo`2P8?00
1_ooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00Sooooo00<0X23`ooooo`2P8?00
3?ooool20:0Pl0Cooooo00<0X23`ooooo`2P8?001?ooool00`2P8?3oooooooooo`02ooooo`040:0P
l?ooooooooooooooo`80X23`3?ooool20:0Pl0Cooooo00@0X23`oooooooooooooooo102P8?04oooo
o`030:0Pl?oooooooooo00<0X23`00Cooooo0:0Pl02P8?00X23`2?ooool00`00003oooooooooo`08
ooooo`002Oooool00`00003oooooooooo`1Kooooo`030?mo0?oooooooooo00Sooooo00<0ogl0oooo
ooooool07oooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo023ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`1<ooooo`030:0Pl?ooool0X23`02kooooo00<0X23`oooo
ooooool02_ooool20:0Pl0Oooooo00<0X23`ooooooooool01Oooool0102P8?3oooooooooo`2P8?02
ooooo`<0X23`00?ooooo0:0Pl02P8?002oooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`19ooooo`030?mo0?oooooooooo00_ooooo00<0ogl0ooooooooool01_ooool00`3o
O`3oooooooooo`02ooooo`030?mo0?oooooooooo00Wooooo00<0ogl0ooooooooool0?_ooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo04Cooooo00<0X23`ooooooooool01?ooool0102P
8?3oooooooooo`2P8?0hooooo`030:0Pl?oooooooooo01Kooooo00@0X23`ooooooooool0X23`0_oo
ool00`2P8?3ooooo0:0Pl0020:0Pl0Oooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0Boooool00`3oO`3oooooooooo`030?mo00Cooooo0P3oO`000oooool0ogl0ooooo`02
ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool00_ooool0103oO`3ooooo0?mo0?oo
ool20?mo00oooooo00D0ogl0oooooooooooooooo0?mo0007ooooo`040?mo0?oooooooooo0?mo00co
oooo00<0ogl0ooooooooool06?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo04Wo
oooo00<0X23`ooooooooool02Oooool00`2P8?3oooooooooo`04ooooo`030:0Pl?oooooooooo00;o
oooo00<0X23`ooooooooool01_ooool00`2P8?3oooooooooo`06ooooo`030:0Pl?oooooooooo01;o
oooo00D0X23`oooooooooooooooo0:0Pl002ooooo`030:0Pl?oooooooooo00;ooooo0P2P8?001Ooo
ool0X23`0:0Pl02P8?3ooooo00@0X23`00Kooooo0:0Pl?oooooooooo0:0Pl?ooool60:0Pl0Oooooo
00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0C?ooool00`3oO`3ooooooooo
o`05ooooo`030?mo0?oooooooooo00Gooooo00<0ogl0ooooooooool00oooool20?mo00Kooooo00<0
ogl0ooooooooool02Oooool0103oO`3oooooooooo`3oO`02ooooo`030?mo0?oooooooooo03?ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`1Vooooo`030:0Pl?oooooooooo01Cooooo
00<0X23`ooooooooool01Oooool20:0Pl0Sooooo0P2P8?0:ooooo`050:0Pl?oooooooooo0:0Pl?oo
ool00P2P8?03ooooo`030:0Pl?oooooooooo0080X23`2?ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`16ooooo`080?mo0?oooooooooo0?mo0?ooool0ogl0ooooo`3oO`04
ooooo`030?mo0?oooooooooo00Gooooo00<0ogl0ooooo`3oO`001?ooool00`3oO`3oooooooooo`0:
ooooo`030?mo0?oooooooooo027ooooo00<0ogl0ooooooooool07Oooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo04Cooooo00L0X23`oooooooooooooooo0:0Pl?ooool0X23`00?ooooo
00<0X23`ooooooooool03Oooool00`2P8?3oooooooooo`0>ooooo`030:0Pl?oooooooooo00?ooooo
00<0X23`ooooooooool02Oooool30:0Pl003ooooo`2P8?00X23`00?ooooo00<0X23`ooooooooool0
1?ooool00`2P8?3oooooooooo`04ooooo`070:0Pl?ooooooooooooooo`2P8?3ooooo0:0Pl003oooo
o`T0X23`1oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1@ooooo`03
0?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool02Oooool00`3oO`3oooooooooo`08ooooo`03
0?mo0?oooooooooo00[ooooo00<0ogl0ooooooooool01Oooool0103oO`3oooooooooo`3oO`0=oooo
o`030?mo0?oooooooooo01gooooo00<00000ooooooooool03oooool00`00003oooooooooo`1;oooo
o`030:0Pl?oooooooooo03[ooooo00<0X23`ooooooooool01oooool30:0Pl0Oooooo00<0X23`oooo
ooooool00_ooool00`2P8?3oooooooooo`03ooooo`80X23`00Cooooo0:0Pl?ooool0X23`1Oooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1=ooooo`030?mo0?oooooooooo
00Gooooo00<0ogl0ooooooooool00_ooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo
00Cooooo00<0ogl0ooooo`3oO`00Aoooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo
04Wooooo00<0X23`ooooooooool00oooool0102P8?3oooooooooo`2P8?0Iooooo`030:0Pl?oooooo
oooo00?ooooo00<0X23`ooooooooool00_ooool00`2P8?3oooooooooo`0<ooooo`030:0Pl?ooool0
X23`00;ooooo00<0X23`ooooooooool01Oooool00`2P8?3oooooooooo`06ooooo`030:0Pl?oooooo
oooo00Cooooo00<0X23`ooooooooool01@2P8?07ooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo04Gooooo00<0ogl0ooooooooool01oooool20?mo0005ooooo`3oO`3ooooo
ooooo`3oO`000oooool00`3oO`3oooooooooo`05ooooo`040?mo0?oooooooooo0?mo00Sooooo00<0
ogl0ooooo`3oO`006Oooool00`3oO`3oooooooooo`0Vooooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0B_ooool01@2P8?3oooooooooooooool0X23`00?ooooo00<0X23`ooooooooool0
3?ooool00`2P8?3oooooooooo`08ooooo`030:0Pl?oooooooooo00?ooooo00<0X23`ooooo`2P8?00
3Oooool01`2P8?3oooooooooooooool0X23`ooooo`2P8?001?ooool0102P8?3ooooo0:0Pl02P8?05
ooooo`030:0Pl?oooooooooo0080X23`1Oooool20:0Pl004ooooo`2P8?3oooooooooo`@0X23`00?o
oooo0:0Pl02P8?001Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1G
ooooo`030?mo0?oooooooooo00Gooooo00<0ogl0ooooo`3oO`001oooool00`3oO`3ooooo0?mo0006
ooooo`050?mo0?ooooooooooooooo`3oO`004oooool00`3oO`3oooooooooo`0Aooooo`030?mo0?oo
oooooooo017ooooo00<00000ooooooooool03oooool00`00003oooooooooo`1:ooooo`80X23`1?oo
ool0102P8?3oooooooooo`2P8?0Dooooo`030:0Pl?oooooooooo00[ooooo00D0X23`oooooooooooo
oooo0:0Pl005ooooo`030:0Pl?oooooooooo00Gooooo0P2P8?05ooooo`030:0Pl?oooooooooo00So
oooo00<0X23`ooooo`2P8?001oooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00Oo
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0BOooool00`3oO`3ooooo
ooooo`03ooooo`80ogl000Cooooo0?mo0?ooool0ogl01oooool00`3oO`3ooooo0?mo0003ooooo`03
0?mo0?oooooooooo00Sooooo00@0ogl0ooooooooool0ogl01Oooool20?mo0003ooooo`3oO`3ooooo
00oooooo00<0ogl0ooooooooool01Oooool00`3oO`3ooooo0?mo000;ooooo`030?mo0?oooooooooo
00oooooo00<00000ooooooooool03oooool00`00003oooooooooo`14ooooo`030:0Pl?oooooooooo
00Oooooo0P2P8?03ooooo`030:0Pl?oooooooooo00_ooooo00<0X23`ooooooooool00oooool00`2P
8?3oooooooooo`03ooooo`030:0Pl?oooooooooo02?ooooo00L0X23`ooooo`2P8?3ooooo0:0Pl?oo
ool0X23`00Kooooo0P2P8?001?ooool0X23`ooooo`2P8?02ooooo`030:0Pl?ooool0X23`0080X23`
1Oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Booooo`030?mo0?oo
oooooooo00?ooooo00D0ogl0oooooooooooooooo0?mo000Aooooo`80ogl00_ooool20?mo00;ooooo
00<0ogl0ooooo`3oO`000oooool00`3oO`3oooooooooo`07ooooo`030?mo0?oooooooooo02Wooooo
00<00000ooooooooool03oooool00`00003oooooooooo`1?ooooo`80X23`1oooool00`2P8?3ooooo
ooooo`04ooooo`030:0Pl?ooool0X23`00Cooooo0P2P8?0>ooooo`030:0Pl?oooooooooo013ooooo
00<0X23`ooooooooool00`2P8?03ooooo`<0X23`1Oooool20:0Pl0Cooooo00<0X23`ooooooooool0
1oooool00`2P8?3oooooooooo`05ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo05Oooooo0P3oO`07ooooo`040?mo0?ooooooooooooooo`80ogl000?ooooo0?mo0?ooool0
0_ooool01@3oO`3ooooo0?mo0?ooool0ogl000;ooooo00@0ogl0ooooooooool0ogl04?ooool00`3o
O`3oooooooooo`0:ooooo`030?mo0?oooooooooo01cooooo00<00000ooooooooool03oooool00`00
003oooooooooo`1>ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooool01oooool00`2P
8?3oooooooooo`06ooooo`030:0Pl?oooooooooo00Kooooo00<0X23`ooooooooool02?ooool00`2P
8?3oooooooooo`09ooooo`040:0Pl?oooooooooo0:0Pl0?ooooo0P2P8?02ooooo`030:0Pl?oooooo
oooo00?ooooo00<0X23`ooooooooool01Oooool0202P8?3ooooo0:0Pl02P8?3ooooo0:0Pl?ooool0
X23`0oooool20:0Pl0Cooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
A_ooool00`3oO`3oooooooooo`0;ooooo`030?mo0?oooooooooo00Kooooo00<0ogl0ooooooooool0
0_ooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00gooooo00<0ogl0ooooooooool0
2Oooool00`3oO`3oooooooooo`0Eooooo`030?mo0?oooooooooo01Cooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`1Cooooo`040:0Pl?oooooooooo0:0Pl0Oooooo00<0X23`oooooooo
ool03_ooool00`2P8?3oooooooooo`06ooooo`030:0Pl?oooooooooo00Kooooo00<0X23`oooooooo
ool02Oooool30:0Pl0Oooooo00<0X23`ooooooooool01_ooool00`2P8?3oooooooooo`03ooooo`05
0:0Pl?ooooooooooooooo`2P8?001oooool00`00003oooooooooo`08ooooo`002Oooool00`00003o
ooooooooo`1Looooo`D0ogl00_ooool0103oO`3oooooooooo`3oO`03ooooo`050?mo0?oooooooooo
ooooo`3oO`000oooool00`3oO`3oooooooooo`06ooooo`030?mo0?oooooooooo01gooooo00<0ogl0
ooooooooool05?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo05[ooooo00<0X23`
ooooooooool09_ooool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00Cooooo00@0X23`
oooooooooooooooo0P2P8?09ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooool02_oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Cooooo`030?mo0?oooooo
oooo0080ogl00oooool20?mo0004ooooo`3oO`3ooooo0?mo00;ooooo0P3oO`08ooooo`040?mo0?oo
oooooooo0?mo00Cooooo00D0ogl0ooooo`3oO`3ooooo0?mo0002ooooo`030?mo0?oooooooooo00[o
oooo00<0ogl0ooooooooool09_ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo05Go
oooo0P2P8?04ooooo`030:0Pl?oooooooooo00Sooooo00<0X23`ooooooooool02Oooool00`2P8?3o
ooooooooo`07ooooo`030:0Pl?oooooooooo00Cooooo00<0X23`ooooooooool01Oooool00`2P8?3o
ooooooooo`020:0Pl0;ooooo00<0X23`ooooooooool01Oooool0102P8?3oooooooooo`2P8?03oooo
o`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool02Oooool00`00003oooooooooo`08oooo
o`002Oooool00`00003oooooooooo`1Kooooo`<0ogl000Gooooo0?mo0?oooooooooo0?mo0003oooo
o`030?mo0?oooooooooo00Oooooo00<0ogl0ooooooooool01?ooool00`3oO`3oooooooooo`02oooo
o`030?mo0?ooool0ogl000Cooooo00@0ogl0ooooooooool0ogl0:oooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo05?ooooo00<0X23`ooooooooool03oooool00`2P8?3oooooooooo`0I
ooooo`030:0Pl?oooooooooo00Wooooo00<0X23`ooooo`2P8?001?ooool20:0Pl003ooooo`2P8?3o
oooo00_ooooo00<0X23`ooooooooool02oooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`1Booooo`80ogl00oooool0103oO`3oooooooooooooool30?mo0003ooooo`3oO`3o
oooo00;ooooo00@0ogl0ooooo`3oO`3ooooo0P3oO`07ooooo`030?mo0?ooool0ogl000;ooooo00<0
ogl0ooooooooool05?ooool00`3oO`3oooooooooo`0Jooooo`030?mo0?oooooooooo00Kooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`1Booooo`80X23`00Cooooo0:0Pl?ooool0X23`
0oooool20:0Pl2Cooooo00<0X23`ooooooooool02Oooool0102P8?3oooooooooo`2P8?03ooooo`03
0:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool00_ooool00`2P8?3ooooo0:0Pl004ooooo`03
0:0Pl?oooooooooo00[ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0
EOooool0103oO`3oooooooooooooool80?mo00oooooo0P3oO`07ooooo`030?mo0?ooool0ogl000?o
oooo00D0ogl0oooooooooooooooo0?mo0004ooooo`030?mo0?oooooooooo00Gooooo00<0ogl0oooo
ooooool07oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo05Kooooo0`2P8?001Ooo
ool0X23`ooooooooool0X23`00[ooooo00<0X23`ooooooooool07_ooool00`2P8?3oooooooooo`0S
ooooo`040:0Pl?oooooooooo000000[ooooo0009ooooo`0300000?oooooooooo05oooooo0P3oO`02
ooooo`030?mo0?oooooooooo00?ooooo00<0ogl0ooooooooool00oooool00`3oO`3oooooooooo`0<
ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool08_ooool00`3oO`3oooooooooo`07
ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0F_ooool30:0Pl0Oooooo00<0X23`
ooooooooool08oooool20:0Pl0?ooooo00<0X23`ooooooooool01?ooool0102P8?3ooooo0:0Pl02P
8?04ooooo`030:0Pl?oooooooooo017ooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0EOooool00`3oO`3ooooo0?mo0006ooooo`80ogl000Cooooo0?mo0?ooool0ogl02?oo
ool00`3oO`3ooooo0?mo0002ooooo`040?mo0?oooooooooo0?mo00Oooooo00<0ogl0ooooo`3oO`00
6Oooool20?mo01Sooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Fooooo`050:0P
l?ooooooooooooooo`2P8?003?ooool20:0Pl0Gooooo00<0X23`ooooooooool02oooool20:0Pl0;o
oooo00<0X23`ooooooooool00oooool00`2P8?3oooooooooo`0>ooooo`030:0Pl?ooool0X23`00ko
oooo00<0X23`ooooooooool01Oooool00`2P8?3ooooo0000000:ooooo`002Oooool00`00003ooooo
ooooo`1Kooooo`80ogl00_ooool40?mo00;ooooo00<0ogl0ooooooooool00oooool20?mo00kooooo
00<0ogl0ooooooooool08_ooool00`3oO`3oooooooooo`0?ooooo`0300000?oooooooooo00oooooo
00<00000ooooooooool0FOooool20:0Pl0[ooooo00<0X23`ooooooooool04?ooool00`2P8?3ooooo
ooooo`05ooooo`030:0Pl?oooooooooo00Gooooo00@0X23`ooooooooool0X23`1?ooool00`2P8?3o
ooooooooo`0Oooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo053ooooo
00<0ogl0ooooooooool01oooool50?mo0004ooooo`3oO`3oooooooooo`80ogl000?ooooo0?mo0?oo
ool01?ooool00`3oO`3ooooo0?mo0007ooooo`040?mo0?oooooooooo0?mo01gooooo00<0ogl0oooo
ooooool01oooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo00Oooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`1Hooooo`030:0Pl?ooool0X23`00Cooooo0P2P8?05oooo
o`030:0Pl?oooooooooo023ooooo00<0X23`ooooooooool01_ooool00`2P8?3oooooooooo`06oooo
o`030:0Pl?oooooooooo0080X23`1oooool00`2P8?3oooooooooo`08ooooo`0300000?oooooooooo
00Sooooo0009ooooo`0300000?oooooooooo067ooooo00D0ogl0oooooooooooooooo0?mo0007oooo
o`030?mo0?ooool0ogl000Sooooo00D0ogl0ooooo`3oO`3ooooo0?mo000Iooooo`030?mo0?oooooo
oooo01Wooooo00<00000ooooooooool03oooool00`00003oooooooooo`1Mooooo`030:0Pl?oooooo
oooo00Sooooo00<0X23`ooooooooool05Oooool00`2P8?3oooooooooo`05ooooo`030:0Pl?oooooo
oooo01kooooo00<0X23`ooooooooool01_ooool00`00003oooooooooo`08ooooo`002Oooool00`00
003oooooooooo`1Kooooo`030?mo0?oooooooooo00?ooooo00@0ogl0oooooooooooooooo0P3oO`02
ooooo`030?mo0?oooooooooo04Kooooo00<00000ooooooooool03oooool00`00003oooooooooo`1^
ooooo`030:0Pl?oooooooooo01[ooooo00<0X23`ooooooooool00P2P8?02ooooo`030:0Pl?oooooo
oooo00Cooooo00<0X23`ooooooooool01_ooool00`2P8?3oooooooooo`0=ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo05cooooo00@0ogl0oooooooooooooooo103oO`03
ooooo`80ogl01?ooool20?mo0003ooooo`3oO`00ogl000?ooooo00<0ogl0ooooooooool01Oooool2
0?mo00?ooooo00<0ogl0ooooo`3oO`002?ooool00`3oO`3ooooo0?mo000Rooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0F_ooool20:0Pl0Gooooo00<0X23`ooooo`2P8?001oooool0
0`2P8?3oooooooooo`07ooooo`80X23`0_ooool00`2P8?3oooooooooo`0=ooooo`030:0Pl?oooooo
oooo00cooooo00<0X23`ooooooooool02Oooool00`2P8?3oooooooooo`0;ooooo`0300000?oooooo
oooo00Sooooo0009ooooo`0300000?oooooooooo067ooooo00@0ogl0ooooo`3oO`3ooooo0P3oO`02
ooooo`80ogl01?ooool00`3oO`3oooooooooo`07ooooo`050?mo0?ooooooooooooooo`3oO`000ooo
ool00`3oO`3oooooooooo`0@ooooo`030?mo0?oooooooooo01_ooooo00<00000ooooooooool03ooo
ool00`00003oooooooooo`1Mooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool00_oo
ool00`2P8?3oooooooooo`0;ooooo`030:0Pl?oooooooooo00?ooooo00<0X23`ooooooooool0=?oo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Oooooo`80ogl000?ooooo
0?mo003oO`000_ooool01P3oO`3oooooooooooooool0ogl0ooooo`D0ogl000Gooooo0?mo0?oooooo
oooo0?mo0003ooooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooooooool02?ooool20?mo02Oo
oooo00<00000ooooooooool03oooool00`00003oooooooooo`1Oooooo`040:0Pl?oooooooooo0:0P
l0;ooooo00@0X23`ooooooooool0X23`2Oooool00`2P8?3oooooooooo`02ooooo`030:0Pl?ooool0
X23`01Sooooo00<0X23`ooooooooool03_ooool00`2P8?3oooooooooo`07ooooo`060:0Pl?oooooo
oooo0:0Pl?ooool000002_ooool000Wooooo00<00000ooooooooool0EOooool00`3oO`3ooooooooo
o`0;ooooo`80ogl000Gooooo0?mo003oO`3ooooo0?mo0002ooooo`80ogl00_ooool20?mo00;ooooo
00P0ogl0ooooooooool0ogl0ooooo`3oO`3ooooo0?mo00cooooo00<0ogl0ooooooooool09oooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo05oooooo00@0X23`ooooooooool0X23`6ooo
ool00`2P8?3oooooooooo`0aooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooo
oooo063ooooo0P3oO`001?ooool0ogl0ooooo`3oO`02ooooo`@0ogl02?ooool20?mo01Cooooo00<0
ogl0ooooooooool02_ooool00`3oO`3oooooooooo`0Hooooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0H?ooool30:0Pl0Gooooo0P2P8?0Dooooo`030:0Pl?oooooooooo00?ooooo00<0
X23`ooooooooool0:oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1T
ooooo`030?mo0?oooooooooo00;ooooo00@0ogl0ooooooooool0ogl08Oooool00`3oO`3ooooooooo
o`02ooooo`80ogl04_ooool00`3oO`3oooooooooo`08ooooo`0300000?oooooooooo00oooooo00<0
0000ooooooooool0HOooool0102P8?3oooooooooo`2P8?05ooooo`030:0Pl?oooooooooo02?ooooo
00D0X23`ooooo`2P8?3ooooo0:0Pl00Cooooo`030:0Pl?oooooooooo00Oooooo00<00000oooooooo
ool02?ooool000Wooooo00<00000ooooooooool0I_ooool30?mo0004ooooo`3oO`3oooooooooo`<0
ogl000?ooooo0?mo0?ooool04oooool00`3oO`3oooooooooo`0@ooooo`030?mo0?oooooooooo01Ko
oooo00<00000ooooooooool03oooool00`00003oooooooooo`1gooooo`030:0Pl?oooooooooo03So
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0I_ooool01`3oO`3ooooo
0?mo003oO`3ooooo0?mo0?ooool00P3oO`000oooool0ogl0ooooo`02ooooo`030?mo0?ooool0ogl0
00;ooooo00@0ogl0ooooooooool0ogl00oooool00`3oO`3oooooooooo`0>ooooo`80ogl00_ooool0
0`3oO`3oooooooooo`0Jooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0I_ooool0
0`2P8?3ooooo0:0Pl005ooooo`030:0Pl?oooooooooo00Wooooo0P2P8?05ooooo`030:0Pl?oooooo
oooo00kooooo00<0X23`ooooooooool01Oooool00`2P8?3oooooooooo`04ooooo`030:0Pl?oooooo
oooo00Gooooo00@0X23`ooooooooool0X23`1Oooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`1Xooooo`80ogl000?ooooo0?mo003oO`001Oooool01@3oO`3ooooooooooooo
ool0ogl001Cooooo00@0ogl0ooooooooool0ogl05?ooool00`3oO`3oooooooooo`0<ooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0J?ooool00`2P8?3oooooooooo`0Dooooo`030:0P
l?oooooooooo02Sooooo00<0X23`ooooooooool01Oooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`1Rooooo`030?mo0?oooooooooo00?ooooo1P3oO`000oooool0ogl00?mo
00020?mo00Sooooo00@0ogl0ooooooooool0ogl00oooool00`3oO`3oooooooooo`02ooooo`030?mo
0?oooooooooo00Cooooo00<0ogl0ooooooooool08Oooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo05kooooo00D0X23`oooooooooooooooo0:0Pl00:ooooo`030:0Pl?oooooooooo01?o
oooo00<0X23`ooooooooool0:oooool00`2P8?000000ooooo`09ooooo`002Oooool00`00003ooooo
ooooo`1Uooooo`030?mo0?oooooooooo00?ooooo00<0ogl0ooooo`3oO`000`3oO`08ooooo`030?mo
0?oooooooooo00;ooooo00@0ogl0ooooooooool0ogl01Oooool20?mo01[ooooo00<0ogl0oooooooo
ool03?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo08Sooooo00<0X23`oooooooo
ool09oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1Zooooo`@0ogl0
00Cooooo0?mo003oO`00ogl03oooool01@3oO`3oooooooooooooool0ogl002cooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`1Zooooo`030:0Pl?oooooooooo02Oooooo00<0X23`oooo
ooooool06?ooool0102P8?3oooooooooo`00000:ooooo`002Oooool00`00003oooooooooo`1Zoooo
o`@0ogl000Gooooo0?mo003oO`3ooooo0?mo0002ooooo`030?mo0?oooooooooo00Oooooo00<0ogl0
ooooo`3oO`001?ooool00`3oO`3ooooo0?mo0006ooooo`030?mo0?oooooooooo00cooooo00<0ogl0
ooooooooool04Oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo06[ooooo00<0X23`
ooooo`2P8?008_ooool00`2P8?3oooooooooo`04ooooo`030:0Pl?oooooooooo01Wooooo00<00000
ooooooooool02?ooool000Wooooo00<00000ooooooooool0J?ooool00`3oO`3oooooooooo`02oooo
o`@0ogl03oooool00`3oO`3oooooooooo`0_ooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0J_ooool00`2P8?3oooooooooo`0[ooooo`030:0Pl?oooooooooo01Oooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0K?ooool50?mo0003ooooo`3oO`3ooooo0080
ogl000?ooooo0?mo0?ooool00_ooool20?mo00?ooooo0P3oO`06ooooo`030?mo0?oooooooooo01Go
oooo00<0ogl0ooooooooool03oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo06go
oooo0P2P8?06ooooo`030:0Pl?oooooooooo00[ooooo00<0X23`ooooooooool02_ooool00`2P8?3o
ooooooooo`02ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool05Oooool00`2P8?00
0000ooooo`09ooooo`002Oooool00`00003oooooooooo`23ooooo`040?mo0?oooooooooo0?mo02_o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`1aooooo`030:0Pl?oooooooooo00co
oooo00<0X23`ooooooooool05_ooool00`2P8?3oooooooooo`0Fooooo`0300000?oooooooooo00So
oooo0009ooooo`0300000?oooooooooo06cooooo00<0ogl0ooooooooool00P3oO`0>ooooo`050?mo
0?ooool0ogl0ooooo`3oO`000_ooool20?mo00?ooooo00<0ogl0ooooooooool01Oooool00`3oO`3o
ooooooooo`0Looooo`0300000?oooooooooo00oooooo00<00000ooooooooool0Joooool01@2P8?3o
ooooooooooooool0X23`00gooooo00<0X23`ooooooooool05_ooool0102P8?3oooooooooo`2P8?0H
ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo077ooooo00D0ogl0oooo
oooooooooooo0?mo000=ooooo`030?mo0?ooool0ogl002Sooooo00D0ogl0oooooooooooooooo0000
000Aooooo`0300000?oooooooooo06gooooo00D0X23`oooooooooooooooo0:0Pl00Nooooo`040:0P
l?oooooooooo0:0Pl1gooooo00<0X23`00000?ooool02Oooool000Wooooo00<00000ooooooooool0
KOooool00`3oO`3oooooooooo`04ooooo`80ogl04?ooool00`3oO`3oooooooooo`04ooooo`030?mo
0?oooooooooo01?ooooo00<0ogl0ooooooooool03?ooool00`00003oooooooooo`0?ooooo`030000
0?oooooooooo06oooooo00<0X23`ooooooooool04_ooool00`2P8?3oooooooooo`0Booooo`030:0P
l?oooooooooo01Kooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0Hooo
ool00`3oO`3oooooooooo`0<ooooo`80ogl000Wooooo0?mo003oO`3ooooo0?mo0?ooool0ogl0oooo
o`3oO`001Oooool0103oO`3oooooooooo`3oO`06ooooo`030?mo0?oooooooooo02?ooooo00<00000
ooooooooool03oooool00`00003oooooooooo`1`ooooo`030:0Pl?oooooooooo00Wooooo00<0X23`
ooooooooool06?ooool00`2P8?3oooooooooo`0Hooooo`0300000?oooooooooo00Sooooo0009oooo
o`0300000?oooooooooo07Gooooo00<0ogl0ooooooooool06?ooool01@3oO`3oooooooooooooool0
ogl001gooooo00<00000ooooooooool03oooool00`00003oooooooooo`29ooooo`80X23`5_ooool0
0`2P8?3oooooooooo`0>ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo
07Oooooo00@0ogl0ooooooooool0ogl06oooool00`3oO`3oooooooooo`0Iooooo`0300000?oooooo
oooo00oooooo00<00000ooooooooool0NOooool00`2P8?3oooooooooo`0>ooooo`040:0Pl?oooooo
oooo0:0Pl0Kooooo00<0X23`ooooooooool06oooool00`00003oooooooooo`08ooooo`002Oooool0
0`00003oooooooooo`1gooooo`030?mo0?oooooooooo01?ooooo00<0ogl0ooooooooool01?ooool0
0`3oO`3oooooooooo`09ooooo`030?mo0?oooooooooo00kooooo00<0ogl000000?ooool04?ooool0
0`00003oooooooooo`2:ooooo`030:0Pl?oooooooooo02Gooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0NOooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo
00Sooooo00@0ogl0ooooooooool0ogl00oooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooo
oooo01Kooooo00<00000ooooooooool03oooool00`00003oooooooooo`1eooooo`030:0Pl?oooooo
oooo013ooooo00<0X23`ooooooooool00oooool00`2P8?3oooooooooo`0<ooooo`80X23`4oooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1`ooooo`030?mo0?ooool0ogl0
00Cooooo00<0ogl0ooooooooool01_ooool00`3oO`3oooooooooo`05ooooo`80ogl03Oooool00`3o
O`3oooooooooo`0Hooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0MOooool01@2P
8?3oooooooooooooool0X23`00?ooooo00<0X23`ooooooooool01_ooool01@2P8?3ooooooooooooo
ool0X23`01Cooooo00<0X23`ooooooooool01Oooool00`2P8?3oooooooooo`08ooooo`0300000?oo
oooooooo00Sooooo0009ooooo`0300000?oooooooooo07Wooooo00<0ogl0ooooooooool07Oooool0
0`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo00oooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`1]ooooo`030:0Pl?oooooooooo00Gooooo00<0X23`ooooooooool0>_ooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1booooo`040?mo0?oooooooooo
0?mo00Oooooo0P3oO`05ooooo`070?mo0?ooooooooooooooo`3oO`3ooooo0?mo0006ooooo`@0ogl0
1?ooool00`3oO`3oooooooooo`04ooooo`80ogl01?ooool00`3oO`3oooooooooo`09ooooo`030000
0?oooooooooo00oooooo00<00000ooooooooool0Moooool0102P8?3oooooooooo`2P8?0;ooooo`03
0:0Pl?oooooooooo00Sooooo00<0X23`ooooooooool00oooool00`2P8?3oooooooooo`09ooooo`03
0:0Pl?oooooooooo00Gooooo00<0X23`ooooooooool01?ooool00`00003oooooooooo`08ooooo`00
2Oooool00`00003oooooooooo`1iooooo`030?mo0?oooooooooo01Kooooo00D0ogl0oooooooooooo
oooo0?mo000Kooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0NOooool00`2P8?3o
ooooooooo`07ooooo`030:0Pl?ooool0X23`00cooooo00<0X23`ooooooooool04oooool00`2P8?3o
ooooooooo`07ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo07_ooooo
00<0ogl0ooooooooool07?ooool20?mo01Kooooo00<00000ooooooooool03oooool00`00003ooooo
ooooo`1gooooo`050:0Pl?ooooooooooooooo`2P8?009oooool00`2P8?3oooooooooo`0<ooooo`03
00000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo07Gooooo00<0ogl0ooooooooool0
1oooool01@3oO`3ooooo0?mo0?ooool0ogl000Cooooo00<0ogl0ooooooooool00_ooool00`3oO`3o
ooooooooo`02ooooo`040?mo0?ooool0ogl00?mo00?ooooo00<0ogl0ooooooooool00oooool00`3o
O`3oooooooooo`0@ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0N_ooool01@2P
8?3ooooo0:0Pl?ooool0X23`00?ooooo00<0X23`ooooooooool08oooool00`2P8?3oooooooooo`06
ooooo`030:0Pl000003ooooo00Wooooo0009ooooo`0300000?oooooooooo08[ooooo00<0ogl0oooo
o`3oO`000_ooool00`3oO`3oooooooooo`07ooooo`030?mo0?oooooooooo00Oooooo00<0ogl0oooo
ooooool00_ooool00`3oO`3oooooooooo`07ooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0R?ooool00`2P8?3oooooooooo`0Hooooo`030:0Pl?oooooooooo00cooooo00<00000oooo
ooooool02?ooool000Wooooo00<00000ooooooooool0N_ooool01@3oO`3oooooooooooooool0ogl0
00;ooooo00<0ogl0ooooo`3oO`000_ooool20?mo00Cooooo00D0ogl0ooooo`3oO`3ooooo0?mo0003
ooooo`050?mo0?ooooooooooooooo`3oO`003Oooool00`3oO`3oooooooooo`020?mo00Oooooo00<0
0000ooooooooool03oooool00`00003oooooooooo`27ooooo`80X23`3_ooool00`2P8?3ooooooooo
o`0<ooooo`80X23`2_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`26
ooooo`040?mo0?oooooooooo0?mo00[ooooo00<0ogl0ooooooooool01oooool01@3oO`3ooooooooo
ooooool0ogl000oooooo00<00000ooooooooool03oooool00`00003oooooooooo`2Booooo`030:0P
l?oooooooooo01gooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0Q_oo
ool00`3oO`3oooooooooo`0Yooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0POoo
ool00`2P8?3oooooooooo`0Jooooo`030:0Pl?oooooooooo00?ooooo00<0X23`ooooooooool02ooo
ool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1nooooo`050?mo0?oooooo
ooooooooo`3oO`002_ooool00`3oO`3oooooooooo`04ooooo`030?mo0?oooooooooo017ooooo00<0
ogl0ooooooooool01oooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo07kooooo00<0
X23`ooooooooool00P2P8?05ooooo`80X23`1Oooool00`2P8?3oooooooooo`04ooooo`<0X23`1Ooo
ool00`2P8?3oooooooooo`02ooooo`030:0Pl?oooooooooo00cooooo00<00000ooooooooool02?oo
ool000Wooooo00<00000ooooooooool0O_ooool0103oO`3oooooooooo`3oO`0>ooooo`030?mo0?oo
oooooooo00Cooooo00<0ogl0ooooooooool01oooool00`3oO`3oooooooooo`0>ooooo`0300000?oo
oooooooo00oooooo00<00000ooooooooool0P_ooool00`2P8?3oooooooooo`0Booooo`030:0Pl?oo
oooooooo01Cooooo00D0X23`ooooooooool0X23`0000000:ooooo`002Oooool00`00003ooooooooo
o`25ooooo`80ogl01Oooool0103oO`3oooooooooo`3oO`02ooooo`030?mo0?oooooooooo00?ooooo
00<0ogl0ooooooooool02?ooool00`3oO`3oooooooooo`07ooooo`030?mo0?oooooooooo00;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`1oooooo`050:0Pl?ooooooooooooooo`2P
8?006?ooool01@2P8?3oooooooooooooool0X23`00;ooooo00<0X23`ooooooooool00oooool00`2P
8?3oooooooooo`02ooooo`050:0Pl?ooooooooooooooo`0000002_ooool000Wooooo00<00000oooo
ooooool0UOooool00`3oO`3ooooo0?mo0006ooooo`030?mo0?ooool0ogl0017ooooo00<00000oooo
ooooool03oooool00`00003oooooooooo`1iooooo`030:0Pl?oooooooooo01Kooooo00<0X23`oooo
o`2P8?005oooool00`2P8?3oooooooooo`03ooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo08;ooooo00<0ogl0ooooooooool00oooool00`3oO`3ooooo0?mo000@ooooo`03
0?mo0?oooooooooo0080ogl000?ooooo0?mo0?ooool00_ooool00`3oO`3ooooo0?mo000:ooooo`03
00000?oooooooooo00oooooo00<00000ooooooooool0P_ooool20:0Pl0?ooooo00<0X23`oooooooo
ool08oooool01P2P8?3oooooooooooooool0X23`000000[ooooo0009ooooo`0300000?oooooooooo
08Sooooo00<0ogl0ooooo`3oO`002Oooool00`3oO`3oooooooooo`0>ooooo`030?mo0?oooooooooo
00[ooooo00<00000ooooooooool03oooool00`00003oooooooooo`27ooooo`030:0Pl?oooooooooo
00;ooooo0P2P8?000oooool0X23`ooooo`0Qooooo`0300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo08Gooooo00@0ogl0ooooooooool0ogl00_ooool00`3oO`3ooooo0?mo0003oooo
o`050?mo0?ooooooooooooooo`3oO`006Oooool0103oO`3oooooooooo`00000Aooooo`0300000?oo
oooooooo08?ooooo00<0X23`ooooooooool03_ooool00`2P8?3oooooooooo`0Jooooo`030:0Pl000
003ooooo00Wooooo0009ooooo`0300000?oooooooooo08Wooooo00<0ogl0ooooooooool01_ooool0
0`3oO`3oooooooooo`0Eooooo`030?mo0?oooooooooo00Cooooo00<0ogl000000?ooool04?ooool0
0`00003oooooooooo`28ooooo`080:0Pl?oooooooooo0:0Pl?ooool0X23`ooooo`2P8?07ooooo`05
0:0Pl?ooooooooooooooo`2P8?004_ooool01@2P8?3oooooooooo`2P8?00000000[ooooo0009oooo
o`0300000?oooooooooo08Kooooo00<0ogl0ooooooooool01?ooool00`3oO`3oooooooooo`03oooo
o`030?mo0?oooooooooo00[ooooo00<0ogl0ooooooooool00_ooool00`3oO`3oooooooooo`0:oooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool0T?ooool20:0Pl1Kooooo00<0X23`oooo
ooooool01oooool00`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`1nooooo`03
0?mo0?oooooooooo00Sooooo0P3oO`02ooooo`030?mo0?ooool0ogl000?ooooo00<0ogl0oooooooo
ool00oooool00`3oO`3ooooo0?mo0005ooooo`040?mo0?ooool0ogl00?mo00?ooooo0P3oO`08oooo
o`0300000?oooooooooo00oooooo00<00000ooooooooool0R?ooool00`2P8?3oooooooooo`0=oooo
o`030:0Pl?oooooooooo01Kooooo00<0X23`00000?ooool02Oooool000Wooooo00<00000oooooooo
ool0QOooool00`3oO`3ooooo0?mo0003ooooo`030?mo0?oooooooooo013ooooo00<0ogl0oooooooo
ool00_ooool00`3oO`3oooooooooo`0<ooooo`0300000?oooooooooo00oooooo00<00000oooooooo
ool0U?ooool00`2P8?3oooooooooo`0Kooooo`0300000?oooooooooo00Sooooo0009ooooo`030000
0?oooooooooo08;ooooo00<0ogl0ooooooooool02?ooool30?mo00;ooooo00<0ogl0ooooooooool0
0_ooool00`3oO`3oooooooooo`0<ooooo`030?mo0?ooool0ogl000Wooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`2;ooooo`030:0Pl?oooooooooo00?ooooo00<0X23`ooooooooool0
4Oooool00`2P8?3oooooooooo`0:ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oo
oooooooo08Wooooo0P3oO`04ooooo`060?mo0?oooooooooo0?mo0?ooool0ogl01oooool00`3oO`3o
ooooooooo`03ooooo`80ogl01Oooool00`3oO`3oooooooooo`05ooooo`030?mo0000003ooooo013o
oooo00<00000ooooooooool0TOooool00`2P8?3oooooooooo`05ooooo`030:0Pl?oooooooooo00Co
oooo00<0X23`ooooo`2P8?003_ooool00`2P8?000000ooooo`09ooooo`002Oooool00`00003ooooo
ooooo`2Booooo`030?mo0?oooooooooo01Cooooo00<0ogl0ooooooooool01_ooool00`00003ooooo
ooooo`0?ooooo`0300000?oooooooooo08cooooo00<0X23`ooooooooool00_ooool00`2P8?3ooooo
ooooo`0:ooooo`030:0Pl?oooooooooo00kooooo00@0X23`ooooooooool000002_ooool000Wooooo
00<00000ooooooooool0SOooool00`3oO`3oooooooooo`02ooooo`030?mo0?oooooooooo00;ooooo
0`3oO`02ooooo`030?mo0?oooooooooo00Wooooo00<0ogl0ooooooooool00P3oO`02ooooo`040?mo
0?oooooooooo0000017ooooo00<00000ooooooooool0U?ooool00`2P8?3oooooooooo`0Cooooo`03
0:0Pl?oooooooooo00Cooooo00<0X23`00000?ooool02Oooool000Wooooo00<00000ooooooooool0
TOooool20?mo0003ooooo`3oO`3ooooo00Kooooo00<0ogl0ooooooooool01Oooool20?mo0003oooo
o`3oO`3ooooo00Wooooo00<00000ooooooooool03oooool00`00003oooooooooo`2=ooooo`030:0P
l?oooooooooo00Wooooo00<0X23`ooooooooool05_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`2=ooooo`030?mo0?oooooooooo00?ooooo00<0ogl0ooooooooool04Ooo
ool00`3oO`3oooooooooo`03ooooo`060?mo0?ooooooooooooooo`3oO`0000004Oooool00`00003o
ooooooooo`2:ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool08?ooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2?ooooo`030?mo0?oooooooooo00;ooooo
00<0ogl0ooooooooool00oooool20?mo00;ooooo00<0ogl0ooooo`3oO`002oooool00`3oO`3ooooo
ooooo`03ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0SOooool00`2P8?3ooooo
0:0Pl002ooooo`050:0Pl?ooool0X23`0:0Pl?ooool00P2P8?02ooooo`030:0Pl?oooooooooo01Co
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0U_ooool20?mo00cooooo
00H0ogl0ooooooooool0ogl0ooooo`3oO`08ooooo`0300000?oooooooooo00oooooo00<00000oooo
ooooool0Woooool00`2P8?3oooooooooo`0?ooooo`030:0Pl000003ooooo00Wooooo0009ooooo`03
00000?oooooooooo09Cooooo00D0ogl0ooooo`3oO`3ooooo0?mo0005ooooo`030?mo0?ooool0ogl0
00;ooooo0P3oO`000oooool0ogl0ooooo`05ooooo`030?mo0?oooooooooo0080ogl000<00000oooo
ooooool03oooool00`00003oooooooooo`2Aooooo`80X23`00?ooooo0:0Pl?ooool00oooool00`2P
8?3oooooooooo`05ooooo`030:0Pl?oooooooooo00;ooooo00<0X23`ooooooooool00oooool00`2P
8?3oooooooooo`03ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo09Ko
oooo00<0ogl0ooooo`3oO`000oooool0103oO`3oooooooooo`3oO`03ooooo`050?mo0?oooooooooo
0?mo0?ooool00P3oO`08ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool0TOooool0
1@2P8?3ooooo0:0Pl?ooool0X23`00?ooooo0P2P8?0Gooooo`0300000?oooooooooo00Sooooo0009
ooooo`0300000?oooooooooo08Kooooo00<0ogl0ooooooooool02_ooool00`3oO`3oooooooooo`04
0?mo0003ooooo`3oO`3ooooo0080ogl00oooool0103oO`3oooooooooo`3oO`02ooooo`030?mo0?oo
ool0ogl000Oooooo00<00000ooooooooool03oooool00`00003oooooooooo`2Zooooo`80X23`1Ooo
ool00`2P8?000000ooooo`09ooooo`002Oooool00`00003oooooooooo`2Dooooo`030?mo0?oooooo
oooo00Cooooo00<0ogl0ooooooooool01?ooool00`3oO`3ooooo0?mo00020?mo00?ooooo00<0ogl0
ooooooooool00oooool20?mo000300000?oooooooooo00oooooo00<00000ooooooooool0U?ooool0
0`2P8?3ooooo0:0Pl004ooooo`030:0Pl?oooooooooo00kooooo00<0X23`ooooooooool00oooool0
0`00003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2Dooooo`030?mo0?oooooooooo
00?ooooo0P3oO`000oooool0ogl0ooooo`020?mo00Gooooo00<0ogl0ooooo`3oO`001_ooool0103o
O`3oooooooooo`00000Aooooo`0300000?oooooooooo0:oooooo00@0X23`ooooo`2P8?0000002_oo
ool000Wooooo00<00000ooooooooool0Toooool00`3oO`3oooooooooo`020?mo00?ooooo0P3oO`04
ooooo`030?mo0?oooooooooo00Kooooo00<0ogl0ooooo`3oO`000_ooool0103oO`3ooooo0?mo0000
000Aooooo`0300000?oooooooooo09Kooooo102P8?02ooooo`040:0Pl?ooooooooooooooo`80X23`
2?ooool0102P8?3ooooo0:0Pl02P8?02ooooo`80X23`00<00000ooooooooool02?ooool000Wooooo
00<00000ooooooooool0U?ooool00`3oO`3oooooooooo`030?mo0003ooooo`3oO`3ooooo00?ooooo
00L0ogl0oooooooooooooooo0?mo0?ooool0ogl000[ooooo00<0ogl000000?ooool04?ooool00`00
003oooooooooo`2Gooooo`030:0Pl?oooooooooo00Cooooo0`2P8?02ooooo`030:0Pl?oooooooooo
00;ooooo00<0X23`ooooooooool01_ooool00`2P8?000000ooooo`09ooooo`002Oooool00`00003o
ooooooooo`2Booooo`030?mo0?oooooooooo00;ooooo00<0ogl0ooooo`3oO`000_ooool00`3oO`3o
oooo0?mo00020?mo00;ooooo00D0ogl0oooooooooooooooo0?mo0002ooooo`030?mo0?oooooooooo
00Gooooo00<00000ooooooooool03oooool00`00003oooooooooo`2Eooooo`030:0Pl?oooooooooo
0080X23`00?ooooo0:0Pl?ooool00_ooool30:0Pl0Gooooo00<0X23`ooooooooool02?ooool00`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2Cooooo`80ogl01_ooool01@3oO`3o
ooooooooo`3oO`3ooooo0080ogl01?ooool30?mo0003ooooo`3oO`00ogl000Gooooo00<0ogl00000
0?ooool04?ooool00`00003oooooooooo`2Hooooo`030:0Pl?ooool0X23`0080X23`2?ooool01P2P
8?3ooooo0:0Pl02P8?3ooooo0:0Pl0Oooooo00<00000ooooooooool02?ooool000Wooooo00<00000
ooooooooool0T_ooool00`3oO`3ooooo0?mo0004ooooo`030?mo0?oooooooooo00;ooooo0P3oO`05
ooooo`030?mo0?ooool0ogl00080ogl00_ooool20?mo00Cooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2Iooooo`<0X23`2_ooool30:0Pl0Kooooo00@0X23`ooooo`2P8?0000002_oo
ool000Wooooo00<00000ooooooooool0U?ooool20?mo00?ooooo00@0ogl0ooooo`3oO`3ooooo0P3o
O`02ooooo`<0ogl00_ooool20?mo00Cooooo0P3oO`03ooooo`030?mo0000003ooooo013ooooo00<0
0000ooooooooool0VOooool60:0Pl005ooooo`2P8?3oooooooooo`2P8?000_ooool00`2P8?3ooooo
ooooo`03ooooo`070:0Pl?oooooooooo0:0Pl?ooool0X23`0000000:ooooo`002Oooool00`00003o
ooooooooo`2Gooooo`030?mo0?oooooooooo0080ogl000?ooooo0?mo0?ooool01Oooool0103oO`3o
ooooooooo`3oO`03ooooo`030?mo0?ooool0ogl000Cooooo00<00000ooooooooool03oooool00`00
003oooooooooo`2Kooooo`80X23`00?ooooo0:0Pl02P8?002Oooool20:0Pl0Gooooo0P2P8?000`00
003oooooooooo`08ooooo`002Oooool00`00003oooooooooo`2Jooooo`/0ogl00_ooool00`3oO`3o
ooooooooo`02ooooo`030?mo0?oooooooooo00;ooooo00<0ogl000000?ooool04?ooool00`00003o
ooooooooo`2Kooooo`030:0Pl?ooool0X23`00<0X23`00?ooooo0:0Pl?ooool03_ooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2Iooooo`030?mo0?oooooooooo00;ooooo
00<0ogl0ooooo`3oO`000oooool20?mo00;ooooo00<0ogl0ooooooooool01?ooool0103oO`3ooooo
ooooo`00000Aooooo`0300000?oooooooooo09kooooo0`2P8?02ooooo`040:0Pl?oooooooooo0:0P
l0_ooooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0W?ooool00`3oO`3o
oooo0?mo00020?mo00;ooooo00<0ogl0ooooo`3oO`000P3oO`03ooooo`80ogl01?ooool00`3oO`00
0000ooooo`0@ooooo`0300000?oooooooooo09gooooo00@0X23`ooooooooool0X23`2_ooool00`2P
8?3oooooooooo`04ooooo`0300000?oooooooooo00Sooooo0009ooooo`0300000?oooooooooo09_o
oooo00D0ogl0ooooooooool0ogl0ooooo`020?mo0003ooooo`3oO`3ooooo0080ogl000Cooooo0?mo
0?ooool0ogl01?ooool0103oO`3oooooooooo`00000Aooooo`0300000?oooooooooo09oooooo0P2P
8?001?ooool0X23`0:0Pl?ooool20:0Pl003ooooo`2P8?3ooooo00Cooooo00D0X23`oooooooooooo
oooo0000000:ooooo`002Oooool00`00003oooooooooo`2Jooooo`030?mo0?oooooooooo00Cooooo
00<0ogl0ooooo`3oO`000_ooool00`3oO`3oooooooooo`020?mo0004ooooo`3oO`3ooooo0?mo00?o
oooo00<00000ooooooooool03oooool00`00003oooooooooo`2Oooooo`030:0Pl?ooool0X23`00Oo
oooo00<0X23`ooooooooool01_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`2Kooooo`030?mo0?oooooooooo00Kooooo1@3oO`001Oooool0ogl0ooooooooool0ogl000?o
oooo00<0ogl000000?ooool04?ooool00`00003oooooooooo`2Rooooo`<0X23`0oooool20:0Pl0So
oooo00<00000ooooooooool02?ooool000Wooooo00<00000ooooooooool0W_ooool00`3oO`3ooooo
ooooo`03ooooo`030?mo0?oooooooooo0080ogl01oooool00`3oO`3ooooo0000000Aooooo`030000
0?oooooooooo0:gooooo00<0X23`ooooooooool00_ooool00`00003oooooooooo`08ooooo`002Ooo
ool00`00003oooooooooo`2Jooooo`030?mo0?oooooooooo00Kooooo00<0ogl0ooooooooool00_oo
ool00`3oO`3ooooo0?mo0004ooooo`040?mo0?oooooooooo0000017ooooo00<00000ooooooooool0
YOooool01P2P8?3oooooooooo`2P8?3ooooo0:0Pl0Oooooo00<00000ooooooooool02?ooool000Wo
oooo00<00000ooooooooool0X?ooool00`3oO`3oooooooooo`0?ooooo`0300000?oooooooooo00oo
oooo00<00000ooooooooool0/_ooool00`00003oooooooooo`08ooooo`002Oooool00`00003ooooo
ooooo`2Rooooo`030?mo0?oooooooooo00cooooo00<0ogl000000?ooool04?ooool00`00003ooooo
ooooo`2Qooooo`030:0Pl?oooooooooo00Kooooo00<0X23`ooooooooool01Oooool00`00003ooooo
ooooo`08ooooo`002Oooool00`00003oooooooooo`2Vooooo`030?mo0?ooool0ogl000;ooooo00<0
ogl0ooooo`3oO`001?ooool00`00003oooooooooo`0?ooooo`0300000?oooooooooo0:Sooooo0P2P
8?07ooooo`030:0Pl000003ooooo00Wooooo0009ooooo`0300000?oooooooooo0:oooooo00@0ogl0
ooooooooool000004Oooool00`00003oooooooooo`2Xooooo`030:0Pl?ooool0X23`00Kooooo00<0
X23`00000?ooool02Oooool000Wooooo00<00000ooooooooool0Xoooool00`3oO`3oooooooooo`06
ooooo`030?mo0?oooooooooo00?ooooo00<00000ooooooooool03oooool00`00003oooooooooo`2X
ooooo`050:0Pl?ooool0X23`ooooo`2P8?001?ooool00`2P8?000000ooooo`09ooooo`002Oooool0
0`00003oooooooooo`2Zooooo`030?mo0?oooooooooo00Gooooo00<00000ooooooooool03oooool0
0`00003oooooooooo`2Zooooo`030:0Pl?oooooooooo00Gooooo00<00000ooooooooool02?ooool0
00Wooooo00<00000ooooooooool0Z_ooool00`3oO`3oooooooooo`04ooooo`030?mo0000003ooooo
013ooooo00<00000ooooooooool0/?ooool20:0Pl00300000?oooooooooo00Sooooo0009ooooo`03
00000?oooooooooo0:Sooooo00<0ogl0ooooooooool00_ooool01P3oO`3oooooooooooooool0ogl0
0000017ooooo00<00000ooooooooool0Z_ooool00`2P8?3oooooooooo`04ooooo`030:0Pl000003o
oooo00Wooooo0009ooooo`0300000?oooooooooo0:cooooo00<0ogl0ooooo`3oO`000oooool00`00
003oooooooooo`0?ooooo`0300000?oooooooooo0:[ooooo00<0X23`ooooooooool01?ooool00`2P
8?000000ooooo`09ooooo`002Oooool00`00003oooooooooo`2/ooooo`80ogl00_ooool00`3oO`3o
oooo0000000Aooooo`0300000?oooooooooo0:_ooooo00<0X23`ooooooooool01?ooool00`00003o
ooooooooo`08ooooo`002Oooool00`00003oooooooooo`2]ooooo`030?mo0?oooooooooo00;ooooo
00<00000ooooooooool03oooool00`00003oooooooooo`2booooo`0300000?oooooooooo00Sooooo
0009ooooo`0300000?oooooooooo0:oooooo0`3oO`000`00003oooooooooo`0?ooooo`0300000?oo
oooooooo0;;ooooo00<00000ooooooooool02?ooool000Wooooo/@0000030?mo008000004Ooooond
000000030:0Pl000003ooooo00Wooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo
003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {399, 0}} -> {-0.0500105, -0.0500105, \
0.00526322, 0.00526322}, {{9.5, 190.438}, {389.5, 208.5}} -> {-0.0754053, \
-0.0755852, 0.00575585, 0.00575585}, {{208.5, 389.438}, {389.5, 208.5}} -> \
{-1.22082, -0.0755852, 0.00575585, 0.00575585}, {{9.5, 190.438}, {190.438, \
9.5}} -> {-13.5849, -294.52, 1.41129, 1.41129}, {{208.5, 389.438}, {190.438, \
9.5}} -> {-294.432, -294.52, 1.41129, 1.41129}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Image classification", "Subsection"],

Cell[BoxData[{
    \(\(pdf1 = 
        MixtureLikelihoodNative[{x, y}, model1];\)\), "\[IndentingNewLine]", 
    \(\(pdf2 = MixtureLikelihoodNative[{x, y}, model2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage2DAugmented[obj1, pdf1, pdf2, {Red, Green}, 
          255. ];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage2DAugmented[obj2, pdf1, pdf2, {Red, Green}, 
          255. ];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1, class1}, {obj2, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55495 
%%ImageSize: 400 221.978 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.013213 0.47619 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.013213 0.477324 0.264889 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7E7E5CBCCC7D1D2CDECECEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F8F7F3DCDBD7B2B1AF7E7D7B4C4B472E2D2935343053524E
777672A5A6A1CCCCCAE9E9E700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00DCD8D59C999466635C3F3C3527241F2D2A25282421302C29322F2A2F2C27
2926212827222E2F274748428B8C86EDEEE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F6F7F2AEADA943403B221D17211E15302D243C3731433E3A443F3B4C4441524B45554E48
544F494D4A4137342B2222181B1B135E5F59D0D1CC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E0E1DC
7D7C7734312A1D181228241B353128413D3440393339312E3D3532423836473E3949403B
4D443D50493F494238433F363532291D1D153E3D39ADACAA00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3E3E15F5E59
28251E2521181F1B1237332A403C333B372E37302A342C293F3533403634433834443933
3F342E3F362D483F364A43394B473C3C39302825202A2925A5A5A300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F4F4F27B7A7525251D
2C2920242017322B21463F353B342A4740363D342D342B26362F29352E283C332E393029
3B322B4A41384F473C423A2F433F334A483C37342D1F1E193C3D38D6D6D400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3A09B28251E26231C
2F2A24261F17342B244A4138372E253F362D494039393029302722382F2A3D342F362D26
433A31534A414F453B40362C403A2E4A463B46433A2827221E1D196E6E6CF4F4F400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFF5F4FFF6F3FFF4F0FFF4F0FFF5F2FFF5F2FFF6F2FFF8F3CBBEB83C332C2017122A231D
312A242A231D2D221E463B37392E2A2E231D4237333F34303227213B302A443933382D27
3E342B4F453C493C343A30273A3128453E34514D442B2A2523221E21211FABA9AA00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFEEE8E8D1CBE1C9C5D8C3C0D4C2C0D5C3C1DBC9C7D2BDBCD5BBBCDEBEBFD1AAABC09495
CC9A99CB9894C48F89B9847EB7857EAF7E77A0756E92706760453C27150B251812312823
2E24222A201E291E1C382D2B4136322F2420372C283A2F2B3A2F29423731514640433832
3F362D4A4037362C2330261D372E25474038443F392B282326221F1B1716484242E7DEDF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDEDEDAFAFAF6A6A68
6565636566616565636667626768636A6B668E8E8CBBBBB9D3D3D1E8E8E600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FCD5CE
BF897F894D42A47065A97C76825D5783625DA4817FA27A78A47474B37978A55D5E8F3E3D
A34A46A64741A6453C9F3F33A34539953D3186382B7A3C2F5F332633150B28150E352724
3329272E24222A201E2C2220342A28372D2B382D293D322E393029443B34534A414F463D
4740363E372D302720281F1841383148413B372F2C2D2523251C1D271B1B251214887473
DCCAC6E0D1CAE6D9D1E9DFD6F1E7DDF8EFE6FFF6EFFFFDF500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEECACAEAB5959572525231A1917
1716121918131B1A161E1D181718120F100A1A1B1623241F2C2E29474944646663878986
AEB0ADE2E4E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFEAE7E5AEA9B26960
9C493B903D2DD08B7CBD83789867608E635D9467629A6764A96C6BC37978C86E6DA9413E
BB4A44BE473FC84D45C54B40C54D3FBD4C3EA33F2FAB584881433442180C2C0F0934211D
3729263328263126242E24222B211F2F2523382D293A2F2B3A312C3F362F423932403931
3F3B3239352C37302A3F383238302D362E2B312927281E1D2D1F1F3420222B0E1040211E
513329593C2E6D5241644E396D5941745F4A7B6955806D5C897665917E6DA18C7BAE988A
BAA496C8B2A5D5BDB3DBC4BCE0CBC6E6D3CFECDAD6F1E2DFF4E9E5FAF0EE00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00F2F2F0AFAFAD5757551E201B1516111F1E1A201F1B
1C1B161C1B162926212828201D1D151D1E161D1E18181913161711161912151712161815
1719164E504DD6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F5FFCECAD0837DB64F46BA4A3E
B045359C3D2BE29585C6887BB48075976860A3736FB27C7AAD6D6BCA7C7ADC7E7CB44845
C34E47C24740D3544DCE4E45CF5145CA5043AE3E30BE5D4D964A3C50160A360E06391D19
3723223424243A2C2B2F24222F2420302521342623332824372E29372E2938312B3A332D
3E393336312B362E2B372F2C2B23212B23212B2122302222352123381B1D320A0B552521
6A392B6B3B257A4D305E36125F391258350B5B350E5B3510552F0A59330E5C3410693E1C
5C2D1168341E672E1B632A19672F226E3A2F73473E734C4576554E7A5D578265618D6F6D
957673A58683AF908DB99A95C4A7A3CFB3AFD9C0BCDDC8C5E2CFCBE7D5D1EDDEDBF3E4E1
F9EBEAFEF3F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00C6C6C465666123241F171813151611191A15201F1B21201B
2F2C27302D26342F2937342D37342D39392F33332B26271F1C1D15181911151811131510
1217131015114A4C4BD2D4D300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F4DBAFACB4615BB6463BCB473BD04B3C
BF4635A83F2CE89583CB8878B97F73AB756BAF766FAA6D689D5652B6615EDB7873BF4E48
C94E47CC4B45D24D46D55047D14C43D04D43BC4034C25143BB5B4D6D1F124307003F120D
3F1D1B3A201F3723223523213A2B283A2B283D2E2B3B2D2A3328263026242E24222F2724
332B282C24212A222029211F2920212B21222D1F1F331F213E2123381112390605652A24
7D3F307C4026915B37794A1E794D1E754B197E5221805423764A197446157545177F4A1E
6F330E77351585391F873B247E35247A362970372C5A2A20542C244B261E4A231E4A2220
502723542B27542B25572E28532C254F2A224C2B24563732593C3660453E684C496F5652
745C587D6561866E6A937B779C8782A9948FB5A09DC1ACA9C9B4B1D7C2BFDEC9C6E5D0CD
EAD7D3F0DDD9F6E7E2FBEEE8FEF5EEFFFDF2FFFFF4FFFFF3FFFEF500FF0000FF0000FF00
00FF0000FF00E2E2E08888863435301C1D181A1B161C1D18191A151617122A2924393631
403B3538332D322D27322D2734312A38352C33302731312734342A2E2F2722231D13160F
171914161815181A19505251D6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FCD3CFA15650BC4A40D24A3ED44537D24635
C64736AC3D2AE68E7AC77C69B97465A76356904A40A65B559D4843C0615BE87B74C14840
CE4D47D14A44D64D47DB5049D84D46D54B41CB4136C94539D55D4FAE4436731910540B04
49120D451C183C1D1A381F1B3A25203C292542302E40312E3A2F2D3E33313429272D2321
342A2933292831272833292A302426312323341E203A1C1E441C1D3E0B0A480806753128
8A46338D4D32AB775294673D855C2E845E2D8A653198703D926A37956C389567369C693A
975C309B57308D3E1D8F3F249247308C4A3A6731275A2F288A685E85645B7C5953835D5A
8259555C302D643933653D35522C23542F2657352C59382F502F26502F264D2A264C2925
4F2C2848251F4E29234E2923502922532C25502922522923562924602D29682E2A6F342E
773E377D493E805044825B4A7F634E7F6B508D8262948E6C9D987AA7A58CADAC9ABBBBAF
C2C3BBA8A9A34D4E491D1E191C1D1721221C1D1C181E1D191F1E1A26252143403B312E29
2C2723302B2728231F2B26202F2A24312C2628231D28231D302D2633332B31302B23241E
1718131516111C1C1A191917505050E0E0E000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF6F3DCA098A7453AD04C40D64234D74132D54433
C74231B13928E27B68EB907DCC7466B75F53B55B52C5645DD16A63F0817ADF645DCA473F
D54C44D84B44D74840DD4E46DE4F47DD4D44D7443ACC3C31DD5346D25245BA453B8C271D
5F0F0653130A4B1610461914411C16401F1A3B1D1B3B212039211F3C2726372322362221
3A2828362424301C1D372123391F223C1C1F3E16174715164D0F104E040365120C903C31
9746339E563DAE76538F5F3782572D7852256B4518724C1D744C1B895F2D865A2B8E5B2C
884F229E5D33A45834974A2C954D358A4B3A55231A835D54AD8C83A1837BA88581B8928F
976E6C59302E633A36502922805B5298766C97756B916F658D685F8C655E8A615B875C56
865D577D544E774F47734B436C443C663B326539305B2A23692F2B6B27247C2E2A802D27
7D2A227B2D20722B19682E165227055C3F1567562260551F5A52235B562E5D5A3B5F5E49
3D3E301011091516101E1F1920211B1F201A201F1B1F1E1A1A19153A39353A3732292621
29262127241F25201C322D292F2A242B26202C24212B26222C272326231C2B282335342F
23241F191A151C1C1A1D1D1B16161689898900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFE7E3B76861BE4C41D3493CD64031D73F31D03D2D
D44736C23D2CDD6453FD8A78F38176E8736AE66D65DD605AD85952D8534CCD443CD3463D
D84A40D7473EDC4941DD4841E14C45DD493FDA433AD74035D94539DF5042DE5447CF5143
B1413389271A6B140A570D0453120C511713481512491917441B194921213A13143C181A
3E1A1A3C181841191A4115164715184B1012530D0F5807066607057A110D9F322BAD4336
AA4B379E4C34B26F5299614083512E885A387448255E340E6F451B7D52276D40177A4920
743E12995B32A86240944D3195533D7B41336C3D35B08B83B19089AE9088B59290BE9798
724A4B5B3435512E2C674641B3928BAC8E84AE8D84AA887FB68D87B58883A77672A77671
AB7E78A98179A38178A080759A7C7199796E96746A976C65A7726E7B37347B2725963934
97342E94342689341F8039196C380988642A856C29786721766B2B79723B817C528E8D6F
65645208080016160E23221D24231E21201B27241F201D181A171243403B2B2A25201F1A
2625201E1D18231E184B443E35302A25201A2D28242B26222A2521231E1A2A252135322D
3C3B361B1C171616141D1D1B181A1740423FE4E4E400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECC3BFAC4F47C84A3ED94B3DD64031D94133D43E2F
DE4B3BD84B3ACC4434DE594AD85247D95048DA4F48D4473ED4453DD24239D6433BD8443A
D64238D9453BD94239DC453CDF463EDA4237DA4139D84035DC4236E0483AE95345E45746
D85344CB5040AF3D328F291D72140C610C075B0C08570D0A5912105612114E0C0D501011
4D0D0E521011520E0F52080959090C5F06086C080A8212119F2522B4352EC5453CBE4638
B04734A54A35B86C54AE6C52A1654BA56D549761478350338B5A3A885736804E2D8C5634
7F4422B57655B372549151388E5341632F228F645DC8A39DBD9A94C09D99CDA6A7AB8286
62393D663F424D2B2A997A77B79893B1938BB4918BBE958FC796928D5653854A46864C48
8150497B50497D5B52A5897EA58A7FA4897EA4867CAC857EBD8785702C2B7D27269E3C39
9A332C9D392A943A22883C18793F0D9B72328D71278170227E712B8B8247948D5F9E9B7A
7978640E0E0217170F26252025241F221F1A27241F23201B201D18403D3835342F1E1D18
20211B191813231E1859544E35302A241F192A252126211D241F1B26211D25201C2C2924
41403B23241E191A151B1B191F211E20221FAFAFAF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF4F2C68F8CAE4740CE4940D64739DC4638DA4235DB4335
DE4839D84436DA483BDD4B3EDE4C3FDF4C42D9453BDA463CD9453BDC453AD94136D94136
D84035D94136DB4338D84035DA4036D83E32D93F35DC4236D93F33E2483CEB5346E55143
E05141DE5243DE584CD8584DCC5046B53E36A3322C8E211C8317147B120F78100F740C0B
700A08740C0B7D13138115158D1A1D9E2627AE2E2DC8413ED24440D84B42CF463CC84A3C
B74837AC4B3AC57260AC6352A05B4BA461519B59499F5E4CA46651B1735E9F5E4AA96854
A3614BB1705CAC6D5B995E4E774336603129966D67AF8A84AF8986B6908FCAA0A4895C63
673C4360373B664242C19F9DC1A09BC09D97C29995DDABAAB2757477312F944A4797524D
8D544D6839316B443DB0928AAC8F87AB8E86AE8D86C39A949F69676622218E3A389C3F3A
9C3B329D402F98442A863E1886511DA1793B8E732C8A7830807533968D549B9468A8A383
89867316140817140D29262125221D25221D26221F24211C21201B33322D3E3D3921201C
1C1B1712110C27241D57524C433F361F1A14211E1724211C26231E221F1A1E1B142D2A23
45453D22231D22231E1D1D1B1B1D1A17191668686600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FEDBD7A45F58BA4941D2483ED9473ADC4638DF4539DE4438
DB4335E0483BE1493CE1493EE2483CDE4639DE463BDE463BDF473ADD4538DD4337D93F33
DB4135DF4539DB4137DA4036DB4135D93F33DD4337D93F33DC4335E1483AE85042E95143
E85243EE5B4BE85649E9594EE95D50EE6459EA6459E46157E15E56D34F4ACF4E48CC4B46
C2423FBE3E3BC44443D95757D75253DA5050E15150E34F4BE74F4ADE4942D7493FC94739
B74636AC4B3AC87565B86F60A15C4D9B594B854335884638935143A56355955345975547
955647985A4D885043B17F745A2E257E5750B8938DAD8A86B28C8BB99192AD8085693C43
70464A50292C866262AB8987A88782B08B85BB8B8BD096958E46478333329E4D4A9D524D
91544F5F2E27916A63C2A19AB99C94BA9D95BF9E97CEA7A2794645713433934747994844
9A483D9548368F472F804422916234A8854D977D408F7D3F8C7F489C9463A19972ACA789
9996831F1D1113100928252027241F26231E27232021201C25241F23221D33322E393836
1918140B0A05312E274C494249453C1F1B121D1A13211E17221F1A1E1B161D1A133A3A32
3E3F3721221C21221D1B1B1919191713131130302EBABAB800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF7F5DFAAA49F483FC44B40D64A3DD84637DD4738DF4539E3493D
E95144E85043E3493DDC4236E2463ADE4438E0463AE2483CDE4438E3493DE4483CE2483C
E04739DF4739E2483CDE4438E1473BDF4539DF4638DE4537E04737E14838E64D3DE64F3E
EB5544ED5746F15E4EED5B4CED5B4CEE5C4DEB5C4EEE6052ED5F51ED6154EE6157F3665D
EC615ADE554FE55E5BF66E6EF16767E55658EB5757EB5350E54D48E04B44D44439CA4639
B74636AB4C3AAE614FA36250995E4C9C65519A634F9F6756955D4E9961549860539B6559
9561548E5E527F534AA67E7663403AA98883C19F9DBB9997C6A09FD8B0B18D636763393D
623B3C563433B49592B69794B79691B8908ECD9797BB76797E2D2C9B43429F4A479B504B
7E433D62332BAB867EB08F86B0928AB4968EBE9D98A8827F6D3F3F875453905654915650
965C51925A4B8F5C4983573C9672509D8058947D51917E538F82589C936CAAA18298927A
B6B3A2413F330C0B0623221E28272324231F24231F22211D2524201F201B22222033342F
34332E24241C2F2C2535322B3C3930221F161E1B1217140B19191120201832312C3B3C36
2728221F201A201F1B21201C1C1B171A19151716122C2D28858583A4A6A3D1D3D0EBEDEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF0ECB9766EAA453BCE5044D44638DC483ADA4435E85043F0584B
EA5245E44C3FDB4336DE4639E0483BE1493CE24C3EDE483AE34B40E1493CE0483DE34B3E
DF493BE14B3DE0483DE34B40E1493EE1493CE1493BDF4837E34C39E14C38E24F3BDE4E36
DE5136E85C41EE6249EE6249EC6047EA5E45EE624BE95E47EE624BEB5E4AEB5E4CEC5F4E
EB5C4EE95B4FEB5E55F96B67FA6B67EB5A57ED5854EB534EE74E48DD463FD44137CB4539
BD4A38AF4E3B8A3C268F4E38894F378B553D834F378A583F8E5C458757418556428A5D4A
8F66548B665484635487675C6C4F47B29591BFA09DC09E9CCDA6A7C9A1A2683F456D4649
4E2C2B896A67C6A9A5BC9D9ABD9B99CB9F9EE5A9AB974C50832B2AA64B4AA14B4A9B514E
5D2621865B54BD9890B19089B89790B89591CCA4A27C525367373782504F65322F703D39
68382E75473A693F2F623C297250375B3D21684D2F58412279664887785B7F7359948C77
BAB5A299978A1C1C1416151022211D25242027262221201C22211D1D1C1822211F282723
28272233332B3A37323C393239362F312E25312E2527271D33332B3837323A3B35262721
22231E1F201B22211D2625231D1C1A201F1B1716141313115F5F5D6163606C6E69858681
A3A49FC9CAC5E7E7E500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00EECDC8A05248BF5045D14D41D94A3CDB4739E44E40EB5547ED5749
E54F41DD493BDE4A3CE14F40DB4C3EDA4B3DDD4E40DC4D3FE14E44E35144DE4B41DE4C3F
E04E41E04E41E14D43DF4B41E14A41DD463BE04A3CE04A39DF4E39E0543BD44D2FCD4D2A
CF512BD1562DDC6138E1653FE86C46E46844DF6341E06442E16241E56444E76446EE664C
EC614AEC5F4BEE5F4FF26355FA675DE9564CE8514AE75049E14A41DD463DD6433BCD4539
C74D3EAC45328A341DAC6247AF6C4FA96C4D8C543395603E8C5A3981533181563485613F
7F5E3D674D2C6F5638725A42593F309E8277C3A29DC4A19FD9B2B39F7778633C41633F43
4E2E2FB69896C2A4A2BE9F9CC29C9BD8A6A7D08E907C2C2F95393AAB4D4DA25150823E3B
5B2824AF8682BE9B97B69590BC9995C9A09EC191915C282A763B3DAA706E8C524E97605B
9E6C659869618E6257865C508D66577F5A4894715D664631846853A2897375634DA89C86
B7B09DCDCAB98583771C1C141516101F201B29282425242025211E25221D211D1A1D1C17
1F1E1A2625202C2B272F2E2931302B32322A32322A34342C34332E2B2C2626272221221D
1F1F1D1A1A182624252624251B1B1B20201E1515151313116E6E6C6F706B6B6C6677776F
77776F75776C7E7F77999C93BCBDB7E1E2DCF5F6F100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FFF7F5C1948F9B4339C84F44D1493DD7483AE24E40EC5647EF594AE85244
E24E40E65445E05141DC5041D54C3CE1594BEB6154E85C4FEB5D51ED5F53E85A4EE4564A
E6584CE5574BE5554CE5554CE45449E35046E65447DF503FE45944D85539DE6342E7734C
D56639D96D3ED5693AD86C3EE27648E4774CE07348D86B40EC7D50D7633AE16B43E76D48
E76646E86245DF573DE45942E25541DE4F3EE14F40DF4B3FE34C41DD463DDC483ED2453B
CC4C3FC04C3DAD4834CC7258C06C50BC7050AE6544AB69469B5F3BA16B45986842906942
8D6D477F6540836C4C806B5069503C94766BCAA7A3CCA5A6D7AFB0734A4E6F484D502D31
7A5C5CCCAEACBFA19FC5A3A2CAA2A2E0AEAFA66468752629A54C4EA650519F5554612524
805350CBA5A2B99795BE9B99C29997D9A9A99C61656624268E4848C27B79B26F69BB7A74
AB706AA56C65A26B64B58078BD8880B17F74AF7D729C6E5FA98271A3826F937A66B2A18D
B6AE99D1CEBBE2E0D366665E1415101515131D1C1A2625232C28252D2A2526231E1F1C17
1D1C1822211D26252122211D26252024251F25251D23231B1F201A21221D25252321211F
1D1D1B1919171F1D20211F221D1D1F2626281212141F1F218787877A7A7871706B808076
84847876766A74766977796E727469777870909189B4B5AFD7D8D3EEEEEC00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FCE0DD9C635CA44237CD4F41D2483BDA4839E6503FF15A49EB5544E65041
E95646E65747E25645E96453FA786AFC7D6EFC786BF0685AEE6457F26657F4685BF3675A
F56B60F2685DF3665CF2655BF1645AEE6157EE6255E96050E5604DD2563EE17052F98E6A
DA754BF49265F39164ED8C5FF19264EC905FF59968F39562F69864DC7C49E5814FDE7546
E5764BE5714AD55D38D85C3AD25332D65337D74C35E25140E14B3DE34C41E04C42D8483F
D54B41D65447DA5F50D5624FCC5F4ACC664DCA684DC76C51CB7A5DC37C5EAB6E4FAD7A5B
A9826387684B9E8368987E678366569F7F74CDA7A4DEB6B7BB919562373E6F484D522E32
AF8F90CCAEACC5A7A5C7A8A5D6AFB0D4A3A67B3E438A4347A15559A0585B894D4D562624
AD8784CBA9A7BF9D9BC49E9DD1A0A3D89DA17B3239873539A34D4CC8706CB05D55BD6F65
A55B529A514A9C564EB8726AC68078A25E55A25E55995B50905B4B8D6251A3826FBEA996
B9AE9ACBC6B3F3F1E4AEAEA631312F454547282629171518201F1D322E2B332F2C2D2926
27232027232024201D231F1C22211C1F1E1924251D23241C1B1C161D1E19222220222220
1E1E1C1E1E1C1F1D202220231F1F211F20240D0E135B5C61A2A1A67C7C7C7A797486867C
8A8A7E8182748384768082757E80737A7C6F75776A7173686B6D6286877FA2A39BC7C8C2
E5E6E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00E4C1BD8A473FB1493ECF4D40D84A3CDA4737EE5847F05946E95342E54F3E
EA5747E65746E15544F26D5CFB7969F07162F97568EC6758EE6656EB6252F3675AF3675A
EE6459F46A5FF3665CF66A5DF46A5FF46A5DF2685BF36B5DF36E5DEF715BEA765DF68769
E87D59F48C65FA926BF79169FC9B71F49569FC9D71F99A6CEA8E5DED8F5CEA8A58EB8756
F98E62ED7E53E7734CF9835DEA724FFD8060E9634AD64834E24E40E34C41E04C42DF4C42
DC4C43E3564CDD5348DF5A4BE05E4ED45A45D45D47CE6049CE6A52C97159C0765DAF735B
87574198725DC8A592C0A091B39187B48F89D6AEAFE8BBC093646C71444B663D436E4A4C
D2B0B1CEB0AEC8ABA7CCAFABD9B7B6BD9395562427743C3F884D4F854F4F603232613B38
CAABA8C6A9A5C2A09FCBA1A3E7B0B5BD777F772229A14246AF4D4AA7463F993F369E473E
A7544CA4544BA75750A95A53A859529D4E47AC5D56A25950A2635493604FA6816FC4AA99
BAAD9AC3BDADE6E2D7E4E3DE3C3A3B3F3E435B585F58555C3C3A3D1A1917181715272322
302C2B403C3B29232328242127262223221D23241E23241F1A1A181C1C1A222222242424
2121212121232422272221261213180C0C140F0F1783838BABAAB0838383807F7A8C8C82
8C8C808B8C7E88887C898B7E888A7D8A8C7F888A7D83857877796C797B7075776C6F7166
7B7C74989993BABBB6DEDFDAF5F5F300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00DAB1AB8F463DBC4D42D44E42D94A3CE65041EF5948EF5948E74F41E54F40
F15B4CE85545EA5B4AED604FED6454E75F4FE96151EA6252E86050EC6353F06455F16558
F1645AF5675DF6665BF06153F36559F26456EF6354EF6354EE6253F16A57EC6754EE6D57
EB6D54E66A4EEE7256EB7255EE7759EB7859ED7A5BF0825FF0865FFF9870FF956EED8059
F4825DED7753EA7250EF7455EA6E52FF8468F46D57D94C3AE35142DE4A3EDF4B41E24E44
DC493FDE4E43E15146DC4D3FE35645DE5241DB5441D95A47CF5C49CB6654BC6957A66152
72392EBB8C84D6ADA7D0A9A4C8A0A0CBA1A3E4B7BEDCAAB378445083515C5F343BA57E81
DCBCBDD2B4B2CCB3AFCDB4B0D5B7B5C8A9A7866262734F4F734D4C674442674845AB8F8B
CCB3AFC7ABA8CDA9ABDAABB1ECADB69747528E2F35B54E51AF4945A6433DB3564EB45B53
B56059A4514BAE5D59994844B86861AF5F58AA5A539F524A995548793F31946958CBAE9C
BEAD9BC2BBABD8D1C7F4F1EC7F7D801E1B223D3A4559565F615F64838184575558262425
2725262422231511122521202D2C2A2928262323212426252021231E1F2128292D292A2E
1B1C2018191E21202815131E30303C4D4F5B23232F666670B1B0B68B8B8B8988838A8A80
8E8E8291938690928781847964675E7E7F7783837B85857D7A7A728B8B818C8C82838377
8183787A7C716E6F67707169878882A8A9A4D2D2D0F0F0EE00FF0000FF0000FF0000FF00
00FF0000FF00
00FF00FFF9F3D1A59C96483CC05044D24C40DB4C3EE75143F25C4DEA5443E54D3FEB5345
EB5546ED5748EC5949F36152E85B4AEC604FEE6555E75F4FE25A4ADA5244E1594BE1574A
E1574CE95D50EA5C50EE6052EF6153EE6253F06455EE6253F16556F06455F16556F36756
EE6552F06955EF6653EF6854EC6853E96751E76650E46850E16A4CE26D4CEC7555EB7253
EA6F50EF7256EF6F54EB6B52E86A53EC6B55ED6653E45B49E95B4DE15146E5554AE25247
DF4F44E15146DF4D40E14F42E24E40E14F40E25345D95040D65748CD5C4CC964589F483F
904540E6A5A3EAAEAEE5AAAEE8ADB3EEB3B9FEBFC8C5838D7F3B468F4D576D343BDAA7AC
EDC1C2E1B9B9E2BCBBDEBABADCB8B8D9B5B5CEAAAACEACABC8A6A5C1A2A0C9ABA9D2B4B2
D3B5B3D4B2B3D9AFB3F3BAC3E294A1862934B4474DBE4C4CBF524DC45C53C5625CCB6C66
C26762AA514BBD6561B35E59BE6964B9645DD27E74B06154AC6354834633A57861CFB199
C4B29CC4BCA9CAC4B8E6E3DECAC8C92B282F36333E413E493E3B44B0ADB4D3D2D76C6C6E
7472754D4B4E5856574442433636361C1D1F23262B24292F1F232C1D212A1E212A191C25
2D2D3712121C201F2D21202E373946555764595B6873737DA9A8AD908F8D928F888F8D81
9192849193869B9D927B7E7540433C5B5C565B5A554E4D484F4E4957574F606056727268
83857A797B708183787C7E7372736B696A6261605C7776728D8C88CECDC900FF0000FF00
00FF0000FF00
00FF00FFF7F2C9998FA04E42C05042D24D3EDB4C3EEF5B4DEE5849EB5546E54D3FEF5749
EC5648EE584AF55F51EE5A4CE75848ED604FF56C5CFE7668F87465F77366F57164F26E61
EE6A5DE56152E76253E96153E25A4CE25A4EE45C50E75F53E95F52ED6152ED6152EE6251
EE6553ED6452F26655F16554F26655F26957EF6654F36C58EC6851EC6851EA664FEB6750
E96550E8644FF06C57F06C57EE6956EE6958F0685AF76F61F46C5EF3695CF06457EC6053
E65A4DE25649E6584CE15146E04D43E24F45E04D43E05246D85042D85649D25950B3433F
A94140B65658B75B60B85D64BC626BC76D76D27780AA4D57A0434BAE535A87353BD2858B
EBA4AAE7A6ACE7AAAFE9AEB4EBB2B8ECB5BAEAB6BAF0BEC1EABCBEEBBFC0EBC1C2E8BEC0
E9BCC1EBBAC0F0B7C0FFB9C4BC5F6A9B2C35CA4F52CC4F4DC94F4AC44F48D96965DA716D
CD6763B1504AC66763CD7069BF655DC1695FEE9688B1604BB3694E925634B78B66CFB18D
CDBD9CCBC4A8C3BDADD3D0C7EAEAE85A595E2E2D353E3C4733313C78777FEDECF25E5D62
383639484649BBB9BABBBBBD5D5E63565A63555B69484F61464E61424A5D21283A2C2F40
A6A8B72D2F3C2C2D3F3031433235442125313133405656609D9D9FA1A09C97948D979589
9495879395889EA0957C7D75555650767570706F6B4C4B474E4F4A4F504A2526205D5E56
484941393B307E807584867B7D7F747F7F777F7C757974704C4741524F4AE4E3E100FF00
00FF0000FF00
00FF00FFF5F1C18B81A75144C55144D24D3EE35446EF5B4DF05A4BE65041EA5445EE5849
ED5749F15B4DF35C51F15A4FEE5C4DEF6050EB5F50ED6356EF6A5BEB6758EF6B5EF36F62
F27060F57461F47360F67562F57260F16D5EF47061F16C5DEC6454E86050ED6452EA614F
E85F4DE75E4CE95D4EE95D4EE75B4CEA5E4DED6150F36756F26754F26754F16653F26655
F26655F36A58F36A58F76E5CF26959F16959F2685BF46C60F56D61F1695DF2685BF46A5D
EF6558F46A5DEE6457F4685BED5F55E85A50E6584EE15349E2544ADB5146D9534ACD4C47
C94D4BC24B4DBD4A4FBE4F55BA4D52B3464CAF4047AD3E44BF5154C85B5EB24B4EAA4A4C
AA4E53AA5359B25D64B05F65AF6066B3666CBA6F74BE767AC47F82CC8A8CD39193D69599
DD9AA1EAA3ABF1A1ACD1767F9F3037C24549D24D4ED24B47D8554DC3443DCF544FD25C58
D3605BCC5D56E27570DA7269D67165D17260D17A5FB56540C37F50925B25A98048CAAF7A
D6C89BD4CEAACFCDB6CCCCC0E7E8E38E8F9124232B4947523C3A4746444FDCDBE1B0AEB3
5C5A5D4F4D509F9D9EEBEBED6D6E73262A3321273720283B253044343F553A4058373C52
BFC2D33D405125263A292C3F9FA5B56A6D7C191B28292933706E71B3AFACA6A39CA19F93
9E9E92A2A296ABADA272736B61605B878681807F7B8485808A8B868C8D8876777182837D
55544F4F50488989818C8C8484847C807D76827974857A767C716B3D342FC3BEBB00FF00
00FF0000FF00
00FF00FFF5EFB97D73AC4E42CC5446D74D40E75548F25C4EE85243E75142ED5748E95646
EE5A4CF35D4FF35C51ED564BF35D4FF35F51ED5E4EEF6251EE6251EF6654E96151E96453
E76450E3624DE86751E4664FEB6A54E86751EE6D57EE6D57EF6D57F2705AF16D58F36F5A
F26D5AF26D5AF06858ED6454E96050E55C4CE55C4CE55C4AE45847EA5D4CE95B4DEA5C4E
EF6153EC6051F16554F26655F46857F36A5AF5695CF06659EF6558F3675AF26659F4685B
F1675AF66C5FF46B5BF1695BF06A5EEC665AEC6359E75F53E05349E6584EE15349E1544B
DD5650D95853DA5E5CDB6362D86464D46060D35D5DD25C5CD1595AD25C5ACF5B5BC95756
C45655C25656C3595BBA5052B44C4DB74F50B44D4EAC4848AD494BAF4D4EAD4A4DAC494E
AE494FAD454CB2434AAF383EC13F41D64E4ED84D48D84B44D94F45D64D45D24B45D5504B
D7544CDA5A51E2665CE26A5CDB6B57D16A4BC26A3CBF7538A66C23805506B39442C0AD61
DAD093DDD9ACD7D6BAD0D2C4E0E2DDBFC3C427272F54525F4B495735313FABA8AFF0EBF1
E3DEE2D6D2D3CCC7CBEBE9ECDAD9DE888B9060646D444A562831421E263D3D425F4E526D
A7ACBF70768615182B262B3E8B91A1787B8A1A1C2925252F38363B928E8DB0ADA8A6A39A
A5A59BA4A69BA9ABA072736B77787262635D6465606A6A686667627475708988849B9A96
9A969383827D8A8782999691999490988E8C988888927E7D998481614E4A988D8B00FF00
00FF0000FF00
00FF00FFEEEAB26F67B55046CD4F43DE5245EE5A4EEF594BE85244E54F40F05D4DEA5747
EF5B4DF66254ED564BF35D4FF05C4EF26150F16251EE614FEC644EEB644EE8664EE7674E
E76B4FE0694BE06B4ADD6B49E06E4CDD6B49E16E4FDE6B4CE16B4FE1694EE66D52E5694F
E66A52E96B55EE6D5AF26D5CF36B5DF66E5EFA7161F46B5BF46756F36655F06254EA5C4E
E95B4DEA5C4EE55847EB5F4EE35746E75B4CEA5E51E85C4FEB5F52EB5F52EC6053EF6356
EE6459EE665AED6859EE6A5DE66659E9695CFB796CF77166ED6056EB5B50E9564CE35348
DC5248DA574FDB625AE1706ADD706BDD716EDF726FDB6E6BDD6D6BDA6867D96663DB6865
D96864D96965D76765D56362D36160D2605FD56561D0605ED0605ECF5F5ED05D60CB585B
C95558C85153C94C50D45254D95350D64D47DA4F48D64C42DB5147D3493FDD5049DF5249
DC4F45DD5348DA5246DB5949D25A42C85E37B55C24CF8B40D5A448BF9D3BC7AF4BC2B356
D8D087E2DFAADEDDBED9DACADCDDD8E8E9EB515159363441555361484452807D86F2F0F5
F3EEF29994986D686CB2ADB1EEECEFE5E6EADFE2E7D5D9E2CFD5E3596073313550545571
84879ACCCFDE434655181B2A23273325273319192521202819171C64605FB9B5B2ACA9A2
AAAAA2A8AA9FA9AAA283847C74736E6667618F8E8A72736E50514C51504C5756526B6764
74706D5C5855696562A098969A8E8EAB9798B99B9DBF9B9DCEA8A7A684827B635FF9EBE8
00FF0000FF00
00FF00FEE5E0AF665FB84D43D24F45E5554AF15D51EF574AE24C3EEF594BEC584AED594B
F36251F05F4EEF5B4DF15F50ED5E4DEF624EEA624CEA664DE7674AE16849E26D4ADF724B
E0764CDA7549DD7D4DDA7B4BD67A49D37748D97C51DA7A52DA7853DC7854DE7555DE7353
E17256DF6D52E46C54E56751E86553ED6555EE6555F46857EF6251F36454F56857F7695B
F66A5BF36758F36756F16554F26657F26959EC6255EC6255EA6053E55B4EE55B50E75F53
E55F54DF5B4FE36358E36559DE6459E1675CFA7A71F26D64F0665BED5D52EC5A4DE25446
D65245CF594BB95146AD5048B35E59B4635FB5615FBD6766C56B6ACA6C6CCD6B6AD67270
DE7874DB7571E07A76DE7673E07974DC7570DD7470DA716DD86C69DA6D6ADB6B6ADB6968
DC6868DC6664DE6463DC605EDC5D57D95852DC5C53D9564CD8534ADD574EDD524BE05349
E05045DF5143E05447DB5643D3573DCA5E37AF591ECC8A3CE9BD5ADABE50D4C252D1C65D
D9D37FE8E4A7E8E5C2E1E0CEE0DFDAF4F4F69A99A1201E2B454351555361595762DDDCE2
D8D6DB57555A656368838186EBEBEDEDEDEFE6E7EBE3E6EBF5F9FF979AA9232439484860
69687AE7E6F4C8C6D18281895A595F4443482A292E1A181D29272892918FBEBAB7B3B0AB
B0B0A8AEAEA6ABABA3A8A8A0A29F989E9E96ABA8A1A0A09896968E8F8E89807F7B61605C
4E4D484D4C475E59569D91919E8588AB878BDBA6ACEFB3B5F6B9B8C38C89714842E7CEC9
00FF0000FF00
00FF00F8DCD8AE635DC05148D65148E5554AF25E54E85146E65042EF594BEA5648EF5B4D
F36251EC5D4CEB5C4CF06351EC644EE6644AE56A4BE16C49DE724CD8754CD2754CD27B50
CF7E51CC7F51C87E4FD18959CA8355C27E51C67E56C67D5AC77C5CC67758C87458C77156
CB7159CB6C56CF6855DE6F5CE56D5CE86958E96453EB6451F06552ED604EF16453F16453
EF6153EE6253EF6352F26655F06455F26657F4685BF5695CF86C5FF46A5DF46A5FF36D61
EC6A5DE4685EE06B61DD6D62C4584EB7483FD7605AEA6B64ED675EE95C52EC5D4FE55C4C
D95A4BCF604F8F33247226197131286C312D6A2E2D7032337A38397A34348A403F924442
9B4C489F504CA04F4CA95854B05D57B4615BBE6964C46C68CA716DCF746FD27371D16F6C
DA7772DF7975DC7370DE726FDA6F69DD7069E3746DDD6C64DF6862E46761E96560E75E56
E05349E25649DB5144DA5848D35C44CE6842BD6C37BA7B34EEC367E3C85FD7C559D8CC68
E0D988D1CD90D7D3B0E0DDCEE1E0DCF0EFF4DEDCE7403E4B3330414744554D4957B7B4BD
D8D5DC3F3D4238333A8E898FF2F0F3EAE8EBE6E6E8E2E3E5EEF1F6C5C8D127283A403E54
454255BFBDCBE9E6EFD5D3D6C8C6C7BBB9BAAAA8AB989697A8A7A5C2C1BFBFBBB8BBB7B4
B4B3AEB7B6B1B6B3AEB3B0ABB1AEA7AEABA4AAA7A0A8A59EA9A9A1A6A69EA8A7A29C9B97
91908B8887827D7573978486AA878DB68189CC838AD88388CE7879AB5D598A4F49CEA9A1
00FF0000FF00
00FF00F1D4D0AA5D55C25348D75249E7574CF25E54E85448E85446EB5749EF5B4DF15D4F
F46253E65948ED6451E46049E66A4EDC6A46DD7349D8794BCC7A4AC88251C18458BE8760
C18F6CC08F6FC29473C49577CD9E82DAAC92E4B49EE3B39FDBAA99E7B3A5EAB1A6ECB0A6
EDADA4EFABA2E79E97D58176CD6959DF705DEA715CE96B54E7634CED654FF06351F06352
F16453EC5F4EF16355EF6052F26355F16254F16355F16355EF6153EF6354EE6255EA6458
E4695ADD6D61D57368CB7169A24B447C211E9B3332C75353E76862ED645CE95C52E86054
E16354CC6151822F1F5A1B0C56261C4C251E4A27254A26264F2829542A2C5A2C2E5E2E2E
5A2A285F2F2B61302C612E2B6B383464312D743F39733C37763B377D403B82413F823E3B
8E4745944A47984D4A994B47994B47A2534FAF5B59B05655B65755C75E5BD35D5BDB5B58
D6514CD6514AD05148CA5446C55C49C66C51BF754EB07440E1B671E7C876DDC771D9CA77
F0E7A2B1AB797E7A5F88867A969696ACACB4BFBFCB5655653D3C4E423F52453E508B8593
F5EFF9BBB6BDA69FA6E2DBE2F1EBEFEBE6EAE6E4E5E1E1E3E7E8ECE5E8EF41435228293D
2B293E797687E9E6EFD9D4D8D1CFD0D3D2D0CBC9CACCCACBCCCBC9CAC9C7C8C4C3C9C5C2
C3BFBCC2BEBBC0BCB9BDB9B6BAB7B2B8B5B0B3B0ABB4B1AAB1AEA7ADAAA3ACA9A4A3A29D
ADACA7B5B2ADB8AEADB89FA2B58A91CA8991AB5059B74E55C35757BE5D57A75D54B08179
FFF2ED00FF00
00FF00E7C8C5A3544DC35348DB574BEA5A4FEE5C4FE85446EE5A4CEB5749F05E4FEF604F
EA5F4CE7604AE7674EE06949DC7147D47442D17F47D08A4FC99158BF915FD3AD86E7C5A9
E8C9B4E6C9B7EACDBFEFD2C4EFD1C6D2B4A9C5A79FC2A39EF2D3D0BFA09EAF8B8DB1888C
B2888CAD7F82CE9A9CFDC0BBDC8F7FCA6E57E1785BE67354EA7152E8684BEC654FED624F
F26655F06352EF6153F26355F16254F16254F26355EE5F51F26456ED6152EF6558E76557
E06C5DDF7A6EA35146D18D8494534F5D17156716158F2D2EC65453E66965E8615BE55F56
E16355D9695B9D4434611E0E48180C411F163A211C372221351F213B25273A2222402627
4026254229254A2C2A452725503230492C2850312C4B2A254F2C284F2926552C2A592D2C
5D302D5F2F2D62312D67363263302D67312F662C2B723232772B2D893032932B2CC14D4D
CB4F4DC94E49BF4C45BF594DB55D4F934A377A3E246F411D886434846A317D692C807136
8B835279755058554255544F56555A5C5C665756643D3C4C3F3E503E3C51413E515D596A
A8A4B2ACA9B4C3BDC9D4CED8DFD7E2E6DFE7E7E2E8E4E2E7E1E2E6F1F4F9848692111320
14132142404DD7D4DBE1DFE2D8D6D7D7D6D4D5D3D4D4D2D3D3D2D0D4D3D1D5D1D0D2CECD
D0CCCBCFCBC8CDC9C8CAC6C5C6C2BFC5C1BEC4C0BDBFBCB7BDBAB5BAB7B2B6B3AEAEABA6
B1B0ACBBB6B3C5B9B9CDB4B7C99AA2D48D95B34F59B23F46C85052C15451B05C52915B4F
EED9D400FF00
00FF00E3C2BDA3534AC35146DC564AED5E50EA5849E55242EB5A49F46352EE5F4EE9614B
E56349DE6546DE6E48D57140D68045D28945CE9249CE9E56C9A567DABF90F0DBBEDFCCBD
BEADA6B3A19FF0DDDFDBC7C9907C7E6F595C5843486D585FD5C1CA6B576268525F6A5262
6C505F6747545E3940C49895FAC2B1C27D5ED07B52DB7A4DE0764CE7764EEA6F4EE7654B
EC6551EB624FF16453F16453F16453F16453F06352F06352ED604FF26657EC6758E36859
E2786AC66E6279362D89574EA47973A67974703634631C1A842928C35554E46866E76660
E46157E1675ACE6353933A2A5F1D0F4315083A1C14301D172E1E1E2D21212D1F1F2E2020
2B1D1D2E201F39272733211F463432392723402F283A27214B36313924213A25223B2623
402826422A28402723482C29402423482A2A442221512728511A1D611B1D691012B34B4C
CA5A58C95955CB6560BB645B9B584F5F2E20441F0F452A154731194435163F35123A3414
3433172A2B193C3C3440404044454A45454F3A39472F2E3E3130423132463A3C5146495C
5455674D4E60535166615F7474718284808F9B95A1DBD8E1E1E0E5E7E8ECC8C9CE7E7F84
65646A545358B8B8BAE5E5E5DBDBDBDBDBDBDADADADADADAD9D9D9D6D6D6D7D5D6D7D6D4
D6D5D3D4D3D1D4D2D3D2D1CFCECDCBCDCCCACBCAC8C9C8C6C5C4C2C5C4C0C2C1BDBCBBB7
ABAAA8A8A4A3B8AEAFC1ABAEC499A2DD9AA3B2535BA33238C24A4CC65652B75D5483473C
CAB1AA00FF00
00FF00E1BEBAA7544CC45247DF594DED5E4EEA5849E04F3EE65746EA5D49E65F49DF5F42
DB6442DB7046CF6F3CD27E40D18941D19646D7A858DBB76DCDB579E7D8AFD8CBB8E3D8D4
C6BBBFBCB2BAE8DCE68175816759665D4F5C392C36B3A5B2988C9A574A5B56495B4E3F54
564359675062452A33957270FFDAC5DCA47FD48E5BD28149DA7F48DE7A48E7784DEC7451
E9694CEB644EED624FF16453F06352F06352F36655EF6251F26554EE6555EA6858E26E5F
D9796BA2584B6430254F2A2272554FB59892B6918B6C393657110F862E2CC35B5ADF6967
E36660E0645ADB6559CB6153913E2E5B1C0D3F130832170E2C1A16271D1B271F1D261D1E
241B1C261D1E312726291F1E3A302F2E2422352C273229243A2F2B3025212E2422342A28
332927372D2B3628272F21202E201F423232352122472A2C4117195C1E21640F12AD4949
CA5A58CC5C58C8655FB161588E554C48231A30180E30221731271B362E21322C1E2C2A1D
2D2D231F201A2929272B2C2E32313735343C36343F2C2A372C2B392A2C392124331A1D2C
2326353235443437483C3D51474658484556464250BCB9C2E6E5EADADADCDDDDDFDBDBDB
DADADAD1D1D1D5D5D5DEDEDEDDDDDDDEDEDEDEDEDEDDDDDDDEDEDEDBDBDBDCDADBDDDBDC
DDDCDADCDBD9DCDADBDBD9DAD8D8D6D6D6D4D7D5D6D4D2D3CFCFCDCFCFCDCFCECCCBCAC8
B7B6B4A09C9BA69DA0AD9A9EC5A0A7E5A8B0BA5F689A2B32C54D4FC65551B85C5188483C
A0857CFFF8EF
00FF00E1BAB5AA574FC7554AE25C50F16252E75546E45544E65B46E35F48DE6143D3613C
E77E4FD77A41D48341CD8539D1933EE2AE58EDC06FD7B470D5BF8DE0D1B2CDC1B5E1D8D9
BCB6BAE8E1E9C0B8C5645C6B5C5461423745706671D4CAD56E6373453C4D5F5667706478
4739506350633B212CB18E8AFFD3BCECB58CF7BA81E7A261D18440D37E3DE08046E67A4B
ED7751E76848ED654FEF6250EF6251F06151F26355F16355ED6150EA6554E26958E37969
C473626F342653281F4A2D2544302959443F9F8681BF9E996E3E3A521512823432B45656
D76A67DD6763E36861DB655BCB6153984032601E103D110630150E291A15271D1B241C1A
292323241E1E29232325201D3C34322A221F352D2A2D26202B241E2A231D362E2B2F2725
322D2928231F271D1B2E2422251B19352A283123223D2427370D1158171B6A1012B54947
D55B56CB5249C05649B4615390584B3F1D132A1710261D1626211B27241F24231E1F1E19
2626241F1F1D1C1C1A1E1E1E211F222321262C272D2621282522291411183F3E43636267
4A4B4F363A3D1E23271F222B2424301D1B281D1A2584818AE9E8EDDBDBDDDAD8D9DBD9DA
DDDBDCE0DFDDE2E0E1E1DFE0E1E1E1E1E1E1E1E1E1DEDEDEDEDEDCE0E0DEE0E0E0E0E0E0
E2E2E2E3E3E3DFDFDFE0E0E0DFDFDFDFDFDFDEDEDEDDDDDDDCDCDCDBDBDBDCDCDCD9D9D9
D3D3D3C9C7C8C5BFC1D2C2C5E2C5CAF6C3CABE6B7391282DC34C4EC4534DBC5E548D4B3F
8C7065FFF6EC
00FF00DDB4B0AC584ECC574DE35D51ED604FE45545E15442E4604BDF634BDA6B4DD26F46
E18755DE8E4FD68E44D99846E5AC55F2C06BE2B86EA8884DDBC59EDBCFB9E3DAD5C1BBBF
CBC6CCEBE5EF777382524E5F413D4EA7A0B0F3EBFA958D9C453C4F3E3749D4CCE1D1C9DE
50445A4C3D50422B35E1BEBCCE9B88BC7D5AF2B07CFFBC7BF1AB63D98C44D6813EE08044
E27645EF7850E96849ED654DEF6250F26353F26355EE6052EF6654E56653DF6E5CD87B69
9E59495C2C1E45271C3D2922402E2A3E2F2A4C3935A9918DC4A5A0683F3B521A19772F30
AD5554CF6766E16B67DF665EDF695DCE64569F493A5F20113C11083017102D1B17261C1A
27221F262221221E1D272322332E2B26211E322D2925201C2A252126211D312C282A2521
2A2722282520221D1A352D2B2A221F342C29312525361D203B11155715196F1014C24E4E
D4554ED15347C65849BB64539157493D1D1026150D211C181D1C181F1F1D1D1D1B1F1F1F
2020201A1A1A1B1A181F1B1A1D1918211D1C251F2121181B140E103E3838B0ACABDCD8D7
C7C7C5B8BAB7A2A6A59094957E7F8466656D4B484F646168DCDBE0DFDFE1E0DEE3DFDDE2
E2E0E3E6E4E7E5E3E6E3E1E2E1E1E1E1E1E1DFDFDFDDDDDDDFDFDDE2E2E0E2E2E2E1E1E1
E5E5E5E6E6E6E0E0E0E2E2E2E4E4E4E1E1E1E0E0E0E2E2E2E2E2E2DFDFDFDFDFE1DFDFE1
DFDFDFE0DEDFE1DBDDE6D7DAF0D7DDFFD7DEC87B83852227BC4849C04F4BBD5F55914F41
8D6F64FFF5EC
FFF7F4DAAFA9AD564CCC584BE76253EA5D4CE25544E45B49DE614DD96B52D07155C87450
D28857DA9659DC9C54EAAD5DF5BA6AE9B5699E7537BD9E70E6D5B9DDD3C7DFD6D7A7A0A7
EAE5ECBFBCC7595669504D62403D52948FA3AAA5B95850654840584F475FA39AB57C748C
50445A352738816B77F6D2D6AD7169B56854CE7A55E3905CFFB672F9B469DF9347D9873D
E28343E67B45ED734CEB684AEF674FEF6250EE6150F06455EB6353E46957DD7461C57461
79402F4C281A3C261B382922382A273527243D2E294E3B35937B77BEA29E8E686550201E
692929A35251CD6765DE6D69E26960DC685BD0695AA34D3E5D1F103C1206331811291A15
251B19231E1B272320282421302C29221E1B312D2A25221D2E2B262C2924322D292D2824
27241F2C292225201C312C2827221F372F2D25191B3A1F244114195A1319761316C54D4E
D8544FD25245CA5B4ABC63518C53423C1C0D23120A221D191D1D1B1618171A1A1A202020
1E1C1D1D1918211C191C17131F1A16241C191C1210251A18746A68CFC7C4DAD5D1D7D3D0
DBDAD6D8D8D6DBDBD9DCDCDCDDDDDFDEDCDFD3D1D4CBC9CCDEDDE2E1E0E6E5E2EDE7E3F1
D9D7E4BDBBC6B7B6BCD9D9DBE0E0E0DEDEDCDCDCDCDDDDDDDFDFDDDEDEDCDFDFDDDEDEDC
DEDEDEE0E0E0DFDFDDDFDFDDDFDFDDDEDEDCE0E0E0E0E0E0E0E0E0E0E0E0E1E1E1E0E0E0
DEDEE0DFDDDEE1DBDDE6DADCF2DBE1FDD4DAC17A82B25359B24143BE4E4ABC5B52975346
937368FFF4E9
FFF7F2D5AAA3A65247CD5C4CE56152E95D4CE25645DB5A47D86854CB6B55CB7B64DD987B
E1A37CE0A470E5A869F5B973F2B771B38041A07847E3C9A8DDCCBAE3DAD3C9C0C3CCC5CC
F9F4FB88828E4E495D504D624D485E5A55695C5469574F64544C64534B635D536C574D65
4237482F2130D1BDC8FFE0E7E9B1B2BE756EBC6A55BD6945D88F58FDB873FBB669DC9346
D58139E58344E77747F1754FE76448EB634DEF6352EE6555E86553DF6A58DB7A67AB6251
5E2F1F40231536251B31262031262231262440322F3D2E2942302C83706AC1A9A5987674
5427246D302F954441C5645EE06F67E16C62DE6D5FCC6657A14E3E62231445160C381710
2A120E2C1A163224212B201E332927271D1B362E2B2C24213029232D26203029232E2721
241F192E2923241F1B2D282429242130282627181B3E212543121860171E7A1317CC5251
D9544DD45245C85745BF67538A513E3D1D0E25140C211C181C1C1A1717171D1B1C201C1B
201B18231B18251A161D130A1D13071910014B3F33A99C93DCD2C9C5BEB88C8783B0ACA9
E2E1DDDDDCDADDDCDAE0DFDDE2E0E1E4E2E3E8E6E9E8E7ECE9E9F1E5E4F2D1CFE4A7A5BB
6E6C814F4E5E514F5AB1B0B5EFEFEFE2E2E2DEDEDEDDDDDDDEDEDCDFDFDDDFDFDDDFDFDD
DFDDDEDFDFDFDEDEDEDCDCDADBDBD9DBDBD9DDDDDDDADADADCDCDCDBDBDBDBDBDBDCDCDC
DCDCDEDDDBDCDFD9DBE3D7D9EED9DEF5CDD5CD878FDC7F87A33538BD4D4BBB5A519D574B
99776DFFF5EA
FFF8F2CFA79FA65448CA5A4CE56355E35B4BDD5847DD6453CC6657CA7769C17F73AF7567
D09881ECB491F8BB8CF8BC86D89C68A87546C7A582EFD9C4EBDAD2DCD1CFC4BABBE0D5D9
EEE5EA918790362D3E40374A443D4F484151463D4E443B4C443B4C43374B3F324436293A
3426338D7D87F8E3ECFDDFE7FFDCE4FDCBCED59691A35B4CB26845D38C58FCB877FBB76E
E1954ADC8540E67F45EC794CF07150EF6950ED6452ED6857E06351DE715DD47B69914E3D
5126163E241738271F2C211B2E25202F2523372E293D322C42352F473831705D57A68F89
8667646F43406B302C8F443EBE6058DC7167E37166DA685DCD6558A84C3F6F2115511108
3C09053B120E43211F361A173D25212E1B1533221B35261F32251F2D201A32251F362B27
281F1A332C2628201D362E2B261E1B3227252E1B1D4324294510185F12187D1418CE5250
DA544BD25042C75844BC6551874E3B3E1E11291810211C181D19181B1718231A1B231918
2A1C192B1C1528160C1F0E002B1D02706343CCC1A3C9BFA67973638F8B82AAA7A2D0CCCB
DFDEDCDEDDDBE1E0DEE3E2E0E7E5E6EAE8EBEAE9EFE1E1EDBEBFD38C8EA7606180565678
6667855E5E76343341747379F0F0F2E6E6E6E1E1E1DFDFDFE0E0DEE1E1DFE3E1E2E4E2E3
E9E4E8E8E6E7E4E2E3E3E1E2E2E2E2E2E2E2E1E3E2DEE0DFDFDFDFDDDDDDDEDEDEDDDDDD
DBDDDCDDDDDDE0DCDDE4D9DDEDDADEFCD4DCD8929ACB6E76A03235C0504EBB5A519B5549
9C7A70FFF3EB
FFF8F2CDA59DA6574ACD5F50E36556DE5B49DA5D4BD46554C26A5ECA847C9F686562312C
8C584DE3AC97F9BD9BDBA078B67F58B28663F2D3BEE6D4C8F1E3E0CABEC0E0D4D8B5A9AD
BFB2BBDED2DC817485605566514958534B5A5E5363625765675C6A655A686C5E6D817380
C3B3BDF5E4ECF9E4EDF9DFEAFBDDE9FFDBE6FFD0D6E2A8A6D69382B56C4BD6905CFFBC79
F9B469DE9046DF8342E87E4AED764EEB6C4CEA6651E76653E36B5ADD7663C1705F773C2C
4C2619422A1E3829222D241F2C24212D2522332C26362D28352A244237314435305A4942
6E59549A7D79A37A747E47408B4138B95F56D87067E5756ADD6B60D16356B853478F352A
6717105E1711662521511612541F1947160F4F231A471F17421D153A180F43201A43241F
371A143F231F3418154024213118143E22213B191A491C2154161B630E138B1A1CD65653
D94F45D65142C95643C469548745353F13082E110B2A15122812142C1316301413331612
381A123114042E1400523C159E8C5AB3A6719086558179529A967DDEDACEE4E1DCE3DFE0
E2DEDFE2E0E3E9E5E6EEEAEBE5E3E6CBCAD0A1A1AD696A7C464861464968595C7F6D7093
5B5C7A3E3C542C293A4E4B54E3E1E6E9E7EAE1E1E3E0E0E0E0E0E0DFDDDEDFDBDCE3DEE2
EAE4E8E7E2E6E6E2E3E1DFE0E1E1E1E2E2E2E1E3E2E0E2E1E2E2E2DFDFDFDFDFDFE0E0E0
DEE0DFDEDEDEDFDDDEE5DCDFEBDBDEFFDBE2C9868FC3666EAD3E44BC4A4ABD5A549D544B
9E7C73FFF3EB
FFF6EFC59D95A8594CCA5F4DE36856DD5E4BD35B4ACF695AB96D60B77E77C6989AB98F91
814F4ED29990F0B29DC08367946345CAA68CE3CDBFDFD2CCE7DBDBC4B7BEF2E2ECDCCCD6
DCCCD9F0E2F1E4D7E8D6CBDCC9C0D1C7BFCEC9BECEC8BDCBC1B6C4BFB5C0D2C4D1CEC1CB
C9B9C3C5B4BEC6B2BDB8A0ADBBA1AEB496A294737EEEC5CBEFB8B5AC6956BA6F48E3985F
FFBF78F2AD60E9974EE18144EA7C4BEC744FE8684DE66955DE6E5ADB7C68A75E4D622E20
4E2C203E2A213528203229243028252D28242C272129241E302923332C263E332F473A34
4C3D3865524C9E827EC7A29AA8736DA55E58B75E58D7726AE7786FDF6A60DA6659CF5E50
BC4C41A73B319B30288D261F88261D7B1D13721A0E6D190E6012065E140B5D140D5F1A13
55120C61221B50110C591C195217135B1F1E5416195E191C610F156E0B0E991E21DB5451
DC4D45D84E41D35848C861508F3D2F4E0B02450B09420F0E3F080B480D0F490C0B4B0F07
4B1302582A08926E34C6AB64B19E52887A31938A49CEC793E9E4C4E9E3D3E9E4E0E8E4E5
EAE5EBE7E2E8D6D1D8ACA9B077767E50505A4042513C3F5243485E4B4F6A656986686985
3F3D552E293D261F2F342C39C9C4CBF0EBEFE2E0E3E1E1E3E0DEE1DFDADEE6E0E4F0E9F0
AAA0A88D878BE9E5E6E5E3E4E0E0DEE0E0DEE1E1E1E1E1E1E1E1E1E0E0E0DFDFDFDFDFDF
DDDFDCDDDFDCDFDDDEE5DCDFEADBE0FFDFE6B87680BA5F68BB4951B94649BC5954A15851
9A786FFFF5EC
FFF6EFC19991AB5C4DCE6351E16654DA5D49D46450C46756C17D7292615DDDB4B89E767E
68353AD49A98DD9D93AB7060A17663EBD0BFCABBB4D5CBCAC4BBBED6CBD3EDDFEC9F91A0
9A8D9E988D9E8E8296898093847D8F867F917C75877E7787716B79716B7779717E7A707B
7A6E7A887A878C7C8987737F8C7683745E6A7D6773F6D8E0FFD8DAC88D85BB6F55C57749
F1AD6EFEBC72EEA459E58E49E68149EA794FEA7152E06850DD725ED47B69995A4B4C2013
452A1F3B2A22372C262F2822332B282E292527221C25201A2A251F2A251F342D2739302B
4439354A3C3955443D806762BC9590CE9794C57C76C86D68C9605AED7B71E47063D76153
D15B4DD15B4DD1584DCD5449C34A3FC14B3FB14032A6382B9E3427912B1F8F2A2089281F
7E20187E211A791F17741B156E17106D18136C14136F13146F0B0D770608A02021DC5250
DB4C44DD5144D25344CF5B4C9A34286A0D065E09065E0A08630B0A660C0B6D1009792012
7C2F15A06233E8BC73EED07AAB953F645502A49C54EEE7B0F3EDC9F1ECD9EDE8E4DFDADE
B7B2B98380895C566047444D46464E454851474B573F425344495C52576A5A5B6F3F3D52
322E3F2B24342D22322B202EA79DA6F4EFF5E3E1E4E0E0E2E2E0E3E3DEE2F5EFF3D4CBD0
261F262B2529D7D1D3F0ECEDE3E2E0E1E0DEE2E0E1E1DFE0E1E1E1E0E0E0E0E0E0DFE1E0
DEE0DFDDDFDEE0DEDFE2DCDEE9DADFFFDEE5BA7B84AF555FBE4F58B54247C05D58A25952
99776EFFF5EC
FFF4EFBB938BA65446D06553E16654D85E49D36652C06958BE7F76906360D8B1B68F666E
A67177CC9092C687829C665CD8B3AAE2CEC7DCD0D0CEC8CCB0ABB1F2ECF6B7AFBE635C6C
6B667A615E735C596E57556B5A586E5C5A705D5B71615F746263776364766B6A7C6F6C7D
6E6A797872807D72827B6F7D736670544750BDADB7FCE7EEFFDFE4EDBDBBBF7A6AC77B59
D89560FFC17FFCB86FF2A55FF19356F48859ED7857DC6A52D7725ED382719C64574E2920
39251C352A242E27212E2623332C262F28222E26232A25212C27232C27232D2522352D2A
3C3431413833463B37523F3B6B4C499F726FC88888ED9E9ACC6D67C05950E68072EF8B7B
E3826FD77461D06555CA5A4CCF5B4CD35D4FCF594BD35D4FD25C4ED35D4FD05A4ECB554B
C44F45BF4D43BC4A40B34338B14237A93A31A33631A1312D9F2C299C2221B63230D54E4A
D64D45D74F43D34F42D05043BE4439A32C249E2721A02923A12A24AC332AB0372CBF4F39
BD5B38B16430F2C175F7D782A9903E8E7E31D7CE8BECE6B2DFDABAC4C1B094908F67646B
4B485145444C4A47504B4A5247474F3F42493C3F463B3E47393C45393C4533313C2C2934
322C382D25322F23312719288F858EF6EFF6E5E0E4E2E2E4E2E2E2EBE9EAE3DFE06A6466
6560643D393AB7B1B3F4EEF0EBE5E5E9E3E3E6E2E1E5E1E0E3E1E2DFDFDFDFDFDFDDDFDE
DFE1E0DEE0DFDFDDDEE2DCDEEADBE2FFDEE7BE808BA9535CBC5159B8474BBD5C56A35A51
9A786FFFF3EB
FFF3EFB78C85A75547D26755E26956D85F4CD26755C06A5BC0847AAB7E7BC29B9EBD9299
C69197C3888AAA706EAA7A76F0D3CFDCCDCAD3CACFBAB5BCD3D0D7ECE9F47D7988636073
615E734D4B603E3C51323045312F452F2D4337354B43445952536855586B424355373948
343341403C4A4B45514C444F3F353D685F64EADFE3F4E5E8F8DFE5FFD8D8CF9186C47D61
C78352FABA7AFFC277F3AE63E78D4EF18956EC7C57D5694FD67765C175679F6B607F5E55
5948403E352E312A242A251F2F2822312A242F2724352D2A2A25212C27232E2623312926
302B27322D294036344738355238375E34357E4242BA6C6CB85955BB544BE88274FD9C8B
FFAF9DFFA894FC9584ED7F6EED7E6DE87765DB6A5AD56454DC6957DA6554E1695BE1695B
E46C5EE86F64E16B5FE26E61DD6C5ED56557D56559CE5E53D05E54CF5A51D35650DB5C55
DF5C52E36154DD594DE05A4FD9534AD9534AE25951E45B53E1584EE05A4EDA5647D65E46
D06946B36332E5B271EDCC85C8B16DBAAA6EAFA57089865D6C6A5158564A4745464B484F
4A49514241494241473C3B4137363B2F303433323726252A27282A2727292B2A2F2C2A2F
2F2A312F252E2C1E2D2315248B7F89F8EEF6E5E0E4E3E1E4E2E2E2F5F5F5A19D9E706A6C
E8E4E57A7677ADA7A9BAB4B6B6ADB0DFD6D7E9E3E3EBE5E7E8E4E5E3E1E2DFDFDFDCDEDD
DDDEE0DDDEE0DDDDDDE2DCDEE9DAE1FFDEE7C38A939A4952CA6168AE4043BD5C55A0584C
9A786FFFF4EC
FFF1ECB1867FAB594DD26757E36A57D9604DD06553C56F60B77B70B98C87C69C9EE2B8BC
C79397B683829D6D6BE1BBB8E4CFCEDED2D4CEC4CCB7B1BBF2EFF8B3AFBD5653645C596C
4440517C78879F9BAA94909E8F8B99908C9BA5A2B35F5C6F535065403D504A4856A9A7B2
A19EA5A6A1A7AFA9ADB5AFB1B8B2B4D2C9CAF1E9E7F0E4E4F4E1E3FFE2E0E3AFA4B27257
BA7846EAAB68FFC778F9BA6ADA8542DA7740E0744DD97156CE7662AD65576F3D347A5952
86756E7E756E5E574F3F3832342F292D2822292420302B272D2522322A273028262B2321
312C28302B27382E2C3D2D2D482E2F5A30326725297D2426A43B38E37069F48277F9897B
FE9484FF9787FF9281FB8D7CFF9583FF9C89FF9E8BFF9E8BF5927FE88371E47A6ADF7565
DD7363DC7264DC7566DA7666DC7D6BDE816FE68978E98979E78676E98575E67A6DF18175
F47C6EF5796DF9796EF57067E75E56EF645DFD7069F1675DE95F55E66255DC6151D66753
CA7153B5714CB3875A977B4C6E5B315D502D4E492C44422D4E4E424B4A46464646424146
37353A3432373634372823272823272B262A2A28292321222929272727252929292A2A2C
2E292F2A232B3024322A1C2B827680F4EAF2E7E1E5E4DFE3E8E6E7E9E7E8928E8DA39D9D
877E7F867D7EC7BEC182797C433D3F585254857F81ABA5A9C6C0C4D8D3D7E1DFE0DEDEDE
DDDFDEDCDEDDDDDDDDE2DCDEE9D8DEFEDDE6CC949F8A3D47D46C75AC3F42B857509D5549
9B7970FFF5EC
FFF1ECAA7F78A8564BD46959E36A59D65D4AD36554C26957C68476E0AEA3AB7E79C39794
B88B86A97E78AA8781EFD3D0E0CECED6CACEBEB3BBE1D7E0EEE6F17E78865B5768524D61
3B3748C2BBCBF1E9F8E7DFECE6E0ECF0EAF8D7D3E26763744B465A242031A8A5B0F8F3FA
EBE6EAECE8E9ECE6E6EDE7E7EFE9E9F0E8E6EFE7E5F2E6E6F7E7E8FFE3E2F7CBC2B27A61
B37343D59653FEC775FCBF6EDC8C45CC6C32DE774ED77254CD7662AB655965352B52312A
594640776C66918881857C756A635D453E38342C2929211E28201D332B282F27252F2A27
2D2824312C28352B2A3E2C2C44272957262A63181D7C1C1EC75554E86D66E96D63EC7265
E87264EB7567E97161EE7968EB7A68F08573F48D7AF5927FFF9A88FF9887FE9484FF9484
FB9181FD9383FB9684FC9986F99A86FDA18CFFA694FFA694FFA290FF9B8BFD9687F98B7C
F37D6FF07468E9695EEF6960EC635BEC6258F2655CE95F55E86257DF6455D76759BF6250
A159438A573C6C482E513C2142361E463F2C433F333A3A323E3E3C383A39323234333237
28272C27252A2C2A2F262125292428292428292526292524262521282924252523232321
262427251E262E22302C1E2D796D77F5EBF3E6E0E4E4DFE3EEECEDDBD9DA9791917D7777
89817F83797ACDC4C7D3CACDD2CCCEBBB5B78882842C26283E383A9B9597E8E4E5E2E2E2
DEE0DFDEE0DFDEDEDEE2DCDEE8D7DDFEDDE6D29DA7853842D9717AAC3F42BB5C56995349
9F7E75FFF5EC
FFF2EEB28780A65449D5675AE66B5BDD604ED86552CF6F59D08570BD84718455457C5544
A88474AD9080D3BBAFDBC8C2EAD8D8CEBEC1CCBBC1F8E9F0CCC1C95E566160596B524D61
49445A736E82827B8D7D7688857E908B84967770825B5466393242453F4DE4DFE6EDE7EB
E9E3E5EAE4E4ECE3E4ECE3E4EDE4E5F1E6EAF3E8ECF6E7ECFAE7EBFCE2E3FFDAD3BC8A73
B6774BC48444FBC474FBC16FE1934BCD7033DD784CD77455CE7763A6615265342D54332E
4D38354D3E3B5B4D4A786D699186829085816E65604F4842362F292A251F27221E2B2622
2C27232F2724352A283E282A462226551C2265101793292DDD6362EE6A65ED685FF26E62
EF6D60EC6A5DEE6A5DED695CED6B5DED6F60EA7160EC7463EE7666ED7364F07669F47A6D
F47C6EEE786AF27F6DF38270F48675F88D7BF88A79F78978F98B7AF9897BFA8679F67D72
F2766AF37368F57165F56C62F3695FF2685EEE645AEC665BE36557DD6D5FBE6255873F31
6231224F2F204734263D3327332F242F2C2531302C2F2F2F2B2C2E25292C26272B2A2B30
26262E26263027242F28252E27242B2A282D2D282C2C2827272622242520242520252523
2725282A232A291D292A1C2B827680F5EBF3E6E1E5E3E1E4F0EEEFCFCECCA09A9A4D4747
6F67657F7775C8BFC0918889B0A7A8B0A8A6C7BFBDB1A9A7C3BABBDBD5D5E4E0E1E0E0E0
DDDFDEDDDFDEDFDFDFE2DCDEE9D8DEFDDEE6D39EA8833640DA727BAF4245BB5C5697534A
A6857CFFF6EE
FFF7F3C59E97A25249D4685BE66859DE5D4ADB624DD46C53DD896FC17F6588553A795439
BD9F85DAC5B0DCCCBDDCCDC6E4D4D5CBB8BCE9D4D9D1BEC4D6C5CD594D574A4251514A5C
4F475C5850675D556A5D5668625B6D645B6E5C53664E4556261E2BA9A1ACF4EDF4EAE4E8
EBE5E7ECE6E6EDE4E5EFE6E7F0E7ECECE1E9EFE4ECF1E1EBECD8E1F5DCDFFFE0DAC89A83
B97C50BA7A3CF6BE71FFC473E5974DC96F31DB794CD17050D07B669E5A4D63342C50312E
4B36334D3E3B4537344C3E3B594B4872676391868291888379726C55504A3B33302E2925
2A25212D25223628273E2626461C205413196A0E13AE3D3FE96966ED6660F1675DF46A5F
F3695EF2685DF2655BF5685EF1675AF0685AF16C5DF26E5FF36F62ED695CEE6A5DED695C
EC6A5DEF7061E96A5BF07263EB7061EB7162ED7263ED7263EC7064EB6F63F17367F27267
EF6C62F56F64F36A60F46A60F3665DF2655BEF6258E76155E16657D76D5FB9655A6E3227
4520173A261D2E231D2C29242B2A2826262627262B292A2F22252C20242D20242F242833
242736292B3A2726362C2A382D2D392C2B332A282D2A2829292728262523272725272727
2A25292E272E2A1E2A2D1F2C8F838DF7EDF5E5E0E4E4E2E3F2F1EFC1BDBC959190464040
655D5B958D8BD0C7C8675E5F534B49342C2A7C7472ADA5A3C3BBB9DED8D8E4E0DFDFDFDF
DEDEDEDEE0DFE0DEDFE1DBDDE9D8DEFDDEE6D4A0AC823640DA757DA83B3EB0534E98554C
B0928AFFF5EF
00FF00D9B8B39E544BCE6457E7695BE05D4BDC5F49DC6D52DB7E5FC77C5CAA724FBC9672
D1B698E5D5BCDCD0C2E5DAD6CBBBBCD9C4CBD3BAC0886F75E0C9D1B8A7AF504450382D3D
312839382F423F3649403748413948423747403543443A458C828BF0E6EEF3EAEFF1E8ED
EFE6E9EEE5E8EDE7E9F6F0F4C8C1C98E8693A497A897899883717DEBD4DAFFE4DFCC9F8A
BB7E51B57434F3BA6BFFC473E7994FD07638D8774ACE7150C97B65925447562B244C302C
483632483D37483D39453A36473C3A4136345449476C6260887F7A948D87847B76655E58
463E3B372D2B3020203B2122481B1E56111478181ACB5456EA6662EE635CF3665DF1645A
F2685DEF655AF26659F4685BF4685BF06659F36A5AF46A5DEF675BF26A5EF0665BEE6457
EF655AF1695DEE665AF0685CEF695DEC665AEB6559EE685CEB655AEA6459EF665CEF655B
EC6258EF6259F06159EE6056EE5E55EB5B50EB5D51E86054DF6153DA6F5FC06A5D6A2E23
3D181034211B2F2724292826262628292A2E26262E21232F2127331D243421283B2B3348
292F4532374D393B52373A4D36384725273323232B26252A2B2A2F26262827272929292B
2B262C29222A30232D2C1F29988C96F6EFF6E5E0E4E4E2E3F5F1F0ABA7A68884835A5454
706866A39B99E7E1E1D9D3D3DBD6D3BCB7B475706D332D2D5F5959C3BFBEE7E6E4E0E0DE
DFDFDFDCDEDDDEDCDFE2DCE0E9DAE1FBDDE5D8A6B1863E49D4737A9E3637AD524D97574E
B89B95FFF7F3
00FF00E6C9C59F5951CD675BE66A5EE25D4EE05F4ADF694FDD7959CB7B58BC825CC9A27B
E0C7A8DBCBB2EADED0DED1CBC6B6B7EBD6DDD8BDC6CBAFBBE2CBD5F8E4EFDDCDDAB5A8B9
A59AABA299ACA097AAA398A9A095A5ABA0AEBCB0BCCEC2CCEFE4ECF3E8F0E0D5DDE1D6DE
F0E7ECF3EAEFF2EBF2F6F1F89C96A4736C7C7E72865F5063948393FBE4ECFFE0DCCA9A84
BC7D51B67535F3B86AFFC171E89A50D1783CDA7B4FCA7151C67E68834B3E4B261E48302C
483934443B364B423D4138333F3533403634433937483E3C4B423D675E59817873958C87
8C8280786D6B5B49474F3131522021550D0E882122D95F5EEF6A65F0635AF06258F16359
F1645AF1675CEF6258F4675DF2655BF06359F3665CF2655BF4675EF1645BF3655BF3655B
F1645AF4675DF2655BF1645AF1645AF4675DF4675DF06359F4675EEF6259F2635BF06159
EF5F57F16159EE5E55F25F57EF5C52EF5C52ED5D52E95F52E26255D7695AC56F626D3126
3D1B123624202F272529292B27282D2F2F37292B37292D39272D3D293043373F563D445E
3B425C3C425C3B3F583E435732354625273424242E22212929282E25242A21202529272C
211C23241A23281B2530232DA0949EF4EDF4E4DFE3E5E3E4F3EFEE9D9998938F8E585252
8D8787B0A7A8CEC8C8B9B3B3D2CAC8C9C1BFC1B8B9BCB6B6DAD4D4E3DFDEE4E0DFE2E1DF
E0E0E0DDDDDDDDDBDEE2DCE0E9DAE1FBDDE5D6A7B1823C46D6777D9A3636A9544D91554B
C1A5A100FF00
00FF00F1D9D5AA6963C6655CE2675FE05C4FDF5B4CE16853DA7257D27F5FB17752CDA783
D7BE9FD3C3AAE5D5C6C9BAB3E1CFCFEAD5DCCFB7C4A890A0AB94A6A893A6A18FA5A092A9
998DA5998DA593879D988AA1978A9E9D90A27F7381988C98F2E6F0B0A4AE837582847884
B2A8B1F0E9F1FAF4FEC9C6D1716D7E726D81675E73504357D7C4D7FEE3ECFFD7D6C88F7B
C27E51BF7A39FABF71FDBE6EE19148DA8044D3764BCA7558BC796677453A4D2C2548352F
3F3430433B3849413E443C393F37343C3431413936453D3A3E3731433C36443A38594F4D
6E605D8C7A78977F7D926F6D8C54537F312FA33B38E56A65EB655CF1645AEE6056F26458
F3675AED6056F3655BF2635BF3645CF1625CF1625EF36460F1625EF46561EF605AF1625A
F5665EF06159F4655DF1625AF2635BF2635BF1625AF2635BF1625AF2635BF16159F06058
F15E56EF5C54F25F57EF5A53EF5B51F05C52EF5C52E85E51DF5F52D86A5BC9736673372D
3D1A143826242D27292E2D332D2D352C2C362F313E3134433A3F5241465A454962434760
4347603F445A3D42584042572E2F412224311C1A271C1A251E1C2723222A1F1C232C272E
3E373E5349526D606A60535D9F939DF3E9F1E3E1E6E2E2E4F2F0F17E7A79BBB5B7C5BFC1
837D7FCFC9C9A49E9EA79E9FD4CACBD7CBCDD9CACDDFD3D5CCC2C1D6CECCE6E2E1E1DFE0
DFDFDFDEDEDEDFDDE0E3DDE1E8D9DEFADFE6D3A1AC7E3840D2787A983B36A6584C8B5549
C4ADA700FF00
00FF00FEEBE7B17670BC6259DD685FE16156DE5F50E26B57D87259CB7C5EB87F61E4BD9E
E7CDB2E0CEB8E5D4C4E6D5CDDCCAC8EFDCE07D69755C47585C495C5443565041564C3E55
4C3E55473B5146384F493C504D40524F42532B1F2DACA0ACF6EAF47D717B6153606A5E6A
594F5ADCD4DFF3F0FB908C9B63607366617740364E8F8095F8E3F4FDDEE6F6C3C0C4836D
BE7749CC8746FFC277FBB96BD98640E2854CCF734AC57457B778666B3F344C2F29493733
3C32303D38343F3A36403B37433E3A3E39353934303A35313C37314039333D3532433836
4436334C3935674B48885C5BAA6A68AD5855C75C56E46860EC665BED6154F16357F06256
EF6356EF655AED6359EE655FEA6560E76563E76768E56468E86869E96769EC6667EA6262
EB615FEE6360EC615EEE6360EE6261EC6260ED6361EB615EEE6360EA5F5CF06260EC5E5C
EB5D5BEB5D5BEB5B5AEE5F5BED5C59EA5954ED5E58E75D53E16156D6665ACA7369783C32
3D1A163E2C2C322C302D2C3230303830303A3434403032413A3D4E373A4D303146323348
34374A282B3E2526381E1F31201F2D24222F2E2B36423F485A57606B686F716C73756E75
777077746A72645761382B35A296A0F3ECF3E3E1E6E3E3E5F6F4F57C7B795A5657544E50
8B8788F6F2F386808062595A5F53555F5053605053635356443838BAB2B0EDE7E7E1DFE0
DEDEDEDEDEDEE0DEE1E2DCDEE8D9DEFADFE4D09FA5813C41CB7274933C35A560517F5142
CDBAB400FF00
00FF00FFF4F2BB8680B46257D76B5FE66C5FD75D4EDF705DDC7E65BF755CBD876FD4AE97
D9BDA8DFC8B8F2DFD1CFBEB4C7B8B3E5D7D782737A7A6D77766875746675726674756879
7467786F62736E6071695B6A695B6A4F414E71656FF1E6EEFBF1F9C1B7BF6D626A544852
746D75ECE6F0C4C0CE696677676278574F663D3147D6C5D7F9E1EFFFDBE0E6A7A0C67E65
B87241E4A061FFC37AF9B36BD37B3CDE7E4BCE724DC7775CAF7561643C30482F28443530
4036343E3634403836423A37473F3C443D373D35323B33303C34313B333039312E403634
42333047322F52302F5B2928691F1E8A2C2AD4615CEA6A61EA6458F26657F16355EF6153
F16558ED6559E8655DE56A65DB6B69BD5556B24F54B15059B2515ABC545DD25E6BDC606B
E4626CE6636BE6636BE15F67E3616BE3616BE3616BE36169E36066E66067E66069E45E67
E45E67E45E67E7616AE65F66E85F67E75C63E75C5FE8615EDF5E58D7675CCB746A80443A
3D1A163F2F2F322C3026252B2A2A3228283026263024242E272733232230201F2D2B2A38
3434403C3C484A48555A586367646D6F6A717D767E827B827A737A6C676B5751554D474B
3B3539362C342E242D291F28B6AFB7F1ECF2E3E1E4E3E3E3F2F2F2B8B8B82826275B595A
D0CFCDEEEDEBD3CFCEDBD5D5857B7AB0A4A6D1C2C5CEBFC2A89C9CD6CECCE8E4E3E1DFE0
DEDEDEDDDFDEDFDFDFE2DCDEE8D9DEFDE0E4CB989D843F42C16D6B924239995E4E795444
D6C7C000FF00
00FF00FFF7F4CB9E98AD6358CE685CE06F5FE37463D26D5BD27F6DA1604EE3B5A6DFBFB4
DFC4BDDDC9C2E5D4CDE0D2CFE4D8D8E7DCE0DFD5DDE0D6E1DED4DFDCD1DFDFD4E4DCD1E1
DED3E3DED3E3DDD0E1DCD0DED8CBDCCABECCD0C6D1E5DBE6DFD8E0E6DFE7DBD1DCCFC7D2
E9E3EDEEEBF6888495635E72665E7534283E857487FFE7F7FFDEE7FBC9C8CE8979C97D5B
BD7743FAB977FFBF78F0A561D97A42D67445D17452C4785EA66F5B5F392C4B342E443532
4238374038363E36343F3734453D3A453E38453C373F36313D35323D35323A322F3C3230
40312E472F2D522B2C5B2324691719993331DE6761ED6A60EF6759F06455F06453EF6354
ED6557E9695EDE675FE27975A44C4AA5595BD8929AC37F8AB56E7CB26472C5687BB34C5F
D36776D76B78B74F5AAC4651A94551A3424DAA4652A94551AD4752AC444FAF4752B9505E
B64D5BB74E5CB54C5ABC505FBE4E5CC04C59C95059D75A5EDF6361D4655ECF786F82463C
3D1A162F1F1F27212523222826262E33333B36343F403E494E4C595D5B68615F6D6F6D7B
7775827D7B8673707B6B6871615C62524D514741453C3638322C2E312B2D2C26282E282A
2E282C2C262A2E242C362F36CBC6CCEEECEFE2E2E2E2E2E2E5E5E5E5E5E5B0B0B0C2C2C2
E5E5E3E4E3E1ECE8E7FDF5F3786E6D685C5C7F7073786C6E6E6465DCD3D4E9E5E6DEDEDE
DEE0DFDCDEDDDEDEDEE1DDDEE8D9DCFFE0E5C59195894544B8676392483D915C4C856556
ECE2D900FF00
00FF0000FF00DAB3ACA76559C86B5CD86F5CEC8775D17868A35F54BC8B84E8C8C97E696E
83727A8578818D818B877D86978F9A958D9A827C8A817D8C7C78897F788A7D758A786F84
7A71867D74897B72877A7184766E83766F817F788A8B8496867F918780928F88989891A1
A5A1B29893A76E667D6B61795749603C293DD7BED3FFDFEDFFD0D5DD9D93CF8467BF7244
D8985AFFC178FAB46CE18E4CDB7743DC774DD07556C97E679863515B392D4E3632463837
3E3232473D3E3C3231403634413936463F39453E38433C34413A343E37313B312F3B302E
40312E492F3051282C5F212672191BAA3E3CE56864EF6960EE6457EF6354F06455EB6355
EA685ADF695FD9736EC77371713433CD9FA1FFDEE4FCD4DDFAD0DEFFD4E5E8A5B7964B5F
C175828B434F9E626AD6A1A9DFAEB4CFA0A6C997A0C3919ABF8C93B27F86A9747CAA757F
A06B759B636E9A606C965865A25B6BA95867B45664AE444ED05E5ED66A67C570698A4E46
5C39355C4A4A5E585A605F6566666E6D707971717D6F6E7C6E6D7D6E6D7F5C5B6D525163
434051403E4C34303E302D362E292F2F2B2C2B27282A2625322E2D2D29282E2A292B2726
2C28292924282620243E383CD9D7DAECECECE1E1E1E3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
E4E3E1E6E2E1E1D9D7EFE3E3CCBEBDB4A4A4B1A3A3AB9FA192898AE3DDDDE4E2E3DFDFDF
DEE0DFDEE0DFE0E0E0E3DDDFE9DADDFFE1E3B98184964F4DA85851A0584C8757499C8275
FEF5F000FF00
00FF0000FF00E9C8C1A1675CC7705FCF6A58EA8B79BA6B5CA97067F7D1CEB1989E685863
6A5C6B685D6D6D6272675F6E6E66756C66745E5A68605C6B615D6E615D6E5E566B60576C
60576C61586D635A6D5F586A5C55675D5668615A6C665F716A6677666273635F70656275
68657A676279675D766A5A74402A3F937486FFD8E8FBC6CCDD9A92CD836ACA7D53C47C42
F9BA73FFC076EFA159D4773ADF7646E07853D67B5EC77F6795645355352A4B3631453736
413535453B3C403635423837413936403933453E384A433B40393137302A3F36313E332F
40312E462C2B53262B5F1E22791D20BE4E4CEC6D67EB625AF16558EF6354F06757EA6659
E46A5DD76F66CD7875995959885E5FF9DCDEF5DCE0F2D8E1F9DAE9FFD9EB99647892596A
885260956771FAD9E0FADFE6F8DFE5F7DEE4F8DDE4FBDDE5FFDEE7FEDDE6FBDCE4F7D9E1
F2D7DEF1D6DFF0D2DCF5D1DFF7CBDCFFC8DAFFBDCDA74753C25457D06764C8736C8E4F48
623F3B6C5A5A5F595D53535B4C4F584345514042514142563D3E5238394D3A3B4F3C3B4D
3A374838364434313C302D34332E322B27262F2B2A2F2B2A2D29262C28252F2B2A2C2827
2925262B2527211B1F544F53E5E3E4E8E8E8E1E1DFE3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
EDECEAD9D3D36F6566C1B3B37E6E6E8A7A7A8C7C7D8377778E8586EDE9E8E2E0E1E1E1E1
DEE0DFDFDFDFE0DEDFE5DCDFEBDBDEFFE0E3A96E70A55B5AAA5D559E5E527D5647C5B1A6
00FF0000FF00
00FF0000FF00F6DAD6A47269C06D5FCC6B5ADD806EA05444CB9B8FD1B2AD52373C66515A
5C4C575F525C5C505A5B515A5A50595C555D58515958505B59515C5A525D5B505E5B505E
594F5A594F5A5E545F5B535E574F5C564E5B5A525F5B53605B5561595661585664585566
5D59706058706757715A425A513043E7B9C4EFAEB2DA9087D6866BCE7F54C88247F3B06A
FAB86CF6AC63EC9253DB7640E17449DF7452D4795CCD856D956654513328493630473938
463A3A403635453B3A443A39423A373F37343F3A36423D37443F393C37313C352F39302B
3E2F2C4529285325285A15187C1E1FD05E5DEA6964EF665EEE6255F16858ED6557E7695B
DE6F64CF756DBC7877724144CCAFB3FCE7ECF1DAE0F3D9E2FEDFEEE2BCCB8350619C6978
6D4550DFC0C8FEE7EDF2DDE4F4DDE7F5D9E5FDD7E6FACEDDF2C2CEF4C6D1F3CBD6F3D4DC
F6DFE7F1DDE6F0DBE4F5D9E7F8D6E6FFD4E5F6ACBB963642C95B5ED56967CB736F81423D
4C292740303338333A31313D333542383B4C3B3D5242445B494B6245475C414256414050
3C3A473130382E2B322E2C2F2E2A292925222F2A272E29262B27242A26232925242E2828
2A24242C2626211B1D615D5EECEAEBE4E4E4E2E2E2E2E2E2E2E4E3E0E2E1E1E1E1E2E2E2
E8E6E7DDD9DAB3AAADD6CACCAA9A9BAA9A9BA898998C80809A9494F2EEEDE1DFE0DFDFDF
E0E0E0E0DEDFE1DDDEE5DADEEDDAE0FEDBE193585CAA6462A46055965E4F856558E8DACF
00FF0000FF00
00FF0000FF00FEEBE7A1766FB1675ACD7260C76A58AB5846FEC2B7CD9E989E72738E676C
664349614247583B3F51373A4A31344F36394C37364935343E2B27412F2B46332F49342F
4B332F4E36324E36324C3432483030452C2F442E3148343647373A44393D48424C4D4B59
544F655E526A67546A4125349F777FEDB7B5C37A6BD28163CF7E4FC87E41FAB771FFBE74
F6AC63F5A05DED8850F38456EC7A55DA6F4FCF7459CB846EA97C69573B2D3C292240322F
433836403634473D3C3D33314238363F37343D3834413C38433E3A3F3A343B342E39302B
3F302D4529285726295A1416862725D86560EC6B65ED645AEF6558ED6557EB695BE36D61
D27067CF827C925C5C815E62F7E2E7F1E0E6F0DBE4F6DAE6FFDDED9E75858C5D6D7C505D
8C6E76FAE5EAF3E0E6F1DCE5F5DBE8FFDAEBF2BBCEB57586A46270AB6D78A16F7A94707A
E8D1D9F1E0E8EEDAE5F0D8E5F7D7E6FFD4E3BF6E7D9A343FDA676AD36663CE76727F403B
5531314130363F39433635433638473A3D503B3D523D3F564A4C63424459444557373743
2D2C342E2D322624272725262C28272A26232C28252D29262A2623282421251F1F2B2525
2B2223342B2C201A1C6E6A6BF2F0F1E4E4E4E2E2E2E2E2E2E2E4E3E1E3E2E1E1E1E1E1E1
E2E0E1E5E1E2F6F0F2CEC3C77C6D7095878794888A7B7172B1ABABEEEDEBE0E0E0E0E0E0
E0E0E0DEDCDDE3DDDFE6DADEF1DCE3F4D1D791595AB2716D9C6055895B4C968073FCF3EC
00FF0000FF00
00FF0000FF00FFF7F5C1A29D9D5F54C87263CB6757BB5546EC9486FDADA2F4A7A1F2A8A5
EFAEAAE8ABA8E2A7A3DDA49DD9A29BDAA69BD7A799D2A794CAA58BC6A387CBA689CAA384
CC9F80D0A183D29E86D29E89D49F8FD19D8FD1A092D4A89DD2B0A6CCB5AFD7CBCD8E8691
5044586051665A42524F2F34ECC2B6D19B81BE7950C27942D09049F7B86BFEBA6FF3A960
F49F5EF18E55F28355F27C56E66F4FDD6F54CF735AC67F69AE816E896D5F67554B42352F
3328243D322E433836403533413634433937423A38453D3A433B38473F3C3D33313E332F
43312F462A29552427601A1A8E2F2BDB6861E96960F1695DEC6456EC6859E4685CDB6F65
CF7871BB7B796F4748CAB1B5F9E6ECEEDDE5F1DBE7FDE1EFEBC4D6865B6C976D7B613D49
D0B9C1F6E5EBF0DBE4F3D9E6F9D8E9FFD0E5B3667AA95062CB717DC97982AC70786C434B
DCC2CBF6E2EBEFD9E5F1D5E3FED8E7F8BBCA963944C35258DD6765D66964CA756E7B3E3B
532F314231393C3441383745393B4A393C4D36394C40415545465A3F3E4E3838442C2B33
28272C2C2A2B252422252422282723282723282725282725282725282423251F1F292021
3026273128291D1719817D7EF5F3F4E5E3E4E2E2E2E1E1E1E2E2E2E2E2E2E2E2E2E2E2E2
E4E3E1E8E7E5F7F3F4D8D2D45E53576A60617D74775D5757B3B2B0EAEAE8DFDFDFE0E0E0
DEE0DFE0DEDFE6DDE0E8D9DEF5DEE4E6C3C7824C4CB479738C5B4D825E50B8A79F00FF00
00FF0000FF00
00FF0000FF0000FF00FAE7E3B1827AB46C60CF6F61C5594CD96F61E57B6ED26A5FD87369
DF7E75E0837BDC8279DF877BDE8879E59481E29780E4A184EAAE89F7C195FBC797EFBA88
D99F6DCC8E5DCA875CD38E67D28C68D79271D89578D49A82BE917EB4968BF3E1E17B6F79
53465863506343293297746EE2B69B9A6438C68649E7A45DFFC172FFBE6EF1A75EEC9756
F18E57F18254F17954EE7153E56951E0705AD57964C5816C885B48674D3E88766C8D807A
6459553D322E362B273C312D403533483D3B443A38443C39443C3948403D413735413634
412F2D4729295220216019179F3E38E16F64E9695CEB6657EC6758EA685AE26C60D47269
CE837E8C59587B5D5FF5E2E6EFDEE4F0DCE5F5DDEAFBDCEBA77C8D90647377515E8B6D77
F9E6ECEFDEE4F1DCE5F6D7E6FFD7EAE0A1B6A14457D66D7CDA7680D48288A0636A885F67
F6DCE5F1DDE6EFD5E2F6D4E4FFD6E6C17987A33840DE6366DC655FD46961C6736B723834
502E2F402F373B333E3A38453A3C4B3436453334463D3C4C403F4D3A38452D2C34262429
2624252827232726222524202726222827232928262625232322202A2625282222281F20
2D23242F2428271E21A29C9EF3F1F2E3E1E2E3E3E3E1E1E1E2E2E2E3E3E3E3E3E3E2E2E2
E4E3E1DFDBDAF7F1F19E9596867C7DF8EEEFF4EBECE1DBDBDEDDDBE2E2E0E0E0E0E0E0E0
DEE0DFE0DEDFE6DBDFE9D9DCFAE1E5D1ADAF73403DB38178855E4F7D6656DDD2CC00FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E7CEC7A37369BA6A5FC66054DD685EF2766CEA6C60E86A5E
EB7166E76E63E87062E77163DF6E5CE37661DB755CDB7E5DDB865DE39766EEA970F8B679
F7B676E5A462D48E50C98146C47940C47844C57D4DBD7F588B5D43D6B6A9C5B1B2574A54
5F51624A3844503B38F0D1BDD0A47DCF9B62FCBF7CFFC076FBB367F0A059EC9253ED8852
F38457F07855F17156EB6953E86956E3705DD27563C985728557484E3427513E376B5E58
877C788C817D70655F4A3D37372C283C312D433834443B36433A35463D38463C3A413332
412D2E49292A552221671D1AAB4940E57164E66758EF6A59EB6657E96B5CDE7063D2786F
BB7C776D4442D2B9BCF8E7EDEDDCE2F0DBE4FCE0EEE0BECC8051619C707D63424BD7C0C6
F7E6ECEEDDE5F4DAE7FBD5E4FFC9DBAE5D6EBC5161DE6E7AD47478C77B7F7E4C4FCCACB1
FCE5EDF0DAE6F1D5E4FFD4E7FCBBCF9C4150C55056E46765DC655DD56F63BC6F6567322A
4C2D2B3B2B2E362F3635343C3C3A473939453838443D3B483D3C443431382E2C31262223
26221F2A27222F2C2724211C26231E26231E2A262326221F231F1C2A25222D24252B2223
2D22262A1F252D2228C0BABEEEECEDE2E2E2E2E2E2E2E2E2E2E2E0E2E2E2E3E3E3E7E7E7
E8E7E5746F6C887E7D564A4A736564998B8A8B807E827876DFDAD7E6E5E1DFDFDDE0E0DE
DEE0DFE0DEDFE6DBDFEBD8DCFCE2E5AF8B8B72433DAE8476775C498D806FF4F0E700FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF8F4C7A9A1995B50B85E53D9675DEF6C62F2695FEE6459
F76D62F56D5FF36B5DF57061F3705EF1725FE76F57E47557E37B56E28355E48F59E9995C
F4A968FDB470FFB571FFB874F9AC68EDA261E49E63BD8353B88D6DF5D8C88A7574634F58
6A56613520259E8378FEDBBFEEBB8CF9BD81F6B36FEA9F5BEA9554E6884BEA824FF28157
EF7453F17156EE6A55F16C5BE76555E06D5BD57866C6826F855A4A51372A493830493E38
4D443F6B625D887D799186827B706C5348443E332F392E2A3E35304239344238363C2E2D
412D2E4F2D2E561E1F702220B14C44E56F63EA6B5AEC6957EB695BE16B5FD9746AD0817A
8A55518D6B6AFAE6E8F1E2E7F1DEE4F3DCE6FFDFECA6808F9264717B515D8F747BFBE8EE
F2E1E7F2DDE6F4D8E6FFD7E7E69DAE923442D86972D96A71D87E809E5A5B895F61F8DDE2
F3DEE5F0D8E5F4D5E5FFD5E8CF7E91982F3DE3666AE2615CDB665CD06F5FB87062633128
4628263A2A2B3329312D2A31322F383B39443A38433E3D453D3A413432352F2B2C282423
26221F2926212B282324211C2A27222A27222A252227221F25201D28222230272831262A
2D2027291C23382D33D7CED3EEECEDE2E2E2E2E2E2E2E2E2E3E3E1E2E2E0E3E3E3E6E6E6
E8E7E59D9895968C8B948685A0918E9687848C7E7B908583EBE6E3E7E3E0E1E0DEDFDFDD
DDDFDEE1DFE0E8DCE0EED9DEFEDFE4926C6B9469629E786B6B5945A7A28FFFFCF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F9E6E0A57970A1584FCA6259E66A60F06A61ED6056
F4675DF96D60F86C5FF46B5BF56D5FF67263EF6E5BEC725BE67356E47756E78159E58658
E78D5BE58E58F09C60F3A263F6AB6AF9B473F6BA7EDFAF7EF8D8B2AF9680472E29533A3D
462E2E553832EFC9B6E9B796E29E71EA9A65E8915BE88A54E6804FEF8355EE7854F27557
EF6D55F06C57F26A5AED6859E96757DE6B59D47765CB877483584750392B46382F49423C
4C4441473F3D4B43405F5651827773988D89847975655A56463D3838312B362C2A3B2D2C
3F2B2C4E2A2C581D1F762625BB544DE86F64EA685BEB695BDF6558DB6F65D27975B97876
683C3DCCB2B3F9E5E7EFDEE4F0DDE3FCE2EDE1BBCA7F54659E727F603A45CEB7BFF6E5EB
F0DDE3F4DAE5F9D9E8FFD0E0BA6373B54B55DF6E74DB7276C77778794142CAA7ABFBE4EA
EFDAE3F2D8E5FCD7E9FFC4D8A34756C34E57E76567E4635DD56456D27564AB68585E2F25
432724392B2B372C34342D3537313B39363F3B3843403D463B383F2B292C2824252D2928
2B272429262128232027221F2C27242C27242C2324281F20251C1D2E252632272B30252B
2B1E27271A234B4048E1D8DDEDE9EAE0E0E0E2E2E2E2E4E3E0E0DEE2E2E0E3E3E3E2E2E2
E1E1DFEAE9E5E4DFDC8C8280998E8A9688859B908EA39997A49C9A7F7B7AE1DFE0E3E3E3
DFDFDDE3DFDEE7DBDDF1DBDEF5D5D886605FB0857E846256665647CECABE00FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E5C8C298635BB8645AD16559E86C62EA665A
EA6256F2685BF3675AF56C5CF56B5EF46C5EF46C5EF06D5BEE705AE66C54EA775AE77958
E67C55E68155E58352E68854E18A54E1925AD7925BDAA273FFDDB7D1AC92B88E82B1867F
AB8079DDAD9FFAC0A8D58E6EE58D67EB8A5FED8359EB7E55EF7B56EF7657EF6F54F16D58
F16A57F46C5CF1675AF0685AEB6758DF6A59D57662CC85718E614E543A2B473930443D37
47423F45403D48403E473F3C453B39584E4C796F6D9389879088857068654E44423A2C2B
301A1C4521235B1F217A2928C05753E66F67E86A5EE3695EDE6F66D0736EC88081824E50
927275F9E5E7F1DEE2F1DEE4F3DEE7FDDFEBA97E8F93677681596496777FFAE7EDF1E0E8
F1DCE3F7D9E3FFD9E7E2A4B3983844D6676EDB6E71D67878A25E5D835557F4D9DEF2DEE7
F1DAE4F5D5E2FFD6E7D18A9C9A303CE2636AE86261E16158D66658D178689A5B4A4F271B
41292535292B372D35352D383A343E3B35413D3A453B3841302D3429272A232122272624
2925222622212824252C28292D27292C26282920232920232E25282E252831282D31262E
2C202A1E121C5B5159EAE4E8EAE5E9E1E1E1E2E2E2E1E3E2E3E3E1E4E4E2E3E3E3E2E2E2
E1E1DFEEEDEBCDC9C8696461877D7B796E6C817674635958847E7E6F6B6AE8E6E7E4E4E4
E0DFDDE1DDDCE8DCDEF5E1E3DEC0C264413FBF9A916F53477D7367ECE9E000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF7F4C5A6A1995F54B96759D26C5DE06A5C
E7695BE45E52E96153E95F52EC6255F06457F4685BF3695CF36B5BF3705CF1705BEB6D56
EC7358EC7557EA7854E87852E97D56E88359DB7B53DA855EF1A686F1AA8EF0A892F3A797
F2A998F8AA96E18971E07E63EB7F62EE7B5CE97254EF7357EB6D54EF6D57ED6855F16A57
F16858F16858F76B5EF1675AED675BE16959D97865CE8572916250573A2A49382E463D36
49413E443F3C443F3C46413E453D3B463E3C4139374E46446B6361867E7B958B898A7C7B
6B565550292A531719701F1EC05656E6706CE16A62DE6F66D67972AF65628F5B5D5C3A3B
D3BDC0F6E7ECEEDDE3F1DCE5FCE2EFD8B6C675495AA074835E3D46D4BBC1FAE7EDF1DEE4
F5DBE6FBD7E3FFD1DEB56B78AF4954DB6E74D57173C87776794343C8A6A7FCE5EBEEDAE3
F2D8E5FAD4E3FFC7D6A85161C04B54E86165E7605CE4665AD36858D17E6C89503F472519
37261F3128293932393B353F37343F3A3742413B47322C362D2A312C2A2F282629252525
26242527252828262B28252C2A252C2D262E2B212A2A20282A2126251F23251F232B2129
3329322D262E736E74F0EBEFE6E4E7E2E2E2E0E0E0E3E3E3E4E4E4E2E2E2E1E3E0E1E3E0
E3E3E3F2F0F1B6B2B3736D6DD9CFD0D9CFCE9F9594A69D9EEDE9E8DBDAD8E2E2E2E1DFE0
E2DEDDE3DDDDE8DCDEFAE7E9B89E9D5A3E3AB59D91635346A8A19900FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F8E9E499786F8D594CB0685AC56D5F
D26D61DA6C5FDC665AE56B5CE06053E26052EB6559EF6759EF6759EE6656F16959EE6958
F16E5AF2715BED6F58EF7359EF7357EB7456EA775AE5785BE37E62DF7D62E07C64DD7962
DA7762E07A64E4765FE8745DEC725BEE705AF06F5AEF6C58F16C59F06858F16858F66D5D
F16858F2685BF4685BF2685BEE685CDF6556DA7563D1836FAB73645E382B4D342D4A3B36
483E3C423D3A433E3B443F3C423D3A453F3F423C3C413B3B473E3F48403E58504E7B6D6C
9F8689A87F83A264678D3B3DBF5756E2726EDB6E67D7766FBC716C753D3CC8A4A6D2B9BD
F1E1E4EFE0E5F0DCE5F8DEEBFFDFEEA982948F60727B515F95777FFAE5EAF3E2E8F0DDE3
F5DBE6FFD8E6E0A3B28C3C49C8646ED87077D57C7EA05A5C835659F6D9DDF6DFE7F1D9E6
F5D6E5FFD5E5E096A5932F3BE16367E95F5DE66057DF6558D46D5EC97A6B7A4638402217
31221D2B25252E2B32322F3A3632403834423C3642302A3429262D26242928272C28282A
28272C26252A1F1E24201D261E1B241F1923251D28302931302A2E3832364D464D5F585F
726B735550568A888DF3F1F4E4E4E4E3E3E3E2E2E2E3E3E3E3E3E3E2E2E2E1E3E0E0E2DF
E3E3E3EAEAEADDD9DA7872725B5253574E4F746B6CD3CDCDEDE9E8E4E3E1E0E0E0E2E0E1
E1DDDCE5DCDDE8DCDEFCEAEA8B7371776058A69687655B4FDEDBD600FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3D6D0C0A9A1B29087AD7E74
AF756AB97367BF6D61C96D5ED36D5EDC6E5DE16C5BEA6F5FEB695BE86455EC6758EB6655
EA6552E96451ED6857EF6A57F06C57EF6D57F06F59F47660F17762EF7661EE7763EF7864
E8705FEC7362F17462F1705DEF6C5AF06B5AF06B5AF36B5BF06858F2685BEF6558F66A5D
F1675AF2685DF4675DF1645AF26A5EE46658DF7162DA7E6FB672676E3C335635304E3938
493B3A443C3A413B3B423C3C423E3D413D3E423E3F423E3D453F3F45403D433E3B463A3A
533A3E774E54A86A6FB9676BC76363DA716DD3706AD7847E7B3F3E9D7575FFE7EAF2DFE3
F0DDE3F2DDE4F3DCE6FFE1F0DBB2C48152669C6D7F633D4AD6BFC7F5E6EBEFE0E7F0DCE5
F5DDEAFCD3E1A1616FA04E5CD0757ECE757BC4797D743C3FBF9CA0FDE4EAF1DAE4F3D7E5
F8D6E6FFCFDDB65C68B9464DEA6465EB605BE35E55E0685ACF6D60C2786B6A3A30351A13
2B201E2B262A29262D29273232303D3634413733412A27322E2B3428252C252229262429
1A171E1F1C232A273035323B413E475C575E6E69706E696F726D716F6B6C696367565054
443F452C272DA09EA3F3F1F4E3E3E3E2E2E2E2E2E2E3E3E3E3E5E4E2E4E3E2E4E3E1E3E2
E2E2E4E9E9E9F2EEEDA49F9C473F3D534B49C4BCBAF1ECE9E3DFDEE1E0DEE0E0E0E1DFE0
E1DBDBE4DADBEFE1E1F0DEDC614A44AB998D84786A8B877BF9F8F300FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF4F0F6E5DE
ECD1CADAB5ACCC9D93C0867ABA7669BF7164C46C5EC96959D66F60DB6B5DE36F60E66E5E
E56A58E66957E46254E76354E86352E45F4EEE6656EB6353F26D5CF16C5BF36E5DF4715F
F36E5DF67160F46C5EF66E5EF16959F06858F56B5EEE6457F3695CF1675AF4685BF3675A
F1675AF1675CF5685EF3665CF1695DE8695AE26C5EDE786CC8766B793A335D312E543837
4E3C3C473D3C483F40423C3C403A3A3F3B3A433D3F453F3F433D3D403A3A464040473B3B
4F363A5A313762232B823036C76363DB7370D97872B665618A4E4DF4CACBFFE2E5F8DBE0
F8DAE2F8D9E1FEDAE6FFD7E5A66F82975E6F81515F9B7580FDE6EEEEDFE4EFDEE6F0DCE5
F9E2ECF0CFDA743C498A46519F58609D5A617541458D6468F5DADFF2DDE4F3D9E4F5D5E4
FFD7E8DB99A799313ADF6164EA605DEB6258E46457D56557CF7668AD6B5F582D27311917
2B21202523262B282F2A2931302D382E2B362A27322F2C35302D342D2A313533384B464C
5A555B6F6A70807D84838087807E837573786560644843473C3839363233302A2E2D262D
27202739343AD3D1D4EDEBEEE2E2E2E2E2E2E2E2E2E2E2E2E2E4E3E1E3E2E3E5E4E2E4E3
E5E5E7EEECEDB2AEAD888481A39E9B918C898B8683E2DEDDE6E5E3E1E0DEE0E0E0E0DEDF
E3DDDDE6DADAF4E4E5C9B7B35E4C42B1A1946B6557D1CEC500FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF5F0FBE6E1EED3CCD8B6ADC79C93B9877CB5776AB87061BE6F60C76E5C
D06F5CD66D5AE06F5FE46C5CE86D5DEB695BE96455EA6252EA6151EB6250EE6553EC6351
F26655F06453F46859F86C5DF66A5BF36A58F66A5BF66A5BF26657F46859F26959F16858
F36A5AF1675AF5695CF4685BF0685AEA6657E6685AE47468DC7B728C4239531E1A4F2C2A
432E2B413332463C3B3E3838443E3E3F3A37453C3D443B3C443B3C433A3D413B3D413537
493336593237602129752329C35F61DE7572DA726FAB4E49B56969FFC3C4FEC6C9FECBD2
FFCDD6FFCDD9FFD3E1E4A7B6914957B06A75804B55E9C1C9FEE3EAF3DEE3F1DEE4F2DDE4
F4DFE6F6DDE3C6A3AAB28A92AC858A967377A08689E0CCCEF7E4E8F0DBE2F3D9E4FDD7E6
FFCBDCA55361BC4851EB6566E9605AE76357DF6757D26C5DC97B6E91584F44211B321E1D
281F202321222E2C2F363437413C424D484E534E546560646E696D7A76777D797A807C7D
777374676364585357474246383637302E2F29282624232122211F2824252922292E242C
2319216B646BF1EFF2E4E4E4E1E1E1E4E4E4E2E2E2E2E2E2E4E4E4E3E3E3E3E3E3E4E4E4
E9E7E8E6E4E58A8687D0CCCBD7D1D1C8C2C28B8786D6D5D3E6E5E3E1E1DFDFDFDDE1E0DE
E6DDDEE8DCDCF9E9EA93817D8072678D8377827E75F7F6F100FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F0FAE6DFEFD1C7D9B3A8C6988BB77F72
AF6D5DB96D5DBD6A5AC96D5ED0695ADC6B5DE66B5CEE6A5BF36B5BF46B59F56A57F46956
F26752EC614CEC5F4DF06351EF6352ED6150EF6354F36758F36758F66A5BF5695AF36A5A
F16858F36A5AF26659F66A5DF06757EF6759EE6A5DEA7063EB7F72AF574B5D1A11501F18
401F18321A16372825382D2B3B313038302E403635433938443A3B433A3D42393C433739
4C383A542F365D212974252BC15F60E17573DE6E6ACD615EC46561CA7270C97779D28388
D78A90E1949CED9DA8B05D67B45761BE676DA55E64FFCACDFFD1D4FCD3D9FCD5DAFED6DE
FDD9DDFDD9DDFFDCE1FFDEE2FFDDE1FCDDE2FBE1E4FDE2E7FBDEE3FBDAE3FFD7E2FFD4E2
DF93A09B3743DE6064EE6261EC6258E46254D96858CB705EBD796C825349654A43695B58
6A6464706E6F7975767E7A7B807C7D7C78797571726A66675B57564C484744403F3C3837
2A26252E2A292E2A292B2726322E2D2C2B272A29252A2925252422262223261F262C222B
2319219F999DF4F2F5E4E4E4E3E3E3E5E5E5E2E2E2E3E3E3E3E3E3E3E3E3E3E3E3E3E3E3
E5E3E4F0ECEDCECACB938D8F544E4E6D6767AEAAABE9E7E8E1E1DFE2E2E0E1E1DFE3DFDE
E5DCDDEBDFDFF4E4E462534E9C90847F796BBDBCB700FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FFF1EDF5E1DA
E6C9C1D1AFA5BB9389B48073B16C5DBF6759D06658E06858E36451EC6A54EB6750EC684F
F06D51EF694EF56B51F46952F16450EE614FEE6150ED5F51EE6150F06352EC5F4EEA5E4D
EB5F4EED6152F16558F06457F26659F2685BEE6457F16F5FEA7564D66F5E863021611D10
532214431F133A1F182C19132A1C192D22202F25242E2423352C2D3B32333A3132403436
4B37395330365D262C74292EBF5F60DF726DE36E67E46B63E9726AE9766FE3746DDF7370
DC6E6DD86A69CF6162C85759DE6C6CDB6F6DBF5D5EDB8181DC8A8CDF9093E0959AE39B9F
E29BA1E8A3A8EFADB1F1B0B6F6B9BEF7BEC4FDC6CCFDC8D0FFC7D0FFC8D1FFC3CFEF9FAC
A43F47C54E52EB6564ED6059EC6458E26455D46B58C87563AB73627854466E5A516D645F
635E5B585453575153464243403C3B3433312F2D2E2725262A29272625232D2C2A2C2827
2C2825312D2A2F2B282A26232F2B282A272226231E2B27242C28272521222822262A2028
332C33CDC8CCEEECEFE3E3E3E3E3E1E3E3E1E4E4E2E1E1DFE2E2E2E3E3E3E3E3E3E3E3E3
E6E4E5F1EDEEC5BCBF70676A685F60A49E9EE8E4E5E5E3E4E1E1DFE0E0DEE1E0DEE3DFDE
E5DDDBF2E6E6D1C1C1463835B9B1A69E9C8FEBEAE600FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF4EEF9E2DACCA49AA2685AB86B5BC86957D66C56E47059E87057F07458
EF7455EC6D4DE46143F06A4FEE664EEF6751F46956F36A58F46B58F26B57F16C59F16C5B
ED6A58F16E5CE96556E66253E35E4FE56051E76253E36151DF6653E87965BD5A47913A29
6E26175F24165323174721183C1B162F1612331B19301C1B2C1C1C2A1C1B302021332022
3C23264824285922286E2327B15250E3746DE66B63EB6B60F16F62EF6D60F17367F2736A
F07168F17168EB6A64EE6D67E96A64E86D66E9736FE2726EDE726FD66E6DD46D6EC96567
C26263BF6162C06263C06668BA6467C06B6EC9747BC6747AC6747ACC757DC76A74B64E55
CB5355EA6664E95E59ED6057EB6559DF6556CF6B5BC67D6C9D6E5E52382B40312A3A3531
34302D2B2726302C2D2A26272C28272F2E2C2726242827252B2A282B2A282726242C2B27
2B27242E2A27292522282421342F2B2C272328231F2723202F2B2A2C28292A24281F181F
615A61EFEAEEE6E4E5E4E4E2E3E3E1E3E3E1E3E3E1E3E3E1E2E2E2E3E3E3E4E4E4E3E1E2
F0ECEDCFC6C77A70719E9495C2B8B9A39D9DAEAAA9EBEAE8DFDFDDE1E0DEE2DEDDE4DFDC
E6DEDCF7EDEB998E8A574E47BCB8ADD0D0C600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFF0E9B3988D89604EA96F5BBB7059CD735BD06A53E6785D
E17052F07A5CF37A5BF57A5BF06F52EF6D53EC6851E9674FE86A53E76D56E56E58E6715D
E67360E5725FEA7764E97462E76F5EEA7261E86F5EE16A56DA6551DB6B57DB6E5AD36A57
AA49368E35237C2A1C722A1C6E3025511D124B1C16441D183A1B1634181533191835181A
3414173F15194F1219621318A74544E5746EE76B61ED6B5DEC6859F06C5DEF6B5EF16D60
EF6B5EEE685CEF695EEF6B5FED685FEE6B61EF7067EC7066ED726AEF766DEA7169EA736D
EB746EE6706CE7716DE16E6BE16E6BDF6C69E36F70E16D6EDC6869DF6969DC6163E26563
EB6562EF645FEF6259EA6055E96559DD6759CD7162C684767E564A432F263C332E373330
373634312F302B292A2E2A2B2925242B272426221F29242126211E2D2825292522282520
292621292621262520272621332F2C2D28252924212C26262A26252D292A2A2529221D21
989699F5F3F4E2E2E2E3E3E1E5E5E3E4E4E2E2E2E0E3E3E3E4E4E4E3E3E3E4E2E3E7E3E4
F7EEEFB4AAA9A09292D0C2C2CBC1C095908DB8B4B1EBEAE8E0E0DEE2E1DFE4E0DDE4DFDC
EAE2DFEDE6E07F7B709492869A9A90E9EAE400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00EEE7DFA391838A6D5B946754A76D59B56D57C16F57
BE674BD07256DE7C5FDC7759DE7558D76B4FD86E54CF674ECF6D54C0644DC26A56C6715D
C26F5DC3705EC56F5EC6705FCB7260D17663D07361CD715CD0745FCC7059D2735DD37762
C56954C16953B15C48A65544944B3A7E3B2B692B1E581F144C1A1144150D3E110C3E0E0C
400D0C480C0C52070B5D0305A23936E8716BEB6D61EB695BE86553ED6857EF6759EF6759
F26A5AF06858EF6759EE695AEE685CED695DF26E62EF6B5FEE6C5FF27063EF6D60F06D63
F06D63F26F65F06D63F26F67EF6C64F26F67F5706BF26D68F26D68EE6763F16862EF645F
ED6059F3665DEE6157EA6256E66659DB6B5DD07A6DB97D725F3D343D2C253B3330343331
3433312C2A2B2927282A26252824212925222B262327221F2D25232E29262E292528231F
28252026231E27241F27241F2723202824212822222F29292822222E2A2B2F2A2E2E292D
C6C4C5EFEFEFE3E3E1E2E2E0E4E4E2E5E5E3E3E3E3E3E3E3E3E3E3E4E2E3E7E3E4E5DFDF
F4EBECE6DADAA59796726463675D5B8F8A87E6E5E1E5E4E0DFDFDDE1E0DEE2DEDBE3DEDB
F2EDE9CBC8BF8587797B7F719EA19800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F2EEE2D9D2C3B2A89F887A92715E946B55
9E6F55AA745AB1735AB07055B67359AE6D51AE6E53B1755DB27F6ABD8F7FBE9486B89084
B28C7FAE887BA98175A47A6CA37868A67868A0715FA1715DA27059A6745BA47058A77157
A86E56AA6E54B2745DB3725CB26F5CB06C599A51408940317D3425772D206D201667190F
67170E69120B6D0E0A72060397201AE0645CEE6E63FB796BF4715FF4715DEF6A59EF6A59
F06B5CEB6657EE695AEB6657ED695AEB695BEA685AED6B5DEE6A5DEF6B5EED695CED695C
ED695CEE6A5DEF6B5EED695CEE685DF16B60F36A62F56C64F0655EF0665CF2655EF0635A
F2655CEF6258F06359EB6559E26859D66F60CD7F72A36D614D2F2741322F3E3634353130
302C2B332F2E2D29282B27242A26232925222C26262A252227221F2B26222C24222D2523
2C27232A252128232026221F1F1B1825211E2723222925242721232B25292620244C474B
E5E3E4E8E8E8E3E3E3E3E3E3E2E4E3E3E5E4E2E2E2E3E3E3E4E2E3E7E5E6EFEBEC908A8A
968D8E998F8E9F9492978C889A938D97948FDAD9D5E7E8E3E1E1DFE1E0DEE1DDDCE4E0DD
EFEEE9B1B3A88E94866B7366D7DCD500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F5ECE4DACEC4B4A4
AD9887B39A86BA9B89BC9B8AC3A08DBE9E89C0A18DD8BDACF1DED0FFF2E8FFF6EDFDF3EA
F8EEE5F2E9E0F2E5DDEDE0D8EBDDD2EADACDDDCBBDCFBCADC3AE9DB8A390AA947FA28772
95796391715C8E68559166539665549B6654A36858A76857AB6858A86353A155479C4E41
9C4A3EA24A3EAB4D43AC453CB6463BD86457DF6759E56B5CE96E5CEE715DED6E5DEF705F
F07160F17261F47262F57363F27060EF705FF27062F16F61F36F60EE6A5BED6859F06B5C
EE6A5BED695AEC6756ED6859EF6759EE665AF2695FEA6056EF655AF06359F06359F16359
EF6157F26659EE6255EC6859E06657D77061CB7D708F564B4F2A22472F2B40312E3B302E
342A28352D2A2F2A272E29262D2926302C292C28272925242E2A272D28252C23242B2223
27221F2D28252C27242B26232824232622212624252725262722262B242B1C151C928D93
F3F1F4E5E5E5E3E3E3E4E4E4E4E4E4E5E5E5E3E3E3E4E4E4E4E2E3E9E7E8EAE8E9979392
817B7B7D75737E767381797679767163625DDCDDD8E5E5E3E2E2E0E1E0DEE2DEDDE9E5E2
EBEBE3A0A398626A5D8E968BF6FBF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFBF5FFFBF5FFFBF5FFFAF5FFFBF4FFFAF300FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDF6EEF5EEE6
EDE4DBE7DDD3DDD0C7D0BFB5C1AFA3B4A193AB9387A4887C9F7F729E786B9A6F5F9D6C5D
AB7364AA6D5BB57061BC6E61C06A5BC76A59CC6858D06958D36854D76855D86755DE6B59
E36B5AE16857E46959E56758E96C5AEA6D5BEE6F60F37463F3725FF47360F26F5DF87563
F67361F77462F77364F67263F67162F67162F16B5FF36B5FF0685CF66E62F4675DF4665A
F36559EF6153F16556E96455E06556DC7063CC76697E3A2F521D154B231B3F21173A2218
3320192F221A2E272128242124231F2726242523242422232625232A26252C26282C2628
2E282A2B25272C23262B25252C2829201E1F211F2228262B2621282520273E3940D9D4DA
EEECEFE5E3E6E4E2E3E5E3E4E4E3E1E4E3E1E4E3E1E4E3E1E2E2E0E3E3E1E1E1DFE3E3E1
E5E4E2E5E4E2E7E3E2E7E3E2E4E3DFDADAD8E3E3E1E2E2E0E2E1DFE1E0DEE4DFDCF2EDE9
C1BEB5787A6F646A60CFD4CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFFAF4FBF2EBF5E8E0EFDED4EAD6CBE3C9BC
DDBDB0D0AC9ECCA093C79688C68E81C38576C27F6FBE7566BF7363C07160C16E5EC46C5E
C76B5CC76A59CC6B5BD06C5DCD6758CF6857D46959D46657D76855D56452DB6A58DB6856
DA6554E16C5BE06858E36B5BE26859E56A5BE56A5BE76C5DEB6D5FED6D60EC6A5CEB675A
E76253E56051E66152E46252DD6354DC6E5FC165567325185E1C0C511C0A461C063E1E07
361D07291806190F03100C030B0A050B0C070C0A0B0D0B0C110F10100C0D100B0F171216
1B1519161014120C0E140E101D1B1C2A282B2F2E342F2E36302F373E3D4598979FDEDDE3
D7D6DBE0E0E2E4E2E5E7E5E6E7E5E6E6E5E3E5E4E2E2E1DFE0E0DEE1E2DDE0E0DEE2E2E0
E3E3E1E3E3E1E2E2E0E3E3E1E1E1DFE2E2E0DFDFDDDFDFDDE0DFDDE1DDDAE9E1DEF3ECE6
6E6A5F64645894978EF6F8F300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFAF5
FFF9F5FFF9F5FFF7F2FFF3EFFFEEE8FAE3DDF6DDD6F2D5CDEBCDC3E3C1B7D9B3A8D0A59C
C79890C09086BF8B7EBB8678B67B6DB47566B87467B76F61BA6E5EBB6E5CBC6B5ABF6C5C
C26B5AC16654C26554C1604FC66252C86152CB6455CD6355CA5F4FD16153CE5D4DD25E4F
D25D4CD5604FD76250D76251D2614FCE6351BE5D4AA551399C5537894D2977471F6E4B21
61451D4F3D19797053837E6A7D7B6F75746F807C7B7975767975767874757772766D6B6E
7672737F7B7C858182908C8DA6A4A7A1A0A672727C4B4D59474B564A4E576D717A74797F
787D838F94989DA0A5B0B1B5C0C1C3CACACADAD9D7E9E8E4E4E3DFE4E3DEE5E4E0E4E3DF
E5E4E0E4E5E0E3E4DEE2E3DDE3E4DEDFE1DCE1E3DEE0E1DCE1E0DCE3E0DBF1EAE2DED8CC
423F30807E71D2D3CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3FFF9F3
FFF6F2FFF0EAFDE9E2F9E1D7F5D8D0F2D1C8F0CBC2EEC6BCE8BEB2E6B8ABDEAEA2DBAA9C
D9A397D49A8ED59A8CD29286D18D80CD877BCD8579C77D72C87C6FC5776ABE6F62C16F61
BD6A5CC46E5FBD6758C0685ABA6455B66353B26553AE684FA76A4BB3825AD0AA7BC5A775
C0AC7AC7BA8EE9E0BFEBE7CEE7E3D7E9E6E1EAE6E5E6E1E5E5E0E4E7E5E8E6E4E9E2E0E3
E4E2E5E7E5E6C2C0C19B999A757678393D4022272D2F363C3740453A4446424C4E485254
4C56584D5758535B5D51565952585850545370726FE3E4DFEEEDE8E6E5E0E5E4DFE3E3DB
E4E3DEE4E5DDE3E4DCE0E3DAE3E6DFE2E5DEE1E4DDE0E3DCE0E1DBE7E4DDE4E0D7A39F93
484536A2A094F6F5F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F5
FFF8F4FFF8F4FFF8F4FFF2EFFFEEEAFFE9E4FFE6E1FDE1DDFCDFDBF9DAD5F4D5D0F3D2CB
EECCC3ECC7BEE3BDB4E0BAB1D5AFA6D1ABA0C9A599C09F8EA98D75B09979A8966EC6B98D
D1C89DA09B75A6A285D7D4C1CCC9C0A6A5A1B4B2B3DFDDE2D1CFD4B0AEB3B8B5BCBEBBC2
E7E5E8E7E5E89A98997577767379777F88854C5753333F3B45524B45524946534A48554E
48554E4A56524F5A564C575349545047524C495049ACAEA9D2D3CDC8C9C1C6C7BFCCCEC3
C9CAC2C8CBC0CACDC2C9CFC3C7CDC3C9CFC5C8CDC6C4C9C2C5C8BFC1C4BB9B9C947A7A70
8B8B81D3D2CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFBF500FF00FFFAF4FFFAF4FFFBF1FCF3E4DBD5BF9F9A7D9A9778
908F70616145373923A4A698BDC0B7414340404143A0A1A5C0C1C53034374142475B5C60
9C9D9F9698977C7E7D646867737975B8C1BCABB4AF89948C909C92939F959FABA19FABA1
A0ABA3ACB7B1B0BBB5AFBAB4B7C2BCBCC7C1BFC5C1D1D6D0DFE2DBDFE0DADEDFD7E3E4DC
E0E3DAE0E3DAE4E7DEE4EAE0E5E8E1E7ECE5EAECE7E7ECE6EDF0E9F0F3ECEEF1EAF4F7F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8F8F0DDDFD4
ACB0A1838A7A5860515A6459657167303B35333C39505B57C2CDC939444035413F3D4945
47524C4C5550464C48797E7AC9CBCAF5F7F600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00E8EFE8CED5CEBAC4BCA5B0A895A09A87928E76817D9FAAA458655E4B575348554E
5D6A639EA9A3D5DBD700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00ECF0EFE3E9E7DAE0DCD2D8D4
DAE0DC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.013213 0.97619 0.264889 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0FF8000A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF800000FF0000FF00
00FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F000FF00
00FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF800000FF00
00FF0000FF00
00FF00FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF00A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
00FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF00
00FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF800000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF800000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
FF800000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF800000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000
00FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
00FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000A020F0
00FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF800000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.290056 0.477324 0.541732 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F5F5DCDCDABEBEBC959593767674
898B86B6B8B3D7D9D6F0F0EE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEECD3D2D0AEADAB8786845D5C5A3E3F3A2425201E1F1A1C1D18
23261F23261F3A3C375355507C7D77A9AAA4E0E1DC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00D4D3D15D5C5834332F1F1E1A24201D1D1C181D1C171B1A15201F1A20211B
22231D1C1D151B1E17181B1421221C22231D54554FC6C7C200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00F3F2F0726E6B211E1923221D25241F27262125241F22211C221F1826231C292621
23201B23221D201F1B22211C26272123241E22251E3D3F3AA7A9A6F6F8F500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A5A4A02F2C2725221D29262126252024231E2926212D2A2535302C3A3531393430
35302C37322E36312E2C282529282323221D2627211E211A2527227D7F7CE8EAE900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D0D0CE41403C23221D27241F25221D23201B2A272238332F3B3632423A38433B3939312F
3C3431433B38423A374139363C37332F2A262926211E1D181E201B1A1C19797B7AF5F7F6
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E8DAD9D1BFBDD8C6C4DDCBC9E5D3D1EAD8D6
EEDFDCF6E7E4FBEBEBFFF1F0FFF7F5FFF6F4FFF7F500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F0F0EE
6C6D681D1E1922211C25241F211E19211E193B36323D383435302D39312F393031332B29
372D2B3B312F3F35333E3432443C39423D393D383425241F1D1E191B1D18323431CDCFCE
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECD7D47C5751582B2561302C6534306D3C376E3F39
784B467F544E865D598D6661916B6892716C987974A68985AB8D8BB59996BB9F9CC5ACA8
CCB3AFD7BFBBDBC3BFE1C9C5E4CFCCE8D6D2ECDDDAF2E4E3F4EAE8F7EFEDFAF6F5A6A5A3
2F2E2A25241F24231F22211D1C1B162B2A25413D3A2F2B28312D2A2F2A272F2A27312C29
37302A342D273C332E3B322D3B342E3D383245403A35352D24251F23241F232321878785
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F7DFDD8D64606B302A75302973292670262370292369241D
6A272164251E6A2D287E433D733C376C3A336A3934683B366236336438355B322E5C332D
5B342D5A332C5530285D3832623F3963423D6B4E4A6C534F6D5A565E504D554D4B37322F
26221F272621262521231F1C19161137342F423D3A27221F2C28252B2724282320302B27
332C262F2822382F2A3B322D362F2939352C38332D43403938373221221C23241F40403E
DCDCDA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAE6E59D706D75312E873633872D2C862D29832A26812927812C29
7F2C287A2B267729257D33307A372F7B3C357136306B322B68312C713C3667322C6D3830
6D3B327242386F3E376C3B3471403974453F673A34562D2753352D2F1812130502211916
2E292625211E26221F221D1A221A173A322F463C3B261E1C36312D312C2827241F292621
2A25212D2522332927372D2B362F2938332D2D28243F3C3740403828292323221D21201C
91918F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFEFEDA88281702F2D87322F8829278C282896302E8925238E2C2B8F312F
882D2A882E2D832E2B81302D7A2F297C362E77342C692A237539317A3F376F342C70372E
69332969352A6E373070393278413A8F564F7C433C622D276F443D47261F1F0A05271C18
2E262326211E28232025201D221816352B29493E3C2F252338312B39342E29241E27221E
26211D2B23202E2624352D2A342D2739342E26211D34312C44443C30302823221D1F1E1A
424240D8D8D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5BC9693692E2A8938359B3C3AB34B4AC65C5C9D3534932D2B9836359E3E3F
993B3B9C4241933B3989363280312C7F362F8C474073332A7C40388449417F463F763F38
7C473F744239713C366C37316F3531753833793A356D302B7D48406237302E110B2D1B17
2F24202E26232A252227221F271D1B2F262144393540352F382F2838312930292329211E
2B2320261E1C2A221F2E2623342D27453E382A252138332F4B48432F2E29252420272622
26262480807E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00C6AAA7662F2A732521A14341B74F4EBC5252B94F4FA03837A94543A64445943435
943636903534943A398F3A378637327C312B742F2875362F6A2F297039327A453F7A453F
84524B814F48723D37753E39743734712D2A762F2B752E2A8946407C433C4C1F1A3A1914
361E1A3526232E23212B23202D23212B221D3027223C332C443B343E352E312A242F2822
322A27271F1C231B18302923413A34423D372F2A26423F3A413E392A292424231F292824
2A29272F2E2C706C6DA6A0A0CFC9C9F0EBE800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D2B9B4693C3669201A89302CAB4541AA413EA8403DA33D399634318E2F2B8A2C2C882A2A
892B298A2F2C8D32318A32308736326D241E8A49439A5F59753E3979464285544F895853
8A5753925D5987504D8B4F4E904F4D843A3981302D83302C8C3935984944813E38561F1A
3B120C3A1D1735221E2E231F2B211F2A231D2A231D2B241E4138334A413C49403B3D342F
3D3630332C26322D2739342E3D38323D3A33423F3A3E3B3634302D2A29252524222A2927
242321201A1A1E14151D0D10422E2F715B5D877173B6A4A4D9C9C9F4E9E700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7D5D1
7249435F20197D28239B3735A63E3BA23A379C363293302B8A2B27842624882A2A8B2B2C
8C2D2B8B2C2A89292A872C2B822D286C211B92514BC58B87AB767094635E92615D93625E
A3706CA5706C9A6261935757945253863C3D8A3636862C2B8E302EA04240A149478B3D39
5E221A4819133D1A16361E1A2F201D2E252029221C2B241E2D241F382F2A453C3747403A
47403A47403A47423C46413B423F3843403943403B2F2E292A29252A29252B2A28262221
261D1E271B1D230E1326090E3F1F225E3C3D5737384A2C2C4C332F65504B897871B8ABA3
DBD0CAF5ECE700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B19591
622B2671241E9132309F3937A33D3B9F3937932F2D8F2D2A8F2D2C8E2C2B8C2A2B8D292B
922A2B8C242591292A8D2B2A8E332E8030296D28218A4D48BB867EBC8A8394615D895653
B07D799C6763AA72719A5E5E7F41426F2B2C7526297C26278F2F30A23E3EAB4543AA4B47
9B433F762D27551B174519163C1E1C3724203325222E23212C22203228262C2421322D29
312C283B3632403B373C373339363136332E2C2B262A29242928242726222B2623291F1E
2A1A1B341B1F2D0C133910184C1F245F32358E6465916B687D5B5265453A5639294D3221
5B41306F5848957F72C1AFA5E3D2CAFCEFE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FBE9E5835E58
65221C842B279F3937A2383898302F9D3735993331952F2D902A288C2425942A2C972A2D
962829962527962829992F2F922F2A8A312B7C312B81403A8D564FBC8A83C79491875451
A26F6CC18E8BB67E7F9A5F61A66A6CAA6A6BA75F629242458933348E32339D3D3E973939
933B39984A4882413F5C29263B15143D211E4028283A26273323233325242D2220312725
352B292F25232F2523362C2A2F2724332B282A25212D28252E26242A201F2D1D1E2C1618
38191E38101834050D4D1A215A252D5C282C7141419A6F69AB83799A756397745E907155
8265476E51335A3F2450361F573E2A6E5948938175BFB1A8E2D5CDFAEFEB00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DBC2BD653630
70221E90312DA13835A537369C3030992F2F9C302E982A299729289A2A29A02C2DA32C2E
A22B2D9E2729A52E30A43031A133328B282395403BEDA6A0C88D87915F58D29F9CAB7978
703E3FDBA7A9D49DA26E353BB77F82DB9FA1C8878BB16F71AB696A894546B97375D99395
BE7C7D8E5051793F3E734140653D3D4927264E2C2D48282B45282A43292C3D27293B2729
3523233422223323233626263424253222232E1E1F311E22311C21361B2039141B390E15
410E15430C12561A226B2E36682C34652E33643032764642A27A6EA27F6B937457937752
9880529A7F509D805495784E80623C6F512F5D3E2253351D593C2A725849978176C3B1A7
E3D4CDFAEFE9FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE8D88602622
7D2A269C3836A33735A13130992B2C99282A9D2A2DA12D2EA83435A42D2FA62E30A92E30
A92E30AA2F31AE3336AB3335A733349F3130842221B86561F2ADA8CD928EA06966D7A4A3
926063D6A3A8F1BCC26B363C935A60DFA4A8B07378BB8082905A5AAF787BF0B9BCF8C1C4
F0BCBEDDABAC916161CCA09FF0CAC9BC98985D3639553133502D3140202548282D523237
4525284022243E2123381E213C21263B1E233A1B2334131C3B152043152048101B4C0D18
53101964212A7330396D2E36894D5570393E6935375727237B5349A98672A5876B8E744F
8D7545917A44957C449D824BA1834FA384559D7C5193714B8463426A4B2E593D254A311B
543F2C716050948477C2B5ACE3D8D2FAF2EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8EAE7825B5663241F
883231A23B3CA336399D2C2E99262BA02C2FB94246B94045BD4449BE4648B73F41B1393B
A93133AB3335BA3F44AF3437B2373AAE3739A431348C2624A44C4AEBA29CCC8C8AC08887
D5A3A6BC8B8FEBB9C2925F685E272DCB9298AB7076CC9497AD797B875556F0BEC1EAB9BC
956769BE9495EBC3C3F9D6D4F8D9D7E8CAC8856566D0B0B3D8B8BDA8858B5C333B5C2D35
602F3557292C471E223D161B4118204B202A481826440F1F511628591627681B2B792636
7E2E397D313B78353C70353BA77278916064774649693B3B5D342E7E5A4CB1917CA68B6D
90794F8B7543917B42968044947E42957D41997E47A28752A78D5AA38958A2875A927950
8167426E5433583E234D351D5A4331705D4FA18F85C9BAB3E8DAD7FEF4F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D9C6C26B3C36722B27
9439389D34389D2F32AA393D9B2A2EAC3B41B7484EA9383EBB484DC45156DA6669E67273
E36C70D2595ED55A5FCA4F54CC4F55C3464ABD4245B541429F39379E4541D58783E7A6A4
FBC5C5C49397A27379EDBBC4AC79807B444AB57C83E3AAB0EDB5B8804C4EDAA9ACEEC2C3
D4AAAB855F5EC09E9CFFE3E1E9CDCA9D817E856968F2D4D6F8DBDFFDDCE3E2B9C1976870
79464D6F3E429B7175C79EA69A6F79623441834E60C1869CA36278BD74888F3A4F9C4153
98404E86353E833C42A96C71A87174A37174966666956767986C697A544B967264B99A85
A58B6A8C754B8069378A743B927940967C419B7E449B7E469E844B997F469E834CA58A55
AA8E5CAB8F60A78A609476507D6040654B305B422C4D36245946386F5D539E9087C9BFB6
E8DDD7FEF5F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE918D6B302C85312F
9B37399E31349D2E34A6373D9D3438B55255BC6166B85D62AF4C51AB4447AE4144BE5051
D66368D96268DF666DEC7176E3666CD95A61D6595DD2575AC65253B64D4AA54644BF6E6B
F1B1B1FFCBCD98676A96696CF7C8CED29FA4935A61A4656DCA878E7C3E43C79598EAC0C1
C39D9CCAA9A4977873ECD0CCFEE5E1DFC7C5A98C8EE7CACEFADFE4B6999EDDBEC4E4C1C7
654145AE8A8ED0B0B5DDBEC6F4D3DEBC98A6906377EEBAD1DCA2BAD38FA6C16F86A0475B
A74C5D822C37B0636BCE8C8EA46868AE7675A06A6A996766A3736F996C66986D66A98376
B99984B193777D613C583B11714F22815D2D8C6335976F3E9E7A489F7E4B9F804A9E8149
9E844B9F864D9F864DA58C54A58E5AA58D5DA0875E957B587B604362462E4C311C472D1C
573D2E735D50A08C83CCBBB3EADDD7FDF4EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAE8E6845C5A77302E943636
9A2D30AE3B40B64147BE4F55A43D41AA4E51EE9FA4FFBABFEB9296DB7C80CD6A6DBB595A
A94448AA4146AD4046BA494FC45158CD5860D96268DA6166DA6365D56363D16563BB5C5A
BE6E6DF7B3B2FBBFBF8C5656B17D7FFFD1D5F4BDC3995C638A474E88464A8C5457F6C8C8
BB9592B1928DBA9B96B39793F9E1DDF2DAD8E1C4C6D4B7BBFFE2E6CFB2B6A88B8FF3D4D9
997B7DE2C5C7FFE5EADFC4CBECCED8FFDEECC79DB1B2859AD8A4BBEAAFC5E69EB49E4C62
A750618E3845A3525BC87D829D595AB87878B07372AE7271AB716FA26B6897625C7E4E44
A97F71CCA794AF8B717B583869411D7C50297F52298051277F5429875E30936D3C9B7743
A3844DA4874D9D8346A38B4DA28A4CA28C52AA915BAB9160A88D62A48861977A5A826448
694B31563A24452C163D26145441327563579F9089C9BEB8E9E0DBFDF5F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E1C5C2753F3D832E319E3438
A42F35B93E43BA3F44B84349B0464A95393ED98C92F6ABB0C0696FC56A6FD98384DB8B8C
E3979BD08186C56E74B55860A2454D9E3D44AB4249BC4D54C55458C75457D05E5ED26463
D36B6AD77977FAA6A4DE9292AD6664D39695FFD9DCFCCBCFB77C82A26467884849BA807F
F3C8C2A3807ACBACA7BCA09CE2CAC8D2BABAD9BBBDE6C6C9E4C4C7FFDFE3DEBBBFF0CDD1
D5B7B7CFB2B4FFE7EAC4A7ACC2A3A9FFDCE6D1ABBAAD8496BA8FA2D5A4B7FCC1D5B36E81
88394C8C384886323F903F4686373A8D3E41AC6062AF6566B3696ABF7876B6716CA3625C
7A4136BE8F7FC99F89A880667D553270462083532B87562E84532B87562E84502B86552D
885B31976E40AC8854AC8D54A58B4EA58D4FA48F50A28E51A08D559B8A56A08B5EA18B62
A38B659E8660957D5979613F664D2E4E34193D220D3E2413533D2F78665AAA9C93D0C6BD
EDE4DDFFFAF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E9E8E4D4D3CFC3C2BEA7A6A28B8A886C6B67
65616063625E69686465645F62635D767771B7B8B3E9E9E700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BA94917232328F3034A43138
B63A42C24048B43338B93E43B14449983C3FE19A9EE1A0A48F474AA65C5D914B4B935655
FFCACACE9697C18182D79295D79096E99CA4CE737CCA656DBB4E54B54448BD4B4BB84645
C14F4EC55957CC6868C96B6BC66E6CAE605EDEA3A5FFD9DBFFC9CCBD7D7EAC6263A15A58
D99F9BE6B7B1DAB5AFE8C9C6C0A2A0EBCDCDB99798E4C0C4D4ADB2D0A6AAF4C1C6F1BDC1
FDCCCFEDBFC1FFD8D9E0B8B981585CDFB6BEE0B6C0A37985F6CCDAE2B4C1DCA7B7DC9FAF
9952647E31417B2D3A7E2E37792A2F7B2C2F9141448331359D4B4DA55053AA5656A25450
6F2A238C5246C39482C79D84A47D5C7E583173491F774A20794A207E4D25854F2B854F2D
844F2D784621805028906538A27D49A98A51AA9053A49053A39459A69B63A195639D9063
998A5F9E8D629E8B619E885FA28A649A805D8B7150785D40664C33472E1835200D362513
5040307A6C5FA89B92D3C9C0EFE6E100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00EAEAE874757048474232312C2625212F2B28322E2B302C29
312C2939353239363137342F32322A2C2C242F2E294D4C4890908ED4D4D200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F9E7E58F625F782E2D983337B13A40
BF4047C03A43BC363FC14249B7494C893130EFB3B2F1C4C1AB7A767D4A4661322CC79C95
FFDDD7ECC9C37C504D704242DEB1B4FFD3D9D58892E48791F28A91EF8285E27676D26463
C65857BC4E4DBD5053BF5557C86061AD4D4E934143E8A0A3FFD0D4FCB8B9D37F7FC66E6C
B2635ED7948CFECBC7FFD9D3C39C97D2AAA8E5BDBEB48A8EEABDC4C28B91D98E95E48F96
EA959AD98789CF8584EEADABDFA5A4C08C8EFBCAD0B4858DC6949FF6C2CEBE8895D9A1AC
E6AAB6A7697472333CA3626AAB696D934C527B2E348332388D363C92373C8F3034903636
883734702C23925D4DD0A68EBB9878A181588E6F408665327C58267C542376471D75411C
824A29854A2C82462A8247297E48248C5D339E7847AA8F5AA3925CAFA570A39D6D959267
9A96709C96729C946F9A916A9C8E679C8D649D8B63A08D659F8C64947E57806947664F2F
50391A452D11381F093B241258423478665AA99A93D2C7C1EEE7E1FCF9F400FF0000FF00
00FF0000FF0000FF0000FF00898A85191A141D1C1723201B2825203B36323E39363A3532
3F3734473F3C473F3C453D3A403B353C37313B3831312E291D1C1731302B8E8F8AF4F5F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DCC4C277403D843330A1373BB73E45
C1444CBB3C45BF4049BD464CB44D50742521D2A099FBD7CBFED9C9BC9785A7826FF3D3BC
BDA18BF4D8C2C0A18DBB9B8CF7D6CFFFD9D8C27B83AA4F58CB6068D8656CE57275EF7C7F
F58182F27E7FE67275D86467C75457BB4F4FA23E409C4443D6878AEE9E9FCD6D6ED16D6B
D77874D07D77DD9A94FFC7C3DAA5A1925F5CE2B2B2DDAFB1F8C7CDEBAEB6BB646DC65E67
C55A60BE5559A24444CA7473F6AAAAE39FA0E5A7AAE8ABB09C5D65E6A7AFC1848C8A4F55
E7AAB1C68990A96B70DB9DA2DD9FA2D29195C47F848F424A852E3690333B902C34903034
8F35357B2C276F2F25C79783DEB99CB99C74A68A5A957A457B5C26906A3997683C905A34
85482B803C2589402F8E4534813D287C3F2378441F90693EA28A5AAA9C6B9D996A68693F
6365407A7B598A8A689895729B95719C946DA1956D9E9167998A5F9D8C619E885F927B52
93775087694574533461422654361E3B200B2C15053A2719544437766A5EA9A097D0CCC3
EFECE500FF0000FF00B6B7B22A2B251B1A152E2B2627241F39343045403C3C343239312E
3C34313B33304E44424D443F3B322D3D342D433C36433C343431281C1C12212119979892
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B59693793937913736A93C3FB84147
B94248B23F46A3363C9532379945455B1812C5998CD0AD97BC997BEFCCA6FBD9ACD0B081
AE8E5DD2B281FCDDB1ECCEA8B8987FFBCDC0E39D9DAD5058CB5561D04E5ACC4951D55258
D45358E16367EE7175F2777AF37C7EEB7979E17372C25A59AE4C4BC15D5DB64C4EC45858
BA5050B65451B25D5ACA7C7ACE8785B87775AF7372EBB5B5FFD5D8FFC6CCC77079C95F69
D36268D05F63C65C5EDF7B7DDD7F80C86E70B76164E28D92A65156AD5B61EBA0A5B87074
BE7679EEA6A9A75C60DD9598D391927D3F40D09297CD878F8A3942AF545DB14D57922D33
8E2B2E892F2F6F241F854A3CD0A38CCDAA8AAF8F66AB8C5D7B59295E330679451D8D512F
A35D439548347D2B1F8B372D8B392E873A2A7C3823763F21805A339C8657A69B6D8F8E60
50552D4B532E555A3A5E61446C6B4F817C5F938A6B998E6E9D9370A3967394855E947E57
9A7E5686663F7C5A3484613B83613E81603F7152355E4026492F1638220A311F093B2E1B
544D3D7B776CA29F984948431F1F1725251D2A27222C272345403A403B35362E2B372F2C
3A302E332A255449454E433F382D273B312845383242382F4841373D392E27241B32322A
B0B1AC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9EAE78C64627B3432983637B64549B43D43
AD3C40A73E42B85E60A85A5AA8635E854D40D7AD95D7B391C7A172D6AF76D5AF6EC6A059
EBC57CCCA760D5B771C8AB6FA98A5BE5BC9EF9BBB0A85454C1535CCE525DD1525DD04E58
D14D58CE4B53D24F57D45358D5575BDF6466E97172EE7A7AEE7E7DF18382EA7E7EDC7272
CB6765C16361AE5A58A35956A35F5CAD706DB07473A3686AE1AAADFFC8CCDE838CCA5C65
CE5961D05B61C95B5ECB6364C9696ABB5F60BB6264BA6467B65D61A44B4FA65458D18184
DA888AE69496BF6D6F954747DB9796A26564A1666AF4B5BDA0505B9A404AA23C4790272E
972E35912C30872D2D691E18925948CDA188BF9B79AC8B62A58258693E1466300A7C3B1B
893D258A37277F251D8D302B8D322D8D342E86372A803C276D3A1B68451D907B50A8A173
83845A484E28424727676A4F7D79606B634C6B5F4770604676674A8677568474509A875F
947B5281643A7F603477562B73522785643B75532D71512B785832745833614A28534224
372B13231C0A1912081C1912201D1625221D26211D27221E4A453F39342E3028252F2724
2C251F332A254C433E473C382F241E372C2641342E3D332A433A314541363E3A2F24241A
3B3C36C0C0BE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00DAC5C27747457E2E2DA63D41B84147B53C43
A6353999393AEDA3A0FFCCC4F4BFB1ECBCA5F4C8A5C49A68D4A869EDBF74E4B460DEAC53
E1B457F2CA6BBD9C3FDDBE6BCBAE68C9A873FFD6BAA466598C38369F3E45A9414CB44452
C54B58D04D5BD54D59D54C54D64D54D24B51CB484DD05255CE5858CF6160CF6B69C86F6B
BA6B64BD7A72B67D76B1827CAF8682BA8E8BC89697B2777BA56367D7868CC25D65C45359
C64F55C14C52AE4446BA5C5CCC7B78B9726EB57170B06C6DB3686CB7686DB35E63A85157
BD6267B15759AF595A803031894343BD7F80D4999FFFC1C9A85C68872F3BA139449D2E37
9F2D37982930942B2F852A276A2118A56C5BDAAE95B4906EAC89639E744C6C3813773618
893B258A32248E2F298F2D2C9331309132308E342C88392C7B392366331464421C8D7A4F
ACA5777F805440401A535031A1977E93816B7A5F4C866A54775C41705738604A25746137
7C673C7D683B826C3D7D6537816639937748795A2C70512378592B7E6233604A1B655228
746544574D3421190C1B140C27221E27221E27221E221A17433E3839342E201B17211C18
241F19362F293B33303B312F3128232E2520332824382F283B342C3A362D454138282820
1C1F165B5D58F2F2F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00B19391703837872E30AC3F44BB3F47B6393F
B5424592302F904943FAC4B8D5A692BC9171DBAF80CB9D61E7B76FDEAC57DCAA4BCA9932
BC9025DCB347CBA93DDBBB56E3C56DB5974FFFDAA9EEC09FD59A88CB867FBB6C71BA5E6B
C65767C84A58D34B57D54851D44950D44D53CF4E52C85153C85C5CB55755A554509A574F
A97369C09489B9978EBB9E96B39A95AA8D89AE8887BD8B8EBC7B7FAD5B61C25D63C15056
C24B51C04C4FAF45479C4140B46963B67A72AD7874A87773AB7374AF7174BD767ABB7074
B9686EAE5E61A95D5F7933359E6262A87073B0757BFEBDC5DB8F99A349559F3541A93540
A32B35A42C359D2A2F9830317A221E732D23C18978DBAF96B7906FAF8763A573506F3213
782D168C392990332B8F302C8E2F2D8E302E913830873529823B27753D2258300D61481F
9C8E5DABA573706D403C38126E6347A8937E77584665422E815D457C5B3C7456326F562D
664F236D5829725D2E76602F7E68378A73419379468E733E876C37866D37614A165F4A1B
8071486E6345271E0D1910072E27212B2622261E1B271F1C362F2945403A2F2A26211C16
25201A2F2A243D36303B342E342C29241D172C231E2D241F39322A39352C49463F33332B
1E211843463FE5E5E300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F7ECEA8F6968763636933438B23F46B3343BB8373C
BE4346B14747802D29AC6E61F2C4ACCAA37CE6BB86EEBE7CEFC072BC8D35B58926C59C30
D2AC3DC5A22EB3901CB69524EDCC65C9A74ED6B46AE4C084F0C69CF2C6ADFECCC5FFCBD2
F08E9BC04756D34C5AD44851D44B52CE4D51C85558BB5958A6575395564FA4736CBA948B
BB9D93AF978DAC988FB3A099A5948C9D8A84A18884A78383C28E92C37C82B95E65C1565C
BD484EC14A4EC251539C3A37944741AA6E66A1746E97746E9876749B77779F7778A67A7B
AF7D80AC7A7BA47275956467F1C7C9F4C7CC93575FB8727AF3A3ACD47982A3353EB03841
A93037A92E33A72E339F2E30932D2B7A221E874338DFA796D4A88FB28969B18560A06C47
6A2B0C7E331C8936268B3329893229822E247D2F2277301C76361B754021653C1E422400
8B7A46A69C61ABA8715D5B2B3D3413827259B0958266432F774E388C6045825A3775522A
6243175B4011674F1F523C0B564210634F1C705B2677622B786229836D347C672E776330
8173466F624021190621190E2F281E2F28202D241F261F192A231D3B342E453E38332C26
27201A2E271F403931463F37372E29261D16281F18292019362F273A362D48453E33332B
24251F3C3D38D9D9D700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00DBC9C77345457D3536A23F44B03B43B4353CB93B3F
BB4748AC464480312A6E3323EBBFA2E7C194C29659E6B86DB0822DB78B2CEBC259F1CB5C
F1CE5AF3D058F0CC54D1AC37BC982ADBB955D0B157DDC074CCAF75A5855EF7D2C2FFC5C7
BE616CC44E5ECC4957CD4A52CB4E52C55456B25454974E4897605BB08A81BEA199A9958C
9E8D859B8D84A1948CA59890AB9E96AEA199AB9995A58B8AB08889CC9195C27379BC5B62
C6575EC14C52BD494CB64C4C933E399A5A51A4756F95776F8C756F8D7A768C7474907677
957978997B7B967677957779CFB2B6F7D3D7BD8890A36069B86871BB6067B74C54B34047
AF3A40AC373DA9363BA436399D353695373571221DA9695FE8B8A4CDA488AF8763BA8E67
97633C6C2D0C82381F8A39268736257425147A2F1C8B473079391D70391A5D30114E2B05
997E479F8D4FADA567AFAA73534E24483D1F947E67AF8E7B6136238858429F6D52956746
7F552F724D238562385C3D115034055D43125D4310634A145D440C5A410870581C89733A
76643261532C221800231C0A2A2414312B1F332A212E251E271E172C231E3A312C49403B
40393130292139322A342D252F261F2B221B2A211A2B241C38342B3F3C353E3E362D2C27
1F1E19343530CFCECC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00BFA7A76C3636883839A63D42B13A40B1363BB74344
A33F3F81312AA3675CDAAB97E8BD9AC9A16ED8AD69E2B564A37619EBBE57F3C95DF3C959
E5BE47D0A930F5D157F8D35ED3AD40A7841ED9BB5BF2D683AF9451D2B385FFD6C3C28081
B95561CF5667C94B59C54C55BA5052AF5554924F49A06F68C8A7A0BCA59DA291899A8B84
988B83998F869B908A9A8F899D928CA49993AFA19EB3A09CAA8C8CBB8E91D19096C06A73
C45C65C8545DBE474DBC4B4DAA4847863732A46B64A37C759178718A79728977758A7A7A
897A77897A778B7977897576877374A4878BAC8188B97D87CA7E88C06971B34F57B0474C
AE474BB14C50B04D52A64348A24244A145468935336F2A23D7A195EBC2ACC09E7BB49167
BC9262925F326A2B0880391B8B3E227E2E13792B14994F36A560439D5E3D935B38996A40
A9824BA185449F8D4DB6AC6F8C895648431B53452AA98F7E956E5F8A594B98604F8F5541
9A61469D6647A671518D5D397F522B7F552B6C471A6947175C3B086E4D17866727866828
674E15635121312402221B01251E0B302A1A332B20372E25342B222D241D2A211A2D261E
433A3349403941383339302B322B25332C2638312B3C3731413C363E3B36302F2A282722
1D1C172C2B26C7C3C000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A88C8B7137368F393CAB3E43B43B40B63B3EAF3B3C
A13F3CE2938CFFD6CAE2B49DB38865DDB381F6CA8BCEA052B18427E7BA53D9AD44B28717
D6AC36E1B93FDFB73EECC550F8D265B59028D5B352DDBF69AB9147FEE0ACF3CBB1965954
AC4F59C75868C3505DBF545CA74F4E96514CA6756EBB9A91C8B4ABA79A919B8E86988D87
978C869A8F899B928D99908B998E889B908A9B908CA69794B19C99B59394C9969BD18A92
C36772C15660BD4952B9464BBD535599403C914C47A3726B977971907C758B7C778A7F7B
877D7B837977827775867A7A8373748D74789C747CA7727AC37A83B15B64A3484D9B4143
9C474AB96A6DB4686CAC6064A4555A9F50539B51526829249A6A60F9D4C2E0C3A5B89B73
BD9C67C59E677D4D1D652A007C390F8139137E33147F3518843A1D8039198442208E532B
96612FA1773D9C7E42A18E53B0A7707F784A3D3212594731AE8E81A67C70915D50814739
8B503E7C3F2A824832A0684FA76F549462418D5D3990643D8B62368B66319B78388A6C24
6348018C7937796C37271E00241D0028210E312A1A3D33293F352B42382F362D262F261F
281F183027203C332E463C3A4038353E39353E39353F3A363733302C282526221F24201D
201B172E26239F9892F2EBE5FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF5F3937472793C3B973E40AD3E44B3363CBA393EBE4244
A0302EBA5D56EBA299FDC5B4E7BA9DD6AC84DDAE7AD3A25FB2842FF9CD6EDAAF499C7003
E8BB46E0B43BB58811CFA433F5CC62CDA742AE8728E9C56FC9A95ED7B87FFCDBBAE4B4A8
A35B5FA24A56B65661AD545A96504EAA7871B08E85AE968CBCABA1B4A79EA89B93A1948E
9D928C9C918D9A8F8B9B908C9A8F8B988D89998C869D8E89A59391B59B9AC29B9ECF989E
CB7F89BE616BB84D57BD4B53C05356B2504F9445419A5D589E756F977C75907F788C817B
877E79897F7D867C7B84787887777A8F767C987079A46F77B86F789F4E549C4A4C8A3E3E
9C5F5CAA7774A77777A37577A67477A16F709E6C6D855855714C46E7CABCFFE5CED6BE9A
BCA06ECCAE72B49253764E116B3A02672F006628016D2B097730107E33147C2F117D3212
7B360F76390D71421491713EB19D68B1A573695D374436196C5A46927668906C5E8C6053
8C5C4E774335764133824A3B8E564589503D8A533E925F44865834926A39A27F3F987B2D
967E24B7A448BFAF5A70631F281C00251B022E2311332A1B392F234B41374E443B443B34
3B322B2B221D2B211F291F1E2B232127221F2923232B2726251F1F221C1C241E1E2C2422
2C222032251F37261F6B594FB5A399DBCAC2F7EAE400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00F4E5E286605D7F3B3A9E3F43AE3B42B13239BF3940C13C3F
B83E3DA338328B372DB67768E9B9A3F5CCACCEA275E0AF75B4843ADBAD57FDD170D2A63D
EBBD4DCFA02CB68715E9BB4CF8CF65C69F3AB68F32EFC974ECCC83AE8F58C3A281FFDBCE
F7B9BCA65D68A5555E91494DA16C68BA958DA48980A08E84A89A8FBDB0A7CDC0B8BEB1A9
ABA09AA0958F9E938D9E938D9D928C9D928C9F928CA0938D9E8F8CA4908FAF9392C2999D
CB8F97CD818BBA5F68B64E57C4595FC35C5FA74D4C8D4340A16F68A07E75957E768E7F78
877C78897F7D877D7C877B7B8676798F747B986F77AE757EAC636A98494E954B4C854543
A3736F97747093757394787796787A9779799878799576747F6662B69F97ECD7C6EBD6BB
CDB78ECAB37FCAB276C5A96AB79558A67D459464347843176F3408702F05702C0776300C
77330C7A3C13602F06633D109A804DB6A672A89C6C5F562D3E33155141287158427B5C47
8B685498725D986D5A8D604D895A488B5A498956437F4F385E3112906A3DAB8949A08431
A68F29BAA636C6B446C4B6557A6D272F2300281E002E24092E26133B3223463C3252483F
564C434D443D3E332F342A282E26242A22202620202C2626281F202920212D2322352B29
3628252B1C1528160C5E483B8D76688972649A8479B5A29BDACBC4F1E6E000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E4CFCC764A478B3D3DA63F43AD353EB5323AC1383FC23A3E
C24040BC4642A8473E863C2F6B3825E0BBA0C9A27BDDB27FC59555B07F32F2C36BE6B856
D5A63CD4A637C39526E2B649F6CB62B18A25DAB356D2AF5DBE9F5CD5B584E1BCA2FFD2CA
FFCACFE29EA99552598D5254B58D8BA58A839C8A809E90879A8D84A39990BBAEA6CABDB5
CFC2BAC0B3ABAEA199A4978F9E948BA297919E918B9F918E9F918E9F908DA18D8CAF9294
B89194C38E94C47D85B35E65C05C64C15A5EB5555697444092534CA77B729C7E76948079
8C7F798B807E8A7E7E8A7C7C8C777C94757BA1727AB778819C51569B4C518741438B5352
A079748F736F8C77748B77768C7A7A8C7A788D79788E7A798876748876729D8C84A79587
A6947EB29F7FBFAC82CAB684CEB87FD3B97ED0B276C6A669BA9658A67E408F652B754811
6537035E32015E35074E2C005D43129F8E56B0A468877E435F5927514A1E60522B614F29
59431A745B337A5D3B8164448D6E4F96775A916F54936F558461419B7A4DAA8C4CA38932
A99123BBA72ACAB935D8C948D2C7539B91324B42002B2300302708322A15372B1B3A2E20
44382C4E443A54473F4E433D4136323F34303E3432403634372D2B332927332824352724
352822271910301E127B6859987E6F8C71608E71619474678E7065997D71AE938AD2BEB5
F2E0DCFFF6F200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00D7BBB774413E933F3FA83B40AC3038BB353EC53C43C4393E
C64041BC403EB64B45A04E43622D1FDEB8A3C09B7EE5BB93DFAF7FC08E51C39349DAAC56
E0B254F3C661F2C761E4B953C09634BB9437E4C06CD0AE66C4A56EFFE0BAEFC6B4B58480
B3767DA86972894E54AA797CAF908D9A87809B8D849B8E86998F869C9289A3968EAC9F97
BEB1A9D1C4BBD3C6BDBDB0A7ABA198A59B92A0938DA0928F9E938F9E938F9D8E8B9E8C8A
A58D8DAF8C90C59096C27C84B55E66B6565ABA5559B459589244409C6159A67B74A0837D
98857F90827F8D7F7E907D7F92797D99747BAB737CB06D76914549994F507E4041966664
9B79778C77728D7B798A7C7B857A78887D7B857A78847977867877817372887A77887974
8A7C718E7E6E9080679C8C6BAD9B73BCAA7AC7B380D1BC85D4BE84D1B97BCDB378C2A56B
B798619F804A8767346A4C18412B00665416ADA35BB5AE66A2A063706F396C663684794C
67562A6C572A70592F533C12644D236750266D542C7D643C8B6F48907442A58A45A38A2E
A9931CBEAA23D2C22FD7C934DBD13EDFD653C3BC546A6514322C00251E002C220031260A
352A143B301E3E32224234273F31263B2D243D30273A2D2435281F2E211833261D36281D
25180824140442311D7A68529F8974937865917260916D5D9974649B76668E6A5C866659
8E7368A18D84CDBCB4EDE3DAFFF7F200FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00C3A29D8045419D4142AD3C40AB2E36C03A43C23940C93E43
C43E3FBF4240BF4F4D903932834A41EEC6BAAA8372D9AF97D6A98CDEAE86D2A36FCC9C5C
C6964AB88B38C89F47B08831C09A47E8C277D8B573E6C38DA4845DDBB9A0F6CEC48D5B5C
8E5055A160689B646AAE8486A188849C8D869C8F87998E889A8F899B908A9B908A9F948E
A29791ACA299BCB2A9C8BEB5CCC2B9BDB3AAA99F969E938DA19690A196909B908C9F918E
9F8F8FA48E90B69296C28F94C37E83B25D64B45458B95659A94E4D984A46A16763AD847E
A387839A8783928080917B7E98777EA1747BB4757EA1585F9045498E4A4986504E9E7674
9379788977758A7C7B8A7E7E867A7A887C7C857979857B7A877B7B817575897E7C8B7D7C
8779768578728779708A7C6F8C7C6C8E7F6A93836A9F9073AD9D7BB9A77FC7B48ACEB98A
D6C08ED2BB85CDB77DC5B071A28F4A83752AA39B48BDBA69D2D38D8F93585E5C2C817952
80714A6D57307D62377C61327F6630776127614B116D591E69521C5941038E7525AB942E
AD981BB8A616D5C62BDAD030D4CC2BDBD63ADED949D3CF51A39F346E68123E37002B2100
231A00261D002F240835270D34251032231038271535241232231031220D30210C281A00
1F110037280770623F76674675654C8A756293796A9B7E6EA18071926E5E95705E96715F
94715E8766538367528B705DA08B7AC8B6A8ECDFD6FFF9F400FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF6F5AF89868645419F3F41AB363CB2333AC23C45C13840C94047
C33B3FC44244BC4445922C2AC67874FFCAC3F2B6AEF7BDB1F5BCABF7BFA8E0AE8BD3A478
E2B57EC99D60D9B26FDEB877E8C486B6915CCDA67BE7BE9ECA9D86D9A99DFFDFDBE8B1B4
9654588E5055B07D828B6767604B468B7E769E938D9B908A9A8F89988D87988D879B908A
9D928CA29992A2988FA99F96B5ABA2C5BBB2CEC4BBBAB0A7ADA29CA297919E95909E9590
9D9391A19191A58D8DB18D8FC99297BA7379BB616ABA575CB95659A34948974D4AAE7772
A7807BA48783977F7F997C7EA0777DAA757DB67078974A50984E4F7F3F3D9366619D7E7B
8E79768C7C7C8A7C7C897D7D857979867A7A857B7A877D7C887E7D837978857979867A7A
887C7C837777897B7B887A79867875887B7585787084766B897C6B8B7C679183699B8C6D
AE9E7AB7A67BC7B585D4C38BD4C486CCC078C5BC6DB9B667D1D58BC3C98B5E603158542E
918464B39F7E8A6E4984653792753B8B702B7D671C8673267D6A1E604B00897212AC9724
B09C15AF9E08C9BB1CDBD22BDFD82FD8D42ADFDC37DEDE42DEDD51D8D65BBCB75397913D
6C651D524D0D3B3200372C002F23002B1D002E20002D1F002D1F00322400382B004A3D06
6B5F239A8E527C6F3A75673A6C5B3D705E4A725B4B81675A886B5D9B7A6BA480709F7C69
9070598C6C538F70549D7F6390775976614672604C867667BCB2A8E9E2DAFDFAF500FF00
00FF0000FF00
00FF0000FF0000FF00FEEEEE9C706F853F3DA43F43AF383EAF3037C23C45C0373FCC434B
C63D44C53C43C74046B4363AC55255D56D6CD77371DA7D78D8847AD38B7DF4BDA9D4A88D
E4B999D2AA86B6936DCEAC87DBB898AC876DFCD1C1F5C0B8EFABA8F5AEACFCB8B9FFC6C7
BB797A884E4DB9908EA789876C5953554842716660968D869D938A998F869C8F879B908A
9C918B9C918B9E938D9F948EA49993ABA09AB9ACA4CEC4BBD2C8BFB7AEA5A9A099A19891
9D948F9E938FA2938EA8908EB79091C99297BD7078BB6069BC575DB654559B43419F5650
AE7770AB827CA17E7CA17A7BA9767BB97B80AB606796474C904849854A46A07773957975
8D7B77897B7A877B7B897D7D847A79857B7A897E7C877C7A867C7B857B7A857979857979
877B7D82767885797B857979867A7A857979857A78877976887B7582756D86797085776C
897C6C8C7C6C93846D9D8E71AD9E77C2B483C9BE80C5BE7AC6C781E6ECAC9CA37043451E
6D684BDBCBB2AA8C726E4A26B9945DBD9B51957A219D87248B7714705D00A28F19B5A21F
B6A414B1A106BDAF0ED0C51EDDD52CE0DC32E6E43AE4E541E3E546E4E44EE6E559E2E260
D9D95FCECD59B6B244A7A33897922C8B862289811F8B812090862499902BA89B35B5A840
BEB14BC4B759A494476C5C21624E2968523B816758866A5F7F635787695E7D6153987E6D
87715A8C785D8C7959937F5AA08D63A9936A9E88637C674858442B625340867C70C4C0B7
00FF0000FF00
00FF0000FF0000FF00F0DEDE906060883C3CA63F43AC353BB8363EC13B42C43E47C64049
C03A43C33B45CA3E47CC4049BA3339B02D32B23638AF3B3BA33A367D241EBC7E73EEBEB0
AB8070CBA191F2CDBBF3CEBEA27C71C19892FFD5D7BF7C839A4147A8484CAB5254C17371
A15D5A9B6662B5908AA68F899D8E897F746E584D47574E477D726C9C9289A1948E9E918B
9E938D9B908A9F948E9E938D9F948EA0958FA2958DA99F96C2B8AFCBC2B9BEB5AEB0A7A0
A59C95A09790A19690A69490A88E8DBC9397CE8F97BC6C75BE5F67BB565AB4545599413F
A66058B47971AF7C78AF7979B77778C27A7DA351579B4B4E853F3F915C58A4817D937B77
8B7C79887D7B897D7D897D7D867C7B857B7A887C7C877D7C867C7B867C7B877B7B877B7B
84787A85797B877B7D84787A867A7C867A7C85797B85797B867A7A867A7A837876857A78
877978897B7885766F8676678B7B6196875E9F9059A39A55BDBE72DCE29AE1EAB36C7148
3D3C1EB4A892EBD0BD65422498703CE3BD72CBAE4AC3AE3BB9A930AB9C1DB8A821C3B322
BFB019C1B314BBAE0ABFB40CD3CB20DDDA2DE6E439E7E63CE2E43BE2E53EE7E946EAEC4D
EAEB51F0F05AEEEE5CE9E85ADDDE54DADA54DAD756D6D151D6D151D6CD4CD7CD49D5C845
CEC043C4B745B09F47927D3C5E471D5A3E266E51417A5C518362598A6C6281675A836D5F
705F4B897D63978C6E9D906D9C8F6599885CA18F61AF9970A5916E7362443B301C746E60
FAF9F500FF00
00FF0000FF0000FF00E2CDCC8451508B3D3DA73E43AC333AB7393DBF3E43BC3D44BB3E46
B73D48B23641C53F4AC73E48C93D46C93E45CD4549C94749C54D4CAC4441843731EFB4AE
D8A9A3FDD2CBF5C6C0ECBDB7DBAFAEE9B8BBFFC7D0B4616BB84952C54E54B44848B05250
954E48B27D77AE8D869E8A839B8E889D928E988D89726763514642574C468274719D8F8C
A39894A0958F9F948E9F958C9F958C9D938A9E938D9E938DA49A91ACA299B7ACA6BEB3AD
C1B7AEB6ACA3A89B95A2938EA38F8EAB8F8EC3949ACD8E96BA6970B5595EB75457B65453
A04743A3534CBD6F6BC47674CA7978C77172A74E50A05051834240A1706CA0817C907D77
8C7E7B867C7A8A807F897F7E8C817F877B7B877D7C8B81808A807F867C7B887C7C8B7F7F
857B7A867C7B887C7C887C7C867A7A877B7B897D7D857979857979877B7B867A7A867A7A
8579798C7E7D8C7D788B7B6E907F659584588B7B3D94893AC4C369CDD27EEAF3B0B4BA8A
53523379715CF4E2CEB7997D744F1BD9B569E0C85ED4C244C9BD35C9C130C7BB27CABF25
CBC124C8BE1EC6BD18C6BE15C9C317D6D324E2E033E8E83AE0E236DDDF34E3E53CE2E43B
E2E33DE1E23CE5E640E5E843DBE03EDCE045DBDD4BE7E658DEDB4ED8D246D8CD40D3C73D
D0C340C1B23DAF9C4098813D71542860412584614E7A564A643E357A584E7E60567D6559
77675868604D736D57A09A80AEA888A59D769B9063998C5FA89B6FB9AD856760436E6C57
F9F8F300FF00
00FF0000FF0000FF00D0B8B87C4644903E40A93E44B0373EB93B3FBD3F43B63B40B13942
F68790E77481BB3D49C9414DC93D48CA3D45CB3E46C73F43C54345BE4A4B852624C77977
FFD1D1F9BCBBA66060874143E8ACAEFFCED4FAAAB5AD4955CB4F59CA494EC14B4BAE4C49
9A534DB98881A688809D8A849C8F89968D889A8F8B9C918D958A866A5F5B4E403D5A4F4B
8075719A8F8BA297919D938A9D938A9E948B9C918B9D928CA39990A39990A79C96A99E98
B8AEA5C7BDB4D1C4BEC1B4AEAE9F9CAD9897AF8B8DCD989EE39AA1B55E66BD5D61BE5A5A
C96A66C56863AD524FB25756CA6A6BC06061B557579D4746964F4DAD7673A37C77997D79
927D7A8F7D7B9384818E807F8F81808D7F7E8C80808D8382897F7E877D7C8A7E7E8C8080
8B7F7F897F7E867A7A897D7D877B7B8A7E7E8B7F7F877B7B8A7E7E887D7B8B7D7C8B7D7A
8C7F798E807790807190806796845C9281498D7D32ADA14BCDCA6DC3C571DCE19FE1E4B7
7473576F6856D6C6B7EED6BE7E5D32B79651F5DD7BE3D35ADDD14BDBD344DAD03DDBD13C
D3CC35D2CC30D1CB2DD2CC2CD2CD29CDCA23DAD730E2E139E3E43EE2E33DE0E239E1E338
E1E337DFE233DEE132DFE334DEE236DBE139DDE142E6E74DE3E24ADAD440D1C732D6CA3A
CEC137BEAE34B5A13E7E671B6B4D196D4C29947056754F3C7D564775514367473A5C4235
6150405F5241675F486A644A827D5DAFAA84B6AF83A59D6E9B9364ACA5799B997386866E
F9F9F100FF00
00FF0000FF0000FF00B89C9B814745903C3CAC3F44B0373EB73A3EBE4145B43B40AD3A41
F78D97EC828EB23A46C4414FC8414FC83F49C43B45CA4149C94248C7464AAB373AA73D3F
F79497BA575AB44A4E9D3438973B3EFFA6ABE9848CB9474FCD4F53C7494ABE4C4BA24742
9F5F56BA8F88A286829C8A869E908D9A8F8B9B908E9A8F8DA09591A196928D8280695E5C
4A3F3D59504B867D78978E87A0958F9D928C9D928C9E938D9B908A9D928C9F948E9F948E
A59A94ACA19BC5BAB6D9CBC8D4C5C2CEB9B8BD9B9CC69599E39EA3BF6D73D77B7EC56566
C76967D27772C96B69AF504EB85454B75051BF5859A64846AA5654BA736FB07571A97975
A47D789A7B769A7E7B99817F927F7B917F7D91827F9082818F81808C817F8F81808A7F7D
8E83818C817F877D7C897F7E897F7E897F7E8A7F7D8B807E8D7F7E8B7D7A8E7F7A8F8178
92817195846A97855F94834F948240928234AB9D44C3BA5DCCC86FC9C77CDBDBA7E0E0BE
918C798B8279B3A29AE8D1C1876A4AAA8A57FAE093F2DB7BEFDD6DEEDE65EBDE5EEAE05C
E4DC55E1DB51E0DA4ED6D443D8D645DAD943D7D63EDAD940DBDC42E6E74BE1E344DEE13C
E2E63ADFE334DCE031DFE334DEE235E1E539DCDF3AE3E441EBE748E0DA3CD7CE33D2C72F
CCC02EBDAF2ABAA83A78630A573E008163317C5C33603D1D8A664C6A473193725F7F634E
6047315540255D4A2A6F613E695D3770693D9E9769B7B384B2AE7F949367AAAA84A9AC91
F8F9F100FF00
00FF0000FF00FFF6F49C7E7C844744953F3EA93C41AD3439B83D40BB4045BB444AAF4248
D5717BDD7985A93B48B74252BB4251C04351BE404CC3444FC2404AC2434AC2474CAB3239
BC474DBC434ACC4D54CC4F559D282EC55259D45B62C94C52CF4E52C44A49BE524F99443D
AE736BB590889D8581998A879A8C89998E8A9A8F8D9A8F8D9A8F8B9D928E9F9492A19795
897F7D5E545248413B58514B847B769F948EA196909D928C9B908A9C918B9A8F899F948E
A39892A29791A89D99B1A3A0C3B1AFE3CBCBEBC4C7E3AFB3CD868CB25D62CE7275CF6F70
DB807DE58A87F09290DA7B79C86464C35C5DC0595AB85454A94B49A85350AA5C5AA96361
AF726FAF7875A97874A87C79A37D7A9E7C7AA18480997D7A99807C977F7B95807D927F7B
93817F9283808D7F7E9385858C817F8E83818E807D8F827A95847A90807197867494846A
98866294825490804492843DA59547B0A450C7BD68D2CB7BDDD894D7D49DC5C29FABA994
9C958DA29897A39594C3B0AA6D5342694F2EA58957BFA260DEC171F0D57AF4DA79F3DE75
F0DE70EFE36DEDE36AEBE366E9E162E7E05EE3DF59DFDB53D7D449EBEA5AE7E753E0E147
E1E340E2E53CE1E539DFE337DEE235DDE135DFE138E0DF39E6E33EDFDA36D5CD2CD3C92A
CCBF25C9BA2BBEAF30A99729806B107D6618836A27785E239F8353775A308266419A805D
745A37765F36816B3C6A562362521E6A5E2A766C3B847E4EABA778A6A579A8AA83B3B69B
F8F9F100FF00
00FF0000FF00F7ECEA8A6B688144419B4341A53B3DAA3337B63E40BA4347BA494FAA4249
9A3B43B0545FA44654A84758AF4A5CAD4657B04555B14554B2424EB7454FB94550B8434C
BE454EC4454ECD4750CA444DC9434CC23C45CF4751D04950CB484DC04A4AAE4A48974843
B9847EAC8B849E8984978A84978C889A8F8B988D899A8F8B9C8E8B9A8F8B9A8F8B99908B
9D948F9D96908C8481574F4C483E3C665B578C817DA39592A49791A396909E948B9D938A
9E938DA29791A49693A79895B09B9ABC9C9DDEADB1F4B3B9C17077B2555DAB4B4FB55255
DE8080FA9F9CF79C99F29794F69B9AE58787D17270D37170BF5B5BB35150AA4A4BA24746
9D45449F4B49A65554A95D5DB16B69B0706EB57B79AD7A77AD7C78A77B78A27C79A0817C
9D807C9B818097828199858693817F907E7A93827A9C8C7C9A896F9886629A875C94834D
8F7D3D94833BA09344B1A656C0B76AD5CC87E0D79CD8D0A1C1BB97AAA68D9F9B8F9D9A95
9F999BA09A9EA399A1B3A7AB8D7B795138316546346B462B875B34B18352DAAC71E8BB77
EFCA7AF4D57BF4DA79F9E37DF4E178F4E475F2E573F3E872EEE66AEDE868E8E65FE5E456
E0E34CDCE043E4E643E2E540DEE13AE2E53CDDDF36DCDE35DBDA32D6D32CD4CD27D5CC29
D0C325D3C62CCFC331CBBE34B9AC2CAA9B26A08F259C8C2D9C8A368E7C34715D1E7A672D
77642A766225B09E56B8A65A8B792F5E4D0866551D756736797142C3C095B0B28DADAF97
F8F9F100FF00
00FF0000FF00E5D7D47B5A55864742953D3BA53B3DAB3438B84042B84447B04348A03B41
AE535CB15B66B46471B66876A65969A254649342517F2D3B8F3B488B333F983B46A13D49
B3434FBB434FC64450CE4650CD414ACC3F48CD3D47CF434CC8454ABE4A4BA849479D5650
BD8E88A2857F9E8B859B8E889B908C9A8F8B978C88998E8A9E908D9B908C9A8F8B99908B
99908B9B948EA099939E9791897F7D5E55504A3F3B685A578B7D7AA2958FA398929E938D
9C918BA29791A49693AA9695AF9294B98F93D4959DD5858EC86770C75E65AE41479C3236
9B3435BD5B5AD47573D97B79E08282E48686E68785EA8684E7817FE47C7BD87071CA6364
B85152B65252A541439F3F40A14343A24848A85452AB5B5AB26867B26E6BB67976B27B78
AD7C78AB7D7DA88081A17D7D9E817D9980799A84769E8A719A886092814D917E439D8C46
A69649B6A95AC5BC6FD8D189DAD496D2CC9AB8B290A8A28CA19B8FA09B97A09C9DA09BA1
A19CA39F9AA1A199A4A89EA7B7AAB36F5C6046292B65423E71473B71422EA7785AB0835C
A37947BB975DC9A767DABC74E9CE81EED583F1D983EFDA7FF0DC7BF0DF77ECDF6FEFE56C
EAE160E4DE54E3DC4DE4E049E3E047E2DF42E1DE41DFDD3DDAD838D9D536D7D133D8CF34
D3CA31D5CA32D2C832D5CB35D0C633C7BF30C8BE38BAB034A99E2B9E932A8E832782771E
7A6B166E6008A49635E1D26DE8D974C0B1547B6B1E635516786F38BBB788B2B28CADB095
F8F9F100FF00
00FF0000FF00DBCDCA73524D844540973F3DA73A3DAE373BB94045B94248AD3E44A23D43
B35C64B66973AC6873965D66935F6BAF7D89B5838EB2808BCC9AA5AC7884B87E8ABD7986
903C4B9E3947BD4753C6444ECC454CCD4048CD3D46CE434AC7464ABE4C4C9E4443A96864
B38A849F867F9D8C85968B859B908A9A8F899B8E889A8D879B908C998E8A9A8F8B99908B
9B928B9B928B9E958E9D948DA198939F96918279745C514D4638356557549183809F9490
A0958FA0958FA3948FA8908EB58E91C38A90DD8D96C2616ACA565FDB5F67CD5056C74A50
B0393DA63336A03434A93F3FB95351D46E6CDD7775E07A78E47E7CE8827EE98381E27C7A
E47E7CE47C7BDF7778C55D5EBA4D50BF5154B24548B14749B24B4EA64445A74B4CAE5655
B26160B76B6DBA7677B67A79B2817CA781769C7D69977F5D927E4CA09052A99B54BBAF65
D1C57DDAD190DAD39DC6C197B2AD8DA09E899D998DA19E99A09C9DA09BA19F9CA39E9BA2
9C99A29A97A09F99A39F97A2B7ABB597879139262C402A2D4026253A1E1A957A6FEFD5C6
CBB09DBA9E88A98970A07F60AE8E68B6956AC7A373D4AF78E2BC7EEAC57FF2CE80F2D27B
F2D673F0D86CEDD863ECDA5EEADC59EADE58E4DB52E4DD51E3DD51DFD94FE0D851D8D049
DAD24BD4CC43D4CD3ED5CF3BD4CF37D5CE35D5CE37D2CC38CAC335C5BE39B6AE31A59C25
A097228B820D9E9419D3CA49EAE15EEAE065E3D86E8E842B605915BBB883B1B288ADB093
F8F9F100FF00
00FF0000FF00E9DBD87B5C577F444096403FA73D3FAC3539BA4146B63F45B5444AA13C42
AD565EB96E759A5D6498676DE3BBC4EDCAD1E0BFC8E6C5CEF1D2DACDADB8E6C2CEAF7F8D
7C3A48842D3DB24854C44A55CA444DCF434CCC3F47CB4249C6484BB7494A9E4A48B27570
AE8983A18A849D8E879A8F899A8F899C918B9E918B9D8F8C988D899B908C9E938F9A8F8B
988F889C938C9A918A9B928B9E958E9D948FA097929C938E857A765D524E4B403E645955
897E7AA0958FA99795AC908FB7898CD39097D57984B84854CA4D55D44E55D64D54D75056
D04D52C84A4DBC4144B13A3CA63233AB3B3AAB3B3ABE504FD06462D96D6BE07676DB7171
D96F6FE47A7AE87E7EEB7D7EE37073E16A6ED2595EC75054C75457BF4E50B34649B04849
A94547A54748A04847A3555394554EB08072D3B09ABDA583B39E6FBDAE75CEC385DDD396
D6CC97C0B78CAAA4849F9A86A19D929D9A959D999A9D9BA09C99A09F9CA5A09AA4A09AA4
A09BA29D989F9F9AA19F98A0AAA0A9B3A8B04B3E472E1F262A1B1E2F21214B3D3CF1E3E0
F8E9E4FAE7E1F7DFDBEDD4CDDFC3B7C8AB99B79780AF8C70A67F5EA88359BB9566C3A068
D5B272DBBB70E3C471E9CC70ECD06FEED56EF2DA70F0DA6DEFDB6BEFDB6BEFDD6FF2E072
F4E473E5D65FDBD054DCD24ED9D043D8D03DDDD640D8D13BD6D03CD5D040C5BF33BFB931
C8C13CBBB52DBCB529B6AF20CCC634E5DE52EFE76BE2DB73726B1DABA96EB1B384A9AC8F
F8F9F100FF00
00FF0000FF00EEE3E17E625E79423D934440A03C3EA73439B63D42BA4148B7444BA83F44
A1464DB96C729D5F6488575BF3CBD3F0D0D58F6E758A6B71C3A5ADBFA4ADCAAAB7A27987
A76D7C984B5BA34150BC4855C74853C8404AC94048CA444BC2474AB34B4A964844B78079
AA87819C88819D8E899E938F9A8F8B9A8F8B9C8E8B9B8D8A988D899A918C9A8F8BA09591
958C879B928D9A8F8B9B908C9C918D9C918D9B928D9E9590A39A959B928D857C775E534F
4C413D685A57917B7DB08E8FC18A90DC8F97C5616BC14C55CD4B53D44B52D5484EDA4E51
D74C51D54D51D44B52CE494ED14E53CB4A4EBC3E41B5393BAE3637AE3838B33F40C15150
CF6361D86C6AD66A68DA6C6BD76766DA6868D56164CD5A5DCF5F5ED66867D86E6ED36B6A
C96162C0595AC35F5FB25955934A41A97464FDDAC6F2DAC0D6C6A4D1C3A0CCBF9DBAAF93
A89D879F9685A49B92A29A97A19B9BA49EA0A09A9EA29DA3A09BA2A39EA59E979FA29BA3
A29BA29E979EA19AA1A099A09E979EB8AFB45C5358291E222D23242E24232B2622D8D3CF
F1ECE6ECE4E1EEE4E2F0E6E4F1E8E3F2E7E1F3E4DDEDDCD2E3CFC4D6C0B2C3AD98B29A82
AD9072A48360A38056AC8453B48952C99D60CEA15EE4B56FEEBF77F1C57AFBD283FFDA89
FFE089FFE286F9E17FF3DE75EBDA68E4D45AE1D452DBD14BD8D047D3CD43D8D049CEC63F
D0C83FC7C032CEC836C4BE2ACBC330E5DE50E2DB59F4EE808C8534A09E61B2B483A5A889
F9FBF000FF00
00FF0000FF0000FF00B8A39E73484281403A933A3CA0373BB34045B74046BA454BB4474C
A14145B16164A66569804E51E1B8BCF9D9DCA38386371A1E80656AD7BCC59F818DBC96A3
E1ACBC924E5D953D4DAD4453BF4753C44550C7434EC3444BBF4B4CAC4846944B45B7857E
A688809D8A849A8B869A8F8B9B928D9A908E9B908E998E8C9A8F8B99908B9B908C9B908C
99908B9C938E9C918D9A8F8B9C918D9C918D9A918A9990899F98929C958F9E95909D948F
8E83816F5F5F684E51795054B1727AD57F88B84E58C95057CA4C4FCE4A48D24C49D34E49
D34C49D54B49D44A4AD74D4DD4494CD64E50D54D51D14C4FCC4A4CBF4142BD3F42B3383A
AF3939AC3839B03C3DC24E4FD56162D15F5FD25E61D05E5ED06261D06462DC7370E8807F
EC8483DF7774CC6461B85953B2645A995E50EFCAB8ECD6C1C5B4A0AA9D8CA09486A59B92
A69D98A19997A79EA1A2999EA29CA0A39DA1A19B9FA49EA2A19CA2A19AA19F98A0A1979F
9E989C9D979B9E989C9C969A999397AFA9AD736D712C2628362D2E2A2522201D18C5C4BF
F2F1ECE6E5E1EAE6E5EAE6E5EAE6E5ECE7E4EDE5E3EEE4E2F1E6E4F2E7E3F5E6E1F7E6DE
F1DDD2EAD3C5E1C4B4D0AD99BD987EB48B6BA0745195653FA7764DA6754AB18352C79C67
D5AB71E4BC7EEDC786F6D18AF8D584F4D57BF6D876EFD76BE8D360E9D65EEBDB61E1D452
DBD249CCC336DDD546D0C839D2C63CE1D754DAD057F2EB819992418D8C4BB3B583A4A887
F8FAEF00FF00
00FF0000FF0000FF00E7DCD879625A7E534A904C4B913739B04349BD4850BC454BBC494E
A84144A85253B26E6F8D5757A17778F6D4D3E7C9C9674D4EA68D91F9DEE5A88792B68C98
A773807A3A4ABA6C7CA84C5BAC4351BB4754C44853C1484FBE4D4FA8494598534CBA8B85
A586819D8A869A8B88998E8C9A908E9B918F9C918F9A8F8B9B908C9B908C9C918F9B908E
9A8F8B9A8F8B9E938F988D899D928C9F948E9B928B9C938C9E95909B928D9D95929E9693
A59B99A49494A285878C5D63B16A70C1666DB84950C85153C04B42B94536B2412FBF4C39
CC5342D05243D25043D14B42D44A47D64A49D5494AD74D4DD44C4CD64E4ED64E50CE4849
C84648BF3E42BF3E43AE3034B73C3FB33B3DB84143C14F4FCB5E5BCE6561D46C69D6706C
D56F6BDC7672D06A66BA5B55CA7A71AE6E64C59B8FBA9E93A6938CA598929E9492A2999A
A09A9A9F999BA59FA39F999D9F999DA09A9E9D989C9F9A9EA09A9E9D979B9C959C9C969A
9B95999C969A9E999F9C979D99949AABA6AA847F833531322E2828282421161510B3B2AD
F5F1EEE8E4E1EAE5E2ECE4E2EEE3E1F0E2DFF2E3E0F3E4DFF2E5DFF0E5DFF1E6E0F1E6E0
F1E8E1F1E6E0F3E8E2F5E8E0F6E5DDF0DED2EAD7C9DDC6B8D0B3A3BE9D8CA4816E8E6853
8B5F469061459E694AAB7350C48B60CE9462DBA368E5B06CE8B768ECC369EBCB64E3CC58
E3D453CBBD38DACC45E0CE4EDDC7579A87209D902AFAF194AAA353848340B7BA85A2A685
F9FBF000FF00
00FF0000FF0000FF0000FF009C928963483F9A6964A258599E3E42B8464EC0494FBA454B
B24A4BA34748AD6364A26666835150C89E9FD2AFADC6A6A7BEA0A2E1C1C6A07B83C398A2
A7737F894C5B8C4555DD8A9A9A3A48AA3E4BB33D49BC454BBE5051A04540A15E56AE817B
9477739B8884988A87988D8B988E8D988E8C9B908C988D899B908C9D928E9C918F9B908C
998E8A9A8F8B9C918D978C889F948E9C918B9B928B9D948D9C938E9C938E9E94929C9290
9E9391A59192B08D91C28B91D88891B7535BC14E53C7514FB7493CAC4830B55B39984018
9A3D14B04D26B94E2CC65439CB523FCF5142CF4D40D24D44D55047D34C46D54C46D84D4A
D34949D34B4DD44C50D24B51CB484DC24146BF4145B4393BB23C3CAB3938C75756CF6160
CF6160D86C6AD56966C3605BB560599C584F906159AD8E89A59190A39797A09599A0979C
A09A9E9B969A9993979E989C9C96989B95979B969A9E999D9E989C9C969A9F989F9F999D
9E979E9B969C9A959B9D989F98969BA5A3A89893993C373B2A262726222114100DA4A09D
F6F1EEEDE3E2EFE3E3F1E1E1F4E1DDF8E0DCEBD2CDECD3CEF6E2DBF6E3DCF7E6DEF4E7DF
EEE7E1EBE8E3ECE8E7EBE9EAEEEAE9F0EBE8F2EAE8F5EAE6F6E7E4FAE7E3F9E1DDF2D5D1
EBC8C2D7AFA7BF9088B07F71A16C5A89513A84482C763C168149168B5A17BD9840DEC358
E3CF56CFBD3DDAC64BE6D060AE9435594100948327FBF096B7B05F7E7E38B3B67FA2A683
F8FAED00FF00
00FF0000FF0000FF0000FF00D3CEC8594B4274534CD39C999C474AB0484FBB484FB9464B
B54B4DA9494BA35155AF696B7E40415820218C5958EDBFBFEBC1C2D7AFB07A4D52B28389
D7A5AE9C6771874853E69AA7AF5360B94F5BA02B34B33C40BB4F4DA54B43A15E56B98D84
6E514B705F58948582998E8C9A8F8D988D8B9B908C9B8E889C8F899E918B9D8F8CA19390
988D899B908A9D928C9B908A9B928B9990899D928E9E938F9D928E9C918D9F94929D9290
9D8F8EAA9194B1868DCD8E97D57B87BC4E59C84F54C9524EAF48399F4A2BF8B682E7B270
C59044A1651C8D490893460EA0491CB1512BBB5232C65439CB533ACC4F39D34F40D24A3E
D44942D64B48D5494AD5494CD84B51D54A51D3484FCF464DD14A50C74247C23F45BD3C41
B93D3FAA2F31AC3636AF43419B403B89403A8D5A56B2908EA28E8FA19597A0959BA0969E
9C969AA09A9E9A94969D97999C979B9893979B969C9D989E9691979B969C9B969D9B969C
9E99A09B969D9D97A19E9BA49A979EABA9AE9792982E282C2C26282A2426161010A19899
FCF0F0F1E1E2F4DEE0F9DFE0FFDDDCC8A29F744B47B8918AFFDBD3E9C8BFB7998FBCA39C
F2E3DCEEE6E3EDE9E8ECEAEBE7E6E4E8E4E1EAE5E2EFE8E2F4EBE6F4E9E3F1E6E0F2E5DF
F2E5DFF4E5E0F9E6E2F8E3DEF2D9D4EDCEC9E0BAB1C89D8CCDA1847C5423B8944AEDD16E
E5CE5AD5C148E2CB5BA48B277C620E5B4200AC9C3DF8EE8DBEB95E7C7D31B0B57B9EA480
F9FBEE00FF00
00FF0000FF0000FF0000FF00F5F6F17F787055423BD1AAA39753529D4448B34A4FB8494F
B3494BB34F51A1484C9342489145496D25298D494AC88888E5A9A9C08587692B2E8D5055
E7ACB2E8ABB2D6959DA85B658F333EA13741A22A33B53E42BE514EA34941A36058BE9289
A0837D725F595A4B487769689486859C918F9B8D8A9C8F899C8F89A0938D9F918E9F918E
9D928C9E938D9E938D9F948E9A918A9D948D9D928E9C918D9D928E9C918D9E93919F9190
A59393A98B8DB9888ED78F9AC86371BF4955CE4D52CA4D4BC3574A7C2708CE955EFBD185
F0CD71F1CF6DE3BA5ECB9B47B1792E93520E954B0C9B4911AA4E1BB55024C35731C55233
CC523BD14F3FCF4B3FD34A44D74948DC4B50D9484FD7464DDA4A53D6464FD94952D2454D
D1484FCC474AC24447BA4646AE4C49924440915A57B69391A59192A095999E959A9E979E
9A94989C969A9B95999A95999E999D9B969C9C979D9893999C979E9E99A09C979E9D989F
9F9AA19F99A399969F9C99A2A09DA4B6B1B7918A912923272C26282E2528180F129F9395
FCECEDF3DADDFBDDDDFDD7D6B98D8C7B4B47B2817CEDBEB8BD908A704840542F26856860
F6E5DEF3EAE5F0EAEAD3CFCE8F8B8A716D6A625D5A76716D9B948ED3CCC6EFEAE6ECE7E3
EAE5E2ECE8E5ECE7E4ECE7E4F0E8E6F4E4E5F8DEDFFFDED9FFE2D286623EBD9C59F3D678
E6CF5BE5D059BDA83F715A00796109846F14E1D36AEBE378CBC766797B28ABB1759CA27C
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF00BEBDB84D453A9E887D895A54843E3E9C4244AC4548
AC4445B14A4DA44448983B43963C459C424B8B32387B22267C26297A2427852A2F792326
A15154DA8B90B8696E8732398E2A34BA4B54C1484FC3484DBE4C4CA849459E5751BE8D86
A68782A48F8C8775736052515143427668679687849F908D9D8F8C9C8E8B9E908D9F918E
A398949E938F9C918D9A8F8B9B928D9A918C9C918D9A8F8B9D928E9C918D9E908FA19191
A5908FAD898DC1888FDA8A95BE525FC84A56D14A51CD4849CE574F94341CA15D2EFFCF8C
EFCC70EACF64EFD868F3DC6AF1D769DDBE54D8B551BE9335A2701B925709924C0799490E
AB4F20B34B24C55233D0523CD54D41DA4C48D74649DB484ED9464ED94650DA444FDA474F
DA474FD6474BD44C50C84E4DBF5754A4534F97605DB59191A69294A095999B95999F989F
9C959C9C959C9C979D9C979D9F9AA09B989F99969D99969D9F99A39D97A19A979E9B989F
9D9AA3A09DA69C99A29C99A0A7A2A9B5AEB5857F81292023342B2E32272B1C1012A19194
FAE6E8F8DBDDF8CFCDA97874905D59F3BEB8E1AEAAA3746E784D46A17A73CFB1A7F2DBD3
FBECE7E5DBD97A72706F676598938F9A959189848177726F46413E56514EA8A09EEBE6E3
E8E3E0CDC8C4D8D5D0E5E2DDE8E3E0EDE3E2F5E1E2FADEDBFFE1D6795837B99A59EDD374
E5D059EDDD63A0912A625400938518D3C751E6DE61E4DF67D7D26A7F7F29AAAF6F969A75
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF00F0F1EC89867D655B516A4F467A4B45914D4C974645
9B403F9838399F3C3F98353A98333BBE565FA83F46A4393F972A3094272DA6373EA83B41
9D363AA0404286272DD26E76A33840B13C44C64951C6474EBD494CAC48489F5451BD8884
A5827E9F8A85A3918F9A8C8B7668674F41405446457F716E998B88A19390A193909F918E
9F9490A196929E938F9B928D9B928D988F8A9E938F9B908C9D928E9C918D9E908FA89696
AB9192B38A8EC88992D57F8AB54551CC4A56D2474ED3484BCF504AB34433923718E29A68
F5BD73F6CA71F3D06AF5D769EED465ECD563F3DC6CF3D96AEFD368E5C45DD4A94AC49138
B172259F510FAA4C18C0522DD1533CD54B40D54544D84649DC464FD9434ED63F48DE4750
DD464DD8454BD24649CA4C4DBB524FA4534F955E5BB39190A69294A2979B9D979BA39EA4
A099A0A19AA19F9AA19E99A09D9AA19C99A09D9AA199969DA09AA49C96A09C99A29F9CA3
A19EA79F9CA39D9AA1A6A1A7A59EA5B5AFB3746B6E261D1E342A2B332729231314B7A4A6
FFEAECE3C5C58357545D2A26AA756FD09B95C28D89DBA8A4F2C3BDF5CCC6F7D9D1FBE4DC
FEF1EBB6ACAA1B110F887E7CF7F0EAF3ECE6F4ECE9EFEAE7DFDAD7938A8B3F3637B0A8A6
C1B9B78A858187827E8E8B8686827FB8B0AEFAE7E9F6DEDEFEE2D77C5D40B7975AF1D67B
E4D15BEBE062877B0B887E0BDBD251DCD64CDCD94EE7E463DAD86B81812BA6AB6B91966E
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF00EEEDE9C6C3BC958B8277635A744F497E4943
914E489E4D4A9D42419C35389D3035AE3B42B13A40BC434ABD4149BD4048C2434EC2444F
C0474EC24D53B13D46C14D569C242DB2353DC94550CA4852C1484FB34A4E9D4C4BC08483
A9817F9E86829E8F8A9B908C9E938F9388866C615F4B3D3C594B4A857776988D899F9490
9E938D9F948E9D948D9B928B9D948D99928A9D948F9B928D9C938E9E938F9E908FA59393
AF9294B18489D28F98C86E78BA4852D04D55D1464DD6474BD44A48D04C47B3392EA33420
AC4A27C87241E89E61FABC73FDC975FCD173F7D46EF2D466EDD460EBD55DEED85EF0D65D
F0CF5EF3C361E19F53A04611CA5836D44F3ED54642DC474BDA474FD9464ED64049DA444D
DA454BD54449D4494EC94D4DBD55529F504B96635FB29391A59393A4999DA09A9EA29BA2
9E979E9F989F9E999F9D9BA09D9AA19C99A09D9AA39A97A09F9CA79E9BA4A09AA4A39DA7
A49FA6A49FA6A39EA5A19CA2A59EA5B1ABAF645B5E2B21203125252C1E1D301E1EDCC8C7
FFEDEAC5A9A6AD8784DAAEABE9BCB9C99894AE7473B478778E57547948438B6960AF968F
FAEBE4E6DDD8BAAFABDFD4D0D4C9C3BFB6AFC8BFB8E0D9D3FFF7F4D0C8C62016158F8584
A39998CCC2C1877F7DA49F9CCAC4C4CDC3C4F7E4E8F5DDDDFFE3DB917357AD8E57F2D883
E1CF5FDFD552A69E19CEC73BD6D03AD8D53CDCDA47E2E25CDEDE707D7F2B9FA5678A906A
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F8F3E3DCD4B6A59E8D706A
815650905652944A47A14B4AAD4B4CAB4145AB383DB43B40BD4046BF3D45C8444FC9434E
CA4651CD4B55C4454EBE3F48B6343EC33F4ACB434FCB4752C64951B94B4E9F4545B67271
B285829E827EA08F88978C869A8F8B9C918DA095938D81816759584C413F5F5450847975
9D928E9F948EA196909D948D9C938C9A938B9D948F9B928D9C938EA196929D8F8E978281
AF8F92B6858BD68E99BE616BC04C55CF4C52D4474DD44348D44547D04443D54B49C94540
B73F2FA63A209A39169D491AB46D2FD2944BE7B35FF4C96BF3D36CEAD35FE3D550E4D74B
EBD953F1D45CFFD175AC6621B94F27D1533DD84B42D94748DA474DD7444CD7414AD7414A
D9444AD7464BCF4449CA4E50BD5755984A469C6B67B39593A39394A39A9DA19AA1A49DA4
A099A0A19AA1A09BA1A09EA39E9BA29D9AA39C99A29C99A49D9AA59A97A29B95A198929C
948E988D888F8681887873796D676B7C767A4C43462D21213626262C1817503836F2D8D7
FBE2DEFADDD9EECCCABA9795A27A7AE5B7B7E2AAABCB8F8FCD9391C49490C1A0997B6760
F0E5DFD6CFC9968B87887D796C635C685F585049434E4741857D7AA59D9A857B7AC7BDBC
948A89A89E9DA9A19FD3CDCDE8E2E4F0E5E9F0DFE5F2DCDEFFE5DEB3947F937344F4D88E
E0CD66DCD153C0B92DE1DB45D0CC2DD5D333DEDD45E0E05AE2E1776D711D8E94568C926C
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6EBE7
D2C0BCA88C8887605B834E4A96524FA45551AC5150AE4647B24143B83F44BB3C43C03C47
C6404BC9434EC8404CCF4753CF4753CD454FD04751CD4750CA4850C24E51A54143AC5E5C
BC8783A07F7A98847D9A8D87998E8A9B908C9A8F8D9D9290A196948D82805F545249403B
665B578B807C9E938DA0958F9C938C9E958E9E958E9D948D9D948DA0958FA3918FA3898A
B28B90BF868DD88B95B7565FC34E56CD4A50D3484DD44549D64548D64749CF4543D04C47
C94F44C45542B74F36A14321983F138C3A0892470EA06324B08139E2C164EBD75CE3D649
E8D94CE9D250FFDF74C98E40A54714D25A3FD34E3FD44642D54344D9464CD8424BD9434C
DA474FD8474ED1464BCA4E50BD5755994B499D6C68B294929F8F909F9699989198958E96
928B928C858C878289817C837C768077717B6E6B766864725F5B6A5D59685A54624F4955
47444D423F464B464D4A454B4F4A4E5C565A382D313626293B2225321414826361E8C6C4
C2A09E916F6D694A488A6A6BEBC7C7F1C7C8EBB9B8D9A3A1AD7C78C29B96FFE8E4F1E4DE
E8E0DD44413C3E36339D9592B0ABA5BCB7B1AFAAA68D8884615C5967625FBCB4B1F6EEEB
A199967F7A77847F7C6B6766747071F3EAEDF0E1E6F2DEE0FDE5E1D9BCAC795531E8C689
EED47DDECE5DC2B834DFD947C6C326D5D235DCDB43E0E05AE4E57F5C61117D85498E966F
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF5F3E7D5D1BDA19D966F6A824F4B8E4F4A954A45A44E4DA94B4BAB4447992C31
A53039B93D48BD3946CB434FCB434DCB434DD04751CC444ECC464DC74C51B94C4F9F4746
BD7D7BAB807A957A7397867F978A849B908C9A8F8D988D8B9C918FA398969F9492857A78
594E4A473C38655754897E789F9490A39A93A198919D948D9C938C9F928CA69291A98B8D
B5888DC5868ED7818CB74F5AC54C55CF4950D3484FD3444AD5464AD14747C94843C85248
C05744A5472B8C37108939088E41098841037F3B00753C005327009E7F25F1DF63E3D747
E6DA46E7D54BF3DA64ECBD619A480EC35733D2513CD2483ED64645D64447D84349DA444D
D6434BD6474DCF474BC84D4FB85454974C49A27270947877685A5A5953575750574E474E
474047443D4446414746414848434A4A444E4D475354505E595563635F6D66606E6A6470
74717A7C7980837E858B868CA29DA1928C8E352A2E3C2C2F41282C3214167858597F605D
5D3B397F5D5BCCAEACFFE2E0D2AFAD956C6AEEBCBBBF8E8A8B5F5C805F5AFBE8E4F9F0EB
E3DEDA34312C615C58D9D4D0EDE8E4F0EDE8F0EBE8EFEAE7EBE6E3807B787E7975F6F1ED
F8F3EFF1ECE8FAF6F38A8685878384F4EEF0ECE1E5EFDFE2F6E2E1F8DDD489654DB28D63
F7D895E3CB71C0B03FDCD350CFCA3BD6D441DFDD4CDFDF5BE5E8815F66187880448D956E
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F0E5E1CDBCB599807B75544D7E534C895851834945C58180
AB565B99353DAF3945B93A45BF3B46C43E47CA424CCC444ECE474ECC4B50C24E51AB4747
AC5E5CBF85819C7771937C7693817D958784968B87988D89998E8A998E8A9D928EA09591
9D928E847975564B47423733685D5B918682A196929F94909D928EA39592A4908FAD8D90
B6838ACE8691D47684B84856CA4C57D34B55D4474FD4454BD14649CD4D4AC35348B65741
7B360F7B470EAB8032C29D42CBA844C7A43CBD9D36AF922C88700E7B6900DDD14BE8DE4B
E4DA44E2D646ECD958FDD66DAB6621AE4D22D0573CD64E40D54743D84647D84349D9444A
D7444AD34448D1494DC1494AB95A5889443F9F73709A82807C7070756F737C757C7D787E
827B828781858B868A8D888E918A919792989A959C9F99A39C96A09C96A09D97A19E99A0
A29DA49C979D9D969D979195ABA5A9837D7F31282B362A2C36272A322020CFBBBAD7C2BF
DEC5C0FCE0DCFFE6E2FFE3DFE3B7B4C49490EBB8B5E6B6B2A47F79C8ACA8F9E7E3F0E5E1
FEF7EFC3BFB65750483F383257504A97928CD8D0CDCCC7C39B96933A35326A6762E9E6E1
E1DCD6E1DCD6D7D2CEB0ADA8D6D5D1EDECEAE9E3E5EBE0E4EFDFE2FCE4E4CBA8A26A4431
D2AC85EDCD90CAB15DE6D770DCD35ED3CE4EDAD650DEDF5FE6E982666E1B777F43848C65
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9F4F0DBD2CBB1A29B8E7A71644942C7A29C
FCC6C6B06569B15057BE4F56BB434CB93C44BE3C44C13B44C63F46C9464CC74A4EBE4D4F
A14343BA706DB47F7B997672937A76907E7A938582928783988D89998E8A9C8E8B9C8E8B
9C918DA59A969F94927F7472584D4B473C3A6C615D908581A09591A49693A28D8CB08D91
BA828BD98B98D26C7ABD4755CA4653D24651D6464FD2454BCE4849C64F49C25E4F7D3213
8F6028E3C676F0DD74E9DE62E9DC59EBDF59EEE15EEEE161EADB64D7C94FE2D552E7DA4E
E4D74AE6D94FE9D656FFDE73D99F55984211CC593CD34E3FD84A46D34343D84347DA454B
D8454BD7484CCF484CC34D4DB055528B4A44A57E79AB9894A298979D979999949A9E999F
9E989CA29CA09D979B9C969AA09A9E9C959CA19CA29E999F9C979D9B969C9C979D9B969C
989399959094979195979193AFA9AB635D5F292021362C2D271D1E4E4242F4E4E4FEE9E6
FFE6E2FADBD6E0BDB7D8AFA9EAB9B4D29F9BC08D89996C678E6D66FBE4DEF4E5E0F1E8E3
C7C0B8C9C2BACFC8C298918B5E5751615A5499908B81787349413E817976E1DCD677726C
3D393089857C4A453F9A9792EBEAE5E8E9E4E5E3E4E8E2E4EBE0E4F2DFE3FDE0E4A68580
67422FBA9873D0B27CD8C47D998A35979028D9D55AE1E167E4E7806C741F7A8445838B64
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDE8E4BBB2AD93827B
B396908E5E5A8A4645A65051B75054C25157C44B52BF4047BA373FC44149C34247C84D50
B44647A94B4BC17774B47F7B9A77738F777392807C8E817B8E837D938882988D89998E8A
998E8A9B908CA196949F94929E94927E74725D52504D42406D6260908080A38A8DB28B90
BD7F8ADE8A99CA5E6EC54858D24C57D2464FD4444DD3484DCC4A4AC5524BB45849672502
D4B066F0DD76E6DB5BE2DC4AE1DB45E5E048E4DD47E8DD4FE8DA55ECDA5CE9D55AE9D55C
EAD65DE7D25BECD261F7D571FCCB7F9E5522BA4E31D25043D54A47D64548D84349DC474D
D74548D34748D04B4CC14F4EA8514A884C44AB8884A3918F9E95969F9B9C95909699949A
9994989D979B97919598929699929999949A9D989E96919799949A989397999498999498
948F93969195958F939B9597ACA6A84842422C2324352B2C211515827272FBE7E6F8DCD9
D2AAA8AF827DCB9C96E2B1AAE9B4AE996662B4857F956C66694C44F5E1DAF4E9E5E8E0DD
494440423D3956514D51494659524C5F56516D625C968983C4B7B1DDD2CCF9F0E7C1B9AE
8A81788780763A352FC1BEB9F1F0ECE6E6E4E4E4E4E5E3E4E8E4E5E6DDDEEEDEE1F9E0E3
A487837E615394765C6149233625006E6218E2DB71E0DD6ADEE37C6B731E7682427A855B
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F0EC
DACDC7B097928A615F894F4E8D4344A1484AAF4D4EBB4E51C24D53C1464BC2434ABE4044
BD4547B14545AE5352BF7876AE7B779976709279748E7B758C7D788D827C928783958A86
978C889A8F8B9C918D9A908E9F9593A29896A095938479775F5452554545775D60A1767D
BE7C88E28A98C55565C64655D04854D2454ED3434CCF4449CF4D4DC3524AAD544475350F
ECC978EBDB6AE4DD51E2DF44E3E13FE3DF3EE5DC41E3D445EFD658F6D466F3C965F3C669
F7C971F7C971F8CA74FAC778FFD394CB7E52A2351ECE4E45D54B49D34247DB484EDB484E
D34245D34949CB4B4CC45655A4514B8A514AB0918EA191919F96979C979B97929699949A
9B969A9994989892969892969691979893999A959B9792989792969A9599979296969195
969195969195958F91A7A1A3A09A9A3930312E2425362A2A221414B4A2A2FFEDEDBB9998
5A2A26BB847FEAB1AAD09790CE9490E6B1ADFCCBC788615CAB9089FAE9E2FCF3EECCC7C3
2C2825B5B1AED1CCC9BEB6B3524A47261D186356505E514B56494170635BD7CDC3BBB3A8
C8BFB6C9C2BA827D799D9C98F1F0EEE6E6E4E4E4E4E4E4E4E4E4E2E4E0E1E4D9DDF6E3E9
FFE7EBA98D8A5C4034381E07352300776C2EE3DB78DEDC6DDEE37D717B2471803F758257
F7FBED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5EBDBDBC9AFAEA07A77885552834240924241A54748B54B4FC0494DC6494F
C74A50C0474CAE4144A94D4EBC7573B8837D99746C90756E8C79738C7F798D827E8E8580
918883958C87988F8A988F8A9D948F99918E9E9492A096959C92918A7A7B785B606F414B
995260E38796C55062CB4858D24855D44750D1414AD0454ACF494AC8514BB75749742F08
E4BD70EBD969E0D74CE3DE44E3DF40E4DB3EE6D843EFD655F2C663CA8F43B36729B55F2C
BE6638C86F43D98354E18F60FCAD86FDA486AD392ACB4743D54A4DD7484ED5424AD9464E
D54449CE464ACA4C4FBD53539F4F4E945C5BB09091A191929D92969A94989A94989A9498
9B969A9A95999C979B9893979893999A959B979298989399959094948F93959094999498
969293959192979394AAA4A687818333282C36272A382829342123E3CECDFFE9E8E5C2BE
C08F8BD19692BD7E79CC8C8AD19191C58B8A9A64628B625EF6DDD8F4E7DFF6EFE9E7E4DF
6A65615D5854978F8C9B9390322A27251B19A09593DBD0CCD2C7C1D2C9C2E4DBD4736C64
221B155D5854807C79BBBAB8EDECEAE5E5E3E5E5E5E4E4E4E3E3E3E9E5E6ECE1E5EFDFE2
FEE8EB9C837F543A2D442C123A2800837838DED876E1E171DDE47D6F7C2469793874835A
F7FBEC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBECE9E1C8C4B6938F8E5D5981403E91403F9D3A3DAC3F44
C14952C74F58C35057B64F52A65252B4736FA7787295726C9175718C77728B7C778E817B
8C817B8D827C8E857E938A8398918B9A938D9B918F988E8D9E9493A59596A78A8EA6777F
AA626ED87A8ABE495BD14C5DD24857D34551D64650D0434BD1494BC64B46C55B4E792908
BD8A48F6DA77E3D453E7DF4CE6DF46E5DC43E8DA46FCE365BB8C32833F00AA4F22AA4121
A6361EA6331EA0301A9E311AA03A24BA4F3FA52921C74140D64B4ED5464CD6454CD8474E
D4454BD0494FC24A4CBA5356964A4C9C686AAF91939F8F929D92969B95999D979BA09A9E
999498948F939C979B9893979A959B9B969C969197999498989397938E92969195989397
959192979394979394ADA9AA6A64662A20213D2D302B181A624E50F6DEDEF6D6D7DBB3B1
CD9D99D19A97E4A8A7DFA2A1844647AC7271B37D7D633A38E4CCC8F6E9E3EDE5E2EFEAE6
DFDAD688807D5C534E4C433E7C736E7B726D453A384A403E978E89E4DBD4958E88716A64
514C49696461D3CFCEE7E6E4E5E5E3E5E5E3E4E4E4E4E4E4E4E4E4E8E4E5EBE1E2EFDFE0
FCE8E98F7773503627472F13382700887D3BDFD977DBDD6FDEE4806D79255261267D8B67
F8FCEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEDBD7C4A5A29A6D6AA665639F4D4F
96353C9A303AB0424BB44C53B3595B9C5251975F5EA579789B75749778758D74708F7A75
8D7C75897C768B807A8C837E8E8781968F8998908D9A908E9A908EA09090A98C8EB5868C
C8808BDC7C8AC0495CCE495AD14756D24450D4444ED3464ECF4449CA4848CA534BA34029
8A4315EABC6FF1D769E2D650E4DC49E5DE47E2D843FCE966C19D3C783F00AF5D2DC05C3A
C4553AC74E3BCC4E3FCA4C40BC4036BA3933CA4340D24647D4484BD6474DD3444AD4454B
D1464BCA494DC14E51B355568E484AA57477B19395A090939E93999D939B9A939A9C959C
9C969A9993979B949B9B949B9A94989A9498999498969195948E92948E90969092999395
959094948F93989697A7A5A6453F3F2D23243B2B2E271416978385E9CFD28F6B6F7E5657
D0A4A3D4A6A6D3A3A3D2A09FE3ADABFFCDCBE7B5B4B99191F2DAD8F8EAE9E5DDDA645F5B
7A726F978E89A19690BEB1A9D7CDC4E8DDD7D6CBC78C82804A413CA7A09AA29994D8D1CB
E7E2DFA39E9B918D8CEAE8E9E7E7E7E6E6E6E3E3E3E4E4E4E5E4E2E7E3E2EBE1E2F0E0E1
F7E3E2866D68523829452D113425008C8340DEDA79DCDF74DEE586606C204F5B2BBCC6AB
FBFEF500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F4AD9893A6817BB27D79
D48E909D4B4F973C4393383D9B46497B3132B87D7FE9B9B9A6787A926667A07878967472
8F726E8C74708E7B778B7C778A7F798D847F918883938987988D8B9E8F8CA78D8CB4878A
CC8690D67886BC495ACB4B5ACF4755D24450D1444DD2454DD1444ACD4547CE4C4AC65547
8A2F149A5723F2C572F2D669E9D757E6DB4EE2D749EDDF5AF6DC6EB68D358C4D08954510
B15127BE5333C7553BCA533FCA4F40CD4F43D14E46D04B46D44A48D04646D24649D04548
CE474BC74B4DBE5154AC56578A4C4DAB8383AB92959F90959E93999C959C9D969D9C959C
9A939A9B949B9A939A9C959C9C969A9892969893979691959690929690929A9194958F91
989296959192A19FA09C9B99353130302826372B2B261617C6B6B7D1BBBE6F51538D6B6C
BA9897BE9B99E7BFBFDCB0AFB585819665619A6D6ADDB7B6FBE3E1F5E7E6EDE3E1726A68
352D2A1A100E1F1410312620483D37524743685E5C7E74728D8680A099936D645F5F5852
7B76727E7A77989795F2F0F1E4E4E4E4E4E4E4E4E4E4E4E4E5E4E2E6E2E1ECE2E3F1E3E3
F2DDDC7B625B4A301F432C0D35270089823CE2DF7EDDE077D8E1884D58147A845FF1F8E6
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C1BAB277695E786153
DAB5ACD09F98D29695A36162985455642424976161FFD4D5E6B4B78A565A8D5558AA7376
A0727298706E9273708F76718F7C768E7F7A90837D9186829287839D8E8BA58B8AB08688
CA8C91CF7982B74B58C94C5ACE4A57CF4650D1444DD54850D1444AD2454BCD4547CE4F49
C2504585250CA35B29F0BC73FBD776F2D963E7D857E6DA54E9DA59F6E16ADDBC55A97B25
90560C8741039A4A17A2491FB0502ABD5635C25538C45039CD503ECF4D40CF4844D04848
CF4A4DC44C4EBA5658A05252885655AC8E8EA390949F949A9A939A9A939B9D969E9F98A0
99929A9891989F959D9F959D9D969D999299999397969094958F91979191989292958F8F
988F92958C8FAEA8AA8783822E2828312C29342C2A2D2522DDD5D2F1E7E5E9DBDAEAD8D8
F3DEDDFFE5E2D5B2AE99706CC59C96BC938D522B26B79593FDE8E5F7E8E5E1D6D4D5CBCA
D3CDCD8F89893D393A272324514849968D8E9E9493756B698B827D8C837CC3BAB57F7872
A9A4A055514E8C8B89F2F1EFE4E4E2E5E5E3E4E4E4E4E4E4E4E4E4E6E2E3EBE1E2F0E2E2
ECD7D46F564F482F1B412A0A362900979147E1DF7ADEE47AD0DA84555F23C7CDB300FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DDDED8716F624E4737
766656C8B1A1F6D1C8D1A49EC18E8AB17B79835150BA8889F3BFC3DAA1A7884B507E4146
8F57589A68679E70709C7472937471927672947D77917E7890817A9885819C8281A98182
C2878BCA7B81B54F5AC6505CC84954CF4751D1454ED2454DD2454BD2454BD4474DCF4749
CF4D4DC5504796321B94421ADB9B5BFACA76F7D470ECD263E6D259EBD85FF0DB68F4D96E
ECCA68D4AB51B58533A1691E9554108D460694430B973C0DAF4722C65338CE5041CE4E45
C64947C25050B35758914D4E936B6BAA95949B8F939C959C99949A99949B9C959D9D969E
9891999B949B9F959D9B949B9C959C9992999993979D979B948E90979193979193948E90
958C8F999091B3AAAB635D5D302B28332E2B1E19155C5753F0EDE8EBE8E3EDE5E3F0E4E4
F4E4E4F9E1DFD3ADACE2B6B3E3B8B2A87F799A756FF5D6D1FDE6E0FFEFE8A697944C4240
5B5555716D6E4846492523262924284E484A9C9394D6CCCBF3E9E7ADA49FA09694CEC6C3
E8E3DF85817ECCCBC9ECEBE9E5E5E3E5E5E3E5E5E5E5E5E5E4E4E4E7E3E4E8DEDFF5E5E5
E4CFCC664E42452C16422E093B3100A5A251DFE277DFE67EC1C97C969E6DF6FAE900FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F8F3B1B2AA636456
4D4A37887D69CEB9A8CDB0A2B38D84D8ADA7BC8F8CA77777AE7C7FDBA7ABC89196B37A80
B57D80A86D718E53599C6467A26F6EA0736E9C776F95776F927972967F79997C78A37B7B
BA8187C3787FB4535EC2505AD25660CB4850D04950D1464DD2474ED4474FD2454DD1464B
D4494ED24D4ECE514DA83729922C13B55D37E49D67FBC27DFACD78F1CF6DEED368EDD666
EBD661F4DF6AF4DD69EFD866E5C95CD9B851D1A94ADDA656B4692F9F4217C9573CCB5241
C64F47BA514EAB5A57814948A0817FA69898988F9298939999949A9B969C99949A979298
9992999A94989A94989A9498999299948F9596919799949A969195969195948F93918D8E
948E90A09A9AA79E9F3C3432332B29342C2A1813109D9895F7F4EFE9E6E1EBE3E1F0E2E2
F5E3E3F3D7D6A97D7EDBA8A7D19B9BD9A9A7FED7D2F9DBD3E0C5BCA79088B7A69FC7BCBA
9F99998C8889716C704E494D3A34382822241B1517473E3F7D75735A5250534B498D8583
CEC9C66B6764E9E8E6E8E7E5E4E4E2E4E6E3E4E4E4E3E3E3E5E3E4E6E0E2E8DEDFF9E9E9
D8C4BD5D463848321A3D2C014B4200C8C86ED9DF73E2EA87C6CF90E1E7C5FDFFF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D5D6CE
7E80725C59487165557968585D4539D0B2A895706ACCA39FC19594BE9293D7A9ABDCABAE
EDBBBCC08C8EAC71779D62668751517E4D498D625B9D7B71987A70987C71987770A07773
B67B7DBE7378A94A52C0525BC44F57C94C52CD4C51D04B50D14A50D0494FD1484FD3484F
D5484ED64B50D34B4FD55053C34745A12F24922E17AC5732D48B58EFB26FFAC776F8CF73
F4D16BF2D668EFD662EDD863EFDC66EFDA67F4D86DFFDC7FEFB66F914511C05936C6563E
C35548B5574F9F5854885856A98F8E9E94959B959996919799949A9A959B99949A9D989E
9B949B9B95999891989C959C9A959B979298969197959096959097989399938E94908B8F
8A86879E9A998C86862B2321372F2D30282626211ED2CECBF1EDEAE8E4E1EDE3E4EFDFE2
F7E1E4EFCFD2A17074D1999CAF7375BF8786F9CEC8B5948BC5A8A0705951B8A7A0FCF2F0
F0EAEAEDEBECECEAEBE5E1E2D5D1D2C7C3C4A39FA08C8889888284ACA6A6C0BABA443E3E
6864636C6865EEEDEBE7E7E5E3E5E2E3E5E2E4E4E4E5E3E4E6E2E3E7DEE1EADBDEFDEBE9
C8B2A7523B29442F123A2C00787224D9DB7AD7DE76E4ED94E1E7B7FBFEE900FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
ECEDE7BCBCB496928780786D50443888766CA78F85B89D94F2D5CDAD8F8795706AD5B0AA
FAD7D3CCA6A3916564A07473A17876A8817C86615970504582625598786BA17B70A87770
B77A77C274748D2E32A0373BBB4A4EC34F52C44C4EC6494DC7494CCA494DD04E50D34C50
D1494DD1494DD24950D14A50D0494DD14F4FC84D48AE392F952A169D3A1DB35934D68454
EBA368F9BA75FCC477FCCC77F8D071F5CF6CF3CB69F9CD74FFD38BA56630A34924BF5B41
BC5B4AAF5B5090534E946C6AAE99989F95969F999D9E989C9A94989992999790989C959D
979098928B928F8A918E8990847F86837E85807B8278737A68656E67646B625D645E5960
4341447571726C66683C36365A51522920214F4949EEEAE9E9E5E4EAE4E4EEE2E4F3DEE3
FCDFE4CAA2AA926167DBA0A4A76567A56867B786818D6860A98E85B7A69EE8DDD7EDE8E4
E7E6E4E6E6E4E6E6E4E6E6E4E8E8E6E8E8E6E9E7E8EAE8E9E6E4E5E8E6E7E9E7E89C9B99
8E8D8BDBDAD8ECECECE5E5E5E3E5E4E3E5E4E3E5E4E5E3E4E9E0E3ECDDE2EEDEE1FEEBE7
A08A7D49331C402D0C3E3300B9B85ED9DE77DCE384E6EEA5F3F6D7FBFCF400FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEE6D4D0C7A89F96A1948BB0A297D2C1B7BAA89E563E349D857B
E1CAC2E1CAC4B79B97B59996D1B5B2F3DAD6DCC3BEA58C85846C6270554A7D5D5290655C
AF7873C6827F954441913635A03C3CAF4545B34546B94747BE4A4BC24A4BC74B4DCA4C4D
CC4B4FCF4C51CC494FD14B52CE494ED24B51D55055D25052CB4E4CC04641AF3A309E311D
9A3519A24420B45D30C97944D38C4CE8A55FF3B36BF8B976FFC78EECA87B9A4121B85842
B65D4DA75D52895450A2807F96848483787C7E787C7872766D676B6861686059615A535B
4A434B4C454C4F48504A454B4B464C544F5558535A58535A5752595F5A61635E65676268
7A787B908C8D423E3F3F3939625C5C241E1E918B8BF5F1F0E6E2E1EAE4E4EEDFE2F8E1E7
F2D3D9C49BA1E9B8BCDEA6A7A366659055519E6F69C39E96D8BDB6F9E6DFF2E4E1ECE2E0
EBE3E0EBE4DEECE3DEEBE4DEE8E3DDE8E5E0E7E3E0E6E5E3E7E5E6E5E5E5ECECECDDDDDD
C7C7C5E9E9E7E5E5E5E3E3E3E3E5E4E3E5E4E5E5E5E7E3E4EADEE2ECDCDFF4E0E1F0DBD6
6E5747453013382900756E2ADDDF7CD0D770E4EB9BEDF4C0FBFEEB00FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F4EFE4DFD9D0C9C3AAA39B857C738E847A
A89F96BBB2ABD2C9C4EFE5E3FFF6F500FF0000FF0000FF00F6EDE8DBD0CABAA9A2977E79
8D6C658F625C8A514A8B463F9647429A413DA2403DA8403DA73E3BB44645B64444BF4949
C54E50C34B4DC44C4ECA4F52CB4E52C94B4ECE4D51D04F53D15152D05051CD4D4CCC4F4B
C2473FB73E33B1392B9F2C199D2D179F3319A1391CB75437C2644BDD7E68A33D2EB65145
B65F569A5550906360987C7B6C5E5E5B55575D575B5B565A5C565A5E585C6258606B6169
695F67756C717C727A7F797D8781858983878982898D868D918B8F948F93959192918D8E
ACA8A78A86852D29282824212A26232C2825D5D1CEF1EDEAE7E3E0E9E4E1EFE1E1FAE4E6
EFD1D3AC8586A97C79C1908BA5746DA4786FF9D2CBF7D6CFE3C4BFF1D8D4F4E1DDF5E2DE
F7E0DAF6DED4FAE0D3FBE1D4F6E3D5F0E2D7ECE3DAE9E4DEE9E6E1E6E5E1F1F1EFC2C2C0
9D9D9DECECECE5E5E7E4E4E6E2E4E3E4E4E4E6E4E5E9E0E3ECDDE0EEDCDCFBE6E3BBA29B
4A311D402C07483E01C5C370D9E078DDE786EBF3B7F8FDDDFBFDF200FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEE6D7D7CF
E6E6DEFAF9F400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F2
F1E0D9D8C1B9BB9A93A1766F945F598A4D4887403C90413C97423F9D423F9D3B38A53F3D
AE4444B14543B64645BC4A4ABD494AC24B4DC74F50C84D4FCC5052CA4C4FCE4D51CF4C51
CE4C4ED14C4FD14C4DD04B4CCD4B4BC44441BB3E3CB13734A7342FA2322EB64944B95852
AE5D5A894D4C977170A58F9194888A928C8E918C90979296989296958F93988F949E959A
A1989D9B92979A91969B95979C9698969092958F939A9496958F91948E8E928E8D999594
ABA7A458545124201D312D2A16120F64605DF1F0ECEAE6E3E9E4E1EBE1E0F0E0E0F8E0E0
F8D8D9E1B9B9DCACA8CF9E97DDB1A8FDD5CDD5B0AAC5A49F674543B29391FFE2E2FBD9D7
F8CBC6E7B2AAD29C90CF9E8FE3BCADF5D9CBF6E4D8F0E6DCEAE6DBE7E4DDE8E7E2DEDFDA
DDDDDBE6E6E4E4E4E4E4E4E4E3E5E4E4E4E4E7E1E3E9DFE0EBDBDBF3E0DCF7E0D87B6454
432B113929008D8638E2E385D6DE79E6EF9CF1F6CDFBFDEF00FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAECE9E9D6D2CAB1ADA78681926963814F48874B438D443E923F3B
9C413EA13F3CA43E3AA63D3AAD413FB24443BC4C4BBF4D4DBE4C4CC45051C34C4EC95153
CA4F51C94D4FCF4E53CF4E53D14E54D04D52CE4D52CF5155CC4F53C44D4FC15457B95D5E
9A5351814F4EA587879D8B8B958B8C938D8F928C8E948E90948E90938D8F938D8F958F91
988F92948B8E948E90958F91948E90928E8D918B8D948E90918B8D918B8B8F8989A29D9A
948F8C3934312C2724322D2A181413A5A1A0F5F1F0E8E2E2EBE3E1EFE1E1F6E2E3F5DBDA
D5B3B2AF8382B7817F743D3AC59490C59895AC8482D2ACABA6807FE1BABBFFE1E2E5AFAF
A052509A413D91383087372C8B4D409F7162CAAD9DE9D8C8EBE2D1E6E3D4E9E7DBE8E8DE
E7E8E0E4E5DFE5E6E1E3E3E1E3E5E4E4E2E3E8DFE0EBDDDCEFDED7FEEADFC2AD9C432E13
3A2800594E10CFCA6CDBDC76DDE38BF1F7B9FAFCE400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF8F3F5E6E1DEC7C1C6A59EA97C77915A57
8645419046438B3E3896433D9B433F9D423DA44541A4423FA94341B04646B44846B94948
BE4A4BC44D4FCA4F54CB4E54CB4C53CB4C55CD4E57CD5058CA4E56C45158BC575BB15F61
824646956D6DA58D8D948686948B8C8F898B908A8C908A8C908A8C8F898B938D8D928C8C
958C8F91888B948B8E938D8F918B8B908C8B8E888A8C86868E8888908B888F8A87A6A19E
615C592B2623362E2C251D1B3B3535DFD9D9EFE9E9EBE1E0EFE1E1F4E2E2F8E2E4BCA09F
C19E9CECC0BFE7B4B3915E5DA173737D5354AD8687D3ABACDDAFB1FFD4D6F2B6B88B4142
A74949C35F5DC36961B2655B905648673E2C604530615339797258BDBCA0EFF1D9E8EBD6
E6EBD7E4E8D9E3E7D9E3E6DBE3E4DCE7E4DDEADFD9EDDCD2F3E2D0F7E6CC826F4F3A2900
3A2F00A49F4DE5E47ADCDE79E9EFA9F6FBD2FBFDEF00FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF3F2EFDBDA
D9BDBAB695909E756F8B5C54814B4184453C8A443C954641A04844A24540A6433EA83F3C
AC3E3DB64645B94649B84349BB444AC04851C34B55C24D56C04E56BE565DB55F62975354
805252A4868698888993898A92898C8E888A908A8C908A8C8F868991888B91888B948B8E
938A8D90878A92878B94898D928C8E8C86888C86868D8787908A8A8E8986A199978E8683
372F2D3129273B32331C1314756C6FF6EDEEEEE2E4F1DEE0F4DEE0FAE0E3F9DFE2DFC1C3
CBA9A8C29C9B9B7270865E5EC8A8A9E9CBCDFFDFE6DCB1B875373CDE8F92C1686A9C3E3E
CC6F6ABF6C6495574C885E4E9F8672A99D85A09B7D858561B2B48CD7DEB2C4CDA2C6D1A7
DBE7C1DFEAC8E3ECCFE6EBD4E4E7D2E7E5D0EBDECBEEDEC4FBEBC7C6B88B433300403600
797418D5D76AD8DF6FE5EC8FF1F5C3FAFDE8FBFCF400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FCEDE8E8D4CDCAADA5AB867E986B658A554F8C4F4A86413C8E403C984541
9C4241A04240A03C3CA63F40A63C40A93C41AB3E44AD4248B34C50AB51539B53547C4644
96736F9D8883938582938B899088868E89868E88888E88888F868791888B8F86898E8588
90878A91888B93888C8F8488948B8E8B85878D87878C86868C878496918EA29A98564E4C
2B2321372E2F32292A22191CBDB7B9F7ECF0F2E3E6F1DDDFA88B8FAE8F94E9CACFFDDDE0
EFCBCBD3B0AE967472EDCFCDFFEAEAFAE4E7FFE8EFBE939C7C333AB2565BA94245C35D5B
C77067924E439F7567E8D3C2AEA8928080647879577A7B518C8C5A8C8F5663682E5F682F
6E7B45869461B7C499C1CCA4CFD0AEE1DDBAEEE0BDF7E6BAE4D59A7C7028817722A7A23E
D3D25CDDE369DDE47AEAF3A4F8FCDBFBFCF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF4F3F7E5E3E7D2CFD5B9B6B79691A07974976763
8D56538847438D423D923F3B9A413D9E403EA34142A24243A048469146415F2420875C55
A0857C9A8A7D90867A8E867B8D847B8D867E8C857F8E86838C87848F89898D87878B8585
8C838690878A91868A8E83878E85868E858692898A8A8182908B88A5A09D706866302728
33282C352A2E1A1114595357E9E4E8EDE7EBF4E8ECF0DBE294767E95747BE9C5C9EAC3C6
BD9697D2AFAD7F615F927877F3DFE0F5E2E4FFE9EFD2A7B08B4249CA6B71C65D61C76562
B5685E8F5A4CE4C9B8867B696B6650918D728E8662786B3E65591F635816766F27797931
6B753067763566783E5966315F612F756D3C9B895799854894842FACA137D4CC50D5D24D
DDE156D4DD60E3EC91ECF4BBFBFFE800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF5F2F9E4E1
EFD2CEDCB7B1C89993AD7671A0635E96524F924B478D48437C3D3669342C785046AF9387
9887759388728C866C8B856B8D876F8C86708C87748A84748A867A8D897E89847E898480
8883808C84828D83848E84838D83818A807E8D847F948B86A49B967A736D362C2A372D2C
3A3031241B1E393033D0CACCECEAEBE6E1E5EBE0E6F0DFE7F6DFE7F5D7DFB49499806063
C6A8A8E5C9C8957D7D705C5DF0E0E1F3E0E4F9E0E6FFD5DFAB5F69AF5058CB6468C86A68
A35D55A6786BB19B8D564F3DDFDAC6D7D0B671613F644F20CAB576A692499C8C3FC2BB6D
93954A6C76316D7738686E306D692A6B601E6B5911695701B1A434DAD14ECDCB38DBDE47
D6DD4FE1EA77E6EDA7F7FDD9FCFEF100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFF5F3FBE6E3EBD2CED8B9B6BB9C998A6F68AF998EE7D7C8E9DECA
C4BFA19D9B7599976E9291638E8D5F8B8A5E87845B88866086876586866A85826F858273
8A867D837F768B827D8B807A8E81788F8176988A7DA89C8E82766A392C23392C243C312D
221A17423D3ABEBAB9F1F0EEE6E5E3E5E3E4E9E3E7EDE2E8FAEDF4B09FA5826F73BBA8AA
B7A7A8AB9D9DB8ACACE3D7D9F5E6EBF5E0E7D8B9C1E2AEBAFDAFBDB05260BC5661C06467
A15B59A77A749A837B645A4E847D6B867A6256422194794AEED390DEC77B9D8A3BB8AC60
E5DE9A7B7738666024776F307C6E257A6A15968722CCC04AD6CE45C8C731D6DA3FDAE04C
DDE665E5EF8FEFF5C7FAFEEDF9FCF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3F9F5ECF7F3E7F0EFDD
D8D8BEC1C2A0B8B892AFB086ACAD81A3A4789E9D7198996F8F946C84886583866B85846F
8584727F796B8B7F719585759A88729B876EAC987D88775B3E2E143D2D1445342031220F
38301DCDC6B4FAF4E4EBE8D9E7E5D9E9E6DDECE4E1EBE3E0F0E8E6D8D0CEE5DBDAF7EDEC
ECE7E4EAE6E5F1EBEBEEE8EAEEE3E7FAE9EFD0B2BC6B3D48A86171B46070BC626EBE6B73
A569698C6663AF9C96574E45BFB7AAD2C7B35C492BA1895DECD297ECD58FA5924DB8A966
B7AB717467307F6E3682712C72600CB1A038DFD156D4CD41CCC831CECF33DBE247D8E057
E4ED82DFE6A0F9FDE200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F9FAF2F7F9ECECEDDDE3E5D0D4D8C1C0C4A9B4B79AACAF90A6AD8C99A07FA2A88CA7AB92
797961736B56AA9A83D4BCA0CCB08BAC8F638368394E38063F2A004B36094E390C3C2A00
A99D6DFEF3C5F4EBC2F0E8C4F0E9CCEFE7D0EFE7D4EFE6D5EDE5D8EDE7DBEFE8E0EAE5DF
E9E6E1E5E4E0E8E4E1E7E3E0E9E3E3EEE3E7F9E6ECAB8B96804C599F5F6DB06C79AF727A
8C6264745A59E8DDDB999490928E85867E7151452F746443D4C196F1DFAD897948918354
7362379582578D78436B540EB3A13DE0D257D0C73AC8C52CCCCC30DCE147D7E051E2EB76
D7DF94ECF1C8FBFDEF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBFEF5FAFEF0F7F9EBEAEDDADDE2CCC7CFB8B6BEA7A6AB95
71705C827B68D3C3ACBCA78A967C57A28758B7A06AB39F649D8A4F8E7C3E82702E7D6C27
C9BD73E7DB93EADD99EFE1A4F3E3AFF2E4B5F4E5BAF5E7C0F6E9C6F3E8CAF2E6CCF0E5CF
EDE4D3ECE5D5ECE5D5EAE4D4ECE6DAECE3DAF3E5E2FBE6E5D2AEB295686D8053587E5559
715554AD9E9BF7EFEDECE8E5C9C6C1B2AEA3B8AFA0AEA38DBAAC8FCBBC9BA0926FDECEAC
E6D4B0ECD7AC887034B19B46E5D460CFC63BC9C62DC9CB2CD5DB3DD9E14ED8E363DEE888
D6DDAAFBFEE900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F7F1
E8E8E0E1DED5DDD5CAB4A89894886EAEA17FCEC396DBD29BDED793DCD68AD0CA76BFB85E
BCB253BEB250B9A949AB983AAD9742BEA759C9B266D5BF76E1CC89EED89CF3DDA4F5DEAC
F6E0B7F5E1BCF7E5BFF4E6C1F3E6C4F1E6C8F0E4CCF5E6D3FFE9DBF2DCCFDCC6BBD1BDB4
DED1C8F0E9E1EAE7E2E7E6E1E9E8E3ECE9E2F3ECE4F6EEE3BEB2A4948774D4C6ACCCBD9E
E3D1AD9A86519E8936E7D567CFC33BD0CB33C6C628D2D83AD6DF48D5E15BDFEA82C7D18A
EFF4D6FCFDF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFDF4FFFCEDF7F2DEEDEACBDEDCB3D5D49ED8D898D7D78FDCD98A
DAD480DFD67BDDCF6ED1BF5BC5AF4CBAA23EAD962EA58E269F8926A089299F862CAF9541
B89E54C3AC68C9B570DDCA88E8D89AEFDEA6F1DFAFF2E1B5F5E6BFF8E8C6F9EAC9F9ECCC
F7ECD0F3E9D0EDE5D0EDE5D2EDE4D3EFE6D5F0E8D5FCF1DDD8CBB87C6D56EEDFC2E4D4B0
AA986884712CE6D470D5C848CAC334C7C62DCBCF34D8E04CD1DD55DEEC7AB7C475CBD3A4
FCFFEE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FDFDF5FEFEF4FCFDEFFDFCEAF9F9E1EFF0D1EAEAC6
E0DFB3D9D8A0D0CB87D3CB78E0D470E7DA68E8DA5DEADC59E4D651E0CF4BD4C341CAB83C
BBAA38AA982AA39125A4912A9B87289F8731AB9240BCA257BFA864CBB675DAC582E7D291
EFDB9EF3DEA7F4DEADF6DFB3F6DFB6F8E2B9F8E3B8FCE7BAF4DFB2E3D1A1FCECBBDFCE96
796421CBB760D8C956CAC23BC5C233C9CB39D8DF51D3DE5BDCED7BC3D37B9FA977F2F7E0
FBFCF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4
FCFFEEFCFFE4F1EFC6C1BF84C1BC6ACEC75FD1C851D8D04BD5CC3FDFD444E3D745EBDF4F
EBDF55ECE058ECDE59E8D95AE4D159DAC656CFB850C2AC49A9963A9E8D359F8E369D8B35
9C8736B29C50AB934DB29957C0A669C5AB6ECFB674D4BD7ADCC784E2CF8DE4D5947F702B
968638DDD070C4BD4BBFBE40CCCF4ED2DB5AD1DC62DAEA7FD1E38D829254CDD6B9FCFFF4
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FCFEF3FFFFF2EDEDD1B3B181B2AF6AC9C56CD2CE63C9C349C9C13CC8BF34CBC334
D3CB3AD9D140DDD244DED548DCD24CDFD655E1D95DE3DC68E3DC71DED973DDD777D8D274
D2C96ECFC46AC5B75FB8A853B3A250AA9844A3913B9886309787329C8D3C988C408F8639
DBD483C5C46AB3B756C6CE69CDD973CADA78C2D57BACC1746E824797A581F7FEEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00E7E6D19FA0789D9C63B9B76DCCC86DD5D26BD3D05DCCCA4F
CECB4ACCC946CAC746CDC94CC8C34BC0BF4BC5C458C0C05CBDC163C0C36CC4C577C1C276
C8C578CDCA7DD6CE83D9D186DED58ADFD689DED286DDD185D7CE83D6CE86D3CB8AD8D494
BFBE7D8487427B823E8B965288975491A16280915A697A4D798869E2EBD800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FDFDF5F5F6E8DFDFC7CFD0AEC1C296C1C289BEC17CC0C573
C5CA70C6CB6DC4C76EC9CB78CCCD81CCCD89D1D298CBCF9CC9CC9FD8DDB5E2E3C1DFE0BE
DEE0BBE4E6C1E9E6C3ECEAC4F0ECC7F1EDC7F0ECC6F3EFCAF3EFCAF2EFCCF0EDCEECEBCD
DEDFC0CACDAEC8CDAFCDD3B7D3D9BFD9E1C9E1E9D4EBF2E2F5FBF100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAFDECF1F5DCE3E7C4CCD2A6
AFB682B5BD84CFD3A0E6E9BCEFF1CAF2F6D5F7FBE2FBFEE9FAFEEFFBFEF300FF0000FF00
00FF00FDFFF2FDFFF2FEFEF2FDFEF0FDFEF0FDFDF1FDFDF1FDFDF1FDFDF1FDFDF3FDFDF3
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4FCFEF1
FAFDECF9FCEBFCFDEDFDFEF0FCFEF1FDFFF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.290056 0.97619 0.541732 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF800000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF800000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF800000FF00
00FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF00A020F0FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000
A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 221.938},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000gB000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`003_oooon/003o01[ooooo[000o`0@ooooo`003_oo
oolZ003o00030=WJeP3Ad/d0k>cZ07l00?l06_oooolZ003o00030=1@N03oP000X23`07l00?l04?oo
ool000kooooo9P00o`002`3hmo<0g=_G0;:a[`1nOG/0?C`h03Dd<01CDTh0MgIb0:FVX@3<c<X0jNWW
07/00?l06_oooolV003o00040?n0002P8?00oh000?n000<0X23`0`3oP0000`2P8?000?l0003o001i
003o013ooooo000>ooooob@00?l000l0g=SE09bIU01VHe`0?c`e02LT7`0]:RD0;2PU038_:P0_;2L0
:BHQ02PW8P0^;bL0AdQ208^<QP3]k^T0N@00o`0Jooooob@00?l000<0X23`0?n0003oP0002P2P8?00
0`3oP000X23`003o001h003o013ooooo000>ooooob800?l00180m_Ob0:j]Z@13@3/08QdG024N5@0`
;B@0?3La04<n>P18@Sh0DT]505E>B01DCdT0CDY103Ld:`0R8QP06a/C05iOF@3@dLah003o01[ooooo
8P00o`020?n000l0X23`00<0oh00003o0000o`00MP00o`0@ooooo`003_oooolQ003o000D0>3Qg01m
O7L0=34Z01dH4P0X91/0=C4X044m=010>C<0>C4^040g=017?ST0BD0k04e4?@1@BCl0BD8h04<o=P0e
<RT07AdE03hm>@2][:Yg003o01[ooooo8@00o`000`2P8?00oh000:0Pl00@0:0Pl0030?n00000o`00
0?l007D00?l04?ooool000kooooo8000o`005P3Shn40GeiI02PU7P0U8AP07a/B03Lc:P10?3<0>cL^
03L`:P0d;2T0@3Hd04<h=014>C<0?c@^03lf;@18?cH0BT<i04]7?00l>C00:2DP02XY9@2UYJ=f003o
01[ooooo8000o`0E0:0Pl0030?n00000o`000?l007@00?l04?ooool000kooooo7`00o`00603dm?80
NgYe02DU7@0/:B00920G038[8@16?cD0>c@Z04M0=P0m=2d0=2/V03H_:@0l<bh0>C0Y03/b:`1:@CP0
CdLl048j;`13?c<0BTPl03Ld;@0O7QT0?3dh0=KFe7D00?l06_oooolO003o0080oh005P2P8?1e003o
013ooooo000>oooooaL00?l000<0P?Yj083kNP20nWP00P20nWT07020ngT0P?aj06KOG01`JV@091hH
02PS7@0`:R@0:24J034W8@18?SP0>2hX03L]9@16?3H0?38]03H/9P11=c40=bdW044g;P1AB3l0C44h
03dc:P0m=R/0B48h04a8?`0Z:B@08B0L04Q8AP3@clmd003o01[ooooo5`00o`08083000030=1@N02P
8?00X23`01@0X23`00<0d51h0?n00000o`00L`00o`0@ooooo`003_ooool;003o000^0?o^j03XdL/0
hLW50=S3`03D`/00eL?10=_9a`3B_K`0eK^l0=jn_`3AZZ/0`9BE0<bJV@3;V9@0_hZ40;N5OP2_OWL0
X7E^099`I`1PAC`09aD;02DH4P0a:2<0;R@R02XP7P0Y7Q`0>2d[044f<P0_9200=b`X03X_:`0n<bd0
DDI004<h<P0o=Rd0BT0g03H/8`0`9Qd0=bhU04M0>014?cT0:bPS02HR7`0K5aH0B4920>ONgd400?l0
00`0kNg]0:n_[`1ZJVP0IFES06EVH@1UIF<0IfQS06Y[IP2>SX`0^k^i0=?Cd@3Xj>HV003o01[ooooo
2`00o`020:0Pl140oh0000<0X23`0?n0002P8?00602P8?11003o00030:0Pl03oP000oh0000D0X23`
0P3oP0020:0Pl2H00?l04?ooool000kooooo2@00o`00=`3on?D0o=G>0;n9O`29CD80Y71U0:UlMP22
GEL0Pf9M0:B1O`2RNWP0Y7Ad0;=iN02UGEh0Schm0:=:AP2VAd40Xd8h0:=5>@2E?C40QSP[07Xl;`1O
<bH0<aD;02PE3P0e9b@0<bTW02hT8P0Z81h0;28P03@Z:00g;B/0>2dY03db;P0o=Rl0DdY104m6?@17
@3H0?SL]030W800X7aP0@CPa04Q1>`0g;b`0;BDS02DL7@0W6a/09A8D08QdL`3Lb/H0h=7:0>KId@3]
hmX0n>oV0?ofk`3ooOD0>000o`004P3^k^`0[:j[05UIE`0U9B<06QTG01LF4P0I61<06aXF01/K5@0?
40X06Q/F02<T7`0/;RT0AdU406AVH`27RHH0[[2]0>;ThB800?l06_ooool9003o00<0oh0000<0X23`
0?n0003oP0000P2P8?040?n000030:0Pl03oP000oh0000D0oh000`2P8?000`3oP000X23`0:0Pl00D
0:0Pl0<0oh00102P8?020?n003P00?l000<0X23`0?n0002P8?00302P8?020?n000030:0Pl000o`00
0?l002000?l04?ooool000kooooo2000o`00AP20mG@0iJjY0;9YH02LBC/0T3d]0=2;O02mPgP0V6MP
08iSG@2DIf80VVMT0:U/J`33NGP0b6i]0:U1?P2kBT@0_TLo0<M<@`35CCl0_D`n0:<o;`2[F4P0PD<d
048H300/3`T0=24M03LY9P0c:2H0<BHT02hT8P0[8Al0;bDS03P]:@0j;b/0?C@^048i<P10>C40?c/b
03Te;00g<2X0?cPb03P`;@0f;R/0<BTW02PN7@0]7al0=20R02/>40108Ah0DC<Y05Tl;P1]DT40JE@m
07AOBP1kJED0P6eL08UfI@2AOVd0XHak0:jHRP2jY9H0b;:U0=Fm/`3Ka;`0h<_60>KCc`3/f]H0lN;O
0?CYi@1mn7LX003o00070?;bl02_[jd0EeME01hP6`0E5Q407ahJ020O6`0201`K5P0<02TV8@0S8a/0
7AhF01dN600H6A<05QLA01HI4P0E5a805QPE01LI5P1>D4d0e]KF8@00o`0Jooooo`P00?l000<0D91h
0?n0002P8?000P3oP000102P8?00oh000?n0002P8?030?n00080X23`203oP0030:0Pl0030?n0002P
8?00X23`0180X23`00<0oh000:0Pl02P8?000`2P8?0=0?n000@0X23`00<0D91h003o0000o`009P00
o`000`2P8?00oh000:0Pl00B0:0Pl2400?l04?ooool000kooooo1`00o`00:P3om_D0j:VT0;I?AP2j
BSh0/4De09`m:`3RUHD0aXQk0;B0M@2GJ600Xg=_0;9lNP2]KF/0bWaj0=anO02dB4D0`di70<97@03A
DDT0ce550<Y@@`2^?S00_Ue=09I:?01@5PX0=Ph603TM6@0g8b80=2@T03X/:`0_9280;b@P030U8@0d
9R<0<bPT03L^:@0h<B/0>S<]03hi<`0f<B/0=Rh[03L_;080:b<Q02X0:b4R030R8P0e8B<0>1/M038:
2`1E9B40JST[06/k9@1jCC00GcPB05Pe2`1K=@h0FcD@05D_2P1I<`h0G3@@06Tn701L;A40J3@N06L^
6`1S:QT0IblR06hj;`1cAch0Lda507IECP1nHE`0SFm]09EfL`2UQX<0[i2=0;VJU@34Yj<0ck>_0=W0
_03Mb<D0h/o;0>OEd@3]g]/0lnCQ0?W[jP3nlo4H003o000G0<K6a01UIV408b@O01LH4`0E5Q406AXE
020O6`0Q81/0;b`W030]9P0d;bT0=c@]03Ti;`0c<b/09RLO01`M5@0H6A405APA01<E400B5a<041DA
04Y<B`3Be=<08000o`0Jooooo`L00?l000<0oh000=1@N03oP0000`3oP0000`2P8?00oh000?n00004
0?n00080X23`0`3oP0000`3@D7P0oh000?n000030?n000<0X23`0P3oP00A0:0Pl0030?n0002P8?00
X23`01H0X23`2@3oP0060:0Pl1P00?l000<0oh000:0Pl02P8?00502P8?0P003o013ooooo000>oooo
o`H00?l00200ooGd0=^_[02eE4/0bdLk0=1;?02oASD0Z3l/0>REP`3;R7P0^Gmc0:]eJ`2_MVl0ZVeX
09eFDP2fHEh0fgQc0;m>B039CTL0c4]50=A?A`3AC4<0d4e30;a0=032DD<0^e]=06dO4P131`00?a8=
03lM6`0j81l0=b<R03DS8@80>R/X04L0?Bh[03/]:P0b9bD0;R@R02lW900c:bP0;2@Q02XR800Y8Al0
:B0Q02/Q8P0]7al0<alQ03hQ8`0h4A80>@H506DZ901m?c00O40V095K=`1iC1h0MD/I07iB8@20E2<0
MTXI07A65@1eAAL0OdXN06lc3P1g=AD0QCTO08Lk901n=B@0NSHY070g;01J:R00E2`T04/U7P1:8R00
D2LS05@[9`1D:bD0EbhX05</9@1?:R80C2/T05Hg<P1I?3H0H4Dn06Q<B@1_EU80M5aH07eUH@26KVX0
V85m0:VDS`2eX9d0`JbY0<Vd/@3G`[l0g/W60>G@c@3Zem<0l=gI0?KWhP3kk^P0o_G^0?omlP3ooo@0
oooc0?onm@04003o000J0>;Rh028R8H0=3D`01`M600J6aH071dH01TJ5@0F5a80:RTT03Tf<@10>cD0
>3<]038]9`0c;bT0>3D/03<`9`0a<BL0=3@Z02h_9`0R8ad04aH?01LI500F61D061XI051BD@3Fe]HO
003o01[ooooo1P00o`020?n000030=1@N03oP000oh000080oh0000<0X23`0?n0003oP000103oP002
0:0Pl0<0oh0000<0d51h0?n0003oP0000`3oP0050:0Pl080oh003P2P8?000`3oP000X23`0:0Pl00?
0:0Pl0@0oh00402P8?0;0?n000D0X23`1@3oP004003o00030:0Pl03oP000X23`01L0X23`7`00o`0@
ooooo`003_ooool6003o001A0?cCc`2QEU00adXo0=A5=`3BASD0aTLf0:`m:P3VSWX0agaY0;UdI@2W
HeH0T4Y00:IKE@2MB4<0`65K0>QkM031B400cTe70=5:A03ICdP0f4e60=E;@@3;@CH0bDDi0=EMC`2^
A3H0LaT@05@;10194Pd0AA`H03`M6P0h7a/0>RDP03`Y9@12<2h0@34^03`a;`0d:BL0;B<Q03@Z:@0c
:BP0<BLX03<Y:P0`92H0<B<S03@N800j71h0A1`M03h;2P1820H0MC4X08Y6<`2=CC80ZgMB08eR=P24
GRd0RVDa09Q`?@2BJSL0UF`h09EW=P2LJCX0Ue``09]G<02=?Qd0SclT0997<02<BSX0Ic4W05X_:02:
J5h0PEmG08=MFP22FED0G30]06@i<`1U?CD0DR`S05@_9P1G=B`0FCP_0080D2lV02T0CBXV04`Y9@1?
;2P0B2DO04hY8`1?:B<0Db`U050Y8P1B:B<0ERTT060]:@1X;RX0Kc@^07Ln=`1mBCh0P514089KBP1o
Hdh0Of]@08f2HP2DSV`0WIQj0:ZYT`2k^jl0`/>k0:RYX`1=CTT07AhI01`M5`0Q8Q`07A`H01hM6@0O
7QX09RDQ04=0>`0a;RT0;2LS030[9`0X8al0;BPR034/9P0202PS7@0:030]9P0c<b/0<C0[02<T7P0G
61<05AHA01`L6P0I6AL0D51@0>3Ph1h00?l06_ooool6003o00L0oh00102P8?000`3oP000X23`0?n0
00020:0Pl0<0oh000`2P8?020?n000030:0Pl03oP000X23`00D0X23`0`3oP00:0:0Pl0030?n0002P
8?00X23`00<0X23`0`3oP0000`3@D7P0X23`0:0Pl0060?n000030:0Pl03oP000oh000080oh008@2P
8?080?n001/0X23`7P00o`0@ooooo`003_ooool5003o001g0?ofl`3LX9P0YdDj0==7>P3G@C80eD@c
0<M2<@2a>BP0hW]X0>^@O@3<M6H0]emC0;EKDP35I5d0dFYS0?21NP3OI5d0bTLo0=E<A03HBd@0fT]3
0=i?A`3MCD@0ed@j0<`l<@3MDdH0dU950;Y5>`2<9ad0G`l605<C2P1;5Q00AQTD044L5P107aX0>adK
03/Q800k92<0=b<R03HR8@0j:2P0=R@T030L7@0g8B<0>AlR03`L7`0n5QL0AaDF04d?401>10<0IA8<
090l<@2GAS<0WUHm0:ifD`29Fc80N58U06]5601bC1d0M4`K08UO;@26FR/0SU//08Q?8P2NGC<0Y5Pd
09M:;02ECCD0RT/j05DS6P23GE@0[Hb30:F4OP2hTXl0Ufi/05T`;P1S>SH0D2TR081KDP2HMV`0UgE[
095_I@2=J5l0S6EN08YQF`27G5H0QUeG07eDCP1gCdL0L4Q006Hk<P1U>C00FbXS06T_:`1[9b@0O2hZ
080]9`1m:R80NbdP078[6@1X;QH0DRL505`o5@1WER80H5DO05YB8`1LF3D0Gei903dn<00@4@T05AH@
01hO6@0P8A/07b0J020O6`0O7QX06QTE03Xi=@0j=c800P0Y9R40400W91l09B0L034/9`0[9R00;2@Q
02/V8P0/9b<09R<L02/X8`0e=2l08b@O01TJ5@0L71X07AdK01HF5P29RHTN003o01[ooooo1@00o`08
0?n000@0X23`00<0oh000:0Pl02P8?000P2P8?000`3oP000X23`0:0Pl0030:0Pl080oh000P2P8?02
0?n000P0X23`00<0d51h0?n0003oP000103oP0070:0Pl0@0oh0000<0d51h0:0Pl02P8?001`2P8?04
0?n00080X23`103oP0040:0Pl0<0oh003@2P8?040?n000@0X23`0`3oP0000`3@D7P0X23`0:0Pl00K
0:0Pl0030?n00000o`000?l001`00?l04?ooool000kooooo1@00o`00RP3oin<0]fQQ0;i<@@3EACL0
ecla0=0m;@3DAcH0`Sd/0=eTD`3mRWP0lh5f0>QcJP3VKFD0gF1J0=QIDP3HDd`0cD@l0==6?@3HBT00
edLn0=e9@@3QC4D0gDTo0=Y3>P3G@3D0fDDi0=m@@P3NE4L0ce530;51<`299aX0Ja@:05L=101C4P`0
DALC04PE4P196AL0AahM03XC500l61X0?QXJ03`H60116AX0@ADF04LE601;4180D`d?05P71P1V1`D0
NQ4=09lb:`2]@cH0ZT/g09i<=02bKe80SUTg08QJ>01dB2D0GS@>06m56`1mDRL0KD0G07Y9801d?Q80
VE/b0:QR@02DCC40UE<m07]1<`1/?CD0/8^30;6@R@2bTH`0_YNH079:B`1K=3D0DBh/06M6@@2cTX/0
[8j40:j=Q02ZR7l0]Xf70;F8P`2WMW80YgIa0:]nN02YPGT0Xh5h09enL`2INFh0UWAZ09M/I@2WLVh0
NcLd07/W9@2F>C@0Uc@^09@d9P29=1l0P3TI06`h2@28I2X0QF`Y07QW8@1fJb/0OGM708j=K`1UI580
20P001HF3P0S8Qd092<N024P6`0W91l081dH01XG4P13@3/0:bXU020O6P0V9B007QdH02<N6010>S@0
9B0J02dX900[9R80:RDQ02<N6P0Z9B40=C8]03`k=P0K71L05QHD01dM6`0H6QL0@48o0>CTi1d00?l0
6_ooool5003o0080X23`1P3oP0080:0Pl080oh001P2P8?00103oP000X23`0:0Pl02P8?030?n001<0
X23`103oP0000`2P8?00d51h0:0Pl0090:0Pl080oh000P2P8?040?n000@0X23`4@3oP0000`2P8?00
oh000?n000030?n00080X23`1P3oP00M0:0Pl1d00?l04?ooool000kooooo1@00o`00RP3/`kl0[4m7
0<Q:?P3HASL0fD4c0=@n;`3NBc/0f4/j0<a4=03NFDX0f5970=U@B03JCdP0e4Ln0=A5?@3B@ST0eT<k
0=Q4>P3F@SP0fDDk0=]4>`3OASh0fT8g0=Y1>@3H@3D0g48f0>18>P3YDdD0i5M60=QCA03;D400[cdb
08lY7@1b50`0H@`705/<201G3@X0F18A04h<3@1@4140C@d>058@4@1B3Pl0DPP905T9301O1PP0K0P:
088B4@2O9B80]3D^0<E5?02nASP0/4Ld0:E:=@2hK5@0Z6U?0:E]E02GHDL0Pe0c08]J>P28EcH0P4h]
08aF=01oA280]GIE0;=bE02ADCP0SU=106<_8P2?I5d0b:>M0;fJU037XZ00Zh:6068i?@1V?d80CB/Z
09UjM`2gV9<0/I>;0;BAR`2nUHl0aiJB08eFD`25BTH0QTa8085@B@1kD4T0OE]B0:F:O`2TRGh0Y8Il
0:b5OP2mQhD0L2`[07dW9P2N?3T0VS</09di:P2D>R80R3`H07To3@2KLS80SG4W085`8P1nLB/0T8QC
09jKNP1iN6@03Ph201LG3`0V9B009B@O028O6P0W91l08b0K020M6010?CP0=C@_01hM600P8A/06APC
02<N6017@S`091lI02XU8@0V8Ad091lK02HQ7@0U81`0;2TT0450>`0S91h06AXE01/K6@0O8Ah0828O
0:n_[ad00?l06_ooool5003o00<0oh0000<0d51h0:0Pl03oP0000P2P8?000`3oP000X23`0:0Pl002
0:0Pl0@0oh0000<0X23`0?n0002P8?00102P8?000`3oP000X23`0:0Pl0030:0Pl0<0oh003`2P8?06
0?n000040:0Pl03@D7P0oh000?n000H0X23`0`3oP0020:0Pl0D0oh000`2P8?060?n000H0X23`1@3o
P0000`2P8?00oh000?n000040?n000030:0Pl03oP000oh0000D0oh00702P8?000`3oP0000?l0003o
000K003o013ooooo000>ooooo`@00?l00140ooCb0<J?S02^Ad00cTU00=U7>@3J@SD0fd<e0=i8>@3H
A3H0fTPk0=e;?P3NC3l0gda20=U5>`3JAS`0fDDk0=a5>P020=U1=P1N0=Q0=@3I@CH0fT8g0=Y0=P3H
?S80fCle0=a2=P3I?c<0hTPl0>]CAP3UDD<0h5510=iB@`3NF4`0f5Q=0<a@AP2e?SH0Xc8/08hQ701o
5A80N10?07@<2`1`2PP0M0`;07dC4`215AD0SAXM09hV9`2^;Rd0b44n0=94@03HBd80cdHl0<Q:?02g
B3L0[4/j0<EbH02VGdl0Y65A09]IB@2OGT`0Y6IA0;5cGP2OGTX0ZFQD0:=QB`2aL5`0[6eK09UNCP1g
@cH0H34Y09I]I`2_RX@0[hV60<2HVP29G6<0Ica3060g>`1V@T80`InM0<6PV`30WIL0`YVE0=f[ZP2b
MG@0Mc4_09A:A`2GDTd0SEA=06Pi<@1[A3d0[Y690:^>QP2^SHH0`iZD09mYI`1V8R40SSXh09`o>P2L
>c80WD0_09Q4:P26?QP0QU4M0:5i>`2>Lb`0RWP`081e<`2ITEh0Z:>308V6L`0F50P05a@=02TV8@80
9B8M01P09R8O02@Q700Q81/0<c8]03hm>@0Q81`071/G018A300W91d0CDU101lJ500Q7QL0924L02HS
7P0R7aX07Q/D02dZ8`15ACd08R<M028S7P0M7A/06adJ01LI5P1XJ6HM003o01[ooooo1000o`040?n0
00030=1@N02P8?00X23`00`0X23`00@0oh000:0Pl03@D7P0X23`0P3oP0000`2P8?00oh000:0Pl006
0:0Pl0@0oh00202P8?040?n000030:0Pl03oP000oh000080oh001@2P8?020?n000<0X23`0`3oP002
0:0Pl0@0oh00102P8?060?n000030:0Pl03oP000oh0000<0X23`1@3oP0000`2P8?00oh000?n00004
0?n000030:0Pl03oP000oh0000D0oh00702P8?000`3oP0000?l0003o000K003o013ooooo000>oooo
o`@00?l000d0o]_G0:AOF02jBD40dTPn0=]7>@3OACT0gT@h0=]3=@3PB3/0hDTl0>59?P3RB3`0gTHi
0080gTHk07d0gdLj0=e5>03M@cL0fClc0=]1=@3OACT0fd4g0=]1=@3I?c<0gD<g0=To<`3L@cD0hDPj
0>Q@@P3YDD<0j5930>iKB`3XETT0jEU>0>UMD03^I5T0jVAI0>AQE`3JEe00cdi80<a;AP32@Sl0_Shk
0<A4@`3IEeL0ee9C0=Y@D03QDE00hdm;0>M?BP3NBD80edTo0<U7>@2gASH0[4/j0<QeI@2]IUL0VeU;
08E3=@28ASP0Te530:ESE@2EDdD0UeE709EFA`2HFTd0R5130;5oM01J;RD0OUM@0;RCS@2]RXH0/Xb;
0;>9S01Y?4<0L4I:050Y;026HV80ZhV70:R7PP2`RhD0^h^;0=2FU@2>ATL0Pc<b09i=BP2MDTd0TEA?
05l^9`2AJV<0_YnG0;ZMU@2oWYL0cZNR07U6A@1a=3<0TdM709U8A02JB3d0UDPf08m7;`20A280TF8d
0:R5C@2GOD00Sgdo08aoB02OUf/0[:N909VFP`0O7A404a0902PU800W91l09R<N02LS800Q81`09B@O
02<R7@0c<Rh0>CPf01TH500;2PD0<BhW04]7?`0O6a807AXC024N5`0R7aX07Q/F01dJ4`0j>S80?Slg
024R700Q8Qd06a/I01TI5`0C4a40<30^0;Zj^00L003o01[ooooo1000o`00103oP000X23`0?n0003o
P00>0:0Pl0030?n0002P8?00X23`0080X23`00<0oh000:0Pl03oP0003@2P8?050?n000P0X23`0`3o
P0030:0Pl0<0oh0000<0X23`0?n0003oP0000`2P8?000`3oP000X23`0:0Pl0040?n000@0X23`2@3o
P0020:0Pl0D0oh000P2P8?050?n000030:0Pl03oP000oh0000H0oh007@2P8?000`3oP0000?l0003o
000J003o013ooooo000>ooooo`<00?l00280ooOe0=nZY02OB3l0a4]00=I:?@3KAcP0gdDi0>=9?@3Y
DD@0j5130>=9?@3L@SH0hTHj0=i4>03PASX0hTPl0=i4>03SBCd0i4Pl0>98?03PAcT0gdLi0>16>P3Q
Ac/0gdDi0=m6>03NACL0h4Lg0>58>03VCCd0iTln0>]EA03]EdH0lEi>0P3]Fd`0C`3^G4d0jea>0>iP
DP3]H5<0kV5G0?=VG@3/HEX0gUE?0>ENF`3fKVh0lFMW0>EFF03[EeL0je=@0>E=B03PBd@0e4@i0<Y6
>@2gASH0Zd`j0:iQC`2NH4h0W6EA09YSC`2OIeH0UEe>09UQE02HH5<0VfEI09EQE02>GU80Oe=:0:In
MP1S@3X0ZHR30<6OW@2kVIL0aZ2O0;>:S01S>Cd0HS/l05Hd<`2dUI80]YND0;NFT@2hT8h0cING0;]f
N@1n;B`0Vd=209m:A`2KD4/0OT<m068c:`2[QWh0/9680;BFSP2nWIP0Z89o06do?`27E5<0T5ID095F
D02FG540TUY;08mLB@23Ec`0UW9@09f0F02DOE40TGiC08n2F02SVWL0V99j0;JcXP11?c<030/602<R
7P0X9b<00P0T8al06`0R8Ad09B@P01lP6`0R8R00<c@_03@c;P0T91`0;b`U03Tf;P0R7aH07Q/B01LD
2`0I6A40820H038a;00k?3H09bPR01lP6P0P7a/08B0L01`K5`0J6AD05aHB02`]:025QH<0Y:JS0=kP
g@0I003o01[ooooo0`00o`040?n00300X23`103oP0000`2P8?00d51h0?n000070?n00080X23`00<0
oh000:0Pl03oP0000`3oP000103@D7P0X23`0:0Pl02P8?050?n000030:0Pl03oP000oh000080oh00
0P2P8?050?n000@0X23`00@0oh000:0Pl02P8?00X23`203oP00N0:0Pl080oh0000<0X23`003o0000
o`005`00o`0@ooooo`003_ooool3003o000Q0?o`k02iMVh0ZTDk0<i@A03DASP0fdHh0>Q@@`3`F4/0
jU950>A<?`3K@cH0gTHi0>18>`3QBC`0hT`n0=i8>P3SBd00hDTl0>18?@3SBch0gdTk0>5;?@3RBSl0
hDTn0>59?03QBC/0gdPg0>=<>@3QC3P0hTlk0=i>=P3NDCH0j5a10080kV9905/0k6170>YNA@3^HT/0
jEi70>ePB`3[GT`0k5m>0>]LCP3YFdl0jeiE0?U[I`3jJfL0jeYG0>eHE03[Ddh0idi80=e6?`3D@CL0
bdDi0;e:>02_CS/0RS`V08a?>02;ECd0Pdlg08YH?`2>G4D0QeM108EF@P2:GDX0SfID08]VE024He@0
QfML06a?A`2bUI40_j2M0<2NW03=YZL0VG1d06e6B@1>;2/0RFYW0<JYY@2lWIX0_I^I0<^OWP3UZJ/0
Uda@08<[:P2VBdX0XD]:09]ACP1M9R40QU]D0;fHT02eU8d0^9FA0<bTXP1lDU<0IcLg089@C`1U<Rl0
L3di06Ph;P1eAcX0JCl_068l:@1bD3L0FcdQ06Q=;`1H@B80NFI808=fFP2DS7L0^[FR09VGRP0L71@0
5QD@028Q7@0U92009bHR024P700R8Ad07A`H028Q7`0X9b<0:2LR03<c:`0j=c80>cPa0080<BhU01<0
9bLM03<c:`0h=c80>S/e02HW8@0R8ah07b0K028Q7@0V9B<07A`J020O6`0G5Q@04a<A05mOG@1QHf00
NGYe0:>TW`39b/D0inOU01H00?l06_ooool3003o0080X23`0`3oP00_0:0Pl0D0oh0000<0d51h0:0P
l02P8?001@2P8?000`3oP000X23`0:0Pl0020:0Pl0@0oh0000@0d51h0:0Pl02P8?00X23`2P3oP002
0:0Pl0@0oh00302P8?060?n001l0X23`00@0d51h0?n0003oP000X23`5P00o`0@ooooo`003_ooool3
003o000D0>k=b02PDTP0_e150=5=@@3IBS`0h4/m0>]EA`3]EdT0iDm10=e9>`3NBS`0hDm00=]<?P3J
Bcd0gDi00=a=?`3QCT@0he540=i;@@3NC3l20>1>@@1X0>1<@P3QBT40gDHk0>1:?03PBST0gdhi0>1D
>`3DCBl0cDdZ0<mA:`3AERd0g64h0>5U?`3XK4H0i6Q40=mS@@3PI480hf=30>MTAP3^IT`0k65:0>aO
B`3^Gdl0lV=E0?YWG@3YET`0j55:0>M@B@3QBT40gDHm0=I3>`3=ACT0addn0:a5<P2:=1d0[VM;0:U/
C@2<E3<0UF0n08aJ>@21Dc40PEHd08EQ?`1oGSd0Idd/06mF>01bFT80FCl`09j2M`33XYd0a:6O0=Vb
/`21FUd0Hcm304h^;`2fV9H0`ZBR0;jOW032W9/0f:JW0=2>T01l;2l0UCTj0:]=C@2RDE00PShk05/X
902_QX80_Y^G0;VGT`39X9h0`I6A05`X:P1f>cd0ZW1^08aBCP2GH5/0WVaU09QYH@2>HUL0QUa@08eV
E`1oFTP0U75M06I6<@24J5<0S7IP0:RLQP2g/9d0cLZi08F3M`0L71@05AH@01lP6`0Y:2@09B@P02DQ
7P0U8Qd08AdJ01dL5`0O7QX09RDP02`[9`0`;bX2038b:P0703@d;00d<bh0:b`V02HW8P0Q8Qd07alM
01XJ600202HT9@0>01/K6`0P81h05ADE01<C4@1^KV`0Kg1[075bJ`1gMfl0MGM/07ioM`2IW9<0_;fg
0>7Rg03em_4B003o01[ooooo0`00o`040?n001X0X23`0P3oP00D0:0Pl0D0oh0000@0X23`0?n0002P
8?00oh001P2P8?020?n000030:0Pl03oP000oh000080oh0000<0d51h0:0Pl02P8?002`3oP0000`2P
8?00oh000?n000030?n00080X23`00<0oh000:0Pl03oP0000P3oP0040:0Pl0030?n0002P8?00oh00
00D0oh00702P8?020?n000030=1@N03oP000oh0000<0oh0000<0X23`0?n00000o`004@00o`0@oooo
o`003_ooool2003o002K0?ogm@31U8l0Vd<i0<Q?A03ABCd0edPj0>MBA03_FDX0j5940>9>@03VE4D0
h5510=a@@@3EC3`0hEU;0>]QE03XG4l0jeeA0>eOD`3XFTh0i5I:0>IHC03UEd/0iEE<0>ADB@3SD4H0
iUA70=m@?`3TFD@0f5Di0=iS@P3WLd`0eFHi0=U]?P3EJCX0f6`n0>9fB03TMd`0h7=80=Q[@03RL4D0
hF]30>M]B03WITH0j6950=mG?@3TFD80hUE10=i??P3QCd00gd/o0>=<@@3MASd0g4Pn0=95>`3<C3l0
`4`m0:e8=036Ke@0_71@0:iUA02[JDH0Velk0:5[A@2HJ480T6U208e]A`1oID00Pfa<081[D01YD3`0
U7I[0<ZWX`3<YJH0ejn`0759CP1@;C40NUaL0<b^[02oXIl0aJ>R0<ZRXP3P[Zl0YVAX07DV:@2UC4h0
YU1A09mEE01Q9B@0P5=@0<^UXP2iUiD0`9ZH0=VYZ@2LHFD0IR@V08i8B032NgT0/VmY0;]jM02[L6X0
YFaU0:9[I02eP7P0_HR00;5oM02_OG80W6iO0:V2L@2KOV/0/Z6=0;J^V@3Ac[/0h^3C06IVGP0D5A00
5ADC01dL6P0V9B<0;2PU02dZ9@0V8ah07a`G01dL600R8Ad09RDQ02@S7`0T9Al09BDM02<S6`0O81X0
8B8M02DU8`0Q8Al07AdK01TI5`0O7B008AlR01dM7`0V9RP04Q8D01lO8@27QhL0NWYh07UhL@24Q7P0
MWIZ07AfJ@1gNFh0LWAY07MhL02@THT0];F_0=OHd`3^k^`03`00o`0Jooooo`800?l01@3oP00a0:0P
l0@0oh00102P8?040?n000030:0Pl03oP000oh0000H0oh000`2P8?050?n00080X23`0`3oP0020:0P
l0D0oh0000@0X23`0?n0002P8?00X23`3P3oP0000`2P8?00oh000:0Pl00J0:0Pl0/0oh000P2P8?0?
003o013ooooo000>ooooo`800?l006T0o>3M09aSG02T@SL0cDm10=98>`3JB3T0k5E40>]EA03VD440
jEI60>IGA`3RETD0jFAC0?YhJP3lOFh0o7Q[0?1XFP3^I5L0lVIG0?AXF`3cIeX0mF]P0?9XG@3cIU`0
lFAJ0>iQE`3^HUD0jF1@0>EPC@3BESh0hG1B0?V>JP3JMD/0m99U0?>AI03]S5l0lI9T0>b@G`3eVFP0
liER0>V:E`3UPDl0gWE60>EfB`3ULDX0eEdh0=QL>P3BDc80eU<g0=M<=@3RDD00hD/m0>=<@@3PC480
f4Po0=E;@@3FE4L0fUm@0=5QC@3<ITd0bVQ=0<M/D@3;NUd0`gaN0:]^C`2]NU/0ZH9S08MXB`2NPfP0
V7iW08=VEP2OOg@0cJNT0=jf]`2kTID0JD16058^<P2_Si00c:j/0<FWY@37Z:D0eZn`0=BSYP1k?T<0
RT=70:5EF@2PF5/0RDe=05HV902]Qh@0bjVW0;nMV`3;Wj00f9fQ07/b>@27=CT0Xde<0<Q`K02`GED0
_FmU0:EKDP2JDDX0W5I>0;QbJP36P7P00P2RGUD0402IFe00T5];09QbH02nZIH0^JjJ0<_6/`3clN@0
[ZjV034a;`15ADL0:2HY01LE600P7ad0<Rh[03<_;00]:BH202LS800702@P7@0S81`07ahI02@U7@0S
91`06a`F01dN6@02028R80807QhL01H07adP028P8`0O7b407b0T00d>4`1KG640XZ6V07alO020P7P0
RXYn0862M023Q7H0P89e07j0L`1jO6l0MGMZ075cJ01[KF80QXMo0::SV`37b<80iNKQ3000o`0Joooo
o`800?l000<0X23`0?n0003oP0000P3oP00k0:0Pl0<0oh0000@0X23`0?n0003oP000X23`103oP002
0:0Pl0H0oh0000<0X23`0?n0003oP0000`2P8?080?n000@0X23`0P3oP0060:0Pl0060=1@N03oP000
oh000?n0002P8?00oh006`2P8?0:0?n00080X23`0`3oP0000`2P8?000?l0003o000:003o013ooooo
000>ooooo`800?l00880gkVd08e7?P2gBd00dTi10=U:?03PC3`0l5U80>QA@P3UCcl0kUU:0>MFAP3V
F4L0l6MF0?A_G`3/J5T0lF]M0>]UE@3[He<0k6=C0?9VF03bIUT0l6AJ0?EYGP3dIUX0m6QL0?=WFP3a
IUP0lFMI0?5XF03`KUT0jfmI0?9jH03ZMEL0kG]J0?B2H@3aPUl0mHUU0?27H@3eS6H0mHiV0?:?HP3e
T6<0k8AH0?N8H03]Ne<0jG=>0?AlF@3ZL540oX9T0>mXD@3HBSL0he110>5;@03PC480hDe30=a;@@3Q
DTP0ge970>1GB03IET<0f5U40=AMB03?Hdh0bVaG0;i`FP2[JUL0ODPh0:YoL@3?ZId0b:FK0;jIU030
V9H0gK>g0>:c^P26E5h0Kd9:08YTI`3G][L0d;:`0<Z_Z`3=/Zh0ekNf0<>NWP1^@dD0M4I707i=CP1f
BTT0I3dl08IUHP3;[j`0ajZW0<RUY@3OZk00ZUmY08<Y;`2[B4`0[d]80:M5?P2VBd80ZE590:iJD`2T
Dd/0ZeYE0:5AC02`HEX0YUM@0:]LE@2QETd0WUa>099SDP38[9/0_:fK0<>l[03Of/l0k>[U05iLGP0_
;C<0C4UB05UFGP1?CE40Cde>03Pf=`0W92@0;2TY038_;`0O6Q/0:BHT02HU8P0S920092DR0P0M7Qh0
800U9RP09bLY01hO8@0M7B408b4X01`J8P0Q8RX0;Bhh01TI8`1eMGh0[Zfc08N7Q`28R800SHf108j@
PP2<SH80QHQl07IiKP24QW/0QXMl08B5N`1iNVl0PX=i0862M`1iNVl0OX1f08V;PP2DUHl0YjRR08W:
Q`1YjFP0N?Qg1P00o`0Jooooo`800?l00`3oP0000`3@D7P0X23`0:0Pl00k0:0Pl0030=1@N02P8?00
oh0000H0oh0000<0d51h0:0Pl03@D7P01P3oP0050:0Pl0030=1@N03oP000oh000080oh000P3@D7P5
0?n000040=1@N03oP000d51h0?n000@0d51h00<0oh000>QX?03oP0000P3oP0000`3@D7P0X23`0=1@
N0030:0Pl080d51h502P8?080?n000030=1@N03oP000oh0000@0oh0000P0d51h0?n0003oP000oh00
0=1@N030X000P<00052@N0H00?l04?ooool000kooooo0:P00?l00?oil`3AYI`0UTPl0<1@A03BC400
fd`n0>MA@`3^F4P0iDdo0>]CA@3[EDH0kEM80>aIB@3cHE80j5]:0>aPC`3^IED0iem?0>9JBP3JDT@0
hEU;0>5GBP3QEd`0jEe@0>aND@3_HE<0kV9C0?1TE@3^HU<0lFEF0?1TE@3aIEH0lfMF0>iUDP3`JED0
kfIC0>mXE03/J5<0jFMA0>MVD03TJ500hVa<0>aeE@3[LU<0jVm@0>mbEP3_Ke@0jf]B0>QZD`3/JeD0
kFIC0>AKB@3YFdd0hE560>EEBP3RDTL0gdm40>5AAP3OCD00hTm10>5?@03RDdD0fE100=IGB03=G4`0
bFAH09m8?`2@AD00iZFS0>Z^[P3UZZh0j:fc0>jc^@3n_lP0aH>=07lkAP1n@DT0fZN/0>g1`P3Q^KT0
h[bk0=jj^P3L^;P0fKFe0<jZZP3>[:/0b:JU0<6RX039ZjT0d[Bb0=>e/`3D/[<0fJnc0>^W/P26:C@0
]4M=0;i<C02oDTd0a5aC0<ERG03;K6H0`VMR0:YAB`2mIF40/eiI0;iYI02iI5d0dWid0;1QE02/He@0
U5m:0<naV@34/Y`0a;bY0<[4^03Vhmh0b/S902/X;`0f<ch0@Ci903hkA02`[K@0dm;G06a/KP1dLWD0
CD]>05QFE`0m?3d071dO02<V:`0T:Bl07b</01dQ:P0N8BX06A`U02d]=`0B4Q`081l]024P;P0g>DH0
EEMT05UKJ01cLgd0ZJR]092?S@2ASXD0TI:4096CQP2KWI80Ngie0413?01KG5H0FeYE04i=B01?CTT0
EeM?061PEP1bLVP0PhEj07UkL021PgP0O7ic06i_I`1QH5`0MgIb08f<R03>cLT4003o01[ooooo00<0
0?l00?n0003oP0000`3oP00m0:0Pl0X0oh0000<0d51h0?n0003oP0003P3oP0000`3@D7P0oh000?n0
00030?n000<0X23`00<0oh000:0Pl02P8?001@2P8?000`3@D7P0oh000?n000020?n000030:0Pl03o
P000X23`00<0X23`103oP00A0:0Pl0P0oh001`2P8?050?n000030=1@N02P8?00oh000080oh001000
o`0@ooooo`003_ooool07`00o`00ooOb0<VIS`2PCT80`5120=9=?P3KC3h0ke]=0>eGB03UCCl0keM9
0>aFB03^F4X0mEmA0>iJC03WF4P0kF1?0?E/G03nMVP0n7AU0?McIP3eLF@0lViQ0>iZG@3UHE80j69C
0>9JC03RFTh0i5a@0>MOD`3YGe800P3]HE803P3^HU40kVEC0>eTDP3bIUD0lFED0?9VE@3bJEL0kfID
0?=/F03/J540jVI?0>]WD03YIE00j6A?0P3`K5L0N03^JEH0kVUH0?1XFP3gKf40m6aN0?=YG03`I5L0
k61C0>IJC@3RETT0iUQ<0>5?A@3RCdD0h4e30>1BAP3HD480f5I90=9ID02c@cl0ZD500;IFF02gFf00
^5eT0;aRJ`37KGH0dWN00:Y=E`2P@d/0VdA;0=:5R`3[Y:X0ijJ/0>NZ[`3Y[[@0jk:h0>be^P3Z][X0
l;k10>Zl_P3[_l00jl720>Rn`03Y_<40jk[00?2g`03NS9L0Vb`e0<Y?DP3<Cdd0bDm:0<A?B03IJFD0
fW5]0<eWH`2aD4X0aVMS0<e`J@2oIEd0`FUO0>jFR02aH4/0/fU>0:EaC@3?/Hd0cKfL0<_4Z033_Jd0
dm370>[Zj01JFEh0;Rde03hlA`0c<C`0N7Mo0>g/lP1NGF80>3Hi04Q6B@2k^KX0S8f@05IJH`1EFfT0
B4mQ04I>H@12BUd08BPj02`_@02VZ;L0;Bll02`]?`0`<D<0<SE4024U<@0a<d00EUIP09fMW`2QX9`0
UiF;09BEQ`2CUHP0WZ2E07amM@1EEU00MWE`071_J`1<BdL0CTm:04m@BP0U9R00GEiF04Q9@@0i>c00
OX1e08B6N`1nOgH0Ogae07UdL01<Ad40DTm:0>CSh@<00?l06_ooool00`00o`00oh000?n000030?n0
03d0X23`1@3oP0030:0Pl0<0oh000P2P8?0>0?n000030=1@N03oP000oh0000<0oh000`2P8?000`3o
P000X23`0:0Pl0050:0Pl0030=1@N03oP000oh0000<0oh001@2P8?000`3oP000X23`0:0Pl0020:0P
l0030?n0003@D7P0X23`00H0X23`00<0oh000:0Pl02P8?001@2P8?070?n000030:0Pl03oP000oh00
00L0X23`1@3oP0030:0Pl0<00?l04?ooool000kooooo01P00?l00?oel@31Rh40Ye540<EAA03BCCh0
heA60>mKC@3[EDH0jUA50>iHB@3]EdT0lE]=0?=LD@3aFTl0kUa=0>mPD03[Ge00kF=F0>mZF`3[IeP0
kf]N0?=_HP3bL6020?EdH@0:0?EbH03aKEh0m71Q0?5/G@3/I5@0j61@0>eTDP3ZHDl0j5m=0>MNC080
jEe>00H0ie]<0>YNC@3]HE00lfMF0?9WE03aIU<20?9VE@80lfYH07T0mfiL0?9YF@3aJET0lVQK0?A/
H03eKF40lFUM0?9XF`3dJUd0kfEH0?AZG@3^I5L0lFAH0>QJD03VF4h0hE=90>9DBP3KDDH0fE=:0<e<
A`39CD/0`T]=0;e:C`2nCeD0^TeB0;=6C02_@4L0[Ci40;mAE02mDeH0ZTY<0:Y>D`2ZDeT0/UeT0;1O
I@2_H6H0/fI/0;Y_M02nMWX0a7n20<b:S03CTI<0eYFI0=fJX@3ZXj/0lJ6/0;QCF`32ADT0dTe>0=9;
A`3HEDd0`d@m0<mDC`3BG5P0df1K0<aMEP3RMG00fW9Y0=IaI@3ALV00dGYO0;EU@033Oe00WVhg0<Z_
NP3Fb9/0e<jZ0<o=]P3<c<00inSS08j?T@0T8b/0BDMB03`jA`16A4l0g=_Q0;2^/`1LFUd0Cde@09nM
WP2/[K009RXc024W=`0P:3/09C1403@oE@0j@5P0=caB0;o2d`0m@5409BHj02T/?`2OYKD0JVel01TK
:00Y:C<0L6ia0;>_[02TXIP0WYjB0::RUP2[[J80LW=[065PF`27QX40P7mk08B5P02:RhH0S8f807Ig
L@22Pgd0EEA?04m@B029RH40S8b408:1N@22NG@0QGYf07aaJ`0m=2l0`kjk00<00?l06_ooool00`00
o`00oh000?n000030?n003d0X23`3`3oP0060:0Pl0@0oh000P2P8?001P3@D7P0oh000?n0003oP000
X23`0?n000/0X23`1P3oP0000`2P8?00oh000:0Pl0040:0Pl0050?n0002P8?00X23`0?n0003@D7P0
1`2P8?001@3oP000X23`0:0Pl02P8?00oh0000<0X23`1`3oP0000`2P8?00oh000?n000050?n00080
X23`1P3oP0000`2P8?00oh00003o0002003o013ooooo000>ooooo`0L003o003omNl0^Gec0:a>@P3<
E4H0ede00>MEB03bG4h0j5930>eGB03YETH0kUY<0?=MC`3cG540kEI;0?=MC`3cGe40kEi>0>mRD@3^
HU40kfID0>UQD@3YI5<0ifA@0>=RC@3VIe00jfYD0>QWD@80kVeG00@0kfeG0?9`FP3aKEP0lfmJ0P3b
KEX00`3`J5P0kFAD0>UPD0020>ELC0200>ELBP3WFdX0jE]=0>YLCP3_HE<0k61A0?5UE03bIUD0m6QG
0?=ZFP3eJE`0l6II0>mUF03cIeX0lVII0?AXF`3aIeX0mVaO0?A[F`3aJUd0k6IJ0>aSF@3WGe<0h5=9
0>IHCP3QDdT0hEA;0=eFD03IF5<0fUiL0=]SHP3HI6@0e61P0==MG@3BG5`0dEUJ0=5LF`39EeH0a5IE
0<9FEP33FE/0^U1B0;A<C@2gCe00]4e>0:a8B02]BD/0[de>0:e:C@2/BDh0[TU?0:e5C02b@dX0^3a0
0=I>CP3HCDP0f4]40=U?A@3FCDD0dT]50=E@B`3GE4`0fUYA0>9VG03RJU`0ff]G0=5ZB`32JS`0_gDh
0:I/8`2JMB@0`:eQ0=[@T`3MfJ`0emJj0=3Ba03Ph]d0_l?402LW;`1DDUl0BdUG03Da?`2[Z:l0l>_a
0>?NhP3Fd]<0c<O;0>?Qi@28Ri00H6A]04A:EP0X<D807RHm03e2G`1>DVd0Yjbo071fQP0E62/09R/n
08^AX@1hNhX06Q`Y02DU;`0h=S/0TXj=0:^XX@2UYI/0Y:JK0:V[X01bLf/0MgQb069SG@1TIF00JVYX
06IWHP1dMG00RHR409^JUP2JUY<0Ph9m08Z7PP2IUY40VI6>09R8R02BOWd0VHB1065>BP2HSH/3003o
01[ooooo00<00?l00?n0003oP0000P3oP0190:0Pl140oh001@2P8?000`3oP000X23`0:0Pl0070:0P
l0040?n0003@D7P0oh000?n00080X23`00<0oh000:0Pl03oP000102P8?000`3oP000X23`0:0Pl002
0?n000030:0Pl03oP000X23`00D0X23`00@0oh000:0Pl02P8?00X23`0P3oP0030:0Pl0L0oh000P2P
8?000`3oP000X23`0?n0000<0?n000<00?l04?ooool000kooooo03D00?l00?o^jP2bKfL0]E160<e?
@`3NDTD0kUY>0>mIB`3WDD80l5e=0>YGA`3_Fdd0mV9D0>eFB`3cGDl0l5a>0?9QD03aHU40kV5?0>aT
CP3[I4h0j6I>0>MWCP3WJdl0h6U;0=m[BP3PKT`0gF]90>5^C`3NJd`0hF]?0>5YCP3VKE80iFU?0>IZ
DP3YJeD0kVeJ0?9]G03cJed0mViN0?YaH@3dJe/0m6MF0?1RE03ZG4h0jE]=0>YLCP3UF4L0jem>0>=G
AP3WFd`0jUiA0>QLC`020>]ODP0O0>aPD`3_HeH0kVAI0>iVFP3]J5T0jVQK0>UYG03kNF`0mg5V0>eP
EP3[Fe00jEI<0>=CB03LDTP0fUM?0=]RFP3QL6X0gG1[0=eaKP3OLVl0ffi[0=e]J`3JIfD0ffQU0=UX
I03IJFD0efMU0=ESHP3CHF00dV1O0=EUH@020=1PGP1B0<mOGP3@GF00beQK0<UEF038DE<0bDa@0=MC
DP3FCDL0fTm80=I<@P3KDDL0ddTo0=e@B@3ODTT0g4m50=eCB03JDTH0feU90=9J@P38GSL0]E`T0<n;
@03EY4P0`jI30<:cEP3Hd8L0h]nZ0=kM_P3If/X0g=gH0>SYj`1ADET0=SA105ECH@18A580P7f60?;`
m@3ck_80VIBH06eXK03@cM00iNKZ0=oRi`3EfN80cmGS05UPL`0a=E00E5Ea08B7VP3<cmh0@dIE01PK
:P0S9c<09BLc01TI9@0Q82P06ALL06APG`2c[jX0ZZZR0:RZW`2YZZ80PhAl07AcKP1VIf40Shj:079c
KP1@DD`0DE1<05MFDP1[If@0M71]05aHE@1YIF80X9RF0:>CT`2iVid0_i^M0<jXY`2VQ880Nf=O0?W[
j0800?l06_ooool00`00o`00X23`0:0Pl0020?n005D0X23`103oP0050:0Pl0030?n0002P8?00X23`
00H0X23`1P3oP0090:0Pl0030?n0002P8?00X23`0080oh0000<0d51h0:0Pl02P8?001@2P8?020?n0
00L0X23`1`3oP0000`2P8?00oh000?n000030:0Pl0/0oh0000<0X23`003o0000o`004?ooool000ko
oooo03<00?l00?kUh02_IUl0^4e30=9?A@3UEDX0lEeA0>mGBP3YDdD0k5Q:0>eIB`3cHU40l5m>0>mK
C@3aGe00kEi=0>mRCP3ZHT`0jVI=0>MWBP3QJ4T0hVe:0=mbB`3PMT`0fWE90=alC03FNTT0dgM80=Ul
D@3JNU80fWQC0=ahE03NMED0gW=C0>5bEP3OKE80i6aD0>EWD@3XIE<0kFEE0>iUE@3dJ5L0lF=C0?EX
E`3gJE/0mVYK0?=WF03cIeH0lFED0?9VE`3bJET00P3/HUD0M@3ZH5<0iE]>0>EKD03WGe<0iEmD0=mK
C`3SHeP0hFEI0>5WG03jNW40lVeT0?1VF`3]GE80k5Y=0>9DAP3FDTD0ceU;0;UAAP2]D4P0/eiI0;AS
G`2eHEl0_FMV0<E[JP3<K6/0eW9`0=ihM03KMG40h7Yf0=ifL`3PNG@0g7E`0=edL03JLFd0f6aY0=Y]
JP3KJfX0ffUX0=aXJ03LIV@0gVAS0=aOF`3IF580g5aC0=UFC03HDdX0gEM>0=eBB`3PDdT0h5150=mA
@`3PE4L0feI30==G?@3:GSL0[eTN0<b:?03Y_EX0el1A0=76G@3Idgl0j>BW0>SU`P3Qh<h0h=oJ0?Cd
mP2JVJ4081h[04E3D@1EDf40FEMR0=gLhP3He]/0EeEJ06ESJ02g][X0kNg_0>KWj`3Si^/0mOWo09NJ
Z@0S93T0B4QP06UXNP3Wi_@0b<KA08:1R@1JFEl0A4=802XY;P0J61d0:BLX09:AS`2i]K40/;2X0:j^
YP2[Zj<0Z:RP0::OV02NWYH0ZjRQ0:2PV02FUXh0Shj9081oN`1QH5`0CTe804e<A`1NFEH0WI6A0:F6
RP3KYZ`0kk>e0?Ji^033S8T0LDQ20>O>b@02003o01[ooooo00@00?l00:0Pl02P8?00oh00@P2P8?02
0?n002@0X23`1@3oP0050:0Pl080oh001`2P8?000`3oP000d51h0:0Pl0020:0Pl080oh000P2P8?00
103oP000X23`0?n0003oP0050:0Pl0d0oh000`2P8?070?n000040:0Pl03oP0000?l0003o013ooooo
000>ooooo`0[003o003hg=P0[V=M0<1AB03FDDP0iEE:0?9NE03XDDH0jeE70>YFB03_Fdd0lf9A0>aM
C03[G4`0l6=A0>aTCP3VI4X0iFY;0>5/B@3NLT`0f7E<0=9eC03BNe00cgiA0<aoD@3=Q5@0bX=E0<9n
D@36OUH0aWeJ0<MlG036MeP0b7AH0<MaEP3;LET0bfaF0<mXE@3NKe`0iFeL0>QYF03YI5<0jfAA0>mS
D0020?5TD`1m0>mQD`3^HU<0kf=B0?9VE@3`I5D0lVIG0?AXF`3eJE`0n6aO0?AZG@3dJUl0lfeQ0>aZ
G@3TJ5h0h6]Q0=5SF02gB3l0ef1J0>Y[I03]Ieh0jEaB0>aMC`3UG4`0fEY;0<mPC`2?<b@0LRHI074a
:01/<Bd0JRh]070b<`1j>3T0PSXj0994@P2KC4P0We1<0:1?C02YF5@0/5eG0;AQF`2nJF@0a6aX0<Ya
K@3?M6l0dW=a0=5_K03JMg80ggUe0=acL03LLF`0gG1Y0>=dK@3MK6@0gfQR0>AWH@3YIF00ieiF0>1C
B@3RETT0fe540=YHB03CG4@0cVQ20;e/=`2jNc@0k/=W0=g7G03Hc6P0h=V80=7=T03Gdk00h=g>0>7P
g03`ko@0g]cW040nB`0c<440AdAE04e9E`2g];d0f=GL03lm@P0h<cX0`;g10>[Xj`3Vi^P0h^?U0>ka
mP35b=409bPj040nE015@UD0_kg;0>WVk`3EdmH0b<K70;^i^P2ZZ:/0V9JG0:RWY@32`Kl0_KVf0;Bc
[P2g][40][>^0;>`Z`2a[ZL0[Z^T0:ZWX02XYIh0ZJVQ0:JVWP2XYj80W9^G096@R`28Qh80OGEc09N4
QP2`Q8/0c8>:0=R3R03>N7T0ZeeI08Y?B@3>ZJ400P00o`0Jooooo`04003o002P8?00X23`0?n003P0
X23`00<0d51h0?n0002P8?001`2P8?000`3oP000X23`0:0Pl0030:0Pl0L0oh006P2P8?040?n00003
0:0Pl03oP000X23`00P0X23`00D0oh000:0Pl02P8?00X23`0=1@N0040:0Pl0060?n0002P8?00X23`
0:0Pl03oP000X23`6@3oP0050:0Pl0030?n00000o`000?l0013ooooo000>ooooo`0c003o003ae=00
ZUeE0<9CB03GDTT0ieM<0?9NE03XE4P0jUI80>mKC@3aGDl0m69C0>IIB03]I540i6190>IZCP3LJTH0
gG=90=QiB`3<NTX0b89A0<64F02nQf00`Hm/0<2?K`33UGD0cIj20=Z/TP3T]9h0hk>O0=^ZV@3W/jD0
j[6V0>b`YP3][J@0kj^R0>NNU`3EPGH0cFUI0=m`G@3ZLE`0jF]D0>YTCP3`He40l6=B0?5TD`3/Gdh0
lF=E0>mPDP3bHeD0lF9D0080lF=E07L0kf5C0>mSE03^HUD0jVAH0>AYFP3MKF40eG=X0;MNE`1l8Ah0
Vc<b0<MCD`3WJ680kFAL0>ULDP3XH5@0hF=D0<aQD@22;al0FQ/<05HV701<9Ah0BRLU04XV9P1?:2T0
Eb/]05h^;P1J:RP0Gbl[064`;01Q;R/0JcPd06@a;@1d?cT0Lc`g07Hk=`1m@3/0PT4o088n>`2>AdD0
U4Y709Q=BP2IBdL0XU=?0:mKF@2`EUD0]UME0<MNF`3CGE/0fe]H0=IAC03FDDX0d5580<YDAP35G4T0
aVaA0;meCP2`M400hKIa0>;8M03IbWL0l>NR0;6[N@1nNUl0R8Ij09JFUP2/[;@0_ko;05IEI@0m?4h0
@SmB04DnD02;QI<0mNoi0;^f_@2VWjH0j^?Y0>_VjP3Vi>D0hN7S0>OXk03Uj>l0@D=B02PY?@0[:Ch0
NGJ70>WVk`3Ie=P0dLo@0=?Bd03;bLX0c<[;0<c;b@3:bLL0bLG30<>o_032_[/0`;bi0;fi]P2j]k80
^;F`0;>`Z`2d/JX0/JjW0:fZX`2/ZJ@0Xj:M0:f/Y`2e/Zd0^:j]0;ROXP30RY40Ze1I0;M>E@33EeL0
_UeG0:MME02`PGT0oo;]003o000Jooooo`04003o003oP000X23`0?n00140X23`3`3oP00H0:0Pl004
0=1@N02P8?00oh000?n000H0X23`00<0oh000:0Pl02P8?00402P8?0:0?n000D0X23`0`3oP0020:0P
l0@0oh0000<0X23`0?n0003oP000103oP0040:0Pl0040?n0002P8?00oh000?n000T0X23`00<0oh00
0:0Pl02P8?00703oP000102P8?00oh000:0Pl000o`0@ooooo`003_ooool0<@00o`00ilS50:=DC@33
DdP0feM;0>YJC`3^G4l0j5A60>eIB`3`GTl0kf1?0>YOC03WH4X0ifM>0>1YB@3LLDL0e7A20=5oA`3@
RTl0bI5H0;nAG`3C[HH0ilFY0>S9]03VbKL0kM320>oAaP3B]:T0aJNO0<:SWP3bdm00_j2N0:n;S@2a
R8`0/XR<0:eoPP3>VY`0oL2k0=b?O`3:KUL0hGQK0>IcE03YKDl0k6E?0>eRC`3bIUD0l6=B0>mQD`3b
HeD00P3aHU@0N@3bHeD0kUmA0?9TEP3]HE80kfEH0>MUE`3PK5d0ggY^0:=AAP2cL6X0GALE06LF5@2?
;Bh0aUAC0>IYI@3XHE/0iEmF0>5SE@3IJE/0WD@d064N3P1860`0@AlF03XQ700g8R40=AlQ03/T9@10
9RL0@2HU048Y9@1:;2X0ABLU050b<019;2P0D34/04/Z9@1?;2P0CbTV05D/:P1I;B`0GC0]05l_;@1R
<Bd0IC<`06La;`1V;2/0LS8b07L[;@29<380Tb//0<5=C@3;Cdd0bDi90;m<A@2oFDd0]Ee?09=:=`1j
?R@0Kd4M08QT=021JRl0P74f08^3DP1iME00F5E205EDC`1FEEX0G5aV05MFI00m?4`0?ci@03hlD@11
?U40GEUZ0:RT/P2/ZK@0`kg90=[Cg@3VgnL0in;X0>CRi`3Qh^H0lOCi08B6TP0A4b0051<Q0490C@3G
e=/0hMoR0=SFe`3Ge]@0eM?D0=CBd`3Cd]00e=?A0=C@c`3@c</0cl_80<g9b03:a/D0a/:o0<G1_P34
`;d0_kbg0;fj]@2j]k80][>^0:j[YP2a/:`0^kJc0<Fi^@3=];L0ciBL0;=?F@2b?dH0b51B0<5DD@2`
G580TE]?0>kIe000o`006_ooool01000o`00oh000?n0003oP00?0:0Pl1<0oh005@2P8?020?n00080
X23`0P3oP0050:0Pl0030?n0002P8?00X23`0080X23`0P3oP0000`3@D7P0X23`0:0Pl00C0:0Pl0T0
oh000`2P8?040?n000T0X23`103oP0000`3@D7P0X23`0:0Pl0030:0Pl0030?n0002P8?00X23`00D0
X23`0`3oP0000`2P8?00oh000?n0000?0?n000030=1@N03oP000oh0000<0oh000P2P8?000`00o`3o
ooooooooo`0>ooooo`003_ooool0;`00o`00hl:m0:=CBP33DDH0g5I:0>eND03ZF4T0iE920?1OCP3^
Gdh0jF5;0>ESB@3NIDH0gVi80=Ea@03FP4D0dXU50<jBB@3>WUH0bJEW0=ZoT03`fkh0glbm0;j]YP2c
XIl0i];D091lOP1_FE`0F4=806eHG`3E`LX0JeMR06QBG`1ZDV80K51O06M7E01N>D00a9RE0?[2/@32
OEh0d7]B0=]jC@3TMTd0jVm>0>MUB`3/IE40jf9?00@0lFAC0P3`He80E`3]H4l0lVIG0>aWF03SJ5T0
hWQZ0<I^HP1i=Rd0UfQQ0:IiM01`=S@0Ha`J08@Y:033EE@0i6QV0>MVH03THEL0hFMJ0<iSD`2C>RX0
Gad?04<E200j71@0<1dG02hN7P0]8200;R0P02/M7@0^81l0>BLW03<Q7`16=380>BLS040_:00j9b40
BcHa03TT8@0j9B80>bHS040X9P12:RP0@2LS04@X9P18:RX0A28Q054W:01A6Qd0HA/M06T@4P2cBd`0
bUYH0<UIE@3;IF00^fAK09]HC`1O;R00A1l?04DZ5@17<AT0@SDD03Xd500d<aL0:R/I03`l=010@400
A4E:04E5C`0j>DL0;bhn034`@P0a<TH0>SaA04I9G01DEFL0CDiP05=AIP1[J7/0Q82?09^EX@3Kf>40
hN3U0>OXk038bLh0OWn406ETJP1DDeP0^;Rj0>GUi@020=_Kf`80f][J01`0fMWI0=KFeP3Ge]D0e]GC
0=CCd@3Dd]<0d]7?0<k=b`3=c<X0bl[80<W8aP35a<80aLC00<;1_@2l^kL0ZjZX0:RTX`2h[Zl0`J^^
0=6JX`2bDe/0Xc8h0<9:C036EU80]eeD08=7?03:/JX00?l06_ooool01000o`00oh000?n0003oP00=
0:0Pl0@0oh0000D0X23`0?n0003oP000oh000=1@N0080?n000<0X23`0P3oP00E0:0Pl0040=1@N03o
P000X23`0:0Pl080oh001@2P8?00103oP000X23`0:0Pl02P8?020?n000@0X23`103oP0000`2P8?00
oh000?n000030?n000X0X23`0`3oP0060:0Pl0030?n0002P8?00X23`00l0X23`0`3oP0030:0Pl0<0
oh0000<0X23`0?n0002P8?002@2P8?0D0?n000030:0Pl03oP0000?l0013ooooo000>ooooo`0a003o
003Q_[X0YeA<0<ABA`3OFDd0kEi>0>YHB@3PCch0j5Y80>IOB@3OGd80ffA20=]`AP3?Kc`0dWi00=69
@@3AUTH0ejQH0=^gK@3=]GT0imR_0=S;^03Sf=@0a[^o0;bb^P2eZK@0IeUV05e?G00i;3H0/jFb09R<
VP1GBU/0ETUK04hoE01F@eT0Ie1R04DZ<`2ELW00om[50=bTO`3DSU/0dX590=amB03WN4d0k7AA0>UY
C03[I4h0kF9?0?5TD`020?1SDP1J0?=VE@3_HU40lVED0>iUE@3ZJ5P0hViO0=UiJ`2RF4/0I30U0650
>@2eV980]Y6;06`i=P1G4@l0QRh/0<=KFP3OJFL0hfIP0>1TFP3KIET0bf5C094n;P1K70d0?a<8038G
3P0/6QH09ahL02HM7P0T6a`09QdN034W9P0Y7ah0>S0_02hT8P0e;2L0<RTT03X_:`0`9B40;R@R03@Z
:00c:BL0=bd[03HX9`0_8B00@S8b03DQ8P17:R`0@ALI05`N8@1T3a80[DU90<YJF03<G5P0b6EO0;5Q
F02>ED`0B2<J030H3P0`8QL0<BLK03@]800/:Qd0;BdS01lP6P0Y:BL0:b`^038a=`0e=3`0=S@o02`Z
=`0/:cT0:R`i024T<`0J7B`08bHe038eA00d=dP0@T9E04Q5EP16@U00_;W20>KUjP3Jf]`0gMgO0=_K
f`3Jf]X0dM7A0=GEe@3Ng]h0gMgM0P3Ng]h0303MgMd0g]kN0=_Kf`3Mfm`0gMcJ0=cKf@3Lf]/0fmWJ
0=SHeP3Fe]@0emGF0=CBd`80clo=00l0clk<0<_:b02g][@0X9bK0:JMX02]VYh0eJB/0;YOJ02J:c80
aDe?0<IED@2hG540R4Pl0:25O03on>l06_ooool01000o`00oh000?n0003oP00<0:0Pl0@0oh0000<0
X23`0?n0002P8?000P3oP000103@D7P0oh000?n0002P8?040?n000040:0Pl03oP000oh000:0Pl0<0
oh004P2P8?000`3oP000X23`0:0Pl0020?n00080X23`0P3oP0050:0Pl0050?n0002P8?00X23`0:0P
l03oP0004`2P8?000`3oP000X23`0:0Pl0020:0Pl080oh00702P8?000`3oP000X23`0:0Pl0030:0P
l0030?n0002P8?00X23`00h0X23`4P3oP00@ooooo`003_ooool0S000o`00hKZe0:YGC`37EDX0hUa@
0?5RDP3WEDH0i5E40>EMA`3NHD<0df4l0>MnC`3GNT40e8=10<f5>@3ATch0hZiH0>g0K`3G]700eKn=
0>3A/P3=`KD0hMSI0;bf^P3XhNT0TXZH05aDH@12=dD0L6Ia0=C:e@1^Hg<0ACa=05mFI`1`I7P0AcU@
06=@H`0k8B`0/Hj:0?oC_03/]H`0mkZ10>NRH@3BPCl0h8160>IjB`3]Me40ifQ80>eUC`3_HU00kf9A
0?1QD@3bHeD0lF=E0>eQD03ZIE@0hVUH0>=iJ@34Lf80Kc@V05<X7`17;bL0FD@o09n6P@2oWYT0KShj
058E4P22=380]5IF0=MZI`3MIf<0hfQQ0=]UF`3;HE<0V40b060N400m4@H0<1D>02PL600T71X0:B<S
02@N7P0Y8b<09B0M03`d<P0Z8Ql0=BdZ02dV800[91h0:R<M03H^:`0_9bD0<RdY02PS7`0W7A/0:R0N
03DZ:00a8b80?B@W03L=4@1H5a/0JQ0B0;E9A`3EFeH0be990<1FB@2dHE<0T5Q;03lM4`0Z5a009QdF
02HQ6`0V91l07ahI02HV900O7ad071`J01hN7P0Q7b808b4V02`W;@0V8BP09B8Y01@A600o?T<0Hf9W
04Y;C`0f>Sd07R<W028S;P0M6bP07AXU08B1RP3Yj>d0fm_M0=[Hf@3KfMX0gM_L0>3Og@3Rh>40hMoP
0`3QhN40203Ng]h0g]kL0>3PgP3Ph>00h^;R0>?Sh`3Ogml0h>3P0P3Ogml04`3Ng]h0gMgM0=cLg03K
fm/0g=cL0=WIf@3Cdm<0bLO80<Fo`@3B`/D0k<C:0;i[L`2A:2d0`da>0<ACC@2lGU@0SD/o08a`I@3o
m^`06_ooool01000o`00oh000?n0003oP00;0:0Pl0D0oh0000D0X23`0?n0002P8?00oh000:0Pl002
0?n000050:0Pl03oP000oh000?n0002P8?000P3oP0000`2P8?00oh000:0Pl0040?n001<0X23`00@0
d51h0?n0003oP000oh000P2P8?020?n000D0X23`00<0oh000:0Pl02P8?006@2P8?00103oP000X23`
0?n0003oP0030:0Pl0030?n0002P8?00X23`00d0X23`00<0oh000:0Pl02P8?00102P8?000`3oP000
X23`0:0Pl00J0:0Pl0@0oh0000<0X23`0?n0003oP0001@3oP00@ooooo`003_ooool0S000o`00gKB`
0:aHCP3<Edd0heeA0>ePC`3TEDD0hEA20>9RB`3JJdd0dVm60>67E@3NSTl0eXi40=VHAP3U[5D0l/1[
0>:hKP2XR4d0flFN0=_?^@3Sf]D0`K^o0<_6c03[iNl0IF5a044mCP2WX;00ln_j09F=W015?4l0?SM9
0=C<h@3AbMh0D4AJ04`mD012:cD0hKjl0<jKR02lOEX0l[1l0?nlN`3UW5@0eX4n0>20A03RMTD0kgQ@
0>UXB@3]IDd0kf9@0?9SD`3bHeD0kV1B0>mVE03UIU<0gfiL0=QkJ@2NFDT0G2`N04DW700o;2H0?RlZ
04`i=@2YTHd0a:FP06Po>`1B6QT0Mbl`0:eEE03?IfH0hF]W0=mVGP3OJEd0cVAF09m9>P1O8140?148
02lI500V71X09b8O02HR8@0R7Qd09b<R03<^:`0V8Ah0<RdY02DP700Z9B409R4M034/:00Z9B40:RLR
02PU800R7AX0<2PU03@/:@0a9BD0=QdP03/A5@1G5AT0Ka0D0<9>CP3DEDh0dE=70<IHB@2kI5<0TEM9
03dM400V5@d08A`H01dL600N7Q`07alO020P800J6QX06aXH01lK6P0M6AP08AdL02DO8@0Q61/050h@
03hh>02`[:/0g=SG0<O7a@2h^[L0XZJU08N:S@1VIFd0BdQ?06AQJ03Lfn00gmoQ0>3Nh`3OgN80h^3S
0>KTi`3UhnH0hn7R0P3QhN40303Ogml0gMgM0=oOg@3Rh^00h^;R0>GUi@3Vi^H0h>3P0>;RhP3Ti>@0
hN7Q0>3Ph080h^;R0100gmoO0=oOh@3Ogn40gmoO0>3Ng`3Qfmd0i]OJ0?SGgP38Nh<0QB8W0;a8B@30
Cd/0_EmE095?@@2=Kf@0ooG/6_ooool01000o`00oh000?n0003oP00:0:0Pl0L0oh0000T0X23`0?n0
003oP000X23`0=1@N02P8?00oh000:0Pl03oP0000P2P8?020?n00080X23`1P3oP00B0:0Pl0030?n0
002P8?00oh000080oh000`2P8?000`3oP000X23`0:0Pl0030:0Pl0040?n0002P8?00X23`0=1@N1L0
X23`00@0oh000:0Pl02P8?00oh000`2P8?000`3oP000X23`0:0Pl00<0:0Pl0030?n0002P8?00oh00
00@0oh0000<0X23`0?n0002P8?007P2P8?000`3@D7P0X23`0:0Pl0060?n0013ooooo000>ooooo`2E
0?ogm03J[jT0[EI<0<aHB`3WHU<0jUe<0>9EA03TFdT0g6I@0=1aE@38M500dXQG0=ZFF@3LW5@0jZeM
0?FjJP3Y]FT0WWDg0;fNL03VeKT0gM?70=oFe`2WX:L0j^G/0;nla`1EDVH0@3eB09B?X`2ZYKT0F51U
04Q0F01?Ael0XiZe07adS01@A5X0=BLh085[M`3fd]H0[G5Y0;EXE03>NUD0hi1L0?beKP3OTdL0fHLm
0>:3@`3VNdD0kG=<0>]XBP3_Idl0kf9@0>iQD03`I5D0jf=C0>AYE`3MM640aGAQ07U0;`1<:1X0?2HK
03PZ9@0e9b@0?BhY04hk=@2CNgL0_Z:N08iXI@1@81h0JBTY0:=BD@3=IfD0gVeY0>9YH03LJ5/0d6UJ
0:==?P1M7a00>1D<02TJ5@0U6aT08ahK02LS800X9240<2`Y028N6`0a;BX09B8M02h[9P0/:B@0<RdY
02dX900W91l0;2TR02DP700/9b@0=bl]02DI6`0j7b@0@A@I05XC6@1f4aH0aDe>0=QDC`3BDTD0bU]:
0;aSD@2<Dd80?1`=02<B2P0R7AT07AdK01PI6@0P82007Q`M01dI600Q71T071LC01lJ5P0T71T0718@
02DJ601dJVP0clO40=[Ed@3Gdm00fm[F0=SHeP3KfmT0gMgN0=kLg`3CdM@0blW<0=kMhP3Qh>H0iN;]
0>OSl@3Ien@0_K_60;Nf_03IfM/0h>3P0=kNg03Lg=`0gMgM0=oOg@3Ng]`0gmoM0=kNgP3Ph>000`3O
gmd00`3Ng]`0h>3P0>3Ph0020>3Ph00?0>7Qh@3Ph>00g]kP0=oMgP3Qfmd0i][L0?SHgP31NX80/U=I
0;91@`2nCTX0_5]B09MCAP2CLfP0ooCY01[ooooo0`3oP0090:0Pl0L0oh000`2P8?000`3oP000X23`
0?n000020:0Pl080oh000`2P8?020?n00080X23`0`3oP00D0:0Pl0040?n0002P8?00X23`0:0Pl0<0
oh000`2P8?000`3oP000X23`0:0Pl0030:0Pl0030?n0002P8?00X23`01L0X23`00<0oh000:0Pl02P
8?00102P8?000`3oP000X23`0:0Pl00:0:0Pl080oh001`2P8?020?n000D0X23`0P3oP00H0:0Pl003
0=1@N02P8?00oh0000H0oh004?ooool000kooooo07h0ooOb0=FZX`2VDTL0cEa<0>EQDP3YGD`0hUI5
0=]JA`3BJUD0bg]T0=fHN`3QXg`0h:A`0>FXJ@3e^G<0l[Ma0;>0@@2PN4L0hlVX0=g<^P3Sf]<0bL33
0<c5c03im?/0R8:>04m;H01=B5h0FUEY05aDJ@1GCf@0E4aT05=;H`1MDf`0EdeU048gB00_8C00dKg8
0?oPi`3Y/K80_WE^0;aZE@2mJDD0jjAV0?^fJ@3LTdH0eH4i0>F3A03WMdL0lGE?0>MTB03[Hdd0kf=B
0>iUE@3XIE<0gfYH0=]jI`2[HU40GRlO040S5@0f9A/0<BHQ034V9010<Rl0?BhY048`;023L6X0`JVU
09QfM01D9b@0KC0_09E4@@35I5h0h6mW0>5/HP3NKEl0c6IG0:5>?P1D7A00>1L@02XB3P0/6QH0<R@Q
02/P7P0c:BL09adK03H^:`0/9240<2TS02dV800`:B<0;RLQ02@O6@0^:B<091lK02/V8`0`:2H09aPK
03hQ9@134QP0H1LN07XC5`3<DU40fEA=0=ABA@38EdD0_fMC08YA?P0m7@h09A@<024L600L71X06QTJ
020L6`0P6aP08a/H02DJ5P0M4`X07A<701T@0@1;?c<0ZIbC0=cBb@35_[P0S8N30;2/Z@3RhMd20=gL
fP0A0>7Pg`3Th^<0j>KY0>SWk03YjO40iNCb0=7?i02WYK/0KVb104m>GP1ACeX0/K2e0>o_k`3Rh^80
g]kN0=gMg@3Ng]`00P3Ogmd0103OgMh0gmoO0=kNgP3Lg=X20=_Kf@030=gMg@3Jf]X0g=cL0080fm_K
00h0g=cL0=cLgP3Mfm`0gmWK0>?Gf@3bdmX0cHN?0=aoQ`2S=CP0_De;0;]JD@2MEd/0VGM]0?oejQ[o
oooo0`3oP0080:0Pl0T0oh0000<0X23`0?n0003oP0000P3oP0030:0Pl0050?n0002P8?00X23`0:0P
l03oP0000`2P8?030?n001@0X23`00<0oh000:0Pl02P8?000P2P8?040?n00080X23`00<0oh000:0P
l02P8?000`2P8?001@3oP000X23`0:0Pl02P8?00oh0001@0X23`00@0oh000:0Pl02P8?00oh000`2P
8?000`3oP000X23`0:0Pl0090:0Pl0030?n0002P8?00oh000080oh002@2P8?030?n00080X23`00<0
oh000:0Pl02P8?005@2P8?000`3@D7P0X23`0:0Pl0030?n000030:0Pl03oP000oh00013ooooo000>
ooooo`0M0?ohlP3?Yil0YUA80<YJC03UHeD0he];0=eHA`3MI5<0bfmP0<5oL`2_MFL0d9R10>bdT@3h
^h`0n;b60=RLJ02XMDH0ajF20>oIa03[f]80g=7?0<Bj^`3PeMT0k^GZ0967T00k<T@0A3e?04Q1D@16
?Dh00P14>d`0N013=d/0?c9403HY>P0d9S<0SGf70?SSk03mgnL0omcT0?g;cP3EUY40Xe]<0<=jC`3l
^7L0nkM^0>6EBP3LQD00iWm50>aiC03`LE00kfU@0>eTDP3]J5L0h6=A0=iaG@3DNfT0TDhm054V5P0n
91L0>2LO02dS7P0_9B<0=bhY03db;012=Bl0AcPa071ME`2VShT0QVMT06m3@01[<2`0Sd@n0;iPF03L
LFL0hg5V0=YXG@3=IEP0S3LZ054A200l2@D0>a8>04<Q7`0f6QL0?BDQ02hK5@0c8Q/0=BHO038U7`0]
81X0<RDO03H[9`0X7aX0<b`V02PP7@0^9R<0<RLU02hK7@1392T0AA0H05lB601m51P0cU9@0=YDB`3B
D480aeQ40;aUD@27CS/0?QhA02TH400Q71P07ATH01lI6P0S6AP0:Q`I02/L5@0X5P`07`h002/M0P1`
Hd<0c<6S0<VoYP1iLf<0Sh^20:ZWXP3@c</0gmkL0=kMf`3Qh=h0iNCS0>[Xj`3ZjNl0hN7]0;jod`2<
SZL0H66005IFN01VIhD0GUif03@c@@1dLgT0l?3b0>KViP3QhN40gmoO0>3PgP3QhMl0i>;S0>WTj03X
i^L0i>;S0>?QhP80h^;R01<0hN?R0=kPg`3Ogml0gMgM0=kNgP3MgMd0fmgL0=gMg@3Pg=d0i=WM0?GG
g@3HTYX0bfif0:0b=@30D4h0^eYA09]EB@2LNW00oo?[01[ooooo103oP0050:0Pl0T0oh000`2P8?00
103oP000X23`0:0Pl03oP00:0:0Pl0030?n0002P8?00oh0000<0oh000P2P8?020?n000/0X23`00@0
oh000:0Pl02P8?00oh001P2P8?020?n000<0X23`00<0oh000:0Pl02P8?000`2P8?000`3@D7P0X23`
0:0Pl0040:0Pl080oh002P2P8?000`3oP000X23`0:0Pl0020:0Pl0040?n0002P8?00X23`0?n000<0
X23`00<0oh000:0Pl02P8?000`2P8?020?n00080X23`1`3oP0070:0Pl080oh001@2P8?000`3oP000
X23`0:0Pl00E0:0Pl0030=1@N02P8?00X23`00D0oh0000<0X23`ooooooooool03_ooool000kooooo
08l0ooSb0<fUW@2VEdX0cEm@0>=UEP3NFdT0fUe;0=AUE036Mfd0WfQU068a;02<F4d0hjbG0?VmV`3K
X7P0]WmH0;:6H`3bdkh0i]C80?7Sh03:_/00h=CH0;FY[@2o/[/0g];L075UMP1ABEP0Dd]J05iCH`1R
EfD0IeaZ06EJJ01/GVd0PG>00<>c_@3ei>`0nNC]0?WOjP3kgNT0om_V0?o@eP3RZ:H0aX1W0=J@G03o
_7T0nKAY0=j@AP3OPd80j7i:0>efCP3[K4`0jVIA0>MVD`3SJeX0gGIS0<5`G`1g?2`0C2HI048Z7P0h
:B80;B@P02dU8P0c;2H0=RdX03DZ9012=c40A3D`05Y9@P1^FE@0VWei0:=jM01nAd00Rd4h0;UOEP3H
L6L0iGEZ0=e[H035Fdl0ScDZ06LG401N5a40IRDQ054F4P1D7aT0AaH?04lS6P177aL0@QdE03XH3`13
81X0@b@O03LJ500o8al0=1PE03TN6`0n8R40>aTJ04TL8@1D5Q/0H`hC08/J703FEU<0fDm50=IA@P39
ET<0a6UD08M5=@0o4`P0;Q4;02XE4P0X4Q@0;Q@E03<F4P0h6Q80<A@402hD001B?1D0WXaJ0;>VL@2@
QUD0PGUB09ZFO@3Nf/h0i>7L0>?Oh03Rg]l0h^3S0>WUiP3ZinT0bl[@0:6Q[@1YJW`0ATQQ04I9J01I
G7l0KG2C05]LNP0n?5@0;2Tj04i;E03ShNH0jNOZ0>7Qh`020>3Ph00;0=oMgP3QgMl0j^CX0>ORiP3V
h^<0hMoP0>7Qh@3Rh^80hN?R0>3Rh@3Rh^800P3Ogml03P3Ph>00g^3O0=kNgP3OgMh0iMcO0?GKh039
QXl0`fI^0:dnA02lBTX0_EYD09eDB`2NO7<0oo?[6_ooool30?n000H0X23`00<0oh000:0Pl02P8?00
1P3oP0020:0Pl0060?n0002P8?00oh000?n0002P8?00oh000P2P8?070?n000<0X23`103oP0000`3@
D7P0X23`0?n0000F0:0Pl0@0oh0000<0X23`0?n0003oP0000`2P8?000`3@D7P0oh000:0Pl00H0:0P
l0030?n0002P8?00oh000080X23`00<0oh000:0Pl02P8?00102P8?060?n000L0X23`0P3oP00P0:0P
l0030=1@N03oP000X23`00D0oh0000<0X23`ooooooooool03_ooool000kooooo01X0ooK_0<>KT`2Z
Fdd0c65?0>9WE@3LGTX0e61=0<YXF02aLfX0dZJY0:b3R01e@T@0diZD0>NXV02fNV@0VfeD0=^kYP3G
a;X0f/o;0=K;c@3=`LT0l>7/0;j_^`2k[K`0a;S80;FZ_080Yin`0800XiZ[0:>JZ@2ITIl0V92L0:JK
Z02TVJ<0XYBO0:NGX`2YUj<0X8ZF0:B<V@2DNXH0RFei0?;?eP3IXY/0^fm?0=B8E03h]W<0n;EY0>bN
E03SR4L0j7m:0>]gC`3YKE00hfUC0=i`G03HO6T0X5a<05LW6P1::b00?BXR03HZ8`0b:RD0;RTU02XU
7`0W8Q`0;BLQ02lY8`0i<2/0@3D`04Pk=`1HAd<0NV=N0:B5OP2bQ7l0^W]f0;i]I`3@L6T0f6aU0>=_
I03CH580aeA70;a;?`2fA3/0[Cdd0:Hh;P2N=2T0TRdP08XY7@1o8aL0N20E07HO5`1d8AT0JQTB070R
6`1U6180I1XE06@L6@1P5AH0IaHH06P=4@1c2@/0WAlQ0=aCD@3LCDD0fe130==FAP3<GTh0UCT/05`<
101B2PP0D0d;054:2`1I3P`0HQP=06@Q301lAQh0_IED0=ZnK`2^VTT0MVPJ09bCC`3Nej80k^W70>gX
eP3[i^80i=oR0=7<dP2e/KT0VIBL06e[L`1;C5H0A4MD03i1D`14BEd0Ce=Z061RN`1DDf`0>CI:02dW
>@0Z8C40<2Hd0;Ra^@3bkO80hn7T0>7Qh`3Qgn80hMcP0>SQiP1XH6L0G5IJ0>3Kg@3[j>T0h^7O0>7P
gP3RhN40hN3Q0>7Qh@80h>3P00h0gn3P0=kPgP3Mgmd0h=kO0>CLg`3egN<0^GV20;EJI02mC5D0]dA8
0;iKEP2RFE80VWQ_0?oek1[ooooo0P3oP0000`3@D7P0X23`0:0Pl0030:0Pl0040=1@N03oP000oh00
0:0Pl0H0oh000P3@D7P01P3oP000X23`0?n0003oP000d51h0>QX?100oh0000D0j6Pl0:0Pl02P8?00
oh000=1@N00;0:0Pl0030?n0002P8?00X23`00P0X23`00@0d51h0?n0003oP000oh000P3@D7P40:0P
l0<0d51h0P3oP0070=1@N0T0X23`00<0d51h0:0Pl02P8?000`2P8?000`3oP000X23`0:0Pl0040:0P
l080d51h1@3oP0000`3@D7P0X23`0:0Pl0020:0Pl080d51h00<0oh000=1@N02P8?002P2P8?000`3o
P000X23`0:0Pl0030:0Pl0040;Ph]03@D7P0d51h0=1@N0d0X23`00<0d51h0?n0003oP0000`3oP000
0`3@D7P0oh000?n0000@ooooo`003_ooool0@03om>l0^i>;0:IDAP3@IE<0hFID0=QNB@3CIU80`6UH
0:MaJ`3H/KH0SfI^0:IaM`3<T980aXN209aVG03H/jX0h/k70=c@d03>b<`0/:^a0?;/mP2g[kh0Hea/
06]VNP1QGW<0FUM]05YHKP1LFW00GE]a065OM01RHgL0HfAf06]ZO01_K7d0KVYi07QbP01mLX80Nfmm
07=VL01DAe00_Jfg0?cWkP3fc]00_gYZ0<MkF@3HUF00ol5o0?bhK`3bYEl0lI=F0?B8F@3]N5L0g6YB
0=MbGP3CPW40W6AG04hY800i9A`0=BXT02hW8@0a:BD0;bPR02hV8`0Z9B4202`W8`1202dU8P0e;BX0
?3@a044h<`16>cL0DSlk06]<B@2OLVl0b8R80>fNVP3<KFL0dfeQ0>n;N`3SPVl0egAQ0=1UE@3:FT`0
ce]<0==MC`3?FD/0dee?0=9LCP3CGDl0d5Y>0<]EB`34CdD0_de30;a:@02b@cP0ZCXa0:<f<@2Q<Bd0
Wb`Y09`R8@2f<S00eDi:0=I=A@3GCd<0ddm20=1@@`2nA3T0Xb`T09hW8@2P:B<0XBXT0:he:`2oCcT0
_E/h0;5T<03b`GD0mmN20:V@?P2>OS40elj;0>cV/P3Of[X0a<6`09B@S`1WI6/0BdQA04E4C01:Ae00
BDUA03m2B@0l?dH0>ci70P0i?4D05P0c<C`0;2Td038/>00]9C80;b<a02LI:02?QHh0m^of0>GPi03R
h^@0h^;R0>_YjP2WXZ<0IF1T03di>P2g/K<0m>k`0>_Ui@3Yhn<0i^;Q0>GQh03ShN820=oOg`0>0=gO
gP3OhN00g^3O0=oMgP3Rg=h0mMgU0;j0R`2YDe`0_55I0;Q7B`2mG5H0XeYA09YhK`3oln/Jooooo`<0
oh001@2P8?080?n000050:0Pl03oP000oh000?n0002P8?00103oP0040:0Pl0030?n0002P8?00X23`
00L0oh0000@0X23`0?n0002P8?00oh000P2P8?030?n000L0X23`00<0oh000:0Pl03oP0003@2P8?00
103oP000X23`0?n0003oP0020:0Pl0030=1@N02P8?00X23`0080X23`00<0oh000:0Pl02P8?001@2P
8?0;0?n000@0X23`2@3oP0000`2P8?00oh000?n000030?n00080X23`0`3oP00?0:0Pl0030?n0002P
8?00X23`00<0X23`00@0d51h0?n0002P8?00oh003@2P8?000`3@D7P0oh000?n000030?n000030:0P
l03oP000X23`013ooooo000>ooooo`1I0?ock`2gS8D0YeE70=9WE@3RJEH0f5m<0=9WE@30JU/0]X5k
0<:KWP2mTYT0aY6G0<>8RP2ZL6h0ZWYf0?3Cc`3LcLX0dl[?0;Ze_03Cd=L0k>Wd07eiR01SH7<0HEic
04e;H00h=T/0<Bm502l]@`0g=D/0@dAI059CJ01EF6/0@T=E03LiB00d<d40@3a:04]5D@1<A4l0?cDm
06QOI03Zgn<0m>GX0?cLg`3?THH0a7eQ0<N3DP3j^WX0ol9g0?>^H`3WSDh0lHUF0>alE`3EJDl0eWMU
0<5eI`2OJf00OeiE05U8@00n=Bh0<BXT02dW8@0a:R@0;bLT03D]:P0Z9B40;2LS02hV8`0a:BH0<2/W
038]:@10=S@0AcPe058h=`1N=3D0OT920;Y/K02hFED0dV]P0?fLR`3o[id0ojRD0?bEQ03]Ofh0kGi]
0>QgI@3KJUX0eFAD0=aYE`3JIE@00P3QJE/03`3TK5h0j6mT0>5[G`3PKF00eFEG0=EUF@3>GU<0d5iD
0<mJD@3CEU00feaE0=mLDP3SHE@0gEU=0>1JC`020=UCBP0c0>9ID@3TFe<0hEQ>0=eHB`3FGTH0d6U6
0;=S<P3U/W40kLb50<RaK@2jZVh0[jE`08V6G@1/JU40F5I:04M5AP1;B4l0BTUA0491B@12@DL0>STn
02l`=00c<SL09RDZ02LX:P0W9bT0:bX_02`Z;`0_:S40;bD^02`N;@0S5B@0Rgn90?S^mP3Uh>@0hn7T
0>;RhP3emOD0RHB50>STi@1jMWL0[JNY0;Zd]P2f[K00gmKG0>WSh`3[iNL0j>CU0>?QhP3Ogml0g=kM
0080gMkP00/0gMgM0>;LgP3dg>@0`hZC09Y9DP3:HFP0[T130;eLE@2PF4`0VWQ_0?odk00Jooooo`03
0:0Pl03oP000oh0000D0X23`303oP000102P8?00oh000?n0003oP00?0:0Pl0050?n0002P8?00X23`
0=1@N03oP0000P2P8?020?n000L0X23`00<0oh000:0Pl03oP0004P2P8?000`3oP000d51h0:0Pl00T
0:0Pl0L0oh004P2P8?000`3oP000X23`0:0Pl0020:0Pl080oh0000<0X23`0?n0003oP0000P3oP00;
0:0Pl0040=1@N03oP000oh000:0Pl080oh0000<0X23`0?n0003oP0004?ooool000kooooo05D0oo7/
0;66O`2[FDd0dVMG0>=ZE`3IH4d0d6EC0<E_H02hQ7`0aYbN0>:h_037TiL0]X>209e]J`3Q^kP0i<o>
0=kBe03>a<`0]k6k0?;_n02c[kd0EU=T05aIK014@540O7R709ZFY02?RiT0T8bK0:FR/`1OG6l0De1U
040mD01:B5H0ZJNb0:6NY@2VXJL0[jV]0;F_/@2h/[@0d/W:0?7Yi`3`i>@0n^;R0>>_Y02bLUL0^WQ6
0>Z[J03oagP0nKYZ0=Z5@P3JMd00h7A=0=UaEP3>MV80[FEG06lm=01jFE80QWE^07ieKP1NEdl0>S@^
02dX8P0Y9200<2/W02dU8P0b:RL0<2PV02/S8@0a;2P0<2/W03P^;00m;Bd0B2h_05X`<P1W9BT0OB@V
0:@k>03/NG00nHUk0?jDQ03oUhL0oi:10?^=O03oUH<0oib90080oij;05D0mI9o0>R3L@3TNVX0ggEU
0=ecH`3LLV@0g7EV0=]jJ@3NPFl0iXUh0>V9N@3WQWH0jHEe0>IjK@3aPGD0m7a^0?EiK@3iNFh0mG1W
0>MNEP3_I5d0oG1Y0?5WG@3YGeD0hF9C0=IWD`3:LE<0]G5<0;>7FP2GNd`0KU/a05e@;@1>BB`0A48]
04i>@P1;BTH0ATI60491AP0g=CX0=38g03Hd=`0X8bL0:bHZ02XX:@0S8B80:BTW02LW9@0Y:BT0:RX/
02hY;`0Z8b/0<2@b02XL:`22MX00m>[b0>OQi@3Tgn<0j>KW0>WWj02KUYD0Qgio08ImOP37_/40PWUl
04<m?`1HDU@0QGn10:^UZ@36`<@0f=?G0>7Oh03Ng]h0gMoN0=cNg@3MgMd0h]cN0?CKhP3<U9l0RSe7
0=A/M@2/?d80^5M@09eEB@2KNG00ooG/01[ooooo00<0X23`0?n0003oP0001@2P8?070?n00080X23`
0P3oP0000`2P8?00oh000:0Pl0020:0Pl0H0oh000`2P8?070?n000<0X23`1P3oP0080:0Pl0<0oh00
402P8?000`3oP000X23`0:0Pl00T0:0Pl0@0oh005@2P8?000`3oP000X23`0:0Pl0030:0Pl0D0oh00
0P2P8?030?n000L0X23`00@0d51h0?n0003oP000X23`1@3oP00@ooooo`003_ooool0H03olN`0ZWmh
0:QFB`3DJET0hfYI0=IMBP3CIE@0`VUG0=>IS@2[OWT0`iND0;R;QP2YOWP0ZXN10>oCd03Pc/h0e/[>
0;jc^`3Qen00k^Ka07ihQP1KEfP0DTeQ03/gB032^l/0k>Cb0>KPk03`j_P0em?R06MSM01;AUX0920a
0:RU/03hloX0jnKZ0>cXj@3/i^H0kNOW0>oYj@3`j>H0knOU0?;ViP3kiND0ml_20;9jH@2cLd<0eIIC
0?k7M@3l_fh0g8a50<a/<P3NMdh0eg9D0<efHP2[IET0ICD[058a:P1IAT00MfaV0968P@1hL6T0AChh
03@/:@0Y8Ah0:20M03<[:00_9bD0;bXW02dX900a;2P0=B/Z03h/;0149bT0EbHZ06<H7@1l71h0aeED
0>U]I@3/LVD0j79T0>]eI`3YLF40kWUX0>]jJ03`QG<0m8ej0?FBO`3oVXP0oiR70?jDQ03oU8@0ni61
0?fCP`3kUX@0niZ60?fQS080ojJD03d0oj:@0?nKR`3mUXL0nH]l0?=mK`3`M6P0jFUN0>mYH03/He/0
k69H0?9UG03YGeD0j69G0=]VE`2oHU00XEU308YG?01/B2h0DC`Q048f7P16?b`0@clc03Xj<P0n?S`0
>3Xi038b=00c<SL0:2L/02LU:P0/:Rl0:2<W02TT:00Y9BH0:BDT02HU8@0X:B@09BDS02<S8@0V92L0
9AhV02hR<00/7Rd0NFeg0?G[l`3Vh>@0i=oS0>k/k@3KfMX0RXB408V1O`23NGX0cLC70=?:c@3Bc<h0
^kFg08R2Q00/9RP0?SPj09^EU`3Xi>D0h^;R0080g^3O00/0g]kN0>;LgP3cf^80dYfW08Dh@P3ILGX0
[3m20;]LEP2IDdT0Wgie0?oek00Jooooo`030:0Pl03oP000oh0000D0X23`1`3oP0000`2P8?00oh00
0?n000020:0Pl0050?n0002P8?00X23`0:0Pl03oP000102P8?00103oP000X23`0:0Pl03oP00:0:0P
l0H0oh00202P8?040?n000X0X23`00<0oh000:0Pl02P8?000P2P8?000`3oP000X23`0:0Pl00U0:0P
l0030?n0002P8?00X23`01D0X23`00<0oh000:0Pl02P8?000`2P8?080?n00080X23`00<0oh000:0P
l02P8?00102P8?00103@D7P0oh000?n0002P8?050?n0013ooooo000>ooooo`0T0?obkP2bQh00YUA9
0=EWFP3VJe/0gF1>0=QUDP3?KeT0ahEa08AEA@1lED@0Z8Ad0:f@P03C^jl0flS20>[Hf03>_/40c;_1
0?SYl03<`LT0GUIQ061IJ`1BCF40BDAJ07=^PP20NH/0QGj@08^4UP1gL880FeAV03Tb@P15?dd0i=oV
0>gWj`3YhnD0j^CT0P3/hn@0G`3]i>D0lNKZ0??Xk03fin`0nnGW0?oJd`2lRW<0]WM;0<B4A03ka7@0
nl5_0>6CB`3=L3<0gGQ<0=MdE@3>Mf<0YV5B06Dd;@1D<bh0CCPe04dn>`1KCDX0QGYf0925P@1^IF00
CdQ203H_:@0Z9Al09b8N02/V8P0/9b<0;bLT03DZ:00n:2X0AR8V05DL8P1U41L0TbT]0=eSHP3^JF80
lViR0>m]H03/JUd0kVYM0>eYG03]Jed0kFmP0>YaH03/M6<0kWIV0>ecI03`MVT0m7Y]0?AlKP3^N6X0
lWm]0?B4L`3hSG/0n8Yi0?N9N03iRgX0nHUk0?Z6N@3fOG80lWIZ0?=cJ03eLFD0mFaR0?=YG`3bJ5h0
kVAJ0>aVF`3SIEL0cVQJ08Lo<@1R<B80CblP04Ld9P0m<bL0<blT02l/9@0a<2`0;bl_02//;P0U:B`0
9RL[02X[<00V9Rh09RH`02LT;`0X9Bd0:RP]02dX;00/:2L09bHR008092DP01P09BDS02LU:00Z8bX0
:AdY02XL:`22MX00mN_c0>KQi@3ShN@0l>k_0<o>c01gLG40KfMU07mgM@38_l00THR90;2WZ02`Z:H0
aknm0;6YY`33^[/0fmGE0>CPh@3Ph>020=gOgP0;0=oOg`3Rg=h0lm_R0=>NZ023=T00fW9k0:m2A@2k
G5H0Ue=:0:J5O03om^h06_ooool00`2P8?00oh000?n000050:0Pl0030=1@N02P8?00X23`00@0oh00
00@0X23`0?n0003oP000X23`0`3oP0020:0Pl0H0oh003@2P8?060?n000P0X23`00<0oh000:0Pl03o
P0000`3oP0080:0Pl0050?n0002P8?00X23`0:0Pl03oP000902P8?00103oP000X23`0:0Pl03oP00H
0:0Pl0030?n0002P8?00X23`0080X23`00<0oh000=1@N03oP000203oP0070:0Pl0040=1@N03oP000
oh000:0Pl0D0oh004?ooool000kooooo0600ooOc0<FNU`2RDTT0e6QK0>IXF@3NGDX0ff9=0=A/D`3?
Q6X0R5Dj07UD>@2mWhD0f/F`0=c<_@3LcLH0i=CE0<^h_03Ye=T0dKk40=K5c@1ICEL0BT9A055:G01?
Ae`0F51W05eFJ@1RFfd0I5]^05aCIP1>AEH09Qh[0:VQ[03dkO@0j^CX0>_Ui`3/i^H0kNCU0>oVi`3`
in`0k>7Y0>oTk03ahN/0lM[P0?oPfP38VX<0^Ga@0;Yj?03f_W40olAc0>FGC@39Kc40fgU<0=5`D03@
NfH0WUY=06<d;01@<Bh0BcHc04dn>`15=c@0DdE2079WH`2AQX80THR307UbK01ED4X0>c<`02hY9@0Z
9B40;BDR03HX9`0n9RH0AQ`P05@C6@1Z3Q<0[Sdo0>UYIP3_Iel0m6YO0?=YGP3bJ5d0lVEK0?EXGP3a
IeX0l6QJ0?5/G@3bKUl0lfmR0>eYG03^JUd0kFUL0>aZG@3_L640jFYK0>iaHP3[LF820>ebH`1:0>a`
I03[Kf<0lG=W0?9bI`3_K680mFmT0?=ZH03dJV00lfIM0?9UF`3_HUP0if5E0>5VE`38JEd0KS8W04DP
5`0j9Qd0;R<M02`Y900[:RP09RHV02LV:`0Y:Rl08RD/020T;@0P92l092Pc02@W=P0Y:cX09bHf02d/
>@0/:c<0:RP]02XX:@0Y9bP09RDS02LW9@0W9bL0:RDY02hW;P0Z7RX0;Al/08n3S@3gkOD0iN3T0>CR
h`3blNl0`Kfl06iYJ01UGE/0UHf;0=37b01WGUl0Dd]903@/:P1lM780[JFS0<>k^@3Nf=P0i>3O0=oO
g`3Ng]h0g^3O0>3Ng`3Qfmd0lm_R0=BP[022=T00fWEm0:Pk?P2`Ddh0V5E<0;2BRP3omNlJooooo`<0
oh001@2P8?000`3@D7P0X23`0:0Pl0040?n000030:0Pl03oP000X23`00<0oh00102P8?040?n00080
X23`00<0oh000:0Pl02P8?002@2P8?060?n000P0X23`00@0oh000:0Pl02P8?00d51h103oP00:0:0P
l0030?n0002P8?00X23`02@0X23`00<0oh000:0Pl02P8?005`2P8?000`3oP000X23`0:0Pl0020:0P
l0030?n0003@D7P0oh0000<0oh000P2P8?030?n000L0X23`00@0d51h0?n0003oP000X23`1@3oP00@
ooooo`003_ooool0DP00o`00fKRc09iDB`3>I5L0ifUK0>1MB`3LGdT0g6eB0=5mGP2ZLTl0_9Ib0=6f
V03UeK`0g=320>GJeP3;^k`0fLC;0=>j`028KgD0h<WA0;RW[`1@A500>2dm034X>@0h;d80@3M9044i
B012=dL0@3E304@jA@2<PX/0l>K^0??Zk`3aj>d0knKY0>kUj03]inT0m_3d0<S1b@2>QY<0Y9NX09N9
V02gXj`0onCO0<bORP2kOU40]G@d0?>jJ`3oa7<0iiU?0=1f>03HMdX0cW5@0<UkI@2BE4L0ER/T04``
;018=S80B3dg04Pm>@16>cP0@CHd05A9A`1/HV00R7mj09B=Q`24NgH0IEiH04Hn>`0g;B/0<20P03/Q
8P186ah0EQ4D07PH6P3;E5H0jVIR0?5UG@3aI5X0lVQM0>mUFP3bIUT20?AXF`1H0?1VF@3cJUX0m6YM
0>mWF`3bJUh0l6IK0>iTE`3_IEX0lFUM0>iVFP3`JEd0k6IJ0>]UF@3^J5`0jfEJ0>YTF@3_IU`0kfEK
0>aRF03_HUT0l65I0>iPEP3^GUD0je]@0>]MD@3XH5@0gf5C0<e]GP1Z;R<0?AP@03@Q6`0_9b@0:BPV
02HV:00Y:Rh09RH^024S;`0Q9c<07B@d024X>`0[<dP0:Bm5038gC@0i>e80=cU:02DW<`0S8b/09RDZ
02/Z;`0V9RP09bLY02TY:`0[9R`0:B8Z030S;@0/7bT0V8bF0?K_mP3Uh>@0i>;S0?Gal02[YjH0LFa/
071XIP2SViT0in7Q0=WCd`3Ke]<0_;Nd07E`K@0c;Bd0GeUI0<>o_P3Wi^@0h>3N0=oOg`3Lg]d0g]cO
0>;Lh03bg><0f:Ja08HnB@3DLgX0WSHg0:eBC@2GEdh0^9^E0?ogla[ooooo00<00?l00?n0003oP000
1P2P8?030?n000030:0Pl03oP000X23`00H0oh002@2P8?000`3oP000X23`0:0Pl0050:0Pl0@0oh00
00<0d51h0:0Pl03oP000103oP0080:0Pl0030?n0002P8?00X23`00<0X23`1@3oP0020:0Pl0030?n0
002P8?00X23`0080X23`00<0oh000:0Pl02P8?00902P8?000`3oP000X23`0:0Pl00G0:0Pl0030?n0
002P8?00X23`0080X23`00@0oh000=1@N03oP000oh000`2P8?020?n000030:0Pl03oP000oh0000H0
X23`00@0d51h0?n0003oP000X23`0P3oP0000`2P8?00oh000?n0000@ooooo`003_ooool0F@00o`00
i/W509mID@3=Ie/0iVYN0>9MCP3PGdX0gfU?0=AjF@2lPU`0bJ9k0>37Z03Kbk80j]k@0=kAb`36][L0
jmKM0=RmaP3;[k/0h/_E0?STk`3McMX0]JRi0:FJZ`2RVJ`0XYRZ0:2EY@2[X:h0_;2l0<k2c03_i>`0
lnS`0>3Eg@3Qe]h0l>O/0??Zk`3bjo80m_7h09bFY01cK7`0OW:605m@H`38]<00on3L0<ZJQ02lOE40
]WDe0?>hJP3o`G40j9Y@0=5h?03JNdl0bW5A0<InJ023Bch0BbHN04P`;018>C@0A3/f04]2?@10=c<0
@3Hd04<i=`18?S`0Bd8m06MNF@21N7<0UHb708b2P01hKF/0FdU704la<@1B8240E@d>08PQ8P3IGeh0
kfYU0?1SF@3aHeT0lFAJ0?5WG03_HUP0m6MM0?9UF`3`HeT0lfIL0?9UF`3dIeh0lFAK0080lfEK00@0
lFAJ0?AWG@3bIE/0lFAJ0P3dIed02@3`HeT0m6MN0>mRF@3bHe/0l65I0>mOE`3aHET0kUiE0?9OE`02
0>mLDP100>eMDP3YGe80hV9E0<i/GP1]<BH0?A/B03HT800_9bD0:BT[02LX;@0_;cL0:B/g02T]>@0W
;Cd0:C1303LoEP0mA5h0>d9L03a2G00k?eP0>3a?02DW=00T92h08R4Y02TX;P0U92X08B0U02TW;00Q
72<091XS02PK9@0`8bd0X9BN0?C]m03Tgn<0iN?T0??_kP2MVIP0MW5`08f7Q`2`YjP0c/S80;Vc/`3B
b/P0bL6o0<6h^@2l][H0f]CD0>?OgP3Th=l0h^7O0>3Ph03MgMd0gM_N0>;Lh03bg><0eZNa088lAP3F
Mgd0VSHf0:UDC@2AED/0`JFQ003o01[ooooo00<00?l00?n0002P8?001P2P8?040?n00080X23`00<0
oh000:0Pl03oP0000P3oP0000`2P8?00oh000?n000070?n000P0X23`103oP0000`3@D7P0oh000?n0
00040?n00100X23`1P3oP00[0:0Pl0030?n0002P8?00X23`01L0X23`00<0oh000:0Pl02P8?000P2P
8?000`3oP000d51h0?n000070?n000P0X23`00@0d51h0?n0003oP000X23`0P3oP0000`2P8?00oh00
003o000@ooooo`003_ooool05`00o`00lMWE0:YYH`36IE`0hVMO0>1LC`3OFd`0hFQC0=IiF`2aMe80
cJN30=NnW`3C`jX0iMG60<Vj/`3Qcll0j]GL0<nga02XT:00ZiBV0:RCYP2QSjD0X9:Y0080VHfU04D0
UXVO09N:WP2MT:80Og>109R<V03bi_00/:B^08=ePP24N8@0/ZRa0?3Yl@3jm?h0bLKA075]OP1bKH40
Ieic0513E`3[e>80omOF0<R?N`32OU40_gXi0?ZoL@3m_Vh0hI580=Z0A03CMT/0bWEH0;aiIP1gACX0
CB`U04Pe;`0o=300@c/h04U1?P12>SL0?3@a044i=P15?CX0?SLa04<l=P14>SP0FDm=06iPG@2<NWP0
Ugmm099_K@2<E5<0Oc4_0:<k>03UJVD0jfEL0?1RF03bI5P0lfMJ0>ePEP3cIE/0lV=K0?=TG03aHU`0
lF9N0?=TH03aHUh0m6EQ0>mPFP3aHUX0mFIN0?1QF@3dIEd00P3bHe/0703aHUX0lV=K0?5RFP3bHe/0
lF5I0?1PF03aGUH0keaD0?9OE`3_FU<0ke]A0?1LDP3_G580j5iA0=mODP3AKf40LcL]03dJ500h9R@0
;BLY02h]<`0];CD0;2`f02la?P0a=4<0>SmB0456FP15BF8204=7H00^03m4FP0m@UP0=cU<028T<@0L
6RL071XU01hL9`0S8RX07a`S02`W;P0n=ch0DdUB06ePJP1PDed0Wi>M0??Yl@3ShNH0h^;T0?;`l@1n
NWT0`;Zl08=mO`3?bLT0Y9jN0:NNW`3Db//0el_=0=W:c@3OdmD0c<;10=K>c03Vh^40hMoP0=oOg`3N
g]h0gmgP0>?Mh@3ag>80dj6/07hh@03BN7X0V3/f0:IHC02;EDT0a:fW003o01[ooooo00<00?l00:0P
l02P8?001P2P8?040?n000040:0Pl03oP000X23`0:0Pl0d0oh0000<0X23`0?n0003oP0000P3oP000
0`2P8?00oh000?n000030?n000040:0Pl03@D7P0oh000?n00080X23`0P3oP0070:0Pl0030?n0002P
8?00X23`00P0X23`1@3oP0000`2P8?00oh000?n0000W0:0Pl0030?n0002P8?00X23`01D0X23`0`3o
P0040:0Pl0T0oh0000<0X23`0?n0003oP0001`2P8?020?n000060:0Pl03oP000oh000:0Pl03oP000
0?l04?ooool000kooooo01H00?l00?k[i`2aMW00_69I0=eXG`3QHEH0gUm@0>9[E`3BMe`0^7mQ0>Bm
WP3WcK80h<jh0>GDa03VeLd0g<[80>oLh01mJGD0G4MH05a9G01D@eH0D45F0P1<?UD0CP17>e40B3Y@
04e0DP1?@U<0:al]0:bP[03fj_@0OG5k065CH01ZGVX0FDmJ0=cDg`3cl?/0T8bK06=PL`1VHGL0@3I>
08n0U@3khNd0m/?00<B3K@2nMdT0c8M60?o2M`3k^F/0fHI00>:5C03?LdX0aGAG0;MhIP1[?c@0C2lY
04Tg<`0l<S00?CPd03lj=P12?CT0?STe03Td<00j=C40?3La040i<`0m=C80@cPf04@f<`1<>CD0Id]8
08QLF`2ZJVP0[EQE0<MLEP3TJ600k6IK0>mREP3`HUH0kf=F0>mUFP3]HeT0kVEO0>YUH03WIF<0ifMX
0>ETJ03XJ6T0jFMY0>aVI`3ZHV80jf5O0>iSH03/HEh0kV=Q0>aRH03]Hf40jf5N0>iSH03ZGe`0l69P
0>aNG080jeeK03L0je]J0>iOF`3]G5T0jUUD0>eNF03WGE<0hF5F0=1]HP1h?380?AXF03h/;00b;300
;B`b030`>00`<3X0=3A0030b@@0j?Dh0=cY=030aAP0b<dP0=3M:02P[?P0U9SP07al_02@R;`0^:cH0
@Sm805YGH01[J6l0LFac07E^M@1gL7L0M6Yb06AGH@0h:cD0XYJP0??/l`3ShNH0hn?U0?Kdm@1lNgT0
Ee9D08^7R03fl_<0QX20069IFP1ODeD0Ge1C061@D`1SDeH0A3Ph0;Zb/03]inL0hMoP0080g]kN00/0
h=kQ0>;LgP3ag>40d9nU084l@@3;LW@0Tc`e0:EPD@1oDD80cKZd003o000Jooooo`03003o002P8?00
oh0000H0X23`0`3oP0030:0Pl0030?n0002P8?00oh0000<0oh00202P8?000`3oP000X23`0?n00003
0?n00080X23`0`3oP0000`2P8?00oh000=1@N0020?n00080X23`0P3oP0040:0Pl0040?n0002P8?00
X23`0?n000`0X23`00<0oh000:0Pl02P8?000`3oP00W0:0Pl0030?n0002P8?00X23`0100X23`1P3o
P0000`2P8?00oh000:0Pl0020:0Pl080oh0000<0X23`0?n0002P8?001P3oP0000`2P8?00oh000:0P
l0060:0Pl080oh0000H0X23`0?n0002P8?00X23`0?n00000o`0@ooooo`003_ooool0G000o`00ooCb
0;^6P02dHUL0ef]O0>I/G`3GGDh0gg1M0<ijH@2mQfl0e:jG0=VmZ03Ob;P0l]oA0<nn]037^;<0iMOG
089cNP1jKGL0MVQe07AVM@1bIW@0MFQi07AWN01_HW<0K5i^06UKJP1?@Dh0LFE_0?7VkP3klOT0`KNo
06eRJP1DB580M6ee0>cVl034`<h0JFIg06MRN01GCfH0?C570=K5e`3lg^P0iZNP0<InI@2hLT40i:1Q
0?o3NP3i/f/0dg/l0=inB`3>LTd0agML0:meH@1T?300B2lX04@e<010=S@0?SHd040h=P15?CX0A3dg
03de<P0k<c00?3@a03/c<00i<Bh0@3Hd048c<017<Rl0DS0_05/Y:01Y7ah0RR`Z0=AQG03ZJV40jVAH
0?9UEP3_HE<0lFEH0>eUF@3XIEd0iFYU0=][J@2mEEH0/TmD0;5@F@2bDEX0_5AM0=9NJ`3LH6/0i69/
0P3VHf/01`3RH6T0hf5[0>=QJ`3SHFT0hf1V0>IPI`3VH6T00`3TGVL0A03WHFX0iUmV0>QOI`3WG6<0
ieaO0>QQGP3OGUP0dFiS0814>P0m6QH0?bl_038/<00V9B/0:RXb02PX<00V9S0092@^02LW<`0S8S00
81l]02/Z>00d=400?3a804Y8E@1QGVP0KfYa07efOP22Nh80NW=j06aWJ`1GDED0CDM;03/e>@0f;3@0
;R@]02TO:02f[kL0lNcb0>?Qi03Shn<0l_;b0;Rh^012@440d<o=0>k]j`3Cclh0fmGE08EkNP2`Y:H0
dL;50<jo`P2XW9`0e/k<0>STh`3Qgn00g]kN0=gOgP3Ogml0h]cN0??Mh@3;V9d0Q3m20<5]J`2B@ST0
VEi>07UDA03Fal000?l06_ooool00`00o`00oh000?n000060:0Pl0@0oh0000@0X23`0?n0003oP000
X23`2P3oP000102P8?00oh000:0Pl02P8?020?n000030:0Pl03oP000X23`00<0oh000P2P8?000`3o
P000d51h0?n000020:0Pl080oh001@2P8?000`3oP000X23`0:0Pl00=0:0Pl0050?n0002P8?00X23`
0:0Pl03oP0002P2P8?050?n002L0X23`00<0d51h0?n0003oP0000`3oP0060:0Pl0030?n0002P8?00
X23`0080X23`00H0oh000:0Pl03oP000X23`0?n0002P8?060?n000L0X23`0P3oP0001P2P8?00oh00
0?n0002P8?00oh00003o013ooooo000>ooooo`0G003o003omo@0bijH0:eSF03>J5`0h6mO0>=dH`3B
KE/0^W1N0>>eYP3O_k@0glBm0=g9`P3Ue<d0h=;?0>CHf03Wg>00gmGM0>3Fh@3Ne=l0g=7O0=oDi03L
dN400P3Ndn<09`3Md>00f<_L0<Znc03@a]40iM_V0=oHh03VgnL0fm7L0<o7dP3Yhnd0k^_f08R4U@1S
GW80IUie03@X?P25M8L0onOg0?gDf03>RGT0bGeK0;eg@`3j^GL0okmh0?2UH@3INT80eWA50=5dDP34
N5h0YVmK05li;01;=2h0A3Db048h=`10>3H0?SHd048j=`15?SP0AC`g03lf<@0203de<P1<03Xb;`0l
<S00@34^04L_;@1B:b`0Fb<T06TG6@2I<c40gVMQ0>eZH03_IeT0l6AD0>mSE03]IEL0jFUN0=iWG`3R
NGD0Y4a:0:EIF`3HTYX0`gn:0;E^O02bI780aFQk0;=<G`3CIgH0ef]h0;M?FP2[AU40Xd9=0:Y6DP2Y
AE40[DMB0:a4C`2_Ae80^E1N0;I=F`2gCU`0]DaJ0;a@G`2nCU`0`4aI0<U@F@3GFUh0gf=Q0=9_I`22
AS`0?AXF02lO7`0W8BD08b8X02HV;P0c<c/0=S@o040nB@1>C5T0GE]X065OK@1_KG/0MgF207ekQP1c
L7/0IV9Z059=D@17@DD0?3Hh038/;P0a:bd0;2HX02hX:P0^:2`0;2HZ02hT;00f;cH0blK<0>k/k`80
h^;R0P3UiND06P2i^KT0iNGS0>CSh@3/j>L0oOGc07Q^K@1XG5`0Og1c07Q/KP1^I6D0g=?D0>WUiP3N
g]h0g^3O0=cNg@3Ng]h0hMgN0?CMh@35TID0RDE40;QWH`2BB3d0TEa<08EUEP3/h]T00?l06_ooool0
0`00o`00oh000?n000060:0Pl0@0oh00302P8?00103@D7P0oh000?n0003oP0030:0Pl080oh000P2P
8?030?n000040:0Pl03oP000X23`0?n000<0X23`0P3oP0050:0Pl0030?n0002P8?00oh000140X23`
00<0oh000:0Pl02P8?001`2P8?020?n000D0X23`00<0oh000:0Pl02P8?00403oP0050:0Pl0030?n0
002P8?00X23`00H0X23`1P3oP00;0:0Pl0030?n0002P8?00X23`00<0X23`00@0oh000:0Pl02P8?00
X23`1P3oP0070:0Pl0040=1@N03oP000oh000:0Pl080oh000P2P8?000`00o`3oooooooooo`0>oooo
o`003_ooool2003o002>0=Zc[02WIET0b6]L0=Q_G03/QgD0dGQX0;1eK03Xb<T0OVU^08=bNP25N840
SH6;08MmQP2GSiX0UHfJ089lRP21OH`0O7R907mhRP1mMHX0N6n407YaQP1mM8T0Ng:607I^P`1fKh40
OgR:08^4UP26Oi40Qh2B08n8V02HTJ40YJ6b09RCY`1^IWd0Jf5i05M9H00l:Cd0ekkC0?oOk@3^]k@0
chAW0;mbA03HV5X0ol5h0?ZdK03QST`0fgM30=agC@3@MEH0bGiW09QSD@1K>Bd0CSHb04Hh=`0n<S80
Acdn03`b<@11>3D0ASli04Dn>013?3@0@CXd03hg<@0k<Bl0>c0^040a;P19;c00DBP/05lQ9P1b6A/0
ZShl0>EXI03_JF00kVAG0?1TE@3[HeD0jVQJ0=mYG`3ILfh0ag=a074d<`3=Wj40omkT0?cDg@3jd=h0
omCU0>RU]`2FBel0`GF208]3C`2NHVX0fjR_0<nPYP39Uj00`i6J0;n<T`2bOhH0ZGAl0:YeO`2PJgD0
Vf=^09YPK02FF6D0XU][0:UHI`2dEV@0[TA>0=1NGP3>KFP0RTi605`i=@1LBTX0GUQJ061OI@1VIVh0
KG1i075aO@1_KW`0KVem06i]O`1LFfd0DU5S04=0D@10?T`0=30n02l[<`0_:b`0:bLX02XV9@0b;Rd0
;BTX02hZ:@0[9bH0;2PY02TT:00V82@0?SPl0=WGfP3/k>`0hN7Q0>?Sh@80hN7O00d0hN7Q0>CSh@3V
h^40hMWG0>oSh`3<_[d0]:BT0;6SX`2[Wj40TXV:0>?Mg@3Th^<0gmoO0080g^3O00/0h>3P0>?Mg`3d
g^00^H6409I?C@2XF540X5Q<08MGB@2LPWD0o_G`003o000Jooooo`800?l000<0oh000:0Pl02P8?00
0`2P8?000`3@D7P0oh000?n0000P0?n00080X23`0P3oP0060:0Pl0030?n0002P8?00X23`0140X23`
00<0oh000:0Pl02P8?00202P8?070?n000030:0Pl03oP000oh0000/0oh000P2P8?030?n000@0X23`
0P3oP0000`2P8?00oh000:0Pl0040?n001`0X23`1@3oP0070:0Pl0040=1@N03oP000oh000?n00080
X23`0P3oP0000`00o`3oooooooooo`0>ooooo`003_ooool2003o000A0>W8`@2QIe`0ag1O0<mZF03Z
RgT0^V]L0=2QV`2aV9h0J5QS06YLJ`1XGFd0KF9b06MOKP1^IWD0K6Id05iJJ01PG6/00P1QGFh0K@1N
EV/0H5M/061GK01QF6d0HEU/05aEI`1MEVP0HEY/06IOL@1ZIWL0IV9c06=OL01UHWD0J6Ej06MRN@1W
GGH0JUYd040Z?`2CM8H0omSX0?_6c03ESgh0bWeC0<Al@P3i^W<0ol1f0>nQF@3DMcX0ggI60>1hD`3F
Neh0agmW09ETD`1E=BX0BcHa04Dg=P11=CD0AC/l040f=@12>CL0@3Tc04Dn>01:@c/0@3Ta03L`:P0o
=S40?S<_040a;P16;2/0DbH[05lN8P1i7B00_Ti<0>a]I`3[HUX0lFEH0?1UEP3ZIUT0i6YM0=M_IP3=
N7D0VEUI08QNG`3ig=h0mMcP0?;Hh@3if^T0omW[09UTN02BFFX0R59P09EWL@3jfN00nMoV0?ONi03h
gN@0nmgU0?oNi`3ngNH0nmcT0?OIh@3bemh0lMKO0?3Bg03edMl0ml_L0?o8fP3o_Ld0YdMC0<9DE`3<
KFP0STm8068o>`1/FUX0GeUM05=CF`1<CeP0@dEA0412D@11@UH0?CiB03PiC@0j>dl0?3]=03XgB00h
=T@0=34l038^<`0[9bH00P0_:bX0300]:BH0;2PU02l[:P0/:2L0:BDV02/U9`0Q6al0E4mC0>GSi03X
j>P0hN7O0>?Sh@80hN7O01P0hN7Q0>g/jP3Idm<0KfEV0<6c/`1nKVh0RWYj08alO@23MgL0SXF60>gY
j03Rh>40hN7Q0=kPg`3Ogml0h=kO0>GLg`3eg^40ZFi`0:EKFP2ZGED0WUiB07eFA`35/JH2003o01[o
oooo0P00o`020?n000@0X23`8P3oP0000`3@D7P0X23`0:0Pl0020?n000H0X23`00<0oh000:0Pl03o
P0004@2P8?000`3oP000X23`0:0Pl00;0:0Pl0<0oh000P2P8?020?n000<0X23`1@3oP0020:0Pl0L0
oh0000<0X23`0?n0002P8?000P3oP00Q0:0Pl0L0oh001`2P8?000`3@D7P0oh000:0Pl0030:0Pl003
0?n00000o`000?l0013ooooo000>ooooo`800?l001<0m][F0:AbJ@30KEl0c6]J0=f0KP2PE4@0cZNN
058g?01VDEX0G4aG05mBG01LD5X0Fe5J05Y@F@1LEEd0F55I05Q@F`1IDE`0FU9M0080Fe1N0P1ICeX0
M@1ME5l0EdmL05I>F`1JDUl0Fe=P05]EH@1IEV40F5IT05QEIP1MFG00H5Q`06MGL@1J@UX0DC130>Ni
a03_[[80fY270=:3H038PTL0lk1Z0?ZhK03f[6<0k99C0=]f@03QM4T0ggAB0=AiG03=QFd0UFID054c
:019=S00AcTh04Hj>P10=SD0AC/j04<j>00o=c@0?cXf048m=`14?cT0?3La03`e;`0i<2/0?Rl/04DY
:01C9BP0FQDH07`N7`3@GUd0jVUT0>mVGP3^HUD0kfMH0>MYF`3NKf@0cgE]0;ahM`1b@D@0c:nc0?cW
k03af^00lmWR0?kOkP3R_</0Pe1Q09aYN01]AE00gl380?kWk@3cgNH0mMWU0?gGiP3jc]d0l/;>0?C6
d@3cbmH0lmCL0?KOi`3agNH0l=_T0?GIi`3he^H0omCU0?J/^`2F=T80bE]N0=1^J`21@Sd0C2TW040`
<`0h<cX0<C4m03<e@P0h>d`0>ceB0494F`19Bf80ADML0452EP11@500?3Y7034`>00^:c80;R//02TU
8P0_:RL0;RTV02/W900Z9R<0:BDT02hX:00Z92@0;2HV024K7@1QGEh0k>[[0>CTi0020>;RhP070>;T
h`3Ph^40h^;R0>SVi`3MfMX0/jZ]0=K:c0020:ZJV`0A0:RHV@2<P800VYBD0?;^k@3Qgn00gmoO0>3P
h03Pg]l0hMgN0>GJgP3ffn40TeQL0:YTHP2TH5D0UUi?08EUF03Xf/l00P00o`0Jooooo`800?l000<0
X23`0?n0002P8?000P2P8?020?n000030:0Pl03oP000oh0000D0oh000`2P8?060?n00080X23`0`3o
P0030:0Pl0@0oh0000<0X23`0?n0003oP0000`2P8?020?n000L0X23`00<0oh000:0Pl03oP0006`2P
8?00103oP000X23`0:0Pl02P8?020?n000040:0Pl03oP000X23`0?n000<0X23`1P3oP0040:0Pl080
oh0000D0X23`0?n0003oP000X23`0?n0000J0:0Pl0030?n0002P8?00X23`00L0X23`1`3oP0070:0P
l0050=1@N02P8?00X23`0:0Pl03oP0000P2P8?02003o013ooooo000>ooooo`800?l008`0o^_W0:5f
K`2aIeX0cG9P0<MZF02[F4H0i[2X09ibL`2>If`0IT=90652A`1H>cl0DCLj04Xa=01?=ST0C3Lf04Te
=00n:bL0@Bl[04Hc;`19=2l0Bc<_04hf<P1==C80B30`04D/;`14;S40B3@f04Lg>P14>Cd0B49<04e;
F@1DCfD0GU9Z06MDJP119C@0WgMo0>fg]@33NV/0dX5S0<anB03j]g40okid0?J/H`3eX5d0kHQ@0?>4
EP3/NUD0fVm?0<mdF@3;Q6h0ZGaY05Lk;@0l:B80@38_04<h=P10=S@0Acdl040f=00o=c@0?CPd044l
>013?SX0?cXd03/d;P0i<2/0?c0]04DY:01G9RT0FQ@F08HW9@3HIF00k6]U0>eTFP3_IEP0k6MI0>=]
H@3BL6L0ch9l099LG021GV80mn;W0?7PiP3`fn@0m][V0?oMk@2NMHD0S5e]07a@G@2<KWH0n^GZ0??P
iP3cg>L0om[[0?:kcP2eMHH0Y69`0:]]N02QKgX0U71j0>SAf@3ah>P0k][U0?3Hi@3genH0omCS0;m^
O@2J=3l0fVMZ0=5^J`1o@3/0EC4a044`=P0o>D<0=SE303HhA`0j?E00>ceB03doEP1:C6<0@TAI04A5
E`0g=d<0;B`d02h]<P0V92L0:RLW02XV8`0/:2D0;BTV02XV8`0X92409AlO02/U9@0[8R<0=2//020J
701^JV/0l_3a0>CTi080h^;R00d0h^CS0>7ShP3QhN40h^3Q0>GQhP3fl?80c/?707a]L02EQhL0U8R:
07]aLP2aZj/0k^g[00<0h>3P00X0g]cM0>?Mg`3Vf]h0lmOM095IFP2bLFd0W61E08UKC02FP7<0o??/
0P00o`0Jooooo`800?l000<0X23`0?n0002P8?000P2P8?030?n000L0X23`1P3oP0050:0Pl080oh00
1@2P8?020?n000030:0Pl03oP000oh0000<0X23`0P3oP0080:0Pl0030?n0002P8?00oh000100X23`
00<0oh000:0Pl02P8?001P2P8?000`3oP000X23`0:0Pl0030:0Pl080oh000P2P8?00103oP000X23`
0:0Pl02P8?030?n000040:0Pl03oP000oh000?n000@0X23`0P3oP0001@2P8?00oh000:0Pl02P8?00
oh0001X0X23`00<0oh000:0Pl02P8?00202P8?060?n000L0X23`00L0d51h0:0Pl03oP000oh000:0P
l03oP000X23`00800?l04?ooool000kooooo0P00o`00S`20ng/0g/G00:MaI`2nKf80cF]L0<1GB@3Z
Rgh0hhV00>F>Q`3WUY00i9NB0=nESP3NUX`0g9F:0>2MSP3MWhd0fjB<0=ZZRP3O/Xh0hkN@0=f_QP3C
WgL0cYQ`0=6EM@3CUW`0e9R00=FKQ@3DXI00b:6B0<2VW@3Ue]L0QG^50595F01RDFD0CcI207=BD@3W
_:T0]X1M0<:0C@3ESe00l[9V0?RaI`3`X5/0liMK0?68E@3bOUD0l7ME0>I/D03OL5L0dWIO0<J0J`2K
KU/0N5e?07QVG01XFeD0C44m03db;P0m<Rl0@3Db04Hk>@13>SP0ACdj04@l>@18@3d0?cDc040e<P12
<2h0AbXY05@R901P6QT0UcLb0=i/H`3YJEh0kVQJ0>aVE`3WJE`0f75W0<mnN02TJVT0ME9D0>3:cP3d
h^P0kmgU0??Lj@3lgnd0bJ2b08]PL027Gfd0MUEP0>G@e`3ch^P0lMcU0?WHj03`^Lh0ZUEY0<1OK`3C
M7l0cgj50:IZL@1jDET0jLoH0?CPj@3_en@0m=GT0?oGi`3MVZT0WCU20=5KG`3MIV80cfmX07Lk>01B
;c00@C0h03`d@00i>4D0>Sa;03LiB@0e=dT0?cmA04=3E00m>dX0<c8l02TX;P0W9RT0:RTW02HU8P0W
9R80:2LS02TX9P0W9R@09RDS02TU900W8B40:B0Q02lU9P0`9RT08Q/M09:=SP3dl_<0i>;S0>?Sh`3Q
hN40h^;R0080hn?S00X0i>?Q0>CQh03gl_<0^kBe079XJP2aYjP0^K2b09nIV@39b<H0i^KT0P3Ph>00
2P3Nh=l0h=kO0>KLh03YfMd0j/c@07]6A@2dOGH0REe>081RD`3;_KH3003o01[ooooo0P00o`000`20
`000d51h0=1@N0020:0Pl0040?n0002P8?00X23`0:0Pl0L0d51h1`3oP0000`3XJ3`0d51h0=1@N004
0?n000040=1@N03oP000X23`0?n00080d51h0P3oP0020=1@N0030?n0003@D7P0X23`00P0X23`0P3@
D7P00`3oP000d51h0=1@N00:0:0Pl0050?n0002P8?00X23`0:0Pl03oP0001`2P8?000`3@D7P0X23`
0=1@N0030:0Pl0030=1@N03oP000d51h00<0d51h0P2P8?00103XJ3`0oh000=1@N03@D7P20:0Pl003
0?n0002P8?00d51h0080X23`00D0d51h0?n0003@D7P0oh000=1@N00M0:0Pl0030?n0002P8?00X23`
00P0X23`0P3oP0040=1@N0L0X23`00@0d51h0:0Pl03oP000X23`0P3@D7P3003o013ooooo000>oooo
o`@00?l008T0ilk70:=cJ@2jJUl0aV1D0>Q_I@3ZK600j6YN0>]aIP3WKV<0j71R0>MaH`3OKU`0hgIQ
0=]eG03KOUd0fhIM0>>GIP3^ZG00n;Ii0?NfMP3UY680chQ;0<Ai@034N4@0aGe=0;eoF02;GD<0e[JY
0<Fa/P1GBU@0Ge5R04XhA01@>cP0l=6m0=2TO@3?Vf80o;ml0?o0MP3fZV00k99C0>f8DP3cQ5L0l7QE
0?5aEP3[JE<0j6UF0>=`G@3BMF<0bHEb08EGB01>=2L0DChg06]NF027O7P0S85m071UG`11=C00?34]
04<h=014>cH0@cXe04Hm>016?3X0@C<b044];P19:BX0EB8Q06LM6P2[BD00iG5T0>IWF03_JUT0jfIG
0>A^H03BN6l0^gag06e4@P3B^K`0n>O]0>gLhP3`fn@0o>3^0>2nc020DF40W71m06=2B`3G`<H0mnK/
0>kMi@3df^L0oLoP0:iMKP2lDF40gVij0=AdN037Ngl0OTa?0<b//@3liNd0l=[V0?7Ei03oe>L0o;_?
09a1D035D5H0i6MU0=aUG@39Kf@0Ic8Z04`]:`0k:bh0=Rlf03Dd?00l>TL0>CU503PhA00m>dP0?Ca4
03@a>00^;3409R8S02HR7`0Z9b80;b`W02DR7@0V8ah0:RHS02HR7`0S7a`0:RDR02dT9@0[8R<0;B8V
02XO9@0]8RP0`;Zn0>k/k@030>;RhP0I0>;Rh03Rh^80iNGU0>SWi@1dKf`0R7im05I:BP1cIF@0VH^:
08^0OP22N7H0gm[G0>KUh@3Ogmd0h>3N0=kPg`3Pg]l0i]_O0>_Hg03F]kP0LT<m0:j4MP1gG4T0SH1_
0?C`i`03003o01[ooooo1000o`020?n00100X23`0`3oP0040:0Pl0030?n0002P8?00oh0000X0oh00
3@2P8?050?n000P0X23`00D0oh000:0Pl02P8?00X23`0?n000060:0Pl0030?n0002P8?00oh0000@0
X23`00D0oh000:0Pl03oP000X23`0?n000030:0Pl0030?n0002P8?00oh0000@0X23`00@0oh000:0P
l02P8?00X23`103oP00N0:0Pl0030?n0002P8?00X23`00H0X23`0P3oP0000`2P8?00oh000?n00002
0?n000P0X23`00H0d51h0:0Pl03oP000X23`0?n0002P8?03003o013ooooo000>ooooo`@00?l008T0
ooSd0<NYX@2IFe00^5iC0>AZH03bJEl0kVAI0?M]HP3eKEl0lf]M0?E`H@3cL5h0lG9O0>M_E`3TMEL0
hg]F0>:3E@3TSeT0jIUL0?BYJ03m]700okMc0?V/J03]XV40i9iS0;f3D`2hSFd0mMS808YeM01SCeP0
JUIQ03DP9@2NPgP0o]^o0>jkS03i_H40m[=_0>ZOF`3XSe00jX9?0?:1E`3_M5<0lG5F0>iZE@3aK5/0
ifEE0>1]F`3EN6H0aX9_08EJBP1A=bX0BCP`04Tn>01=A3l0Jf9M08QmN@26NgL0DdQ403hc;`0i;RX0
?SD`048i=012>3H0?2h]044];P1?;Bh0EQhO070R802aC4@0iFmS0>Y[FP3/JEL0jfUK0=e`I@3@PGX0
RUEA08e[JP3ji^P0lN;W0?7Ni03cg>H0omo/0:J0S`2BI740Ne5M08mdN`3kj>h0l^7W0?;MiP3df>H0
lk[;098d@P3HJG80fFYa0=QnP02NFU/0REmQ0?SMhP3cg^D0l=SU0?CEi@3oeNP0cgjA09P_?@3SIVX0
hV5L0=]VG034L640Hc4X04HX9P0j:R/0<bTa02dZ<@0b;cP0>cU403Xh@`0n?DD0?CY103@b=@0_:b`0
:2@S02HR7`0Y9R40:bPS02LT7`0Z9b80:RDR02LR7`0U81d0:28R030W:00a9RX0;B0W02TL8`0h;C<0
elkC0>k/k@030>;RhP0I0>?Sh@3Rh^00iNGU0>SWi@2MV9D0UXb;09B6Q@2PTHh0UXN408anN`2@QH<0
jnKS0>OSh03Qh=h0gmoM0=gOgP3Qgn00j=cP0>kIgP38YZP0U6UR09ihJ`1[FDD0Yj:?0?olm@03003o
01[ooooo1000o`020?n000030:0Pl03oP000X23`01@0X23`303oP00A0:0Pl0<0oh001`2P8?001@3o
P000X23`0:0Pl02P8?00oh0000`0X23`0`3oP0000`2P8?00oh000:0Pl0030:0Pl0030=1@N03oP000
X23`00L0X23`0P3oP0000`2P8?00oh000:0Pl00N0:0Pl0030?n0002P8?00X23`00H0X23`1`3oP008
0:0Pl0H0oh000`00o`0@ooooo`003_ooool5003o002S0?WVh02UNG00XEQ?0=QVG@3`JV40kF1F0?AW
G@3iKF00n6aO0?A[F`3eKEl0mW9S0>m^F`3/LU/0iW=F0>AgEP3WPET0iHIH0>N=F`3USUP0lYmR0?J[
JP3i]7<0m[Yn0=n_OP3hf;80[iJ004L^:@1C>Sd0ARh^05Dh<P3_bKH0jKNF0>:NL@3ZVVD0j95K0>R:
E03[PU80kWQD0?9eE`3_KED0l6aG0?9ZFP3]J5T0jFMG0=i[F@3DMfD0bhMd08=HA`1@>B/0ASP_04U2
?01<A440Aclm04]3@01aIf80V8f908AiM@1UFUH0ASdh03Pa:`0f;2X0>bd/03l[;01>:R`0F1dO07HV
9@2kE4d0j6mT0>YXF`3[JE/0gfEH0=MdK@2iN7H0J3`m0<bb/`3iiNL0kmkT0?3Mh`3lh^d0hK_:07mD
I@2NLWl0H3Y50<jg_`3fiN/0l=gS0?CJi@3ifNP0gIZZ0;E;E@3OKW@0fg9f0<MgN01i@D80bZN[0?_T
jP3_f^<0l]SU0?cGj@3oa=P0XdMF0<=>E`3WIFL0i6=M0=ETEP2oKeh0GRlU04<W900i:b/0=b`d03@]
=@0g<C/0>CHo03/h@`10?DH0>cPo02/Y;00X92D0;BTX02/W900Y9R40:2<P02XU8P0/9b@0;2<T02PO
800U71d0;RDV038W:`0`9B/0:ahW02LJ8`1;@4P0hMSM0>gYjP3Ph>00h^;R0>;Th`3Ph=h0h^;P0>?S
h`3QhMl0j^WU0>COg02<PX00VHj:09J8Q@2KT8h0XiVG0:BLVP1oNgX0hMoP0>?Sh`3Ogmd0hmoN0>OK
g@3afmh0_Y^L0;25OP24HUH0IUI70<k:_P04003o01[ooooo1@00o`000`2P8?00oh000?n0000D0:0P
l0@0oh00102P8?030?n000l0X23`00<0oh000:0Pl02P8?000`2P8?040?n000@0X23`00D0oh000:0P
l02P8?00X23`0?n000050:0Pl0030?n0002P8?00oh0000@0X23`00D0oh000:0Pl03oP000X23`0?n0
00030:0Pl0030?n0003@D7P0oh0000@0X23`00@0oh000:0Pl02P8?00X23`103oP00Z0:0Pl0L0oh00
1P2P8?000`3@D7P0oh000:0Pl0020?n000@00?l04?ooool000kooooo1P00o`002P3Ub<80V6=K0<EU
FP3XK680jVIJ0>YREP3bJ5/0lfMJ0?E/G03eJeh20?A/GP1`0?1]F`3^L5X0iVaD0>YgFP3WNEP0iWaE
0>J1E@3VQU<0hHYD0>6BFP3GTU/0fZ9c0?oM]`3A[980^8j20;66O`2[P7T0gJfO0?[0Z03ESVh0iHeW
0>^:G`3]PeT0jgiE0>miE`3_Ke@0lFeH0?5ZE`3dK5`0lFMJ0?1XFP3[IeP0gfYI0=EfHP3<QG40SV5>
05@j:`17>C00A3dg04M2?`15@3d0B40n04Hm>`1HCT`0NFm]09>9Q`2@R8D0L6QU04i4@P0j;2/0<1XL
04DQ8`1K7b40NRTX0<1GD`3VKfL0j6YN0>=YGP3NKfH0c7Yh089>D02BLWD0nNGW0?7NhP3ag^@0lmkW
0?gOj`2YOXl0TfMf085II02FMgl0n^O]0?7Pj03ag><0mmWS0?oIi`2mKW`0eVM^0=]^L@3FN7P0XUiM
08=EE`3dfMh0l]kW0?7Ji03eeN80omKW0=6:W02J<3`0hV=Z0>QRH@3QHEP0eVIH0;IZF@1?9a/0@BTU
03DY:`0g;CD0=Bdh03Xd?P0k=D40?CY503/h@@0`;C@0:BLZ02<Q8P0W9R@0:BDR02HR8@0X92D0;BPY
02`V:080:B0S0P0^9BP08P0a:2d0<BH^02`P:P0N4Q`0Fe5I0>[Tj03ZiNT0hN7Q0>;RhP3Qhn80hn?Q
0>CThP3Shn<0hN7O0>k]j`3=bLP0JFAQ08MmN`1iKV`0PGId06=IF024OWh0Kf]Z0>SVi`3Ti>@0h=oM
0>7Mg03Xg=h0mN7S0:61P@2oVY40Ke=707ecI`3/jN04003o01[ooooo1P00o`020?n001D0X23`203o
P00I0:0Pl0@0oh001P2P8?000`3oP000X23`0:0Pl0040:0Pl0030?n0002P8?00X23`0080X23`0`3o
P0000`2P8?00oh000:0Pl0020:0Pl0<0oh00202P8?020?n000030:0Pl03oP000X23`01h0X23`00<0
oh000:0Pl02P8?00202P8?080?n000H0X23`00D0d51h0?n0002P8?00oh000:0Pl004003o013ooooo
000>ooooo`H00?l002L0ooOd0<FVX@2YHeL0dVaM0>1ZG03WJE/0i5iB0>UQD`3YGe80k69E0?1TE`3d
J5/0lfUL0?=[F`3cL5`0lG1K0>]]EP3/LeP0k7EG0>UhD`3YOEH0j8=I0=]kD`3JQEh0lJJ60?6ZSP3`
Z980ljNG0?:YV03hZYH0hHUa0>1nH`3[Of80kW]L0>UbE03_LeL0kFeF0>eXE@3aJUL00P3aJ5P02`3g
Jeh0lFMJ0>eWF`3QJET0fGQU0<j5LP2AHU00EcXZ04Th;P16?CH0BD4n0080A3ll04T0ASlm04Hn?011
>CL0CTI406]SH@26OW/0UH^908YlN`1[EUD0D2TZ05<G6@1`7ah0`5IF0>I`K03QJV80gVmV0=IiLP2O
H600G3Xk0=>m`03fin`0k]gS0?7Li@3lh^l0f;K607E9FP2PM8<0GSe60=Bk`@3jind0lMkT0?GKiP3k
en<0om7N0;9JIP3KKW@0eG5c0<QgMP1i@d<0b:JW0?cUj`3^f^<0l]SU0?[Dh`3oamH0Z55Q0<1;E03X
HFD0if1L0>AVFP3CJ5P0[FMF04LU6@0g9Ql0<BPY03Tb>@0k=Cl0=c@o03Xg@P11>dL0<R`f02dZ<@0/
:Rl0:2HY02DU9@0V92D09bDX02PV:`0Y9B`0;BH^02/Q:P0Z82P0:R4V00809AlS0200:b4Y03<Y<P0]
9Rh0Lfid0?3[k`3Vi>L0h^;R0>3Ph03Shn<0i>CT0>;RhP3Qhn00hn?S0?;`l@2f/[<0Lfe]0=W?d03I
clh0WiFD0:JMWP3]jNP0fm[H0>;RhP3Qgn00h]kM0>?Mg@3Xg=h0n^OY08U^K02eWI40He=60:RQV@D0
0?l06_ooool6003o0080oh0000<0d51h0:0Pl02P8?00:P2P8?000`3oP000X23`0:0Pl0080:0Pl0D0
oh000`2P8?000`3oP000X23`0:0Pl0040:0Pl0030?n0002P8?00X23`0080X23`00D0oh000:0Pl03o
P000X23`0?n000030:0Pl080oh0000<0d51h0:0Pl02P8?000P2P8?00103oP000X23`0:0Pl02P8?04
0?n000H0X23`00<0oh000:0Pl02P8?005P2P8?000`3oP000X23`0:0Pl0080:0Pl0H0oh00202P8?00
103@D7P0oh000?n0003oP005003o013ooooo000>ooooo`L00?l000/0n>WT09=YGP2`J5X0aFeO0=9]
H@3JK5l0g6IJ0>E[G03PH5<0hV1B0>]UF@020>mWF@0W0>iVEP3aJET0kVUH0?5^FP3bLE/0kW5I0>mc
E`3[M5H0jWMJ0>EhF`3SOV80ggeR0>1lI03MNF80fWMR0>1jI03TMUl0j7AM0>abF`3^L5X0l6mJ0>m/
F03aJUT0lFQH0?I]G@3aJ5P0lVQK0?AXF`3bJ5/0kVQL0=mUEP3JMF<0dH=_0:]cI01N>2/0CC@]04Xk
=P18?S`0@Sdj0080@chk0580AClo048l?011>c/0Acho04Q0?P1HD4h0Nfe/09n6R@2XOh<0XVAW08dk
?@2oEeH0hW9^0=]^I`3GMVl0_75/09maL@3B^Kd0lN7T0>oPi@3`g>D0n=k[0?oOkP2YPY@0Sf1b07]A
G`2EMgl0n^GZ0??Rj03`gN<0mM_V0?oHiP3PXk80ZU1L0=Q`M`3EO7h0X5YL08=FF@3ffMd0m]oW0?7I
iP3ee^D0omGU0>2FY@2C;c/0hF=W0>UOG@3VH5L0gfEH0=A]GP2RH580@28G034R7@0[9BD0;R/b038_
>P0f<T00>3A203`f@P0`:S@0:BH]02HT:@0X9b`0:2PZ02PW;00V9BX07ahT01lL9@0O6B<09AdX030Y
<@0`:Rh0>38f04e6C@1OF5l0LV]c05E@EP2:R8d0lo7d0>CTi03Shn<0h^;R0P3Shn<05P3Rh^80hN?P
0>?Sh`3Zj^X0gMWJ07QbLP1KDU<0Edi?07A[K03CcLd0kNWX0>CSh@3Ph>00h^3Q0>7Mg03Ug=d0j=cN
0?cZjP21JVD0YYJ706EKC`3NfmH5003o01[ooooo1`00o`000`2P8?00d51h0:0Pl00[0:0Pl0030?n0
002P8?00X23`00/0X23`1P3oP0040:0Pl0030=1@N03oP000X23`00<0X23`0`3oP0000`2P8?00oh00
0:0Pl0030:0Pl080oh0000<0d51h0:0Pl02P8?001@2P8?020?n000030:0Pl03oP000X23`01`0X23`
0P3oP0000`2P8?00oh000:0Pl00:0:0Pl080oh0000<0X23`0?n0003oP000202P8?030?n000030:0P
l000o`000?l000<00?l04?ooool000kooooo2000o`007`3B`;T0/Y270:enM02_MFX0^G=W0;m]H@39
KEh0dfeN0=a^G@3QK5/0jVmO0>]YF`3XI5D0k6MH0>]VE@3ZIE80jFAA0>iYE`3`K5L0kfeG0?1_F@3d
MV00lGMR0>mfH@3^Mf<0kgQT0>Q`G`3/Lf80lGAR0?5`G@3_K5X00P3`JeX0I03cJe/0lFQJ0>mUF03f
JUd0lFMJ0?9XG@3dIed0lFAJ0?9ZGP3TIUP0gg5R0=YnK`2fLVL0KS`c05He<01>>CP0BC/j04@l>P11
>c/0@Sdm044m?P12?Sl0@Shm04Do?`15@3d0@chk04Hj>P1C>Sh0MdiD0:QZK`2iIf/0af=S0=YaK@3C
L6X0ehAn07/o?P3>[[00l]oS0?3Mh`3bgN@0lmcV0?oQl03K//@0PE9V09a]O`1S?DX0e[o70?GVj`3_
h>L0l=cU0?GMjP3ldn40XF5_0;QRK@3>MG/0a7Um07@l?`2oW:00oNCZ0?7Ji03cenD0n=KV0?o?g@2f
G6P0^DI=0>YTI@3[H5/0heiE0>1XFP3?KF00UUU>03DJ4`0[81h0:bHZ02TV;@0Y9c80<S0m03Hd@@0g
<d40:RLb02h[=00X9B`09B8Y02HT:@0J5ah07a`S02XW<00k>440G5MN06iYL01^JFl0LVea06m[K01Y
HfL0EU1D04@oA@0/9bd0X9jS0??am03Shn<20>;RhP0H0>?Sh`3SiN@0h^CS0>;Th`3Rh^@0jNWY0?;^
k@2TWi`0Aclm05=;B@34_;X0lNcY0>?OgP3Qh=h0h>3P0>7Oh03Qfm/0i=[K0>oQh@3`g]`0QW9Y08Ah
JP2;Qg/0nOSc1@00o`0Jooooo`P00?l000@0d51h0?n0003oP000oh00;02P8?000`3oP000X23`0:0P
l00;0:0Pl0030?n0002P8?00X23`00@0X23`00<0d51h0:0Pl02P8?000P2P8?020?n000040:0Pl03o
P000X23`0?n000@0X23`00<0oh000:0Pl03@D7P00`2P8?00103oP000X23`0:0Pl02P8?040?n001L0
X23`1P3oP0030:0Pl0030?n0002P8?00X23`00T0X23`00@0oh000:0Pl02P8?00oh002@2P8?040?n0
00D00?l04?ooool000kooooo2@00o`00P`3om?00m^GN0>cAbP3J]J`0c9fC0<26NP2jMVT0_g5T0<A/
GP39JET0eVmP0=][G@3SKf00iViN0>EZF03VJEL0iV=D0>QSDP3TGdh0kVIF0>]SD`3bKE`0lFaK0?=^
G@3dLEl0lfiM0?IaH03dK5h0mViN0?5YF@3`J5P0mF]N0>iTE`3bJ5/0m6QK0?=WFP3aIeX0lFML0?EX
GP3cIU`0lFUM0>QYFP3RK5h0gWQ/0<QfJ`1i>S<0GC4^05@h=`1>?3`0Acdl04Po@011>c/0?c/j04<m
?`15?cl0@cdm040j>P16@400Ac/k04lf>P1J<CL0HR<[088`=P37Hf<0fg=`0=UhLP2fIF40RTi=0?[F
f03hfn00n=[R0?SIh@3nf^H0omOU0:I_PP2GGVl0PE5O09]eP03mi^h0k]oT0>oNiP3`g>D0nN;/0?3?
fP1d?4T0UDmI09eJH@1e@DD0SFAX0?GJg`3bgN@0lmWT0?GEi03oenP0fiVW09Ta>P3OHF@0jV1M0>]R
F03TI5L0eFEG0<mfJ023C4<0<ATG02/Q800U8bH0:bP_02XY<@0`;CP0;R/f02XW<P0_;3D0<2dd02dZ
<@0e<cP0BdI<05YEF`1_JW00P7f4089oQ@1eLgP0IF1T04Q3A`0l>3T0=S8c030Z;P0]9Rd09b0W03Td
>P3CdM@0kN_^00@0h^;R01H0h^CS0>7ShP3SiN@0iNGW0>k/k@2b[Zd0R8B10:>NV`2AS8T0RhJ30>;N
g@3ViN<0hN3N0>3Ph03Pg]l0hmgM0>KJfP3di>D0bKNc08QgJ`1[IEL0dLk51P00o`0Jooooo`T00?l0
00<0oh000:0Pl03oP0000`3oP00Z0:0Pl0030?n0002P8?00X23`00/0X23`00<0oh000:0Pl02P8?00
0`2P8?000`3@D7P0X23`0?n000050?n000030:0Pl03oP000X23`00@0X23`00<0oh000:0Pl03@D7P0
1P2P8?040?n001D0X23`1@3oP0070:0Pl0030?n0002P8?00X23`00P0X23`1@3oP0080:0Pl0@0oh00
1P00o`0@ooooo`003_ooool=003o000K0?oel03ki^40k]?<0=Rf[@37W9<0^HMl0;EgJP2hL640_VmP
0<M^G03@Ke`0eVeJ0>9^GP3XKEd0jfUK0>UTE@3ZHU80jV5A0>]RD03^IE<0k6=A0?9VE@3`I5<0m6QI
0?Q/G@3fJU/0lfYH0080mVYK01D0lfMH0?9YF@3aJ5P0lfYJ0?5WFP3eJE`0m6QK0?1XFP3ZIUL0iVQJ
0>AdJ03LNg80S48i05<N6P1?;2X0@bh[044c<P16?3/0@C/k03lj=`15?3d00P14>c`0C@13>Sd0@C/m
044e=`19<cH0FC8g060Q:@1e8bT0`emQ0=ieLP3JLVl0Zdi90;EYJ@3oaLL0o/_B0?o=eP3ocMT0om?Q
0>BW]P2ABEL0/6Ye081;E@3Y`LT0o^?Z0??Nh`3ag^@0l]gT0?COiP3fgN<0aZ>Z0:n8SP2FLgL0X8J9
0>3<cP3gi>P0l=_R0??Ii03menH0ol_L0:ECH@2lB540jfEV0>UPFP3WHeL0gfMG0=9/G@39Nfh0Jcde
038N7@0X7b008b4R02h/;`0f=3L0@Ca204e8CP1CCU@0IF1T06iYK@1jMWL0OGUj081lO@1gLg@0If=T
05QCE`10?3l0<2h_02TX9P0T8b408R4O02PT9@0Y8RT0;R@/02<I8@1[I6/0lNob0>CTi03QhN40i>CT
0080h^;R01H0i>CT0>?Sh`3Ti>@0jNOX0>KTi@2:QXL0d<c;0=OAd@38`/80RhN60=KEd`3ViN<0hN7O
0=oOg@3Qh=h0i]gN0>SLg03ijNX0Th5m08MkK`22OWD0moKa1P00o`0Jooooo`d00?l000<0oh000:0P
l02P8?00103oP00R0:0Pl0040?n0002P8?00X23`0?n000X0X23`00D0oh000:0Pl02P8?00X23`0?n0
00020:0Pl0030?n0002P8?00oh0000H0oh000P2P8?000`3oP000X23`0:0Pl0040:0Pl0D0oh000`2P
8?040?n000L0X23`00<0oh000:0Pl02P8?001@2P8?070?n000X0X23`00<0oh000:0Pl02P8?002@2P
8?050?n000P0X23`103oP006003o013ooooo000>oooooa400?l001T0ooG`0?[Vg`3_dLL0fK>X0<JH
R`2gOg80[feM0;U]G@33K5`0d6UJ0=a[G@3VJe`0kVYK0?=[F`3dJeT0mFYG0?AYEP3bIe80k65<0>aO
C@3`He40kf=B0>eQD03_He@0lfMH0080mFUJ02l0lfYJ0?5XF03cJUX0lVII0?IZG@3`IeL0kfMI0>iZ
G@3ZL6<0jgmb0:mGB`1M6Q40D1lH040O600b6QH0=bPU03X_;P0h<2h0@3He04<i>014>S/0@cXm048i
?013=cT0C3Pj05@_=P1M8BT0M2D[0<5OH03QMG<0gViZ0<eQGP34IF40bWEe0=:3R03GRY00hIBL0>fM
Z02`GFL0]5MQ0;iWK@2UGV@0ol[=0?oAe03ldmT0o=GJ0?kFgP020?gIg@0Q0?oLh@3og^80o=gR0?_Q
i03mh^L0nmkS0?_Jh`3oen80omCR0=nCX02K=d<0gV1T0>iRH@3/HUP0i69D0=UXF03;L5h0_GU/07A?
AP1YFeP0JVAT071^K`1iMGH0OWYk081lO@1lN7T0MG5b06YVI`1KEeH0C4Q704A0?`0l>3L0:RHU0080
;RXY00l0;b/Z02`[9`0Z:BD0:RTU02DT8P0V8R<09QlV02`R:`0S6B40WiVM0?Cbm@3Ti>@0hn?S0>GU
i@3Rh^80103Shn<04P3Uhn@0l>c]0<k:b`2CSHl0E4i>06eWI`2^ZZ/0jNOX0>7Qg`3Rh^00hN7O0>?O
gP3Ug=d0jmoO0?CTi01RDdh0SXEh0;fl]`L00?l06_oooolA003o00030?n0002P8?00oh0000<0oh00
7`2P8?000`3oP000X23`0:0Pl00;0:0Pl0050?n0002P8?00X23`0:0Pl03oP0002P2P8?000`3oP000
X23`0:0Pl00:0?n000<0X23`0`3oP0000`2P8?00oh000:0Pl0070:0Pl0T0oh00402P8?000`3oP000
X23`0:0Pl0090:0Pl080oh0000<0X23`0?n0003oP000202P8?030?n000L00?l04?ooool000kooooo
5000o`00N03on?D0oo7]0?GQfP3VbL40dJnU0;R:OP2aK5d0_fMI0=1VF03PJ5P0hfAA0>aZE03[Ie00
k6Q?0?1]D@3_JDh0mF]A0?AYDP3aI500kV5?0>iQD03]Ge40kf9A0>aOCP3ZGTd0jem>0>eQDP3aIEP0
l6AG0?9VF@3bJ5/0kVAG0?5_G`3ZMF@0eVmN08H`8@1Q7A00Db8D04<O4`0j7aP0:a/F02dR800_9B@0
;R@S03D/;@0k<S<0>S4b040d=P1;=cT0Dc0f05dV;01d:Bh0_emP0=mbK@3SKVL0i6]S0>UbJP3VMFh0
gg=`0=a^K@3HJVT0cf5R0<QGF@3NK6`0ffm]0;mMGP3KPH40g8Z<0=n@T`3PUIX0hi^O0>:KX@3XXjP0
kjfa0?Be^P3g_/@0oLK<0?g8d03oam00olSA0?o3c`3_Wj`0Y3m70<E>DP3[IF@0kF1I0>aTF03RI5D0
e6]H0<QeH`2[Lf80LeM<06eTG`1SGU/0F5AC05MAD`16@T<0@3`k03@c<@0_;Bh09bDV02XY9`0V9B<0
;B`Z02`X9`0/:2D0<BdZ02l[:00]:BH0:RLR02HS7P0[9b@0;2PW02DQ8P0X8RH0:R0X03</<`3=b<`0
k^c_0>?Sh`80hn?Q00<0i>CR0>7Qg`3Rh^800P3Shn<04P3Vi>D0lNg^0<Fl_`1`IfX0J5mP0:BNWP3X
i>D0iN?T0>7Qg`3Ph=h0hN3N0>?OgP3UgM/0l^KV0=71`@16>3D0[:NK0>_ZiPL00?l06_oooolD003o
00030?n0002P8?00X23`00<0oh007@2P8?000`3oP000X23`0:0Pl0020:0Pl0030=1@N02P8?00X23`
00D0X23`00D0oh000:0Pl02P8?00X23`0?n000090:0Pl0040?n0002P8?00X23`0?n000L0X23`203o
P0000`2P8?00oh000?n000060:0Pl0040?n0003@D7P0oh000?n001L0X23`00<0oh000:0Pl02P8?00
2@2P8?040?n000P0X23`00@0oh000:0Pl03oP000X23`1`00o`0@ooooo`003_oooolI003o00180?c[
i03<Y9X0XVQJ0;Q[F`38JEL0eVaF0>A`F@3XL5L0l7AH0>mdE@3/KDd0i6530?1ZC`3^ITh0kfMA0?AY
EP3cJUP0lf]H0?5/F@3aK5/0kFYH0?5^G03YIEH0iV9C0>=NC`3UH540if9C0>=QD@3OIU<0j7UU0;eJ
A`2A>RT0KRHG05lT5P1C8aL0@QhG02lF4P0c6aT0<1`K02`L700Z71/0<20Q03<P8P0l8bH0B2@X05TR
:01^8bL0/E9@0>=dK@3VJf<0jf]P0?5_HP3`L6@0lW=Z0?1aJ03aLFP0jfYT0>i]I`3YJV@0j6eV0>Uc
K`3RLVh0gW9_0=I^K@3DKFh0bFEW0<9RH`2oHF80`69S0;eUJ030Jfh0bGAk0P36M7X05P3<MGd0afYd
0;I>E@3;DeD0jVIT0>UNF@3]H5L0jfEI0=mUEP3?Je/0aWe/09e^GP19=B/0>SDa03@`;@0[9bH0<2`]
02XV9`0/:2L0;bh/02LV900X9bD202/Z:00A02LV900/:bL0:bLT02hZ9`0Y9B80;RXV02`W8`0X8al0
9b<P02l[:P0/:2T0:R@X01lH7`1QFV40kn[^0>KTi@3Ti>80103Shn40503Rh^80hn?S0>CSh`3`k>d0
clK707Y`L@2NU9D0`[Ri0:>MW@2^ZZT0jn[X0=oOg@3Qh=h0h]kM0>COg03Vg]`0mng[09V>RP1GCTL0
a/Bj2000o`0JoooooaT00?l000<0d51h0?n0003oP0006`2P8?020?n000H0X23`0P3oP0000`2P8?00
oh000?n000040:0Pl0030?n0002P8?00X23`01X0X23`0P3oP0070:0Pl0030?n0002P8?00X23`01L0
X23`00<0oh000:0Pl02P8?002@2P8?060?n000L0X23`00<0oh000:0Pl03oP0002000o`0@ooooo`00
3_oooolJ003o001S0?o`j@2cV8d0RF1>0:U_F`2kL5T0cG=K0=1ZD`3VN5d0hG1B0?1jG03cNU/0mGYK
0?1_DP3_KE<0k6QA0>UWC`3XK5D0iFiH0>IaG@3VLf00iG9O0>YgI03YM680ifmN0>YbH@3XKeh0hFYF
0=YUD@3KJeL0ffiJ0==ZE`2ZBCH0SSDS07`Z701`;B40DAdB04/L5P147AP0>Q/F03@H5@0c6AP0=APJ
03@D5`0o5AT0Ca8I068C602WAD@0iGA^0>M[H@3]Jed0k6QI0?1/GP3aKF00kf]N0>iXG03_JEh0kf]O
0>eXG`3^Jf40kg1W0>a`IP3]LVX0kgI]0>YaJ@3ZLfd0jgA^0>I`K03WLFd0hFi[0=m/J@3SKg00hFe^
0=aXJ@3OJFT0g65S0>9UH`3[IF80kfAO0>mRF@3ZH5D0jFEI0=eWF@3=LF80aXAf07iFBP10<BX0=c<`
03Lf=00a;c00:bTZ02hZ:`0Y9B@0:bLT02HR7`0Y92409R4N02dX9@0Y9B80:2DP0080:BHQ02D09RDP
02d[9`0]:2D0:B@Q02`V9P0Z9RD0;BTZ02XU:@0R7B40V9JI0?Gcm03Rh^80hn?Q0>GUh`3Ti>80h^;P
0>?Sh`3Ti>@0hn?S0>KSi03gk^l0]:ZY0:2BTP3@`/80bl7009F@S@2h];40jn[X0>3PgP3RhMl0i>3M
0>COg03Zh]l0kNKP07mkL02DTXH0`/:j00P00?l06_oooolJ003o00040:0Pl03oP000X23`0?n001/0
X23`0`3oP00<0:0Pl0030?n0002P8?00X23`0280X23`00<0oh000:0Pl03@D7P0602P8?000`3oP000
X23`0:0Pl0090:0Pl0H0oh001`2P8?020?n000030=1@N000o`000?l000H00?l04?ooool000kooooo
6`00o`00?`3^iml0Xi6308Y]F`2DIe@0YfeI0;E]E`31KeL0_VM;0=1bEP3NO5l0g7MI0=ieF03GJdl0
f6iD0<mWCP38JE40`VYF0<IaG@32Ked0`g1N0<E_GP36L5l0bg9P0=5fH`3@Lf40cG5L0=1dG`3<L5T0
dW=M0==gHP35JE@0`FUC0;5LB02MD3l0OS/[06T[7P1H7a@0C1XA04@E3@0n4@`0?Ph<040=301830`0
DPL;05d31@2R>CH0j75[0>]]H@3[JE/0j6EC0>iXF03_IeT0lVYJ0?1XF03_IeT0kVUJ0>iXG03]JEd0
lViR0>m[G`3^K5l0lW1S0>m]H0020?1]H`050?9_I@3`KF<0lFiV0?9_I`3eL6/00P3bKFP03@3^If<0
lFQR0>mTG`3]H5T0lfIM0>iQE`3ZHUH0iVII0=][G@3@NVd0^Geb05lm=00l<2/00P0d<c40700/:R/0
:BLX02XV9@0X9240:BDR02/V8`0W8Ql0;BDS02hY9P0^:BD0:2<O02PU800V8ah09b@O02LT800X9240
:28R02lY:@0X8R80;RX[02lZ;P0^:Bd0a/C50>o_k`3Shn40h^;P0>CThP3UiN<30>?Sh`0C0>CRh`3V
hN80m>_/0>KJfP2UUiH0LVAS06MMF`2?RXL0i^GQ0>GTh03Ogmd0hN3N0>;Nf`3Sg]/0l^gY0<_8_`25
QgT0Ngma04o@C008003o01[ooooo6`00o`000`2P8?00oh000?n000020?n001/0X23`0`3oP00:0:0P
l0030?n0002P8?00X23`0280X23`00<0oh000:0Pl02P8?00602P8?000`3oP000X23`0:0Pl00:0:0P
l0@0oh001`2P8?020?n000030:0Pl020`0000?l000L00?l04?ooool000kooooo7000o`00?@3gl^h0
h]WB0<>bZ02OR7X0TW5N09A[E@2NKeD0ZWAJ0;5cFP2`L5D0]W=I0:i]D@2^KU<0/GEM0;R7M@2nU8H0
^9240;:<O`2^R7/0ZH5e0:AjK02SN6P0YWQX0:1aG`2QLEd0XW1I0:IdF`2TL5P0Yg5G0:Q^EP2ZKU@0
/WAM0;=aG02`K5T0VU5008U0<@1m=2D0MbdP06dP5P1W6@l0IaL>06TB2`1]3PX0LPH309LP6P3PI5`0
kViS0?]iJ`3dLEl0lViK0>mZF@3`Je`0jfIG0>iYFP3[IUL0kFUJ0>]YF`3ZJ5X0kF]M0>iZG@3_Jeh0
0`3]JE`0;P3^JUd0kf]N0>iYG@3aJf00lfYR0?E/I03`IEh0l6IL0?9UGP3`HeX0lVEL0>mRF03`HeT0
jfEI0>9XF@3FKf00cGmb0:=]H@1=;bL0@3@b03Da<00`;2/0<bl^02dY:00[9b@0:RHS02TU8P0/9RH0
:RDR02LR7`0[9R80;2@R02dU8`0/9b<0:RDQ02PS800S7a`09B4N02LS8P0Y9B@09b4S02/U:@0V82@0
C4M;0>GSi03Xj>P20>?Sh`0H0>;Th`3SiN@0h^;R0>?Sh`3Th^<0inGV0<2k^`2FSHh0VHn>09nDTP2G
S8P0VY>=09NDS`3JfMD0inSS0>7Qg`3Qh=h0hMgL0>CPg@3_k^T0/K>X08jDQP1[LfH0K>i[2000o`0J
oooooa`00?l00P2P8?080?n000030:0Pl03oP000oh0001<0oh0000<0d51h0:0Pl03oP0000P3oP007
0:0Pl0030?n0002P8?00X23`0280X23`00<0oh000:0Pl02P8?008P2P8?000`3@D7P0oh000?n00004
0?n000L0X23`0P3oP0000`2P8?00D91h003o0007003o013ooooo000>oooooal00?l004@0nOG/0>CJ
cP34]:@0[IR70;>JQP2jVhT0_9^:0<>PS@2nWXT0`:6=0=Rm[03hj=`0ooK]0?gcjP3hk^D0l^WP0?;U
g@3]h=P0jmgB0>[Jc@3Mbkd0ckb]0<>^W@2hXi00ZYAo0::7LP2ENF<0TG5L08iXE@2DIU@0VfID0:=X
F02WJ5L0ZfQH0:QSD`2QEDL0W4i109a:?P2RBSh0Zde30:a5?02fAS/0f6AG0=mWF@3UJe`0jFiL0>i`
G@3_L5l0l75P0?5bH@3dLV80mG=S0?9`H03_L5l0lW1R0?5_H@3cKf00kVYK0>eXF@3`Je`0kVYK0>eY
FP3/IeH0kVQI0>iVFP3bJEl0jV1F0>mUFP80l6=I02H0lF=I0>mQE`3bIUT0kV9E0>aXF@3PIUL0eg1Q
0<]mL02?ET/0CbXR04@`;@0k<2h0=2XX03D]:P0_:RL0;RTV02dY9P0`;2T0;2PW02TU900^:RL0;BPU
02`S900[8R<09b8O02dX9@0/9b@0:RDS02HR8@0V92D09bDV02LR9P0[92/071DL09:=T`3clO@0iNGU
0>?Sh`80i>CT01L0iNGU0>?Sh`3Ti>@0i>;S0>WWj031_[h0PG]k07eeL`1nMW<0PGUf07UfL@1SHUd0
g=gH0>GUh`3Rh^00hN3N0>;Ng@3YiN80jn_S0:2SV01RJUd0SYJ;07_mN`08003o01[ooooo7`00o`00
0`3oP000X23`0?n000080?n000030:0Pl03oP000X23`00H0X23`203oP0000`2P8?00oh000?n00002
0?n00080X23`1`3oP00n0:0Pl0030?n0002P8?00X23`00P0X23`00<0d51h0?n0003oP000103oP007
0:0Pl0040?n0002P8?00X23`083000P00?l04?ooool000kooooo8P00o`04083mN`80P?ej3`00o`00
@01ongL0NoMc07ObKP1dkVX0KnQT06GKE`1Jd4X0eLNn0=2m]03:]:T0aj^P0<:SU@30Vhd0a9R:0;f=
O@31R7X0`X9e0<=lKP35N6P0agAT0<M_G`39KU`0cFaK0=5/G03EJe/0e6UH0=QZFP3KJU/0ffYI0=e[
F@3QK5d0i6eM0>E]FP3UK5T0ifeK0>Y_G@3XK5/0k71O0>a^GP3]KUl0kViO0>][G@3]K5h0kV]N0?9^
H@3`JEd0l6MJ0>eTEP3ZHE80k6=D0>MSE03OI5D0g6mQ0<M^H01i<2@0F1dA04TP4@0l8100=Al@02`M
400T6a8071PB01PG4P0I6AH201TG600D01`J6P0M6AT07QTL028L7`0U7b808A/N01lH6P0S7Ql09B<U
02PW:`0/:S40:bP`038_=P1[J700g=WO0>?Qi@3Sh^@0i>;T0>KTi@3Vi>@20>GThP040>?Rh03QhMl0
h^?O0>;Rh080i>CR00@0iN?Q0>GShP3Sh]l0g]kL0P3QhMl0203Qh=h0hMoL0>OPg@3ckNP0V9B:06i_
I01lPGL0hnKP2@00o`0Jooooob800?l01P20`00?003o00030830001@T7P0D91h0080D91h0P20`000
0`3oP000d51h0=1@N0020=1@N0<0oh001@3@D7PR0:0Pl0040=1@N02P8?00X23`0:0Pl080d51h4`2P
8?000`3@D7P0X23`0:0Pl00F0:0Pl0040?n0003@D7P0d51h0=1@N0T00?l04?ooool000kooooo@`00
o`00=@3on_D0ooWe0?oim@3omo80oo?_0?o^j03jhmd0m]gF0?;Ec@3[cL<0g[Z`0=2UW037V900`926
0;n;OP2kQWP0]W]]0;AeIP2hM6L0]fmQ0;Y^GP2kKU`0_6]J0;m/G032JeX0`FID0<9UE034HE40b65B
0<]TE@3=HeD0bUm?0=5QD`3>GDd0dUi?0=9MC03EH4l0ef9@0=MRD@3BHDl0cV=A0;iMBP2UDCT0W5Dg
081:901^Bb40HDDM04lm6@1iL5<0PgiZ07ekK`1eM6l0P7ak0080NGEf01P0N7Ae07MbMP1]Jfh0MW9c
07mkO025PH80ViRJ0:6PYP1bLW`0BdeI04M;EP1:CUL0KG5j07AiO`1hOH<0SiBH09fPY@2`/KD0`<73
0<[:bP3JfML0jNST0>CSg`3Thmh20>GTh00>0>CUh03Si=h0h^?M0>?TgP3OhM`0hN?N0>3Qg03Qh=`0
hn3K0?7ZhP3Nf<`0@Sl`081nL@3Bdld:003o01[ooooo@`00o`040?n000@0X23`2P3oP00G0:0Pl0<0
oh000`2P8?0A0?n000H0X23`1@3oP00B0:0Pl0030?n0002P8?000?l000T00?l04?ooool000kooooo
C@00o`00E@20o7X0ooWc0?oflP3ol>X0oNWR0?WQe`3ef=00l]780?3;`P3^a[`0j;jb0>JhZ`3N[Z80
fjZL0=VSU`3DVXh0eIZ<0=:@P`3=Qg/0cHEi0<MmLP38O6l0aGMZ0;i_HP31Kf40_FYL0<A^G`2mIeP0
`6QJ0;YTE@2fHe<0/VEC0:iXC`2WJT/0`YI[0<FWM@30[7X0akZ>0>WP_`3[ilh0in?G0>WVh@3Zi^D0
i^7U0>GPi03WiNP0i^CY0>;Ph`3Th^D0inGV0<;0`@28R8T0>Ce0028W;@0_=S`0=d1503Y4AP12C4h0
B59D04aFF01=EeP0De]M055FF@1BF5P0D5AC071bK`3Si=l0k^gX0>KUh03Ti=d0i>?N0>CUg@3Si=`0
h>?J0>?Vg`3RiMh0hNCM0>3Sg03PhM/0inCM0>CPe`2SWi<0B4Df0::PU03fmO402P00o`0Jooooodd0
0?l000<0P<000?n0003oP0000`2P8?0<0?n000l0X23`1@3oP00<0:0Pl080oh007@2P8?00103oP000
X23`0?n0003oP00:003o013ooooo000>oooooeX00?l002<0ooWe0?ohm03on?@0ooSd0?o`k@3ojN@0
onKQ0?gQg@3lgm/0nM[E0?CEd03cd//0k/c30>c7_P3S_K@0h;Za0=F_YP3AZj00bJFI0<2OSP2YSGD0
[9Qd0<JiS@3Ab9d0X9]e0:JRQ@3Ge<40c<W00:JUX@2d/[<0gmgR0=7?e02`[[<0^;Fl0;jk`P020>OU
j00809ZHV@1dN7L0OhR504aGD`0c?c/0AE9;04EBB@16DdX204QECP0H04YFDP1?FUH0C5MC04UDD017
DT`0BE190:b^Z@3Bdld0b<W10<W;`@39b/80b<_00<[=`P39cl<0alg30<W?a@38cLH0a<W20<G8_`31
a;/0VibD07YjL02;Rh40dm;=2`00o`0JoooooeX00?l0103oP0050:0Pl140oh0000D0X23`0?n0003o
P000oh000:0Pl0040?n00080X23`00<0oh000=1@N02P8?003@2P8?000`3oP000X23`0?n0000?0?n0
00/00?l04?ooool000koooooJ@00o`007@3onoD00?l00?ojm03on_@0oo_a0?cci02m^9h0VYMh092?
L01QHDD0=cTS0:BVV02m`;L0@D=00411@`2PXJD0`<75030d=`11@TL0FeaP09bMW`2FV9L0O7im06aa
KP2h`K`0ZkB_08VDS02@W980TinE0080Wj^Q00/0X:^S0:bg/@2`^kD0[kZd0;O2_02lal40_lG10=7F
d03Oh]/0gn3J0>7RfP020>3SfP0:0>CWgP3Tj^00iNSQ0>O/i@3Zk>L0incV0>g`j@3`ln`0k_7Z0?Cg
l0d00?l06_oooomY003o00030?n00000o`00oh000080oh0000@0X23`0=1@N03oP000oh000P2P8?02
0?n00080X23`0P3oP0030:0Pl0<0oh0000<0X23`0?n0003oP0001P2P8?060?n000l0X23`00<0oh00
003o0000o`002`00o`0@ooooo`003_oooom_003o000C07clN03Mgm@0[;2Q08>:NP1HH540FVAI06Ea
I`0`>cD0<c`i051KE`32cLT0>DA003E1?`0mBDD0Ae9<04aED016C4P0XJFR0?GgmP0Z003o01[ooooo
K`00o`000`20`000X23`0?n000070:0Pl0030?n0002P8?00X23`00@0X23`00<0d51h0?n00000o`00
:@00o`0@ooooo`003_oooomb003o000>0>S_j03>eLh0^/Bl0:F`Z02EX9X0Qi:>07J1O@2OZZ@0F6EN
04]GD`18EDh0GFYS09jYX`3EfmL/003o01[oooooLP00o`020:0Pl0030?n0002P8?00X23`00T0X23`
;000o`0@ooooo`003_oooomi003o00050>c`k`3SjNL0f^3L0=;He03Jh=`0;P00o`0JooooogT00?l0
1@2P8?0^003o013ooooo000>oooooj`00?l06_oooon/003o013ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo000>oooooj`00?l06_oooon/003o013ooooo000>
oooooj`00?l06_oooon/003o013ooooo000>oooooc@00?l000T0mOGe0=cLfP2n_[`0UIFC07IfM029
RhH0][Rc0=OIeP1hn7L0K`00o`0Joooooc@00?l000<0oh000:0Pl03oP000103oP0000`2P8?00D91h
003o001^003o013ooooo000>oooooc000?l000T0k^k/0=?Bd02^[J/0QhJ405eLFP0n?cX092DP01hO
6P0L7AP00P0S9Ql0100j?3L0J6UT0:VZY03PhMa]003o01[ooooo<000o`00102P8?00oh000?n0003o
P0080:0Pl0030=1@N03oP000X23`06d00?l04?ooool000kooooo;`00o`004@3Ddm40GEaH03@c;`0O
7QX0920M01dL600M71L06aXE020O6P0P8A/08R<M01`M5@0K7QL07AlH028S7@1DEDl0a/O206`00?l0
6_ooool_003o0100X23`00<0oh00003o0000o`00JP00o`0@ooooo`003_ooool^003o000D0??bl01b
KV/08AhI02<R7@0U91l09bHQ02DT7`0R8A`08QlH02HS700Y9R408b0K02<R7@0P7a/092@O02<T7P0R
9Ah0?Clj0:NYYP3fn?EZ003o01[ooooo;P00o`000`2P8?00oh000:0Pl00?0:0Pl080oh00JP00o`0@
ooooo`003_ooool^003o000E0:FTX00_;2L09B8M02TV8@0V9B0092<N02TV8@0]:RD0=C0/03Xe<@0i
=300=C0/03Lb;P0f<Bh0:bPT02<R7@0V9b407R4J02DW8P1mOg`0j>[Y06T00?l06_ooool^003o0003
0?n0002P8?00X23`0100X23`00<0oh000:0Pl000o`00J000o`0@ooooo`003_ooool]003o000G0=3@
cP11@3`08b8M02LT7`0U8Qd08b0K02XW8P0h<bl0>cHb048j>013>cT0>C4_03`d<@13>cP0@SXg03lh
=@0_:RH0:BHQ01hM600N81/06Q`I07UkNP3emoH0J000o`0Jooooobd00?l000<0oh000:0Pl02P8?00
4P2P8?020?n006P00?l04?ooool000kooooo4@00o`00303Xf]T0dKnm0=S6a03MblT0iM?A0>[HeP3^
gm`0m^OT0?g^kP3omoD0ooKd0?ogm@l00?l000D0l?3^06a]J00M7QT08R4L02DT7`02024N6@0A03/f
<P0m>3@0=C0]03Ta;`0i<340<b/Y03L]:`0k<Bl0?cDc044h=P12?CT0?CPd02DT7`0M7QT06adH038d
<@3=clh0J000o`0Joooooa400?l000@0X23`0?n0003oP000oh001@2P8?030?n000l00?l000<0X23`
0?n0002P8?00502P8?000`3oP0000?l0003o001V003o013ooooo000>ooooo`l00?l003H0O>m_0;fN
VP1dA3h0IbhW06X]:@1[;BX0Kc<]06`b:`1a>C@0LSdf07m=B022E500OeI@085IE027HUh0Qf9O08eY
IP2;JFD0TG1[09AdKP2ING@0V7Yd09n1O02SQh<0YXb80:bFTP2_W9T0[Z6N0:RRX01_K6T0:bPU02HU
800U92008b0M01/I500a;bX0@Sdj02/W900_:bP0;BTV02`W900a;2P0=BhX038[9@0j<B`0>S8]03/g
;`0o>S@0?3/c02h^:@0R8ah08b@P06ATHP1^kVeW003o01[ooooo3`00o`000`1@T7P0X23`0:0Pl008
0:0Pl0`0d51h0`2P8?040=1@N1H0X23`00<0d51h052@N000o`00IP00o`0@ooooo`003_ooool>003o
000g0?[Vi@2ML6d0MC4^08Lf<`27;B`0QRdY08<Z9P21:BL0PB`Y07l/:01j:bH0NRh[07Xg;`1k?3D0
LCH`06/b:`1X<B`0LC`f06Lb;01]>300KC/b0792>01_?SL0K3/d0750>@1dACl0IcXd05H]9`119b00
4`D2024I5P0^:BH09B4N02HR7`0R7AX08QXG03Xb;`16?3/09QhL03Ha;@0a;2P09b@O02TV8@0Z9B40
;BDR03<Y9`0g;RX0>3<]02dX900o?3L0@40h02PY8`0S8Qd08B0L096AS`1W003o01[ooooo3P00o`00
0`2P8?00oh000:0Pl0080?n000030=1@N03oP000X23`02P0X23`00<0oh00003o0000o`00I@00o`0@
ooooo`003_ooool=003o000i0?o_k@2XPX40L2l]08Lb;`28:BL0S2PX09H`;P299B<0SR`[08la;`28
;BX0R2h]088_;01j;bT0O3H^07Ld;01Y:R<0MCTa07Xo=`1_=2`0L3L^06Tc:@1Y=BX0KSL`070i<P1h
@CX0SeI?07a3?01R;BL0FcD^01l:1@0W71P0;RHS02HQ7P0X8b009B0M028H5P0e:bT0BChl02lU8`0h
<B/0>C@^02TT7P0W8Qh09R4M02/S800^9R@0=BdY03Td;P0V8Ad0=34/04A4?00`<2P08b8M01lN6P12
@T00f=SF06H00?l06_ooool=003o00030:0Pl03oP000X23`00`0oh00:P2P8?1V003o013ooooo000>
ooooo``00?l003X0ooKe0;bFT`1Y;RX0RCPe09/l>P2cBdX0aUaL09de=02C;B/0V3He09hn?`2I>c/0
W49108hi=P20<B`0OcH_08a7@01c<bX0O40h08A9@@1oASl0MSlh07a7?`1d@ST0LC`f06`g<@1_=C40
MCPc07Tj=@1]<2/0L40h02hA2`0]6aL0;b@P02hV8`0Z9B809b8O02LM6`0_9R40A3Te040e;`0h;bP0
>34Y030Y8`0Y8Ah0:b<P02HN700Z8Ql0<BXU04Dn>00Z9B40>3<_04]8@`0_;RT09B@P02LV8P0V9R@0
P81nIP00o`0Jooooo``00?l00P3oP0000`2P8?00oh000?n0000<0?n000l0X23`00<0oh000:0Pl02P
8?005P2P8?000`3oP0000?l0003o001T003o013ooooo000>ooooo``00?l001@0aZZW06H_:P1c9B40
XD=10;M?CP2lDU80^Dm?0:0h=`2YAD<0YTA509@d=@2D=SH0T3Dd098j>026=c80O34[07@_:01e=Rl0
JRlY070i<P80NTDo02P0Q59;085?B01b?CL0MChi07@g=01a;BX0MRl[07D^:P23ACh0C1lJ03XI500f
7QX0=BHS02hS8@0[8b00;B<Q02/R7@0`9b80?3</04@k=00n=Bh0<BXT02lX8P0b:RL09alL02<K600i
<R`0@Sdg02lZ9P12?cX0@Chi02XY900T8al0:BPT02XY9`0_;R`0L6a]0:JPX03?bLT0l>_XHP00o`0J
ooooo``00?l000<0oh000:0Pl02P8?003@3oP00>0:0Pl0030=1@N02P8?00X23`01T0X23`0`3oP000
0`2P8?000?l0003o001P003o013ooooo000>ooooo`/00?l002L0d[Vd06Tl=P1Y81X0RC0/0:]5@@2Z
@Ch0Z40m0:<m>@2F=340SRl[08X/;028:RX0RB/Y08X_;02<<S40QcHb06dT7P2:BD<0VUmI07Dn>@1i
AT80QEA?08UHD`2:Ee<0TUeI08M@C@2;Cdh0T4m=08@j>@21<2d0Pc0/0991?@21?SP0EQlJ03/B300j
7AL0=B8N02hS7`0[8Al00P0Z8ad06P0[91h0@CPc04Y1?019@3/0?C@_03df<00c;2H0<RdW03/f<00m
>S<0@Slj03hk=P0d<2d0:RTU02DT8P0Z:BL092<Q020J6P0N51D07@d@048^;`1aFed0Qg5c0;JTY03I
bLT0N_AdGP00o`0Jooooo`/00?l000<0oh000:0Pl02P8?003@3oP0000`2P8?00oh000?n000050:0P
l0030?n0002P8?00X23`00H0oh000`2P8?000`3oP000X23`0:0Pl00F0:0Pl0D0oh0000<0D91h003o
0000o`00G000o`0@ooooo`003_ooool:003o000^0>OEd@1bBD<0Gb0I07dX8`2K=cD0YShk0:8j=`2L
=S80Tc0[08X[9`249R@0R2XZ08/[;02<;B/0Rb`Z08P[:`22;BP0K24K099AB`35RhL0ZgI`09ASGP2B
HEd0Tf9N0:=`K02UL6`0VV9Q09=GE`2DDU<0QS`m08Xf=P26;2/0UcTg0:59A`2;?CT0GR8J04PI4`0m
6QH0=QhJ02lP7@0^9B00:B8L02/T7P0]91l0>2lZ04Dl=`<0Ad0j00D0Ad8l04A0>P13@3T0@d0k02l^
:@0202XY9@0?02/Z:00V8R409QdN02LK7@0S3Q<09PT>03lO8P1N?3d0EcLh04X/;01<<bl0MfAN0;R[
X`3Kd<X0mNcW05/00?l06_ooool:003o00<0X23`3P3oP0000`2P8?00oh000?n000070?n000030:0P
l03oP000oh0000D0oh00802P8?030?n000030:0Pl000o`000?l005T00?l04?ooool000kooooo2P00
o`00B`2aUI40HR/V074T7P2A<S00WcTg0:<m>`2O>CL0Tbl]08l]:P2?;B`0SR`[08`Z:`2=:B/0TRX[
08`T9@2?:RX0SS<^080`:@1]:240RTe80;^6OP2lRX<0U65M08UFD`2`OGT0W6MS0:YbL@2JGUh0Od52
06l[;01e9RT0O2HW09Tg=`2[AD<0ZT]709]3?`1f;BL0EA/G04DI5P0l7Q`0=b@P03<U8P0^8b40;28P
038X9P0/9240<RdY034/:00k=S80@3/g03/g<P0f<bh0;2/V02XY900Y:2@09bHR02/V8`0Y7ah0:QXK
03@K7`0]31<0>A0H04`O901O<SD0SVAU095[J01mFe80GSlb04db8@1K@C00KeQ809EoLP31[jD0hm;:
0?c_j@1G003o01[ooooo2P00o`000`3oP000X23`0:0Pl00?0?n00080X23`0`3oP0000`2P8?00oh00
0?n000020?n000@0X23`103oP0040:0Pl0030?n0002P8?00X23`00l0X23`00<0oh000:0Pl02P8?00
102P8?000`3oP000X23`0:0Pl0020:0Pl0<0oh000P2P8?1G003o013ooooo000>ooooo`T00?l00340
nnWU08=NF01U8Q`0Q2/W09li=`2R>3P0V30_09dg=@2I<c40UBl]090Z:02<92D0U2X/09LZ;@2F:2T0
URDW09P/;02B;bX0RS4[07`a:`21@3X0SEI?0;b:P`37U940QeAA0:9_K031SX/0]Wio09YOH@2VJV`0
ZVY[0:MOHP2B@TD0S3<d09dm?P2G>CT0Tc/i09Q:B022@Cl0G2TV03/E500m8Ah0@2PX03XV9`0c8b<0
<bDT02dR800a9bD0=B/Y0080;bDS01d0<bXW03<[:00Z9B40;BPU02hV900Z81l0;AdN02`F600h6Ah0
>10H03@53@1=6R40FRD]05`X;01a@D40VVmY0:^3N@2IMF40T75E089UA`1^DC<0FSlT050f7`1G?RX0
KUU809>1M@2o/JP0h]G=0?[_j`1C003o01[ooooo2@00o`030:0Pl180oh0000@0X23`0?n0003oP000
X23`1P3oP0000`2P8?00oh000?n000050?n000@0X23`0P3oP00<0:0Pl0030?n0002P8?00X23`00H0
X23`103oP0050:0Pl0<0oh000P2P8?1C003o013ooooo000>ooooo`T00?l005D0fl:m06Df<01`8Qh0
T34]0:4h=@2U=cH0W30`09T_;`2L<2h0V2XY09LY:02J:RT0X2`]0:</;P2R:bd0WRLY0:D_<@2Q<c80
RbPS09E0>`3]YZ00b8f7095OF03BWi`0ZgUh070n?`3KYjT0e9fR06he>`2gOh80finQ0<R7R`2aKg40
VUMH0;UcM@3ITiD0_Wam08i@D@1i?ch0Ld5006Dm?@199bH0CR`]04PX:`15:2X0@bT/03dW:@0k9bT0
=B<S03@R8P0c8b<0=BDV038R8`0^7Ql0<AhR034L8@0f6b00>A@K03T>5@113QD0@``B05HJ8P1[;SH0
J2`d06D^<`1T<380MTI20:9jKP2KNV40TgMB09R0DP2JOe00WH1D09EhCP20HS`0Ke4_05dn8P1C=Ad0
FC`Z079HB@2GPGH0`k6W0>?Dc@3jknT0ooSe04h00?l06_ooool9003o00030?n0002P8?00X23`0140
oh0000<0X23`0?n0003oP0000P3oP000102P8?00oh000?n0002P8?030?n000050:0Pl03@D7P0X23`
0:0Pl03oP0002@2P8?050?n000030=1@N03oP000oh000080oh002`2P8?070?n000D0X23`0`3oP002
0:0Pl0030?n00000o`000?l004`00?l04?ooool000kooooo2@00o`003@2^SHP0H2HR07dZ9P2L>3H0
XcLe0:4a<02I:b`0VBPZ09dZ;@2Q;Bh0Z3@e0:@];`2V;S000P2Y;S00B02Z;c40[C<f0:Lc=02O<C00
Q28Q0;QUH@3b[JP0cI:>0:1YIP3GY:<0TV1S0=JSZ03a_<80JcHl09=JH03OY:P0/7=h0;^0PP2PJF/0
l;Vl0?S1a03`_;h0gJ^/095QH@3<X9l0l<[90;bHV01M=ST0EC4c050]<@1082D0B2P]058b=`159BP0
@28T03hQ8`0j82@0>ahS03XK8`0d4a`0>aDP04<E801841/0C0dH05<@6@1T8BX0Lc0i06d^=P29CED0
L3Tn06Te=`1G9b<0Ne=90:N7K`2>M4l0SGE5095jA02EO4@0WH9;0:63C`2SQ5D0WGaA09=aB`24Hd80
JT/^05Tm9@1:<A/0E3l/075PD02DQ7L0dlNo0?[bkd`00?l06_ooool9003o00030?n0002P8?00oh00
0100oh000`2P8?060?n00080X23`0`3oP0000`3@D7P0oh000?n000060?n001X0X23`2P3oP0040:0P
l0<0oh0000<0d51h0:0Pl000o`00B`00o`0@ooooo`003_ooool8003o001L07ceM022FeH0Hb@O08Pb
<@2R>c`0XcHi09d/;P2I9R/0X2`_0;U2AP2i@4D0_DA90;i6B02g?d40/CTk0:Ta<`2[<cD0]CXn0;8g
>P2^=cT0Y34d08`V902TC4X0jj:L0<b<RP30R8L0eJ>V0;b;S`3[^L80TUmX05hW;@3;TYP0Zg1f0<bD
U`2JIfT0l;k10>Zi_02EIfT0_YBE0>_3``3ie]@0n=WG0>S:b025IFH0d;2c0=Rh_@2XQH/0G3<k05`]
=@1P;cD0EbT/04LN8P0o5ah0Bb0Z04PH9P143al0DAHX05TF9`1X6b/0NBHf07h^>@1m<C/0N3Dl070e
>`2WLWP0TF1T07M6B@1Y>c/0GC@^09QfI02VRfd0T7U?08]e@`2ANd80UX1409An@P2EOD40VGi70::7
DP2WSEX0XhUH0::7FP2BNE00PFM206iD<`1H?R<0E3`W071MC`2QShD0bKZc0>SJe`3nm?98003o01[o
oooo2000o`000`1@T7P0X23`0:0Pl00D0?n000030:0Pl03oP000oh0000@0oh0000D0X23`0?n0003o
P000oh000=1@N0080?n000040:0Pl03oP000oh000?n000d0X23`0P3oP0020:0Pl080oh000`2P8?00
0`3@D7P0oh000?n0000<0?n00080X23`00H0d51h0?n0003oP000oh000:0Pl03oP018003o013ooooo
000>ooooo`P00?l00600KN=Q06/l=P1b:bL0U3Th09dd>02M;c80ZSTm09/Z;P2/>d40]dQ>0:Th?P2k
B4d0a55F0=YVJ@3VLW<0hfa`0=9IGP3@EEX0c4mE0<=6BP2m@TD0]D5209li=`2NAD40eHN30>NVY03k
aLD0a9>G0:9cN@3]^l@0[7V007]4BP2eO8<0hjZ`0;N1P`3JZJ`0k/;30=BZZ`25Geh0`9jL0?oSh@3Y
cLX0WH5n08EYJ03be=H0n=_O0?gLh`3R^L40UfQ`07U6C@1_?T80Vg5e0;67T01R=440PdiP0<66W02S
HWP0_GB808ljC`2L@E<0V41>08He?P23?480ZFaa0:QaM02SLG@0UVIV09EWI`2HK6T0R6=H0;VJQ@2U
RfX0S7E;081Y=`2:M3/0TWU009Il@@2KOT@0Vgi609j4B`2IOdH0WX=<0:F:E@2ZSU`0ZhmP0:N:H029
JdP0ID/`05]2;01==R@0FDHh06mMD`2NT8L0bKnf0>SMe`3nmO14003o01[ooooo2000o`000`20`000
X23`0:0Pl00:0?n000@0X23`00<0d51h0?n0003oP000103oP0000`2P8?00oh000?n000040?n00004
0:0Pl03oP000oh000=1@N0<0oh0000<0X23`0?n0002P8?00103oP000102P8?00oh000?n0003oP002
0:0Pl080oh000P2P8?000`3oP000X23`0:0Pl00;0?n000030=1@N03oP000oh0000h0oh0000<0d51h
0:0Pl02P8?001@3oP0000`2P8?00oh00003o0013003o013ooooo000>ooooo`P00?l005@0ElQ706/`
;025<Bl0VcLi09ha=02M;S@0YSLm09dd>02eDUD0_65V0;QMHP2_C540ZdA70:i1A02nD540eV=X0=UR
J03VK780hfI/0=UJH@3FFEd0dUMJ0<IBD`2fCDX0YDI40;m^J`3a/K40ol_=09QWJP2FJF`0mlS>0=:O
Y02CFV40Y6E]0:=SJ@37UIP0j/310<>MW03:ZJ@0UgQc0>c@c03niN40glO50:V<SP3Wb/h0n]oT0;JI
WP3M_/@0i<7706E1A@2^RXh0d;2e0>W9dP2lV:H0T6=g0>jjd@3LX[X0dhnV0<5_QP2PAe/0YdaM088/
=`2`Hf/0cXb>0:AXJ02^MWD0X6YZ09UWIP2SLfl0VFeV0:V3MP2iVH@0/I=g07eQ?01H>a40LDlR085M
;@2<HcD0Ufln09ijB02OOT/0Wh1:09j1B@2NQ4/209n6C@0>0:F=E`2USEd0X8MN09EkF01kH4<0HTH^
04`a7017;A`0Ecd^07=MD02PS8<0c;^c0>[Me`3mm>m0003o01[ooooo2000o`000`20`000X23`0?n0
00060?n000030:0Pl03oP000oh0000<0oh001`2P8?030?n000030:0Pl03oP000oh0000@0oh0000<0
X23`0?n0003@D7P01P3oP0001@2P8?00oh000?n0003oP000X23`00<0oh0000<0X23`0?n0003oP000
1P3oP0001@2P8?00oh000?n0003oP000X23`00X0oh001@2P8?0=0?n000@0X23`0`3oP0000`2P8?00
oh00003o000o003o013ooooo000>ooooo`P00?l006P0_j:P07L`;P2D=SH0VRd`0:hk@02f@DL0_TmE
0:@m@@2ZCU40kYnT0?nj_`3[TYH0fgb00<eZK@2kFEX0ZDA80:Y1AP2dAD/0a55H0<eHH03IHVP0fV5V
0=YSI@3EHf<0dFES0;]LFP2nKVd0mk>b0?^o_`2<EUH0/Geo0?oAe@3d_L<0VEaS08U7C02<E5L0m/S8
0;^ETP2aTXd0^Y^F0;>GT`3ihMd0l][H0>74aP3D]k/0on;V0<nb]P2XRhl0lmCI09UkO@3RaLL0onGZ
0>K9dP3og^`0aifa0;:5VP3HY;/0jZo50>JN]02NC680Ye1Q08hhA@2SDU/0b7f209eIFP2hN7P0/7=b
0:ibL@2[LFl0WFMR07i>A02YOg40c:ND0:n;L@1kF3P0JD4M07a@:@1oDRT0P54W07mD:@27GS00Tfdl
09]g@`2SQ4d0Y8M=09f3AP2SRdd0XXaB0:ZAF`2[TF00Z8eR0:B8H@2GNUX0PVA806U;<@1F>R@0AB`F
03dV501D@C80MF=G09n@R@39_[P0jN3K07ojNC`00?l06_ooool8003o0080X23`1`3oP0050:0Pl0D0
oh001P2P8?001@3oP000X23`0?n0003oP000X23`00<0oh0000<0X23`0?n0002P8?001@3oP0020:0P
l080oh0000<0X23`0?n0003oP0000`3oP0000`2P8?00oh000?n000040?n000030:0Pl03oP000oh00
0080oh000P2P8?050?n000040:0Pl03oP000oh000?n000L0X23`303oP0050:0Pl0@0oh0000<0X23`
08300000o`00>`00o`0@ooooo`003_ooool8003o001[0:^2P023;S40WS@h0:@_=@2i?T<0^Sm40;Q3
B@2`ATX0UCTn0=V<TP3fZk00`6U_0<EZK`3IPh@0fh^<0>>GV`3@PHH0_F=Z0:95C@2N?D@0Zd990;a=
E035E5P0aeAG0=1NGP3BI6<0df]Z0=MiM`3jYZ@0gY:B0:eVI03CUYD0omWL0?c;c`2]L7D0R4Q90;Z0
O`3cb<80Xh1j0<^/Y`2lX9`0h/[80=:j^P3I^kd0i/K90>C4a`3ogn<0g[^o0?3=d@3E]kL0ck:d0?oW
jP33YJ/0omcV0=6[^P2]Q9H0^XnR0=FT]`3l`MD0/fj108PiC02<>4P0QS8o090oAP26=cX0SCi10:aP
HP2_IFH0/fUZ0;]eL@2SHU`0NT4f0;j?O`39WhT0Z81V07eE<P1`AR00Pe<[08MF;P24Db/0QeH^08A@
:`26EBd0R5/a09M^@02/R5@0ZHaA0:F=C`2TSe00XXiA0:2=E@2KRUH0X8]N0:6;HP2SRfD0WXIP09Em
F@1iHCl0ITd^04hd6@0m8Pd0?R@C05<m;`2APGL0d<Jm0>gTg@3on_@03`00o`003P3Yj>@0e=??0<?2
_P2WYZ80RhZ806a[I`1UHF00Hf9N06UXI01UI5l0HV=M07IgL@2g^;<0jNWW7000o`0Jooooo`P00?l0
00<0d51h0?n0003oP0001P3oP0080:0Pl0030=1@N03oP000oh0000@0oh001`2P8?0D0?n000030:0P
l03oP000oh0000D0oh0000<0X23`0?n0003oP000103oP0060:0Pl0<0oh002@2P8?0?0?n000<0X23`
0`3oP0000`2P8?00oh00003o000>003o0080X23`203oP000102P8?00oh000?n0002P8?0L003o013o
oooo000>ooooo`P00?l006h0UV=R08l`=02T<CP0]SY20<90B02d<cP0^Ci30;54B@2H?3l0hIZN0>6P
Y02?AdX0YUaM095;B`2CEUD0ol[:0<jFU`3<RX`0ei2F0>VLY03>Lg`0bVE]0;]>E02eA4P0_D];0;Q6
A@31Cdh0aEUG0<aXJ039Jf/0aVi/0:iPGP3NXjD0omWK0=jSY@2/HV<0XEYH0=VOV`3V]k40f[F_0>S9
aP30XZ00jlg=0;VGV03T`<@0e:fb0=2VZP3d`LH0lKg10?g<c`3]_l40omSI0;68R`3O][h0h;K00:=i
Q@3fc=X0h[C10=bW]`3LWjl0VE9T07ha@@1k;CX0ORhg07TZ;`1k;2l0TD5408<a=@2MBdd0Z5=E0:9D
D01_:R<0S5960<>DPP37WH@0Y7eL07iH<@1cBAl0MdXP07U:801nCBD0QDl[08E?;@24Cbd0N4HQ081@
:02ILD40ZHYA0:Z@D`2TT5<0XiAI0:JKH`2QUF<0WI1S09V:G`2NSF80WX]Q09j8G`2RRV@0VX1M08]a
D01hGD00IT`c03hW4`0f9A<0D40`07Y/G`2XVi80dlW00>oVh@X00?l00180MOEd07AeL018Ad80<S4/
02HU8@0_:bP0<Rh[030/:@0a;2T0>CDb03Tf<@0g=2l0<S8Z02`/900_;RT0CDa8092@SP3De=8J003o
01[ooooo2000o`000`3@D7P0oh000?n000060?n000060:0Pl03oP000oh000:0Pl03oP000X23`0P3o
P0000`3@D7P0X23`0:0Pl0020:0Pl0H0oh00102P8?030?n00080X23`3`3oP0000`3@D7P0oh000?n0
00090?n000030:0Pl03oP000oh0000@0oh000P2P8?030?n000X0X23`3`3oP0020:0Pl0030=1@N03o
P000oh0000<0oh0000<0X23`003o0000o`002000o`000`1@T7P0oh000:0Pl00=0:0Pl0030?n0002P
8?000?l001T00?l04?ooool000kooooo1`00o`00M03iinD0Q4Q609Pc=`2a>T00_d170<0j@`2l=Sl0
`D990;M9C029<C00kk>b0?74`@2[NWH0ODY6064b;037W9D0omgG0>c9``1fBDP0g[6d0?oCf@3ER980
i8NA0?::T@3_PXD0hWIf0=9TH`36F5L0_4i=0;e@D`2oEEL0b61Q0:e=CP2C@D<0j:2S0?k4a`3COgl0
aVi/0;9SGP3GU8`0o/_70?oId`33W9L0dZZX0>Fm_P2dRXh0j[g40<:;T@3ISYD0i8nF0>ZEVP3IQhT0
chF40>NYZ030S8h0nl[@0;B5S@36U9l0m/;>0;j8U@3IXJ`0iZZf0:MYM01b<c`0Xf9Z0:]YK@2CC580
Nbhd08<b>02==S`0TC@h090f=P28=c@0L2`S099MC@3@YXh0^iQh0:61F02>Kd00QVDb07aH9P1lE2<0
MTLM07E17022BRT0QDX/0896:P20B2L0S5dc09ihA`2ZSeX0Xi9L0:nUL02SWFd0UI9W09ZFL02LUW80
W9A_09ZAJP2LSVL0W8eT09f;H`2PSFD0WhaT08YdC`1VCbl0D3TJ04D]4@0h7`T0>b@B05Q2=01hIUX0
ZIZC0=;7`@3^in40o?Wd1@00o`002@15aD<06AXD01dL5`0S81/0:2DP03/f<P0n>CH0>SDb03lg=002
04Lo?00804Dm>P10>cD0?3La03/h<@0a;RT07A`G034`:`31`[dI003o01[ooooo1`00o`000`2P8?00
d51h0?n0000:0?n00080X23`0`3oP0000`2P8?00oh000?n000060:0Pl0@0oh0000D0X23`0?n0003o
P000X23`0?n000030:0Pl0T0oh001@2P8?0:0?n000<0X23`1`3oP0000`2P8?00oh000?n000030?n0
00X0X23`4P3oP0030:0Pl0@0oh0000<0X23`0?n00000o`001000o`000`20`000X23`0:0Pl00?0:0P
l0030?n00000o`000?l001L00?l04?ooool000kooooo1`00o`00M`3La<80OSXg0:4g>`2g?TD0`DA<
0;/lA@2o@4T0_DI<0;A=D01d9B40dZ2I0?_Gb`3nfLT0_9N50:N2K`3cdk`0_J6;0?CH`P2nWXd0mmK?
0?oIf032Nh<0ZTmH0<]PJ03HIF`0iG9e0>mlO`3ePH80lWio0>IbM@3HI6L0aeAG0;]?C`2R?T00W4A3
0>:CU@3=KFh0dFe[0=MhM03@OGL0gIZD0?o7``3JYJ40TUmL0>:b/P3M[k40n<O=0>^^]P2kI6d0aUiW
0<EJH02nEET0XTA40>2?S`3SWj00iJNZ0>R[/02LGFD0iZN_0<64S02:CeD0ijZa0<J9T02YJg00fifR
0=fOXP3BTID0a7n408m2BP25;SH0T30h090`=02?=CD0Nb`W06l_9@37Uh<0g[VL0;VLM02VRUX0UGY5
07]L9P2@JST0UfPl091J=025B2/0P3`U08U0;`28@Bh0O3lS07Q47`2@JCh0XXYJ0:ZLJ`2MVFX0J6To
06=U@01jNeT0RXYX09RELP2KUG40W9A]0:6EK@2NTFL0VHYO09j:H02BNe80TgM@08MYA@1dDc@0HD8V
05@f7P0k80/0;1D503XW6@1DA3L0MVYN0:VPU`3@c<<0kncU00800?l001<0L75/01/J5@0^:bH09b@O
03Td<015@3`0?3@b03Ta;P0l=340>c<`04i4@P1=A3l0>c8]03dd;@13?3H0@c`d03@a:00L7180G5eF
01T00?l06_ooool7003o00030?n0003@D7P0oh0000H0oh0000<0X23`0?n0003oP0001@3oP0001P2P
8?00oh000?n0003oP000X23`0?n000P0X23`103oP0050:0Pl0P0oh000P2P8?030?n000050:0Pl03o
P000oh000?n0002P8?000P3oP0000`2P8?00oh000?n000040?n000030:0Pl03oP000oh0000@0oh00
00<0X23`0?n0003oP0000`3oP0000`2P8?00oh000?n000020:0Pl0<0oh000P2P8?040?n00080X23`
2`3oP0060:0Pl0D0oh0000@0X23`003o0000o`00d51h4@2P8?000`3@D7P00?l0003o000G003o013o
oooo000>ooooo`H00?l001/0OOEd0:5mN`28=cH0/4540;HoA@2c?d@0[Cm40:i:CP2OATT0XEAB070c
:@3>Xi40e;2D0<:MM`3S_Xh0j<B=0<^XK@3=ZVd0cjea0>;4S`2aTFd0l<F_0>j/Y`2[DUH0aUAO0<m@
G03?CUL00P3CD5P0H`3HEed0h61V0>=UJ@3TJVd0iFm`0>EbLP3HJVX0e6]Z0=1UIP3@IFD0`eaK0;aL
F@2`G5T0]f]X0;UcL@2cM740/7Ac0<N?T03``<<0olO<0==jP`3:GVL0dEiU0=1MHP38G5h0e79c0<9W
J02iHV@0cWUm0:iGG02YDeP0bGYo0<EiO03<Oh80jYfP0;=UJ02iKW00eiBD091BDP2iO840hIjV09E5
C`2XB580TBXa09<]<P2=;S00NbTV07Ld:P2aOVX0cJJ90;NEL02/S600T6i106@i3@1`>a@0QDHU09I=
=02@@2h0ORPN08`e;@2:=b`0PCPW07/n901gBRL0PVHj09^;G`2LV6X0JVe404YA:`1<DC40HfI:07Eb
F01fL5H0OgEI08EgFP2:OEd0TH9N09N3F`2GOE@0Q6Dm07iM=01nG3<0NeXc08=R?@1cDc40J4TY0654
901F?Al0BCDI04Lh8016?2P0CdXk05iID00Z:2409B@M02PT800Z9B40B4<m03dh<P0203<[:00=03<[
9`0c:RD0D4I204]0?00d:B<0>BlW04<f<010=Rd0AShd044m<P0_;B@0MWMa063PG`0G003o01[ooooo
1P00o`000`1@T7P0d51h0>QX?0060?n000030=1@N02P8?00oh0000X0oh0000@0d51h0?n0003oP000
oh00103@D7P50:0Pl0H0d51h00<0oh000:0Pl02P8?001@3oP0040:0Pl0030?n0002P8?00d51h0080
X23`0P3oP0000`3@D7P0X23`0:0Pl0020:0Pl0050=1@N03oP000d51h0?n0003@D7P01@3oP0000`3@
D7P0X23`0=1@N0030?n000030=1@N02P8?00X23`0080d51h00<0oh000=1@N03oP0000P3oP0000`3@
D7P0X23`0=1@N0020?n000040=1@N02P8?00X23`0:0Pl0P0oh00202P8?00103@D7P0oh000=1@N02P
8?020=1@N1<0X23`00<0d51h08300000o`005P00o`0@ooooo`003_ooool6003o001k0=[5`P1gAdD0
TSHg0;Q1A`2e?4<0YSDi09Ti>P3]Xj00olc40?Bo/@3/_:D0m<RU0<BJJ03DZ6T0kKmd0>BdH03N[5<0
hKAG0?;:J`3=[ED0bjiX0<VXL`3oe[X0Y6II08`h=P2O?TD0ZD5<0;A4DP35BeP0d4eK0=E=F@3EC5@0
eTeD0=9;D@3;B4d0d59E0<mMG03?JfT0b6m[0;Y[I02mNW80]Wef0;62O02_QX80^Xj;0<RFU`2bMg/0
YF=W0=N6S032GFD0a5=I0<I?E@31C580[TA60<=/JP2iLVh0]G5`0;1/K@2cJ6`0]fQ]0;=NH`2XDEL0
_F9W0;5GF@2_FEX0P30a08U3@`2mOh00e9VO0?o1b@2XG6P0U3A009d^=`2O;CL0V2T`09@[;`25:RL0
JR4H0:E/F`3J[YD0]91^0:b9H`2NM4`0K3PC07Lf6029>bD0RS8T08h_:@2A;bh0TC8`08hd;028>B`0
NcTS06Hc501T@Q`0SGY?0:bUM`1oP5@0@40J05=@<@2QUgh0Th5[07YOC026JU@0Mea106QA;`1dHCL0
O6Ll07eX>`22K3d0OFDg085V>@2CMdP0NEX/071A8`1hFB/0OV8c061:6`1UDRP0M6E405M==00Q6@`0
8A/E00809b8N01<08QXG04<n>00i=2h081/G024L600T7aT0=RlY03/c<00k<Bl0<BPS02hU800c:2@0
>2lX03/d;00j=Rd0=cD/01`O5P1KGEP0l_;`01H00?l06_ooool6003o00030?n0002P8?00oh0000@0
oh0000<0X23`0?n0003oP000503oP0030:0Pl0<0oh001@2P8?060?n00080X23`1@3oP0000`3@D7P0
X23`0:0Pl0040:0Pl0030?n0002P8?00oh0000H0oh0000<0X23`0?n0003oP000103oP0000`2P8?00
oh000?n000030?n00080X23`203oP0020:0Pl0<0oh000P2P8?020?n000030:0Pl03oP000X23`00P0
oh00102P8?030?n001P0X23`5P00o`0@ooooo`003_ooool6003o002@0;6CT@1`>3L0VSLj0;/oA`2f
>Cl0]D95098`;`2@BD<0n/Bh0=FVTP2lTG40fjn00<^MH@3W]fl0gZaG0=bZB`3:VC80_90U0=bcA`3C
/TX0hlE]0;FGC`3ofZT0k/2O0=FJR03;QWl0^faa0;YNJ`36EfL0b4YH0==;E`3EB540e4U@0=A=D`3?
CU80b55C0;mJF@2UE500VUM?0:UcJ@30U8T0^IN>0;^NUP2cVYD0ZXf90:j8Q`2mRhh0_7]o0:eKH@32
GF<0`E1F0<9;D@30C4l0[dE70:QEDP2fNW80[GQd0:QgL`2[Lg@0[g5d0;efNP2kL7@0^FQ^0:iNH@2Y
GEl0NC<e09iRHP2XL7<0/7Ek0?jma@3KSiT0XCm;0:Te@02S:cD0Y2`e09dZ;`2H<340NR8N07<]8`31
RGP0fjnF0;N@K`2_Qf<0YG=@06lb4`1h;AH0S3TY090c:`2?<2d0SS0^094h<027=BT0PS/W07Dm8P1H
<0d0HDPO09b>G@2[YG<0L6e003`h4P1^HdL0Z9=n07MHAP1U@Rh0PEe507QI=`1_ERd0ITlS06eH:@1b
GBh0MV0_07iX=`2:Ld40TgU608ic?P27K3L0QVdg065:5P1OBQ/0P75806iSA@0W7Pd091`D02/V8P0V
7Q/09alL03H_:@15@3X0;bXV024L5P0U81X0;bXT03df<00k=2h0=2`Y02@M5`0/8ah0;B@O03Tb:P0i
=B`0?Sde01hQ6013ASl0iNGS5P00o`0Jooooo`H00?l000<0oh000:0Pl03oP0005P3oP0020:0Pl0H0
oh0000<0X23`0?n0003oP0000P3oP0000`2P8?00oh000?n0000=0?n000030=1@N03oP000oh0000<0
oh001@2P8?050?n000030:0Pl03oP000oh0000@0oh000P2P8?050?n00080X23`1`3oP0020:0Pl0@0
oh0000<0X23`0?n0003oP000102P8?0?0?n001L0X23`5P00o`0@ooooo`003_ooool5003o002A0?O/
jP2?JFP0MSHf0:<j?`2c=3/0^3Ll0;i3AP2aAdL0P2dY0:a^H@3ba:`0bZ=l0>JkQP3^_W`0kl1b0;b=
=@2eRBH0aI``0=:/?@35XRh0]I<P0>g<I@39Ydh0e[AZ0>C0Q03`aY`0l/J]0?k<a@3obm80l8jK0<17
EP3CC5X0e4QA0=A;DP3>CE40b5EH0;]IF02NEe40Y7=/0;ZDR`2kWI<0[iN=0:bHS`2cX9T0YIB<09f:
Q02QR8@0Yh>30<:>TP33O880^EiU0<5FG02mB4h0`DY>0<9AD`2H@C`0ZViV0:5dKP2GM6h0V7Id09]g
M`2OMgP0YWYk0:mmP02/NW/0Y79e09ETI`3aalT0m<O<09=GG`2hLWX0lj>/0;aGH02`>440ZC0g0:T^
<`2W;S<0Wbh`09<]:`1j8Qh0Qd<h0=nWUP3DZ8l0/XUY0;65H02PK4L0JR/<07hc7029=RH0RS<Y088^
901m;b80Mc0L07Hf6`1e@240IC`N048T002;NTH0YYaQ0:^XL@1MFb/0?C@C089bF@2`UH80IT<_07M>
>027GCh0ME8Z06935`1K@140IdlO058l2`1F@Q00HdlL071K9P1gHR/0N68Y08=]=01lIbh0Mf<`085c
AP1_HT008AT602PQ5P0_:200;B@O02HO6@0Z8ad0>c@^04Dn>00c;2H09b0J02hW7`10>C40ASlg03L^
:@0V7AH0:1lH02TP6@0f;bL0>SH]03hl=@0T9Al0?3dh0=WIe`0F003o01[ooooo1@00o`030:0Pl1X0
oh0000<0X23`0?n0003oP0001@3oP0000`3@D7P0oh000?n000090?n000030:0Pl03oP000oh000140
oh000`2P8?000`3@D7P0oh000?n000040?n000030:0Pl03oP000oh0000@0oh0000<0X23`0?n0003o
P0000`3oP0050:0Pl0<0oh000P2P8?020?n000H0X23`303oP00G0:0Pl1H00?l04?ooool000kooooo
1@00o`00T@3KbLL0LdE507de=P2Y?D@0]3Dl0;Tk?`2kAdP0[4I4080a:P1^<b<0jknR0>O1U032UUT0
i[Q]0;22;@2gRb`0jl9I0?7;G03acUX0lm1H0>6lAP2lV2X0fkUE0=2aE`3M`7@0c:me0:F5GP3gd/80
olG70;iQK034CUh0c4UG0<e:DP3;CU80aEAF0;9DE02GCTP0Y7E^0;jQV@2YUH`0WXf509^=Q02QU8`0
YIR@0:^NUP2^XIT0ZiVE0:F;RP2`R8T0c96E0<9cN@2lFf80aUMN0<5<DP2mBD`0YDE309YJD@2TMFl0
UGM_08aeK`2=NWH0S7Ad091fM`2ENGP0VG]k09IfM`2EMgT0ck:f0?OCe`2mR900Xf1Y0;QXL@2iEUh0
/d170:lj@02/=cd0ZCHk0:@f>@2M=CH0UCLe074R7@2YJEl0j;RT0<fTR02_Qf<0^XiW09MS?01/;@`0
PSPO08Th9P1d9A@0NRlL08]7<01i>Ad0L3TJ05d`4@1>:`D0VGi709n=C`2]YFL0[jYc05=>9018?Al0
U7iW0:n>N`1Q=R<0U6=:09EWAP1oEBl0LTdS08ER>01L?A40D3@505e34P1M@a00HdXD05e4301J@@P0
L5PL08Uc>P1fI380HE</028H000W80l0<B/O03<Z8@0^9Ah09ahG02`S7P0j<B`0BD0k040i<@0`:B40
>C8Z03@]9@0_9Ql0:b8K02XQ6P0[91`0>3@[03ll=@0f=Bl07ahI03@e<03?c/`05P00o`0Jooooo`D0
0?l000<0oh000:0Pl03oP0001P3oP0000`2P8?00oh000?n0000A0?n000030:0Pl03oP000oh000180
oh0000<0X23`0?n0003oP0000`3oP0000`2P8?00oh000?n0000;0?n00080X23`00<0d51h0?n0003o
P0001@3oP0000`2P8?00oh000?n000040?n000040:0Pl03oP000oh000:0Pl080oh00102P8?040?n0
0080X23`0P3oP0000`2P8?00d51h0?n000070:0Pl0030?n0002P8?00X23`00@0oh005P2P8?000`3o
P0000?l0003o000D003o013ooooo000>ooooo`D00?l003l0_jNW06`f=P28>3T0[3a10;4f>`2g@d@0
Xclo084a:P2SIe`0fZ^G0>RmVP39XFh0f:eY0>:eI02SMQT0jkiG0??9G@3cbET0iKi70=2Y<03gdU/0
dje00:N47P3I^e/0l]J30:nDD@3B/hD0omK30<:0P@2iEF40ceIW0<U;F@35C5D0^U1B0:mEE02BCdT0
X6mX0<:VW`2RTHT0VX^409R;P`2IShH0Vi2:09Z?R@2MTX`0Y9VC0:nQWP2cX9`0ZXb<0;^>T@3AT9H0
`6Yc0<ALI@38E5d0_TM=0;=:BP26=c80Y6]T0:=lM@2AN740RWUb08UgM@2:NWX00P29NWL0D02;NGL0
RGEf08McM02TQh/0[8680;UmQ`3:OXP0^UaT0;17C02^Ad/0/Da@0;1=DP2V@dP0XT940:55AP29=C<0
KbXS0=NQU@3[`Z`0`9ik0;BAI`2lTV80TUlb06X[2026?1l0ORhC07T[502ICcH0YF1309eN?@2CFcP0
VFY00:V2B`2QQD@0Whe=0;J/K`2<REH0B4<K05=5:P2YSgh0UFiO095MC@2?ED40VV5609eVA`2VLE40
SEdi07mB:`1oEB/0K4LJ06U75`1L>`P0KTdG08IW9`26J2P0IdhE06=A8@0a908091d6030Z6P0c:b00
=bhU03@[8P0]91d0:R4J02dV7P13>S<0BD0i044h<`0i<2/0<R/U03</9P0h<B/0?3La044l=P0n>cH0
;2/V01dL5`0/:bH0al?05P00o`0Jooooo`D00?l000<0oh000:0Pl03oP0005@3oP0000`2P8?00oh00
0?n000030?n000030:0Pl03oP000oh000180oh0000<0X23`0?n0003oP0004@3oP0000`2P8?00d51h
0?n000070?n000030:0Pl03oP000oh0000@0oh0000D0X23`0?n0003oP000X23`0?n000020:0Pl0L0
oh000P2P8?020?n000030=1@N02P8?00oh000080oh002@2P8?020?n001H0X23`00<0oh00003o0000
o`005000o`0@ooooo`003_ooool5003o00280:R<R`1a=cH0ScTl0;0m@P2f>ch0[c/l0:4o?03RTh`0
omK:0>:dW@2cR6D0gK>10?K:R`3>X580/H@W0>NjD`3I[D@0/XLG0=J/=P3Q^Cl0i[i70?SBI@2eT2P0
eK=B0=foJ@2[TDL0o^2/0??;/@2FFE@0[4mI0<MHJ033D5d0_eAL0:M?CP2FDD`0YWE^0;^JT@2hYih0
Vhj609R=Q`2GS8H0VXn909^BS@2IT8/0VHj809^@RP2KT8`0YYND0;6LV@2eTi@0bIJK0=6:TP33Ig80
`EIP0;e9DP2kCE00VD0l095<A`2SLV/0UgUa091lM@2;O7L0RWmk08MmN`23NGL0PWMe08IjNP23Lg@0
SGAh09adO02WLWX0`gZ30:YBF@2K@D<0W4M:0;UZK@2dJ6`0[61T0:AEFP2OD5<0Ve5B06PY902JJV00
nMC20>33Y@2hVg<0_IaW0<FNI`1mCAd0LC88084i4`1n<a@0OcDH08@j7@20>AT0Q48P08iC:`2FHBl0
XGLm09an@P2QSU<0/:M`07mhBP0m<Q80FDLa0:j>P@2LKF00PDLi08]@?P1l?bX0PTPb0:1XC`2WKe@0
U69108eM>@2@I3d0Rf8f08]V<@2KN3P0RV`T06=80@2<NCL0NF`g02HN000X8@h0<BXJ03dc:@0o=B/0
@SP_03H]9P0_9Ql0:1lH030W800l<bh0AS`j040h=@80?STe00T0?cXf03Lc<00/:2D09B4N020K5`0^
9R<0WiRB0?;[i@3on?D05000o`0Jooooo`D00?l000<0oh000:0Pl03oP000103oP0000`2P8?00oh00
0?n0000B0?n000030:0Pl03oP000oh0001@0oh000P2P8?0B0?n000040:0Pl03oP000oh000?n000<0
X23`0`3oP0000`2P8?00oh000?n000040?n000030:0Pl03@D7P0oh0000D0oh0000<0X23`0?n0003o
P000103oP000102P8?00oh000?n0003oP0040:0Pl0<0oh0000D0X23`0?n0002P8?00X23`0?n00002
0:0Pl080oh005@2P8?000`3oP000X23`0?n0000D003o013ooooo000>ooooo`@00?l009H0ooGc09=d
LP1i?3/0Uci00;0j@02j>Ch0_T940:0`;P2jGEH0jj:I0?g5]03W^Yd0eZb40=f^NP3CXUl0/X@_0?W=
KP3J[dT0W7030>RkAP3P]3/0`YHR0?G<HP3=Yd80[XLX0>W5K`39ZEh0ekQo0?cK^P3T]:P0Xe]O0:9:
EP2fEV40[EAJ09I@CP2ZN740/8j50:jFS02hZJ00Z9^C0:6DSP2MTX`0W96=09Z?R`2KT8`0VXn;09R=
R@2IS8H0WHj90:FCT@2eViX0`Y^N0<nHWP3;OhT0_V5[0;Q=E`2oCeD0/U1?09A5@@2JGEP0WWE_09Ml
M@2@OgP0S85k08MnN@29Ogd0QWak08AhN027MgX0SgIl09Q`N@2TKgL0^6mh09i<D02:?Sh0W5mL0:Yg
M02WMgL0XgEg0:IdM`2QKg00WVa]08EHE@1aC4H0ilZl0?oUcP3F_YX0_:1^0<b^LP2dTU<0LD@:06L_
001V:040KB/907L`401n<a@0O2lA07db4P1k=Pl0MST=0752502ALCh0/IeX0;6UL`1YGCL0A3HI06aJ
AP2ALF<0S61C08aLCP1g@cD0MT4c089:>`2>ETD0RE0m08YC?P2BGd@0QUPd099Z>@2ROcl0V7/]09In
902gY4P0_jmJ04a0400U6`80;R<A03<Z6`0i;b<0Bd4g04i4>`14>c@0>c8[02/R7@0[8Al0:AlN02/S
8@0W8Ql0:B<S02/W9P0U7al08Q`L02PQ800/8R00<RDO03LV7`1[FDl0]J>I0=_:`P3gj^@B003o01[o
oooo1000o`020?n000030:0Pl03oP000oh0000@0oh0000<0X23`0?n0003oP0004P3oP0000`2P8?00
oh000?n0000D0?n00080X23`103oP0000`2P8?00oh000?n0000:0?n000030:0Pl03oP000oh0000L0
oh000P2P8?000`3oP000X23`0?n000030?n000D0X23`103oP0020:0Pl0@0oh0000<0X23`0?n0003o
P000202P8?000`3oP000X23`0?n000050?n000030=1@N02P8?00X23`0180X23`103oP0000`2P8?00
0?l0003o000@003o013ooooo000>ooooo`@00?l002/0m>GR08IPG@1o>cX0WSm30;0g?P2o>D00`C`o
0;Pn?@2S>380RcL]0;IgJ03Y^J<0mLb/0<jRM@3P[gD0]8@j0=^]E`3mdG00dZHm0>^mC@3?X2`0d:4a
0?S?I@36WcX0]Xlb0>o9M03/c8<0[XmH0<>RP@3oflh0mkVl0:IMJ02UEEh0TDU=0:5/J02jUHd0Y8V0
0:2>Q02cYI/0cL2h0;jaZ@2[X9X0X9F?0080WY>=0P2MTX`0JP2OTX`0X9>=09j?S02TT8l0[i>B0<:I
W@3;SiL0cH6;0;YOJ02mE5/0`eaO0:M=C02=@d00XFmX0:1nM@2EOWH0SWmh08MlN029Ogd0Qgel08Mk
N`26MWT0SgAk09Q_M`2^MGh0[6=Z09M:C@25AD<0Xg=_09MdL02CMG<0U7Qg09IhNP2GNGT0V7Qi09Ef
M01oIV80]YnG0>cGaP3[e[/0cKN>0<ZcO`3:/WH0_YmQ0:ImA@2DI3@0N4<G06ld201`;`D0L2`707H`
301g<``0NS`C060_1P1S?A00VX1=0;JVLP2XW6`0GeH]03hc5@1QCCD0Nea708]XE02HLUd0V6eJ08eP
C@29FTP0ReY908UF@`1oCcP0GS4B091Z?@2[RDT0X8@a0:J?:@2jYSH0a[A609nB?P0_8`00:1h002hT
2@0^9Q<0>c8S04Hl<P1BB3l0ETa304e4?@0n<bl0=2XX02hV900Z8R009R0P02`V9P0X7b00:B0Q034W
9P0f:2D0:a`E02PF301NB3/0SGIX08UbI02JQ7T0]J:K0=[;a03ai^0?003o01[ooooo1000o`020:0P
l1d0oh0000<0X23`0?n0003oP000503oP0000`2P8?00oh000?n0000?0?n000030:0Pl03oP000oh00
00X0oh000P2P8?060?n000T0X23`103oP000102P8?00oh000:0Pl02P8?020?n000H0X23`1`3oP00C
0:0Pl0P0oh0000<0X23`003o0000o`003@00o`0@ooooo`003_ooool4003o000`0>C?c01fBTL0Rcdm
0:Ho@`2a=3`0`CPo0<8j?P32@400_4I20:Q7?P26?2l0JcPU0>2kX039XW/0gK9o0<FEE@2`Oc80l/=[
0>JhEP3EYS`0e:Hg0=>V>03fbf80/HXU0=ZcEP3B[ed0_YmL0=FeQ03Q_:80om;:0?o:c`3RWZT0UE9I
08eBE02eSH/0YHZ309b:P02NT8L0Wi>:0;^^YP3:_KD0cl:j0<2cZ`2^XIT0Y9N?09jDR`2RUi40WY6;
0P2OTHh0J`2OT8d0XHf<0:nBU02hTI@0`hjD0<AmQ@2jGFD0`EYN0;EEEP2GA400TU=<0:MkLP2LOWH0
U81i08aoN@2;P7h0RWin08YlO02<Mg`0U7Ek0:5bNP2gN840W55F0957BP2;De80X7Ud08mcK`2<Mg@0
RgMf08ajNP2<NWP0SGUh08ijN@28MW@0R7Ib09f<Q02WUHL0YYAn0;:OO`2o[880c;N20=>iOP3@/WH0
aZIY0;ZFF02VOT00SfD[07E84@1U=`<0GS8105he1`1>;000GD<B09n>EP2`Y6P0Qgi305mI9`1ICRD0
HDlY05U36P1dFc<0NUdk085TA02=KTl0UWMJ095_E02CKeD0Q65109]jC@2ZS4`0XhTb0:VA8`2kYbX0
b[Te0=G8CP2KTC80Bd8002/S000`9`P0<RXE03L[6`0j;R00A3P/04i4>P1DAcl0CT<m044f<P0o=300
?S@b040f=00g;B/0<bTW03@X900e:2809aT@030N4P1kJ5T0V7i_08aaH02>LF40U7AW08i`I@2IOG40
[Y>:0=:n]@3bh=`0ooKb00/00?l06_ooool4003o0080X23`2@3oP0000`2P8?00oh000?n0000C0?n0
00030:0Pl03oP000oh0001<0oh0000<0X23`0=1@N03oP0000P3oP0000`2P8?00oh000?n0000;0?n0
00030:0Pl03oP000oh0001@0oh001P2P8?040?n000040=1@N03oP000oh000?n00080X23`103oP000
0`2P8?00oh000?n000060?n001<0X23`2P3oP0000`2P8?00oh00003o000:003o013ooooo000>oooo
o`@00?l00340ek^g07A1?P2C?cl0Z3]00;@c>`35?4<0a3Tn0<I0@@2l@3h0]T]50:1>@`1R;Al0g[RS
0<2KOP3U^i<0gjmo0<2>D@33TdT0fZaF0>2bE03caV40jl1J0<2F=02kU3L0i<1/0=2^IP34YFh0on2j
0>o6]02eQ800/gIm0:QYLP29CU@0ZWUl0:n@S@2JQh00Vhf409^>QP2KTHP0XiJ>0:bOU`2n/JT0dLBk
0=?6_@2m/:L0Zj6H0:FKTP2PThd0X9:?0080WY>?06d0WHj;09j<RP2USHd0[hb@0<F@UP2lKGD0]UIJ
0;YEF@2dFEP0TTA009aQF@2VNg@0X8=m09R5O`2@PWl0SGmn091mO`2BNGd0VGAk0:]cO02`KGH0TDE9
08a8B@2FIV@0VgUg08agLP2=NgT0RWak08EjN028OG/0QGYh08AiM`26N7L0PG=b08QjM`28NG@0RWaa
08inKP2@P6L0YIA_0;bZNP37/h00dKb50=BnQ03A^G/0cK=h0<:UJ`2gV640Wh1:08MW=01ZC1P0@B/0
06ID5P2]Xe/0]JiV0::PH`1^JcP0Q7U<06MF:P1/EbX0L5T_05<l4P1TCB<0Ie0V06eD;01mI3`0Rfm8
091d@P2URTD0XhX^0:VC702nZR<0d/8_0=W=>@3OeU<0`kaD06YU500b;0009Ah002`R000a9PX0=BXD
03/`7P0n<R80@S@W03la9P0k;B@0?C0W03X]900e:1l0;R4H03DW7@0U60P091@4048a7@1jJ580WhUd
09=hI@2ALV00TFeM09UdI02KMVH0SVYL08IVF@2>LfP0XHf40<fl]03]hmX0P?]i00P00?l06_ooool4
003o00030?n0002P8?00oh0000P0oh0000<0X23`0?n0003oP0004P3oP0000`2P8?00oh000?n0000E
0?n000030=1@N03oP000oh0000`0oh0000<0X23`0?n0003@D7P06P3oP0020:0Pl1L0oh0000<0X23`
0?n0003oP0004P2P8?070?n00080X23`0`3oP0000`2P8?00P<00003o0007003o013ooooo000>oooo
o`@00?l002H0`j:M0815@@2M@D80[Ca00;Hd?@32>D00bCi30<@n?`2o@T00_dm=090i<P23BT40k/Jj
0:Z3LP3I[iL0eZV<0=j^QP3BXfl0c9aL0<JFBP2hRcP0_9@l0<2JA`3X`WL0f;Ec0>K3S@2TQ5d0fkVP
0?K>a02=Fe`0SU1E0:5PJ02KI6X0[XB60:68Q02LSHH0W8n709V>R080Vi2:00T0WiB>0::GT@2/XYT0
_;:Y0<Rn]@3<`[T0_K>Z0:VOUP2NThd00P2QUY00K`2KT8`0Wi6>09n?S`2TSY00]Y:F0<>7S02bGF@0
]5AH0;UFF@2YCTd0V4Y60:5WH`2]Q7h0XhN309Z7P`2BP800TG]n09QgOP2QM7/0]7En0:5HG`2@ADT0
RTe<09ifM02CNGP0RGMe08YlN`2:OWh0QWYj08QlO025NGT0QG]j08MkN`21MGD0RGil08]mO027NGH0
QGQb08MiL02;O6h0SWmZ09>3JP2OT7<0[Iek0;VWO`37]8X0c[V:0=K0SP3B^hD0cKMm0<F`L@2RSdX0
PgDZ0:>KB02m^VT0d]>=07Mh@P21NE80P75:06eG<01mHSL0O64b07mV<01gHBL0HD/A06eI7P1YDQ`0
FD4308ie9@2[U2h0[IPK0;RV5P3EaR/0elh^0=_F>P3NfDT0dlmA0:>O=01^J180?SL002/Q000S6P00
9Qd002lT200e9`d0=2D@038S400h9aD0=B@B038S400a8Pd0;1h601lA000g:0L0L68o07IWAP1eID`0
RWER09=iJP2KOVh0XH1a099^GP2EL5h0UW5O09AaGP27IU<0PfMB08]`G@2dXI40k=oF0?oim006003o
01[ooooo1000o`000`3oP000X23`0?n000080?n000030:0Pl03oP000oh0000l0oh000`2P8?0H0?n0
00030=1@N03oP000oh0000h0oh0000<0d51h0?n0003oP0007P3oP0000`2P8?00d51h0?n0000@0?n0
0080X23`0`3oP0080:0Pl080oh001@2P8?0;0?n000060:0Pl03oP000oh000?n0002P8?00oh001P00
o`0@ooooo`003_ooool3003o000d0?ofm@2_RHH0QTE109lo@@2[=S`0^SQ00<4h@039@4L0`c/o0<A2
A02lA4D0TR`Z0<IhM03ob/<0l[J^0?Nm/@3e_:/0mknX0>2^R`3CY7P0h[En0<VMH03L]G<0j<B60;JA
G03=YW/0ikjN0<ZMQP3IZId0omoK0>Ra]02FE5P0SU1E0;1mPP2;IfL0H4]608]nMP2NThd0Vi2:09V>
R02HSHL0Vi2:09fBS02RVI80XYR?0:VOUP2eZj80aK^b0<k4^`2j/:L0[J:L0::GT@80WYF@05H0WI>A
0:6AT@2USHd0_I2C0;YcN@2kHFX0^UML0;UFF@2SBDP0Ude:0:igLP2WP7/0Y8N309MoO`2IO7h0X7Mm
0:YeO@2fL7P0UdY@09Q>C`29Ddl0WGik08iiMP2<O7`0RWal08UmO@25NGT0QWYj08EkNP27OG`0R7im
08=iN025NGT0QWYj08QlO023MgL0RG]k08MiM`28NgD0QGQ`08AfJ`29O6/0RgaW0963J@2KS6d0[Yij
0;NVN`37]HD0e<>;0=C4QP3<`7P0aKa]0;VfI`3AeH/0TIEN05QD;P2AQ6@0/imn08Y^B@24ICL0TWDk
08]`:`1mIa`0QW<V07eZ7P1PB`00RG8B0:bG902`W1D0[ih80<Vk703MeBd0f=@Z0=oL=`3NgT80g]eA
0=SFF`2l]e<0Ui4m06aU7@1BC@d0>c8003L/000_8`00:ad002hP0080;Al001P0<R@0044d0`1[Gb<0
VXiB07a_>P1eIcX0K5/m071NBP1bFd/0PFMJ08Q[G@2KNV/0Y81`09mlJ@2@L5T0S6aC08m`E02MOf<0
Pfa@079PC026MVL0_;:X0>WRfP3mn_D3003o01[ooooo0`00o`0<0?n000030:0Pl03oP000oh000140
oh0000<0X23`0?n0002P8?005`3oP0020:0Pl0/0oh0000<0X23`0?n0003oP0008@3oP0000`2P8?00
d51h0:0Pl0030?n000030:0Pl03oP000oh0000T0oh001P2P8?030?n000X0X23`3@3oP0000`2P8?00
oh000?n000040?n000030:0Pl03oP0000?l000800?l04?ooool000kooooo0`00o`00:P3nk^h0W71_
08Do?@2T?d<0[cPn0;Tf?P30=cl0c4=;0<HmA035?4<0ad160;@f>P35DUD0eFe/0=McL@3JOGP0f8Aj
0=>;O@3d_JT0e:R=0>BiV@3BZXH0`Z1j0=^hV02/Qfd0o=710?G0^03_ZjP0mJj/0?bh^@3oa/L0^gUj
08Q>C@2iT8h0YhV706aID`1EB480LFIP09J=QP2KTHP0W8n709^@RP80W96;02X0WY>=09nDSP2TVI<0
Zj2J0;V/Y03>a;/0d/Ro0;N^Y@2YX9T0XIRA09fDS`2NThl0XY>>0;2@T039TYL0_G1h0;]PJ@2lEed0
]UAE09]3@@2OEU00[WM`0:^2O02QOW`0XGYk0:UfN`2iNh00Zf1W09I7C02@B4T0Tf5M09EiM@2=NgL0
RG]j08MkN`29OGd0Q7Yi08EkNP29OW`0Qgaj08IlN`25NgX208EiN@1?08MkO@22MWP0QGUk08IjNP25
NGT0QGYh08MiMP28NgD0PWE]08IiL025Mf`0RGa/08alK02CQ6d0WHia0:fNM`32]8<0bKj00<FnNP36
ah40`LR>04=57P1]J4/0fl^b0:Z<LP1^BRH0^IAM0;fKD@2ENR40WHLT08]g501`G@00XXlI0;FR7`2f
Y1@0/J460;f_3P3GcBD0h=`b0>KT>P3TiD40hnE60>CTCP3ViET0h^9P0=WIG`3>cET0][940:NS>02G
TR`0RhHR08V17`2;PB00T8HT09V@:`2_XS/0_[5;0<BgF@2TU4L0K5`Q069>:@1XDS/0PFMH08IZG`1o
HeL0QfUN07eQD`2HOVd0Qg5J08ahG@2<NET0TgmJ0:F@I`2NR6<0O6M805Q4:`1RDd00QWa`0<C0]`02
003o01[ooooo0`00o`000`2P8?00oh000?n0000:0?n000D0X23`2P3oP0001@2P8?00oh000?n0003o
P000X23`00<0oh0000<0X23`0?n0003oP000503oP0020:0Pl0X0oh0000@0X23`0?n0003oP000d51h
8@3oP0000`3@D7P0X23`0?n000020?n000030:0Pl03oP000oh0000T0oh0000<0d51h0:0Pl02P8?00
1P2P8?0B0?n000<0X23`303oP002003o013ooooo000>ooooo`<00?l004h0l=kN091PH028?3`0YSm3
0:`e>`2m>D00a3i70<I0B@30>T<0`c]50<XnA`3<@4T0^S<i0;0]<P2b=SP0[c/k0:<j=P1m91h0_7ic
0>jn/02[P700bj6A0??>_@2RO740`IRB0?oEe`2oO8<0VT570:Q8C02[DU@0`G=a0:5MFP2KIV80]I2:
0:J?R@2MSXT0OgA^05Q=A`1GCTL0SH9k0:6DSP2NTH/0WY>=09^@RP2OU8h0WY>=09nDSP2PUHl0XYF=
0:VOUP32^:l0bl:i0;je[P2`Yj00YIbE0:2GT02QUY00Yi6?0;bCU`3>SiL0_6ae0;iOI`2kEUX0]5AE
09U1?`2VH5P0]7Ua0:mlN02_NGT0]gMh0<9jO@2SDEL0Vd]>08Do?`2KKf/0Tg]g08]lN@28OG/208Um
O@0408IlN`25NgX0R7al08MmO080QWak0P27Ng/01@24N7X0QGUk08MkO@25NG/0QWYl0080QGUk0P26
NWX0:`23N7H0QGYh08MiN029NgP0QGI_08IfI`2;Nf40UXMN09n@F@2SVUD0_Kib0=oVY`1/LDP0?C`N
0;BXTP3[d;d0ID8T09Q`?03S_G80bji:0<>^>`2iZC00Zi`M0;RX8@33/b80_k0I0<6c502k[PX0bL0F
0=gJ;@3Vi3T0inHl0>;T>`3RiCh0inU60>[/C@3Zje40l?1J0>k^G03Yj5X0gMiD0=[JE03JeeH00P3F
dE406`3FcD`0e/]70<k0@`34]dD0/9m7099m?01NAad0FShV06iA@@1jG540Pf9I08Y/HP21IeX0PfeO
071OB`29OF<0Uha^09f@K@2KS640XHmQ0:nIL02UTFh0Lf9403/`701dKV00n_We003o000Jooooo`<0
0?l000<0X23`0?n0003oP0003P3oP0000`2P8?00oh000?n0000:0?n00080X23`1P3oP0000`2P8?00
oh000?n0000C0?n000030:0Pl03oP000oh000080oh0000<0X23`0?n0003oP0000P3oP0000`2P8?00
oh000?n0000S0?n000<0X23`0P3oP0000`2P8?00oh000?n0000:0?n000h0X23`2@3oP0050:0Pl0/0
oh0000@0X23`0?n0003oP0000?l04?ooool000kooooo0`00o`00;@3RcL`0Q55@08/m?@2W?T<0[3<j
0;/l@02l?D@0^ci60;LmB02b=T40aCm:0<LnB039?DH0bCi50<e5B@39AdT0aDe<0:a4@@24=c40kkB^
0=RYX`3md//0lL:l0=^_[P3Y^;/0olO@0;AQJ`2hBE80aDiD0;A8B02`DU00UDi80;9mM`2^SHH0WXZ3
09^>R02MTXh0V8f9079WH`1DBD@0PWAa09f?S02SV9@0X9F?09nDSP0209nES00/09fCRP2NThd0WY>=
0:BJT@2/XYT0]jbV0;jc[@31]jh0]ZbS0:RKU@2STHh0Zhn>0<>DVP3=SYH0^VU`0;EIGP2gE5L0]UAC
0:17@`2SDd`0_Fm[0<AfM03:NGP0ag5b0:M>D02PD540Pd900:5iM02@OGL0S7ik08IlNP2:P7l0RGmn
08b1O`27Ng/0Qgel08^1P02:P7l0QWak08QlO02;Ogl0QG]j08IlN`28O7`208MkN`0408UmO@25NGT0
QGUi08MkN`80QWYj04H0QGUi08anO@2<OGP0Rg]^091oI@2EQ5P0Rg/m09B9>P34`fT0g>>G0;BjRP1C
DS<0NG5L0?CRcP2gVGd0M4lK0=VeJ@3Pb5h0e<940<Vm=@39`C00ak/W0<Zo9@3;`B@0b;hN0<Jm6038
`AH0e]<T0>;P<`3Xj3X0h>8f0=gO=03SiC`0h^@k0>;S?@3QhS`0iNI00>GX@`3Kh3h0g>150=_MB`3W
iUP0g]]>0=SBAP3FbSl0d<=00<6b?@2_W400V84m075D:01P@BD0Q65>07YFBP1T?SD0NUQ>07iPEP1m
IET0MfMH06QPC@1cKEL0X9Z00:ZSO`2KT6<0VHaO0:RKK`2i[HD0If1306i/E`3in?<00?l06_ooool3
003o00030?n0002P8?00oh0001L0oh0000<0X23`0?n0003oP0002P3oP0000`2P8?00oh000?n0000C
0?n000030:0Pl03oP000oh0000<0oh00102P8?0U0?n000070:0Pl03oP000X23`0?n0002P8?00oh00
0:0Pl00;0?n00100X23`1P3oP0070:0Pl0d0oh0000<00?l0ooooooooool03_ooool000kooooo0`00
o`00;@3@^;P0O4I4090n@02Y?T@0/3Ln0;/m@@2f>d00/CU20?J7T03WM840^ce90<U1C@39?DP0bSe5
0</nAP37?d<0aD=50;i:B`259R@0agUg0?oAd@3i_;/0Ue5B0>R/[P3oc]@0nZZe0:e9E@3;CeT0bTU>
0<5;B`2^C4T0VU==0;V8P@2VR800WHZ409b?R@2FSHP0VXn;09bAS@20MG40CT0m05Y?B`20MG40VXn;
0::GT@0209fCRP0309jDR`2LTH/0WI:<0080XiV@07D0YibF0:VNV02h[ZD0akfd0=74_P2hZZD0[IRG
0:n;S@3=V9h0hiZQ0;ENIP2mGF40_UYJ0<UZIP35J6<0[E9?0;9GEP3:JV/0`61Q0;EGE`2MAdH0UTm=
0:QiM@2IOGT0TWej08mmN`2CQ840SX1o08n1P02=Ogh0S82008f3PP29Ogh0Qgel08YnOP2<P800Rgmo
08UoOP26NWX0R7al08YnOP2;Ogl0Qg]k08YnOP28OG/0Rgel08]mNP2<OgT0SX1g0920L@2@P6L0UXAL
09:1B@2=OC80[J5;0<g:K@3@dhP0hNBg07AcE`1_J5H0e/Jg0>kF_P1nGC80]iIA0?GMN`3SdeX0gM5;
0=_CA03Jd3d0fm4l0=?<=@3Bc300dL/]0=;=:`3=bR<0f]L`0>;Q>@3Si3h0h^<m0>3R>@3QhcP0hN<g
0=oR<`3NhC80gn<d0=kR=P3KhCT0gN520>KWC@3ShTX0f]A00=C9=P3>`CL0_Zhd0;FQ?P1nIa/0JddI
06e<:@2DL5H0MDll07eFA`1eDD<0IdLj05a2=@1QD400Ge9106MOB01ZI4X0VIAa0;J_P`2UWFh0Vi=T
0:bUN@2KVG<0QXI^0?Wil@00o`006_ooool3003o00030?n0002P8?00oh0000D0oh000P2P8?090?n0
00040:0Pl03oP000oh000=1@N080oh0000<0X23`0?n0003oP000303oP0000`2P8?00oh000?n0000B
0?n000040:0Pl03oP000oh000?n00080X23`0P3oP0020:0Pl2D0oh0000<0d51h0:0Pl03oP0000P3o
P0020:0Pl0030?n0002P8?00X23`0080X23`1`3oP00@0:0Pl0D0oh000P2P8?000`3oP000X23`0:0P
l0030:0Pl0`0oh0000<00?l0ooooooooool03_ooool000kooooo0`00o`00;`2hW9/0PDM5090l?02/
?d@0/3Ln0;/n@P2d>d00[CY10?N=U`3/PXh0/SY60<A1C`38@Dl0b3m90<@kA@3:@DT0bD980<M6BP2[
=cX0Ycdo0?NDU`2jEeX0ZCm309Lk?P3oYZ/0jHB<0;U7C`3=Ce<0adU:0;i<B`2RAd80WemF0;Z?R02R
QX80W8Z609j@S@2JSh/0Vi2>09Z?S@2QUY80SH:006UNG01:?cd0FE1;08ImN02GSXL0X9F?0080WI:<
00<0WY>=09^@RP2MTX`00P2OU8h09@2UVY@0[:6K0<Fj]P3Gb<D0c[Vh0;fKW036UIT0hijS0;m]L`3G
Ngh0aFEV0<MYI`3BMg80bF]Y0:m@CP2hE5@0]e1A0;mHF@2VB4H0ZUID0;EdL02YNGD0Y7eh09YkMP2J
OW/0VH5o099oN`2AOgd0TH9o0922P@2?PH00S85o08n1P02:Ogd0SX>108b1O`27OG`00P29Ogh0C02:
Ogd0Rh1n08eoOP2;OGX0SWmj08n1N02BPG40UHAZ09N5G`2DPdl0U89009:2=02[WD@0`kYM0<c8K`3B
dI80h>2n096<N@2;PWT0/j:J0>SA`@27JTX0ZXYG0?[PT`3bfg/0kme]0>kNI@3[gUh0j^1L0>CLE@3Q
fe40h=Y>0=OEA03JfD<0emHn0=[I@03Kg480i^M;0>7SA03NhC`0h^Hj0=oS=03Lh340gn<d0=kR=@3Q
iCT0g=lj0>?T@@3[idP0h=Xl0=G;<@3<`2h0_JlZ0;ZX>P1hH`X0Ech0085S<@1lG3<0H3dM08YVC01Z
Ac40Tg9O07mSCP1PAc40ED0U05e::P1_HCh0KF<j09jGJ@2g/h@0/Zio09BCI`2ZZX@0ZJbA0?Sil@00
o`0Jooooo`<00?l000<0oh000:0Pl03oP0001@3oP0020:0Pl0X0oh0000@0X23`0?n0003oP000oh00
0P2P8?050?n000030:0Pl03oP000oh0000P0oh000P2P8?0A0?n000L0X23`1P3oP0000`3@D7P0oh00
0?n0000O0?n000030=1@N02P8?00oh000080oh000P2P8?000`3oP000X23`0:0Pl00I0:0Pl0D0oh00
1P2P8?000`3oP000X23`0:0Pl00;0?n00003003o0?oooooooooo00kooooo000>ooooo`800?l002H0
ooKd09anO024Ad@0UCln0:Tl@@2]=3T0^Sm30;]4BP2_@TP0eG5k0=eiQ@2Y>dP0]d9B0;]2D@30@e40
_T1<0<=4C`32@4X0`T=:0<97C02[<ST0_4M=0;a3BP3<CUD0WBP^0<EBF@3DFf80bDaB0<m>DP34BTT0
_U9?09U4?@2^Lf/0]I2809f5P@2IRXL0VXb909V>RP80VXn=0880W96=09nDTP2QUiD0RGmm05iDDP18
@C/0F55;08AkMP2OU8h0XIJ@09fBS02KT8X0W96;09Z?R@2OU8h0XiRB0::GT@2XWIT0^ZZX0>?;b`3[
a<L0hjnc0<f6S02bGF80cW9e0<m_L03KP7d0iHZ70?2BT03JNgT0b6AT0<=LG@30FEX0^5AD0:U;B@2Y
F5D0ZF=Q0:mbK`2_N7D0ZGQd0:QlN@2SOGX0WWaj0:64P02IOGX0VH1l09MoN`2EP7d0TWmk09>1O`2B
Ph00SGmn0923PP2>Ph40SX1m08n2NP2EQ7X0T81a09N6M02DQ6X0V8IR09B2E02@P4@0TX@m0:FEA`2`
Y500akeX0=;;N`3Mf9@0c/^N0:^YU02LUHd0XYRG0:>EU033/:X0KE=206U?;P2UREL0_j9P0=k1L@3`
eGX0m=Yi0??NM@3`gW00kn=]0>gSJP3ZhV@0in1N0>?OF@3Ofe<0emA90>_ZFP3Wie<0h>570>7S@03R
iC`0hNDi0=oS=`3NhSD0gN4e0=oQ>03PgcT0i^<n0=oJ=P3Dbb/0c;lU0<Vj:`2n[c00ZILY081[401m
IQP0PfXW07QN8`2OPe<0MeX`089V@@2JP5d0M5Xg07IO=P21Jc`0JUHS06IH901fK3/0Q7i>0:^WN02V
YGT0Z:Z30;>fV`3hnO400?l06_ooool2003o0080oh0000<0X23`0?n0003oP000103oP0020:0Pl0l0
oh0000<0X23`0?n0003oP000403oP0020:0Pl0l0oh0000<0X23`0?n0002P8?001P2P8?040?n00003
0=1@N02P8?00oh0001h0oh0000<0X23`0=1@N03oP000103oP0020:0Pl0<0oh00602P8?0:0?n00080
X23`3@3oP0000`00o`3oooooooooo`0>ooooo`003_ooool2003o002Z0?O/jP2:JfP0PDA109]3@@2U
>cd0ZS<g0;Q1A02jBDl0ZT9909Xk@`2`E5l0Y4ID0:Q7F02_BU`0[DIG0;15E@2aAE@0/T9>0;M5C`2i
AE00^4=<0;i5CP34ADh0c4I?0<U3C032?4D0cdMA0=19D03;B4d0`4Y:0:i:B02GB4<0^HAn0:b;Q02N
RH@0UhZ409N<R02JSh/0V8f909Z?R`2KSh/0VXn;09V@R`2MU8l0WIJ@08b4P@1GCd`0B3hl06IKE`2<
PGd0XiFB0:BGT@2SUY00WYB;09fCRP2NThd0XYNA0:BFT`2/VYP0_9bM0=j]/@3d/kT0`G1g0;9EG@2[
Bdl0]E9E0=j0P03jWi`0mibI0?:GU03fViX0iHN70=5bL03CLG00_e]K0:m>CP2RAdH0WDE409m;B@2V
EE@0ZEeM0;5[J@2`L6h0]G]i0:ejM`2]O7P0Yg]h0:9lN@2PPG`0WH1l09^1P02GPX40UX>3091nNP2C
PWX0W8al09Z9K`2HQV80VXML09B3C@2?OCd0U8<k0:2CA02aYUH0`;MZ0=G<Q`3Pei`0f=2Q0<6kU`2U
XHh0WIZE09nIV`2PVYh0XiVQ0;>WZ`2=NgT0DCPa06E6=01[AR/0Qe/d0;63DP3J[740j;]g0>o:NP3d
eG/0m=Yi0?ORN`3di7D0l^Ec0??XLP3^iVX0kNQX0>SVG`3Ui5H0h>=<0=cP@`3TiT<0h^E00=kQ>P3R
iC`0gMlf0=cN=@3KfS80e]</0=G=:03@`bD0dlH/0<o3<@3;_S@0^J`/0:ZK9P2PSbD0W8`]09b:=P2>
O3@0LEdN07YW;@1gI2X0MV8U0;2NEP2hYUX0MF<L06IE7@1eIcH0NG520<?0U@2`/Xd0[JnG0?Sil@00
o`0Jooooo`800?l00`2P8?0[0?n00080X23`3P3oP000102P8?00oh000?n0003oP0080:0Pl0H0oh00
0P2P8?0H0?n000030:0Pl03oP000oh0000L0oh00102P8?050?n001<0X23`6@3oP0000`00o`3ooooo
ooooo`0>ooooo`003_ooool2003o002Z0>3Bc`1gEU40QDI109Hn?02V>cd0[CHj0;U2AP2_@DH0XCa2
0;5HH02dHVd0/6Ib0:ISKP2MG6X0ZFUg0:ASL02IEf<0[V]g09aFHP2XGFP0[e]X0:90C@2]?T/0aTIA
0<e3B`3=@4P0cCe70<m3B`38ATX0_T]<0:=7A@2SGeX0^8b60:66O`2NS8D0VHf709^@R`2JShX0VHf8
09Z>R@2LT8`0VXn;09V@R`2JTH/0Vi>=09nGT@2NUXl0UHb807mfL@1VG5P0HUIB06UKF024MW80VXj9
09nDS`2NThd0XIJ@0:BET@2^TY<0_XfB0=VAVP3<Lg`0bEmX0=5OIP2nBDl0/Si30:Hg>@2bAdP0^UED
0<5MG03=JfX0g7Yi0>9oO@3UP7h0iX1n0>AmN`3FL6l0cVQW0<eWI`32G5h0/Ti?0:i8BP2aCDh0[De=
0:iADP2bFU/0[5UH0:mRH@2`JFL0/6m/0;5dM@2aNg`0ZWml0:21N02KPG00VhEW09J3EP2IRE00WHe<
0:bNEP2l[V<0b;ee0=38QP3?bI00a/6B0;VeTP2[YXl0YJ2C0:6LUP2PW9h0Wi^R09nKX`2MVJ40X9VT
0:BKY@2gZk@0Pg9i040X;01C=SH0FCL`05H`902NNFD0d:bA0;NELP2kVg<0^IQ/0<FVL03B]GL0g;ik
0>;5O03Yc7d0kM9k0>oGN03ag7@0k]aZ0>[KH03XfUP0j=eD0>OND03Vgdd0hme:0>;MA`3OfdD0g=M3
0=[C@@3GcSh0eL/k0=?;>03EcCP0d//e0<k7<`3?aSP0a[hf0;Za<02bZC80XYT/09B:8P2=PA`0OG4;
0:6E9`3JcU/0gm=S0:nRAP1iKB40K6@W0;^hQP2b/XX0[K2D0?Sil@00o`0Jooooo`800?l000<0d51h
0:0Pl03oP0001`3oP0000`3@D7P0X23`0=1@N0070?n000030=1@N03oP000oh0000P0oh0000<0d51h
0?n0003oP0003`3oP0000`3@D7P0oh000=1@N0080?n000040=1@N02P8?00d51h0:0Pl0@0oh000`3@
D7P60:0Pl0<0d51h1@3oP0020=1@N080oh000`3@D7P:0?n000030=1@N03oP000d51h00`0oh000P3@
D7P20:0Pl0030?n0003@D7P0oh0000<0oh001`3@D7P:0:0Pl0030>QX?03oP000oh0000d0oh0000<0
d51h0;Ph]03@D7P01P3oP0000`00o`3oooooooooo`0>ooooo`003_ooool2003o000S0>WKf01kG5L0
OdA009I0?`2W?Cl0[3Di0;Q0AP2eA4X0XCa20:eFGP2iKWD0VUeT09QWK@3S^l@0kL[A0>2ob03VaLh0
lM;J0<f]^03V`/h0[gn=07`jB024;Cd0^dUE0<Y4C@3?@d`0c3m70<]2B@36B4/0]dU:09i:B02bMG00
[XV30:6:Q02MSXL00P2JShT08P2LTH/0WY6;09f?S02JSh/0WY>?09Z?R`2HShP0W9><09ZARP2KTX/0
WYF>09fDS`2PUi80W9>>08EjMP1MDTh0Bd0n06AIE@29OWX0X9F?0:VGU@2bSHh0di2G0=EiQ02hB5@0
bTeE0=A>E@3FCE@0ee1F0=1=DP38BTd0_4540;4j?02V<S<20:/k>P150;i@C`3@I680gG9a0=]aL@3I
Kfl0i7Yj0>QnOP3[OGh0hg1c0>5ZKP3BFEh0ae1D0<MDE`2oCU00/dI90;18B@2YADL0YDM80:18A`2L
EE40/81b0=>`VP2mYH<0/ii_0;f^M@3>`hD0gM>F0=K<U`30]h`0ZZB409nJQP2QWI80WIZE09fIVP2M
Vj00W9VP0:2KY@2PVZ@0X9^R09fHW`2OVZ40WiRP0:ZPZ@2cZ;00Bci702hO9P0Z6ah0;b4Q04/m?03a
hn00n>WT0?[Wh@3ggm/0i/c20<R[V@2gUh00[ha`0:IoGP2XPeT0^iEV0<>PJ03E/W80fk]`0>?4L@3Y
c700k=1_0>kEKP3bfW00l=Y]0080km][01X0lMma0?CTL`3UeUl0fm1D0=cBCP3Id4<0f=0m0=gF@03H
dC/0e]0l0=G@@035_c<0_kTa0<S1?02k]Bd0_;DY0;J_803IdT<0knM[0>;KL`1bJad0ZjU^0;6cQ02Y
[8l0n?Wa003o01[ooooo0P00o`030:0Pl0L0oh000P2P8?0Y0?n000030:0Pl03oP000oh0000@0oh00
00<0X23`0?n0003oP0000`2P8?080?n000X0X23`203oP0000`3@D7P0oh000?n000040?n000030:0P
l03oP000oh0000l0oh0000<0X23`0?n0002P8?001P2P8?000`3@D7P0oh000?n0000:0?n000P0X23`
00D0oh000:0Pl03oP000oh000:0Pl0090?n000030=1@N02P8?00X23`00D0oh0000<00?l0oooooooo
ool03_ooool000kooooo0P00o`00903^hn40OV9N07U2?@2CA400X3`n0:Ld>@2h?dD0]dA;0:PoA02Q
ATd0^Fab09eOI028Ee/0ll_C0?3@e@2?KWD0RV]a0<>U[@2oY:d0bZZg0:9iQ`2WKG`0V4]K0;15D`37
B5<0b41:0<U0B03:A4/0`TM:0;=;BP2FB4@0]h1i0:Z7P@2LR840WHj909jCS`80VXn;00T0W8j;09^=
RP2ISh/0VXn;0:2ET@2ES8L0Vi:=09Z?R`2KT8`00P2LTHd0N@2KTXd0WYF@0:>JU@2KTXd0QGag05iC
C`1<@Cd0J5YG095kO@2iS900g8nG0<EQJ`31C5D0cD]C0=A;DP3EB4h0fTiA0=M<D@3ECE40e4]B0<i9
CP3ACU<0bdY>0;`n@@2e>C/0[SHg0;4l?031DE00cf=Q0=Q/JP3FJVP0fVa[0=MWIP3JJ6P0eF5T0<eJ
G@3?Geh0eVQW0=Q^KP3CJfX0bF5R0<1IFP33Gel0Xe9;0:UdI03mf/H0l][00=K6Y03A`j00c;nM0;Z_
T`2XWHL0WiJ50:BKTP2RVYL0XI^K0:BNX02PVYh0XYfS0:2KXP2QVj80XY^S0::KXP2NUih0XIZQ0:2I
X02NUih0^:nd05aCF00Y7R80;B<T02hT8`0[9R80f=??0?7/iP3/i>40k^CR0?7Wi03bin40lnCM0>gL
dP3Scl@0e/2b0<>]V02bVX80[I1b0:B3H02SP5H0[8AC0;B9DP39WF00cZ5N0>BeK`3^_gL0lLEj0?gF
QP3oh8T0on:60?WQO`3cgWD0jmYX0>CDFP3Qe580fm5;0=S@A`3CcD<0f=190<k6?`3@b3l0al0b0<k8
=P34_RX0f=500>;KF@3dkX00S8Dd0:2NH@2b]8<0YJR90?Wkl000o`006_ooool2003o00<0X23`1`3o
P0030:0Pl080oh000P2P8?0V0?n000040:0Pl03oP000oh000?n00080X23`103oP0030:0Pl0T0oh00
3@2P8?050?n000030:0Pl03oP000oh0001@0oh003@2P8?0?0?n000H0X23`2@3oP0000`3@D7P0X23`
0:0Pl0050?n00003003o0?oooooooooo00kooooo000>ooooo`<00?l002P0^:>N07=8@P21@3X0TcXl
0:0g>`2e@4H0^TE;0;A7C02Q@DD0/F5T0:IUJ@20CU40hKRl0?WIg02SPhH0=aXN081UJP3G_<D0Wh6=
0;bFX`3Q[;`0TTiM0:51D02oAe<0a4E@0<M3CP33A4/0_d]<0:a8AP2DBdD0]hEn0:J8P02MRX@0VX^6
09Z?R`2KTXd0VY2>09^@SP2ISX`0VY2;0P2KT8`0102IT8/0W9>>09bAS@2JSh/209bAS@1<09ZARP2I
T8T0WiRB09bES`2NUI00WIB?08j3P@1_Gel0J4iA09EQI`3EOhP0^4iH0<U@E`3:C4l0cTY80=9<B@3C
CTT0dda90=E;B@3DBTX0ede=0=A9C03FCU00eDeA0=5<C`3<BT`0_T120;<h>P2_>CT0[3Pi0;0l?@32
CTl0eF5R0=5OG`3BGV40d5iN0=1RH@3@I680g7=`0>R0O`3/Q8<0ggMd0<aTH@2eGeL0VEi@0>o:^03/
e/40aKBP0:ZMS02PU8H0YI^B0:JMV02QVIL0YijQ0::IWP2RW:00XifQ0:6KW`2TWZ80XIbR0:2IX@2Q
Uil0WYRL09fGV`2NV9`0W9JJ09VCU`2_ZJd0Lfea02`V:00f;Bh0:RDR020M6035a;l0l_7/0>KUh@80
j^KU02/0k>OT0>gUh`3^i>80lNKT0?;Wh`3ei^40mnKN0?7MdP3ZdlD0hLBd0=2]V@2mV7h0]8][0:1d
D@2EICl0YgI=0:IeBP2lT5d0eJ]a0>BlOP3]ahH0m]6:0?SEQ03deG/0m]Qf0>oGJ`3Xdf00jMIN0>_K
H@3Qe580fm990<c3=P3MeDH0d<Pi0=[?B03Jd5L0l^^109VB@@2=S4/0/kF30:BXQ`3hn^l00?l001[o
oooo0`00o`000`3oP000X23`0?n000060?n000<0X23`0`3oP0000`2P8?00oh000?n0000V0?n00003
0:0Pl03@D7P0X23`00D0oh0000H0X23`0?n0002P8?00oh000:0Pl03oP0020:0Pl0P0oh002`2P8?00
103@D7P0oh000?n0002P8?0F0?n000@0X23`00<0oh000:0Pl02P8?002`2P8?0@0?n000H0X23`00H0
oh000:0Pl03oP000d51h0?n0002P8?050?n00003003o0?oooooooooo00kooooo000>ooooo`<00?l0
02X0imcH07URFP1nDdX0T4a;094g>@2gATd0_4E;0;a9CP2X@D@0Z59C0;9^K`2=EeL0XGMh0?KDd`3W
bLT0Ide>0:J=T@3ig^D0Z8NB0;J<V02WLh00NSY:0;5LK02/@e40^dMD0<A8D`31B4l0_Te?0:Q9A@2H
Dd`0^X^50:F6P@2MRXH0VX^809V>S02JT8h0Vi6?09bAS`2JSh/0Vi2<09bAS`2KT8h209Z?R`0j09jC
S`2HSHT0WI:<09nDSP2KTX/0W9><09jET02KTXd0WIFB09jFT`2UViT0Y9BD0::5Q`2OI6X0`FI]0;Q9
D038DE<0`4]20;U5=P2b@Bl0_d`i0<aC@P3@DT<0dU130=5;@P3DBTL0eTY90=E9BP3GCDd0e4a<0=I>
C`3>B4T0b4I80;ln@P2o?T<0[S0d0;Ll?`2c>cd0^4530<5?C`3;GU/0cVEQ0=A/J@3FL6`0eFm[0=af
LP3@JVH0`V]S0:i^I035Vhl0^YjC0:JCS02UV980WYBB0::IVP2PVYX0WiVK0:FOX`80WiVM01/0X9ZN
09fHW02OVYh0X9ZN09fFW02LUYX0ViFI09bFVP2NVIl0W9NM09VDVP2[YZX0Q7n303Da<P0^:2P0:2@Q
01HE402c/Zd0mO7^0>STh@3ZiN80kNCR0?3Rg`3bhn00lnCO0?;Ug`3`iMl00P3ai^00903aj>40lNKP
0??XhP3ej>00m^GM0?3NdP3ZelT0gLJh0=2cX`2nWH`0VGEQ08]OAP2@HDD0WVU:0:]cD034Rf00cYAR
0=^SJ03U/6`0j;MX0>c3J@3[bf@0hlaH0>?DD`3;_CP0f/a50>3>CP2lYc`0WI0Z0?[aU02ZXe<0Q8=0
0;NjQ@2RYXD0nO_`003o01[ooooo0`00o`000`2P8?00oh000:0Pl0070?n00080X23`0`3oP0000`2P
8?00oh000:0Pl0030?n000030:0Pl03@D7P0oh000240oh000P2P8?080?n000050:0Pl03oP000oh00
0:0Pl03oP0000`2P8?090?n000L0X23`00<0d51h0?n0003oP0005`3oP0040:0Pl0030?n0002P8?00
X23`0100X23`0`3oP0000`3@D7P0X23`0?n0000:0?n000040:0Pl03oP000oh000:0Pl080oh0000<0
X23`0?n0003oP0000`3oP0000`00o`3oooooooooo`0>ooooo`003_ooool4003o000a09bBR@1SB3l0
VVUT0:9HF@2[@TP0`4U?0;Y5B`2bBT/0XdM80:eSI02RIVH0Pe5@0<RNW`3B[jd0aZJW0;jPXP3Q`LH0
X7^30<>HXP2WLgl0RDaK0;EXN02J>TP0ZSi;0;<mB@2lAD/0_U1A0:15@02QGUH0[X5k09AgL`2KR8@0
V8Z709R=R`2HSXd0V8j<09^@S02HSHT0W96=09bAS`2KT8`0VHj:09Z?R`2LTHd0Uhb809nDSP2LTH/0
Vi:;09fDS@0209bCSP0S09jDTP2LTY00WY>A0:FATP2`SI40cHZA0;MCF`31CU<0ae5?0;M9?02/B300
]E/i09Q0602J?A@0/4dV0;U>;036E3T0be8o0<mA@P3?CD00dTe40=E@A`3DC4H0f4e:0==9B@3CBdd0
e4a@0=9;D@3;B4d0`T560;m1A@2d>C/0/S`l0:/i>037EeH00P3?HF00D03HK6X0eFUV0;aPFP2LF4l0
T65I0:f>R@2UTI00XiNG0:2EV@2PUi`0X9ZN09^FVP2ITiL0WYRL09bFV02KUIL0ViJJ09jIW@2NV9`0
WYNM09nIW@2NUih0ViJL09ZEV`2MV9l0V9JK0:FSZ02HTiT0?3Lk02XV9`0V8R40510=0:BPW@3flNh0
kN?R0>oSh`3chMl0n>3L0>_Bc@3/dlh0m^;K0?KSg03gi]h0m>OO0>kWh@3[j><0k>SW0>_YjP3^j^T0
l>_X0?;Zj03ej^H0m^OT0?[Wh`3ffmL0jlS20=N_Y`2oT8P0/7ma0:5/FP29DCX0Q4P/07Hl5P21BAH0
ReXG0;fH@03N`eP0hlmF0<nm?@3JaT/0i]1P08A[6`2DPbL0no2F0;N`G`1nOSP0/kIo0::VP`3hn^d0
0?l06_ooool4003o00030?n0002P8?00oh0000H0oh0000<0X23`0?n0002P8?00203oP0000`2P8?00
d51h0?n000050?n000030:0Pl03oP000oh0001T0oh0000<0d51h0?n0003oP0003@3oP0000`2P8?00
d51h0:0Pl0020?n000030:0Pl03oP000oh0000H0oh001P2P8?0H0?n000@0X23`00<0oh000:0Pl02P
8?004`2P8?000`3@D7P0oh000?n000030?n000D0X23`0P3oP000102P8?00oh000?n0002P8?020?n0
00030:0Pl03oP000oh0000<0oh0000<00?l0ooooooooool03_ooool000kooooo1000o`00Z03Cc/P0
FD]207ACC03CW9T0YTQ=0;]8C`2iAT/0]D]=0:U9B`2SDED0[fU[07i0@@1H8240S5UH0>fo_`3[`L80
ejn`07Y=DP2bPhT0ejF^09aWL@2gLGd0[e=P0;U?F`2P:c@0/ca00;]?C@2UBd<0XEiF0;V=Q01^DD/0
L5mH09B5PP2ISX`0VXn=09R=R`2KT8`0Vhj809f@RP2MSh`0XI>@09R=R@2KT8X0WI:<09^@RP2KTX/0
VI2909fBSP2NThl0WI:>09bAS@2OU980WI:@09f?SP2ZTI@0/HJ=0=65S`2lCUT0b4mD0<UBCP2_B3T0
WdX[0?RfPP3W/W00aI140:5U702=B@P0TdH>0:19702aDB/0^e8b0<ID>@3;DcX0d4lm0=9:?P3DBD80
eT]80=E9BP3EBD`0f4]A0=E:D@3CB4l0cdI=0=5:D037@TL0`Sm50;dl@@2i?Cl0ZRla0:`f=P2U@Sh0
RD0j08eJEP2bT8h0XXj?0:6EU`2PUI/0X9JN09bFVP2PVYh0VYBF09fGV@2LUi/0V9>G09^FW02MV9h0
UY6G09^FW@2KUY`0WYVP09^FW@2MUj40WY^T09ZGWP2[ZJh0Ui:H02hX;00/9RP0:R@V01H@402QV9T0
o?3`0?7QhP3dg^00o=kN0<RRW`1dBdL0^96:0?oKd`3Yb;l0]iV?0;bSW03bhm`0k^KS0>gYj03/j^/0
inKT0>STh@3ZiN80knSR0?C[iP3djN<0l^KP0?;Ug`3diN00nNKR0?SSgP3bfM@0kLk90>2j/@38WH`0
cJ6407aD8`2hU4X0kM5^0>G>FP3E`DP0h/]K0:B;9`1/DPL0[9`m0?S^S@2n^Eh0O7da0;2eN`2NY800
nO_^003o01[ooooo1000o`020?n000030:0Pl03oP000oh0000D0oh00102P8?030?n000050:0Pl03o
P000oh000?n0003@D7P01P3oP0000`2P8?00oh000:0Pl00I0?n000030=1@N03oP000oh0000h0oh00
00@0d51h0?n0003oP000X23`0P3oP0020:0Pl0/0oh0000<0X23`0?n0003oP0005@3oP0040:0Pl007
0?n0002P8?00X23`0:0Pl03@D7P0oh000:0Pl0050?n00100X23`103oP000102P8?00oh000?n0002P
8?030?n000030=1@N03oP000X23`00D0oh0000<00?l0ooooooooool03_ooool000kooooo1000o`00
9`3em_40OgQ`05E2>`3AZZ<0VTa=0;=:C`2hBDl0/dU;0;=?D@2QB4`0Td980955B@1]9BT0SDU:0<R8
R03UZJT0`8F706T[;P2=D5D0ijbb0>R[/P2oN840Sc<n0:4g@@2R:S<0]Ci20;iACP2SBD40Xf1H0;jB
R@2PPgd0LUmI05Y;B01gJFP0U8J509bAS`2KSHX0W8n909jAR`0209nASP1209fBS02NThd0WY>=09nD
SP2JTHX0WIB=09fBSP2LTHd0WI:>09bAS@2NTi40Wi6@0:FCT`2YRhd0^HR>0=1iQP2oBED0cTeB0<Y=
B`33EdX0O2L80<jEGP3kdHD0l<ea0?7?K@3S^Uh0bi]70;5i;P2CDPh0UD/<09]94@2ZCQ/0_5@[0<EB
<`3<DS/0dDlo0<m;?`3CBT@0edU80=a;D03IB4l0edI=0=Y:D`3FATl0fDUB0=95C@3AB4l0c4M:0<94
A`2dBDP0TTA0095JE`2fTi40YI6B0:2EV@2NUIX0WYNN09ZDV02LUYX0ViFI09ZEV@2NVId0ViJL09bG
W@2HTiT0W9NN0P2MV9l0902OVZ40WiVS09VFW`2LVJ80X9fT0;Ja]`2ARY40:B<W02`V:00^9BP060lB
09nCU@3lk>d0lm[M0?_Mg@3K/[40Nd]70;:1O03]_[P0_I2:0718@01D;bH0QFQP0?KUgP3cj^D0l>[Z
0=??cP2?RhX0LFeZ069MFP1fLFd0ViB>0=?<aP3^jND0j^GR0>cXi@80k>OT01D0l>SV0?CTi@3hg]l0
omkI0?oRdP26HSh0_IaI0??FN03Vce/0iM1I0;fX?`1aFP00OfP?0>7CJP3[hgP0blMV07Uk:02[/GD0
W:9l0?WkkP00o`006_ooool4003o00`0oh0000<0X23`0?n0003oP0000P3oP0020:0Pl080oh0000<0
d51h0?n0003oP000103oP0000`2P8?00oh000?n0000I0?n000030:0Pl03oP000oh000080oh0000<0
X23`0?n0003oP0003`3oP0050:0Pl0030?n0002P8?00oh0000D0oh0000<0X23`0?n0003oP0005@3o
P0040:0Pl0030?n0002P8?00X23`0080oh0000@0X23`0?n0003oP000oh001P2P8?070?n000P0X23`
00<0oh000:0Pl02P8?000P3oP0020:0Pl0<0oh000P2P8?050?n00003003o0?oooooooooo00kooooo
000>ooooo`D00?l005D0_[fh04e5>P2NR7d0Qda909a2A02/ADP0[4A50;5:C@2TA4P0V3]309HlA@2L
@T/0Rc8h07/R9P1l9RT0NR@W08DZ;`1i8bH0XE5D0=Z;T02PCU@0SRXd0;Y;E031B4l0`dQ=0;i<C02X
BDD0WUMA0;j=QP2VQh80Y8n<08MeL`1PDU40DD=207IXI`2FQh@0Wi2=09f?S02NT8d0Wi6>0:>HU02N
Thl0W96=09Z?R`2KTXd0VY6<09bAS@2JSh/0WI:>09bAS@2NT8l0XI6A0:F@S`2]RHd0`HR?0<a^NP38
BUH0dDYA0<e8B@3>Edl0U3@L0:5M;P3och`0kla`0>[?I03_f6P0lmaZ0?7GJ@3M_U@0f;EA0;jC=@2R
L1/0TU8809U93P2[Cb00/d/T0<EB<`3@DS`0eDe10=Y<B03GATT0fdQ>0=U6CP3IAU00fTA?0080fTM?
00X0eTM;0=A<D034De40Y5=?09MPG@2eTI40YY:D0:2EV@2KUIT0WiRO0P2LUI`209bGW@1209nJX02K
V9l0VIJM09VFW@2OVJ<0W9NP09^HW`2MVZ<0X9fV09bIXP2LVJ00Yj:Y0;F^]@25Oh40:B0S03@[;P0b
9b/0710B0:6AU03ji^P0n=_M0?S?c@2MJfL0lkjh0>6^ZP2SM6h0N4e60:5jL`3?/JL0l]_C0?_/i`3U
fmT0NW9`06mWI@2HThl0VYFA08V4P@1gLVl0AT4n05IACP3:`l40j>?P0<g8a03HeM00iN;M0>SSh03]
hn80mN7R0?[Nf`3ohMH0NEPg0;VJF@3]dg@0iM1I0>gMH`2PTBX0HU@00;>V=@3VgV40i=mW0=OBJP1o
ObT0ZZm_09JJM@3hn^d00?l06_ooool5003o00040?n0002P8?00oh000=1@N0T0oh000`2P8?001@3o
P000X23`0?n0002P8?00d51h00`0oh0000<0X23`0?n0003oP0004`3oP0001`3@D7P0oh000?n0003o
P000X23`0?n0002P8?000`3oP0030:0Pl0@0oh0000<0d51h0?n0003oP0000`3oP0090:0Pl0030?n0
002P8?00oh0001T0oh00102P8?000`3oP000X23`0:0Pl0050?n000030:0Pl03oP000oh0000<0X23`
1P3oP0020:0Pl0030=1@N02P8?00oh0000H0X23`00<0oh000:0Pl03oP0000`2P8?030?n00080X23`
1@3oP0000`00o`3oooooooooo`0>ooooo`003_ooool5003o000[0?3ak029QWd0IE]A079=AP2ACD`0
UdI509]0?`2H>3T0Wc`o09Pe>P2H<c/0_UIO0:PoAP2T>Cl0UbX`09@W;@2V=ch0Z3]109df>P2P@480
[4]B0:<h@02a?4@0aTUA0<I7CP2mBD`0[4Q809mDD@2mR8@0YH9n09n:Q@2STHl0VXb;07IXI`1?@D00
E4I507maKP2MSh`0XI>@09nASP2OU900XIJB09jCS`0209^BS@1j09R?RP2NThl0Vi2<09fBSP2LTHd0
WY2?0:RFUP2[TI80/hZ>0<R9TP35HVh0c4YF0=97CP3CB4/0ce1:0;=4<`2B=aP0hYYX0?FmL`3fbW40
lm1Z0?GGJ@3^e6D0k=ES0??LK03cfFX0km=X0=fgE034TCP0/G8U09mA3`2ZC1P0`58]0=5C?03EBd00
eDE40=Q6B@3LATl0fD=>0=HoB03NAe00gDI=0=Q5B`3BATT0`dm>0:ACC`2EGU/0/i6@0:JBU02RUi/0
WINK0:>NY02PVJ00XIZQ09nJX@2NVJ00WIZQ09bIX02MVZ40VIJM0:2JY02LV:40WibS0:6NY`2OW:<0
WIZQ0:JQY`2UWZD0]Jnc07A[KP0V7Ah0=2X[03<W:@0S4a@0]jBV0?oZk03SaLD0PeMD08A@B`3@ViD0
`Xf90=^XY03b`kd0mLc60?OId@3ki=`0o_7[0;J/ZP0K4@l0R7il0?O`jP3ck>H0m>cY0>oZi`3Of]L0
ThZ;07Q_K`31^KL0RXF108N2OP2>RhH0QX9o0;R`[P3jinT0m]kN0?kRe`1lGD00]iMJ0?7FN`3TdE/0
jn1R08Mk2`28OP/0g=A?0=cICP3Wi6<0f]Q[0861:`2VZf/0TII^0?Sjk@00o`0Jooooo`D00?l000@0
X23`0?n0003oP000X23`403oP0000`3@D7P0oh000?n0000;0?n000030:0Pl03oP000oh000180oh00
00<0d51h0?n0003oP000103oP0000`2P8?00oh000?n000020?n000@0X23`1`3oP0020:0Pl0050?n0
002P8?00X23`0:0Pl03oP0000`2P8?0K0?n000@0X23`00D0oh000:0Pl03oP000X23`0=1@N0060?n0
0080X23`00<0oh000:0Pl03oP0001@2P8?000`3oP000d51h0?n000050?n000@0X23`00@0oh000:0P
l02P8?00X23`0P3oP0040:0Pl0@0oh0000<00?l0ooooooooool03_ooool000kooooo1P00o`00J`3^
kNT0a/>l08IgKP1dCdT0OTU3095>B02NCDX0WD9109`e>02M<3D0[S]20;4j@02l@dX0_D590;e0B032
@dh0`TA?0<17CP32CE<0^DE>09`T;@2b=Cd0bDE@0<Y8DP31B4l0/dY>09e<B`30Q8<0ZH5o09j6PP2N
ShX0Vi2<09jCS`2CR8H0K65O04/m?01_HF00V8f909nDT02NThd0WiB>09fDS@2KTX/0WIB=09VBRP2M
U8l0Vi:=09bCSP2NThl0WY2?0:FCT`2_TY@0/HB90=:?V031FfD0d4eE0=56C@3FAd/0e4Y80=1<A`2c
>Bh0Xc@P0:a:9`38LT40j9iQ0?ZlL`3mbGD0o=5c0?ODKP3be6H0kMAP0>gGGP3`eUd0l<mN0??3H@3Q
We<0X4HA0<YH=P3DCch0eDI20=a7B`3JAdl0fDI>0=I0B@3JA4d0fTE;0=E4B@3DBDh0`e5@09m@B`2F
Hel0/Y>A0:FCT`2TVId0X9ZN0::KXP2NUih0WiRO09jIW`2MVj00WIZQ09bIX02MVZ<0VYNP09nLY`2O
Vj@0XifW0080Y9nV03T0XijU0:6LXP2UWZD0/J^_06AKGP0[8B00<BDU02`N7@0`7Qh0g<S70?o]jP35
ZJH0[HN40>:e/P39V9@0[WAc0;AhM`2>Ee@0NDQ308]YH02_UXl0n^_T0>KMf02j[j/0gmC@0=C9``2o
]Zl0b;nh0>3Id`3omo@0d<S605Q>C@2SVIP0c<;108MoO@2TWi`0b/C40<g3a03gi>P0mMgM0?oSf`2A
LeL0[HiG0?;HP`3Qcel0gmEB0:JN6@3>ac/0em<k0=cJA`3RhU`0g]i`07eo:`2OYFL0RY1Z0?Sjk@00
o`006_ooool6003o00030:0Pl03oP000oh000080X23`7P3oP0000`2P8?00oh000?n0000@0?n00003
0=1@N03oP000oh0000H0oh000P2P8?050?n000<0X23`1@3oP0000`2P8?00oh000:0Pl0020:0Pl003
0?n0002P8?00X23`01`0oh000`2P8?020?n000030:0Pl03oP000oh0000@0oh000`2P8?001@3oP000
X23`0:0Pl03oP000X23`00<0oh0000@0X23`0?n0003oP000d51h1P3oP0030:0Pl080oh000`2P8?02
0?n000040=1@N02P8?00X23`0:0Pl080oh0000<0X23`0?n00000o`004?ooool000kooooo2000o`00
D@3^j^@0]ZFN08e`JP21EU00T5IB09A:A`2QBdX0[D]<0:]1A@2[>3d0]3]00;e0AP2o?DD0b4A?0<U3
CP3:AU40cD]E0<52B`2f=3h0`cm:0<]3C`3;Ae80aTUA0;U;CP2OADD0]W9a0;:5PP2NPWh0X8n809N<
QP2JSh/0W96=0:2ET`2=PH40FTe<05mDD024NGD0WI:>09nDSP2QUY00WIB=09bCS02JTh/0WIB?09^B
S@2LThh0XIJB09f?SP2GPX40[hnB0;J5R`3FSYT0_eMP0<m<DP3DAdd0e4=80=A5A`3@A4<0eD]90<U5
@02g?bl0YSXP09Xi5P2MBAX0]6d_0=:DB`3W/el0m<U[0??CK03We5P0i=M;0>_ID`3ae5`0om5e0:aV
8@2iCbL0dE<m0=Q;@P3IAdP0fTM=0=M4C0020=M1BP1A0=U4BP3GAT/0cdA90<ACD`2HBTH0W6]W0;>E
T`2STi@0XiZM0:6JX@2TWJ@0X9VP0:6JX@2PVj40X9jS09jKXP2MVZ<0W9VR09bIY02MVZD0ViJR09RB
W02DSYP0SHR?08J1R01hLgT0KFM[07afNP1<@dH0;B4Q03HV9P0/61L0D3Pf0?;He`3kh]h0n]gI0>k<
bP2^RHP0iKNg0>:ZZ`3;Shl0cI>A0<BDT031X9T0NfMP0?3Ug`3FclT0UX^708QmN@1/He`0J5mH0519
@`1>Ad40QGej0:FMVP2VW9/0U8Z90:RNW@2YXIl0dlg=0>SRi03`iNT0l=oU0?;LgP3oiMh0/iAo09=c
A03df8h0h<eV0=cAD`30^Bd0hM]50=?@<03NgDD0h>1J0>;QM`1]LAd0SYAF08bBK03hn^d00?l001[o
oooo2000o`000`3@D7P0oh000?n000020:0Pl1@0oh0000<0X23`0?n0003oP0001P3oP0000`3@D7P0
oh000?n0000>0?n000030:0Pl03@D7P0oh0000@0oh0000<0X23`0?n0003oP0000`3oP0000`2P8?00
oh000?n000020?n000<0X23`0P3oP0000`2P8?00oh000:0Pl0030:0Pl0<0oh000P2P8?0J0?n000<0
X23`00<0oh000:0Pl02P8?000P2P8?090?n000030:0Pl03oP000oh0000<0oh000P2P8?070?n000D0
X23`0P3oP0001P2P8?00oh000:0Pl03oP000X23`0?n000@0X23`0`3oP0000`00o`3oooooooooo`0>
ooooo`003_ooool:003o000X0?K[i`3B`;`0Z8b808MPF`23CTX0UU9?0:AED@2/DE00[TI70;91@`2h
?d@0^ca30<0lA`36@4/0bD=>0<a4D03?Ae<0cDE?0=17D@3=Ae00bTQ@0<9>D@2U@D<0[5iL0;b7P`2P
OgX0V8Am09Z=Q`2ISXX0Vi2<09Z?S@2MTY00Uhb:05mDDP19@3/0IU]G08^0O02NThd0X9F?09bCS080
WYF>0P2MU8d0MP2PUHl0Xi6?0:>9RP2bRi00_hJ=0=R;U@2mDU/0cDY@0==8C@3DADT0eTE80=I7B@3?
AD<0d4a70<U?A034ED80]dlf0:538@2H?a<0S3X809973P2PHb@0/84i0>O<H03SeTT0j=U<0>WBD03o
gg@0bHi00:E7503BFSl0ddho0=A6@P3E@d@0fDI<0=Q2B`3I@d`0fTM?0=Q7CP3AAT/0a5=C09U;B@2M
K6P0/YBB09n?T02OUYT0V96H09F>UP2BRi80S8F<08N2R@21O8<0O7J007MaN`1^JgH0J6Ab05mKJP1L
EfD0CdUE04M4C@12?dH0BdI=04Y5B`1?BTh0G5IJ03P]<@0f9RT0>b8U038D5022Hf40j<K40<:PWP2A
Kfd0JDY80;^IV@3aalP0jkVh0=VSX@2]O7P0`Y^F0?oXi03ai=h0j>3M04A1?00n=S<0WIFB0;2[Y@2l
]k40[jZV08f8Q01QG5T0If9O0=WAcP2QVIH0OgYg08AoO01[IfH0M71a0??Zk@3`hNH0l]kP0?gUh@3I
_:`0NEDa0>S6R@3^e7d0g/iM0<:h=03OfDL0c//^0=cK@`3Ph5X0i>Eo05aQ4@1mQDT0SYI_0?Oik000
o`0Jooooo`X00?l000<0X23`0?n0003oP0000P2P8?0B0?n000030:0Pl03oP000oh0000P0oh0000<0
X23`0?n0003oP000303oP0000`2P8?00oh000?n0000?0?n000040=1@N02P8?00X23`0:0Pl0<0oh00
0P2P8?020?n000030:0Pl03oP000X23`0080X23`4P3oP0000`3@D7P0X23`0:0Pl0040:0Pl0030?n0
002P8?00X23`00<0X23`0`3oP0000`2P8?00d51h0?n000040?n000D0X23`1`3oP0000`3@D7P0oh00
0?n000030?n000@0X23`00@0oh000:0Pl03oP000X23`0P3oP0000`2P8?00oh000:0Pl0050:0Pl003
0?n00000o`3ooooo00oooooo000>ooooo``00?l000h0ooGc0>OEd@2mXId0UVmZ089?B`2>CdX0UDY5
0:A>C@2YBd/0ZdA709T/<@2U<3T0^Ce80<@nB`80bd==0900d4MA0<a4CP3<ATd0adaA0;U<C`2OAdH0
_Gek0:^0NP2ENW<0UhIo09N:Q02KT8`0VXn=09R=R`2PUI<0WiBB08EjN01ICTX0Ac`h06EGE029OWP0
WiB@0:>JT`2QV940WIB=09bCS02OTX`0YY:A0:V;S@2eR8d0aHJ>0=N1S02nCUP0cdU@0==8C`3CA4X0
eDI:0=57A`39B4<0b5980<1GA02UAb/0S3L@08Ti202>@@T0R44307lk001e?000DbL00<R_A03SedL0
i]Y60>OEB`3cfV@0k;eQ09Y83P33Ec<0dU4l0=98?P3FATD0eTA70=Q3B@3JA4d0eT=;0=I7C@3?Ad/0
`55B09M<B@2RLW00U7Qg06QJFP1IDeL0Ee1G04i7CP17@4L0A3e404I1A`16@DP0B4=:04Y4CP1=Ae<0
E51N05UEH`1UH6h0JVA`07AaNP1lNH00Pgj508^6S02RWJ40TXb>03DZ;P0l;2l0@BP/038D5P1hF5T0
Of1M05dk>@1oGE/0c:j/0>W9a`2EK6X0k[bk0;n>RP2;Ge`0P5mJ0?_Xi03il>/0hmkJ03@a;01QG5P0
fMC@0>gXi03`kNP0l>_X0>oZi`3[i^<0P7]h0;Ze/@3hlnl0lNcX0?[fl`2:QXD0Qh>40?C^l03/hND0
kmoR0?KRh@3hgM@0RFE=0;:=H`3gf9D0hl]a0<2`?`3Lde00dlln0=oMC03Oge/0iNR105mV601hP4@0
SIE^0?Oik000o`0Jooooo``00?l000D0oh000:0Pl03oP000oh000:0Pl00M0?n000030:0Pl03oP000
oh0000X0oh0000<0X23`0?n0003oP0003@3oP0020:0Pl0030=1@N02P8?00X23`0080X23`0`3oP000
102P8?00oh000?n0003oP0020:0Pl0P0oh00302P8?080?n000P0X23`00<0oh000=1@N03oP0000P3o
P0060:0Pl0030?n0002P8?00X23`00@0X23`00@0oh000=1@N02P8?00X23`0`3oP0060:0Pl0@0oh00
00<0X23`0=1@N02P8?001@2P8?000`3oP0000?l0ooooo`0?ooooo`003_ooool?003o00240?3Uh@3=
_;D0VH1k07EDC@1nDd`0REQA08=9A@35PH00ZeIK09Te?@2d>TD0_c]60<@nA`3:@T`0c4A>0<i7CP3<
Be00`TiA0:]7A`2/GU`0_hF109agL@2CO7H0Th5m09F7Q02FRhL0V8f909V>RP2MTXh0X9FA09fBSP24
NGD0ET]7048g<`1XGE/0THJ20:6FTP2OU900WI:>0:>ETP2TT8l0[Hf@0;J3RP3>QY40e7J40<5:E`3C
BeD0e4M?0=A5B`3AATT0cDe:0<=CB02fEd40NcH?07]73P2[P380`Ye20<^XA037Y3`0_Idf0:nB;028
L0h0[9dV0>SNB`3TfT@0h]I60>cIF03meVd0ZfHQ0:i=8P3@Ec`0eTi00=E7@`3HATL0f4=90=U4BP3G
A4X0ddA80=59C@2mDU40RD@o09mcL02JPX00O71`07E_L`1lMG`0OGQn089kPP27PHD0RhJ:08f8SP2A
RY40Ui:H09ZEW02OVJ<0W9JP09fGX@2NVJ00XYfT09bGW@2MUYd0Ui6E0:^UZ@23OGl0<BP[03HZ;00f
9bX0<R0P0<nk^P3G`[l0g/G00?cPg03oi^80lLg:0<BDT03[^;D0i[Jb0:AoN@38[:P0nNOS0?3Uh@3n
mnl0`knf05M@B00o>380Ee1:09NBS03Hd<d0c<O309^FT`0j=C80ZZNR0P3Qg=H05`3Gd/h0/:fX0=KE
d@3]k>X0jN?U0>_Pi03_gn80o>CT0<^XXP1ZA340dZb50>g=T03:/Ed0i]M`0=SAEP3JeU00g]mO0>KY
PP1VKQ/0Mgm308B<I@3hn^d00?l001[ooooo3`00o`000`2P8?00oh000?n000050:0Pl0/0oh0000<0
X23`0?n0003oP0002P3oP0020:0Pl0T0oh000P2P8?090?n000030:0Pl03oP000oh0000D0oh0000<0
d51h0:0Pl02P8?000P2P8?000`3oP000X23`0?n000020:0Pl0040?n0002P8?00X23`0:0Pl1`0oh00
0`2P8?040?n00080X23`00<0d51h0?n0003oP0000`3oP0020:0Pl080oh000`2P8?040?n000040:0P
l03@D7P0X23`0:0Pl080oh001P2P8?000`3oP000X23`0?n000020?n000030:0Pl03@D7P0X23`00D0
X23`00<0oh00003o0?ooool03oooool000kooooo4@00o`006P3im?00fm;;0;6RV`2>NW40I4U20<NR
W03la/H0/6EY0;Q@E`2k@d`0^Ca40;hlA031>d@0aSm60<U6C037BTh0_Te?0:53@`2jL6d0]7mk09Uf
LP2CNWH0T7ij09>5PP2BQh<0VHj:0P2LSX/0@@2LTHd0YIZF09nDTP1oM780F4e;04Ll>P1/HEd0T8F1
0:2ET@2TUY<0XXf<0;2=T@2jPX/0fH^H0=9/NP34Ae@0dTIA0=I6C`3BAD/0cTQ90<I?B@32GTl0OC8C
08mP:03SaWH0l=ed0>WNHP3Yg5T0jmmI0>kQGP3^hF40j]]T0=g?D@3WfTh0i=M:0>KIC`3YeUH0omic
0=VOE@2H@Q40c5Tl0==>?`3HBTH0dd=30=Q3A`3JAD/0f4E;0=M8C03?B4`0^U5@08]:A02UOWT0ZiRD
0::HU`2MUiT0VIBJ09jIW`2NV9`0XYbP09fGV`2LUYX0X9ZN09bEW02QW:80WYVO0080W9NM03`0ViJL
09RCV@2ET9@0Ui6E09NAT`2_ZJ/0HeeO02TP8@0f;2d09adN04i2@P3di>@0o^WV0?oVhP3jfmH0h;fg
0>6d[`3BWi/0`8f909U/I`2>KFH0nnCN0?CUh03aj><0al2h0<W2^P3?b<80V96;05iGD@1QFU@0VI2;
085hL`19@Ch0PGUf0:bWX@0m>C00RHEl04Y5?`2JUi80jn[U0>SYi03Uhn@0j>;T0>_Pi03bgn<0oN3T
0:J5P01W@Rl0^YQc0=2bO03Ha7d0V8d_0=WEFP3QhFL0i>N006ad7`1jQ4D0Ph]T0?Sjk@00o`0Joooo
oa400?l000D0oh000:0Pl03oP000oh000:0Pl0020?n000030:0Pl03oP000oh0000P0oh0000<0X23`
0?n0003oP000303oP0000`2P8?00oh000?n000050?n00080X23`2P3oP0070:0Pl0030=1@N02P8?00
X23`0080X23`0`3oP0030:0Pl0030?n0002P8?00X23`0080X23`6P3oP0070:0Pl0H0oh00102P8?08
0?n000070:0Pl03oP000d51h0:0Pl03oP000X23`0?n000070:0Pl0030?n0002P8?00oh0000<0oh00
1P2P8?000`3oP0000?l0ooooo`0?ooooo`003_oooolD003o000H0>gXi02k/Zd0Th9k0;>FT02>GUX0
V4];0;M@E032DEL0a4]B0;m0A`2j=cl0a4590<=2A`38CE00]4I70:U;B`31Mg@0]7mk09YgL`2?Mg<0
TX1l08j1N`2AQX00V8f90P2ISXX0@@2KT8`0XIJD09nDTP2NU980OWAb05eBD01=@T00KF9P0920P02S
RXd0/X^@0;eoRP3NRYT0bUi^0<a:F03BATl0e4A=0==8C@3<BTX0aE9;0;AHB@1W9@80e;1V0?3MMP3V
fe/0h]a:0>7KA@3Uh4P0i=e70>SMC`3XfUD0jmQK0>WEG03ZeUd0im9K0>cBH@3geG40o<]o09iE8P2j
CS40dU130=E:A`3FADP0f4=90=a7C@3GADP0ddM80=1;C02eD4`0R4a40:^8Q02STHl0WYFF09nKW02E
T9H0VIBJ09VDV02MUi/0Ui6E09RBUP2ITYT0VIBJ09fHWP2FTIL0VIBJ0080VIBH03/0U8nC09JAU@2E
Si<0ViFG0:bVZ018@T80;2<T03D[;00Q5AD0PW9b0?_WiP3hg=T0dZZX0:n2O@3;W9H0i[>/09UVHP2d
QGl0UFaV06U<A03ehMX0m>WU0>SPg@19A400@Sdi05IAC@1ABDH0FE9<05mFD@1]HU`0UXV30<Bg/@3M
d/`0gMG;08Z1N027P7H0>SD_0<6n^@3al>`0i^KT0>CTi03Uhn@0j>CU0>KMgP3^g^40nN3S0:B7P`1n
HE<0U7IL06598`1BA0`0h]]a0>3MJP3Nhg`0Jg<N07J2@P1jQE/0nO_^003o000Joooooa@00?l000D0
X23`0?n0003oP000oh000:0Pl00;0?n000030:0Pl03oP000oh0000d0oh0000<0X23`0?n0003oP000
0`3oP0020:0Pl0L0oh0000<0X23`0?n0002P8?00302P8?040?n00080X23`00<0oh000:0Pl02P8?00
103oP0000`2P8?00oh000?n0000D0?n000@0X23`00<0oh000:0Pl02P8?001`3oP0090:0Pl0@0oh00
00H0X23`0=1@N03oP000oh000:0Pl03oP0080:0Pl0030?n0002P8?00oh000080oh001P2P8?000`3o
P0000?l0ooooo`0?ooooo`003_oooolF003o000i0?G`k03JcLL0/9NB08YHE`2=@d@0XDQ:0:m=CP2k
CU40`TeC0<56B`32@dX0_T140;e5A`2aADD0[U=B0;mhMP2^NgL0VGI`099iM02>NgD0SH1j09:7P`2E
RXH0Uhb809Z?R`2LTHd0VY2>09nET`2RV9H0X9FC08AiM`1OE580EDE507MMH02QMWd0_Wb80>::V035
EFD0bdME0=95CP3C@d`0cdA90<m=C@33DTX0[EA407De3`3/bGP0jm]Z0>CMD@3Rgd@0hn4o0>?O?P3U
g440hmA50>oFF03ecfH0llIY0080mlUa00P0n<Yd0?[7N03odi@0bgiB0:8e7P3>CTD0eD]90==2A`80
fdQ>00d0dd950==9B@3;Bd`0]5A@08YABP2`THh0XI6A09nFU`2LUi/0Ui:F09VDVP2KUYX0VIBH0080
V9:F00H0UY6G09RCV@2JUI/0Ui:H09NBUP2IU9P309JAU@0V09F?T@2WXJ<0X9ZJ03T`<@0^92D0=RXZ
028D502dXZ80ong]0;^IV01J:RH0^hAo0>ZaZP3?UY00i[6]0?c;a`28HE`0Zi290?[YhP3llnh0c<O3
02`X9@2e/Jh0dLc90;jf/`1BBTL09QdH06=FD01NDD/0ETU1071SF`39`;H0b;nf0<W2^P22OGT0WIbH
0?7`kP3Vi^@20>CTi00A0>CThP3Th>40i=WM0?KSj@3oin/0ZHf:05a0=00h7PL0ETPG0>?KN03Ng6d0
g^=m075k901aP3l0MH9G0?Okk@00o`006_oooolF003o00040:0Pl03oP000oh000:0Pl0/0oh0000<0
X23`0?n0003oP0004P3oP0000`2P8?00oh000?n000060?n000030:0Pl03oP000X23`00L0X23`1`3o
P0001@2P8?00oh000?n0002P8?00oh000080X23`103oP0000`2P8?00oh000?n0000D0?n000@0X23`
00@0oh000:0Pl03oP000X23`1@3oP0001P2P8?00oh000:0Pl02P8?00oh000:0Pl0<0oh000P2P8?09
0?n000T0X23`00@0oh000:0Pl02P8?00oh001P2P8?000`3oP0000?l0ooooo`0?ooooo`003_oooolH
003o000G0?ofm@3JaLD0X7Yg08QEDP23@T00TT910:E7B02eBdl0`4U=0<I9C`37BU00`4M<0:i1A02Y
CDh0_7Ec0;R3O@2IM6`0T7E^08alMP2=PWh0SXF00968P`2ES8L00P2HShX0<P2MU8l0VI6>09jDTP2P
UYD0W9:A08YjN`1hFf00Kd5;09UBH03SQiH0aE1R0<m8E`3DAe00dD5:0=15BP3?BDX0b55;0;MGB@1d
;`P0i;e`0>_IJ@3Ped`0hmi40>?O@03Tfch0i]Q30>oFE@3baV<0_g/f0;EO;02nISP0b6m30=V3E03Q
Sf00o:f60?fTQP2]>BX0bdM30=E:C@3GB4h0eD9:0=U6CP3EA4T0cTI:0<Y<C`2^DE40U5aK0;2@T@2Q
TI80WI:F0`2JU9P0202KUYX0VYFI09bGV`2HTiL0V9>I09ZEV`2GTYP0V9>I0P2ET9@0?02IU9P0UY:C
09FATP2GTi@0ZZBV08N1P`0c:2`0=RLZ03PX:@0d8B<0hlk=0?oYj03U`[h0`8n;0=6FTP2mOWT0chn>
0<F;RP2JI680Rf9N0?KMf03diml0m^oY0>OTg`1ZIF40GEQD09N?S02KTi00<RXW02DK6@2PUI<0fm3<
0=;7`@3BbL80[:BL028K5@1MF5@0P7ai0;^j^03]k>X0iNGS0>GUi@3Ti>@0hn?S0>WUiP3/hND0kmoR
0?kXj`2LPgl0E3X]04@/4P1OD1`0g]Qf0>7QL@3Mi7d0Kg`T06Ui>01dPeX0mo_/003o01[ooooo6000
o`00103oP000d51h0?n0002P8?0:0?n000030:0Pl03oP000oh0000h0oh000P2P8?000`3oP000X23`
0?n000070?n000030:0Pl03oP000X23`00H0X23`00<0oh000=1@N02P8?001P2P8?020?n00080X23`
00<0oh000:0Pl03oP0006P3oP0030:0Pl0030?n0002P8?00X23`00L0oh001@2P8?040?n00080X23`
103oP0000`3@D7P0X23`0?n000020?n000T0X23`00@0oh000:0Pl02P8?00oh001P2P8?000`3oP000
0?l0ooooo`0?ooooo`003_oooolJ003o001m07kfM@1ai680FlU80;jLV02SLg00UUME0:9@D02VATX0
[3m70;50B@2jBE40]DiC0:eFE`2XHf00WfaX09efLP2DMg@0S7Qd08mnN02=OgP0Rgmi08f3O02@Qh40
Thb609RAR`2JTHh0VHn>09bBT@2STi<0Z8^>0:ioQP2iLGd0fW^:0;m9G03ABUX0ddEA0=E5C`3BADd0
d4M:0<Q:A`38Edd0SSDI0:AW;`3`bg<0j]IN0>GKCP3UgTP0iMe50>GIA@3liVH0_YDg09I;502eCbh0
]DH/0;M1;@2f?bd0]3l]0:hm;@2jA3T0^3Ha0<e4A03EBTd0eTM=0=E5B`3FATd0ddI;0<e9CP32C4l0
YDmA0:5^L@2`TY@0X92C09jCV02LU9X0W9FK09jHW@2KUIT0Ui6E09bFV`2JU9T0VYFJ09^EVP2HTiP0
V9>G09JAU@2ET9<0VI>F09FAT`2FTI@0V9FF0:ZWZ01HDU<0;28S03`/;`0Y5QP0OFU[0?3Gf033XJ<0
[HF40<nQWP3CX9l0g:JU0<N>S@3FX9h0cIVI08iVI@3[dm00mn[V0>WQgP2ZYJ40[JJS0927P`1oMFl0
QGYd0:ZPV@2bZ:80SX>006]QG`1aJ6<0a[jg0:6IT`2LUi@0QX5n0;:^[@3YinL00P3Vi^D20>CTi00A
0>GTh`3Xi>@0jn7R0?3Ph@3ji^H0Rg9^054g:016;Q80H5<O0=oJN03LgW80g^F306Mc8`1AGRT0WJV9
0?[mlP00o`006_oooolJ003o0004052@N020`000P<000:0Pl080oh0000<0d51h0?n0003oP0005P3o
P0020:0Pl0P0oh0000<0d51h0?n0003@D7P01P2P8?000`3oP000d51h0?n000080?n000040=1@N03o
P000oh000=1@N1X0oh0000<0d51h0:0Pl02P8?000P3oP0030=1@N0H0oh000P3@D7P20:0Pl080d51h
0P3oP0000`3@D7P0oh000=1@N0040=1@N0040?n0002P8?00oh000?n000X0X23`00@0oh000:0Pl02P
8?00j6Pl1@2P8?000`3@D7P0oh00003o000@ooooo`003_oooolN003o001i0?oim02]V9<0YX5k0;9m
N@3DSY00WD]?09Ll@`2C>3d0VdI907/a<P2hOGl0jKVi09a_L@2PN7P0UWAb08mbKP2<M700SW]g08]l
M`2:OgT0SHAo0968P`2CRHL0V8f;09j?S02WSH`0]8N:0<b6T03FN8H0_4UJ0<e9F03BA500dDA=0=95
C@3AA4X0cDE70<i<BP36EDL0RRlD09YG8`3baG80l]IY0>WGE`3Vfdh0h]M90>gOFP3fg6h0XFdO09E5
402aDBL0_U<c0<ME>`3:Dcl0bTm00<e?@`3ACTH0d4]60=A:B03@ATH0dTI90=15B03>Ad/0ad]=0;iA
E02KDE80Zh>30:^BU@2OT9D0WY>I09bEW02MUYd0W9FL09ZCVP2KU9/0VY>J09bEW02LUYX0V9:F09RC
U`2FTID0UY2B09RAT`2ESi40V9:F09FATP2QWj00W9^I03Da<00`:2H0=b/[02HF5`36][L0dK^n06mA
D`2=Jf`0^YRG0;jKV@3W_kl0bI^H09IUH@2JKFX0gKNf0?_Sh@3einH0kN?Q079ZJ00e;BX06Q0>01lD
400a9R00B3dg0597@`1XGU`0OWAb08f6P02PVI<0IUiI07]fLP1nNWL0V9NE0?;`l@040>CTi00?0>GT
hP3Vh^40k>;S0?7Sh`3bgM`0Nf9K04X`7`13;0d0GeDN0>;OOP3Mh7L0f>6804eH501jQ5l0lOSV0080
0?l06_oooolN003o00@0oh0000<0X23`0?n0003oP000503oP0020:0Pl0X0oh0000<0X23`0?n0002P
8?001@2P8?0X0?n000<0X23`0`3oP0020:0Pl0L0oh000`2P8?000`3oP000X23`0:0Pl0040:0Pl0P0
oh002P2P8?00103oP000X23`0?n0003@D7P50:0Pl0030?n00000o`000?l0013ooooo000>oooooal0
0?l004T0`KZb07MYGP1hHE<0f[F/0=2OV03BUYD0Xf5R09QDE@1T92@0Uf5Q0?oDe@2hQHT0SEEH0:Yc
MP2PLW80V71^099cL02?MW40Sgaf08ioNP2@Pgd0THJ209:7P`2MSX/0YH^:0;26R03:S940cgV20;M;
F03<BeT0cdI@0=54C@3EB500dDA:0=95B`3=ADL0cTm90<9@A@259@`0Xe/Y0?2lL`3kegH0l]US0>OH
E`3VfU@0jMYI0>[?H02YNbD0T5H<08M10`2JBQL0XTTO0;1@:P2mESD0`UDh0<A@>@3=D3h0cde00<m8
A03@B4P0cdY=0<A<CP2jEUP0U5AD0:b>SP2ST9@0WiBJ09ZCVP2JTi/0WIJN09nHX02ITYX0V96H0080
WiFM02l0WIJM09VBV@2ITiL0UY2D09F?T@2HTY80UHn?09R?TP2ES8l0[ZRZ08N3PP0^:2P0<B`Y03@/
:P0]9B80gMGB0?7Wi@3YfmX0j]SH0??Ng@3oiN80eK:^0:n6P@2lThd0DR/V0;NET`3mj>D0mnSU0>7F
e03EblX0dlg=08n9R@0m>CX09b<T0558B@2FSHh0WYBC07E[J@2;PWd0S8=l0:6IU02YY:00EE5>08b;
R@3blNl0i>CR0>GUh`030>CTi00=0>KRh`3[hN80l>;R0>cGe01_ETl0B2lK044Z2P1WGB@0hMmj0=kT
NP3@fX@0EElS0<O=/`03003o01[ooooo7`00o`060?n000030:0Pl03oP000X23`0080oh0000<0d51h
0:0Pl03oP0003@3oP0000`2P8?00oh000?n000090?n000030:0Pl03oP000oh0000@0X23`00<0d51h
0?n0002P8?003P3oP0000`3@D7P0oh000?n0000D0?n000X0X23`0`3oP0000`2P8?00oh000:0Pl002
0:0Pl0<0oh000`2P8?070?n000030:0Pl03oP000X23`00T0X23`00@0oh000:0Pl02P8?00d51h102P
8?00103oP0000?l0003o0000o`0@ooooo`003_oooolO003o000Q0=gNf01aKf80CTLg07IVEP38/J40
m]780=6TWP31SXX0/G]i08=AD02jR8T0ik2e08Q;D01n@DH0SeMH09YXI`2NL700W7Ab09=dL@2BMW80
U7eg095nN02@PGX0V8F109b2P@2YPH80`XN;0<YkP@2eCeX0adeH0<m7D@3AADh0dTE=0080dTE;05D0
e4M=0<m7B@3?CDd0aE1709Hb6`2D@QX0fi]K0?[:MP3ge700k=9S0>KBF@3^fV@0m=U^0>c:J03DZe40
]HDc0:5Y7P2EE100SDH609A32`2G?0d0[dLR0<IC>03>D440cTi50<I9A`32D500/eMH099LG@2ZUI@0
VhnC09bEW02IU9X0VIBK09bEW@2MUYh0V96I09^DV`2OUId0ViBK09bEW02ITYT0VI>G09fGV`2DSY00
Ui6C09B>T02ES8l0VI2A0;>ZZ`1SGEd0<2/X03<^:`0N6AD0G5MC0?3]j03[j><0kNGS0?3Ti03di>@0
nN7O0=>][03S]k<0Z7mi09YeK`3ee]40oNKP0?o_j02VUi@0C49005]EE@1aKFh0B4I902DS9P0Y92P0
CTQ:09bCU03Fc</0lnWW0:fTW`2g[Z`0j>?O08F1OP3<blT0k>_Y0080iNGS0P3UiND03P3Ti>@0in?T
0>SNg`3eiND0i<o<06I>@P15;1H0@Rh9071Z:@3OhWL0gnIn0<79O02FWVd0m_[Y0`00o`0Joooooal0
0?l000<0X23`0?n0002P8?001P3oP0000`2P8?00oh000?n000030:0Pl0`0oh0000<0X23`0?n0003o
P0003P3oP0040:0Pl2H0oh000`2P8?000`3oP000X23`0:0Pl0040:0Pl0D0oh000P2P8?00103oP000
X23`0?n0003oP0040:0Pl080oh0000@0X23`0?n0003oP000X23`0P3oP00:0:0Pl0040?n0002P8?00
oh000=1@N080X23`0`3oP003003o013ooooo000>oooooal00?l004P0m_Sc0;6bZP1SI5H0CDXg08Qm
J@3>^JP0cK2R0;>=Q03H[JL0_8n<0:MgM`35TYD0b96F0;=jP02eOH00Z6ea08iCF@2LI6L0XVm^0:1c
KP2LMfl0UGM_099iLP2FOgT0VGah0:=kN`2jPHL0`gQo0;ACGP3:Ded0bdQ@0=19D03AATd0dTM>0=A7
C`3BADd0dDI;0=A9CP3BCDh0cU5=0:Pg:@2B;1<0]Edg0>BMI`3k`Wd0n/eh0?3AJ`3]eVH0jmIQ0?CO
JP3dgFT0kmQV0>G9G03I^540dJU:0=fVEP2dJBl0Wd8G0<UG?03;DT40aTm70;YACP2[FUL0TFET0:JH
V02HSi80V9>I09VDVP2KUY`0VIBJ09NBV02ITYT309ZDV00o09VBV@2DSiD0UY6G09VDVP2FTID0UI2D
096=SP2DSY00X9ZJ0:NNW`0l=380<b/Y03@/:P0H4a00WIRE0?Odk`3Yi^40jn?Q0?3RhP3ehn<0lmOF
0:UmOP3FXZ40fJVW0?kGdP3ifm<0h<Fl0:N@R02gYYl0akbj09nIV@2<R8T0LFa`04i9C@0j=3P0:28T
01/E5`17?Sl0OGEc05YBD01`J6H0c/W606]WI03Yj>H0j>OU0>CThP3Ti^<0i>CT0>?Sh`3Uhn@0i^3R
0>SNg`3ijNT0f<Bm05e6>018<QX0?B`108Z5=`3Igg<0h^Z70<K?T03QilD0oOoe00<00?l06_oooolO
003o0080oh000P2P8?0<0?n000030:0Pl03oP000oh0000P0oh0000<0X23`0?n0003@D7P03@3oP000
102P8?00oh000?n0003@D7P50:0Pl0@0oh0000<0X23`0?n0003oP000103oP0000`3@D7P0oh000?n0
000C0?n000@0X23`0P3oP0050:0Pl0`0oh001@2P8?020?n000030=1@N03oP000oh0000X0X23`0`3o
P0001`2P8?00d51h0:0Pl02P8?00oh000:0Pl03oP0000`00o`0@ooooo`003_oooolQ003o001f0=GF
cP1nP780G5U8075UE@1iJ5P0GDDi0=2bZ02EL6X0c:>O0<2DU03GZJ/0g:^^0>fk_030S8h0[75g09eR
IP27DE40OTe908eRF`2MNg40V7Y`09QlL@2HMg00X7Mc0;IkO@2nLgP0ZDYB0<9AF@39C580cDaA0=1;
D03ABU00d4U?0=58C`3CB4l0eDQ>0=I;D03CBdl0eE1C0<=7A@2Q;b@0TRhG0:aG<P3DReP0mKec0?S?
L`3ddF/0l]IX0>oFHP3]f6<0kmaV0>oJI`3df6d0omao0>nfK`2AAA40`5Tf0<IF?P33EDP0]EM?09mH
E02IM780WYBE09^EV@2FTIL0VIBJ09ZEV`2IU9X0WIRN09^DV`2KUIT0V96H09bEW02JUI/0Ui:H09JA
U`2ET9H0UI2G09JAU`2@Rhl0RXJ709jJV@2<QXH0:b<Q03L_;@0`:2H09R4N0=;>b`3akNX0j>CQ0>gS
i03_gn80mn7T0>o?dP2QL7@0`8J90;n7QP3ic/P0]IB;0<FXX01`FE40^:NP0?cbl03`j^X0kN_/0>cZ
j`3UhN80eM7B0<O3a02SWj00S8R908R2Q02/YZH0PWal06QTH`1/J6D0k^g[0>OWi@80hnGR00l0i>CT
0>GSi03Vh^<0imkQ0>[KgP3mjnT0b;:W058k:@14;a80>R`00:VWC`3GgWH0i>fD0>7W]`3ko^T01000
o`0Jooooob400?l000<0X23`0?n0002P8?003@3oP0030:0Pl0H0oh0000<0X23`0?n0003oP000203o
P0000`2P8?00oh000:0Pl0040?n000040:0Pl03oP000oh000?n000H0X23`1`3oP0000`2P8?00d51h
0?n0000D0?n000@0X23`00<0oh000:0Pl02P8?000`2P8?090?n000D0X23`1P3oP0000`3@D7P0oh00
0?n0000:0:0Pl0<0oh0000<0X23`0=1@N02P8?000P2P8?000`3oP0000?l0003o0002003o013ooooo
000>ooooob800?l00280k>gW0;bl]02FTXL0P7Q]0514>028MV`0Yhn50;RMU03@/ZX0UG1Z0=F`ZP3j
em<0c:JS095UI02PM7<0XGQf0:R1O026HET0L515089RE@2HN6/0XG]`0:QgL02gNWL0`WAd08d^<P2^
@DD0`dmB0<A<CP36BDd0adU<0<Y9C@3@CU00dda@0P3ABDd0@`3BBE00dDY@0=19C@3ACdl0b4e80:hi
;`2E:QH0Z4XY0=J4E03[XfP0nKYe0?c4M`3lc7L0n=1a0?G?K03cbfT0nLed0?oCR`2UIS00XdTT0;mK
@@2lFdX0[e]@091CCP2QPh40WiFF09nIW@2NV9`0VYBH09VBV@2GT9P0W9FM09N@V02BRi80ShZA08j9
T024OhH0Pgj5081kPP1hLgX0J6E^06EQJ01NFF00@d5407EaLP1/IVP0?3Hf05YADP0Y8240CdU90>kZ
j@3YiN@0j^CT0>kRi03cg^<0o=oT0<ZRZP2BHFL0`H>60:EXI`2gQX40SFQP0:V>Q@2gYYh0j=gG0>gX
i03Wi^@00`3Vi^@20>SXiP090>WWj03Zj>T0i^CU0>SVi`33`L40SXf;0=_Jf03/k>`0iNGU00<0hnGT
00h0iN?T0>WPh`3/gN80k]kQ0?k[i`2PRWd0BC<L040]300n<`00bL][0=cSQ03VkZD0loKG0?_lm0@0
0?l06_oooolR003o00050:0Pl03oP000oh000?n0002P8?00303oP0030:0Pl0@0oh0000<0X23`0?n0
003oP0004@3oP0020:0Pl0d0oh0000<0X23`0?n0003oP0004@3oP0001@2P8?00oh000?n0002P8?00
oh0000P0X23`0P3oP000103@D7P0oh000?n0002P8?020?n000`0X23`00<0d51h0?n0002P8?002P2P
8?030?n000040:0Pl03@D7P0X23`0:0Pl080oh001000o`0@ooooo`003_oooolU003o00170>k^iP3D
d<L0Z9nF0:6DR`2`XYL0a[F[05Hn=02MQG/0hL[20>7:a02gViL0]IVF0=6e/P3cf]H0g<>n0:F<Q@24
K680L5E:07eMDP2@IE`0[gQc0<J2O`2EA440VCTi0:m5A@2cADH0^DM70;i:B`32BT/0ad]=0<Y<C@3<
Bdl0cdaA0<a9C`3ABe80cTU>0=9;D@3ED5D0dU1B0<]>C02h@3T0WS4M09Xe6@2RA200]5d`0<UiA03C
S4`0j:EO0?>cJ`3h^GH0olN>0>bXN`2J@B40^5Q20;IMC@2WGE80REA@09b2PP23N7`0OWQl07QbMP1]
If/0J65X061IH@1JDe/0BT=;04a5C01?B500BTE;04]6C01DCeD00P1HDeX08`1GDUT0HEaS06MRJ01j
N7/0T8b=048n?`0o>CT0HUaL02@N7P2ARh/0mO7`0>KRh@3Zi>@0k]oR0?SQi`3bdmT0a9^Q0>Vh_031
QXH0T5EA09i_J@33WYH0f;ff0?WVg`3bi>40k>;P0>_Sh03[i=h0k>?N0>_TgP3Xhmd0j>GP0>OSh03V
iN<0inGV0080iNGU00@0alO50>WYi`3UiND0hn?S0P3SiN@03P3UiND0in?T0>[NhP3/g=l0m>3Q0?3K
eP1^EdL0AC0C03PY001eKRX0em]f0>C[V`3]m<00nok[1@00o`0JooooobD00?l000<0X23`0?n0003o
P0002P3oP000102P8?00oh000?n0003oP0020:0Pl080oh0000<0X23`0?n0003oP0003@3oP0020:0P
l0H0oh000P2P8?080?n00080X23`1`3oP00:0:0Pl0@0oh000P2P8?000`3oP000X23`0?n000050:0P
l0@0oh0000@0X23`0?n0003oP000oh003P2P8?000`3oP000X23`0:0Pl0090:0Pl080oh0000<0X23`
0?n0002P8?000P2P8?000`3oP0000?l0003o0003003o013ooooo000>ooooobP00?l000X0moC_0>CO
f@2m]Zl0QGac08j4NP2XWiH0^k:[0=;9a03_iN<0ooKe0`00o`00LP3fkNP0fm3:0;ZYXP2GOWT0SFaU
08mRG02:DDX0TDM109Y1?@2R@3d0Z40m0:Ln>`2dATD0]TA40;m9B@35CU00`d]=0<A<CP3:Ce80bdiB
0<U;CP3>CE40d4mC0=5ADP3?Cdl0c4m;0<97?`2g?S<0/CT[09l/6@2M;AL0Wc<I0:4i702gE3L0`VA;
0=enJ02S?Bh0]U550;IOEP2JEE00T6=P089]K@1KEEL0GEMK05]FFP1LEUX0GUQL069HH01[HFT0JEmW
07E/L@1lLWX0OgUm08N1Q@29PhL0RH:908f6S@2ARhl0UI2C096=SP2/Z:L0RXJ502dY:00X9240:RHS
02`X9@3EdLh0lNgZ0>OSh03Yi>40kn7Q0?[TiP3_dM<0[8F60:UlN@2cPW`0Y7Q_0?WBb`3ge/l0hlBo
0?7He03dhMd0mN;N0?OPfP3fg]@0n^3C0?_Qe03fhmD0l>;G0>cSfP3Yi=h0jNKQ0>KUh@3Jf]P0WIfM
0>c/k03UiNL0i>CV0>;Th`3Ti>@0i^CU0>WPh`3/gN00k]cL0?_Vh`2kXY/0BS4M040/1`18?P40aL=`
0=_TO`3[lkL0n?gM0?_mlPD00?l06_oooolX003o00030?n0002P8?00oh0000D0oh0000<0X23`0?n0
0000o`000P00o`001`2P8?00oh000?n0003oP000X23`0?n0002P8?00403oP0000`2P8?00oh000?n0
00080?n00080X23`0P3oP0000`2P8?00oh000?n000030?n000030:0Pl03oP000oh0000l0oh00102P
8?000`3oP000X23`0:0Pl0030:0Pl0P0oh003@2P8?000`3@D7P0oh000:0Pl0090:0Pl0050?n0002P
8?00oh000:0Pl03oP0000P2P8?020?n000D00?l04?ooool000kooooo:`00o`00103^k^H0emO?0>KV
gP3jnO@9003o001M0?oflP3ah=T0f<6i0;^JT`2KJf@0RTe808M0?02@@C`0Ud8o09e2?`2M>cP0YClm
0:i4A02aAD<0]TI50;a:BP2mBDX0`T]=0<M?D038CDl0c51B0<a=D03?C540cTa>0=5<C`3AC4d0d4]<
0<e;B`34A440^chl0;4g=02W=2l0XS8^0;I9A02iF580[UeJ08U=C02GLG00WHb>09:<SP2AS900Ui:F
09RBUP2ESi<0V8nD09jEVP2QV9d0Vi:G09ZAUP2KUIL0W9JH09J@TP2ESi<0VYBF09F?T@2CSXh0VIFD
0:^WY01HE540920M034]:P0F4Pl0I61M0?7`k03Zi^<0jNCQ0>_Qh03`h>00n>3P0?SHf@3Q^KT0g:bX
0=JXX03meLd0eK2Z0<FTW`1WAD<0/Y>A0?oRhP3kfML0n<_60>NbZP3BW900cij?0>>l[@3efL/0m^CH
0?3Vg03Zi]/0inCM0>?SgP3MgM/0i^KT0080i>CT00l0hnGT0>CTi03WhN<0jMoP0>_Kf`3ch=`0mn3H
07]TE013:a40>BT008f6>03RhhD0g^N;0?7fc@3koNl01P00o`0Jooooob/00?l00`2P8?000`3oP000
0?l0003o0007003o00030?n0002P8?00oh000080oh0000<0X23`0?n0003oP0006`3oP0020:0Pl1D0
oh00102P8?000`3oP000X23`0:0Pl0040:0Pl0L0oh0000<0X23`0?n0002P8?001P3oP00A0:0Pl004
0?n0002P8?00X23`0?n00080X23`0P3oP006003o013ooooo000>oooooc`00?l001D0l^7N0<Za[@2W
QX40TVUS085?B027Bd<0SD@n098o>`2L@Ch0XCll0:@n>P2V?CX0[D4o0;94@`2lC4/0_de=0;i<C034
CU00bE5C0<Y?D@39CDl00P3?CU<03P3ACU@0d4eB0<i=DP3?DED0c4mC0<A=C`31E5L0^EeN09YCD@21
Cdh0YHN709V;S02CSHl0TXb>0P2DSY0209>=S`1009F?T@2HSi80U8^>09B>T02ESi40U8j@09:>S@2A
Rhd0U8j@096;S@2@RXX0XYfJ09B?S00i=340;2LT038]:P0H51<0YJ6P0?Gal03Xh^80jn?Q0>oQh@3f
h^<0mM_J0=Fc/P2_Ph80]h5o09eYI@35V9D0[8B20=:/Z`2VP7l0hKZk0?oQhP3U[jl0X59@09Y1?@2A
>300QcL/08]=@02OLF80bZfM0>WHb03[h]40i^?D0>WXg@3Wj>00i>GO0>GVh@3Shn40hnGT0>CRh`3X
gn00jmgL0>oNe`3nj]l0`ZfL04<^4`0j:000FDh@0<o:K03Kg7H0infR0?[li0L00?l06_ooooll003o
00040:0Pl03oP000oh000?n00080X23`6P3oP0000`2P8?00oh000?n0000C0?n000@0X23`00<0oh00
0:0Pl02P8?00102P8?030?n000030=1@N03oP000oh0000`0oh003P2P8?050?n000030:0Pl03@D7P0
oh0000L00?l04?ooool000kooooo?P00o`008P3on?<0mNKQ0=k7`@36YIh0ZGag095JE`26AD40T4I3
08/n>02F@cd0Vd<o09e2?@2TAD40Y48o0:U3@@2bAdH0^DU80;i:B`34CDl0bTmD0<]>E03;C5<0bdaE
0<e>E`3=D5P0bTiF0<AAF02lEe/0/EmQ0896AP2EKFd0YHf=09B9R@2?RH/3092:S01208n9R`2CSHd0
TXb<09F<S`2AR8/0U8^>09>=S`2ARh/0T8b;08j8RP2<QXH0SXR8092;R02VXIh0HEaI02/V8`0f;R`0
9AdK03/e=@3OfMT0knWY0>_Qh03_hN40m>;R0?SRi02lX9l0`IjL0>c0_`3W];<0VFUX07eCE02]QXL0
dj^/0=f_/@3oe=H0l[Jh08]1@P2WBDT0`emM0<=YH@2bIE/0T5I806Ln;01PAC00HE<i07UbF02m_:00
k>kH0>K[e`3Tj=T0hnOI0>?Vf`3Si=`0inCM0>[Of@3]g=80ln;@0?OVc022Kdl0>RT003X_002TWdd0
iNAj0=cNN@3`mKh0nog_1`00o`0Joooooch00?l000<0oh000:0Pl03oP0000P3oP0000`2P8?00oh00
0?n0000D0?n00080X23`5P3oP00:0:0Pl0D0oh0000<0X23`0?n0003oP0001P3oP0050:0Pl0<0oh00
2`2P8?020?n000060:0Pl03oP000X23`0:0Pl03@D7P0oh001`00o`0@ooooo`003_oooom2003o000N
0?oclP3_fmX0fKfj0;JET02NMFl0ReaD085;@@24AC`0RT@l09E6@@2PB4@0Y4@o0:Po?02/?Sd0]TI5
0;U6B@2h@dT0^dA:0<18D@33BeD0`TeF0<1>EP2nEUd0]EmR09MCE020DU80Y8J609R8R@2CRH/0SXR:
0P2@RX`0@`2?QXT0THR;0968R`2DRhh0ThZ=0927RP2BQh/0U8V=09:<SP2<QXP0S8J608f7Q`2@RXX0
V96?08j6P`0g;bd0<BTW03/b<`0L4a@0MFa_0?K]kP3^h^@0lMkP0?CNh03jh><0nMoR0=o1``3;ZJP0
`YbK09]bL02WPh@0jL_=0?oOiP3L/KP0MCLl0=j?TP31J6X0W3hn0<a_JP2oK6@0UEM<08QNCP2OQW80
ZIf50:2KO@25QF40/[B<0=ON/P35cjD0fnO10=oZb03Sk<l0i^_D0>CWdP3WiM00jmk;0>kNa03kjlL0
a[R;04<c0010=P00NG@H0=GGJP3Hgfl0iNb?0?KieP3ko?@01`00o`0Joooood800?l00P2P8?030?n0
0080X23`403oP0000`2P8?00oh000:0Pl00E0?n000@0X23`00<0oh000:0Pl02P8?00102P8?040?n0
00040=1@N03oP000oh000?n000<0X23`00<0oh000:0Pl02P8?000P2P8?050?n000030:0Pl03@D7P0
X23`00P0X23`00@0oh000:0Pl02P8?00oh000`2P8?000`3@D7P0oh00003o0006003o013ooooo000>
ooooodH00?l001X0o>gX0>SDc@3:[JD0ZhIn09Q[I@2:EDl0S4m:08Y1?02HAD40W4910:12@02P?3`0
YSm00:Hl@02Y?440Zci40:e2B02cC500Ze5C09]CE01lAT@0UW=_09f8P`2CQH80TXZ808j9QP80SXR8
0480ShJ70968R`2?QXT0SXF80927RP2AR8/0ThR<08n4R02DRhh0RhF708f7Q`2<QXH0S8N409bFT`1F
CT`0:b<Q03L^;`0b:BX08QTL0;fg^@3gk?00l^?V0?7Mg`2XRhl0[XnD0>W:c`3mgN00kl_;0=>`[P2F
M780m]gL0?[Ti`3oj>l0_Y>L07`c>P2bEU/0ZD950<=MF`37L6L0TTi309meI`3Xdl80[ZRB0820I01h
NEL0NW]A08b<FP2<SeH0HFP_06ikA@26U640]lBI0<7<Y03?d:h0hMfj0>kP_@3gi[X0i=FJ07a`:021
Mb80Yj8n0=?BG03MhfT0gNAj0>[cY03jo>P8003o01[oooooAP00o`020:0Pl0<0oh000P2P8?0=0?n0
00030:0Pl03oP000oh0001<0oh001@2P8?00103oP000X23`0:0Pl02P8?070?n000030=1@N02P8?00
X23`00D0oh0000@0X23`0?n0003oP000X23`1P3oP0030:0Pl0<0oh00102P8?040?n000<0X23`00<0
oh00003o0000o`001P00o`0@ooooo`003_oooom9003o000Q0?odl`3giN<0im;?0=Fi]P2/R8<0UfMS
08eFD`28Ad<0SD8m098o>`2J@Cd0WT0n0:=1@P2R@T<0X4Q60956@@1O9200QeaE0:25O02JRWd0T8Ij
08j5N`2=QWh0S8Eo08j6P`2<Qh@0ShV908f7Q`2;QHD0S8>60927RP2AQXX0SX>70080SXF603P0TXV:
08Z1PP2@RhP0RhB2030W:00c:2`0=BX^01XA501IDeL0jNCX0>gWj`3dj>`0l=_R09AfOP2EM7/0jLG9
0>[3aP2mUYL0dZn]07mQG`33[:`0mN;T0?oYk`3BYk00Rd990<Y[L@36GF40afER0;EXGP2?FT`0i<Vh
08IkJ@1[IU00THeb08j6HP1hJch0IETO06=H5P1hM2`0JgD`06Mf=@1VN3h0FFHa05mQ;`1eKC`0VhUG
09V5B02DQ2l0[:4g0=C<D03EdTd0gN5F0=CMH03Sk940k?Bk07koM0P00?l06_oooom9003o00030?n0
002P8?00X23`00<0oh0000<0X23`0?n0003oP0001`3oP0020:0Pl1D0oh002@2P8?060?n000040:0P
l03@D7P0X23`0:0Pl080oh0000<0X23`0?n0002P8?000P2P8?090?n000D0X23`1`3oP0040:0Pl003
08300000o`000?l000H00?l04?ooool000koooooC@00o`00E`20nWT0nNCQ0>oBcP3L]k40b9VC0:ef
L@2PHeh0UU9?099;A`2=B4<0O3df06Td;01hD4H0[i>709R7M@2CR780S8I/08b6K@2<QW00S8Md08Z4
M02:QWX0SHUn08V4OP29Q800R8>008b4PP2=Ph@0SXB308f3P@2:P7h0SHAo09B;QP2TViH0F51<03L]
;00j<34091/N03T`<`3@b/`0k>[[0>KQi@3[h>H0l=oW0?KOi`3eeml0]9BI081PH`36Z:P0iLW809Em
O@2`WYl0ln3T0?WPiP3oeMl0ZemY0:m@F03;I6P0b6YX0:=ME@2VN6/0/I^=05I??@3Of/H0em2f075Q
?`1TCb00b[Ef0:JBB@2_Y5H0TiE:06af<@1]McP0J6h`06eY:P1[H1h0JeTA06UG0@2aY3@0f]5>0<g;
>03KgTL0e]e?0>7ZM`3VkJL0mogI07koN@08003o01[oooooC@00o`000`20`000X23`0?n000070?n0
00<0X23`5@3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030?n0002P8?00X23`00<0X23`0P3oP0001@2P
8?00oh000?n0003oP000d51h0080X23`00<0oh000:0Pl03oP0000`2P8?020?n00080X23`1`3oP003
0:0Pl0L0oh00102P8?000`3oP000P<00003o0007003o013ooooo000>oooooe800?l00580ooGc0?_V
h`3[d/h0f;Vf0;^LV@2:KfP0[iV>0>OGb03Yg/X0a;nQ09fKM@2IUfh0T8mQ08^:GP27Q5/0R8IP08J7
I@26QVX0QH9_08F2L`2:QWd0Pgmf08^2O@2;P7X0SX5h08n1MP2HRWd0Z9b>089fJP0i;2@0?34]028J
5`12?CX0_[Zi0?7`kP3ViN<0iN?T0>WSi`3]h^P0n^gd0;2OY@22Kg<0^jRZ0;NWZ02[WId0^:b/0>cO
hP3eh>L0f;W10>:^^P3m[kd0/59P0;aFH@30I6L0XE]I0:MjM02JPg/0I5Y>08AmJ`26NV80ET8Q09Ai
BP3^di00g/Mk0:^KCP3UgYX0NgLh06IP901gKc00O6hU07YZ5@2FQb80c<1:0=K>A@38ac40e]Xo0=[P
C03MiVD0iNn?0>oea`3jo^d0OOik2000o`0Joooooe800?l000<0oh000:0Pl02P8?00103oP0020:0P
l1@0oh00102P8?000`3oP000X23`0:0Pl0040:0Pl0H0oh000P2P8?020?n000030:0Pl03oP000oh00
0080X23`1`3oP000102P8?00oh000?n0002P8?090?n000D0X23`00<0oh0008300000o`001`00o`0@
ooooo`003_oooomG003o001;0?oil`3imN`0mo?W0?3_g@3Hf;h0`L:P0;RhTP2^[h@0XjAh09jML@2H
VFl0SiA/08B8I@23QV/0QHA_08F4LP1oNF/0Rgma09F5M@2JR780VhM^0:bHO@28Me/0?RhD044a6P0a
8Pl0>30M0<g6]03jm>@0jnSI0>OUf@3Yi]d0k>CQ0>_Sh03`j>H0f=3>0>GKfP3gkN`0k>OT0>[Vi@3a
jn/0k^KY0?[Yk`3@/[`0Jce80:QQL@2dH700_69^0;i[L`2UJFT0S6IS0:nLUP1GCTD0_kNZ0=;7/`1L
BB/0XHUM0>cBU`3/eHl0[iiJ0;N[L@1dIc00Ofhf089a;01bH0`0/J0h0=oAEP3DcD40c<Pa0<k?<`3K
hTL0f>1G0>C]PP3OiZ00nOgR00X00?l06_oooomG003o0080oh000`2P8?0B0?n000@0X23`0P3oP006
0:0Pl0030?n0002P8?00X23`00D0X23`00<0oh000:0Pl02P8?000`2P8?00103oP000X23`0?n0002P
8?040?n00080X23`1`3oP000102P8?00oh000?n0003oP0040:0Pl0030?n00000o`000?l000P00?l0
4?ooool000koooooF`00o`00A`3in_80moW/0>c]g@3LglT0`<BY0;BgVP2/[i00YZf<09VPO`2RZ8`0
Yj^B07UiH@1cJeH0ZYZ30=BlX03</8/0[8mS08=X>@1>>0H0?bX004dh2`0l:P00ZIe]0?kca@3djl80
l>S40?3Yc03_im00knOD0>oVe@3]iMP0kNOK0>oXh03ZiMl0jNKQ0>GTh03Xi>40j>?R0>kSi`3ii^`0
Zh^F081<F@2OGfd0/6ai0:mbNP2<HV@0M5YI0>SMf`2IU900TXj508InL@1AABl0M6A30=C1UP3agjd0
SGi>07=R=`2EPUL0SGQ306]D3P2cXCd0h=9G0=37>P38aB`0c<``0=cQA`3Gh540h^]f0=OOU03/lLP0
nog_00X00?l06_oooomK003o0080oh000P2P8?0C0?n00140X23`00P0oh000:0Pl02P8?00X23`0?n0
002P8?00oh000:0Pl0<0oh0000@0X23`0?n0003oP000X23`1P3oP000102P8?00oh000?n0003oP005
0:0Pl0030?n00000o`000?l000P00?l04?ooool000koooooGP00o`00@`0ooch0OOmh07clMP1emVd0
Ko5V06CWG01Kge@0c]730:f/WP2b[Il0f<bk0;RXT@2EPV<0Z9A/0<>bP037^H00_[5a0:nSF`2NTT<0
`kQS0=?7LP3B`g40cKe_0=2mN@3HaXL0glb@0>GCV`3/fjP0lN2c0??R^03ch[h0l^;50?7Sb@3biLX0
l>K=0>oUd@3biML0n>KL0>W<a`34XYh0[Xf:0:R9Q`2XThh0clBn0?7[j03Zin<0fMOB0<o<``3Fc/80
d/Vh0;b_VP2`XXP0b;VJ0>GC[`33[gl0Tgde0<bhE`3Jc4h0d<Tg0<S6:`3>dS<0e]e30=OQE@3Lig<0
dmf90>?Y`03lo^l02`00o`0Joooooeh00?l000<0@>0008300020`0000P1@T7P2083000040?n0003@
D7P0d51h0=1@N0@0oh000P3@D7P00`3XJ3`0oh000?n000080=1@N0X0X23`103@D7P0102P8?00d51h
0:0Pl02P8?040=1@N0<0oh0000<0X23`0=1@N03oP0000P3@D7P20?n000030=1@N02P8?00X23`00<0
X23`00<0oh00003o0000o`002@00o`0@ooooo`003_oooomY003o000g0?omm03oo>d0mo;N0>gZb`3N
g;<0eMBN0=SHU03LfHX0f]B00=oFN`3Mcfh0dKmK0<F_C02jXSh0[IH^0:F>9P2ORBH0X8TY09n6;02_
UD40^9iD0<>/J039]G00hm6A0>oNYP3agjl0l^6e0?GV_`3hj<H0nN[90?W/c03gk=00lnW@0>gUd03]
iM80kNCC0>oVe@3`j=D0o?7M0=S;^01lKEH0jMZi0:ZHJ024LB`0i]A`0=G8B03:`c@0alH]0<_?=03H
h4`0dMeE0=k/NP2ga7D0bm>T0?cokP0<003o01[oooooJ@00o`020?n000P0X23`3@3oP0000`3@D7P0
X23`0:0Pl00=0:0Pl080oh0000@0X23`0?n0003oP000X23`103oP0030:0Pl0030?n0002P8?00oh00
00`00?l04?ooool000koooooJ`00o`00=@3moOD0o_kd0?cmk`3mo>X0m?GI0>[ZaP3Pgk<0fMRP0=3;
Q`3CbgP0h=A`0>OJJ03XfUd0j]aI0>CFD@3Pcd/0e<=10<Zh?02kZSP0ZYPZ0:>A9@2PS2T0WhLa0:^B
@02lXUL0_jQT0<^fM@3JaH80im:A0>oKWP3cgZL0m=j]0?KO/`3fgkH0n>:i0?SS^03likX0m=nb0>?A
X@3^gJT0NF@Q0<^gH03HbEH0b/8k0<G2<`39bcT0f=mA0=?NF`3LkG/0`m=k09nYM`3bmn00nocd00`0
0?l06_oooom[003o00@0oh0000@0d51h0:0Pl02P8?00X23`0P3oP0060:0Pl0`0oh002`2P8?000`3@
D7P0oh000?n000040?n000D0X23`0P3oP00<003o013ooooo000>ooooog000?l002l0oOod0?cokP3l
on@0lNo60<6oQ031_6X0c/MO0=78D@3Hd4/0eL`o0=oDA03SedD0jmm?0>_OE@3/h5P0k=iI0>KEFP3J
aUH0ckQ@0<:/B@2YUSX0WXde09n>=P2MRcD0W8Lf0;:LD02[Tdd0/YUG0<2VJ@35Zfh0ckId0=BmNP3L
ah@0h/n=0;:SH02FQSP0gM1`0<BmB`2o_T00c<m>0=;KFP3Ag680f^Yo0=7SS@22TU@0cMJi0?com00=
003o01[oooooL000o`030?n000030:0Pl03oP000oh0000@0oh001`2P8?0@0?n000040:0Pl03@D7P0
oh000:0Pl0<0oh001P2P8?000`3oP0000?l0003o000;003o013ooooo000>ooooog800?l002`0o?kc
0?oolP3]kM40/k610;:_JP39aF`0d/iS0<W3B@39`C`0b;ld0<_3=03CbcX0fM500=gBA03Me4X0gmIE
0>7IG@3Sg6P0hmaa0=kIL`3MegL0f=9d0=;9KP3?a6X0aKMO0;RXD`2cXU00ZYQ40:>A>`2HQS00UhLb
09b=?02DRCd0fmB30<G4JP2c]eH0a/iY0<gIL`3:fWP0`]Ek0:c1M01^PTL0UjF10?OnkPh00?l06_oo
oomb003o0080oh0000<0X23`0?n0003oP000203oP0080:0Pl0`0oh0000@0X23`0?n0003oP000oh00
1P2P8?000`3oP0000?l0003o000<003o013ooooo000>ooooogD00?l002P0inKA09nPN02MW6<0^KM]
0<c8K@3EdV/0dm1M0<c:C`3>bdX0c<U60<[7AP3;aT`0`;m;0<G4F030`5`0_L5S0<33K034aGL0`L9f
0<S5N03=bWd0e/j30=WAQP3NeHX0gmJ90=kBQP3MdHD0elj30=K>QP3Fd8l0_kim08B7@P1kPSh0RiIB
08RGE02AXF80P95J06UjC@1iR6T0h^_H3`00o`0JooooogD00?l000<0X23`0?n0003oP000503oP004
0:0Pl080oh0000<0d51h0?n0003oP000202P8?0?003o013ooooo000>ooooogD00?l001X0oOge0?Gf
j03OglL0cm2^0<72UP31`XT0_/5l0<35L`35bW00a/]]0<C7KP3;c7d0c<f90=7BV03;ci`0bLbO0=SM
]@3Rhl40gn2n0=kP^`3Ti/40jNK30>cZa03`k<L0lNg70?3/aP80lno:00/0l^o<0>k/cP3Ngl00b/f^
0<S=[`3=dkL0dmVo0=WQb@3QjM@0jo;R0?Gkl@0@003o01[oooooM@00o`020?n000030:0Pl03oP000
oh0000/0oh003`2P8?020?n000D0X23`00<0oh00003o0000o`003P00o`0@ooooo`003_oooomi003o
000=0?[mk03amM`0hnO40<cBYP2_]X80]Kf40<oCX03[kL<0l_KE0?OkhP3ko^T0n_k_0?_nl`03003o
0080oOob00<0o_kb0?gnl03mo_00103moO400`3moO<00?l0003o000G003o01[oooooN@00o`00103o
P000X23`0:0Pl02P8?020?n00080X23`1@3oP003003o00X0oh006@00o`0@ooooo`003_oooomk003o
00070?gom03lo_40n_g/0?Wlj`3loNd0oOka0?gom00Z003o01[oooooN`00o`070?n002X00?l04?oo
ool000kooooo[000o`0Joooooj`00?l04?ooool00?ooooooTOooool00?ooooooTOooool00?oooooo
TOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {220.938, 0}} -> {-0.0523276, -0.0277532, \
0.00527483, 0.00527483}, {{9.875, 190.438}, {215.625, 115.438}} -> {-15.0024, \
-13.1403, 1.05837, 1.05837}, {{208.5, 389.062}, {215.625, 115.438}} -> \
{-225.221, -13.1403, 1.05837, 1.05837}, {{9.875, 190.438}, {105.438, 5.25}} -> \
{-15.0189, -124.786, 1.05854, 1.05854}, {{208.5, 389.062}, {105.438, 5.25}} -> \
{-225.271, -124.786, 1.05854, 1.05854}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error plot", "Subsection"],

Cell[BoxData[{
    \(\(cnt1 = CountPixels[class1];\)\), "\[IndentingNewLine]", 
    \(\(cnt2 = CountPixels[class2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bar\  = \ {cnt1, \ cnt2}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(BarChart[bar[\([1]\)], \ bar[\([2]\)], \ 
        BarStyle \[Rule] {pointStyle1[\([1]\)], 
            pointStyle2[\([1]\)]}, \ \[IndentingNewLine]Frame \[Rule] True, 
        BarLabels \[Rule] {"\<Kellogs\>", "\<Tide\>"}, \ 
        imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.0084823 [
[.27273 -0.0125 -23 -12 ]
[.27273 -0.0125 23 0 ]
[.72727 -0.0125 -14 -12 ]
[.72727 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09954 -12 -4.5 ]
[-0.0125 .09954 0 4.5 ]
[-0.0125 .18436 -12 -4.5 ]
[-0.0125 .18436 0 4.5 ]
[-0.0125 .26918 -12 -4.5 ]
[-0.0125 .26918 0 4.5 ]
[-0.0125 .35401 -12 -4.5 ]
[-0.0125 .35401 0 4.5 ]
[-0.0125 .43883 -12 -4.5 ]
[-0.0125 .43883 0 4.5 ]
[-0.0125 .52365 -12 -4.5 ]
[-0.0125 .52365 0 4.5 ]
[-0.0125 .60848 -12 -4.5 ]
[-0.0125 .60848 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -23 0 ]
[.27273 .63053 23 12 ]
[.72727 .63053 -14 0 ]
[.72727 .63053 14 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -84 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kellogs) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tide) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09954 m
.00625 .09954 L
s
[(10)] -0.0125 .09954 1 0 Mshowa
0 .18436 m
.00625 .18436 L
s
[(20)] -0.0125 .18436 1 0 Mshowa
0 .26918 m
.00625 .26918 L
s
[(30)] -0.0125 .26918 1 0 Mshowa
0 .35401 m
.00625 .35401 L
s
[(40)] -0.0125 .35401 1 0 Mshowa
0 .43883 m
.00625 .43883 L
s
[(50)] -0.0125 .43883 1 0 Mshowa
0 .52365 m
.00625 .52365 L
s
[(60)] -0.0125 .52365 1 0 Mshowa
0 .60848 m
.00625 .60848 L
s
[(70)] -0.0125 .60848 1 0 Mshowa
.125 Mabswid
0 .03168 m
.00375 .03168 L
s
0 .04864 m
.00375 .04864 L
s
0 .06561 m
.00375 .06561 L
s
0 .08257 m
.00375 .08257 L
s
0 .1165 m
.00375 .1165 L
s
0 .13347 m
.00375 .13347 L
s
0 .15043 m
.00375 .15043 L
s
0 .1674 m
.00375 .1674 L
s
0 .20133 m
.00375 .20133 L
s
0 .21829 m
.00375 .21829 L
s
0 .23525 m
.00375 .23525 L
s
0 .25222 m
.00375 .25222 L
s
0 .28615 m
.00375 .28615 L
s
0 .30311 m
.00375 .30311 L
s
0 .32008 m
.00375 .32008 L
s
0 .33704 m
.00375 .33704 L
s
0 .37097 m
.00375 .37097 L
s
0 .38794 m
.00375 .38794 L
s
0 .4049 m
.00375 .4049 L
s
0 .42187 m
.00375 .42187 L
s
0 .45579 m
.00375 .45579 L
s
0 .47276 m
.00375 .47276 L
s
0 .48972 m
.00375 .48972 L
s
0 .50669 m
.00375 .50669 L
s
0 .54062 m
.00375 .54062 L
s
0 .55758 m
.00375 .55758 L
s
0 .57455 m
.00375 .57455 L
s
0 .59151 m
.00375 .59151 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kellogs) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tide) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09954 m
1 .09954 L
s
.99375 .18436 m
1 .18436 L
s
.99375 .26918 m
1 .26918 L
s
.99375 .35401 m
1 .35401 L
s
.99375 .43883 m
1 .43883 L
s
.99375 .52365 m
1 .52365 L
s
.99375 .60848 m
1 .60848 L
s
.125 Mabswid
.99625 .03168 m
1 .03168 L
s
.99625 .04864 m
1 .04864 L
s
.99625 .06561 m
1 .06561 L
s
.99625 .08257 m
1 .08257 L
s
.99625 .1165 m
1 .1165 L
s
.99625 .13347 m
1 .13347 L
s
.99625 .15043 m
1 .15043 L
s
.99625 .1674 m
1 .1674 L
s
.99625 .20133 m
1 .20133 L
s
.99625 .21829 m
1 .21829 L
s
.99625 .23525 m
1 .23525 L
s
.99625 .25222 m
1 .25222 L
s
.99625 .28615 m
1 .28615 L
s
.99625 .30311 m
1 .30311 L
s
.99625 .32008 m
1 .32008 L
s
.99625 .33704 m
1 .33704 L
s
.99625 .37097 m
1 .37097 L
s
.99625 .38794 m
1 .38794 L
s
.99625 .4049 m
1 .4049 L
s
.99625 .42187 m
1 .42187 L
s
.99625 .45579 m
1 .45579 L
s
.99625 .47276 m
1 .47276 L
s
.99625 .48972 m
1 .48972 L
s
.99625 .50669 m
1 .50669 L
s
.99625 .54062 m
1 .54062 L
s
.99625 .55758 m
1 .55758 L
s
.99625 .57455 m
1 .57455 L
s
.99625 .59151 m
1 .59151 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .5 0 r
.09091 .01472 m
.09091 .57893 L
.27273 .57893 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .57893 L
.27273 .57893 L
.27273 .01472 L
.09091 .01472 L
s
1 .5 0 r
.54545 .01472 m
.54545 .27434 L
.72727 .27434 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .27434 L
.72727 .27434 L
.72727 .01472 L
.54545 .01472 L
s
.628 .126 .941 r
.27273 .01472 m
.27273 .29873 L
.45455 .29873 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .29873 L
.45455 .29873 L
.45455 .01472 L
.27273 .01472 L
s
.628 .126 .941 r
.72727 .01472 m
.72727 .60332 L
.90909 .60332 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .60332 L
.90909 .60332 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00Roooool3o`000?oooooo0oooool008kooooo00?o0000ooooooooool0
ooooool006cooooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol000000ooooooo0000
o`000003o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l0001oooooo`?o0000
0_ooool5o`0000;ooooo1?l00002ooooo`?o0000J?ooool006gooooo00Ko0000oooooooooooo0000
ooooool00007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0006_ooooo001]ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00ol00020ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00Go0000Ioooool006gooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000008?ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1Uooooo`00KOooool00ol0003oooooo`000003ooooo`?o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Go000000?oooooo`00
0?l000000_l0001mooooo`06o`000?oooooo0000ooooool0003ooooo0ol00004ooooo`?o00000ooo
ool3o`0006Sooooo001]ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2?ooooo`05o`000?oooooo0000ooooool000002_ooool00ol0003ooooo
ooooo`1/ooooo`00K?ooool3o`000003ooooool0003o000000Kooooo0ol00003ooooo`?o0000TOoo
ool5o`0000?ooooo00?o0000ooooooooool00oooool2o`0006kooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000Roooo
ool00000G000000Cooooo`008_ooool00`00003oooooooooo`1Looooo`0300000?oooooooooo09[o
oooo00<00000ooooooooool0Foooool00`00003oooooooooo`0Aooooo`006_ooool2o`0000Kooooo
00<00000ooooooooool0G?ooool00`00003oooooooooo`2Jooooo`0300000?oooooooooo05_ooooo
00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo00001Oooool00`00003ooooo
ooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co
0000oooooooooooo00001Ooooooo000005`000004oooool001Wooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Iooooo`04o`000?oo
ooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`006_oo
ool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol00000
0000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?oo
ool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0
003o000001gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001?ooooo
0ol00004ooooo`;o00001_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001Oooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Kooooo`<000004oooool001Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo
00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool001Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001?ooooo0_l0
0004ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl0
0?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl0
0?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`005?ooool00ol0003oooooooooo`03ooooo`;o00001_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
0?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
0?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo
00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
00030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Boooo
o`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<0
00000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
00000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`03
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l00000
7Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0
7?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo
00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo
00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001;ooooo1Ol00003ooooo`;o
00001_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Cooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001Oooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Kooooo`<000004oooool001Gooooo00Go0000oooooooo
ooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Boooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`0300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool001?ooooo0ol00004ooooo`;o00001_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol00000
0000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000o`000?l000007Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool0
0`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool0
0ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001?ooooo
0ol00004ooooo`;o00001_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`03
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool001Kooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool001Cooooo0_l00003ooooo`04o`000?ooooooooooo`0000Gooooo00<00000o`000?l0
00007Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000oooooooo
ool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000oooooooo
ool06oooool3000001?ooooo000Fooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Moooood000000?@2P8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo05cooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Cooooo`?o00001?ooool2o`0000Ko
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl0
0?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000oooo
ooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000oooo
ooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool0G?ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0
G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo03l00000G_oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooo
oooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003o
oooo01;ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl0
0?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<0
00000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`00
0?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`03
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oo
oooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000
ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooooooo01gooooo
00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001Cooooo0ol00003
ooooo`;o00001_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00?ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooo
oooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Booooo`Go00000_ooool01?l0003oooooooooool00005ooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000Gooooo00<00000o`000?l000007Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Kooooo`<000004oooool001?ooooo00?o0000ooooool000000oooool0
1?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03o
O`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`005?ooool2o`0000?ooooo00Co0000oooooooooooo00001Ooo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool001Gooooo00?o0000ooooooooool00_ooool2o`0000Kooooo00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooooooo
o`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000
003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[o
oooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooo
ooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<0
0000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0L
ooooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
0000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo
09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003o
ooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool001?ooooo0ol00004ooooo`;o00001_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Fooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00oooool00`00003o0000o`00000Mooooo`030000
003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01_ooooo0`00000Cooooo`005_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00?ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
0?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Booooo`Co00000oooool01?l0003oooooooooool00005ooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`Go00000ooo
ool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oo
oooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl0
03`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo
00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Joooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000oooooooo
ool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?oo
ool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
0?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03o
O`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01go
oooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o0000
o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000R
ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2J
ooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000oooo
ooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
00000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00
?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000003o
O`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004oooool3o`0000Co
oooo0_l00006ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003o
ooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooo
oooo00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000oooo
ooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool001;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooo
oooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Booooo`Co00000oooool01?l0003oooooooooool00005ooooo`0300000?l0003o
000001gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool06oooool3000001?ooooo000Booooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool001?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`005?ooool2o`0000Cooooo0_l00006ooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooooooo
o`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000
003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[o
oooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooo
ooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<0
0000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0L
ooooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooood00
0000W?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOoo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l00000nOooool00`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;o
oooo00<00000ooooooooool0nOooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0nOooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001Cooooo00?o
0000ooooooooool00oooool2o`0000Kooooo00<00000ooooooooool0nOooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool001Cooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo0?Wooooo?`00
000Oooooo`0300000?oooooooooo017ooooo000Eooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`03ooooo`0300000?oooooooooo0?ooooooF?ooool00`00003ooooooooo
o`0Aooooo`005Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00ooo
ool00`00003o0000o`00003ooooooeKooooo0`00000Cooooo`005_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool0G?ooool00ol0003ooooooooo
o`2Jooooo`0300000?oooooooooo05_ooooo00<00000ooooooooool04Oooool001;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool0
G?ooool00ol0003oooooooooo`2Jooooo`0300000?oooooooooo05_ooooo00<00000ooooooooool0
4Oooool001;ooooo1Ol00003ooooo`;o00001_oooooo000005`000004oooool00?ooooooTOooool0
0?ooooooTOooool00?ooooooTOooool00?ooooooTOooool00?ooooooTOooool008_ooooo0ol0003o
ooooo`?ooooo002>ooooo`03o`000?oooooooooo0?oooooo001/ooooo`?o000000Coooooo`000?l0
003ooooo0ol00002ooooo`Go000000?oooooo`000?l000000ol00002ooooo`?o00000oooool4o`00
0003ooooool0003o000000;o0000Ooooool3o`0000;ooooo1Ol00002ooooo`Co00000_ooool3o`00
06Sooooo001]ooooo`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000_ooool01?l0003oooooooooool0001[ooooo`00KOooool00ol0003ooooo
o`000002ooooo`Go00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?o0000P?ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05o`00
06Oooooo001]ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool0
0ol0003oooooo`000023ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0IOooool006gooooo00?o
0000ooooool000000oooool3o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`?o00000oooool5o`000003ooooool0003o000000;o0000OOooool01_l0003oooooo`00
0?oooooo0000ooooo`?o00001?ooool3o`0000?ooooo0ol0001Xooooo`00KOooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Soooool01Ol0003o
ooooo`000?oooooo000000[ooooo00?o0000ooooooooool0K?ooool006cooooo0ol000000ooooooo
0000o`000006ooooo`?o00000oooool3o`00097ooooo1Ol00003ooooo`03o`000?oooooooooo00?o
oooo0_l0001^ooooo`00oooooonAooooo`00oooooonAooooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.378218, -7.30317, \
0.00636706, 0.341195}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["3d mixture-of-Gaussians classification (RGB)", "Section"],

Cell[CellGroupData[{

Cell["Visualize distributions", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gobj1\  = \ 
        PlotRepresentativeSample3D[data1, \ 2000, pointStyle1];\)\), "\n", 
    \(\(gobj2\  = \ 
        PlotRepresentativeSample3D[data2, \ 2000, pointStyle2];\)\), "\n", 
    \(\(gdist1 = 
        Show[{gobj1, gobj2}, yS, \ ImageSize \[Rule] 288];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 288 312.623 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 0 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
1 .5 0 r
.01 w
.84334 .49598 Mdot
.71169 .37959 Mdot
.82923 .47225 Mdot
.85068 .50668 Mdot
.8322 .49341 Mdot
.86945 .50754 Mdot
.84231 .50093 Mdot
.75307 .42162 Mdot
.83227 .47188 Mdot
.84085 .50927 Mdot
.84856 .50845 Mdot
.85195 .51097 Mdot
.79117 .45953 Mdot
.85029 .51743 Mdot
.82268 .49257 Mdot
.8137 .46662 Mdot
.76401 .43304 Mdot
.81681 .5115 Mdot
.83677 .52283 Mdot
.85792 .53021 Mdot
.82318 .53544 Mdot
.78766 .45061 Mdot
.78687 .45838 Mdot
.8818 .54799 Mdot
.73151 .41753 Mdot
.78833 .46543 Mdot
.77317 .47093 Mdot
.83213 .51623 Mdot
.73229 .44878 Mdot
.8257 .51502 Mdot
.8034 .48988 Mdot
.75035 .46466 Mdot
.53724 .34147 Mdot
.82043 .50257 Mdot
.79484 .48403 Mdot
.85364 .51109 Mdot
.82811 .5536 Mdot
.84396 .51652 Mdot
.77054 .47067 Mdot
.82262 .54648 Mdot
.85632 .5215 Mdot
.8195 .49397 Mdot
.49024 .30453 Mdot
.84264 .53422 Mdot
.78108 .48211 Mdot
.80026 .49947 Mdot
.75021 .47476 Mdot
.82253 .50825 Mdot
.85473 .51352 Mdot
.81491 .50374 Mdot
.77946 .49055 Mdot
.5751 .37048 Mdot
.85113 .532 Mdot
.45033 .37804 Mdot
.81897 .57356 Mdot
.84335 .51825 Mdot
.87193 .56394 Mdot
.75594 .45652 Mdot
.85823 .53909 Mdot
.65251 .42476 Mdot
.83952 .53482 Mdot
.83935 .52556 Mdot
.81362 .56839 Mdot
.8552 .54046 Mdot
.82993 .54955 Mdot
.87282 .53416 Mdot
.46051 .34632 Mdot
.85971 .52245 Mdot
.79842 .49976 Mdot
.54136 .34898 Mdot
.85753 .57021 Mdot
.79647 .51172 Mdot
.82126 .58154 Mdot
.57002 .39668 Mdot
.85644 .55962 Mdot
.78144 .52857 Mdot
.57023 .29361 Mdot
.64815 .41361 Mdot
.53109 .3395 Mdot
.79894 .50561 Mdot
.74243 .51469 Mdot
.83636 .53542 Mdot
.70543 .49073 Mdot
.72952 .46896 Mdot
.79009 .49039 Mdot
.87433 .56194 Mdot
.39449 .38464 Mdot
.83125 .51744 Mdot
.86998 .55069 Mdot
.65485 .34005 Mdot
.57549 .3949 Mdot
.46121 .43783 Mdot
.60378 .413 Mdot
.62019 .39394 Mdot
.84703 .56115 Mdot
.39765 .27605 Mdot
.51565 .42397 Mdot
.63333 .43636 Mdot
.43541 .32461 Mdot
.60912 .39797 Mdot
.86142 .53746 Mdot
.74422 .48549 Mdot
.36694 .27725 Mdot
.86398 .64655 Mdot
.8487 .54638 Mdot
.67985 .45585 Mdot
.26768 .26541 Mdot
.84081 .53244 Mdot
.49373 .34875 Mdot
.49768 .37949 Mdot
.72615 .5226 Mdot
.87395 .5566 Mdot
.86137 .5441 Mdot
.701 .38217 Mdot
.81973 .59324 Mdot
.87596 .5371 Mdot
.50833 .46843 Mdot
.77055 .43107 Mdot
.22988 .26152 Mdot
.60529 .42612 Mdot
.23756 .26055 Mdot
.87152 .57144 Mdot
.83258 .59306 Mdot
.58306 .43987 Mdot
.81112 .52688 Mdot
.78576 .55496 Mdot
.70336 .48591 Mdot
.28661 .25781 Mdot
.4974 .37955 Mdot
.25505 .25775 Mdot
.59528 .48869 Mdot
.37856 .29502 Mdot
.57028 .41983 Mdot
.62592 .44163 Mdot
.7624 .44769 Mdot
.50661 .39143 Mdot
.628 .126 .941 r
.7914 .54744 Mdot
1 .5 0 r
.85414 .63716 Mdot
.84889 .54025 Mdot
.60532 .4244 Mdot
.24385 .28053 Mdot
.54049 .4553 Mdot
.19462 .25435 Mdot
.77654 .63875 Mdot
.7662 .45418 Mdot
.90807 .61055 Mdot
.2048 .26015 Mdot
.83176 .63228 Mdot
.40794 .3755 Mdot
.628 .126 .941 r
.13799 .2593 Mdot
1 .5 0 r
.33172 .29059 Mdot
.41406 .40564 Mdot
.86161 .64661 Mdot
.628 .126 .941 r
.53885 .37415 Mdot
1 .5 0 r
.85479 .64337 Mdot
.86814 .51485 Mdot
.60446 .43628 Mdot
.9069 .58296 Mdot
.86247 .62368 Mdot
.4697 .36659 Mdot
.57534 .39153 Mdot
.39415 .31941 Mdot
.88313 .57263 Mdot
.69678 .41274 Mdot
.85621 .64142 Mdot
.50821 .37181 Mdot
.54221 .43396 Mdot
.28504 .30509 Mdot
.78408 .53401 Mdot
.55834 .44916 Mdot
.57614 .43324 Mdot
.628 .126 .941 r
.162 .27289 Mdot
.54351 .38583 Mdot
1 .5 0 r
.74645 .4542 Mdot
.87484 .64861 Mdot
.20728 .28133 Mdot
.60567 .5544 Mdot
.84406 .57951 Mdot
.87444 .56673 Mdot
.47114 .39655 Mdot
.63236 .46854 Mdot
.77529 .59103 Mdot
.28809 .31138 Mdot
.64463 .3992 Mdot
.83614 .62845 Mdot
.86764 .55603 Mdot
.25346 .28554 Mdot
.48968 .42047 Mdot
.88778 .59291 Mdot
.79408 .49851 Mdot
.44766 .36291 Mdot
.89133 .59557 Mdot
.45202 .41297 Mdot
.28363 .27455 Mdot
.86333 .67071 Mdot
.77427 .58228 Mdot
.628 .126 .941 r
.19199 .29592 Mdot
1 .5 0 r
.51121 .36494 Mdot
.18403 .29874 Mdot
.628 .126 .941 r
.58253 .47137 Mdot
.15555 .30125 Mdot
.17356 .29476 Mdot
1 .5 0 r
.23615 .30099 Mdot
.76106 .5968 Mdot
.63762 .3827 Mdot
.628 .126 .941 r
.64227 .50547 Mdot
1 .5 0 r
.75437 .60305 Mdot
.86099 .59349 Mdot
.23431 .26906 Mdot
.88559 .57129 Mdot
.71049 .44845 Mdot
.23786 .28113 Mdot
.91218 .64616 Mdot
.88129 .57682 Mdot
.18483 .30587 Mdot
.36131 .26165 Mdot
.58455 .51674 Mdot
.628 .126 .941 r
.17101 .29932 Mdot
1 .5 0 r
.88449 .56045 Mdot
.628 .126 .941 r
.16743 .29861 Mdot
1 .5 0 r
.79973 .58522 Mdot
.86214 .63565 Mdot
.77986 .49657 Mdot
.19361 .31019 Mdot
.48144 .42352 Mdot
.87686 .56536 Mdot
.17958 .2941 Mdot
.38702 .30974 Mdot
.47314 .40733 Mdot
.628 .126 .941 r
.17746 .30633 Mdot
.15209 .29049 Mdot
1 .5 0 r
.76081 .56492 Mdot
.46512 .46392 Mdot
.628 .126 .941 r
.18292 .29667 Mdot
1 .5 0 r
.89137 .6025 Mdot
.628 .126 .941 r
.16822 .30575 Mdot
.18627 .29925 Mdot
.34946 .37498 Mdot
.12879 .27381 Mdot
.24237 .25796 Mdot
1 .5 0 r
.29207 .29577 Mdot
.628 .126 .941 r
.17156 .30833 Mdot
.15877 .29564 Mdot
1 .5 0 r
.24691 .31773 Mdot
.40351 .34595 Mdot
.15731 .28269 Mdot
.20722 .33004 Mdot
.628 .126 .941 r
.19443 .31735 Mdot
.20702 .32051 Mdot
.18164 .30466 Mdot
1 .5 0 r
.46432 .42778 Mdot
.628 .126 .941 r
.1875 .31406 Mdot
1 .5 0 r
.1875 .31406 Mdot
.21058 .33263 Mdot
.628 .126 .941 r
.21038 .32309 Mdot
1 .5 0 r
.18499 .30724 Mdot
.76277 .53765 Mdot
.628 .126 .941 r
.18834 .30982 Mdot
.19421 .31923 Mdot
.16754 .29995 Mdot
1 .5 0 r
.24344 .27461 Mdot
.2169 .31872 Mdot
.628 .126 .941 r
.18476 .30911 Mdot
1 .5 0 r
.18476 .30911 Mdot
.33422 .31498 Mdot
.87452 .52658 Mdot
.628 .126 .941 r
.19253 .30814 Mdot
.19253 .30814 Mdot
1 .5 0 r
.21122 .33028 Mdot
.628 .126 .941 r
.19841 .31757 Mdot
.19147 .31428 Mdot
.19695 .3046 Mdot
.51197 .36455 Mdot
.20177 .32015 Mdot
1 .5 0 r
.20177 .32015 Mdot
.37355 .23153 Mdot
.628 .126 .941 r
.18221 .3137 Mdot
.19483 .31686 Mdot
1 .5 0 r
.43504 .34216 Mdot
.628 .126 .941 r
.13154 .29149 Mdot
.34699 .27568 Mdot
1 .5 0 r
.6232 .44964 Mdot
.75406 .60462 Mdot
.50524 .25347 Mdot
.628 .126 .941 r
.20031 .30718 Mdot
.20513 .32274 Mdot
.19839 .329 Mdot
.19819 .31945 Mdot
.19819 .31945 Mdot
.43894 .30996 Mdot
.15298 .28755 Mdot
.18431 .31286 Mdot
.14016 .27483 Mdot
1 .5 0 r
.20261 .3159 Mdot
.628 .126 .941 r
.20849 .32533 Mdot
1 .5 0 r
.18979 .30318 Mdot
.628 .126 .941 r
.23374 .33166 Mdot
.40329 .41704 Mdot
1 .5 0 r
.67946 .58154 Mdot
.20162 .2681 Mdot
.48455 .42635 Mdot
.4419 .22993 Mdot
.26331 .27094 Mdot
.628 .126 .941 r
.21186 .32792 Mdot
1 .5 0 r
.21186 .32792 Mdot
.59025 .4577 Mdot
.35768 .24858 Mdot
.49436 .40358 Mdot
.16623 .27688 Mdot
.628 .126 .941 r
.57605 .43202 Mdot
.20934 .32108 Mdot
1 .5 0 r
.20934 .32108 Mdot
.20934 .32108 Mdot
.20895 .30195 Mdot
.628 .126 .941 r
.20828 .32722 Mdot
.24532 .35242 Mdot
.16959 .27946 Mdot
1 .5 0 r
.34086 .26996 Mdot
.56595 .50115 Mdot
.628 .126 .941 r
.21271 .32367 Mdot
.19988 .31093 Mdot
1 .5 0 r
.2186 .33311 Mdot
.88739 .57065 Mdot
.21232 .30453 Mdot
.21232 .30453 Mdot
.628 .126 .941 r
.262 .33291 Mdot
1 .5 0 r
.21125 .31068 Mdot
.5258 .4944 Mdot
.56961 .51335 Mdot
.22899 .28501 Mdot
.628 .126 .941 r
.20324 .31352 Mdot
1 .5 0 r
.61943 .48778 Mdot
.628 .126 .941 r
.19696 .28494 Mdot
.19629 .31023 Mdot
.21502 .33241 Mdot
.20238 .32924 Mdot
.26472 .3608 Mdot
1 .5 0 r
.75617 .57938 Mdot
.55511 .41454 Mdot
.628 .126 .941 r
.21945 .32885 Mdot
1 .5 0 r
.76921 .48414 Mdot
.628 .126 .941 r
.20661 .31611 Mdot
.20661 .31611 Mdot
.20661 .31611 Mdot
.76294 .45556 Mdot
1 .5 0 r
.21906 .30971 Mdot
.57263 .43331 Mdot
.628 .126 .941 r
.21839 .335 Mdot
1 .5 0 r
.40225 .31909 Mdot
.39597 .2905 Mdot
.19251 .29994 Mdot
.628 .126 .941 r
.22389 .3253 Mdot
.19184 .32524 Mdot
1 .5 0 r
.54547 .44886 Mdot
.78604 .46465 Mdot
.628 .126 .941 r
.22283 .33145 Mdot
.22283 .33145 Mdot
1 .5 0 r
.29309 .29658 Mdot
.49498 .38217 Mdot
.628 .126 .941 r
.19038 .31224 Mdot
1 .5 0 r
.4813 .38515 Mdot
.628 .126 .941 r
.72677 .53416 Mdot
1 .5 0 r
.31058 .31534 Mdot
.22137 .31845 Mdot
.88412 .56253 Mdot
.628 .126 .941 r
.19521 .32783 Mdot
1 .5 0 r
.20786 .331 Mdot
.628 .126 .941 r
.20766 .32143 Mdot
1 .5 0 r
.20766 .32143 Mdot
.628 .126 .941 r
.21336 .3213 Mdot
1 .5 0 r
.22475 .32104 Mdot
.628 .126 .941 r
.19971 .27023 Mdot
1 .5 0 r
.46544 .33684 Mdot
.70445 .50176 Mdot
.86848 .57788 Mdot
.628 .126 .941 r
.19858 .33043 Mdot
1 .5 0 r
.59694 .44778 Mdot
.628 .126 .941 r
.21103 .32402 Mdot
.21103 .32402 Mdot
.21103 .32402 Mdot
.22958 .33665 Mdot
.21673 .32389 Mdot
1 .5 0 r
.62732 .47932 Mdot
.89215 .61572 Mdot
.628 .126 .941 r
.22852 .3428 Mdot
.55646 .48549 Mdot
.21461 .3362 Mdot
.21461 .3362 Mdot
.18929 .32985 Mdot
.26438 .36463 Mdot
.29044 .29159 Mdot
1 .5 0 r
.49204 .41216 Mdot
.628 .126 .941 r
.21315 .32319 Mdot
.21315 .32319 Mdot
1 .5 0 r
.21315 .32319 Mdot
.628 .126 .941 r
.28168 .37384 Mdot
.26293 .35162 Mdot
.23111 .30706 Mdot
.21798 .3388 Mdot
.19903 .307 Mdot
1 .5 0 r
.21778 .32922 Mdot
.628 .126 .941 r
.23635 .34185 Mdot
1 .5 0 r
.26777 .36724 Mdot
.53978 .45293 Mdot
.51445 .44658 Mdot
.26194 .3037 Mdot
.628 .126 .941 r
.22309 .30992 Mdot
1 .5 0 r
.21652 .32579 Mdot
.23489 .32883 Mdot
.37354 .38908 Mdot
.628 .126 .941 r
.22136 .3414 Mdot
.22687 .33169 Mdot
1 .5 0 r
.24563 .35391 Mdot
.628 .126 .941 r
.2199 .32839 Mdot
.226 .34744 Mdot
1 .5 0 r
.24484 .31556 Mdot
.628 .126 .941 r
.23828 .33143 Mdot
.26971 .35684 Mdot
.21274 .31549 Mdot
1 .5 0 r
.65005 .40758 Mdot
.628 .126 .941 r
.19987 .30272 Mdot
1 .5 0 r
.91451 .56947 Mdot
.20577 .31219 Mdot
.20577 .31219 Mdot
.628 .126 .941 r
.19291 .29942 Mdot
.23025 .33429 Mdot
1 .5 0 r
.24902 .35652 Mdot
.628 .126 .941 r
.21061 .32781 Mdot
1 .5 0 r
.1661 .28004 Mdot
.27311 .35944 Mdot
.628 .126 .941 r
.22879 .32126 Mdot
1 .5 0 r
.22879 .32126 Mdot
.628 .126 .941 r
.24757 .3435 Mdot
1 .5 0 r
.22813 .34661 Mdot
.628 .126 .941 r
.20915 .31478 Mdot
.22793 .33702 Mdot
.22793 .33702 Mdot
1 .5 0 r
.45652 .35926 Mdot
.628 .126 .941 r
.18864 .32406 Mdot
.22667 .33359 Mdot
1 .5 0 r
.22667 .33359 Mdot
.27651 .36205 Mdot
.53472 .54951 Mdot
.67462 .54951 Mdot
.628 .126 .941 r
.23131 .33962 Mdot
1 .5 0 r
.23131 .33962 Mdot
.39695 .24727 Mdot
.628 .126 .941 r
.57144 .49191 Mdot
.82437 .58084 Mdot
1 .5 0 r
.24844 .33924 Mdot
.628 .126 .941 r
.32977 .39315 Mdot
.19055 .31362 Mdot
.21591 .31998 Mdot
1 .5 0 r
.18425 .28495 Mdot
.57549 .52335 Mdot
.24041 .3421 Mdot
.24041 .3421 Mdot
.628 .126 .941 r
.22076 .33562 Mdot
.24002 .3229 Mdot
.25223 .36105 Mdot
1 .5 0 r
.30981 .3133 Mdot
.628 .126 .941 r
.22627 .32589 Mdot
1 .5 0 r
.22627 .32589 Mdot
.23895 .32907 Mdot
.628 .126 .941 r
.21272 .33848 Mdot
.21272 .33848 Mdot
.21272 .33848 Mdot
1 .5 0 r
.2438 .34471 Mdot
.628 .126 .941 r
.28797 .37333 Mdot
1 .5 0 r
.36455 .35743 Mdot
.628 .126 .941 r
.23683 .3414 Mdot
.22414 .33822 Mdot
.23683 .3414 Mdot
.22414 .33822 Mdot
1 .5 0 r
.87068 .53538 Mdot
.44479 .47172 Mdot
.628 .126 .941 r
.25523 .34446 Mdot
1 .5 0 r
.25523 .34446 Mdot
.628 .126 .941 r
.22966 .32849 Mdot
1 .5 0 r
.22966 .32849 Mdot
.51067 .25853 Mdot
.36292 .33479 Mdot
.7727 .63056 Mdot
.24148 .34745 Mdot
.24148 .34745 Mdot
.628 .126 .941 r
.36273 .32518 Mdot
.31103 .38243 Mdot
1 .5 0 r
.83597 .63686 Mdot
.628 .126 .941 r
.29157 .38555 Mdot
1 .5 0 r
.27257 .35368 Mdot
.628 .126 .941 r
.21504 .34726 Mdot
.21464 .32804 Mdot
1 .5 0 r
.58202 .44568 Mdot
.628 .126 .941 r
.23305 .3311 Mdot
.23305 .3311 Mdot
1 .5 0 r
.23305 .3311 Mdot
.628 .126 .941 r
.24574 .33428 Mdot
1 .5 0 r
.60063 .45834 Mdot
.628 .126 .941 r
.22016 .31831 Mdot
.23285 .32149 Mdot
.21969 .3533 Mdot
1 .5 0 r
.21357 .33421 Mdot
.628 .126 .941 r
.22607 .32779 Mdot
1 .5 0 r
.22607 .32779 Mdot
.628 .126 .941 r
.20049 .31181 Mdot
.3387 .4518 Mdot
1 .5 0 r
.56811 .43907 Mdot
.628 .126 .941 r
.23092 .34344 Mdot
.19949 .26376 Mdot
1 .5 0 r
.26202 .34968 Mdot
.628 .126 .941 r
.23624 .32409 Mdot
.20407 .32403 Mdot
.24874 .31766 Mdot
.22946 .33039 Mdot
.22288 .3463 Mdot
1 .5 0 r
.26649 .34611 Mdot
.628 .126 .941 r
.19622 .3365 Mdot
.50802 .36196 Mdot
1 .5 0 r
.45629 .41925 Mdot
.28471 .33956 Mdot
.28424 .37457 Mdot
.83593 .56555 Mdot
.628 .126 .941 r
.25253 .33949 Mdot
.27134 .36177 Mdot
1 .5 0 r
.26503 .33306 Mdot
.35468 .2757 Mdot
.23285 .333 Mdot
.23285 .333 Mdot
.628 .126 .941 r
.25166 .35528 Mdot
1 .5 0 r
.21995 .3202 Mdot
.27028 .36795 Mdot
.27028 .36795 Mdot
.628 .126 .941 r
.2762 .37744 Mdot
.2248 .33586 Mdot
.2248 .33586 Mdot
1 .5 0 r
.20599 .31358 Mdot
.26883 .3549 Mdot
.27475 .36439 Mdot
.628 .126 .941 r
.22374 .34204 Mdot
.23032 .32612 Mdot
1 .5 0 r
.50839 .50125 Mdot
.628 .126 .941 r
.23624 .33561 Mdot
1 .5 0 r
.21064 .31962 Mdot
.45202 .38012 Mdot
.45719 .46929 Mdot
.26079 .35777 Mdot
.31772 .38961 Mdot
.628 .126 .941 r
.2411 .35127 Mdot
1 .5 0 r
.86979 .52643 Mdot
.628 .126 .941 r
.30941 .43714 Mdot
1 .5 0 r
.59601 .45625 Mdot
.24662 .34153 Mdot
.628 .126 .941 r
.20172 .33828 Mdot
1 .5 0 r
.23372 .32873 Mdot
.628 .126 .941 r
.29067 .36058 Mdot
1 .5 0 r
.21422 .33185 Mdot
.628 .126 .941 r
.23305 .35414 Mdot
.23964 .33822 Mdot
.25894 .32548 Mdot
1 .5 0 r
.23964 .33822 Mdot
.88491 .71089 Mdot
.628 .126 .941 r
.18814 .35089 Mdot
1 .5 0 r
.2771 .37319 Mdot
.2638 .34115 Mdot
.628 .126 .941 r
.26207 .37275 Mdot
.26207 .37275 Mdot
.24304 .34083 Mdot
1 .5 0 r
.24304 .34083 Mdot
.628 .126 .941 r
.2805 .37581 Mdot
.22247 .35013 Mdot
1 .5 0 r
.26061 .35969 Mdot
.21615 .32139 Mdot
.87632 .5572 Mdot
.20324 .30858 Mdot
.25342 .34676 Mdot
.628 .126 .941 r
.28498 .37225 Mdot
1 .5 0 r
.43755 .41049 Mdot
.22101 .33707 Mdot
.36135 .33707 Mdot
.271 .36563 Mdot
.628 .126 .941 r
.29643 .372 Mdot
1 .5 0 r
.4495 .37519 Mdot
.628 .126 .941 r
.20702 .33044 Mdot
.20682 .32081 Mdot
1 .5 0 r
.45439 .39088 Mdot
.628 .126 .941 r
.25683 .34937 Mdot
1 .5 0 r
.25683 .34937 Mdot
.628 .126 .941 r
.31383 .38125 Mdot
.25663 .33974 Mdot
.2242 .33005 Mdot
1 .5 0 r
.31889 .40657 Mdot
.628 .126 .941 r
.21041 .33305 Mdot
.21654 .35218 Mdot
1 .5 0 r
.26742 .36493 Mdot
.4719 .3458 Mdot
.28587 .368 Mdot
.26023 .35199 Mdot
.628 .126 .941 r
.2918 .3775 Mdot
1 .5 0 r
.444 .45084 Mdot
.628 .126 .941 r
.21527 .34874 Mdot
.24731 .33917 Mdot
1 .5 0 r
.2278 .34229 Mdot
.628 .126 .941 r
.25324 .34867 Mdot
1 .5 0 r
.25324 .34867 Mdot
.87573 .57509 Mdot
.628 .126 .941 r
.19555 .34223 Mdot
.33485 .40276 Mdot
1 .5 0 r
.47481 .43784 Mdot
.5389 .41871 Mdot
.628 .126 .941 r
.24605 .33572 Mdot
.21993 .3548 Mdot
1 .5 0 r
.22633 .32922 Mdot
.628 .126 .941 r
.28929 .37062 Mdot
.32067 .38651 Mdot
1 .5 0 r
.70292 .44711 Mdot
.628 .126 .941 r
.23119 .34491 Mdot
.24946 .33834 Mdot
1 .5 0 r
.79441 .65099 Mdot
.402 .36699 Mdot
.49892 .25845 Mdot
.628 .126 .941 r
.44707 .31588 Mdot
1 .5 0 r
.45178 .44031 Mdot
.628 .126 .941 r
.29271 .37324 Mdot
1 .5 0 r
.29271 .37324 Mdot
.628 .126 .941 r
.17114 .34121 Mdot
1 .5 0 r
.54551 .52309 Mdot
.628 .126 .941 r
.22234 .30924 Mdot
.2478 .31562 Mdot
.23459 .34753 Mdot
1 .5 0 r
.29758 .38895 Mdot
.28465 .37612 Mdot
.628 .126 .941 r
.23946 .36323 Mdot
1 .5 0 r
.27766 .3728 Mdot
.628 .126 .941 r
.29652 .39514 Mdot
.32839 .37593 Mdot
.29613 .37587 Mdot
.29613 .37587 Mdot
.2832 .36304 Mdot
.22074 .23211 Mdot
.25753 .34702 Mdot
.23167 .32136 Mdot
1 .5 0 r
.85474 .54799 Mdot
.628 .126 .941 r
.26967 .32129 Mdot
.28807 .37875 Mdot
1 .5 0 r
.689 .49686 Mdot
.628 .126 .941 r
.25061 .2893 Mdot
.2372 .31159 Mdot
.22427 .29875 Mdot
1 .5 0 r
.70648 .50614 Mdot
.628 .126 .941 r
.22367 .26982 Mdot
.25481 .33048 Mdot
.26094 .34964 Mdot
1 .5 0 r
.26094 .34964 Mdot
.628 .126 .941 r
.23507 .32397 Mdot
1 .5 0 r
.43983 .30481 Mdot
.50258 .39102 Mdot
.62856 .52832 Mdot
.29149 .38138 Mdot
.41322 .35903 Mdot
.628 .126 .941 r
.3951 .25678 Mdot
1 .5 0 r
.2911 .36209 Mdot
.24021 .2949 Mdot
.628 .126 .941 r
.18197 .32358 Mdot
.29051 .33316 Mdot
.27729 .3651 Mdot
1 .5 0 r
.84877 .64933 Mdot
.51966 .381 Mdot
.24461 .34575 Mdot
.30785 .39685 Mdot
.628 .126 .941 r
.65332 .37768 Mdot
1 .5 0 r
.88033 .61084 Mdot
.628 .126 .941 r
.29491 .38401 Mdot
1 .5 0 r
.30746 .37756 Mdot
.628 .126 .941 r
.5628 .40631 Mdot
.21718 .3614 Mdot
1 .5 0 r
.49993 .25598 Mdot
.628 .126 .941 r
.21699 .35175 Mdot
.31128 .39948 Mdot
.31041 .41534 Mdot
.20851 .33533 Mdot
.22814 .27775 Mdot
.30983 .38639 Mdot
1 .5 0 r
.89532 .60368 Mdot
.628 .126 .941 r
.22039 .35438 Mdot
.25985 .24885 Mdot
.25277 .29999 Mdot
1 .5 0 r
.23341 .31277 Mdot
.628 .126 .941 r
.17533 .35112 Mdot
.28393 .3607 Mdot
1 .5 0 r
.28393 .3607 Mdot
.628 .126 .941 r
.32832 .38946 Mdot
1 .5 0 r
.23935 .32229 Mdot
.23935 .32229 Mdot
.628 .126 .941 r
.34701 .40218 Mdot
.24576 .29666 Mdot
.20657 .35738 Mdot
1 .5 0 r
.61316 .56511 Mdot
.49963 .42124 Mdot
.25016 .34754 Mdot
.628 .126 .941 r
.19848 .36026 Mdot
1 .5 0 r
.33215 .4114 Mdot
.59948 .51369 Mdot
.628 .126 .941 r
.30031 .37618 Mdot
.28736 .36333 Mdot
.27393 .38564 Mdot
.34932 .4655 Mdot
1 .5 0 r
.62424 .48149 Mdot
.47147 .39831 Mdot
.628 .126 .941 r
.3048 .37261 Mdot
1 .5 0 r
.30432 .40777 Mdot
.628 .126 .941 r
.24838 .26064 Mdot
.24015 .37248 Mdot
1 .5 0 r
.29098 .37561 Mdot
.628 .126 .941 r
.21337 .36263 Mdot
.22612 .36583 Mdot
1 .5 0 r
.25806 .34658 Mdot
.46928 .34658 Mdot
.628 .126 .941 r
.24518 .27923 Mdot
.25746 .31761 Mdot
1 .5 0 r
.32012 .3943 Mdot
.55576 .46141 Mdot
.628 .126 .941 r
.28145 .36539 Mdot
1 .5 0 r
.24958 .33014 Mdot
.628 .126 .941 r
.43239 .4707 Mdot
1 .5 0 r
.24879 .2915 Mdot
.27932 .37781 Mdot
.628 .126 .941 r
.68019 .56656 Mdot
.34247 .41934 Mdot
1 .5 0 r
.89747 .5761 Mdot
.628 .126 .941 r
.3106 .38408 Mdot
1 .5 0 r
.35598 .34249 Mdot
.628 .126 .941 r
.20166 .36482 Mdot
1 .5 0 r
.29764 .37122 Mdot
.628 .126 .941 r
.28373 .42875 Mdot
.27786 .3647 Mdot
1 .5 0 r
.31548 .39983 Mdot
.53989 .35817 Mdot
.50073 .36444 Mdot
.59465 .50199 Mdot
.628 .126 .941 r
.31403 .38672 Mdot
1 .5 0 r
.33295 .40912 Mdot
.60155 .44113 Mdot
.2883 .37065 Mdot
.628 .126 .941 r
.30107 .37385 Mdot
.22405 .33532 Mdot
1 .5 0 r
.34541 .33846 Mdot
.40906 .34479 Mdot
.47954 .34479 Mdot
.628 .126 .941 r
.28684 .35753 Mdot
.29961 .36074 Mdot
.27359 .38954 Mdot
.31191 .39915 Mdot
.2538 .38302 Mdot
1 .5 0 r
.2361 .2453 Mdot
.628 .126 .941 r
.28558 .35408 Mdot
.29173 .37329 Mdot
.29173 .37329 Mdot
.25956 .38289 Mdot
.21469 .33474 Mdot
1 .5 0 r
.68684 .48842 Mdot
.895 .73495 Mdot
.86927 .71889 Mdot
.628 .126 .941 r
.29046 .36983 Mdot
1 .5 0 r
.27067 .3633 Mdot
.78736 .54582 Mdot
.23857 .31834 Mdot
.628 .126 .941 r
.24425 .37278 Mdot
.26298 .38553 Mdot
1 .5 0 r
.37351 .24456 Mdot
.628 .126 .941 r
.27536 .36939 Mdot
1 .5 0 r
.3525 .35338 Mdot
.43417 .4526 Mdot
.58666 .50693 Mdot
.53611 .40431 Mdot
.628 .126 .941 r
.31157 .39144 Mdot
.32435 .39464 Mdot
.26072 .33371 Mdot
.31137 .38176 Mdot
1 .5 0 r
.58638 .43302 Mdot
.30455 .38811 Mdot
.62322 .48409 Mdot
.74393 .56739 Mdot
.34191 .34935 Mdot
.25176 .35249 Mdot
.25176 .35249 Mdot
.31481 .3844 Mdot
.628 .126 .941 r
.3594 .35864 Mdot
.25076 .3041 Mdot
.35163 .43549 Mdot
1 .5 0 r
.51168 .45792 Mdot
.53062 .48036 Mdot
.42767 .4803 Mdot
.628 .126 .941 r
.26315 .28794 Mdot
.25017 .27506 Mdot
.2999 .39364 Mdot
.31845 .39672 Mdot
.2993 .36461 Mdot
1 .5 0 r
.57969 .50564 Mdot
.628 .126 .941 r
.22833 .34525 Mdot
.27996 .32281 Mdot
1 .5 0 r
.49671 .40289 Mdot
.51566 .42532 Mdot
.64773 .55338 Mdot
.25272 .29356 Mdot
.628 .126 .941 r
.32189 .39937 Mdot
1 .5 0 r
.22519 .30927 Mdot
.61403 .48558 Mdot
.63801 .58814 Mdot
.26203 .36039 Mdot
.32533 .40202 Mdot
.33813 .40522 Mdot
.628 .126 .941 r
.30571 .40516 Mdot
.8221 .64886 Mdot
.24749 .389 Mdot
1 .5 0 r
.61727 .53322 Mdot
.628 .126 .941 r
.80289 .55241 Mdot
1 .5 0 r
.73132 .62298 Mdot
.31021 .40158 Mdot
.628 .126 .941 r
.35552 .35019 Mdot
1 .5 0 r
.89829 .57475 Mdot
.628 .126 .941 r
.24108 .24105 Mdot
1 .5 0 r
.63596 .48166 Mdot
.628 .126 .941 r
.27881 .27627 Mdot
1 .5 0 r
.9169 .57785 Mdot
.628 .126 .941 r
.30875 .38844 Mdot
.37845 .45902 Mdot
1 .5 0 r
.68518 .57132 Mdot
.61436 .56164 Mdot
.628 .126 .941 r
.31452 .38831 Mdot
.23732 .34968 Mdot
.31366 .40423 Mdot
.41655 .3946 Mdot
1 .5 0 r
.70247 .62564 Mdot
.628 .126 .941 r
.35803 .42342 Mdot
.22317 .39769 Mdot
.31923 .39442 Mdot
1 .5 0 r
.35764 .40404 Mdot
.59408 .47138 Mdot
.628 .126 .941 r
.31208 .3267 Mdot
.36188 .44546 Mdot
1 .5 0 r
.73821 .55436 Mdot
.59714 .50936 Mdot
.78831 .62814 Mdot
.628 .126 .941 r
.31612 .35842 Mdot
.42978 .48356 Mdot
.22511 .38718 Mdot
.44808 .53166 Mdot
.29635 .29715 Mdot
.22641 .21682 Mdot
.2302 .41268 Mdot
1 .5 0 r
.83704 .68883 Mdot
.36618 .31308 Mdot
.628 .126 .941 r
.47483 .35803 Mdot
1 .5 0 r
.61433 .49932 Mdot
.74244 .53143 Mdot
.36456 .40935 Mdot
.84949 .67266 Mdot
.24317 .30646 Mdot
.628 .126 .941 r
.26167 .36427 Mdot
.1842 .3159 Mdot
.24711 .39292 Mdot
.40638 .47637 Mdot
1 .5 0 r
.90424 .74296 Mdot
.628 .126 .941 r
.43713 .50831 Mdot
.30972 .39582 Mdot
.4769 .3475 Mdot
1 .5 0 r
.32832 .39891 Mdot
.628 .126 .941 r
.32812 .3892 Mdot
1 .5 0 r
.83227 .67513 Mdot
.628 .126 .941 r
.28235 .42127 Mdot
.25034 .38587 Mdot
.37786 .44364 Mdot
.4672 .44673 Mdot
1 .5 0 r
.60774 .51742 Mdot
.71125 .47244 Mdot
.628 .126 .941 r
.37213 .2698 Mdot
1 .5 0 r
.49892 .40798 Mdot
.628 .126 .941 r
.65287 .39179 Mdot
1 .5 0 r
.23573 .29531 Mdot
.628 .126 .941 r
.31219 .34995 Mdot
.36185 .45916 Mdot
1 .5 0 r
.47897 .33696 Mdot
.628 .126 .941 r
.25915 .36898 Mdot
.2981 .34326 Mdot
1 .5 0 r
.8291 .56505 Mdot
.54679 .48463 Mdot
.67408 .5875 Mdot
.89304 .57142 Mdot
.628 .126 .941 r
.21553 .21455 Mdot
.45141 .35272 Mdot
.31013 .30765 Mdot
.30253 .39444 Mdot
.45169 .30765 Mdot
1 .5 0 r
.36694 .36545 Mdot
.35344 .38789 Mdot
.628 .126 .941 r
.3848 .44897 Mdot
1 .5 0 r
.49358 .49398 Mdot
.628 .126 .941 r
.21785 .39747 Mdot
.19784 .32642 Mdot
1 .5 0 r
.38229 .44206 Mdot
.628 .126 .941 r
.31937 .31014 Mdot
.21557 .34545 Mdot
1 .5 0 r
.3244 .39048 Mdot
.3244 .39048 Mdot
.40043 .48053 Mdot
.628 .126 .941 r
.28598 .32603 Mdot
1 .5 0 r
.75867 .57684 Mdot
.27303 .25828 Mdot
.49547 .47379 Mdot
.74547 .55421 Mdot
.628 .126 .941 r
.28975 .40291 Mdot
.38624 .40934 Mdot
1 .5 0 r
.60974 .49929 Mdot
.59025 .51216 Mdot
.628 .126 .941 r
.2188 .33838 Mdot
.29466 .41874 Mdot
.5528 .37692 Mdot
.4097 .48309 Mdot
.39667 .47016 Mdot
.28721 .39597 Mdot
1 .5 0 r
.53521 .48893 Mdot
.8039 .62732 Mdot
.628 .126 .941 r
.2081 .33432 Mdot
.2081 .33432 Mdot
1 .5 0 r
.46587 .32788 Mdot
.628 .126 .941 r
.74171 .41478 Mdot
.45664 .51128 Mdot
1 .5 0 r
.73772 .68831 Mdot
.628 .126 .941 r
.31091 .30522 Mdot
.3165 .29537 Mdot
.68828 .41441 Mdot
1 .5 0 r
.51447 .37894 Mdot
.628 .126 .941 r
.33922 .4497 Mdot
.21914 .25003 Mdot
.30172 .31435 Mdot
1 .5 0 r
.83199 .63304 Mdot
.628 .126 .941 r
.27353 .42042 Mdot
1 .5 0 r
.40446 .22064 Mdot
.628 .126 .941 r
.21495 .3396 Mdot
.23351 .39756 Mdot
.48553 .32665 Mdot
.27804 .41683 Mdot
.27785 .4071 Mdot
.26718 .21701 Mdot
.30846 .4294 Mdot
.42365 .49382 Mdot
1 .5 0 r
.42365 .49382 Mdot
.628 .126 .941 r
.28256 .41323 Mdot
.51437 .43578 Mdot
.25047 .37774 Mdot
.26285 .41639 Mdot
1 .5 0 r
.63556 .50981 Mdot
.4362 .42271 Mdot
.628 .126 .941 r
.28129 .40976 Mdot
.25662 .27754 Mdot
1 .5 0 r
.34517 .40642 Mdot
.37706 .43219 Mdot
.73079 .50308 Mdot
.628 .126 .941 r
.32069 .28392 Mdot
.32593 .37414 Mdot
.29363 .3289 Mdot
.30601 .36756 Mdot
1 .5 0 r
.39505 .46101 Mdot
.628 .126 .941 r
.36866 .48028 Mdot
1 .5 0 r
.7672 .58018 Mdot
.84386 .63496 Mdot
.628 .126 .941 r
.31208 .32226 Mdot
1 .5 0 r
.54265 .39625 Mdot
.70218 .52516 Mdot
.628 .126 .941 r
.32959 .38652 Mdot
1 .5 0 r
.40674 .40586 Mdot
.28423 .32831 Mdot
.628 .126 .941 r
.30232 .42179 Mdot
.36556 .44417 Mdot
1 .5 0 r
.56018 .34095 Mdot
.49645 .23443 Mdot
.4246 .25042 Mdot
.42413 .28588 Mdot
.628 .126 .941 r
.31884 .43741 Mdot
1 .5 0 r
.30054 .33418 Mdot
.628 .126 .941 r
.30578 .42445 Mdot
.27319 .42439 Mdot
1 .5 0 r
.47834 .50172 Mdot
.628 .126 .941 r
.29145 .40802 Mdot
.40057 .45317 Mdot
1 .5 0 r
.76014 .5692 Mdot
.86926 .61435 Mdot
.61824 .51426 Mdot
.628 .126 .941 r
.29113 .33359 Mdot
1 .5 0 r
.55353 .47867 Mdot
.628 .126 .941 r
.77323 .46254 Mdot
.48118 .53016 Mdot
.32207 .31069 Mdot
.33455 .29443 Mdot
1 .5 0 r
.6218 .51696 Mdot
.26265 .31043 Mdot
.628 .126 .941 r
.27532 .30391 Mdot
1 .5 0 r
.31831 .41993 Mdot
.628 .126 .941 r
.28569 .41987 Mdot
.27452 .26493 Mdot
.30599 .32623 Mdot
1 .5 0 r
.39448 .44556 Mdot
.628 .126 .941 r
.31179 .3261 Mdot
1 .5 0 r
.3565 .29041 Mdot
.42803 .25491 Mdot
.628 .126 .941 r
.56108 .44854 Mdot
1 .5 0 r
.20159 .23218 Mdot
.628 .126 .941 r
.30202 .42577 Mdot
.42411 .47418 Mdot
1 .5 0 r
.32901 .31596 Mdot
.628 .126 .941 r
.37965 .34488 Mdot
.38442 .47077 Mdot
.72699 .41255 Mdot
1 .5 0 r
.93049 .63201 Mdot
.54201 .54773 Mdot
.628 .126 .941 r
.75003 .45732 Mdot
1 .5 0 r
.66463 .56064 Mdot
.628 .126 .941 r
.76321 .41528 Mdot
1 .5 0 r
.3231 .43782 Mdot
.628 .126 .941 r
.27757 .43453 Mdot
.38159 .38932 Mdot
.43169 .5088 Mdot
.62428 .58302 Mdot
.34971 .30846 Mdot
.38645 .46024 Mdot
1 .5 0 r
.48981 .4408 Mdot
.628 .126 .941 r
.86347 .53446 Mdot
.26341 .42782 Mdot
.25033 .41484 Mdot
1 .5 0 r
.84115 .70552 Mdot
.42298 .48249 Mdot
.57075 .52765 Mdot
.41591 .47914 Mdot
.5257 .36899 Mdot
.628 .126 .941 r
.39489 .47884 Mdot
1 .5 0 r
.38896 .41416 Mdot
.33088 .30727 Mdot
.66255 .63036 Mdot
.628 .126 .941 r
.27032 .43318 Mdot
1 .5 0 r
.32858 .42995 Mdot
.85671 .59799 Mdot
.628 .126 .941 r
.37928 .45891 Mdot
1 .5 0 r
.53353 .53324 Mdot
.628 .126 .941 r
.32062 .44263 Mdot
.26454 .25833 Mdot
1 .5 0 r
.39779 .45226 Mdot
.56476 .52008 Mdot
.628 .126 .941 r
.50583 .54911 Mdot
.50583 .54911 Mdot
1 .5 0 r
.5598 .26432 Mdot
.4677 .32885 Mdot
.628 .126 .941 r
.50935 .55183 Mdot
.32378 .37069 Mdot
.63148 .59057 Mdot
.2801 .22512 Mdot
1 .5 0 r
.34986 .33183 Mdot
.628 .126 .941 r
.28994 .43201 Mdot
1 .5 0 r
.65576 .63891 Mdot
.628 .126 .941 r
.69075 .39625 Mdot
.39905 .40265 Mdot
.53286 .56113 Mdot
.25023 .37348 Mdot
.3721 .45757 Mdot
1 .5 0 r
.51451 .45757 Mdot
.41672 .41204 Mdot
.42245 .46703 Mdot
.9165 .77752 Mdot
.51709 .53144 Mdot
.628 .126 .941 r
.24611 .40837 Mdot
.43954 .44714 Mdot
.37002 .295 Mdot
.38054 .4762 Mdot
.51498 .54403 Mdot
.73493 .56345 Mdot
.34743 .4566 Mdot
.46917 .53097 Mdot
1 .5 0 r
.68962 .51479 Mdot
.56434 .55981 Mdot
.4151 .45593 Mdot
.628 .126 .941 r
.57774 .40737 Mdot
1 .5 0 r
.93554 .78289 Mdot
.628 .126 .941 r
.33769 .38135 Mdot
1 .5 0 r
.8599 .55611 Mdot
.628 .126 .941 r
.6056 .57855 Mdot
1 .5 0 r
.77401 .58503 Mdot
.628 .126 .941 r
.39229 .48777 Mdot
.45019 .52015 Mdot
.8459 .49424 Mdot
.27582 .44885 Mdot
1 .5 0 r
.43162 .40669 Mdot
.44434 .40015 Mdot
.628 .126 .941 r
.69701 .40986 Mdot
1 .5 0 r
.43649 .47781 Mdot
.628 .126 .941 r
.28925 .24112 Mdot
1 .5 0 r
.3843 .38033 Mdot
.57672 .53582 Mdot
.628 .126 .941 r
.47582 .27654 Mdot
1 .5 0 r
.46624 .50654 Mdot
.628 .126 .941 r
.31766 .44169 Mdot
.74325 .49971 Mdot
.45771 .48993 Mdot
1 .5 0 r
.71673 .51909 Mdot
.86372 .6811 Mdot
.36175 .36674 Mdot
.628 .126 .941 r
.33426 .45741 Mdot
1 .5 0 r
.43059 .47997 Mdot
.70766 .59333 Mdot
.50443 .24651 Mdot
.628 .126 .941 r
.30043 .46364 Mdot
.3144 .34036 Mdot
.29983 .43429 Mdot
1 .5 0 r
.39657 .47643 Mdot
.628 .126 .941 r
.29532 .26244 Mdot
1 .5 0 r
.78432 .56388 Mdot
.628 .126 .941 r
.39618 .45686 Mdot
.90101 .54762 Mdot
1 .5 0 r
.90658 .59294 Mdot
.628 .126 .941 r
.29185 .44701 Mdot
1 .5 0 r
.42261 .37245 Mdot
.628 .126 .941 r
.74586 .38847 Mdot
1 .5 0 r
.43285 .47919 Mdot
.38004 .47252 Mdot
.60043 .49198 Mdot
.628 .126 .941 r
.30806 .44315 Mdot
1 .5 0 r
.7278 .60205 Mdot
.33977 .44952 Mdot
.628 .126 .941 r
.29452 .41054 Mdot
.76043 .47204 Mdot
1 .5 0 r
.77012 .66977 Mdot
.42197 .46537 Mdot
.28757 .29663 Mdot
.44335 .29988 Mdot
.628 .126 .941 r
.44766 .46206 Mdot
.37078 .36144 Mdot
.27875 .44578 Mdot
1 .5 0 r
.44296 .28028 Mdot
.33251 .26075 Mdot
.628 .126 .941 r
.53633 .50718 Mdot
1 .5 0 r
.67728 .64993 Mdot
.628 .126 .941 r
.32145 .4778 Mdot
1 .5 0 r
.6072 .4778 Mdot
.83301 .58812 Mdot
.53778 .27975 Mdot
.628 .126 .941 r
.37445 .25352 Mdot
1 .5 0 r
.53346 .48062 Mdot
.628 .126 .941 r
.33809 .49355 Mdot
.35792 .36996 Mdot
.55648 .58095 Mdot
.4877 .35691 Mdot
1 .5 0 r
.59706 .43806 Mdot
.5113 .48664 Mdot
.46467 .49944 Mdot
.628 .126 .941 r
.32199 .45393 Mdot
.43166 .48958 Mdot
1 .5 0 r
.85241 .61296 Mdot
.628 .126 .941 r
.38588 .48628 Mdot
.87892 .52843 Mdot
.34807 .34977 Mdot
1 .5 0 r
.47108 .28781 Mdot
.628 .126 .941 r
.39842 .34945 Mdot
.30628 .43389 Mdot
1 .5 0 r
.46186 .41753 Mdot
.85666 .52465 Mdot
.628 .126 .941 r
.80254 .63498 Mdot
.31037 .46601 Mdot
1 .5 0 r
.25401 .28078 Mdot
.9121 .66085 Mdot
.628 .126 .941 r
.34261 .43665 Mdot
.29701 .44314 Mdot
.38926 .30332 Mdot
.48508 .40722 Mdot
.41171 .49482 Mdot
.56775 .49807 Mdot
.48277 .53056 Mdot
.43744 .49151 Mdot
1 .5 0 r
.48959 .45896 Mdot
.628 .126 .941 r
.52079 .55644 Mdot
.26276 .37441 Mdot
.34063 .33854 Mdot
1 .5 0 r
.41842 .35804 Mdot
.628 .126 .941 r
.8261 .51402 Mdot
1 .5 0 r
.67628 .53027 Mdot
.628 .126 .941 r
.53875 .57571 Mdot
.29497 .22445 Mdot
.31754 .48122 Mdot
.5644 .50723 Mdot
.29813 .44866 Mdot
.33644 .42897 Mdot
.57382 .6304 Mdot
1 .5 0 r
.41395 .37345 Mdot
.39454 .34088 Mdot
.628 .126 .941 r
.35475 .34725 Mdot
1 .5 0 r
.66944 .65939 Mdot
.83099 .6983 Mdot
.628 .126 .941 r
.34723 .32423 Mdot
1 .5 0 r
.54616 .5356 Mdot
.628 .126 .941 r
.40911 .4899 Mdot
.50743 .41503 Mdot
.56366 .59066 Mdot
.37795 .33691 Mdot
1 .5 0 r
.49907 .52881 Mdot
.628 .126 .941 r
.43447 .46695 Mdot
.4859 .51574 Mdot
.30066 .22619 Mdot
.81109 .51568 Mdot
1 .5 0 r
.50406 .54483 Mdot
.628 .126 .941 r
.37437 .45688 Mdot
.45801 .53171 Mdot
.45156 .50237 Mdot
1 .5 0 r
.38214 .31361 Mdot
.628 .126 .941 r
.36829 .3265 Mdot
.37935 .47291 Mdot
1 .5 0 r
.46973 .53147 Mdot
.76059 .69415 Mdot
.628 .126 .941 r
.27194 .20279 Mdot
.57896 .59318 Mdot
.34057 .35227 Mdot
1 .5 0 r
.51992 .57679 Mdot
.628 .126 .941 r
.80505 .68418 Mdot
.37259 .36847 Mdot
.50675 .56372 Mdot
.32094 .30983 Mdot
.71073 .36183 Mdot
.35084 .4594 Mdot
1 .5 0 r
.50569 .57006 Mdot
.628 .126 .941 r
.39055 .38774 Mdot
.48173 .3649 Mdot
1 .5 0 r
.44759 .48207 Mdot
.6111 .43324 Mdot
.42286 .35832 Mdot
.44989 .23776 Mdot
.44055 .42323 Mdot
.51078 .53065 Mdot
.39523 .32864 Mdot
.628 .126 .941 r
.89407 .5435 Mdot
.38638 .47833 Mdot
.46431 .49786 Mdot
.45064 .52059 Mdot
1 .5 0 r
.49933 .24372 Mdot
.628 .126 .941 r
.66002 .40977 Mdot
.9052 .56925 Mdot
1 .5 0 r
.59228 .55292 Mdot
.628 .126 .941 r
.4617 .54635 Mdot
.38316 .49732 Mdot
.5126 .56571 Mdot
1 .5 0 r
.35986 .26604 Mdot
.48883 .37025 Mdot
.628 .126 .941 r
.66891 .50366 Mdot
.4998 .45148 Mdot
1 .5 0 r
.66824 .52965 Mdot
.628 .126 .941 r
.49065 .5261 Mdot
1 .5 0 r
.48391 .54239 Mdot
.628 .126 .941 r
.49238 .37293 Mdot
.62187 .44134 Mdot
.53464 .55193 Mdot
.54716 .59103 Mdot
.41939 .36942 Mdot
.35524 .21607 Mdot
.37354 .31057 Mdot
.39694 .48647 Mdot
.51972 .57119 Mdot
1 .5 0 r
.61101 .54832 Mdot
.628 .126 .941 r
.57086 .60041 Mdot
.32283 .48931 Mdot
.40085 .50886 Mdot
1 .5 0 r
.43534 .34583 Mdot
.628 .126 .941 r
.51095 .54466 Mdot
.33881 .2219 Mdot
.3942 .46963 Mdot
1 .5 0 r
.52309 .5641 Mdot
.628 .126 .941 r
.31577 .43039 Mdot
1 .5 0 r
.52897 .56398 Mdot
.4016 .30638 Mdot
.5281 .58017 Mdot
.75451 .72688 Mdot
.628 .126 .941 r
.30341 .28017 Mdot
.45227 .37146 Mdot
1 .5 0 r
.88055 .55077 Mdot
.628 .126 .941 r
.37961 .38763 Mdot
1 .5 0 r
.26828 .29274 Mdot
.628 .126 .941 r
.48878 .3742 Mdot
.32377 .48502 Mdot
.73628 .39045 Mdot
1 .5 0 r
.35209 .24674 Mdot
.3839 .30871 Mdot
.628 .126 .941 r
.456 .26298 Mdot
.29916 .24987 Mdot
1 .5 0 r
.4934 .37056 Mdot
.64032 .54 Mdot
.89386 .62155 Mdot
.628 .126 .941 r
.38734 .36697 Mdot
1 .5 0 r
.41365 .32776 Mdot
.38666 .39301 Mdot
.628 .126 .941 r
.36043 .37663 Mdot
.47854 .33422 Mdot
.49686 .42883 Mdot
.50168 .55608 Mdot
.28964 .24925 Mdot
.41885 .35366 Mdot
1 .5 0 r
.58258 .29487 Mdot
.54719 .47427 Mdot
.628 .126 .941 r
.56503 .60479 Mdot
.31998 .29786 Mdot
1 .5 0 r
.53292 .4675 Mdot
.43348 .50322 Mdot
.628 .126 .941 r
.49945 .38226 Mdot
1 .5 0 r
.60797 .57159 Mdot
.628 .126 .941 r
.51276 .33976 Mdot
.50456 .46381 Mdot
.46405 .56174 Mdot
1 .5 0 r
.58733 .60085 Mdot
.56177 .55841 Mdot
.53215 .30699 Mdot
.628 .126 .941 r
.41184 .48321 Mdot
.5088 .56156 Mdot
.33977 .47336 Mdot
1 .5 0 r
.54093 .57783 Mdot
.54682 .57771 Mdot
.54036 .54827 Mdot
.55965 .57113 Mdot
.4813 .54168 Mdot
.628 .126 .941 r
.49413 .53509 Mdot
1 .5 0 r
.72139 .64611 Mdot
.628 .126 .941 r
.4703 .33911 Mdot
1 .5 0 r
.55985 .45987 Mdot
.628 .126 .941 r
.48631 .55778 Mdot
1 .5 0 r
.49316 .48581 Mdot
.5641 .55766 Mdot
.67732 .37797 Mdot
.714 .5674 Mdot
.628 .126 .941 r
.39143 .2244 Mdot
.66295 .42684 Mdot
1 .5 0 r
.50416 .56729 Mdot
.628 .126 .941 r
.43399 .41371 Mdot
.72212 .37778 Mdot
.48399 .56064 Mdot
.46593 .42012 Mdot
1 .5 0 r
.53592 .56385 Mdot
.91253 .71074 Mdot
.30275 .27605 Mdot
.628 .126 .941 r
.36531 .46222 Mdot
.47538 .5439 Mdot
1 .5 0 r
.51574 .43602 Mdot
.41947 .27585 Mdot
.54046 .49471 Mdot
.628 .126 .941 r
.5395 .56659 Mdot
.57909 .54045 Mdot
.41763 .36394 Mdot
1 .5 0 r
.55186 .59595 Mdot
.3986 .29525 Mdot
.35225 .33774 Mdot
.8386 .60231 Mdot
.55041 .58259 Mdot
.55717 .56625 Mdot
.628 .126 .941 r
.54288 .55948 Mdot
.39972 .4777 Mdot
1 .5 0 r
.60094 .57244 Mdot
.628 .126 .941 r
.76606 .38592 Mdot
.57332 .60823 Mdot
1 .5 0 r
.47052 .41849 Mdot
.628 .126 .941 r
.52231 .41182 Mdot
.52665 .57531 Mdot
1 .5 0 r
.65093 .53268 Mdot
.628 .126 .941 r
.39803 .33315 Mdot
1 .5 0 r
.53216 .55546 Mdot
.53216 .55546 Mdot
.53197 .54559 Mdot
.628 .126 .941 r
.69686 .40484 Mdot
.43377 .47346 Mdot
1 .5 0 r
.56329 .57812 Mdot
.537 .56171 Mdot
.76474 .6172 Mdot
.628 .126 .941 r
.61713 .37182 Mdot
.59007 .43724 Mdot
1 .5 0 r
.5166 .54518 Mdot
.56184 .56475 Mdot
.54812 .58759 Mdot
.628 .126 .941 r
.53487 .57445 Mdot
.72707 .3781 Mdot
.30293 .2439 Mdot
.46922 .53834 Mdot
.85596 .5089 Mdot
1 .5 0 r
.54058 .56446 Mdot
.5662 .60699 Mdot
.54715 .53823 Mdot
.53342 .56107 Mdot
.67683 .58719 Mdot
.628 .126 .941 r
.64975 .65263 Mdot
1 .5 0 r
.51515 .41044 Mdot
.628 .126 .941 r
.89325 .54132 Mdot
1 .5 0 r
.53913 .55108 Mdot
.55218 .55435 Mdot
.56476 .59362 Mdot
.60711 .34159 Mdot
.45992 .54769 Mdot
.628 .126 .941 r
.46263 .32183 Mdot
1 .5 0 r
.43555 .38728 Mdot
.628 .126 .941 r
.90461 .57709 Mdot
.46853 .32169 Mdot
.478 .5671 Mdot
1 .5 0 r
.537 .56382 Mdot
.537 .56382 Mdot
.628 .126 .941 r
.88424 .56055 Mdot
.49957 .40011 Mdot
.52375 .55067 Mdot
1 .5 0 r
.54291 .56371 Mdot
.40148 .33779 Mdot
.38871 .28863 Mdot
.49415 .2428 Mdot
.628 .126 .941 r
.5222 .59305 Mdot
.39867 .49806 Mdot
.41782 .5111 Mdot
.47635 .54383 Mdot
1 .5 0 r
.54213 .52419 Mdot
.54775 .56997 Mdot
.63869 .62889 Mdot
.628 .126 .941 r
.5043 .34067 Mdot
1 .5 0 r
.54059 .56658 Mdot
.54059 .56658 Mdot
.48137 .55997 Mdot
.5134 .5664 Mdot
.628 .126 .941 r
.57823 .61879 Mdot
1 .5 0 r
.49317 .55974 Mdot
.57765 .58915 Mdot
.53091 .55617 Mdot
.53091 .55617 Mdot
.53091 .55617 Mdot
.64125 .63805 Mdot
.55008 .56922 Mdot
.628 .126 .941 r
.77995 .53646 Mdot
1 .5 0 r
.54989 .55933 Mdot
.628 .126 .941 r
.57554 .60191 Mdot
1 .5 0 r
.57554 .60191 Mdot
.51243 .3955 Mdot
.47951 .40533 Mdot
.45928 .39865 Mdot
.56818 .58864 Mdot
.628 .126 .941 r
.83469 .73599 Mdot
1 .5 0 r
.5436 .41818 Mdot
.628 .126 .941 r
.48483 .37553 Mdot
1 .5 0 r
.54776 .57209 Mdot
.53411 .53915 Mdot
.628 .126 .941 r
.41821 .35561 Mdot
.516 .39821 Mdot
1 .5 0 r
.52811 .47357 Mdot
.628 .126 .941 r
.38945 .51938 Mdot
1 .5 0 r
.60489 .59146 Mdot
.59812 .60784 Mdot
.628 .126 .941 r
.55851 .57824 Mdot
.40822 .51264 Mdot
1 .5 0 r
.53314 .48971 Mdot
.5651 .55197 Mdot
.63095 .5323 Mdot
.56462 .58801 Mdot
.628 .126 .941 r
.6356 .65022 Mdot
1 .5 0 r
.53808 .56168 Mdot
.53808 .56168 Mdot
.628 .126 .941 r
.59842 .44037 Mdot
1 .5 0 r
.5377 .5419 Mdot
.40287 .29931 Mdot
.628 .126 .941 r
.53702 .56806 Mdot
1 .5 0 r
.46757 .34185 Mdot
.628 .126 .941 r
.65306 .69583 Mdot
.41177 .51538 Mdot
1 .5 0 r
.53673 .49244 Mdot
.55543 .54155 Mdot
.55494 .57761 Mdot
.628 .126 .941 r
.77775 .59727 Mdot
1 .5 0 r
.61966 .62016 Mdot
.60639 .607 Mdot
.61947 .61027 Mdot
.61947 .61027 Mdot
.628 .126 .941 r
.4662 .27255 Mdot
1 .5 0 r
.56066 .5676 Mdot
.59312 .59383 Mdot
.628 .126 .941 r
.75629 .5871 Mdot
1 .5 0 r
.45727 .30165 Mdot
.628 .126 .941 r
.78674 .69185 Mdot
.3403 .1901 Mdot
.57288 .46554 Mdot
1 .5 0 r
.54526 .56719 Mdot
.628 .126 .941 r
.88637 .58031 Mdot
.31277 .23587 Mdot
1 .5 0 r
.59672 .59659 Mdot
.88262 .81303 Mdot
.628 .126 .941 r
.37508 .4588 Mdot
1 .5 0 r
.54468 .53751 Mdot
.6886 .57358 Mdot
.51541 .24885 Mdot
.53092 .5604 Mdot
.5504 .52749 Mdot
.628 .126 .941 r
.70936 .42254 Mdot
.38959 .23217 Mdot
1 .5 0 r
.49864 .42241 Mdot
.54885 .56995 Mdot
.54885 .56995 Mdot
.628 .126 .941 r
.4333 .35012 Mdot
.57047 .4026 Mdot
1 .5 0 r
.61361 .61254 Mdot
.60033 .59936 Mdot
.628 .126 .941 r
.52404 .38936 Mdot
.56718 .59931 Mdot
1 .5 0 r
.56718 .59931 Mdot
.628 .126 .941 r
.34109 .29743 Mdot
1 .5 0 r
.53451 .56316 Mdot
.61255 .61893 Mdot
.78367 .58941 Mdot
.9194 .75016 Mdot
.38598 .35314 Mdot
.48341 .43188 Mdot
.56728 .54342 Mdot
.628 .126 .941 r
.56776 .50733 Mdot
.3213 .25465 Mdot
1 .5 0 r
.55351 .56633 Mdot
.628 .126 .941 r
.52132 .49409 Mdot
.3209 .23483 Mdot
1 .5 0 r
.55264 .58262 Mdot
.45015 .366 Mdot
.628 .126 .941 r
.61965 .43484 Mdot
1 .5 0 r
.61189 .52344 Mdot
.42988 .35931 Mdot
.628 .126 .941 r
.51453 .38878 Mdot
1 .5 0 r
.80643 .66114 Mdot
.628 .126 .941 r
.36838 .48716 Mdot
1 .5 0 r
.60288 .60853 Mdot
.628 .126 .941 r
.43491 .37546 Mdot
.53752 .53621 Mdot
.53732 .52631 Mdot
1 .5 0 r
.60794 .62471 Mdot
.62084 .61809 Mdot
.54644 .26354 Mdot
.628 .126 .941 r
.58767 .61803 Mdot
1 .5 0 r
.58767 .61803 Mdot
.58767 .61803 Mdot
.60756 .60491 Mdot
.628 .126 .941 r
.40753 .30942 Mdot
1 .5 0 r
.66635 .58181 Mdot
.45302 .27311 Mdot
.40694 .27968 Mdot
.47048 .44054 Mdot
.628 .126 .941 r
.72079 .39458 Mdot
1 .5 0 r
.56071 .57185 Mdot
.59321 .59811 Mdot
.628 .126 .941 r
.73 .68675 Mdot
1 .5 0 r
.58137 .47659 Mdot
.52801 .53568 Mdot
.628 .126 .941 r
.57361 .56523 Mdot
1 .5 0 r
.62446 .62087 Mdot
.62446 .62087 Mdot
.58643 .49276 Mdot
.57867 .58141 Mdot
.61117 .60768 Mdot
.61117 .60768 Mdot
.628 .126 .941 r
.40187 .50912 Mdot
1 .5 0 r
.6302 .61085 Mdot
.62389 .59115 Mdot
.6234 .62727 Mdot
.628 .126 .941 r
.45339 .53855 Mdot
1 .5 0 r
.41049 .28235 Mdot
.54539 .5155 Mdot
.87049 .77821 Mdot
.52627 .44648 Mdot
.36234 .36754 Mdot
.51132 .53175 Mdot
.628 .126 .941 r
.43445 .35762 Mdot
1 .5 0 r
.43396 .39375 Mdot
.64119 .62693 Mdot
.88869 .79772 Mdot
.42843 .29187 Mdot
.5816 .6104 Mdot
.5816 .6104 Mdot
.628 .126 .941 r
.31668 .21611 Mdot
1 .5 0 r
.61373 .61686 Mdot
.61373 .61686 Mdot
.61373 .61686 Mdot
.60063 .61357 Mdot
.628 .126 .941 r
.54364 .42628 Mdot
1 .5 0 r
.60043 .60366 Mdot
.60043 .60366 Mdot
.60043 .60366 Mdot
.60043 .60366 Mdot
.628 .126 .941 r
.43229 .37037 Mdot
.53403 .60355 Mdot
.4785 .30782 Mdot
1 .5 0 r
.87298 .77756 Mdot
.628 .126 .941 r
.41742 .39968 Mdot
1 .5 0 r
.56646 .56395 Mdot
.628 .126 .941 r
.59851 .62637 Mdot
1 .5 0 r
.61841 .61323 Mdot
.61841 .61323 Mdot
.61841 .61323 Mdot
.628 .126 .941 r
.41771 .35362 Mdot
1 .5 0 r
.56608 .54412 Mdot
.628 .126 .941 r
.53889 .60983 Mdot
1 .5 0 r
.61735 .61963 Mdot
.61735 .61963 Mdot
.628 .126 .941 r
.42295 .37971 Mdot
1 .5 0 r
.58414 .61958 Mdot
.63027 .61301 Mdot
.60405 .60644 Mdot
.60405 .60644 Mdot
.60405 .60644 Mdot
.628 .126 .941 r
.61648 .63595 Mdot
1 .5 0 r
.52549 .53074 Mdot
.57065 .59646 Mdot
.628 .126 .941 r
.7375 .39266 Mdot
.52432 .59312 Mdot
1 .5 0 r
.50568 .4879 Mdot
.63533 .62921 Mdot
.628 .126 .941 r
.58949 .58972 Mdot
1 .5 0 r
.62203 .61601 Mdot
.62203 .61601 Mdot
.62203 .61601 Mdot
.58882 .61596 Mdot
.628 .126 .941 r
.58833 .65211 Mdot
.60271 .53702 Mdot
1 .5 0 r
.63428 .63562 Mdot
.65419 .62247 Mdot
.50538 .41206 Mdot
.628 .126 .941 r
.53695 .51066 Mdot
.50422 .47445 Mdot
1 .5 0 r
.60767 .60921 Mdot
.60767 .60921 Mdot
.60767 .60921 Mdot
.628 .126 .941 r
.46322 .56314 Mdot
1 .5 0 r
.52326 .47761 Mdot
.628 .126 .941 r
.71317 .54336 Mdot
1 .5 0 r
.52306 .46769 Mdot
.628 .126 .941 r
.46263 .53338 Mdot
1 .5 0 r
.61953 .60899 Mdot
.61953 .60899 Mdot
.628 .126 .941 r
.44398 .42812 Mdot
1 .5 0 r
.57368 .56948 Mdot
.62566 .61879 Mdot
.62566 .61879 Mdot
.628 .126 .941 r
.79209 .45107 Mdot
1 .5 0 r
.73944 .42799 Mdot
.628 .126 .941 r
.67677 .68443 Mdot
.48954 .39176 Mdot
.49391 .55616 Mdot
.60662 .49369 Mdot
1 .5 0 r
.6246 .6252 Mdot
.46408 .30293 Mdot
.63752 .61857 Mdot
.61129 .61199 Mdot
.61129 .61199 Mdot
.61129 .61199 Mdot
.57806 .61194 Mdot
.628 .126 .941 r
.67553 .68093 Mdot
.73559 .59538 Mdot
1 .5 0 r
.92976 .81565 Mdot
.628 .126 .941 r
.5457 .47359 Mdot
1 .5 0 r
.62928 .62158 Mdot
.62928 .62158 Mdot
.49964 .42414 Mdot
.51227 .4636 Mdot
.628 .126 .941 r
.63668 .51293 Mdot
1 .5 0 r
.54337 .59844 Mdot
.6289 .60173 Mdot
.39447 .3879 Mdot
.628 .126 .941 r
.57185 .41421 Mdot
1 .5 0 r
.5634 .52926 Mdot
.628 .126 .941 r
.60908 .55886 Mdot
1 .5 0 r
.62172 .59833 Mdot
.61491 .61477 Mdot
.61491 .61477 Mdot
.61491 .61477 Mdot
.6084 .58511 Mdot
.6084 .58511 Mdot
.69394 .5884 Mdot
.39533 .24956 Mdot
.628 .126 .941 r
.53045 .48309 Mdot
.53511 .60145 Mdot
.65273 .66723 Mdot
.62708 .56844 Mdot
1 .5 0 r
.63291 .62436 Mdot
.60034 .59804 Mdot
.63291 .62436 Mdot
.63291 .62436 Mdot
.628 .126 .941 r
.64555 .66383 Mdot
1 .5 0 r
.6927 .58489 Mdot
.628 .126 .941 r
.68765 .44666 Mdot
.56758 .5618 Mdot
.4972 .361 Mdot
1 .5 0 r
.61854 .61756 Mdot
.61854 .61756 Mdot
.4691 .44312 Mdot
.628 .126 .941 r
.42826 .54183 Mdot
1 .5 0 r
.59987 .51222 Mdot
.61203 .58789 Mdot
.628 .126 .941 r
.54182 .397 Mdot
.53871 .60423 Mdot
.48747 .47255 Mdot
1 .5 0 r
.63041 .61733 Mdot
.60416 .61075 Mdot
.60416 .61075 Mdot
.60416 .61075 Mdot
.628 .126 .941 r
.42309 .33758 Mdot
1 .5 0 r
.48192 .37048 Mdot
.63654 .62715 Mdot
.84611 .71599 Mdot
.628 .126 .941 r
.60329 .62709 Mdot
1 .5 0 r
.60329 .62709 Mdot
.62216 .62034 Mdot
.62216 .62034 Mdot
.46149 .29775 Mdot
.5889 .62028 Mdot
.628 .126 .941 r
.60233 .57744 Mdot
1 .5 0 r
.58871 .61035 Mdot
.45312 .3568 Mdot
.60778 .61353 Mdot
.60778 .61353 Mdot
.60778 .61353 Mdot
.80573 .59049 Mdot
.64018 .62993 Mdot
.60759 .6036 Mdot
.57432 .60354 Mdot
.57432 .60354 Mdot
.38005 .32698 Mdot
.628 .126 .941 r
.73962 .48815 Mdot
1 .5 0 r
.60585 .63629 Mdot
.628 .126 .941 r
.48112 .57698 Mdot
1 .5 0 r
.57939 .61978 Mdot
.628 .126 .941 r
.75014 .66258 Mdot
1 .5 0 r
.67046 .65917 Mdot
.70306 .68551 Mdot
.628 .126 .941 r
.48881 .42206 Mdot
1 .5 0 r
.67027 .64924 Mdot
.55166 .59974 Mdot
.44248 .3626 Mdot
.628 .126 .941 r
.85508 .55688 Mdot
.40384 .27033 Mdot
1 .5 0 r
.52889 .2835 Mdot
.5396 .46791 Mdot
.55858 .52718 Mdot
.47469 .36906 Mdot
.49415 .39211 Mdot
.62942 .62591 Mdot
.62942 .62591 Mdot
.47984 .45132 Mdot
.628 .126 .941 r
.5397 .4118 Mdot
.5397 .4118 Mdot
1 .5 0 r
.59614 .62586 Mdot
.59614 .62586 Mdot
.628 .126 .941 r
.43176 .5467 Mdot
1 .5 0 r
.55732 .52365 Mdot
.56861 .61575 Mdot
.628 .126 .941 r
.57085 .42466 Mdot
1 .5 0 r
.44606 .36531 Mdot
.628 .126 .941 r
.81012 .74739 Mdot
1 .5 0 r
.60872 .47718 Mdot
.61359 .60564 Mdot
.61359 .60564 Mdot
.63257 .66494 Mdot
.628 .126 .941 r
.61924 .65171 Mdot
.58887 .43423 Mdot
.58059 .55941 Mdot
.69139 .63183 Mdot
1 .5 0 r
.64495 .62848 Mdot
.628 .126 .941 r
.76014 .37474 Mdot
1 .5 0 r
.61847 .61195 Mdot
.61847 .61195 Mdot
.63162 .61524 Mdot
.64427 .65478 Mdot
.628 .126 .941 r
.72996 .65808 Mdot
1 .5 0 r
.53406 .48999 Mdot
.5212 .4405 Mdot
.58498 .60195 Mdot
.628 .126 .941 r
.71498 .74363 Mdot
1 .5 0 r
.63689 .64144 Mdot
.628 .126 .941 r
.36501 .23608 Mdot
1 .5 0 r
.62355 .6282 Mdot
.61722 .60843 Mdot
.628 .126 .941 r
.50874 .28867 Mdot
1 .5 0 r
.53308 .44025 Mdot
.628 .126 .941 r
.57301 .41389 Mdot
1 .5 0 r
.61635 .62479 Mdot
.42917 .29519 Mdot
.628 .126 .941 r
.80996 .42701 Mdot
1 .5 0 r
.93024 .80269 Mdot
.51322 .39729 Mdot
.6223 .62468 Mdot
.6221 .61474 Mdot
.628 .126 .941 r
.50533 .42017 Mdot
.52968 .57178 Mdot
1 .5 0 r
.4988 .39044 Mdot
.83594 .78256 Mdot
.60683 .62429 Mdot
.628 .126 .941 r
.60664 .61434 Mdot
.62593 .62747 Mdot
1 .5 0 r
.62593 .62747 Mdot
.60674 .55818 Mdot
.628 .126 .941 r
.37349 .18881 Mdot
.5552 .4163 Mdot
.51331 .58774 Mdot
1 .5 0 r
.60587 .57455 Mdot
.628 .126 .941 r
.62449 .614 Mdot
.63033 .67005 Mdot
1 .5 0 r
.5975 .63373 Mdot
.63696 .64362 Mdot
.65694 .63043 Mdot
.61065 .63703 Mdot
.85913 .80848 Mdot
.628 .126 .941 r
.41391 .49512 Mdot
1 .5 0 r
.52042 .40273 Mdot
.628 .126 .941 r
.33778 .19154 Mdot
1 .5 0 r
.57753 .52462 Mdot
.56437 .52132 Mdot
.4404 .38935 Mdot
.628 .126 .941 r
.69722 .43552 Mdot
1 .5 0 r
.5827 .60701 Mdot
.63221 .33651 Mdot
.628 .126 .941 r
.70299 .42543 Mdot
1 .5 0 r
.94875 .75846 Mdot
.628 .126 .941 r
.48942 .5242 Mdot
1 .5 0 r
.56156 .56049 Mdot
.628 .126 .941 r
.52393 .33928 Mdot
1 .5 0 r
.53563 .45145 Mdot
.6186 .61628 Mdot
.67759 .64928 Mdot
.4312 .28629 Mdot
.60476 .63932 Mdot
.56634 .50063 Mdot
.628 .126 .941 r
.61228 .47411 Mdot
1 .5 0 r
.63666 .6259 Mdot
.63666 .6259 Mdot
.6035 .6358 Mdot
.6035 .6358 Mdot
.57942 .43775 Mdot
.628 .126 .941 r
.63598 .65224 Mdot
1 .5 0 r
.51973 .43109 Mdot
.628 .126 .941 r
.81036 .43109 Mdot
1 .5 0 r
.59726 .55979 Mdot
.62156 .64542 Mdot
.60839 .64212 Mdot
.60839 .64212 Mdot
.61551 .57936 Mdot
.628 .126 .941 r
.57777 .41427 Mdot
.50861 .59569 Mdot
1 .5 0 r
.59397 .6353 Mdot
.60713 .6386 Mdot
.60713 .6386 Mdot
.6403 .6287 Mdot
.628 .126 .941 r
.48452 .39757 Mdot
1 .5 0 r
.5806 .62204 Mdot
.628 .126 .941 r
.58705 .58561 Mdot
.51397 .56569 Mdot
1 .5 0 r
.61203 .64492 Mdot
.6252 .64822 Mdot
.628 .126 .941 r
.56256 .36754 Mdot
1 .5 0 r
.63818 .64157 Mdot
.73672 .68448 Mdot
.628 .126 .941 r
.43748 .30805 Mdot
1 .5 0 r
.54139 .44341 Mdot
.59262 .56557 Mdot
.69 .67117 Mdot
.628 .126 .941 r
.68951 .70749 Mdot
1 .5 0 r
.50197 .37725 Mdot
.628 .126 .941 r
.59272 .50932 Mdot
1 .5 0 r
.5976 .6381 Mdot
.65663 .67111 Mdot
.55984 .47294 Mdot
.58423 .62483 Mdot
.58423 .62483 Mdot
.62375 .63474 Mdot
.628 .126 .941 r
.7029 .5983 Mdot
1 .5 0 r
.50655 .42983 Mdot
.61049 .56522 Mdot
.628 .126 .941 r
.64221 .66429 Mdot
.68905 .62136 Mdot
1 .5 0 r
.62865 .64106 Mdot
.45424 .31405 Mdot
.628 .126 .941 r
.73972 .71367 Mdot
1 .5 0 r
.70684 .67728 Mdot
.57683 .48897 Mdot
.628 .126 .941 r
.78913 .43282 Mdot
1 .5 0 r
.61441 .6442 Mdot
.61441 .6442 Mdot
.628 .126 .941 r
.74892 .44927 Mdot
.55692 .4459 Mdot
.55702 .38962 Mdot
1 .5 0 r
.56141 .55479 Mdot
.6193 .65053 Mdot
.92927 .70999 Mdot
.628 .126 .941 r
.6977 .69672 Mdot
1 .5 0 r
.6977 .69672 Mdot
.56698 .53473 Mdot
.71051 .6801 Mdot
.63269 .54128 Mdot
.63172 .61396 Mdot
.60487 .6437 Mdot
.60487 .6437 Mdot
.61805 .647 Mdot
.628 .126 .941 r
.65057 .66347 Mdot
1 .5 0 r
.71024 .60388 Mdot
.628 .126 .941 r
.37734 .22706 Mdot
1 .5 0 r
.47549 .30637 Mdot
.628 .126 .941 r
.65029 .58725 Mdot
1 .5 0 r
.60342 .6302 Mdot
.62295 .65333 Mdot
.6625 .66325 Mdot
.40253 .29638 Mdot
.56494 .49129 Mdot
.55059 .55072 Mdot
.64923 .59368 Mdot
.6085 .6465 Mdot
.58389 .4845 Mdot
.59024 .50433 Mdot
.628 .126 .941 r
.42722 .27945 Mdot
.3943 .24302 Mdot
.51787 .40168 Mdot
1 .5 0 r
.68618 .65284 Mdot
.66615 .66606 Mdot
.79754 .73547 Mdot
.628 .126 .941 r
.49501 .57675 Mdot
1 .5 0 r
.69166 .68909 Mdot
.81164 .59978 Mdot
.628 .126 .941 r
.67467 .42781 Mdot
1 .5 0 r
.62533 .65262 Mdot
.62533 .65262 Mdot
.62533 .65262 Mdot
.62533 .65262 Mdot
.50301 .37485 Mdot
.58665 .50367 Mdot
.59174 .51996 Mdot
.628 .126 .941 r
.84876 .60263 Mdot
1 .5 0 r
.6109 .52314 Mdot
.62898 .65542 Mdot
.628 .126 .941 r
.63661 .55616 Mdot
1 .5 0 r
.46049 .33782 Mdot
.91741 .81737 Mdot
.57074 .48328 Mdot
.49235 .38068 Mdot
.49821 .43691 Mdot
.628 .126 .941 r
.55735 .46999 Mdot
.56859 .61882 Mdot
1 .5 0 r
.6287 .57913 Mdot
.72596 .73128 Mdot
.74513 .73448 Mdot
.72472 .72776 Mdot
.41218 .31089 Mdot
.46448 .36051 Mdot
.61943 .65493 Mdot
.61943 .65493 Mdot
.63263 .65824 Mdot
.93569 .77071 Mdot
.628 .126 .941 r
.88467 .60194 Mdot
1 .5 0 r
.61905 .63497 Mdot
.63225 .63828 Mdot
.61837 .66138 Mdot
.64536 .57524 Mdot
.65074 .66789 Mdot
.45694 .28071 Mdot
.4631 .29057 Mdot
.63628 .66105 Mdot
.63628 .66105 Mdot
.63628 .66105 Mdot
.62308 .65774 Mdot
.62308 .65774 Mdot
.62308 .65774 Mdot
.68224 .69083 Mdot
.60969 .64445 Mdot
.43541 .28037 Mdot
.46769 .34325 Mdot
.42083 .32988 Mdot
.44773 .30009 Mdot
.60305 .54824 Mdot
.60334 .50185 Mdot
.628 .126 .941 r
.63562 .56473 Mdot
1 .5 0 r
.64785 .64086 Mdot
.628 .126 .941 r
.62095 .67065 Mdot
.40165 .2039 Mdot
.38747 .27341 Mdot
.55131 .4058 Mdot
.5831 .5051 Mdot
1 .5 0 r
.63445 .62756 Mdot
.628 .126 .941 r
.72591 .72355 Mdot
.63456 .57118 Mdot
1 .5 0 r
.62673 .66055 Mdot
.628 .126 .941 r
.49252 .26989 Mdot
1 .5 0 r
.61333 .64726 Mdot
.439 .28306 Mdot
.628 .126 .941 r
.54642 .64714 Mdot
1 .5 0 r
.50367 .35245 Mdot
.63917 .62392 Mdot
.628 .126 .941 r
.48977 .37556 Mdot
.66588 .58413 Mdot
1 .5 0 r
.49642 .34901 Mdot
.628 .126 .941 r
.74427 .62043 Mdot
1 .5 0 r
.84994 .64692 Mdot
.628 .126 .941 r
.56257 .30914 Mdot
1 .5 0 r
.48869 .38199 Mdot
.628 .126 .941 r
.55474 .39854 Mdot
.35179 .16331 Mdot
1 .5 0 r
.61698 .65007 Mdot
.54564 .48438 Mdot
.628 .126 .941 r
.57207 .491 Mdot
1 .5 0 r
.62932 .66982 Mdot
.48771 .33199 Mdot
.55866 .4777 Mdot
.628 .126 .941 r
.5064 .3716 Mdot
1 .5 0 r
.5064 .3716 Mdot
.51178 .46433 Mdot
.628 .126 .941 r
.65027 .51732 Mdot
1 .5 0 r
.64244 .60674 Mdot
.628 .126 .941 r
.74668 .74252 Mdot
1 .5 0 r
.44111 .27217 Mdot
.628 .126 .941 r
.43231 .43446 Mdot
.56327 .53044 Mdot
1 .5 0 r
.63404 .66618 Mdot
.628 .126 .941 r
.63629 .47402 Mdot
1 .5 0 r
.62063 .65288 Mdot
.62063 .65288 Mdot
.75963 .66944 Mdot
.61339 .64946 Mdot
.628 .126 .941 r
.51824 .30489 Mdot
.53371 .60959 Mdot
.69182 .68578 Mdot
1 .5 0 r
.6185 .6658 Mdot
.628 .126 .941 r
.84252 .74857 Mdot
.55202 .62924 Mdot
1 .5 0 r
.63769 .669 Mdot
.63769 .669 Mdot
.65091 .67231 Mdot
.628 .126 .941 r
.57738 .64233 Mdot
1 .5 0 r
.69666 .6257 Mdot
.50061 .38374 Mdot
.628 .126 .941 r
.65926 .42351 Mdot
.53733 .61239 Mdot
.66366 .5892 Mdot
1 .5 0 r
.54644 .40356 Mdot
.628 .126 .941 r
.73448 .72501 Mdot
.55996 .36041 Mdot
1 .5 0 r
.56583 .41675 Mdot
.628 .126 .941 r
.73361 .74147 Mdot
1 .5 0 r
.61667 .50936 Mdot
.62794 .65851 Mdot
.44702 .27398 Mdot
.63411 .6684 Mdot
.63411 .6684 Mdot
.76077 .59874 Mdot
.628 .126 .941 r
.39422 .20423 Mdot
1 .5 0 r
.51725 .37978 Mdot
.62041 .57862 Mdot
.45122 .30672 Mdot
.628 .126 .941 r
.69939 .5785 Mdot
.67783 .70117 Mdot
.70429 .7078 Mdot
.5297 .34305 Mdot
1 .5 0 r
.63159 .66133 Mdot
.51578 .36619 Mdot
.628 .126 .941 r
.6412 .41592 Mdot
.56801 .40591 Mdot
1 .5 0 r
.61945 .52859 Mdot
.628 .126 .941 r
.6514 .57158 Mdot
1 .5 0 r
.70383 .62132 Mdot
.49442 .37588 Mdot
.628 .126 .941 r
.74804 .74058 Mdot
1 .5 0 r
.7549 .724 Mdot
.628 .126 .941 r
.83605 .58798 Mdot
1 .5 0 r
.8148 .6642 Mdot
.628 .126 .941 r
.80628 .78022 Mdot
1 .5 0 r
.92536 .81007 Mdot
.59027 .50484 Mdot
.68124 .6275 Mdot
.68007 .69046 Mdot
.64047 .62401 Mdot
.628 .126 .941 r
.66008 .64723 Mdot
1 .5 0 r
.63312 .67708 Mdot
.628 .126 .941 r
.55676 .38173 Mdot
.59989 .63053 Mdot
1 .5 0 r
.94302 .78977 Mdot
.5948 .49114 Mdot
.628 .126 .941 r
.64676 .5774 Mdot
.69823 .70014 Mdot
1 .5 0 r
.45783 .28207 Mdot
.628 .126 .941 r
.58088 .5143 Mdot
1 .5 0 r
.75098 .70341 Mdot
.47087 .27537 Mdot
.73069 .70667 Mdot
.628 .126 .941 r
.51558 .35818 Mdot
.69796 .62362 Mdot
.74955 .68987 Mdot
.6918 .49065 Mdot
1 .5 0 r
.60414 .54031 Mdot
.62326 .60005 Mdot
.628 .126 .941 r
.75204 .38427 Mdot
.50341 .59667 Mdot
1 .5 0 r
.62209 .66304 Mdot
.628 .126 .941 r
.85239 .80238 Mdot
1 .5 0 r
.62789 .65292 Mdot
.47908 .3309 Mdot
.628 .126 .941 r
.59709 .42378 Mdot
1 .5 0 r
.58924 .5134 Mdot
.61573 .52004 Mdot
.628 .126 .941 r
.57365 .6361 Mdot
1 .5 0 r
.65243 .68252 Mdot
.628 .126 .941 r
.73152 .68241 Mdot
.52185 .43668 Mdot
1 .5 0 r
.65921 .59936 Mdot
.628 .126 .941 r
.7959 .78855 Mdot
1 .5 0 r
.61988 .48629 Mdot
.628 .126 .941 r
.73597 .7253 Mdot
1 .5 0 r
.6296 .67871 Mdot
.64266 .67201 Mdot
.55316 .38304 Mdot
.628 .126 .941 r
.85378 .74164 Mdot
.57191 .42276 Mdot
.69754 .47258 Mdot
1 .5 0 r
.47896 .38948 Mdot
.56347 .48236 Mdot
.50487 .36604 Mdot
.628 .126 .941 r
.71592 .49226 Mdot
1 .5 0 r
.77856 .75462 Mdot
.628 .126 .941 r
.46962 .46556 Mdot
1 .5 0 r
.57545 .48211 Mdot
.628 .126 .941 r
.66116 .51195 Mdot
.64654 .56166 Mdot
1 .5 0 r
.77694 .73105 Mdot
.43014 .28577 Mdot
.56054 .45516 Mdot
.66345 .69102 Mdot
.93398 .85051 Mdot
.45605 .26231 Mdot
.628 .126 .941 r
.63969 .45503 Mdot
1 .5 0 r
.63674 .67435 Mdot
.63674 .67435 Mdot
.628 .126 .941 r
.74831 .73738 Mdot
1 .5 0 r
.51389 .33853 Mdot
.65041 .57448 Mdot
.628 .126 .941 r
.59767 .51461 Mdot
1 .5 0 r
.58422 .50125 Mdot
.74775 .70731 Mdot
.78065 .73389 Mdot
.628 .126 .941 r
.67193 .38486 Mdot
1 .5 0 r
.68224 .60755 Mdot
.4466 .27172 Mdot
.628 .126 .941 r
.61114 .40468 Mdot
1 .5 0 r
.4187 .31812 Mdot
.628 .126 .941 r
.43835 .34139 Mdot
.52578 .27159 Mdot
1 .5 0 r
.61075 .3846 Mdot
.628 .126 .941 r
.69572 .49762 Mdot
.51114 .32131 Mdot
1 .5 0 r
.64013 .6005 Mdot
.78388 .77331 Mdot
.628 .126 .941 r
.82102 .46075 Mdot
1 .5 0 r
.5354 .39751 Mdot
.628 .126 .941 r
.65312 .52712 Mdot
.67209 .57693 Mdot
1 .5 0 r
.63063 .66665 Mdot
.628 .126 .941 r
.5587 .54689 Mdot
1 .5 0 r
.50248 .24755 Mdot
.54769 .35064 Mdot
.53374 .37385 Mdot
.67034 .60996 Mdot
.90768 .77955 Mdot
.628 .126 .941 r
.44066 .34053 Mdot
1 .5 0 r
.59968 .37039 Mdot
.50661 .33707 Mdot
.49245 .35024 Mdot
.59173 .39348 Mdot
.5244 .45002 Mdot
.6225 .55639 Mdot
.628 .126 .941 r
.41981 .25697 Mdot
.68257 .4964 Mdot
1 .5 0 r
.64227 .52301 Mdot
.6288 .50965 Mdot
.628 .126 .941 r
.7051 .72909 Mdot
1 .5 0 r
.64739 .53941 Mdot
.6995 .6259 Mdot
.628 .126 .941 r
.51693 .31311 Mdot
1 .5 0 r
.65261 .62252 Mdot
.62666 .52259 Mdot
.628 .126 .941 r
.7068 .50595 Mdot
1 .5 0 r
.63797 .67231 Mdot
.56088 .41266 Mdot
.628 .126 .941 r
.44789 .34598 Mdot
1 .5 0 r
.77733 .6122 Mdot
.42851 .27603 Mdot
.55174 .49893 Mdot
.48073 .30585 Mdot
.63662 .60204 Mdot
.628 .126 .941 r
.68825 .72518 Mdot
1 .5 0 r
.53177 .39884 Mdot
.51171 .35544 Mdot
.628 .126 .941 r
.76384 .40863 Mdot
.56444 .34865 Mdot
.59395 .6316 Mdot
.76562 .74811 Mdot
.73886 .73141 Mdot
1 .5 0 r
.6216 .50831 Mdot
.47776 .27854 Mdot
.52991 .36509 Mdot
.628 .126 .941 r
.62928 .40837 Mdot
.75551 .41164 Mdot
1 .5 0 r
.54968 .33167 Mdot
.56248 .37162 Mdot
.628 .126 .941 r
.5792 .61467 Mdot
.77058 .7545 Mdot
1 .5 0 r
.53552 .34485 Mdot
.628 .126 .941 r
.60686 .49136 Mdot
1 .5 0 r
.52056 .44135 Mdot
.628 .126 .941 r
.74049 .44135 Mdot
1 .5 0 r
.5922 .54118 Mdot
.57891 .53785 Mdot
.628 .126 .941 r
.69337 .4279 Mdot
.61425 .31455 Mdot
1 .5 0 r
.53355 .36783 Mdot
.59162 .51103 Mdot
.628 .126 .941 r
.66592 .43777 Mdot
1 .5 0 r
.65805 .52768 Mdot
.55924 .39101 Mdot
.628 .126 .941 r
.63858 .39088 Mdot
.75866 .38422 Mdot
.80492 .4142 Mdot
1 .5 0 r
.61052 .49414 Mdot
.628 .126 .941 r
.7941 .72395 Mdot
.55304 .25752 Mdot
1 .5 0 r
.5175 .34725 Mdot
.628 .126 .941 r
.64992 .41721 Mdot
.64204 .50715 Mdot
.7782 .77027 Mdot
.6643 .29049 Mdot
1 .5 0 r
.60021 .52018 Mdot
.628 .126 .941 r
.65467 .41349 Mdot
1 .5 0 r
.51494 .34006 Mdot
.628 .126 .941 r
.84287 .75325 Mdot
1 .5 0 r
.50834 .31 Mdot
.628 .126 .941 r
.59924 .46989 Mdot
1 .5 0 r
.46117 .29653 Mdot
.628 .126 .941 r
.73545 .7331 Mdot
.68355 .59974 Mdot
1 .5 0 r
.51888 .41971 Mdot
.628 .126 .941 r
.67499 .71633 Mdot
.46599 .35965 Mdot
1 .5 0 r
.63983 .32966 Mdot
.6684 .68628 Mdot
.81417 .7596 Mdot
.628 .126 .941 r
.55936 .33626 Mdot
1 .5 0 r
.57118 .44958 Mdot
.7869 .77955 Mdot
.54488 .39619 Mdot
.64979 .53285 Mdot
.628 .126 .941 r
.73431 .67278 Mdot
1 .5 0 r
.83922 .80945 Mdot
.628 .126 .941 r
.51198 .31272 Mdot
.65728 .42272 Mdot
1 .5 0 r
.4842 .36932 Mdot
.628 .126 .941 r
.597 .41599 Mdot
.79994 .70601 Mdot
.66804 .54255 Mdot
1 .5 0 r
.53533 .46248 Mdot
.89839 .75585 Mdot
.628 .126 .941 r
.46419 .26904 Mdot
1 .5 0 r
.62135 .49242 Mdot
.628 .126 .941 r
.7849 .7358 Mdot
1 .5 0 r
.61425 .49903 Mdot
.628 .126 .941 r
.56332 .29224 Mdot
1 .5 0 r
.65191 .57881 Mdot
.92242 .81223 Mdot
.628 .126 .941 r
.57387 .40201 Mdot
.57268 .46531 Mdot
.71903 .50199 Mdot
.70751 .34186 Mdot
1 .5 0 r
.62699 .34846 Mdot
.628 .126 .941 r
.51168 .4852 Mdot
1 .5 0 r
.80729 .76852 Mdot
.628 .126 .941 r
.65135 .42491 Mdot
.61025 .47822 Mdot
.63717 .43813 Mdot
1 .5 0 r
.6421 .56822 Mdot
.628 .126 .941 r
.85188 .83169 Mdot
.76396 .39463 Mdot
1 .5 0 r
.47105 .25431 Mdot
.628 .126 .941 r
.47598 .38443 Mdot
1 .5 0 r
.49008 .30429 Mdot
.54234 .39104 Mdot
.52291 .3209 Mdot
.49629 .31423 Mdot
.71273 .60784 Mdot
.60259 .33085 Mdot
.628 .126 .941 r
.79684 .78463 Mdot
.71826 .64443 Mdot
1 .5 0 r
.77792 .6778 Mdot
.91561 .82118 Mdot
.628 .126 .941 r
.49481 .30054 Mdot
.73396 .39732 Mdot
.57361 .32704 Mdot
1 .5 0 r
.68358 .59404 Mdot
.628 .126 .941 r
.85471 .78427 Mdot
1 .5 0 r
.52656 .32363 Mdot
.69621 .62402 Mdot
.628 .126 .941 r
.78893 .68409 Mdot
.61267 .35361 Mdot
.71112 .46035 Mdot
1 .5 0 r
.72098 .7207 Mdot
.78165 .68064 Mdot
.8941 .76409 Mdot
.628 .126 .941 r
.69761 .44694 Mdot
1 .5 0 r
.77319 .74057 Mdot
.628 .126 .941 r
.65708 .40669 Mdot
.80556 .79393 Mdot
1 .5 0 r
.51048 .303 Mdot
.53613 .38312 Mdot
.628 .126 .941 r
.64842 .45651 Mdot
1 .5 0 r
.62178 .44983 Mdot
.6346 .4899 Mdot
.628 .126 .941 r
.76682 .59674 Mdot
.89293 .63675 Mdot
1 .5 0 r
.85741 .79367 Mdot
.628 .126 .941 r
.70132 .44971 Mdot
.8299 .80359 Mdot
1 .5 0 r
.51492 .34606 Mdot
.52133 .3661 Mdot
.53416 .40617 Mdot
.61371 .40604 Mdot
.628 .126 .941 r
.70006 .44611 Mdot
.69345 .416 Mdot
1 .5 0 r
.72336 .65305 Mdot
.51393 .29563 Mdot
.66494 .49936 Mdot
.46734 .25549 Mdot
.55233 .34887 Mdot
.628 .126 .941 r
.77522 .65277 Mdot
.82655 .8131 Mdot
1 .5 0 r
.81353 .76295 Mdot
.628 .126 .941 r
.66982 .43874 Mdot
1 .5 0 r
.6094 .43199 Mdot
.628 .126 .941 r
.70232 .43521 Mdot
.59509 .37821 Mdot
.66817 .41497 Mdot
1 .5 0 r
.60053 .47177 Mdot
.57416 .41825 Mdot
.628 .126 .941 r
.70155 .39485 Mdot
1 .5 0 r
.67933 .55525 Mdot
.628 .126 .941 r
.68013 .47165 Mdot
1 .5 0 r
.74432 .67215 Mdot
.628 .126 .941 r
.71648 .7289 Mdot
.61357 .398 Mdot
.78097 .38463 Mdot
1 .5 0 r
.78246 .77229 Mdot
.628 .126 .941 r
.81554 .79903 Mdot
1 .5 0 r
.81554 .79903 Mdot
.628 .126 .941 r
.73437 .34446 Mdot
.75362 .40462 Mdot
.74375 .6419 Mdot
1 .5 0 r
.5875 .29761 Mdot
.628 .126 .941 r
.71374 .33765 Mdot
.83208 .46793 Mdot
1 .5 0 r
.75534 .67845 Mdot
.54602 .27387 Mdot
.628 .126 .941 r
.67198 .36078 Mdot
1 .5 0 r
.49841 .30723 Mdot
.52508 .31391 Mdot
.63573 .54457 Mdot
.628 .126 .941 r
.66369 .43085 Mdot
.57754 .34386 Mdot
.58229 .46415 Mdot
1 .5 0 r
.76655 .69483 Mdot
.51668 .31692 Mdot
.628 .126 .941 r
.77655 .4005 Mdot
1 .5 0 r
.64118 .51418 Mdot
.81786 .78829 Mdot
.6067 .54081 Mdot
.72577 .64446 Mdot
.88418 .78484 Mdot
.628 .126 .941 r
.62094 .40352 Mdot
.66739 .43362 Mdot
.77511 .3868 Mdot
.66187 .2729 Mdot
.71376 .39664 Mdot
.65703 .58381 Mdot
.72634 .35959 Mdot
1 .5 0 r
.841 .79441 Mdot
.67029 .52008 Mdot
.62938 .52665 Mdot
.628 .126 .941 r
.74801 .66714 Mdot
.74386 .45299 Mdot
1 .5 0 r
.79329 .76076 Mdot
.628 .126 .941 r
.52894 .45286 Mdot
1 .5 0 r
.64857 .51977 Mdot
.66093 .59672 Mdot
.52913 .33885 Mdot
.64939 .31194 Mdot
.628 .126 .941 r
.61428 .43241 Mdot
1 .5 0 r
.59401 .44579 Mdot
.628 .126 .941 r
.62743 .42565 Mdot
.58175 .31181 Mdot
1 .5 0 r
.57384 .40216 Mdot
.628 .126 .941 r
.76372 .72677 Mdot
1 .5 0 r
.54081 .31836 Mdot
.91664 .76348 Mdot
.83554 .81702 Mdot
.628 .126 .941 r
.47374 .22437 Mdot
.7883 .74653 Mdot
.8343 .81348 Mdot
1 .5 0 r
.64962 .57242 Mdot
.628 .126 .941 r
.76338 .58246 Mdot
.75497 .70966 Mdot
1 .5 0 r
.83411 .80338 Mdot
.628 .126 .941 r
.67248 .31789 Mdot
1 .5 0 r
.61639 .47851 Mdot
.52884 .51199 Mdot
.5049 .27423 Mdot
.628 .126 .941 r
.67704 .42823 Mdot
1 .5 0 r
.45078 .28756 Mdot
.616 .4583 Mdot
.72088 .63239 Mdot
.83991 .72608 Mdot
.83942 .7629 Mdot
.89186 .84995 Mdot
.628 .126 .941 r
.69626 .42134 Mdot
1 .5 0 r
.84715 .66241 Mdot
.54269 .35431 Mdot
.628 .126 .941 r
.8247 .81302 Mdot
1 .5 0 r
.52914 .34085 Mdot
.65382 .53841 Mdot
.80521 .74266 Mdot
.83836 .76944 Mdot
.628 .126 .941 r
.89081 .8565 Mdot
1 .5 0 r
.47501 .35418 Mdot
.628 .126 .941 r
.87727 .84306 Mdot
1 .5 0 r
.84393 .80617 Mdot
.628 .126 .941 r
.80515 .67552 Mdot
.73785 .69562 Mdot
1 .5 0 r
.50657 .42431 Mdot
.628 .126 .941 r
.82327 .79937 Mdot
.84306 .82282 Mdot
1 .5 0 r
.51429 .32377 Mdot
.628 .126 .941 r
.76073 .44099 Mdot
1 .5 0 r
.7246 .63523 Mdot
.628 .126 .941 r
.85722 .74239 Mdot
1 .5 0 r
.909 .85621 Mdot
.628 .126 .941 r
.57229 .44756 Mdot
.72769 .35713 Mdot
.51914 .38721 Mdot
1 .5 0 r
.49291 .34367 Mdot
.79629 .71544 Mdot
.65208 .44743 Mdot
.67039 .58141 Mdot
.5722 .38038 Mdot
.5915 .44067 Mdot
.628 .126 .941 r
.72662 .36363 Mdot
1 .5 0 r
.72296 .61144 Mdot
.67624 .57118 Mdot
.61022 .47063 Mdot
.628 .126 .941 r
.68496 .39693 Mdot
1 .5 0 r
.60972 .50748 Mdot
.64566 .30306 Mdot
.84063 .6915 Mdot
.628 .126 .941 r
.79688 .43011 Mdot
.80678 .69145 Mdot
1 .5 0 r
.55587 .34956 Mdot
.59994 .56401 Mdot
.746 .67458 Mdot
.628 .126 .941 r
.83196 .74155 Mdot
.76938 .38294 Mdot
.85059 .82862 Mdot
.6043 .66436 Mdot
1 .5 0 r
.54122 .3426 Mdot
.628 .126 .941 r
.76207 .37946 Mdot
.78386 .75479 Mdot
1 .5 0 r
.55439 .33583 Mdot
.628 .126 .941 r
.70989 .74468 Mdot
1 .5 0 r
.66444 .58371 Mdot
.628 .126 .941 r
.90215 .86523 Mdot
1 .5 0 r
.57956 .3859 Mdot
.628 .126 .941 r
.70684 .39931 Mdot
.75388 .3926 Mdot
.89602 .79815 Mdot
.88859 .85178 Mdot
1 .5 0 r
.54548 .37571 Mdot
.88129 .84833 Mdot
.47208 .2716 Mdot
.71609 .56318 Mdot
.628 .126 .941 r
.74829 .66375 Mdot
1 .5 0 r
.66933 .52289 Mdot
.63545 .52283 Mdot
.78704 .72734 Mdot
.88711 .77092 Mdot
.628 .126 .941 r
.83311 .79439 Mdot
.75415 .65353 Mdot
1 .5 0 r
.45572 .36513 Mdot
.628 .126 .941 r
.60385 .32825 Mdot
.696 .46236 Mdot
.91845 .88817 Mdot
.87169 .84789 Mdot
1 .5 0 r
.95839 .88812 Mdot
.687 .55941 Mdot
.87113 .81756 Mdot
.53499 .33461 Mdot
.70644 .56265 Mdot
.628 .126 .941 r
.6889 .34461 Mdot
.84351 .82752 Mdot
1 .5 0 r
.87076 .79734 Mdot
.628 .126 .941 r
.83192 .66649 Mdot
1 .5 0 r
.75789 .65638 Mdot
.628 .126 .941 r
.80349 .76034 Mdot
.69042 .60925 Mdot
.8619 .83733 Mdot
1 .5 0 r
.65751 .5354 Mdot
.628 .126 .941 r
.6246 .46154 Mdot
1 .5 0 r
.61846 .39439 Mdot
.628 .126 .941 r
.70372 .54534 Mdot
1 .5 0 r
.86066 .83378 Mdot
.628 .126 .941 r
.9474 .87403 Mdot
1 .5 0 r
.6954 .61567 Mdot
.628 .126 .941 r
.73189 .37406 Mdot
1 .5 0 r
.662 .57871 Mdot
.628 .126 .941 r
.71713 .42426 Mdot
.70325 .45781 Mdot
.87974 .8168 Mdot
1 .5 0 r
.5102 .30676 Mdot
.628 .126 .941 r
.59013 .30663 Mdot
.86462 .8468 Mdot
.6889 .4038 Mdot
1 .5 0 r
.54194 .31984 Mdot
.50752 .35669 Mdot
.5943 .39696 Mdot
.628 .126 .941 r
.72125 .4473 Mdot
1 .5 0 r
.83084 .7896 Mdot
.628 .126 .941 r
.60135 .323 Mdot
.58845 .28272 Mdot
.56068 .34985 Mdot
.66513 .55115 Mdot
1 .5 0 r
.60423 .53425 Mdot
.81651 .73564 Mdot
.86957 .78599 Mdot
.4731 .26902 Mdot
.628 .126 .941 r
.8684 .84971 Mdot
.85482 .83624 Mdot
.86821 .83959 Mdot
1 .5 0 r
.52527 .33602 Mdot
.628 .126 .941 r
.67805 .46693 Mdot
1 .5 0 r
.98112 .9134 Mdot
.628 .126 .941 r
.73986 .34266 Mdot
1 .5 0 r
.88272 .71193 Mdot
.96754 .89992 Mdot
.96754 .89992 Mdot
.628 .126 .941 r
.761 .74545 Mdot
.89394 .85287 Mdot
1 .5 0 r
.85457 .75882 Mdot
.628 .126 .941 r
.87323 .84606 Mdot
1 .5 0 r
.64186 .53713 Mdot
.628 .126 .941 r
.87218 .85263 Mdot
.87218 .85263 Mdot
.87218 .85263 Mdot
.88588 .80893 Mdot
.87199 .84251 Mdot
.85859 .83915 Mdot
.83875 .81564 Mdot
1 .5 0 r
.97135 .90285 Mdot
.628 .126 .941 r
.7315 .72146 Mdot
.89773 .85579 Mdot
.68764 .45947 Mdot
1 .5 0 r
.5614 .32507 Mdot
.5346 .31835 Mdot
.628 .126 .941 r
.67504 .37208 Mdot
.69439 .43253 Mdot
1 .5 0 r
.81151 .72136 Mdot
.628 .126 .941 r
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
.87701 .84898 Mdot
1 .5 0 r
.87056 .82882 Mdot
.79097 .72466 Mdot
.628 .126 .941 r
.70077 .38532 Mdot
.7906 .7044 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
.87596 .85554 Mdot
1 .5 0 r
.64747 .3248 Mdot
.55217 .41213 Mdot
.628 .126 .941 r
.66682 .38526 Mdot
.66682 .38526 Mdot
.68668 .40877 Mdot
.84878 .82857 Mdot
1 .5 0 r
.60489 .44223 Mdot
.628 .126 .941 r
.6719 .45902 Mdot
.82279 .73783 Mdot
.91511 .87219 Mdot
1 .5 0 r
.97517 .90578 Mdot
.58583 .33467 Mdot
.58533 .37162 Mdot
.89439 .86538 Mdot
.628 .126 .941 r
.8942 .85525 Mdot
.8808 .85189 Mdot
.8808 .85189 Mdot
.8808 .85189 Mdot
.59845 .29744 Mdot
1 .5 0 r
.51803 .27729 Mdot
.628 .126 .941 r
.60391 .39151 Mdot
.87974 .85846 Mdot
1 .5 0 r
.59557 .46194 Mdot
.628 .126 .941 r
.7331 .73746 Mdot
1 .5 0 r
.83388 .74418 Mdot
.91332 .83825 Mdot
.91332 .83825 Mdot
.628 .126 .941 r
.78386 .41477 Mdot
.77721 .38447 Mdot
1 .5 0 r
.88545 .83811 Mdot
.628 .126 .941 r
.852 .80109 Mdot
1 .5 0 r
.89818 .8683 Mdot
.98507 .90862 Mdot
.56083 .4213 Mdot
.628 .126 .941 r
.81258 .70695 Mdot
1 .5 0 r
.81308 .66998 Mdot
.628 .126 .941 r
.88459 .85481 Mdot
1 .5 0 r
.66292 .30698 Mdot
.628 .126 .941 r
.85969 .63284 Mdot
.88353 .86138 Mdot
.67426 .39079 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
.88334 .85125 Mdot
1 .5 0 r
.78433 .68651 Mdot
.78433 .68651 Mdot
.628 .126 .941 r
.62719 .34025 Mdot
1 .5 0 r
.5068 .26287 Mdot
.628 .126 .941 r
.62004 .3469 Mdot
1 .5 0 r
.75067 .63934 Mdot
.90911 .86455 Mdot
.59203 .40398 Mdot
.628 .126 .941 r
.85528 .84097 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
.88837 .85773 Mdot
1 .5 0 r
.90179 .86109 Mdot
.51196 .2794 Mdot
.62274 .54834 Mdot
.7961 .66601 Mdot
.628 .126 .941 r
.67799 .39357 Mdot
.69786 .4171 Mdot
.87372 .85081 Mdot
.87372 .85081 Mdot
.645 .31953 Mdot
.70462 .39014 Mdot
.86012 .83731 Mdot
1 .5 0 r
.98662 .91459 Mdot
.51047 .2656 Mdot
.628 .126 .941 r
.74994 .47407 Mdot
1 .5 0 r
.73504 .58167 Mdot
.628 .126 .941 r
.80658 .7666 Mdot
.90179 .66903 Mdot
.89217 .86065 Mdot
1 .5 0 r
.83384 .66892 Mdot
.89161 .83024 Mdot
.628 .126 .941 r
.87751 .85373 Mdot
.87751 .85373 Mdot
.87751 .85373 Mdot
.87751 .85373 Mdot
.84701 .59471 Mdot
.89074 .84695 Mdot
1 .5 0 r
.66642 .48366 Mdot
.99045 .91753 Mdot
.628 .126 .941 r
.64783 .33897 Mdot
1 .5 0 r
.57985 .33883 Mdot
.628 .126 .941 r
.69367 .38592 Mdot
1 .5 0 r
.89646 .82657 Mdot
.89596 .86357 Mdot
.628 .126 .941 r
.84259 .80297 Mdot
.49197 .31515 Mdot
1 .5 0 r
.68483 .49344 Mdot
.628 .126 .941 r
.74398 .60109 Mdot
.78008 .39582 Mdot
1 .5 0 r
.89491 .87015 Mdot
.628 .126 .941 r
.89472 .86001 Mdot
.89472 .86001 Mdot
.8813 .85665 Mdot
.89472 .86001 Mdot
1 .5 0 r
.5381 .31494 Mdot
.628 .126 .941 r
.73198 .41924 Mdot
1 .5 0 r
.91423 .86328 Mdot
.628 .126 .941 r
.71817 .39556 Mdot
.65602 .50995 Mdot
.76689 .77912 Mdot
1 .5 0 r
.92747 .8565 Mdot
.628 .126 .941 r
.70406 .41904 Mdot
.86663 .84972 Mdot
.70635 .72518 Mdot
1 .5 0 r
.89976 .8665 Mdot
.628 .126 .941 r
.69174 .28432 Mdot
1 .5 0 r
.56992 .32806 Mdot
.628 .126 .941 r
.94762 .76545 Mdot
.88559 .82255 Mdot
.89852 .86294 Mdot
.8652 .83601 Mdot
.87167 .85621 Mdot
.88509 .85957 Mdot
.60007 .44209 Mdot
1 .5 0 r
.91767 .84591 Mdot
.90356 .86942 Mdot
.54009 .29372 Mdot
.5396 .33075 Mdot
.628 .126 .941 r
.65877 .46197 Mdot
1 .5 0 r
.903 .83898 Mdot
.628 .126 .941 r
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.88889 .8625 Mdot
.90232 .86586 Mdot
1 .5 0 r
.90232 .86586 Mdot
.90213 .85571 Mdot
.83628 .71764 Mdot
.83578 .75467 Mdot
.9885 .923 Mdot
.7366 .58965 Mdot
.80226 .71758 Mdot
.628 .126 .941 r
.93509 .86235 Mdot
1 .5 0 r
.98832 .91285 Mdot
.57771 .35391 Mdot
.628 .126 .941 r
.87421 .85557 Mdot
.88746 .84878 Mdot
.88746 .84878 Mdot
.88746 .84878 Mdot
.90736 .87235 Mdot
.92079 .87572 Mdot
1 .5 0 r
.52388 .2729 Mdot
.628 .126 .941 r
.79305 .80491 Mdot
.80748 .7342 Mdot
.69713 .37041 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.89268 .86542 Mdot
.87278 .84185 Mdot
1 .5 0 r
.89268 .86542 Mdot
.89318 .82838 Mdot
.628 .126 .941 r
.87906 .8519 Mdot
.95918 .90915 Mdot
.56787 .41069 Mdot
.78781 .59591 Mdot
1 .5 0 r
.853 .76093 Mdot
.628 .126 .941 r
.7294 .40389 Mdot
.72056 .51154 Mdot
1 .5 0 r
.90469 .85508 Mdot
.628 .126 .941 r
.69498 .38349 Mdot
.65417 .41043 Mdot
1 .5 0 r
.87216 .74388 Mdot
.9911 .92239 Mdot
.70524 .59899 Mdot
.92423 .85834 Mdot
.628 .126 .941 r
.61396 .34294 Mdot
.76726 .4743 Mdot
.89648 .86835 Mdot
.89648 .86835 Mdot
1 .5 0 r
.89648 .86835 Mdot
.61905 .41691 Mdot
.628 .126 .941 r
.88286 .85483 Mdot
.88286 .85483 Mdot
1 .5 0 r
.87122 .69308 Mdot
.53811 .31895 Mdot
.88211 .8142 Mdot
.628 .126 .941 r
.86817 .84789 Mdot
1 .5 0 r
.67034 .49071 Mdot
.53124 .27838 Mdot
.628 .126 .941 r
.78944 .61189 Mdot
.88155 .78373 Mdot
1 .5 0 r
.90097 .84438 Mdot
.63092 .33889 Mdot
.628 .126 .941 r
.88037 .8477 Mdot
1 .5 0 r
.90029 .87128 Mdot
.90029 .87128 Mdot
.55654 .32872 Mdot
.628 .126 .941 r
.88666 .85776 Mdot
.69427 .59486 Mdot
.86655 .82401 Mdot
1 .5 0 r
.50934 .27803 Mdot
.66102 .5105 Mdot
.628 .126 .941 r
.8856 .86435 Mdot
1 .5 0 r
.58214 .33182 Mdot
.9123 .86093 Mdot
.628 .126 .941 r
.73613 .36875 Mdot
1 .5 0 r
.97169 .91139 Mdot
.628 .126 .941 r
.75985 .58777 Mdot
.81214 .71248 Mdot
1 .5 0 r
.57488 .27087 Mdot
.628 .126 .941 r
.73575 .3484 Mdot
.71383 .47311 Mdot
1 .5 0 r
.90409 .87422 Mdot
.57368 .33485 Mdot
.628 .126 .941 r
.73456 .41238 Mdot
.70667 .47979 Mdot
.89843 .76967 Mdot
.89046 .86068 Mdot
.89046 .86068 Mdot
.67391 .35831 Mdot
1 .5 0 r
.56512 .39532 Mdot
.628 .126 .941 r
.8894 .86728 Mdot
.9696 .92459 Mdot
.53155 .35818 Mdot
1 .5 0 r
.6257 .38177 Mdot
.57887 .35143 Mdot
.628 .126 .941 r
.99631 .92117 Mdot
.66535 .41879 Mdot
1 .5 0 r
.63925 .3277 Mdot
.628 .126 .941 r
.69156 .45244 Mdot
1 .5 0 r
.61215 .31077 Mdot
.59751 .3714 Mdot
.94327 .75577 Mdot
.628 .126 .941 r
.88797 .85355 Mdot
.72486 .41179 Mdot
1 .5 0 r
.74379 .50957 Mdot
.89426 .86361 Mdot
.53035 .29708 Mdot
.628 .126 .941 r
.56882 .39811 Mdot
1 .5 0 r
.54919 .32722 Mdot
.71562 .49921 Mdot
.628 .126 .941 r
.86611 .8533 Mdot
1 .5 0 r
.9269 .84993 Mdot
.628 .126 .941 r
.8734 .78918 Mdot
1 .5 0 r
.52886 .28324 Mdot
.91239 .85315 Mdot
.91239 .85315 Mdot
.92585 .85653 Mdot
.628 .126 .941 r
.91171 .88009 Mdot
.71466 .44831 Mdot
.87265 .74849 Mdot
.89806 .86655 Mdot
1 .5 0 r
.89806 .86655 Mdot
.97831 .92388 Mdot
.628 .126 .941 r
.68138 .36385 Mdot
1 .5 0 r
.81196 .69442 Mdot
.93109 .87319 Mdot
.628 .126 .941 r
.76143 .41101 Mdot
.73402 .44137 Mdot
1 .5 0 r
.87738 .80226 Mdot
.94368 .89334 Mdot
.628 .126 .941 r
.59705 .5357 Mdot
1 .5 0 r
.67232 .46148 Mdot
.6783 .51883 Mdot
.50513 .31635 Mdot
.628 .126 .941 r
.77413 .37364 Mdot
.78441 .5895 Mdot
1 .5 0 r
.94294 .85266 Mdot
.628 .126 .941 r
.89558 .85941 Mdot
.91552 .88302 Mdot
.92898 .8864 Mdot
1 .5 0 r
.96288 .87628 Mdot
.72389 .54558 Mdot
.628 .126 .941 r
.90187 .86948 Mdot
1 .5 0 r
.90187 .86948 Mdot
.5507 .34307 Mdot
.628 .126 .941 r
.69079 .47129 Mdot
1 .5 0 r
.64343 .47804 Mdot
.58999 .35974 Mdot
.628 .126 .941 r
.58949 .39686 Mdot
.88218 .73093 Mdot
.91409 .86928 Mdot
.8737 .85916 Mdot
1 .5 0 r
.91409 .86928 Mdot
.628 .126 .941 r
.88717 .86254 Mdot
1 .5 0 r
.93454 .85579 Mdot
.58281 .36643 Mdot
.881 .795 Mdot
.96826 .83549 Mdot
.628 .126 .941 r
.61682 .2988 Mdot
1 .5 0 r
.79435 .6599 Mdot
.628 .126 .941 r
.79915 .78134 Mdot
.75826 .80834 Mdot
1 .5 0 r
.89939 .86234 Mdot
.628 .126 .941 r
.9328 .88934 Mdot
.69672 .33578 Mdot
1 .5 0 r
.57504 .34253 Mdot
.628 .126 .941 r
.90568 .87242 Mdot
.90568 .87242 Mdot
.64896 .32215 Mdot
.64926 .27482 Mdot
1 .5 0 r
.5529 .332 Mdot
.81777 .73372 Mdot
.628 .126 .941 r
.84552 .65602 Mdot
1 .5 0 r
.79744 .68972 Mdot
.628 .126 .941 r
.87626 .85852 Mdot
1 .5 0 r
.89072 .78763 Mdot
.628 .126 .941 r
.9032 .86527 Mdot
1 .5 0 r
.61217 .37231 Mdot
.61716 .50398 Mdot
.91648 .85847 Mdot
.628 .126 .941 r
.68631 .36212 Mdot
1 .5 0 r
.49803 .26751 Mdot
.628 .126 .941 r
.94255 .88201 Mdot
.75976 .37887 Mdot
1 .5 0 r
.54403 .31464 Mdot
.56997 .39568 Mdot
.628 .126 .941 r
.72514 .41594 Mdot
.71117 .44971 Mdot
1 .5 0 r
.93519 .87854 Mdot
.94218 .86165 Mdot
.58325 .38886 Mdot
.628 .126 .941 r
.90807 .8616 Mdot
1 .5 0 r
.90807 .8616 Mdot
.628 .126 .941 r
.63624 .41912 Mdot
1 .5 0 r
.65121 .31106 Mdot
.65121 .31106 Mdot
.628 .126 .941 r
.77197 .3786 Mdot
1 .5 0 r
.99452 .91891 Mdot
.628 .126 .941 r
.70222 .48992 Mdot
1 .5 0 r
.51349 .37489 Mdot
.56769 .34105 Mdot
.7264 .60451 Mdot
.628 .126 .941 r
.83152 .80712 Mdot
1 .5 0 r
.66213 .30713 Mdot
.628 .126 .941 r
.63368 .41185 Mdot
.98557 .89151 Mdot
.63448 .32733 Mdot
1 .5 0 r
.51299 .28673 Mdot
.628 .126 .941 r
.71465 .37456 Mdot
1 .5 0 r
.91713 .88123 Mdot
.628 .126 .941 r
.53805 .38456 Mdot
.58497 .41497 Mdot
1 .5 0 r
.878 .74943 Mdot
.61104 .43849 Mdot
.61104 .43849 Mdot
.628 .126 .941 r
.82771 .41822 Mdot
.90259 .88447 Mdot
1 .5 0 r
.60485 .37085 Mdot
.628 .126 .941 r
.75313 .40802 Mdot
1 .5 0 r
.74963 .66818 Mdot
.628 .126 .941 r
.94934 .90469 Mdot
1 .5 0 r
.92936 .88104 Mdot
.59766 .37754 Mdot
.5705 .36058 Mdot
.94878 .87414 Mdot
.628 .126 .941 r
.9421 .84367 Mdot
1 .5 0 r
.9421 .84367 Mdot
.92163 .85719 Mdot
.9481 .90112 Mdot
.628 .126 .941 r
.86852 .75914 Mdot
.92794 .86728 Mdot
1 .5 0 r
.52257 .27913 Mdot
.628 .126 .941 r
.981 .8976 Mdot
1 .5 0 r
.97401 .9145 Mdot
.628 .126 .941 r
.64114 .41744 Mdot
1 .5 0 r
.53456 .26865 Mdot
.628 .126 .941 r
.66822 .3666 Mdot
.98589 .89393 Mdot
1 .5 0 r
.92545 .86013 Mdot
.628 .126 .941 r
.62707 .38344 Mdot
1 .5 0 r
.61258 .45443 Mdot
.92477 .88712 Mdot
.628 .126 .941 r
.69381 .42732 Mdot
1 .5 0 r
.97785 .91745 Mdot
.9382 .82274 Mdot
.628 .126 .941 r
.7207 .36627 Mdot
1 .5 0 r
.63178 .43727 Mdot
.628 .126 .941 r
.76816 .35951 Mdot
1 .5 0 r
.63128 .47446 Mdot
.54515 .31211 Mdot
.6056 .34592 Mdot
.63099 .39644 Mdot
.94277 .86645 Mdot
.628 .126 .941 r
.87513 .83935 Mdot
.93559 .87316 Mdot
1 .5 0 r
.93622 .77838 Mdot
.62301 .36229 Mdot
.628 .126 .941 r
.96083 .91355 Mdot
1 .5 0 r
.54885 .31487 Mdot
.60932 .34869 Mdot
.70778 .57867 Mdot
.628 .126 .941 r
.79635 .48723 Mdot
.65622 .31128 Mdot
1 .5 0 r
.93311 .86601 Mdot
.628 .126 .941 r
.58704 .39578 Mdot
1 .5 0 r
.93942 .87611 Mdot
.58685 .38556 Mdot
.53366 .2874 Mdot
.58615 .41256 Mdot
.96554 .89969 Mdot
.628 .126 .941 r
.89769 .86238 Mdot
1 .5 0 r
.95817 .89621 Mdot
.57936 .31418 Mdot
.61885 .39877 Mdot
.628 .126 .941 r
.73834 .57808 Mdot
1 .5 0 r
.65865 .43592 Mdot
.628 .126 .941 r
.78664 .48667 Mdot
1 .5 0 r
.77764 .65246 Mdot
.95794 .8182 Mdot
.90325 .83168 Mdot
.628 .126 .941 r
.56307 .41881 Mdot
1 .5 0 r
.55657 .3985 Mdot
.628 .126 .941 r
.75249 .36108 Mdot
.73849 .39492 Mdot
1 .5 0 r
.74949 .58444 Mdot
.628 .126 .941 r
.71779 .39824 Mdot
.63678 .37794 Mdot
1 .5 0 r
.54957 .28988 Mdot
.628 .126 .941 r
.65109 .29664 Mdot
1 .5 0 r
.60308 .34064 Mdot
.628 .126 .941 r
.83512 .71631 Mdot
.78661 .79753 Mdot
.65039 .32365 Mdot
.56887 .34057 Mdot
1 .5 0 r
.90126 .78728 Mdot
.628 .126 .941 r
.76053 .64845 Mdot
1 .5 0 r
.84787 .67886 Mdot
.98691 .91918 Mdot
.628 .126 .941 r
.81417 .64157 Mdot
.65592 .29284 Mdot
.75646 .37409 Mdot
.98655 .89878 Mdot
.98655 .89878 Mdot
.91933 .83441 Mdot
1 .5 0 r
.57949 .38411 Mdot
.628 .126 .941 r
.73606 .32994 Mdot
1 .5 0 r
.60681 .34342 Mdot
.68034 .4179 Mdot
.84642 .66504 Mdot
.628 .126 .941 r
.72117 .38059 Mdot
1 .5 0 r
.93879 .82749 Mdot
.628 .126 .941 r
.63973 .33983 Mdot
.8902 .84088 Mdot
.99058 .91194 Mdot
1 .5 0 r
.61663 .47169 Mdot
.5774 .33956 Mdot
.62424 .35981 Mdot
.628 .126 .941 r
.64976 .47833 Mdot
1 .5 0 r
.64426 .38351 Mdot
.628 .126 .941 r
.73864 .39699 Mdot
.74965 .58664 Mdot
1 .5 0 r
.74915 .62389 Mdot
.628 .126 .941 r
.89527 .8474 Mdot
.98934 .90836 Mdot
.98934 .90836 Mdot
.6849 .33597 Mdot
.74526 .35961 Mdot
1 .5 0 r
.96145 .91843 Mdot
.628 .126 .941 r
.71104 .35954 Mdot
1 .5 0 r
.64948 .40018 Mdot
.55419 .4035 Mdot
.53547 .25779 Mdot
.628 .126 .941 r
.72967 .43731 Mdot
1 .5 0 r
.68763 .53892 Mdot
.64839 .40676 Mdot
.628 .126 .941 r
.7433 .38298 Mdot
1 .5 0 r
.62117 .38976 Mdot
.628 .126 .941 r
.91298 .87416 Mdot
.933 .89787 Mdot
.64249 .29145 Mdot
1 .5 0 r
.8128 .68768 Mdot
.93276 .81975 Mdot
.93226 .85702 Mdot
.61898 .40291 Mdot
.628 .126 .941 r
.72762 .39275 Mdot
1 .5 0 r
.92488 .85353 Mdot
.9454 .83998 Mdot
.53868 .29781 Mdot
.628 .126 .941 r
.6246 .44005 Mdot
1 .5 0 r
.6246 .44005 Mdot
.628 .126 .941 r
.61839 .37222 Mdot
.78963 .75173 Mdot
.90329 .87372 Mdot
.74738 .33827 Mdot
.91762 .79234 Mdot
1 .5 0 r
.66607 .3077 Mdot
.58445 .32465 Mdot
.628 .126 .941 r
.83281 .5178 Mdot
1 .5 0 r
.53698 .27367 Mdot
.94961 .86335 Mdot
.628 .126 .941 r
.7386 .38883 Mdot
1 .5 0 r
.92238 .84636 Mdot
.60319 .34471 Mdot
.60319 .34471 Mdot
.628 .126 .941 r
.65157 .25313 Mdot
.66459 .2938 Mdot
1 .5 0 r
.57595 .32769 Mdot
.628 .126 .941 r
.65658 .38531 Mdot
.98844 .90722 Mdot
1 .5 0 r
.98844 .90722 Mdot
.628 .126 .941 r
.76287 .50381 Mdot
1 .5 0 r
.74834 .57499 Mdot
.76788 .63601 Mdot
.96822 .87328 Mdot
.628 .126 .941 r
.70408 .31054 Mdot
1 .5 0 r
.92145 .79526 Mdot
.628 .126 .941 r
.70839 .46979 Mdot
.90674 .85623 Mdot
.75609 .40525 Mdot
.63336 .44932 Mdot
1 .5 0 r
.71301 .58154 Mdot
.628 .126 .941 r
.63517 .28992 Mdot
.95928 .91371 Mdot
.73497 .38811 Mdot
1 .5 0 r
.91883 .84581 Mdot
.80542 .67623 Mdot
.65392 .30999 Mdot
.61284 .33711 Mdot
.628 .126 .941 r
.92447 .88301 Mdot
.95854 .87284 Mdot
1 .5 0 r
.89172 .77106 Mdot
.89855 .74388 Mdot
.628 .126 .941 r
.98473 .89647 Mdot
1 .5 0 r
.91057 .85917 Mdot
.628 .126 .941 r
.72048 .33352 Mdot
1 .5 0 r
.85057 .73021 Mdot
.628 .126 .941 r
.77321 .40121 Mdot
1 .5 0 r
.77622 .68268 Mdot
.92354 .8319 Mdot
.92267 .84875 Mdot
.65787 .323 Mdot
.59653 .31615 Mdot
.88972 .72655 Mdot
.628 .126 .941 r
.94835 .9097 Mdot
.92812 .87574 Mdot
.98877 .90966 Mdot
1 .5 0 r
.71592 .47544 Mdot
.628 .126 .941 r
.89435 .83838 Mdot
1 .5 0 r
.9144 .86212 Mdot
.628 .126 .941 r
.66861 .43467 Mdot
1 .5 0 r
.65569 .33616 Mdot
.628 .126 .941 r
.98753 .90607 Mdot
.98101 .88572 Mdot
.98101 .88572 Mdot
.74322 .36663 Mdot
.72899 .39031 Mdot
.78294 .39363 Mdot
1 .5 0 r
.69972 .52256 Mdot
.628 .126 .941 r
.89505 .61749 Mdot
.9522 .91267 Mdot
.73423 .40701 Mdot
1 .5 0 r
.73173 .59363 Mdot
.92626 .77346 Mdot
.628 .126 .941 r
.91774 .90239 Mdot
.95133 .92954 Mdot
.74808 .36283 Mdot
.69443 .31193 Mdot
.71379 .36276 Mdot
.68621 .3933 Mdot
1 .5 0 r
.9655 .83783 Mdot
.628 .126 .941 r
.9314 .84801 Mdot
.68 .32537 Mdot
.79433 .4102 Mdot
.77778 .63078 Mdot
1 .5 0 r
.58453 .32869 Mdot
.74399 .59339 Mdot
.59787 .32184 Mdot
.628 .126 .941 r
.61793 .34559 Mdot
.73227 .43044 Mdot
.67942 .29462 Mdot
1 .5 0 r
.67089 .42358 Mdot
.628 .126 .941 r
.98381 .89532 Mdot
.98381 .89532 Mdot
1 .5 0 r
.99033 .91568 Mdot
.628 .126 .941 r
.7725 .42012 Mdot
.95605 .91563 Mdot
1 .5 0 r
.91555 .84766 Mdot
.628 .126 .941 r
.71174 .3181 Mdot
.98258 .89173 Mdot
.9891 .9121 Mdot
.9891 .9121 Mdot
.68998 .3961 Mdot
.77173 .37913 Mdot
1 .5 0 r
.97537 .89847 Mdot
.64143 .41973 Mdot
.628 .126 .941 r
.80094 .68451 Mdot
1 .5 0 r
.70845 .4638 Mdot
.628 .126 .941 r
.98786 .90851 Mdot
1 .5 0 r
.74731 .50768 Mdot
.91939 .8506 Mdot
.73187 .59584 Mdot
.83272 .67733 Mdot
.628 .126 .941 r
.80142 .45317 Mdot
1 .5 0 r
.91112 .86399 Mdot
.59832 .34437 Mdot
.628 .126 .941 r
.7604 .42248 Mdot
1 .5 0 r
.95773 .86384 Mdot
.67802 .4087 Mdot
.95754 .8536 Mdot
.5903 .31007 Mdot
.628 .126 .941 r
.73133 .43914 Mdot
1 .5 0 r
.92304 .84331 Mdot
.628 .126 .941 r
.65566 .45599 Mdot
.9829 .89416 Mdot
1 .5 0 r
.98943 .91454 Mdot
.60206 .34716 Mdot
.628 .126 .941 r
.72453 .34037 Mdot
.71098 .33697 Mdot
1 .5 0 r
.62916 .35395 Mdot
.628 .126 .941 r
.68839 .50002 Mdot
.91427 .89407 Mdot
1 .5 0 r
.92882 .82273 Mdot
.628 .126 .941 r
.98184 .90081 Mdot
.69603 .38779 Mdot
.71611 .41157 Mdot
.8406 .76148 Mdot
.67676 .27901 Mdot
1 .5 0 r
.81381 .70707 Mdot
.628 .126 .941 r
.72978 .35708 Mdot
.73581 .41484 Mdot
.72306 .32644 Mdot
.70831 .38753 Mdot
.78311 .38753 Mdot
1 .5 0 r
.70078 .44189 Mdot
.70078 .44189 Mdot
.86043 .70691 Mdot
.628 .126 .941 r
.74878 .38746 Mdot
1 .5 0 r
.64717 .33303 Mdot
.61955 .36361 Mdot
.94641 .83931 Mdot
.82603 .63872 Mdot
.628 .126 .941 r
.98571 .90378 Mdot
.6742 .27165 Mdot
.6742 .27165 Mdot
.68053 .28178 Mdot
.65291 .31236 Mdot
1 .5 0 r
.93161 .83232 Mdot
.628 .126 .941 r
.72553 .45163 Mdot
1 .5 0 r
.59778 .31562 Mdot
.628 .126 .941 r
.66608 .29523 Mdot
.74643 .39039 Mdot
.85339 .52974 Mdot
.87348 .55353 Mdot
.75257 .39026 Mdot
1 .5 0 r
.95698 .8729 Mdot
.628 .126 .941 r
.72978 .54315 Mdot
.73159 .38333 Mdot
.68399 .33221 Mdot
.78495 .41379 Mdot
.69504 .52257 Mdot
1 .5 0 r
.93665 .77072 Mdot
.628 .126 .941 r
.95523 .9067 Mdot
.96829 .94749 Mdot
1 .5 0 r
.96929 .8727 Mdot
.628 .126 .941 r
.75814 .35933 Mdot
1 .5 0 r
.90161 .79782 Mdot
.95586 .81141 Mdot
.628 .126 .941 r
.9413 .8828 Mdot
1 .5 0 r
.98852 .9134 Mdot
.628 .126 .941 r
.72792 .50873 Mdot
.66894 .31487 Mdot
.92096 .78061 Mdot
1 .5 0 r
.59319 .33173 Mdot
.7193 .56974 Mdot
.55209 .30099 Mdot
.628 .126 .941 r
.73248 .55262 Mdot
1 .5 0 r
.67852 .49135 Mdot
.9594 .86201 Mdot
.9795 .88582 Mdot
.628 .126 .941 r
.63913 .35866 Mdot
1 .5 0 r
.61802 .40967 Mdot
.64566 .37906 Mdot
.628 .126 .941 r
.78837 .39607 Mdot
1 .5 0 r
.92505 .86196 Mdot
.628 .126 .941 r
.70777 .29058 Mdot
1 .5 0 r
.59169 .31778 Mdot
.628 .126 .941 r
.6937 .32458 Mdot
.77461 .3824 Mdot
.89069 .86191 Mdot
.68698 .29391 Mdot
.74024 .38233 Mdot
1 .5 0 r
.87191 .71562 Mdot
.56366 .32785 Mdot
.628 .126 .941 r
.94409 .89242 Mdot
1 .5 0 r
.56929 .36513 Mdot
.628 .126 .941 r
.73966 .35152 Mdot
1 .5 0 r
.61703 .35832 Mdot
.628 .126 .941 r
.93718 .85151 Mdot
.6103 .32764 Mdot
.7445 .4739 Mdot
1 .5 0 r
.96395 .83781 Mdot
.67676 .39894 Mdot
.628 .126 .941 r
.65796 .2526 Mdot
1 .5 0 r
.60217 .35125 Mdot
.64288 .36146 Mdot
.628 .126 .941 r
.74473 .35799 Mdot
.702 .49746 Mdot
1 .5 0 r
.87524 .75596 Mdot
.628 .126 .941 r
.79109 .40548 Mdot
1 .5 0 r
.77984 .71162 Mdot
.628 .126 .941 r
.81906 .8341 Mdot
.71027 .28967 Mdot
1 .5 0 r
.62078 .36112 Mdot
.62078 .36112 Mdot
.628 .126 .941 r
.76306 .41556 Mdot
.89981 .88168 Mdot
1 .5 0 r
.61405 .33043 Mdot
.628 .126 .941 r
.74326 .34404 Mdot
.68796 .40528 Mdot
.66212 .27592 Mdot
.89943 .86117 Mdot
.74941 .3439 Mdot
.59183 .38807 Mdot
1 .5 0 r
.87995 .74197 Mdot
.5856 .31995 Mdot
.628 .126 .941 r
.7621 .36418 Mdot
.72841 .33696 Mdot
.7621 .36418 Mdot
.74852 .36078 Mdot
1 .5 0 r
.75908 .58878 Mdot
.628 .126 .941 r
.91898 .85422 Mdot
.66737 .29265 Mdot
.8851 .81673 Mdot
.66063 .26195 Mdot
.75328 .41497 Mdot
.75378 .37753 Mdot
1 .5 0 r
.65722 .46602 Mdot
.95897 .82339 Mdot
.628 .126 .941 r
.738 .51361 Mdot
.69908 .34336 Mdot
.69939 .29564 Mdot
.67927 .27181 Mdot
.7532 .34669 Mdot
.65694 .38747 Mdot
.72515 .35677 Mdot
.68452 .28855 Mdot
.92177 .86383 Mdot
.75708 .41778 Mdot
1 .5 0 r
.96887 .88421 Mdot
.628 .126 .941 r
.75084 .34962 Mdot
.71694 .3121 Mdot
.77078 .36318 Mdot
.82612 .80921 Mdot
.92706 .88066 Mdot
.92033 .84996 Mdot
1 .5 0 r
.94096 .83634 Mdot
.628 .126 .941 r
.92637 .90785 Mdot
.73598 .34254 Mdot
.72189 .37659 Mdot
.74957 .34595 Mdot
1 .5 0 r
.63999 .3356 Mdot
.628 .126 .941 r
.6883 .29132 Mdot
.68578 .47862 Mdot
1 .5 0 r
.94625 .85317 Mdot
.628 .126 .941 r
.74125 .3593 Mdot
.76138 .38314 Mdot
1 .5 0 r
.62531 .3388 Mdot
.628 .126 .941 r
.86385 .84967 Mdot
.72073 .31489 Mdot
1 .5 0 r
.74589 .47156 Mdot
.85259 .64867 Mdot
.628 .126 .941 r
.76029 .38975 Mdot
.95104 .90747 Mdot
1 .5 0 r
.95859 .85297 Mdot
.628 .126 .941 r
.67303 .26366 Mdot
1 .5 0 r
.64484 .33178 Mdot
.628 .126 .941 r
.92418 .85292 Mdot
.92418 .85292 Mdot
1 .5 0 r
.94431 .87676 Mdot
.94481 .8393 Mdot
.628 .126 .941 r
.7735 .37259 Mdot
.73223 .39984 Mdot
1 .5 0 r
.59663 .31802 Mdot
.66942 .45762 Mdot
.628 .126 .941 r
.65815 .25656 Mdot
1 .5 0 r
.62996 .32469 Mdot
.628 .126 .941 r
.77896 .39964 Mdot
.77877 .38935 Mdot
.75863 .3655 Mdot
.77877 .38935 Mdot
.91569 .85608 Mdot
1 .5 0 r
.58174 .31093 Mdot
.60893 .31774 Mdot
.628 .126 .941 r
.76448 .41313 Mdot
1 .5 0 r
.86315 .68228 Mdot
.628 .126 .941 r
.68928 .40285 Mdot
.71546 .48462 Mdot
.84182 .72311 Mdot
.69059 .28012 Mdot
.73067 .31753 Mdot
.75081 .34138 Mdot
.75585 .47427 Mdot
.73048 .30724 Mdot
.87045 .54917 Mdot
.68245 .30377 Mdot
.84338 .4843 Mdot
.68156 .32067 Mdot
.78277 .40245 Mdot
.78277 .40245 Mdot
.74884 .3649 Mdot
.78258 .39216 Mdot
.74078 .45691 Mdot
.70131 .32394 Mdot
.68097 .28979 Mdot
.78219 .37158 Mdot
.70111 .31364 Mdot
1 .5 0 r
.75903 .57266 Mdot
.628 .126 .941 r
.91917 .83849 Mdot
1 .5 0 r
.63897 .34425 Mdot
.65237 .33736 Mdot
.84476 .74296 Mdot
.59023 .36797 Mdot
.628 .126 .941 r
.75341 .40887 Mdot
.74737 .35093 Mdot
.90551 .76676 Mdot
1 .5 0 r
.9181 .84516 Mdot
.628 .126 .941 r
.74717 .34063 Mdot
1 .5 0 r
.75171 .51106 Mdot
.90375 .80064 Mdot
.628 .126 .941 r
.71819 .36763 Mdot
.85905 .52439 Mdot
.77151 .38789 Mdot
.969 .92658 Mdot
1 .5 0 r
.57433 .3094 Mdot
.628 .126 .941 r
.76477 .35714 Mdot
.76477 .35714 Mdot
.70381 .32304 Mdot
.75117 .35373 Mdot
.75117 .35373 Mdot
1 .5 0 r
.62099 .3673 Mdot
.628 .126 .941 r
.85527 .70827 Mdot
.77004 .37392 Mdot
.77004 .37392 Mdot
.77004 .37392 Mdot
.74264 .3568 Mdot
.72248 .33293 Mdot
.71442 .425 Mdot
.68853 .29535 Mdot
.68814 .27474 Mdot
.68763 .31226 Mdot
.76171 .38729 Mdot
.76222 .34977 Mdot
.77532 .3907 Mdot
1 .5 0 r
.61789 .39746 Mdot
.628 .126 .941 r
.77513 .3804 Mdot
.75497 .35653 Mdot
.94547 .91247 Mdot
1 .5 0 r
.61164 .32917 Mdot
.628 .126 .941 r
.75477 .34623 Mdot
.68704 .28135 Mdot
.72698 .3085 Mdot
.7804 .39719 Mdot
.77385 .37672 Mdot
.73989 .33913 Mdot
.83276 .49251 Mdot
1 .5 0 r
.64352 .32187 Mdot
.628 .126 .941 r
.69192 .27752 Mdot
.74586 .32869 Mdot
.77894 .38321 Mdot
.77238 .36274 Mdot
.74566 .31839 Mdot
.77188 .40027 Mdot
.75171 .37639 Mdot
.77188 .40027 Mdot
1 .5 0 r
.96396 .8438 Mdot
.628 .126 .941 r
.69738 .3046 Mdot
.6634 .267 Mdot
.76405 .37612 Mdot
1 .5 0 r
.78251 .50231 Mdot
.628 .126 .941 r
.72937 .36575 Mdot
.72968 .31791 Mdot
1 .5 0 r
.71456 .42711 Mdot
.628 .126 .941 r
.6957 .2803 Mdot
.6957 .2803 Mdot
1 .5 0 r
.64729 .32466 Mdot
.628 .126 .941 r
.76933 .39292 Mdot
.76258 .36213 Mdot
.76258 .36213 Mdot
.91992 .85359 Mdot
.70036 .39278 Mdot
1 .5 0 r
.91299 .81253 Mdot
.61876 .31415 Mdot
.63894 .33804 Mdot
.62512 .32432 Mdot
.628 .126 .941 r
.76786 .37893 Mdot
.91866 .84997 Mdot
1 .5 0 r
.74446 .57002 Mdot
.86602 .67584 Mdot
.628 .126 .941 r
.69938 .34125 Mdot
.93796 .89084 Mdot
1 .5 0 r
.79805 .60062 Mdot
.63674 .35128 Mdot
.66449 .32056 Mdot
.66449 .32056 Mdot
.628 .126 .941 r
.95707 .92142 Mdot
.86387 .68916 Mdot
.86337 .72671 Mdot
1 .5 0 r
.64271 .34084 Mdot
.67046 .31011 Mdot
.83644 .67203 Mdot
.64201 .36808 Mdot
.628 .126 .941 r
.77167 .38174 Mdot
1 .5 0 r
.63525 .33729 Mdot
.75483 .59338 Mdot
.83536 .67869 Mdot
.628 .126 .941 r
.9499 .80162 Mdot
1 .5 0 r
.6616 .36105 Mdot
.628 .126 .941 r
.71458 .4874 Mdot
.75677 .37465 Mdot
.72277 .33701 Mdot
.79038 .39165 Mdot
.75638 .35402 Mdot
.7695 .395 Mdot
.9219 .7536 Mdot
1 .5 0 r
.74761 .47349 Mdot
.62559 .34699 Mdot
.628 .126 .941 r
.92639 .8559 Mdot
.76166 .37083 Mdot
.76166 .37083 Mdot
.74147 .34692 Mdot
1 .5 0 r
.59138 .29903 Mdot
.628 .126 .941 r
.76046 .43566 Mdot
1 .5 0 r
.59118 .28871 Mdot
.628 .126 .941 r
.7944 .40479 Mdot
.95895 .87962 Mdot
.77401 .37056 Mdot
1 .5 0 r
.77906 .50379 Mdot
.628 .126 .941 r
.74 .33291 Mdot
.76019 .35683 Mdot
1 .5 0 r
.77079 .58572 Mdot
.65025 .34644 Mdot
.65025 .34644 Mdot
.65712 .31904 Mdot
.61623 .30879 Mdot
.64279 .34289 Mdot
.61553 .33605 Mdot
.61553 .33605 Mdot
.628 .126 .941 r
.9437 .85199 Mdot
.67743 .28473 Mdot
1 .5 0 r
.59443 .32908 Mdot
.628 .126 .941 r
.74489 .32908 Mdot
1 .5 0 r
.86203 .7733 Mdot
.628 .126 .941 r
.76439 .38027 Mdot
1 .5 0 r
.93708 .76299 Mdot
.628 .126 .941 r
.77783 .37337 Mdot
.77783 .37337 Mdot
.71654 .32888 Mdot
.764 .35963 Mdot
.764 .35963 Mdot
1 .5 0 r
.87541 .6979 Mdot
.628 .126 .941 r
.78312 .39019 Mdot
.80332 .41411 Mdot
1 .5 0 r
.60616 .29784 Mdot
.628 .126 .941 r
.9203 .84812 Mdot
1 .5 0 r
.94757 .85496 Mdot
.61253 .30802 Mdot
.628 .126 .941 r
.74233 .3217 Mdot
.7487 .33188 Mdot
.7682 .38309 Mdot
.82629 .64287 Mdot
.82559 .67016 Mdot
.76782 .36244 Mdot
.76731 .40004 Mdot
.71933 .40688 Mdot
.73327 .36237 Mdot
.78694 .39301 Mdot
1 .5 0 r
.65034 .34849 Mdot
.67106 .33482 Mdot
.628 .126 .941 r
.77311 .37927 Mdot
.76635 .34843 Mdot
.73906 .34159 Mdot
.7719 .44416 Mdot
.69017 .36539 Mdot
1 .5 0 r
.65632 .33803 Mdot
.64248 .32429 Mdot
.628 .126 .941 r
.75819 .37216 Mdot
1 .5 0 r
.64178 .35157 Mdot
.628 .126 .941 r
.95 .844 Mdot
.825 .44384 Mdot
.77055 .37189 Mdot
.75741 .33085 Mdot
1 .5 0 r
.70839 .41293 Mdot
.628 .126 .941 r
.77584 .38872 Mdot
1 .5 0 r
.64626 .32709 Mdot
.628 .126 .941 r
.762 .37497 Mdot
.78222 .39892 Mdot
.85298 .73756 Mdot
.77495 .40569 Mdot
.75403 .40905 Mdot
1 .5 0 r
.69874 .42267 Mdot
.628 .126 .941 r
.79459 .39865 Mdot
.76053 .36095 Mdot
.78075 .3849 Mdot
.74668 .3472 Mdot
1 .5 0 r
.94536 .85013 Mdot
.96521 .85345 Mdot
.65531 .34672 Mdot
.628 .126 .941 r
.77819 .37752 Mdot
1 .5 0 r
.61396 .31578 Mdot
.628 .126 .941 r
.75758 .3329 Mdot
.74373 .31914 Mdot
.76345 .38074 Mdot
.74322 .35678 Mdot
1 .5 0 r
.90961 .71957 Mdot
.96928 .86674 Mdot
.89526 .74348 Mdot
.628 .126 .941 r
.94868 .82215 Mdot
1 .5 0 r
.61923 .33262 Mdot
.628 .126 .941 r
.74851 .37363 Mdot
.93414 .83574 Mdot
1 .5 0 r
.65252 .32899 Mdot
.68571 .3837 Mdot
.95363 .81842 Mdot
.628 .126 .941 r
.73875 .4417 Mdot
.80755 .42116 Mdot
1 .5 0 r
.65103 .31495 Mdot
.628 .126 .941 r
.70415 .44163 Mdot
1 .5 0 r
.63666 .33885 Mdot
.628 .126 .941 r
.75233 .37645 Mdot
.75031 .52711 Mdot
1 .5 0 r
.80293 .69147 Mdot
.628 .126 .941 r
.68951 .38652 Mdot
.75833 .36597 Mdot
.75833 .36597 Mdot
.78211 .63651 Mdot
1 .5 0 r
.83018 .62966 Mdot
.71492 .4857 Mdot
.64115 .31433 Mdot
.628 .126 .941 r
.77729 .38625 Mdot
1 .5 0 r
.65461 .30741 Mdot
.64044 .34166 Mdot
.628 .126 .941 r
.75615 .37927 Mdot
.77581 .37221 Mdot
1 .5 0 r
.67306 .36536 Mdot
.628 .126 .941 r
.66426 .4852 Mdot
.77492 .38921 Mdot
.78111 .38907 Mdot
.79351 .38881 Mdot
1 .5 0 r
.68363 .39909 Mdot
.66369 .32706 Mdot
.628 .126 .941 r
.76597 .37161 Mdot
.76597 .37161 Mdot
1 .5 0 r
.62906 .32699 Mdot
.628 .126 .941 r
.75849 .36804 Mdot
1 .5 0 r
.64872 .31993 Mdot
.66239 .32336 Mdot
.628 .126 .941 r
.78494 .3919 Mdot
1 .5 0 r
.61408 .31986 Mdot
.63434 .34385 Mdot
.628 .126 .941 r
.77747 .38834 Mdot
.79773 .41233 Mdot
1 .5 0 r
.63931 .40877 Mdot
.61936 .33672 Mdot
.628 .126 .941 r
.7154 .31266 Mdot
1 .5 0 r
.61896 .31601 Mdot
.8136 .59014 Mdot
.628 .126 .941 r
.96083 .84379 Mdot
1 .5 0 r
.61766 .31231 Mdot
.66579 .30545 Mdot
.67167 .35338 Mdot
.83158 .68591 Mdot
.81213 .57613 Mdot
.6503 .33603 Mdot
.628 .126 .941 r
.76614 .37369 Mdot
1 .5 0 r
.75784 .45592 Mdot
.86577 .59652 Mdot
.6563 .32554 Mdot
.628 .126 .941 r
.75118 .36656 Mdot
.9354 .86366 Mdot
.73398 .5 Mdot
1 .5 0 r
.74798 .45534 Mdot
.628 .126 .941 r
.70676 .30741 Mdot
1 .5 0 r
.65149 .33143 Mdot
.628 .126 .941 r
.76081 .34852 Mdot
1 .5 0 r
.65738 .3794 Mdot
.628 .126 .941 r
.76062 .33816 Mdot
.7738 .37933 Mdot
.75992 .36554 Mdot
1 .5 0 r
.65 .31736 Mdot
.628 .126 .941 r
.77911 .39622 Mdot
1 .5 0 r
.92516 .77374 Mdot
.87781 .69475 Mdot
.66239 .31708 Mdot
.70144 .4784 Mdot
.628 .126 .941 r
.75095 .3479 Mdot
.76375 .36836 Mdot
.76375 .36836 Mdot
1 .5 0 r
.68138 .3374 Mdot
.63738 .36782 Mdot
.80735 .50517 Mdot
.62288 .32291 Mdot
.628 .126 .941 r
.75208 .40183 Mdot
1 .5 0 r
.65648 .32964 Mdot
.65648 .32964 Mdot
.628 .126 .941 r
.88485 .72803 Mdot
1 .5 0 r
.93255 .75894 Mdot
.628 .126 .941 r
.82325 .68332 Mdot
1 .5 0 r
.65609 .30889 Mdot
.628 .126 .941 r
.93065 .85156 Mdot
.77141 .37401 Mdot
1 .5 0 r
.65498 .31555 Mdot
.63296 .39449 Mdot
.628 .126 .941 r
.76322 .39786 Mdot
.94323 .79286 Mdot
1 .5 0 r
.66028 .33245 Mdot
.628 .126 .941 r
.89317 .765 Mdot
.74623 .41444 Mdot
1 .5 0 r
.79021 .6996 Mdot
.67049 .34551 Mdot
.65017 .32145 Mdot
.64797 .33478 Mdot
.64797 .33478 Mdot
.64646 .32068 Mdot
.70653 .40994 Mdot
.628 .126 .941 r
.75292 .36821 Mdot
1 .5 0 r
.81136 .62959 Mdot
.628 .126 .941 r
.75824 .38514 Mdot
.75824 .38514 Mdot
1 .5 0 r
.64094 .35404 Mdot
.628 .126 .941 r
.94332 .83548 Mdot
1 .5 0 r
.65957 .35363 Mdot
.67742 .31164 Mdot
.66238 .30448 Mdot
.628 .126 .941 r
.95792 .87248 Mdot
1 .5 0 r
.80392 .49024 Mdot
.6677 .32141 Mdot
.628 .126 .941 r
.94147 .85137 Mdot
.96183 .87548 Mdot
1 .5 0 r
.67261 .31755 Mdot
.628 .126 .941 r
.92755 .83755 Mdot
1 .5 0 r
.67151 .32423 Mdot
.65757 .31038 Mdot
.65615 .36535 Mdot
.628 .126 .941 r
.75728 .38562 Mdot
.96429 .86445 Mdot
.93534 .84352 Mdot
1 .5 0 r
.64923 .32594 Mdot
.628 .126 .941 r
.93276 .76712 Mdot
1 .5 0 r
.80412 .48419 Mdot
.92487 .74278 Mdot
.628 .126 .941 r
.72171 .40476 Mdot
1 .5 0 r
.65304 .32876 Mdot
.67282 .32165 Mdot
.628 .126 .941 r
.96745 .87664 Mdot
.91999 .73851 Mdot
.96492 .86935 Mdot
.95343 .84443 Mdot
1 .5 0 r
.88973 .63654 Mdot
.67666 .31816 Mdot
.628 .126 .941 r
.73293 .38625 Mdot
1 .5 0 r
.66922 .31662 Mdot
.628 .126 .941 r
.95259 .83523 Mdot
.95923 .85597 Mdot
.73587 .40626 Mdot
.95828 .85476 Mdot
1 .5 0 r
.8218 .57759 Mdot
.628 .126 .941 r
.94021 .80096 Mdot
.95352 .84254 Mdot
.95225 .83887 Mdot
.92209 .74701 Mdot
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 312.562},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0001>2000`400?l00000o`00003o_oooool2
o`0005oooooo002looooo`?o000000?oooooo`000?ooool0G_ooool00;[ooooo0_l00004ooooo`;o
0000G_ooool00;Sooooo0_l00006ooooo`03o`000?oooooo000005gooooo002eooooo`?o00002?oo
ool00ol0003oooooo`00001Mooooo`00/oooool2o`0000_ooooo00Co0000oooooooooooo0000G?oo
ool00;3ooooo0ol0000=ooooo`04o`000?ooooooooooo`0005cooooo002^ooooo`;o00004?ooool0
1Ol0003ooooooooooooooooo000005_ooooo002/ooooo`;o00004_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo05Sooooo002Yooooo`?o00005Oooool01Ol0003ooooooooooooooooo
000005[ooooo002Wooooo`;o00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05Oooooo002Uooooo`;o00006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Ko
oooo002Rooooo`?o00007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo
002Pooooo`;o00007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Gooooo002M
ooooo`?o00008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Gooooo002Koooo
o`;o00009?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Cooooo002Iooooo`;o
00009_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?ooooo002Fooooo`?o0000
:?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05?ooooo002Dooooo`;o0000:ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05;ooooo002Aooooo`?o0000;Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo057ooooo002?ooooo`;o0000<?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo057ooooo002=ooooo`;o0000<_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo053ooooo002:ooooo`?o0000=?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo053ooooo0028ooooo`;o0000=oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo04oooooo0026ooooo`;o0000>Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo04kooooo0023ooooo`?o0000>oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo04kooooo0021ooooo`;o0000?oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo04gooooo001nooooo`?o0000@Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo04gooooo001looooo`;o0000A?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo04cooooo001jooooo`;o0000A_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo04_ooooo001gooooo`?o0000B?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
04_ooooo001eooooo`;o0000Boooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04[o
oooo001booooo`?o0000COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo
001`ooooo`;o0000D?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Wooooo001^
ooooo`;o0000D_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Sooooo001[oooo
o`?o0000E?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04Sooooo001Yooooo`;o
0000Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Oooooo001Wooooo`;o0000
FOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Kooooo001Tooooo`?o0000Fooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Kooooo001Rooooo`;o0000G_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Gooooo001Oooooo`?o0000H?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04Cooooo001Mooooo`;o0000Hoooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo04Cooooo001Kooooo`;o0000IOooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo04?ooooo001Hooooo`?o0000J?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04?ooooo001Fooooo`;o0000Joooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04;ooooo001Cooooo`?o0000KOooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo047ooooo001Aooooo`;o0000L?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo047ooooo001?ooooo`;o00004oooool2oj0Pl5gooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`10ooooo`00C?ooool3o`0001Gooooo0_nP8?1Mooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0?oooool004[ooooo0_l0001gooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0?oooool004Sooooo0_l0001iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0?_ooool004Gooooo0ol0001kooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0?_ooool004?ooooo0_l0001nooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0?Oooool0043ooooo0ol00020ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0??ooool003kooooo0_l0000Pooooo`;oX23`2?ooool2oj0Pl5Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0looooo`00??ooool2o`0002;ooooo0_nP8?08oooo
o`;oX23`Eoooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03_ooooo000iooooo`?o
00009?ooool2oj0Pl67ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0jooooo`00
=oooool2o`0008[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0jooooo`00=?oo
ool3o`0001Kooooo0_nP8?0Qooooo`CoX23`Coooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo03Wooooo000booooo`;o00006Oooool2oj0Pl27ooooo1?nP8?1?ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0>Oooool0033ooooo0_l0002Booooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0>?ooool002gooooo0ol0000<ooooo`;oX23`Q_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03Oooooo000[ooooo`;o00003oooool2oj0Pl0;ooooo
0_nP8?09ooooo`;oX23`3Oooool2oj0Pl0Wooooo0_nP8?1Mooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0=oooool002Wooooo0_l0000Eooooo`;oX23`2Oooool2oj0Pl0gooooo0_nP
8?09ooooo`;oX23`3?ooool2oomo04oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0fooooo`009_ooool3o`0002Kooooo0_nP8?02ooooo`;oX23`2oooool2oj0Pl0gooooo0_nP8?02
ooooo`;oogl04_ooool2oj0Pl3_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0f
ooooo`009?ooool2o`0002Wooooo0_nP8?02ooooo`CoX23`2Oooool2oj0Pl0Wooooo0_nP8?02oooo
o`;oX23`5_ooool2oj0Pl3_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0eoooo
o`008Oooool3o`0001Cooooo0_ooO`04ooooo`;oX23`5Oooool2oj0Pl1?ooooo00Coogl0oj0Pl?nP
8?3ooooo0_nP8?0=ooooo`;oogl0AOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
03Cooooo000Oooooo`;o00005oooool2oomo00Cooooo0_nP8?0Kooooo`;oX23`3Oooool2oomo00;o
oooo0_nP8?0=ooooo`;oogl03_ooool2oomo03Gooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0dooooo`007Oooool2o`0003Wooooo0_nP8?000oooooooX23`oj0Pl00:ooooo`;oX23`
5oooool2oomo00_ooooo0_ooO`0eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
<oooool001[ooooo0ol0000Wooooo`;oX23`3?ooool2oj0Pl0Cooooo0_nP8?0=ooooo`;oX23`5ooo
ool2oomo04;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0booooo`006Oooool0
0ol0003oooooooooo`0Vooooo`;oogl00_nP8?0<ooooo`;oX23`0_ooool2oj0Pl1;ooooo0_ooO`04
ooooo`;oX23`6_ooool4oomo03Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0b
ooooo`006Oooool00ol0003oooooooooo`0Vooooo`;oogl01Oooool2oj0Pl0Oooooo0_nP8?02oooo
o`;oX23`3?ooool3oomo00?ooooo0_ooO`04ooooo`;oX23`00?oogl0ooooooooool05oooool5oomo
00;ooooo0_ooO`0_ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0<Oooool001Wo
oooo0_l0000Sooooo`;oX23`2Oooool2oj0Pl0Oooooo1?nP8?0>ooooo`?oogl02Oooool3oomo00Go
oooo0_ooO`0Eooooo`;oogl00_ooool2oomo02Gooooo0onP8?07ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0<Oooool001Wooooo00?o0000ooooool000006_ooool2oomo00Kooooo
0_nP8?0Dooooo`;oX23`1Oooool2oj0Pl0gooooo0_nP8?0<ooooo`?oogl02_ooool3oomo00Kooooo
1?ooO`0Xooooo`CoX23`1_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo033ooooo
000Hooooo`05o`000?ooooooooooooooool000002Oooool2oj0Pl0kooooo0_ooO`000oooooooogl0
oomo0009ooooo`;oX23`0_ooool2oomo0003oooooonP8?3oX23`00;oogl00_ooool2oomo00Sooooo
0_nP8?0=ooooo`;oX23`1?ooool2oj0Pl0Gooooo0_nP8?02oomo00[ooooo0oooO`06ooooo`Googl0
1Oooool2oomo00?ooooo0_nP8?0Mooooo`;oX23`1_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02oooooo000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool2oj0Pl17ooooo0_ooO`06ooooo`?oogl01?nP8?02oomo0003oooooonP8?3oX23`00;oogl00_oo
ool2oomo00;oX23`2Oooool2oomo00Kooooo0_ooO`08ooooo`;oX23`1Oooool2oj0Pl0Sooooo00?o
X23`oomo0?ooO`002_ooool5oomo00Gooooo0_ooO`000oooooooogl0oomo0002oj0Pl1gooooo0_nP
8?02ooooo`;oX23`0_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02oooooo000H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool2oj0Pl0Oooooo1?ooO`00
0oooooooX23`oj0Pl003ooooo`;oogl00_nP8?04ooooo`;oX23`2Oooool2oomo00Kooooo0_ooO`0I
ooooo`03oj0Pl?ooO`3oogl000cooooo0oooO`08ooooo`;oogl00_ooool2oomo01_ooooo0onP8?00
0oooooooX23`oj0Pl002ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;_ooool0
01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`;oX23`1Oooool2oj0P
l003ooooooooO`3oogl000Oooooo0_ooO`02oj0Pl17ooooo0_ooO`04ooooo`;oogl000?ooooooj0P
l?nP8?002?ooool2oj0Pl0oooooo0_nP8?02oomo00Cooooo0_nP8?02oomo0003ooooooooO`3oogl0
00Gooooo0_ooO`05ooooo`;oogl07?ooool2oj0Pl0Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooooooo
o`;oX23`1oooool2oj0Pl0Wooooo0_nP8?05ooooo`;oX23`00?ooooooomo0?ooO`001_ooool2oomo
01Cooooo0_ooO`07ooooo`;oX23`0oooool2oj0Pl0?ooooo0_nP8?08ooooo`Koogl000?ooooooj0P
l?nP8?000_ooO`04ooooo`;oX23`0_ooO`05ooooo`;oogl000?oX23`oomo0?ooO`000oooO`07oooo
o`;oogl05oooool2oj0Pl003oooooonP8?3oX23`00;oX23`00?oooooo`000?ooool0:Oooool00ol0
003oooooooooo`0]ooooo`006?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
X23`00?ooooooj0Pl?nP8?001?ooool00onP8?3oogl0oomo000Dooooo`;oogl01?nP8?02oomo00?o
oooo0_nP8?000oooO`3oooooooooo`02ooooo`;oogl02_ooool2oj0Pl0;oogl00_ooool2oomo00Co
oooo0_nP8?000oooooooogl0oomo0004ooooo`;oogl000Cooooooomo0?ooO`3ooooo1_ooO`000ooo
ooooX23`oj0Pl002oomo0003oj0Pl?oooooooooo00Gooooo0_ooO`000oooooooogl0oomo0002oomo
0003oj0Pl?ooooooogl000?oogl01oooool2oomo01?ooooo0_nP8?02ooooo`;oX23`00?ooooooj0P
l?nP8?000onP8?000ol0003oX23`ooooo`0Yooooo`03o`000?oooooooooo02cooooo000Hooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool2oj0Pl0Gooooo0_ooO`000onP8?3o
ooooooooo`0=ooooo`;oX23`0_ooool01?ooO`3oX23`oj0Pl?nP8?02oomo00Gooooo0_nP8?000ooo
O`3oooooooooo`02ooooo`;oogl02_ooool2oj0Pl0;oogl00_ooool2oomo00Oooooo1?ooO`02oooo
o`;oogl000?oX23`oomo0?ooO`001?ooO`02ooooo`;oogl00_ooool4oomo00Kooooo2oooO`0Noooo
o`;oX23`0_ooool2oj0Pl0;ooooo0_nP8?000oooooooX23`o`000002oj0Pl2Wooooo00?o0000oooo
ooooool0;?ooool001Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`Co
ogl000?oX23`ooooooooool01oooool2oomo00Cooooo0_nP8?000oooooooogl0oomo0002oj0Pl003
ooooooooO`3oogl000cooooo0_nP8?03ooooo`;oX23`5_ooool3oomo00?ooooo0_nP8?000ooooooo
ogl0oomo0002oomo00;ooooo0_ooO`04ooooo`;oogl01oooool3oomo0003ooooooooO`3oogl000Co
ogl03Oooool2oj0Pl1Oooooo1?nP8?000ol0003oX23`oj0Pl00Zooooo`03o`000?oooooooooo02_o
oooo000Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool2oj0Pl003oomo
0?oooooooooo00Cooooo0_ooO`001?ooooooX23`oj0Pl?ooool2oomo00Cooooo0_ooO`000ooooooo
ogl0oomo0002ooooo`;oogl000?ooooooj0Pl?nP8?003oooool2oj0Pl1Oooooo0_ooO`02ooooo`Co
ogl000Cooooooomo0?ooO`3ooooo1?ooO`02ooooo`;oogl02_ooool2oomo00;ooooo1?ooO`0>oooo
o`;oX23`5oooool4oj0Pl003o`000?nP8?3ooooo02_ooooo00?o0000ooooooooool0:_ooool001Oo
oooo00?o0000ooooooooool02_ooool2oj0Pl0Cooooo0onP8?07ooooo`;oogl000?ooooooj0Pl?nP
8?001oooool2oomo00Cooooo0_ooO`001?nP8?3ooooooj0Pl?nP8?0Booooo`;oogl01Oooool2oomo
00Oooooo1?ooO`06ooooo`Coogl01?ooool2oomo00;ooooo1?ooO`09ooooo`03oj0Pl?ooO`3oogl0
00Cooooo0_ooO`02ooooo`;oogl02_ooool2oomo00_ooooo1?nP8?04ooooo`;oX23`0_ooool4oj0P
l003o`000?oooooooooo00;ooooo0_nP8?0Wooooo`03o`000?oooooooooo02[ooooo000Gooooo`03
o`000?oooooooooo00[ooooo0_nP8?001?l0003oooooooooooooool2oj0Pl0Cooooo0_nP8?02oomo
013ooooo1OooO`03ooooo`;oogl01?ooool2oj0Pl0[ooooo00?oogl0oj0Pl?nP8?001?ooool2oomo
00;ooooo0_nP8?02oomo0003ooooooooO`3oogl000;oogl02?ooool2oomo00Sooooo0_ooO`0;oooo
o`;oX23`1oooool4oomo00;ooooo0_nP8?02oomo00;ooooo1?ooO`0;ooooo`CoX23`0_ooool5oj0P
l0;ooooo0onP8?000ol0003oooooooooo`02ooooo`;oX23`:?ooool00ol0003oooooooooo`0Yoooo
o`005oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo0_nP8?02ooooo`;o
X23`00Coogl0oj0Pl?nP8?3ooooo0_nP8?0:ooooo`?oogl00_nP8?02oomo00?ooooo0_ooO`03oooo
o`;oogl00onP8?03ooooo`?oX23`0oooool4oj0Pl0Kooooo0_nP8?02oomo00Cooooo0oooO`06oooo
o`;oogl01oooool2oomo00gooooo0_ooO`03ooooo`Googl01?ooool2oj0Pl0;oogl00_ooool3oomo
0004oooooonP8?3oX23`ooooo`;oogl02_ooool7oj0Pl0;ooooo0onP8?001?l0003ooooooj0Pl?nP
8?0/ooooo`03o`000?oooooooooo02Sooooo000Gooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool00onP8?001OooooooX23`oj0Pl?nP8?3ooooo00GoX23`0oooool2oomo00;ooooo0_nP
8?001?ooooooogl0oomo0?ooool4oj0Pl0Sooooo0oooO`02oj0Pl0?ooooo0onP8?05ooooo`;oX23`
3_ooool3oomo00Kooooo0_ooO`02ooooo`?oogl000Cooooooomo0?ooO`3oogl02?ooool2oj0Pl0?o
oooo0_ooO`03ooooo`Coogl00_ooool2oomo00Sooooo0oooO`02oj0Pl004ooooooooO`3oogl0oooo
o`;oX23`1oooool2oj0Pl0?ooooo0_nP8?04ooooo`03oj0Pl?l0003ooooo00;oX23`;?ooool00ol0
003oooooooooo`0Xooooo`005_ooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooX23`oj0P
l0;ooooo0onP8?001?ooooooX23`oj0Pl?ooO`04oj0Pl005ooooooooO`3oogl0oomo0?ooool00_nP
8?000oooooooogl0oomo0003ooooo`;oX23`00?ooooooomo0?ooO`000_ooool2oj0Pl0;oogl01_oo
ool2oj0Pl1Cooooo0_nP8?02ooooo`;oogl02Oooool4oomo0003ooooooooO`3oogl000;oogl01Ooo
ool2oomo00;oX23`0_ooool2oomo00;oX23`2?ooool2oomo00Wooooo0_ooO`06ooooo`;oX23`1_oo
ool2oomo00?ooooo0oooO`02ooooo`;oX23`00?oooooo`000?ooool00_nP8?0]ooooo`03o`000?oo
oooooooo02Oooooo000Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool5
oj0Pl0?oogl00_nP8?02oomo0003ooooooooO`3oogl000?ooooo0_nP8?001?ooooooogl0oomo0?oo
ool2oj0Pl003ooooooooO`3oogl000;ooooo0_nP8?02oomo00Kooooo0_nP8?04ooooo`;oogl00ooo
ool2oj0Pl0Sooooo0_ooO`000onP8?3oooooooooo`02oomo00Sooooo0_nP8?001?ooO`3ooooooomo
0?ooO`02ooooo`;oogl000?ooooooomo0?ooO`001?ooO`001?ooooooogl0oomo0?ooool2oomo00;o
X23`0_ooool2oomo00oooooo0_nP8?04ooooo`?oogl01oooool8oomo00;ooooo0_nP8?000ooooooo
0000ooooo`04oj0Pl0Cooooo0onP8?0Tooooo`03o`000?oooooooooo02Oooooo000Fooooo`03o`00
0?oooooooooo01;ooooo00Co0000oooooooooooooooo1OnP8?000oooO`3oX23`oj0Pl002oj0Pl0Go
ogl000?oX23`oomo0?ooO`000onP8?02oomo00Cooooo0_ooO`05ooooo`;oogl01Oooool5oj0Pl003
ooooooooO`3oogl000?ooooo0_nP8?05ooooo`;oX23`00Cooooooomo0?ooO`3oogl00_ooool2oomo
0003oj0Pl?ooO`3oogl000Gooooo0onP8?000oooooooogl0oomo0005ooooo`Coogl00oooool2oomo
0003ooooooooO`3oogl000Cooooo0_ooO`02ooooo`;oogl00oooool2oj0Pl004ooooooooO`3oogl0
ooooo`Coogl01?ooool4oomo00Oooooo2_ooO`000oooooooX23`o`000002oj0Pl004oooooonP8?3o
X23`ooooo`;oX23`00Cooooooj0Pl?nP8?3oX23`9Oooool00ol0003oooooooooo`0Vooooo`005_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Cooooo1onP8?02oomo00?oX23`0_oo
O`001Oooooooogl0oomo0?nP8?3oogl000;oX23`0_ooool2oomo00Gooooo0_ooO`02ooooo`;oX23`
00?ooooooomo0?ooO`000onP8?02ooooo`;oogl01oooool2oomo00;oX23`1?ooO`04ooooo`03oj0P
l?ooO`3oogl000Kooooo1?nP8?02oomo00Wooooo0_nP8?001?ooO`3oooooooooooooO`03oj0Pl0;o
ogl00_ooool5oomo00;ooooo0_nP8?000oooooooogl0oomo0007oomo00;ooooo1?ooO`05ooooo`Ko
ogl00_ooool4oomo0003oooooonP8?3o000000GoX23`00Cooooooj0Pl?nP8?3oX23`:Oooool00ol0
003oooooooooo`0Uooooo`005_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo1onP8?02oomo00CoX23`0_ooool4oomo00;oX23`00?ooooooj0Pl?nP8?002_ooool2oj0Pl003
ooooooooO`3oogl000?ooooo1?ooO`07ooooo`;oogl00_ooool2oomo00;ooooo1?ooO`03ooooo`;o
ogl01_ooool2oj0Pl0;oogl02Oooool2oj0Pl005oomo0?ooooooogl0oomo0?nP8?001?ooO`000ooo
ooooogl0oomo0004oomo00Oooooo0_ooO`000oooooooogl0oomo0002oomo0003ooooooooO`3oogl0
00?oogl01Oooool<oomo00;ooooo00?o0000ooooooooool00_nP8?000oooooooX23`oj0Pl002oj0P
l003oooooonP8?3oX23`00;ooooo0onP8?0Qooooo`03o`000?oooooooooo02Gooooo000Fooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool6oj0Pl0Googl00_nP8?02oomo00?o
X23`00Cooooooj0Pl?nP8?3ooooo0_nP8?000oooooooX23`oj0Pl007ooooo`;oX23`0oooool2oomo
017ooooo1?ooO`03ooooo`;oogl02_ooool4oj0Pl0Wooooo0_ooO`000onP8?3oogl0oomo0002oomo
0003ooooooooO`3oogl000;oogl02oooool5oomo0003ooooooooO`3oogl000Coogl01?ooool<oomo
0003oj0Pl?oooooo000000Gooooo0_nP8?03ooooo`;oX23`0_ooool3oj0Pl2;ooooo00?o0000oooo
ooooool09?ooool001Kooooo00?o0000ooooooooool05_ooool01?l0003oooooooooooooool9oj0P
l0Googl00_nP8?02oomo0004oj0Pl?ooooooooooooooo`;oX23`00Cooooooj0Pl?nP8?3ooooo1?nP
8?03ooooo`CoX23`2?ooool2oj0Pl0?ooooo0_nP8?0Cooooo`;oogl01Oooool4oj0Pl0[ooooo00Co
X23`oomo0?ooO`3ooooo0oooO`02ooooo`;oogl01?ooool2oomo00Cooooo0oooO`001?ooooooogl0
oomo0?nP8?02ooooo`Koogl00_ooool;oomo00;oX23`0_ooool00ol0003oX23`oj0Pl002oj0Pl0Wo
oooo0_nP8?0Tooooo`03o`000?oooooooooo02?ooooo000Eooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool03OnP8?02oomo00;oX23`00?oogl0ooooooooool00_ooool2oj0Pl0Gooooo
0_ooO`03oj0Pl003oooooonP8?3oX23`00;oX23`2?ooool2oj0Pl0?ooooo0onP8?02ooooo`;oogl0
0_ooool2oomo00?ooooo1?ooO`03ooooo`;oogl01_ooool3oomo00?ooooo0_nP8?06ooooo`;oogl0
0_ooool2oomo00Cooooo3?ooO`000oooooooogl0oomo0003oj0Pl0;oogl00_ooool3oomo00;oX23`
2_ooO`000oooooooX23`oj0Pl002ooooo`03o`000?nP8?3oX23`00;oX23`00?ooooooj0Pl?nP8?00
0_nP8?04ooooo`?oX23`8oooool00ol0003oooooooooo`0Sooooo`005Oooool00ol0003ooooooooo
o`0Iooooo`04o`000?ooooooooooooooo`SoX23`00?oogl0oj0Pl?nP8?001OooO`000oooooooogl0
oomo0003oj0Pl0;oogl00oooool2oomo00?oX23`0oooool2oj0Pl0Wooooo0_ooO`03ooooo`;oX23`
0_ooool2oomo00;ooooo00?oogl0oj0Pl?nP8?000_ooool4oomo00_ooooo0oooO`001?ooooooogl0
oomo0?nP8?02oomo00cooooo0_ooO`000oooooooogl0oomo000:oomo0004ooooooooO`3oogl0oooo
o`;oX23`1?ooO`000oooooooogl0oomo0002oj0Pl0Soogl01?ooool2oj0Pl003ooooool0003ooooo
00Cooooo1?nP8?02ooooo`SoX23`8Oooool00ol0003oooooooooo`0Rooooo`005Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo2_nP8?000oooO`3oX23`oj0Pl002oj0Pl0;o
ogl00onP8?02oomo00Gooooo0_nP8?000oooooooogl0oomo000<ooooo`;oogl00_ooool2oomo00So
oooo0_nP8?0Aooooo`;oogl00_ooool2oomo0003ooooooooO`3oogl000Sooooo0_ooO`001Ooooooo
ogl0oomo0?ooO`3ooooo00Coogl000?oX23`ooooooooool00_ooO`000oooooooogl0oomo0003oomo
0004ooooooooO`3oogl0ooooo`?oogl00_ooool:oomo0003ooooooooO`3oogl000;ooooo0_nP8?00
1?oooooo0000oj0Pl?nP8?04ooooo`?oX23`0_ooool3oj0Pl003oooooonP8?3oX23`00;oX23`8Ooo
ool00ol0003oooooooooo`0Rooooo`005Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooooooo`[oX23`00Coogl0oj0Pl?ooO`3oogl01_nP8?05ooooo`;oogl00_nP8?000oooooooogl0
oomo0009ooooo`;oX23`1oooO`02ooooo`;oX23`1Oooool2oomo00Cooooo0_nP8?09ooooo`?oogl0
1?nP8?06ooooo`Coogl000?ooooooomo0?ooO`000oooO`04ooooo`;oogl000?oX23`ooooooooool0
1_ooO`06ooooo`Woogl000?ooooooomo0?ooO`000_ooO`02ooooo`;oogl000Kooooooomo0?ooO`3o
X23`ooooool00002oj0Pl0;ooooo1onP8?000oooooooX23`oj0Pl002oj0Pl0;ooooo0_nP8?0Qoooo
o`03o`000?oooooooooo027ooooo000Eooooo`03o`000?oooooooooo01Sooooo0_nP8?02ooooo`03
o`000?oooooooooo00CoX23`00Cooooooj0Pl?nP8?3oX23`0oooO`001?nP8?3oogl0oomo0?ooO`04
oj0Pl0;oogl01?ooool2oomo00;ooooo0_nP8?03ooooo`;oX23`1Oooool2oj0Pl0Koogl00oooool2
oj0Pl0?ooooo1?ooO`04ooooo`;oX23`00?ooooooomo0?nP8?000_nP8?04ooooo`Coogl000?oX23`
oomo0?ooO`000_ooool2oomo0003oooooonP8?3oogl000?oogl000Gooooooj0Pl?ooO`3oogl0oj0P
l003oomo0003ooooooooO`3oogl000;oogl000?ooooooj0Pl?nP8?000oooO`05ooooo`Googl000?o
oooooomo0?ooO`001OooO`001?nP8?3oogl0oomo0?ooO`05ooooo`;oogl00_ooool01?l0003oX23`
oj0Pl?ooool3oj0Pl003oooooonP8?3oX23`00SoX23`00?ooooooj0Pl?nP8?008_ooool00ol0003o
ooooooooo`0Pooooo`005Oooool00ol0003oooooooooo`0Hooooo`;oX23`0oooool01?l0003ooooo
oj0Pl?nP8?03ooooo`SoX23`2OooO`07ooooo`;oX23`0oooool2oj0Pl0Wooooo0_nP8?000oooO`3o
ooooooooo`03ooooo`;oX23`0_ooool6oomo00Gooooo00?oogl0oj0Pl?nP8?000onP8?02ooooo`Oo
ogl00_ooool2oomo0004oooooonP8?3oX23`ooooo`?oogl000?ooooooomo0?ooO`001?ooO`000ooo
ooooogl0oomo0002oomo0003oooooonP8?3oX23`00;oogl01?ooool5oomo00?oX23`0_ooO`000ooo
ooooogl0oomo0006oomo00;ooooo0_ooO`03ooooo`;oX23`00Co0000oj0Pl?nP8?3ooooo0_nP8?03
ooooo`[oX23`9?ooool00ol0003oooooooooo`0Pooooo`005?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00?ooooo2OnP8?08oomo00_ooooo0_nP8?07ooooo`;oogl01?nP8?05oooo
o`;oX23`0oooool2oj0Pl0?oogl01Oooool2oj0Pl004oomo0?ooooooX23`oj0Pl0;ooooo1?ooO`02
oj0Pl003oomo0?oooooooooo00?oogl00oooool3oomo00?ooooo2?ooO`03oj0Pl003oooooonP8?3o
X23`00Cooooo1_ooO`02oj0Pl0Koogl000?ooooooomo0?ooO`000_ooO`02ooooo`;oogl00oooool2
oj0Pl003o`000?oooooooooo00Sooooo3?nP8?0Qooooo`03o`000?oooooooooo01oooooo000Doooo
o`03o`000?oooooooooo01[ooooo0_nP8?02ooooo`;oX23`00?o0000ooooooooool00_ooool5oj0P
l003oooooonP8?3oX23`00;oX23`1_ooO`000oooooooogl0oomo0002ooooo`;oX23`1Oooool2oj0P
l0Kooooo0_nP8?000oooO`3oX23`oj0Pl002oj0Pl0Kooooo0_ooO`02ooooo`;oX23`1?ooool2oj0P
l0;ooooo0_nP8?03ooooo`;oX23`1Oooool2oomo00?ooooo1OooO`09ooooo`Koogl00onP8?001?oo
ooooogl0oomo0?ooO`04ooooo`;oogl000?ooooooomo0?ooO`000oooool8oomo0004ooooooooO`3o
ogl0ooooo`;oogl01Oooool00ol0003oooooooooo`09ooooo`_oX23`8Oooool00ol0003ooooooooo
o`0Oooooo`005?ooool00ol0003oooooooooo`0Jooooo`;oX23`0_ooool2oj0Pl003ooooool0003o
oooo00;oX23`00Cooooooj0Pl?nP8?3oX23`0_ooool4oj0Pl0Googl000CoX23`oomo0?ooO`3oogl0
0_ooool2oj0Pl0gooooo0_nP8?02ooooo`;oogl000?ooooooomo0?ooO`001?ooool2oomo00Sooooo
0_nP8?02ooooo`;oX23`0oooool00onP8?3oogl0oomo0004ooooo`;oogl00_ooool2oj0Pl0;ooooo
1?ooO`07ooooo`;oogl02?ooool3oomo00Cooooo0_ooO`000oooooooX23`oj0Pl003ooooo`Koogl0
0oooool2oomo0003ooooooooO`3oogl000Gooooo00?o0000ooooooooool01_ooool3oj0Pl003oooo
oonP8?3oX23`00OoX23`8oooool00ol0003oooooooooo`0Nooooo`005?ooool00ol0003ooooooooo
o`0Qooooo`CoX23`0_ooool2oj0Pl0Kooooo00?oogl0oj0Pl?nP8?001_ooO`000oooooooogl0oj0P
l002oj0Pl003oooooonP8?3oX23`00;ooooo0_nP8?0;ooooo`;oX23`00?oogl0ooooooooool02_oo
ool2oomo00;oX23`0_ooO`02oj0Pl0Cooooo0oooO`02oj0Pl003oooooonP8?3oX23`00;ooooo1?nP
8?001?ooooooogl0oomo0?ooO`02oj0Pl0;ooooo0_nP8?000oooooooogl0oomo0003ooooo`;oX23`
00?ooooooomo0?ooO`001?ooool2oomo00Kooooo1?ooO`02ooooo`;oX23`1Oooool2oomo00?oX23`
1?ooool00ol0003oooooooooo`02ooooo`;oX23`0_ooool3oj0Pl003oooooonP8?3oX23`00SoX23`
8oooool00ol0003oooooooooo`0Mooooo`005?ooool00ol0003oooooooooo`0Qooooo`;oX23`0_oo
ool3oj0Pl0Cooooo0_nP8?02ooooo`;oX23`00?oogl0oj0Pl?nP8?000_ooO`02oj0Pl005oomo0?nP
8?3oX23`oomo0?ooool00_nP8?02ooooo`;oX23`2oooool2oj0Pl003oooooonP8?3oX23`00[ooooo
00?oogl0oj0Pl?nP8?001?ooO`02ooooo`?oogl000?ooooooomo0?ooO`000_nP8?000oooooooX23`
oj0Pl004ooooo`;oX23`00?oogl0oj0Pl?nP8?000onP8?02ooooo`;oX23`00?ooooooomo0?ooO`00
0oooool2oj0Pl003ooooooooO`3oogl000Cooooo0_ooO`06ooooo`Coogl00_ooool00onP8?3oogl0
oomo0004ooooo`;oogl01onP8?000ol0003oooooooooo`02ooooo`;oX23`0_ooool?oj0Pl2;ooooo
00?o0000ooooooooool07Oooool001Cooooo00?o0000ooooooooool08_ooool2oj0Pl005oooooonP
8?3oX23`oj0Pl?ooool00_nP8?000oooooooX23`oj0Pl005ooooo`;oX23`0_ooO`05oj0Pl003oomo
0?ooooooX23`00;oX23`3_ooool3oomo00;oX23`0oooool2oj0Pl0;ooooo0_ooO`02ooooo`;oX23`
1_ooool5oomo00;ooooo0_ooO`02ooooo`;oX23`0oooool4oomo0005oj0Pl?ooO`3oogl0oomo0?oo
ool00oooO`06ooooo`;oX23`0_ooO`02ooooo`Coogl01_ooool3oomo00?ooooo0oooO`02ooooo`;o
ogl000?ooooooj0Pl?nP8?000_ooO`04oj0Pl003o`000?oooooooooo00;ooooo2?nP8?000ooooooo
X23`oj0Pl008oj0Pl2?ooooo00?o0000ooooooooool07?ooool001?ooooo00?o0000ooooooooool0
8oooool2oj0Pl003o`000?oooooooooo00;ooooo0_nP8?07ooooo`;oX23`0oooO`03oj0Pl003oomo
0?nP8?3oX23`00;oogl00_nP8?04ooooo`;oX23`1oooool2oj0Pl0?oogl00_nP8?02ooooo`;oX23`
0_ooool2oomo00?ooooo0_nP8?02ooooo`;oX23`0_ooool4oomo00;ooooo2OooO`02ooooo`[oogl0
1_ooool>oomo00?ooooo0_ooO`03ooooo`?oogl00_ooool2oomo0003oooooonP8?3oX23`00;oogl0
0oooool01?nP8?3o0000oj0Pl?nP8?04ooooo`;oX23`00?ooooooj0Pl?nP8?002_nP8?000ooooooo
X23`oj0Pl002oj0Pl27ooooo00?o0000ooooooooool06oooool001?ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`05ooooo`CoX23`00Cooooooj0Pl?nP8?3oX23`0_ooool3oj0Pl004
oomo0?nP8?3oX23`oomo00?oX23`1?ooool2oj0Pl0Gooooo1?nP8?03ooooo`;oX23`2Oooool2oomo
00;oX23`00Coogl0oooooonP8?3oX23`0oooool2oj0Pl0Gooooo1oooO`000oooooooogl0oomo0003
oomo00;ooooo1?ooO`000onP8?3oooooooooo`03ooooo`;oogl00_ooool2oomo0004ooooooooO`3o
ogl0ooooo`Koogl00_nP8?0>ooooo`;oX23`1?ooool00ol0003oX23`oj0Pl003ooooo`;oX23`0ooo
ool3oj0Pl004oooooonP8?3oX23`ooooo`WoX23`8Oooool00ol0003oooooooooo`0Kooooo`004ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Cooooo1OnP8?000oooooooX23`oj0P
l002ooooo`Coogl01_nP8?001?ooO`3oooooooooooooool3oj0Pl0Cooooo0_nP8?000oooooooX23`
oj0Pl00<ooooo`?oogl000Cooooooomo0?ooO`3ooooo0_nP8?03ooooo`;oogl02?ooool3oj0Pl0Oo
ogl01?ooool2oomo0003oj0Pl?ooO`3oogl000;oX23`2_ooool00onP8?3oogl0oomo0002ooooo`;o
ogl00_nP8?03ooooo`;oX23`0oooool2oj0Pl0Cooooo0_nP8?001OooO`3ooooooooooooooooo0000
00Gooooo1onP8?02ooooo`_oX23`8oooool00ol0003oooooooooo`0Jooooo`004oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo0_nP8?05ooooo`04oj0Pl?ooO`3oogl0oj0P
l0;oogl00onP8?001?ooO`3oX23`oj0Pl?nP8?02ooooo`;oX23`00?ooooooj0Pl?nP8?001?ooool2
oj0Pl0Gooooo0_ooO`05ooooo`;oogl00_ooool2oj0Pl003oooooonP8?3oX23`00?ooooo0_ooO`08
ooooo`03oj0Pl?ooO`3oogl000Coogl000?ooooooomo0?ooO`000_ooO`05ooooo`;oogl00onP8?03
ooooo`;oogl01?ooool00onP8?3oogl0oomo0006ooooo`;oogl000Cooooooj0Pl?nP8?3ooooo0_oo
O`000onP8?3oogl0oomo0004ooooo`;oogl00oooool00ol0003oooooooooo`02ooooo`;oogl000Co
oooooj0Pl?nP8?3oX23`1Oooool:oj0Pl2?ooooo00?o0000ooooooooool06_ooool001?ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`GoX23`1Oooool01?nP8?3oogl0oj0P
l?nP8?03ooooo`03oj0Pl?ooO`3oogl000Gooooo0_nP8?0;ooooo`;oogl000?ooooooomo0?ooO`00
1_ooool2oj0Pl0Kooooo0_ooO`05ooooo`;oX23`1oooO`02ooooo`Coogl00_ooool00oooO`3oX23`
oj0Pl002ooooo`;oogl000CoX23`oooooooooooooooo1_ooO`05ooooo`;oogl00_ooool01?ooO`3o
X23`oj0Pl?ooool4oomo0004ooooooooO`3oogl0ooooo`?oX23`0_ooool2oomo0003oooooonP8?3o
000000;oX23`00Cooooooomo0?ooO`3ooooo0_nP8?000oooooooX23`oj0Pl00>oj0Pl2?ooooo00?o
0000ooooooooool06Oooool001?ooooo00?o0000ooooooooool0:Oooool2oj0Pl0Gooooo1_nP8?00
0oooooooX23`oj0Pl003ooooo`?oX23`0_ooO`08oj0Pl0Gooooo0_ooO`04ooooo`;oogl00_nP8?00
1?ooooooX23`oomo0?ooO`0:ooooo`;oogl02Oooool2oj0Pl0;oogl00_ooool3oomo00;ooooo1?nP
8?02ooooo`03oomo0?nP8?3oX23`00;oX23`0_ooO`06ooooo`?oogl00_nP8?04ooooo`;oogl00ooo
ool2oj0Pl003ooooooooO`3oogl000;oogl000Cooooooj0Pl?nP8?3ooooo0onP8?02ooooo`;oogl0
0_nP8?000ol0003oX23`oj0Pl002oj0Pl0Gooooo4?nP8?000oooooooX23`oj0Pl00Qooooo`03o`00
0?oooooooooo01Sooooo000Cooooo`03o`000?oooooooooo02Wooooo0_nP8?000ol0003ooooooooo
o`02ooooo`;oX23`1Oooool2oj0Pl0Gooooo0oooO`05oj0Pl003oomo0?nP8?3oX23`00Gooooo0_oo
O`04ooooo`;oogl00_nP8?001?ooooooX23`oomo0?ooO`0:ooooo`?oogl00_ooool2oomo00Gooooo
0_ooO`000oooooooX23`oomo0005oomo00GoX23`0oooool2oomo0003oj0Pl?ooooooX23`00;oogl0
0oooool4oomo00;oX23`0_ooool2oj0Pl0?ooooo0_ooO`03ooooo`;oX23`0_ooool3oj0Pl0?ooooo
0_nP8?03ooooo`;oX23`00?o0000oooooonP8?000_nP8?04oooooaCoX23`8Oooool00ol0003ooooo
ooooo`0Hooooo`004_ooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooooooo`;oX23`
1Oooool2oj0Pl0;ooooo0_nP8?001OooooooX23`oj0Pl?nP8?3ooooo00CoX23`0_ooO`000onP8?3o
ooooooooo`0;ooooo`;oX23`0_ooO`06ooooo`;oX23`0oooool4oomo00;ooooo0_ooO`05ooooo`;o
ogl000?ooooooj0Pl?ooO`001oooO`000oooooooX23`oj0Pl003ooooo`;oogl00_ooool00onP8?3o
ogl0oomo0005oomo0004oooooonP8?3oX23`oomo00;ooooo0_nP8?02ooooo`?oogl000?ooooooomo
0?ooO`000_nP8?02ooooo`;oX23`1?ooool3oj0Pl005oooooonP8?3oX23`ooooool000000onP8?02
oooooaKoX23`8oooool00ol0003oooooooooo`0Gooooo`004_ooool00ol0003oooooooooo`0Xoooo
o`CoX23`00?ooooooj0Pl?nP8?000_ooool2oj0Pl0Wooooo0_nP8?001OooooooX23`oj0Pl?nP8?3o
ogl000GoX23`0_ooO`0?ooooo`;oogl01_ooool2oj0Pl0?ooooo0_ooO`05ooooo`;oogl00_ooool2
oomo00;ooooo0_nP8?06ooooo`;oogl000?oX23`ooooooooool00oooO`001?nP8?3oogl0oomo0?oo
ool2oomo0003ooooooooO`3oogl000?oogl000Gooooooj0Pl?nP8?3oX23`oomo0002ooooo`;oogl0
00GoX23`oomo0?ooO`3oogl0ooooo`02oomo00;ooooo0_ooO`07ooooo`Coogl00_nP8?000ol0003o
X23`oj0Pl00;oj0Pl0Gooooo0onP8?000oooooooX23`oj0Pl005oj0Pl2;ooooo00?o0000oooooooo
ool05_ooool001;ooooo00?o0000ooooooooool0:?ooool4oj0Pl004oooooonP8?3oX23`o`0000go
oooo0_nP8?03ooooo`?oogl00_nP8?03oomo00;oX23`00?ooooooj0Pl?nP8?003Oooool2oj0Pl0?o
oooo0_nP8?06ooooo`;oogl00_ooool2oomo00;ooooo0_ooO`02ooooo`;oX23`00Cooooooomo0?nP
8?3oX23`0_ooool01OooO`3oX23`oj0Pl?ooO`3ooooo00?oogl000CoX23`oomo0?ooO`3ooooo0_oo
O`02ooooo`;oX23`00Coogl0oooooooooooooooo0_nP8?000oooO`3oooooooooo`02oomo0003oj0P
l?ooO`3oogl000;ooooo0_ooO`02ooooo`?oogl01_ooool4oomo00;oX23`00?o0000oooooonP8?00
1OnP8?02ooooo`CoX23`00?ooooooj0Pl?nP8?000_ooool7oj0Pl0;ooooo0_nP8?0Rooooo`03o`00
0?oooooooooo01Kooooo000Booooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02_oo
ool2oj0Pl0;ooooo0_nP8?001?ooO`3oX23`oj0Pl?ooool2oomo0003oooooonP8?3oogl000?oogl0
00?ooooooomo0?ooO`002_ooool2oj0Pl0?oogl00_nP8?06ooooo`;oogl02?ooool2oomo00?ooooo
00?oogl0oj0Pl?nP8?000oooool2oj0Pl003oomo0?oooooooooo00;oogl000Cooooooomo0?ooO`3o
X23`0_ooO`03oj0Pl0;oogl01?ooool2oomo00?ooooo00GoX23`oomo0?ooO`3oogl0oj0Pl006oooo
o`;oogl02Oooool2oj0Pl003ooooool0003oX23`00Gooooo1_nP8?02ooooo`CoX23`00?ooooooj0P
l?nP8?001?nP8?001?ooooooX23`oj0Pl?nP8?0Sooooo`03o`000?oooooooooo01Gooooo000Boooo
o`03o`000?oooooooooo033ooooo0_nP8?07ooooo`?oX23`00?ooooooj0Pl?nP8?000_ooool2oj0P
l004oooooonP8?3oX23`oomo00;ooooo1_ooO`000oooooooogl0oomo0002oomo00Cooooo0_nP8?04
ooooo`Coogl01?ooool2oomo00Wooooo1?ooO`02oj0Pl004ooooooooO`3oogl0oomo00Sooooo0_oo
O`001?ooooooogl0oomo0?nP8?02oomo00KoX23`0oooool2oomo00?ooooo00CoX23`oomo0?ooO`3o
ogl00onP8?001?ooooooogl0oomo0?ooool2oomo00?oX23`0oooool2oomo0006oooooonP8?3oX23`
ooooool0003oX23`0_ooO`02ooooo`OoX23`0oooool5oj0Pl003oooooonP8?3oX23`00?ooooo0onP
8?0Sooooo`03o`000?oooooooooo01Gooooo000Booooo`03o`000?oooooooooo02cooooo0_nP8?02
ooooo`;oX23`00?o0000ooooooooool01?ooool7oj0Pl003ooooooooO`3oogl000;ooooo0_ooO`02
ooooo`;oogl01oooool2oomo00Cooooo0_nP8?07ooooo`;oogl00oooool3oomo00;ooooo0_ooO`04
ooooo`;oogl00_ooool2oj0Pl0Soogl000?ooooooj0Pl?nP8?000oooool2oj0Pl004ooooooooO`3o
ogl0ooooo`;oogl01?nP8?000oooooooogl0oomo0003ooooo`;oogl00_ooool2oomo0004oooooonP
8?3oX23`oj0Pl0;oogl000?ooooooomo0?ooO`000onP8?03ooooo`;oogl000Kooooooj0Pl?nP8?3o
ooooo`000?nP8?03oomo00OoX23`1?ooool5oj0Pl0Oooooo0onP8?0Sooooo`03o`000?oooooooooo
01Cooooo000Aooooo`03o`000?oooooooooo02gooooo0_nP8?03ooooo`;oX23`00Co0000oooooonP
8?3oX23`0_ooool4oj0Pl003oooooonP8?3oX23`00?ooooo0_nP8?04ooooo`;oogl03_ooool2oomo
00Kooooo0_ooO`03ooooo`;oX23`00?oogl0ooooooooool00_ooO`0:ooooo`;oogl00_ooool4oomo
0003oooooonP8?3oX23`00?ooooo0_nP8?001?ooooooogl0oomo0?nP8?02oomo00CoX23`00Cooooo
oomo0?ooO`3ooooo0_nP8?02oomo00;ooooo0_ooO`02ooooo`;oX23`00Cooooooj0Pl?nP8?3oogl0
0onP8?000oooooooX23`oj0Pl004ooooo`?oX23`00?o0000oomo0?ooool00_ooO`02oj0Pl003oooo
oonP8?3oX23`00_oX23`1?ooool2oj0Pl003oooooonP8?3oX23`00?oX23`8?ooool3o`0001Gooooo
000Aooooo`03o`000?oooooooooo03;ooooo0_nP8?001Ooooooo0000oj0Pl?nP8?3ooooo00?oX23`
00?ooooooj0Pl?nP8?000_nP8?03ooooo`;oX23`0_ooO`05ooooo`;oX23`2oooool2oomo00;ooooo
0_nP8?07ooooo`;oX23`1Oooool2oomo00;oX23`0_ooO`03ooooo`;oogl00oooool2oj0Pl0;ooooo
0_ooO`03ooooo`Coogl000?ooooooj0Pl?nP8?000_nP8?03oomo0005oj0Pl?ooooooX23`oj0Pl?oo
ool00_nP8?04ooooo`;oogl00oooool2oj0Pl0;oogl00_nP8?03ooooo`;oX23`0_ooool2oomo00?o
X23`00Co0000oj0Pl?nP8?3oX23`1?ooool?oj0Pl0;ooooo0_nP8?03ooooo`?oX23`1?ooool2oj0P
l1Oooooo0ol00002ooooo`03o`000?oooooooooo01?ooooo000Aooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool00_nP8?000oooooooX23`oj0Pl005oj0Pl0?ooooo0_ooO`05ooooo`;o
X23`0_ooool2oj0Pl0_ooooo0_nP8?08ooooo`?oogl00oooool2oomo00;oX23`0_ooO`000ooooooo
ogl0oomo0002oj0Pl003ooooooooO`3oogl000;oX23`0_ooool2oomo00?ooooo1?ooO`03ooooo`;o
X23`0oooO`05ooooo`;oX23`2Oooool2oj0Pl0;oogl01_nP8?02oomo0003ooooooooO`3oogl000;o
oooo00?oX23`o`000?ooO`000onP8?05ooooo`;oX23`1?ooool01OooO`3oX23`oj0Pl?nP8?3ooooo
00;oX23`2?ooool2oj0Pl0Cooooo0_nP8?0Dooooo`?o00001Oooool00ol0003oooooooooo`0Coooo
o`004Oooool00ol0003oooooooooo`0gooooo`05o`000?ooooooX23`oj0Pl?ooool00_nP8?03oooo
o`?oX23`3Oooool2oj0Pl1Gooooo0oooO`0:ooooo`;oogl00_nP8?000oooooooogl0oomo0002oomo
0003ooooooooO`3oogl000Kooooo0_nP8?03ooooo`;oogl00onP8?05ooooo`;oX23`0_ooO`05oooo
o`;oX23`1Oooool5oj0Pl0;oogl01Oooool00onP8?3o0000oomo0003oj0Pl0;oogl02Oooool2oomo
00;oX23`2oooool3oj0Pl1Kooooo0ol00008ooooo`03o`000?oooooooooo01?ooooo000Aooooo`03
o`000?oooooooooo03Kooooo0_nP8?001?l0003oX23`oj0Pl?ooool2oj0Pl0?ooooo1_nP8?02oooo
o`;oogl00_nP8?0Mooooo`;oX23`1?ooool2oomo00Cooooo0_ooO`000oooooooX23`oomo0003oomo
0003ooooooooO`3oogl000Kooooo0_nP8?05ooooo`;oX23`2?ooool2oomo00Gooooo0_nP8?05oooo
o`;oX23`00Cooooooj0Pl?nP8?3ooooo0onP8?03ooooo`04oj0Pl?l0003oX23`oj0Pl0;ooooo0_oo
O`03ooooo`;oX23`0_ooO`0>ooooo`;oX23`0_ooool2oj0Pl1?ooooo0ol0000;ooooo`03o`000?oo
oooooooo01?ooooo000Aooooo`03o`000?oooooooooo03Kooooo1?nP8?02ooooo`CoX23`00?ooooo
oj0Pl?nP8?001?nP8?02ooooo`;oogl00_nP8?0:ooooo`;oogl04Oooool2oj0Pl0Cooooo0_ooO`03
ooooo`;oogl00_ooool2oj0Pl003ooooooooO`3oogl000;ooooo0_ooO`04ooooo`;oogl01oooool2
oomo0003oj0Pl?ooooooogl000;oX23`1?ooool00oooO`3oX23`oj0Pl00<ooooo`KoX23`0oooool0
0onP8?3o0000ooooo`08ooooo`;oX23`0_ooO`05ooooo`Coogl00oooool4oj0Pl0;ooooo0_nP8?0@
ooooo`?o00003oooool00ol0003oooooooooo`0Booooo`004Oooool00ol0003oooooooooo`0hoooo
o`CoX23`0_ooool2oj0Pl003oooooonP8?3oX23`00;oX23`00Cooooooj0Pl?ooO`3oogl01?ooool2
oj0Pl003oooooonP8?3oX23`00Gooooo0_ooO`0>ooooo`;oX23`1_ooool2oomo00;ooooo1?ooO`03
ooooo`;oogl00_ooool01?nP8?3oogl0oj0Pl?nP8?04ooooo`;oogl01oooool5oomo00;oX23`0_oo
ool3oomo00?oX23`0_ooool2oomo00Kooooo0_ooO`03oj0Pl0Gooooo00CoX23`o`000?nP8?3oX23`
1_ooool2oj0Pl0Oooooo0_nP8?03oomo00?ooooo0_nP8?04ooooo`;oX23`3Oooool3o`0001;ooooo
00?o0000ooooooooool04_ooool0013ooooo00?o0000ooooooooool0>oooool2oj0Pl0Oooooo0_nP
8?001?ooooooX23`oomo0?ooO`04ooooo`;oX23`00?ooooooj0Pl?nP8?005Oooool2oj0Pl0?ooooo
0_ooO`001?ooooooogl0oomo0?ooool3oomo00;ooooo0_ooO`000oooooooogl0oomo0002ooooo`04
oj0Pl?ooO`3oogl0oomo00;ooooo0_ooO`08ooooo`;oogl000?ooooooomo0?ooO`000oooO`02oj0P
l0Coogl00_nP8?04oomo0003oj0Pl?oooooooooo00?ooooo0_ooO`03oj0Pl0Kooooo00?o0000oj0P
l?nP8?001_ooool5oj0Pl0Cooooo0_nP8?0Hooooo`?o00005Oooool00ol0003oooooooooo`0Boooo
o`004?ooool00ol0003oooooooooo`0mooooo`04o`000?ooooooooooooooo`;oX23`00Cooooooj0P
l?nP8?3ooooo0onP8?0;ooooo`;oX23`00Cooooooj0Pl?ooO`3oogl04_ooool2oomo00?ooooo0ooo
O`03ooooo`;oogl01oooool2oomo00;ooooo1?ooO`06ooooo`;oogl00_ooool4oomo00?oX23`0ooo
O`001OooooooX23`oomo0?ooO`3ooooo00;oX23`2?ooool2oj0Pl0Oooooo00?o0000oj0Pl?nP8?00
1_ooool4oj0Pl0Cooooo0_nP8?000oooooooX23`oj0Pl00=ooooo`;oX23`0oooool3o`0001Sooooo
00?o0000ooooooooool04_ooool0013ooooo00?o0000ooooooooool0??ooool2oj0Pl003o`000?nP
8?3oX23`00;oX23`00Cooooooj0Pl?nP8?3ooooo0onP8?09ooooo`CoX23`00Cooooooj0Pl?ooO`3o
ogl00_ooool2oomo00_ooooo0_nP8?06ooooo`;oogl02oooool2oomo00;ooooo0_ooO`02ooooo`;o
ogl00_ooool2oj0Pl0?ooooo0_nP8?001?ooooooogl0oomo0?ooool2oomo00;oX23`00?oogl0oooo
ooooool00_ooool2oomo00Kooooo0_ooO`08ooooo`;oX23`00?ooooooj0Pl?l000000_nP8?000ooo
ooooX23`oj0Pl002oj0Pl0?ooooo0_nP8?04ooooo`;oogl000?ooooooj0Pl?nP8?003Oooool2oj0P
l0?o00006oooool00ol0003oooooooooo`0Booooo`004?ooool00ol0003oooooooooo`0kooooo`?o
X23`00?ooooooj0Pl?nP8?000_nP8?0:ooooo`;oogl01?ooool2oj0Pl0Gooooo0_nP8?000ooooooo
ogl0oomo000;ooooo`;oX23`00?oogl0ooooooooool00oooool2oj0Pl003ooooooooO`3oogl000Co
oooo0_nP8?02ooooo`;oogl000?ooooooomo0?ooO`000oooO`001?ooooooogl0oomo0?ooool4oj0P
l004oooooonP8?3oX23`ooooo`;oogl000Cooooooomo0?ooO`3oogl01Oooool2oomo0003oooooonP
8?3oX23`00Cooooo0_ooO`08ooooo`;oX23`00Gooooooj0Pl?l0003oX23`ooooo`06oj0Pl0;oogl0
0oooool2oj0Pl003ooooooooO`3oogl000Kooooo00?oogl0oj0Pl?nP8?001_ooool3o`0001kooooo
00?o0000ooooooooool04_ooool0013ooooo00?o0000ooooooooool0>oooool2oj0Pl0?ooooo00?o
0000oj0Pl?nP8?001Oooool2oj0Pl0?ooooo0_ooO`0;ooooo`;oX23`0_ooool2oomo0003oj0Pl?oo
oooooooo00Gooooo0_ooO`000oooooooogl0oomo0008ooooo`;oogl01?ooool2oj0Pl0Gooooo00?o
ogl0oj0Pl?nP8?001OooO`02ooooo`?oogl000?ooooooomo0?ooO`002Oooool2oomo0004oooooooo
O`3oogl0ooooo`CoX23`3Oooool2oj0Pl004ooooool0003oX23`ooooo`;oX23`0_ooool2oj0Pl0;o
ogl000?ooooooj0Pl?nP8?000_nP8?03ooooo`;oogl01?ooool01?ooO`3oX23`oj0Pl?ooool2oj0P
l0?o00008Oooool00ol0003oooooooooo`0Booooo`004?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo00Cooooo0_nP8?02ooooo`;oX23`00?ooooooj0Pl?nP8?001Oooool3oj0Pl0Co
oooo0_nP8?001?ooO`3oX23`ooooooooool2oomo00?ooooo0_ooO`0Dooooo`?oogl00_ooool2oj0P
l0;ooooo0_ooO`04ooooo`;oogl01_ooool5oomo0004ooooooooO`3oogl0oomo00Gooooo0_nP8?00
0oooooooX23`oj0Pl002oj0Pl0;ooooo0_ooO`001?ooooooogl0oomo0?ooool2oj0Pl003ooooool0
003oX23`00Wooooo0_nP8?02oomo0003oj0Pl?ooO`3oogl000;oX23`00Coogl0oooooooooooooooo
0_ooO`02ooooo`03o`000?nP8?3oX23`02Gooooo00?o0000ooooooooool04Oooool000oooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`07ooooo`;oX23`00Gooooooj0Pl?nP8?3oX23`
ooooo`07oj0Pl003oooooonP8?3oX23`00;oX23`1?ooool2oomo00Oooooo0_nP8?0:ooooo`;oogl0
1?ooool3oomo00[ooooo0oooO`07ooooo`Googl00_ooool2oomo0003oooooonP8?3oX23`00Gooooo
1OnP8?000oooooooogl0oomo0003oomo00;oX23`0_ooool00ol0003oX23`ooooo`02oj0Pl0Kooooo
0_nP8?02oomo0003oj0Pl?ooO`3oogl000;oX23`1?ooool4oomo00Kooooo0_nP8?0Pooooo`03o`00
0?oooooooooo017ooooo000?ooooo`03o`000?oooooooooo04?ooooo0_nP8?0<ooooo`;oX23`00Co
oooooj0Pl?nP8?3oX23`0_ooool2oj0Pl003oooooonP8?3oX23`00;oogl01_ooool2oomo00Gooooo
0_nP8?03ooooo`03oomo0?nP8?3oX23`00Cooooo0_ooO`02ooooo`;oX23`00?ooooooomo0?ooO`00
1?ooool2oomo00Cooooo0oooO`02ooooo`;oX23`00?ooooooj0Pl?nP8?000_ooool2oomo00Kooooo
0_nP8?08ooooo`;oX23`00Cooooooj0Pl?ooO`3oogl00_ooool4oj0Pl005o`000?ooooooogl0oomo
0?nP8?002Oooool2oomo00Gooooo0_nP8?000ol0003oogl0oomo0002oomo00Kooooo0_nP8?0Poooo
o`03o`000?oooooooooo017ooooo000?ooooo`03o`000?oooooooooo04?ooooo0_nP8?000ol0003o
X23`oj0Pl009ooooo`;oX23`4oooool2oomo0003oooooonP8?3oX23`00Oooooo00?oogl0oj0Pl?nP
8?002?ooool2oj0Pl0?oogl000Cooooooomo0?ooO`3ooooo0oooO`08ooooo`;oX23`00?ooooooj0P
l?nP8?003?ooool2oomo00Gooooo0_ooO`04ooooo`;oX23`0oooool2oj0Pl004o`000?ooooooogl0
oomo00Cooooo0_ooO`04ooooo`;oogl00oooool2o`0000;oX23`00Cooooooomo0?ooO`3oogl01Ooo
ool2oomo00?ooooo0_nP8?0Mooooo`03o`000?oooooooooo017ooooo000?ooooo`03o`000?oooooo
oooo04Kooooo0_nP8?0Booooo`;oogl000CoX23`oooooonP8?3oX23`1_ooool2oomo0004oooooonP
8?3oX23`ooooo`;oogl00_ooool2oomo00Oooooo0_nP8?04ooooo`;oogl00_ooool2oomo0004oooo
ooooO`3oogl0oomo00Cooooo0_nP8?05ooooo`;oX23`00?ooooooomo0?ooO`000_ooO`000ooooooo
ogl0oomo0002oomo00;ooooo0_ooO`05ooooo`;oogl01?ooool3oj0Pl006oooooonP8?3oX23`oj0P
l?l0003ooooo0_nP8?001?ooO`3oooooooooooooool2oomo00?ooooo0_ooO`02o`0000;oX23`00Co
oooooomo0?ooO`3oogl02Oooool2oomo00?ooooo0_nP8?0Mooooo`03o`000?oooooooooo017ooooo
000?ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01Oooool2oj0Pl0[ooooo0onP
8?000oooooooX23`oj0Pl006ooooo`;oX23`00Cooooooj0Pl?nP8?3ooooo0_ooO`02ooooo`;oogl0
1oooool2oj0Pl0;oogl00_nP8?05ooooo`;oogl00oooool2oj0Pl004oomo0?ooooooX23`oj0Pl0Go
oooo0_nP8?000oooooooogl0oomo0002oomo0003ooooooooO`3oogl000;oogl00_ooool2oomo0003
oj0Pl?oooooooooo00Wooooo0_nP8?001_ooooooX23`oj0Pl?nP8?3o0000ooooo`;oX23`0_ooO`06
ooooo`03oj0Pl?ooO`3oogl000KoX23`0_ooO`0>ooooo`;oogl07Oooool00ol0003oooooooooo`0A
ooooo`003oooool00ol0003oooooooooo`17ooooo`04o`000?ooooooX23`oj0Pl0?ooooo0_nP8?0:
ooooo`CoX23`00?oogl0oj0Pl?nP8?000_nP8?000oooooooogl0oomo0002oj0Pl004oooooonP8?3o
X23`oomo00oooooo0_ooO`02oj0Pl0Cooooo0oooO`03ooooo`;oX23`1?ooO`04ooooo`;oogl01_oo
ool00oooO`3oX23`oj0Pl002oomo0005ooooooooO`3oogl0oomo0?nP8?000_ooO`02oj0Pl0Sooooo
0_nP8?03ooooo`04o`000?ooO`3ooooooj0Pl0;oogl00oooool3o`000003oj0Pl?ooO`3oogl000?o
X23`00?ooooooj0Pl?nP8?00;oooool00ol0003oooooooooo`0Aooooo`003oooool00ol0003ooooo
ooooo`18ooooo`?oX23`2oooool2oj0Pl0Cooooo0_nP8?001?ooO`3oX23`oj0Pl?ooO`02oj0Pl0So
ogl000?ooooooomo0?ooO`005?ooool2oomo00;oX23`00Coogl0oooooooooooooooo1OooO`02oooo
o`?oogl01_ooool00oooO`3oX23`oj0Pl009oomo00;oX23`2?ooool2oj0Pl0?ooooo00?o0000oomo
0?nP8?000oooool3o`0000kooooo0_ooO`0/ooooo`03o`000?oooooooooo013ooooo000>ooooo`03
o`000?oooooooooo04Wooooo1?nP8?0:ooooo`;oX23`0oooool2oj0Pl0;ooooo0_nP8?001OooO`3o
X23`oj0Pl?nP8?3ooooo00Coogl00oooool2oomo00_ooooo0_ooO`03ooooo`;oX23`1?ooool2oj0P
l003oomo0?ooooooogl000;oogl00_nP8?08oomo00Oooooo1OooO`000oooooooogl0oomo0006oooo
o`;oX23`00?oogl0ooooooooool01_ooool01?l0003oX23`oj0Pl?l00002oomo00Kooooo0_ooO`05
ooooo`;oogl00_ooool01?ooO`3oX23`oj0Pl?ooool4oomo00[ooooo0_nP8?0Jooooo`03o`000?oo
oooooooo013ooooo000>ooooo`03o`000?oooooooooo04[ooooo0onP8?0:ooooo`;oX23`0oooool6
oj0Pl004oooooonP8?3oX23`oj0Pl0?ooooo0onP8?05ooooo`;oX23`2?ooool2oomo00;ooooo00?o
ogl0oj0Pl?nP8?001Oooool2oomo0004ooooooooO`3oogl0oomo00;oX23`0_ooool6oomo0003oooo
ooooO`3oogl000Cooooo1?ooO`02ooooo`;oogl01_ooool2oj0Pl003oomo0?oooooooooo00;ooooo
0_ooO`02ooooo`04o`000?nP8?3o0000ooooo`;oogl01Oooool2oj0Pl003oomo0?oooooooooo00?o
oooo0_ooO`03ooooo`;oX23`00?ooooooj0Pl?nP8?000_ooO`0:ooooo`;oX23`6_ooool00ol0003o
ooooooooo`0@ooooo`003_ooool00ol0003oooooooooo`1:ooooo`;oX23`00?o0000ooooooooool0
0_nP8?06ooooo`;oX23`1Oooool2oj0Pl0?ooooo0_nP8?05ooooo`?oX23`1?ooool2oj0Pl0cooooo
0_ooO`06ooooo`?oogl01_ooool2oomo00;oX23`00?oogl0ooooooooO`001OooO`02oj0Pl004oooo
ooooO`3oogl0oomo00;ooooo0_ooO`08ooooo`Koogl00_nP8?02o`000003oj0Pl?ooO`3ooooo00;o
X23`1Oooool2oj0Pl0Wooooo0_ooO`000oooooooogl0oomo0002oj0Pl0;oogl01?ooool3oomo00;o
X23`7Oooool00ol0003oooooooooo`0@ooooo`003_ooool00ol0003oooooooooo`1=ooooo`04o`00
0?ooooooX23`oj0Pl1?ooooo0_nP8?000oooooooogl0oomo0002ooooo`;oX23`3_ooool2oomo00Ko
oooo0_nP8?02oomo0004ooooooooO`3oogl0oomo00Gooooo0_ooO`02oj0Pl0;ooooo1_ooO`001?nP
8?3oogl0oomo0?ooool2oomo00cooooo1_ooO`02oj0Pl005ooooool0003oogl0oomo0?ooool00_nP
8?0@ooooo`;oogl000?ooooooomo0?ooO`000_ooool2oomo00?ooooo1?ooO`02oj0Pl003oooooonP
8?3oX23`01[ooooo00?o0000ooooooooool04?ooool000kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0;ooooo`;oX23`0_ooool2oj0Pl0;ooooo0_nP8?000oooooooogl0oomo000:
ooooo`;oX23`1_ooool2oomo00Kooooo0_nP8?02oomo00;ooooo0_ooO`000oooooooogl0oomo0003
ooooo`;oX23`2Oooool01?nP8?3oogl0oomo0?ooO`0<ooooo`;oogl00ol000000oooooooX23`oj0P
l003oj0Pl004o`000?nP8?3oooooooooo`;oogl00oooool2oj0Pl003oooooonP8?3oX23`00Sooooo
0_ooO`03ooooo`?oogl01?ooool2oomo00Gooooo0_nP8?0Jooooo`03o`000?oooooooooo013ooooo
000>ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool02_ooool2oj0Pl0;ooooo0_nP
8?08ooooo`;oogl00oooool2oj0Pl0;ooooo0_nP8?02ooooo`;oogl01oooool2oomo00[ooooo0_oo
O`02ooooo`;oogl000?oX23`ooooooooool01OooO`000oooooooogl0oomo0004oomo00[ooooo00?o
0000oomo0?ooO`000_nP8?03ooooo`GoX23`00?o0000oomo0?ooool00_ooO`000onP8?3ooooooomo
0002oj0Pl003oooooonP8?3oX23`00Cooooo0_nP8?02ooooo`?oogl00_ooool3oomo00?ooooo0ooo
O`04ooooo`;oogl06oooool00ol0003oooooooooo`0@ooooo`003Oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo01Oooooo0_ooO`03ooooo`;oX23`0_ooool2oomo00;ooooo0_ooO`07
ooooo`;oogl01_ooool2oj0Pl0Kooooo0_ooO`000onP8?3ooooooomo0005oomo0003ooooooooO`3o
ogl000Coogl01Oooool2oj0Pl0?o00000oooool2oj0Pl0Sooooo00Co0000oj0Pl?oooooooooo0_nP
8?000oooooooogl0oomo0008ooooo`;oX23`0_ooool3oomo00?ooooo1?ooO`001?ooooooogl0oomo
0?ooO`04ooooo`;oogl000?ooooooomo0?ooO`000oooool2oomo01Cooooo00?o0000ooooooooool0
3oooool000gooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0=ooooo`;oX23`1ooo
ool3oj0Pl0Kooooo0_ooO`0Cooooo`;oX23`1_ooool3oj0Pl004ooooooooO`3oX23`oj0Pl0;oogl0
00CoX23`oomo0?oooooooooo2OooO`02oj0Pl0;ooooo00?oX23`oomo0?ooO`002oooool00ol0003o
X23`ooooo`04ooooo`;oX23`0_ooool4oomo00cooooo1?ooO`03ooooo`;oogl00oooool4oomo00;o
X23`0_ooool2oomo01Cooooo00?o0000ooooooooool03oooool000gooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`0<ooooo`CoX23`00?ooooooj0Pl?nP8?000_ooool3oj0Pl0Cooooo
0_nP8?0Booooo`;oogl000?ooooooj0Pl?nP8?001oooool2oomo0004oooooonP8?3oX23`ooooo`;o
ogl000?oX23`oomo0?ooO`000oooool5oomo00;oX23`0_ooO`02ooooo`03oj0Pl?ooO`3oogl000_o
oooo00Co0000oooooooooooooooo0_nP8?000oooooooX23`oj0Pl002oj0Pl0Coogl02oooool2oomo
00Cooooo0oooO`02oj0Pl0;ooooo1?ooO`02oj0Pl1Sooooo00?o0000ooooooooool03oooool000go
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0=ooooo`GoX23`2Oooool2oj0Pl0Ko
oooo0_nP8?0:ooooo`;oogl00oooool2oomo00Gooooo0_ooO`000oooooooX23`oj0Pl003oomo00;o
X23`0oooO`001?ooooooogl0oomo0?ooO`02ooooo`;oX23`0_ooO`02oj0Pl003oooooonP8?3oX23`
00Oooooo0_ooO`02ooooo`04o`000?ooooooooooooooo`;oX23`0oooool2oj0Pl0;oogl03Oooool2
oomo00;ooooo0_nP8?02oomo0003oooooonP8?3oX23`00;oX23`00?ooooooomo0?ooO`000oooO`02
ooooo`;oogl05?ooool00ol0003oooooooooo`0?ooooo`003Oooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo00Kooooo0_nP8?05ooooo`;oX23`2Oooool2oj0Pl0Sooooo0_nP8?0?oooo
o`;oogl01?ooool2oomo00?ooooo1?ooO`000onP8?3oogl0oomo0006oomo00Kooooo0_ooO`04oooo
o`Coogl00_ooool2oomo00;ooooo00?o0000ooooooooool00_ooO`06ooooo`;oogl04Oooool2oj0P
l0?ooooo0_ooO`02oj0Pl003ooooooooO`3oogl000?oogl00_ooool2oomo01Cooooo00?o0000oooo
ooooool03oooool000gooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`05ooooo`;o
X23`4?ooool2oj0Pl0Wooooo0_nP8?0=ooooo`?oogl00_ooool4oomo0003ooooooooO`3oogl000;o
oooo0_ooO`001?l0003oogl0oomo0?ooool3oomo0004ooooooooO`3oogl0ooooo`Koogl01?ooool4
oomo00?ooooo0_nP8?001?ooO`3o0000ooooooooool2oomo0003ooooooooO`3oogl001kooooo1?oo
O`001?ooooooogl0oj0Pl?nP8?0Gooooo`03o`000?oooooooooo00oooooo000<ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool08Oooool2oj0Pl0cooooo0_nP8?06oomo0003oooooooo
O`3oogl000;oogl01?l00004ooooo`;oogl00_ooool7oomo0004oooooonP8?3oogl0oomo00;ooooo
0_ooO`05ooooo`;oX23`00?oogl0o`000?ooool01?ooool2oomo00Gooooo0_nP8?0?ooooo`;oogl0
1_ooool3oomo00;ooooo00Coogl0oj0Pl?nP8?3ooooo0oooO`02oj0Pl17ooooo00?o0000oooooooo
ool03oooool000cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Dooooo`;oX23`
00Cooooooj0Pl?nP8?3ooooo0_ooO`02ooooo`CoX23`00Cooooooomo0?ooO`3ooooo1_ooO`02oooo
o`;oX23`0_ooool3oomo00;oX23`0_ooO`02o`0000[ooooo0_ooO`000oooooooogl0oomo0005oooo
o`04oj0Pl?ooO`3oogl0ooooo`;oogl000?ooooooomo0?ooO`001Oooool00oooO`3o0000ooooo`09
ooooo`;oogl00_nP8?07ooooo`;oogl01_ooool2oomo00Oooooo0_ooO`02ooooo`;oX23`00?oogl0
ooooooooO`000_ooO`02oj0Pl17ooooo00?o0000ooooooooool03oooool000cooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0Cooooo`;oX23`00Cooooooj0Pl?nP8?3oX23`0_ooO`02
ooooo`;oX23`00?ooooooj0Pl?nP8?000_ooO`000oooooooogl0oomo0004oomo0003ooooooooO`3o
ogl000Kooooo0_nP8?000oooO`3oooooooooo`07ooooo`;oogl00_ooool2oomo00;ooooo0_ooO`03
ooooo`Coogl000Cooooooomo0?ooO`3ooooo0_ooO`06ooooo`03o`000?oooooooooo00?ooooo0_nP
8?03ooooo`;oogl02Oooool3oomo00Wooooo0_ooO`02ooooo`?oogl000?ooooooomo0?nP8?000onP
8?000oooooooogl0oomo000Dooooo`03o`000?oooooooooo00kooooo000<ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool05?ooool6oj0Pl0Gooooo0_nP8?08ooooo`?oogl00_nP8?03
oomo00;o000000Cooooooomo0?ooO`3ooooo0oooO`03ooooo`;oX23`0_ooO`02ooooo`;oogl00_oo
ool2oomo0003ooooooooO`3oogl000Coogl01oooool2oomo00?ooooo00?o0000ooooooooool00ooo
ool2oj0Pl0Wooooo0_ooO`02ooooo`;oX23`0_ooO`09ooooo`;oogl00_ooool3oomo0004oooooooo
O`3oogl0ooooo`;oX23`00Cooooooomo0?ooO`3oogl04oooool00ol0003oooooooooo`0>ooooo`00
3?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00cooooo0_nP8?05ooooo`;oX23`
0_ooool2oj0Pl0;ooooo0oooO`0:ooooo`?oogl00_nP8?05oomo00Cooooo0oooO`02ooooo`03oomo
0?nP8?3oX23`00?oogl01Oooool8oomo00Sooooo0_ooO`03ooooo`03o`000?oooooooooo00kooooo
0_ooO`02ooooo`;oX23`4_ooool6oomo00;ooooo0_ooO`03ooooo`;oX23`3_ooool00ol0003ooooo
ooooo`0>ooooo`003?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00_ooooo0_nP
8?0;ooooo`;oX23`0oooO`03ooooo`;oogl00_nP8?02oomo00;ooooo1?ooO`03ooooo`;oogl000?o
oooooomo0?ooO`000_ooool2oj0Pl0;ooooo0_ooO`001?ooooooogl0oomo0?ooO`05ooooo`Koogl0
1?ooool2oj0Pl0Wooooo00Go0000oj0Pl?nP8?3oX23`ooooo`02oomo00;oX23`3oooool2oomo00oo
oooo1_ooO`07ooooo`;oX23`3_ooool00ol0003oooooooooo`0>ooooo`003?ooool00ol0003ooooo
ooooo`1Nooooo`03o`000?oooooooooo00_ooooo0_nP8?06ooooo`;oogl00_ooool2oj0Pl0Kooooo
0_ooO`02oj0Pl0;oogl00_l00002oomo0003ooooooooO`3oogl000?ooooo0_nP8?02oomo00Wooooo
1?ooO`000oooooooogl0oomo0002ooooo`;oogl01oooool2oj0Pl0Wooooo00Go0000oj0Pl?nP8?3o
X23`ooooo`02oomo00;oX23`3oooool2oomo0003oj0Pl?oooooooooo00Gooooo0_ooO`05ooooo`Ko
ogl00_nP8?02ooooo`;oogl000?ooooooj0Pl?nP8?000_nP8?0<ooooo`03o`000?oooooooooo00ko
oooo000;ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool02_ooool2oj0Pl0Kooooo
0_ooO`0;ooooo`?oX23`00Ko0000oooooonP8?3oX23`oooooonP8?03oomo0003ooooooooO`3oogl0
00;oX23`0_ooO`09ooooo`Coogl000?ooooooomo0?ooO`002oooool2oj0Pl0;oogl01oooool00ol0
003oooooooooo`05ooooo`;oX23`3oooool2oj0Pl003oooooonP8?3oX23`00Cooooo1?ooO`03oooo
o`Coogl00_ooool2oj0Pl004ooooooooO`3oogl0oomo00?ooooo0_nP8?0<ooooo`03o`000?oooooo
oooo00kooooo000;ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool06_ooool2oj0P
l003o`000?nP8?3oX23`00;oX23`0_ooool2oj0Pl0Coogl00_ooool2oomo0004ooooooooO`3oogl0
oomo00Kooooo0_ooO`000oooooooogl0oomo0007ooooo`;oX23`0_ooool2oomo00?ooooo0_nP8?04
oomo00Gooooo00?o0000ooooooooool01Oooool2oj0Pl004oomo0?ooooooogl0oomo00Wooooo0_oo
O`03ooooo`;oX23`1Oooool3oomo00Kooooo0_ooO`001?ooooooogl0oj0Pl?nP8?02oomo01;ooooo
00?o0000ooooooooool03_ooool000_ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0Gooooo`CoX23`00?ooooooj0Pl?nP8?000oooool2oj0Pl004ooooooooO`3oogl0ooooo`;oX23`
0oooO`001?ooooooogl0oomo0?ooO`02ooooo`;oX23`0_ooool6oomo00;ooooo0_ooO`02ooooo`;o
X23`0_ooool2oomo00Oooooo1?ooO`03ooooo`03o`000?oooooooooo00Kooooo0_ooO`000ooooooo
ogl0oomo0009ooooo`;oogl02_ooool2oomo00Kooooo0_nP8?000oooO`3ooooooomo0002oj0Pl003
oomo0?oooooooooo01;ooooo00?o0000ooooooooool03Oooool000_ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0@ooooo`;oX23`0_ooool01?l0003oogl0oomo0?nP8?02oomo00?o
oooo0_nP8?001?ooooooX23`oj0Pl?ooool4oomo0003oj0Pl?ooO`3oogl000;ooooo0_ooO`02oj0P
l003oooooonP8?3oX23`00?ooooo0_ooO`000oooooooogl0oomo0004oomo00Gooooo0_nP8?03oooo
o`;oogl01Oooool2oomo00?ooooo00?oogl0o`000?ooool00_ooO`0Tooooo`;oogl00_nP8?03oooo
o`?oogl00_nP8?0Booooo`03o`000?oooooooooo00gooooo000;ooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool03oooool2oj0Pl0;o000000Cooooooomo0?ooO`3oX23`1?ooool4oj0P
l003ooooooooO`3oogl000Googl000?ooooooomo0?ooO`000oooO`03oj0Pl0Cooooo1?ooO`001?oo
ooooogl0oomo0?ooO`04ooooo`;oX23`00?ooooooj0Pl?nP8?000oooool2oomo00?ooooo0_nP8?05
ooooo`03oomo0?l0003ooooo00;oogl01?ooool2oj0Pl0Gooooo0_ooO`05ooooo`;oogl02oooool4
oomo0003ooooooooO`3oogl000Gooooo0oooO`02oj0Pl1;ooooo00?o0000ooooooooool03Oooool0
00_ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0<ooooo`?o00000oooool2oj0P
l0Gooooo0oooO`02oj0Pl003ooooooooO`3oogl000;oogl00_nP8?0:oomo00Cooooo1?ooO`001?oo
ooooogl0oomo0?ooO`02ooooo`CoX23`0_ooO`09ooooo`;oX23`1_ooool00ol0003ooooooomo0002
oomo00?ooooo0_nP8?02oomo00?ooooo0_ooO`05ooooo`;oogl01_ooool2oomo00?ooooo1?ooO`04
ooooo`;oogl00_ooool3oomo00Kooooo0_nP8?000oooooooogl0oomo0009ooooo`03o`000?oooooo
oooo00gooooo000:ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool02?ooool3o`00
00Kooooo0_nP8?05ooooo`?oogl00_ooool2oj0Pl003oooooonP8?3oX23`00;oX23`0oooO`001Ooo
ooooogl0oomo0?ooO`3ooooo00;oogl01_ooool4oomo00Cooooo1?nP8?04oomo0003oj0Pl?oooooo
oooo00?ooooo1OooO`04ooooo`03o`000?ooooooogl000;oogl01Oooool2oomo00;ooooo0oooO`0=
ooooo`Coogl02Oooool2oomo00;ooooo0_ooO`000oooooooogl0oomo0003oomo0004oooooonP8?3o
X23`ooooo`;oogl02Oooool00ol0003oooooooooo`0=ooooo`002_ooool00ol0003oooooooooo`1X
ooooo`03o`000?oooooooooo00Cooooo0ol0000:ooooo`;oX23`0_ooool2oj0Pl0Gooooo1onP8?00
1?ooooooogl0oomo0?ooool3oomo00Wooooo1?ooO`06ooooo`;oX23`00Gooooooomo0?ooO`3oogl0
oj0Pl004ooooo`03oj0Pl?ooO`3oogl000?oogl01?ooool00ol0003oooooooooo`08ooooo`;oogl0
00?ooooooomo0?ooO`003_ooool4oomo00gooooo2OooO`02oj0Pl0cooooo00?o0000ooooooooool0
3Oooool000[ooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`03o`0000gooooo0_nP
8?02ooooo`;oX23`1Oooool2oomo00CoX23`1_ooO`000onP8?3oogl0ooooo`08ooooo`;oX23`2?oo
O`03ooooo`05oj0Pl?ooO`3oogl0oomo0?ooool00_ooO`000oooooooX23`oj0Pl005ooooo`;oX23`
00?oooooo`000?ooO`001oooool2oj0Pl0;oogl000Cooooooomo0?ooO`3ooooo0_ooO`0;ooooo`Co
ogl01Oooool2oomo00Gooooo1OooO`02oj0Pl003ooooooooO`3oogl000;oX23`0_ooool2oomo00So
oooo00?o0000ooooooooool03Oooool000[ooooo00?o0000ooooooooool0J_ooool2o`0001gooooo
0_ooO`02ooooo`Koogl000?oX23`oomo0?ooool00_ooool2oomo00Cooooo0onP8?000oooooooogl0
oomo0004oomo00?ooooo0_nP8?000oooO`3oX23`oj0Pl004oomo0003ooooooooO`3oogl000?ooooo
0_nP8?001?oooooo0000oomo0?ooO`05ooooo`03oomo0?nP8?3oX23`00?ooooo0_ooO`02oj0Pl0?o
ogl02oooool2oomo0003oj0Pl?oooooooooo00;ooooo0_ooO`05ooooo`;oogl00oooool2oj0Pl0Co
oooo0_ooO`000oooooooogl0oomo0009ooooo`03o`000?oooooooooo00cooooo000:ooooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool08_ooool3oomo0003oj0Pl?oooooooooo00?ooooo
0_ooO`02oj0Pl0Cooooo0_ooO`03ooooo`;oX23`1Oooool4oj0Pl0Ooogl000Cooooooomo0?ooO`3o
oooo0ol00002oomo00Gooooo0_ooO`02ooooo`KoX23`0oooO`05ooooo`;oogl01?ooool00oooO`3o
X23`oj0Pl00Fooooo`;oogl03?ooool00ol0003oooooooooo`0<ooooo`002_ooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooooooo01Sooooo0_nP8?08ooooo`;oogl00_ooool00onP8?3oogl0
oomo0003oomo0004oooooonP8?3oX23`oj0Pl0?ooooo0oooO`02ooooo`;oogl00_nP8?02oomo0003
oooooonP8?3oX23`00;ooooo0_nP8?001?ooooooogl0oomo0?ooO`02ooooo`?o00000_ooool00ol0
003oooooooooo`05ooooo`;oogl00_ooool2oj0Pl0;oogl000?oX23`ooooooooO`000_ooO`000ooo
ooooX23`oj0Pl002ooooo`Koogl01?ooool00oooO`3oX23`oj0Pl00Pooooo`03o`000?oooooooooo
00cooooo000:ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool06?ooool5oj0Pl0Go
oooo0_nP8?02ooooo`03oj0Pl?ooO`3oogl000?oogl000KoX23`oooooonP8?3oX23`oomo0?ooool4
oomo00;ooooo0_ooO`02oj0Pl0;oogl000?ooooooomo0?ooO`000_ooool2oj0Pl0?ooooo0ol00000
0oooooooogl0oomo0002ooooo`03oomo0?l0003ooooo00Cooooo1OooO`001Oooooooogl0oomo0?oo
O`3oX23`00;ooooo0_ooO`000oooooooX23`oj0Pl004ooooo`Koogl00_ooool00oooO`3oX23`oj0P
l005ooooo`;oogl01Oooool2oomo00Cooooo0_ooO`0<ooooo`03o`000?oooooooooo00cooooo0009
ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool05Oooool4oj0Pl004oooooonP8?3o
X23`oj0Pl0Kooooo0_ooO`02ooooo`?oogl000?ooooooj0Pl?nP8?000_ooool5oomo00_ooooo0_oo
O`001?ooooooogl0oomo0?ooool3o`000004ooooooooO`3oogl0ooooo`;oX23`0_ooool2oomo0003
o`000?oooooooooo00;ooooo0_ooO`001?nP8?3oogl0oomo0?ooool4oomo00;oX23`00Cooooooj0P
l?nP8?3ooooo0_nP8?07ooooo`;oogl00_ooool2oomo00;ooooo0_nP8?000oooooooogl0oomo0002
oomo00Cooooo0oooO`03ooooo`;oogl03?ooool00ol0003oooooooooo`0<ooooo`002Oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo01Gooooo1?nP8?05ooooo`;oX23`00?ooooooomo
0?ooO`000_ooO`02ooooo`?oogl00oooool6oomo00Cooooo0oooO`02ooooo`;oogl01?ooool3o`00
00Cooooo0_nP8?001?ooooooX23`oj0Pl?nP8?02oomo00;ooooo00Co0000oooooooooooooooo0_oo
O`03oj0Pl0?ooooo0_ooO`02oj0Pl004oooooonP8?3oX23`ooooo`;oX23`00?ooooooomo0?ooO`00
0_ooool2oomo00Sooooo0_nP8?000oooooooogl0oomo0002oomo00Gooooo0_ooO`0Aooooo`03o`00
0?oooooooooo00cooooo0009ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool07_oo
ool3oj0Pl0Coogl00_ooool5oomo0003ooooooooO`3oogl000;ooooo1?ooO`02ooooo`Ooogl01?l0
0002oomo00Gooooo0_nP8?03ooooo`04oj0Pl?ooO`3oogl0oomo00;ooooo00Co0000oomo0?ooO`3o
ogl00_ooool2oj0Pl003ooooooooO`3oogl000;oogl02Oooool2oomo00;ooooo0_ooO`05ooooo`;o
ogl000?ooooooj0Pl?nP8?002Oooool2oj0Pl0?oogl03oooool00ol0003oooooooooo`0<ooooo`00
2Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01kooooo0onP8?06ooooo`Soogl0
00?ooooooomo0?ooO`001_ooO`000oooooooogl0oomo0003o`000003oomo0?oooooooooo00Oooooo
0_ooO`06ooooo`?oogl000?oooooo`000?ooO`000_ooO`05ooooo`;oogl05_ooool2oomo0003oooo
oonP8?3oX23`00Wooooo0_nP8?03oomo00oooooo00?o0000ooooooooool03?ooool000Wooooo00?o
0000ooooooooool0Joooool00ol0003oooooooooo`0Nooooo`?oX23`1_ooool2oomo00;oX23`3Ooo
O`03o`0000;ooooo0_ooO`06ooooo`;oogl000Cooooooomo0?ooO`3ooooo0_nP8?04ooooo`;oogl0
00?ooooooomo0?l000004Oooool2oj0Pl1Sooooo0_ooO`06ooooo`;oogl03Oooool00ol0003ooooo
ooooo`0;ooooo`002Oooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo01kooooo0onP
8?0:ooooo`;oX23`0oooO`000oooooooogl0oomo0002oj0Pl0?o00000_nP8?02oomo00Wooooo0_oo
O`04ooooo`;oX23`1oooool2oomo0003o`000?oooooooooo00_ooooo0_ooO`000oooooooX23`oj0P
l00@ooooo`;oogl00oooool2oomo0003ooooooooO`3oogl000Kooooo0_ooO`0=ooooo`03o`000?oo
oooooooo00_ooooo0008ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool07oooool2
oj0Pl0Oooooo0_nP8?000oooooooX23`oj0Pl003oomo0003ooooooooO`3o000000;o00000oooO`02
oj0Pl0Coogl03_ooool2oomo00Wooooo00?o0000ooooooooool01_ooool2oomo00;ooooo0_ooO`0C
ooooo`;oogl00oooool2oomo00Gooooo00?oogl0oj0Pl?nP8?004?ooool00ol0003oooooooooo`0;
ooooo`002?ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo02Sooooo0_nP8?001?oo
ooooogl0oomo0?ooO`04o`0000;ooooo2_ooO`02ooooo`;oogl02?ooool2oj0Pl0;oogl000?ooooo
oomo0?ooO`001oooool01?l0003ooooooj0Pl?nP8?04ooooo`;oogl08oooool00oooO`3oX23`oj0P
l00@ooooo`03o`000?oooooooooo00_ooooo0008ooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool0:oooool3o`0000Coogl000Cooooooomo0?ooO`3ooooo2?ooO`02ooooo`;oogl02?oo
ool2oj0Pl0Googl01_ooool2oomo0003o`000?nP8?3oX23`00;oogl07_ooool2oomo00Oooooo0_oo
O`0Aooooo`03o`000?oooooooooo00_ooooo0008ooooo`03o`000?oooooooooo06cooooo00?o0000
ooooooooool08oooool2oj0Pl0?ooooo0ol000000oooooooogl0oomo0002ooooo`Googl000?ooooo
oomo0?ooO`002?ooO`08ooooo`;oogl00_ooool4oomo00Oooooo0_ooO`000ol0003oooooooooo`02
oomo00Wooooo0_ooO`02ooooo`;oogl02?ooool2oomo00Gooooo0_ooO`0Jooooo`03o`000?oooooo
oooo00_ooooo0008ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool08oooool2oj0P
l0?o000000?ooooooj0Pl?nP8?001?ooool4oj0Pl003oomo0?oooooooooo00;ooooo0_ooO`000ooo
ooooogl0oomo0003oomo0003ooooooooO`3oogl000;oogl00oooool2oomo0003oooooonP8?3oX23`
00Oooooo0_ooO`04ooooo`03o`000?oooooooooo00Gooooo0_ooO`02oj0Pl003ooooooooO`3oogl0
00;ooooo1?ooO`04ooooo`Coogl01?ooool2oj0Pl1?ooooo0_ooO`06ooooo`03o`000?oooooooooo
00_ooooo0008ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool08oooool3o`0000Co
oooo0_nP8?04ooooo`CoX23`0_ooO`000oooooooogl0oomo0002oomo0004ooooooooO`3oogl0oomo
00?ooooo1?ooO`06ooooo`;oX23`1oooool3oomo00Cooooo00?o0000ooooooooool00oooool3oomo
00;oX23`1Oooool2oj0Pl0;oogl01?ooool2oomo00;ooooo0_ooO`02ooooo`;oX23`00?oogl0oooo
ooooool04?ooool2oomo00Oooooo00?o0000ooooooooool02_ooool000Sooooo00?o0000oooooooo
ool0Joooool00ol0003oooooooooo`0Oooooo`Co00001oooool2oj0Pl0Cooooo4?ooO`02ooooo`;o
ogl04_ooool2oomo00Gooooo00?o0000oomo0?ooool00_ooool4oomo00;oX23`1?ooool2oj0Pl0Go
oooo1oooO`000oooooooogl0oomo0002oomo00Kooooo0_ooO`000onP8?3oooooooooo`0@ooooo`03
o`000?oooooooooo00[ooooo0007ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool0
7?ooool3o`0000cooooo0_nP8?04ooooo`Koogl00oooool:oomo01Oooooo0_nP8?000oooO`3o0000
ooooo`04ooooo`;oogl00_nP8?07ooooo`;oX23`0_ooool2oj0Pl003ooooooooO`3oogl000?ooooo
0_ooO`08ooooo`;oogl000?oX23`ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`001ooo
ool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Wooooo0ol0000?ooooo`;oX23`1_oo
ool<oomo0003ooooooooO`3oogl001;ooooo0_nP8?02oomo00?ooooo0_nP8?000ooooooo0000oooo
o`0?ooooo`;oX23`0_ooool2oj0Pl0Gooooo1_ooO`0;ooooo`;oogl03Oooool00ol0003ooooooooo
o`0:ooooo`001oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo01Kooooo0ol00009
ooooo`;oX23`3oooool8oomo0003ooooooooO`3oogl000Gooooo0_nP8?000oooooooogl0oomo0002
oomo00[ooooo0_nP8?02oomo00Oooooo00?o0000oj0Pl?nP8?004?ooool2oj0Pl0Gooooo0oooO`00
1Oooooooogl0oomo0?ooO`3ooooo00;oogl02?ooool2oomo00gooooo00?o0000ooooooooool02_oo
ool000Oooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`0Booooo`Co00003?ooool2
oj0Pl0[ooooo0_nP8?06ooooo`Koogl00_nP8?02ooooo`;oX23`00Cooooooj0Pl?nP8?3ooooo1?oo
O`000oooooooogl0oomo0008ooooo`;oogl01oooool2oj0Pl005o`000?nP8?3ooooooooooonP8?00
0_ooO`03ooooo`;oogl01_ooool2oj0Pl0Gooooo0oooO`05ooooo`;oogl05oooool00ol0003ooooo
ooooo`0:ooooo`001oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00oooooo0ol0
000Looooo`;oX23`1oooool5oomo00;oX23`00Cooooooomo0?ooO`3oX23`2Oooool2oomo00Sooooo
0_ooO`07ooooo`04oj0Pl?ooO`3oogl0o`0000;ooooo00?oX23`oomo0?ooO`000oooool2oomo00co
oooo0_nP8?0Pooooo`03o`000?oooooooooo00[ooooo0007ooooo`03o`000?oooooooooo06cooooo
00?o0000ooooooooool03?ooool3o`0002Sooooo1_ooO`02ooooo`;oogl01Oooool2oomo00oooooo
0_nP8?06ooooo`;oogl000?oooooo`000?ooool01_ooool2oomo00cooooo0_nP8?0Aooooo`;oogl0
3_ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00Wooooo0ol0000Wooooo`;oX23`0_ooool7oomo00CoX23`0_ooool4oomo00oooooo0_nP
8?03ooooo`?oX23`1?ooool00ol0003oooooooooo`04ooooo`;oogl000?ooooooomo0?ooO`000_oo
O`08ooooo`;oogl04?ooool2oomo00kooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000
ooooooooool0KOooool00ol0003oooooooooo`06ooooo`?o0000:_ooool2oj0Pl0;ooooo0oooO`00
1?ooooooogl0oomo0?ooO`05oj0Pl004ooooooooO`3oogl0oomo01Gooooo0onP8?04ooooo`03o`00
0?oooooooooo00Cooooo0_ooO`000oooooooogl0oomo0002oomo00?ooooo0_nP8?03ooooo`;oogl0
8?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`1]ooooo`03o`000?oo
oooooooo00;ooooo1?l0000aooooo`;oogl000?oX23`oomo0?ooO`000oooO`000oooooooogl0oomo
0002oomo0003ooooooooO`3oogl000Gooooo0_ooO`0>ooooo`04oj0Pl?ooO`3oogl0ooooo`;oogl0
00?ooooooomo0?l000001Oooool2oomo00?ooooo0_ooO`02ooooo`;oX23`0_ooO`02ooooo`;oogl0
0_ooool2oomo00Wooooo0_nP8?0Aooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oo
oooooooo06gooooo00?o0000ooooool000000_l0000fooooo`;oX23`2_ooO`08ooooo`;oogl02_oo
ool2oj0Pl003ooooooooO`3oogl000;oogl000Cooooooomo0?ooO`3ooooo0_ooO`000ol0003ooooo
ooooo`07ooooo`;oogl00_ooool2oj0Pl0?oogl000?ooooooomo0?ooO`000_ooool2oomo00Wooooo
0_nP8?0Aooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo06cooooo0ol0
000looooo`Ooogl03_ooool2oomo00Kooooo0_nP8?001?ooooooogl0oomo0?ooO`07ooooo`03oomo
0?l0003ooooo00Gooooo0_ooO`05ooooo`Coogl000?ooooooomo0?ooO`000oooool2oomo01_ooooo
00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0JOooool3o`000003ooooool0
003ooooo03_ooooo0oooO`0;ooooo`;oX23`1_ooool4oomo00[ooooo0_ooO`05ooooo`;oogl000?o
0000ooooooooool00oooool2oomo00Gooooo0oooO`02ooooo`;oogl00oooool2oomo01_ooooo00?o
0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0I_ooool3o`0000Cooooo00?o0000
ooooooooool0>_ooool2oomo00Gooooo0_ooO`05ooooo`;oX23`2?ooool2oomo00Cooooo0_nP8?00
1?ooO`3oooooooooooooool2oomo00Cooooo0oooO`001?l0003oX23`oj0Pl?ooool4oj0Pl0?ooooo
0_nP8?000oooooooogl0oomo0002ooooo`;oogl00_ooool3oomo01cooooo00?o0000ooooooooool0
2?ooool000Gooooo00?o0000ooooooooool0Hoooool4o`0000Oooooo00?o0000ooooooooool0@Ooo
ool2oomo00;ooooo0_ooO`000oooooooX23`oj0Pl002ooooo`;oX23`00?ooooooomo0?ooO`001_oo
ool3oj0Pl003oomo0?oooooooooo00Oooooo0_ooO`001Oooooooogl0o`000?nP8?3ooooo00CoX23`
0_ooO`000oooooooX23`oj0Pl002oomo00Oooooo0_ooO`0Mooooo`03o`000?oooooooooo00Sooooo
0005ooooo`03o`000?oooooooooo063ooooo0ol0000;ooooo`03o`000?oooooooooo04Cooooo0ooo
O`02ooooo`;oogl000Cooooooj0Pl?nP8?3ooooo0_ooO`06ooooo`;oX23`0_ooO`02ooooo`;oX23`
2?ooool2oomo0003o`000?ooO`3oogl000;oogl000?oX23`oomo0?ooO`000oooool5oomo00Gooooo
0_nP8?0Looooo`03o`000?oooooooooo00Sooooo0005ooooo`03o`000?oooooooooo05gooooo0ol0
000>ooooo`03o`000?oooooooooo04Cooooo0_ooO`03ooooo`;oogl000?ooooooomo0?ooO`002ooo
ool2oj0Pl0;ooooo0_nP8?000oooooooogl0oomo0002oomo00?ooooo0_nP8?000ooooooo0000oomo
0002oomo0003oj0Pl?ooO`3oogl000Gooooo0oooO`05ooooo`;oX23`1?ooO`0Hooooo`03o`000?oo
oooooooo00Sooooo0005ooooo`03o`000?oooooooooo05[ooooo0ol0000Aooooo`03o`000?oooooo
oooo047ooooo0_nP8?0;ooooo`;oogl02Oooool2oj0Pl0Gooooo1?ooO`07ooooo`04o`000?oooooo
ooooooooo`;oogl00oooool2oomo00[ooooo1?ooO`0Hooooo`03o`000?oooooooooo00Sooooo0005
ooooo`03o`000?oooooooooo05Oooooo0ol0000Dooooo`03o`000?oooooooooo047ooooo0_nP8?05
ooooo`;oX23`1?ooool2oj0Pl1Sooooo0_ooO`02ooooo`03o`000?oooooooooo00Gooooo0_ooO`0;
ooooo`;oogl06Oooool00ol0003oooooooooo`08ooooo`001Oooool00ol0003oooooooooo`1Coooo
o`Co00005oooool00ol0003oooooooooo`18ooooo`;oX23`1?ooool2oj0Pl0gooooo0_ooO`09oooo
o`;oogl00_nP8?000ol0003oooooooooo`08ooooo`;oogl08oooool00ol0003oooooooooo`08oooo
o`001?ooool00ol0003oooooooooo`1Aooooo`?o00006oooool00ol0003oooooooooo`1<ooooo`;o
X23`0_ooool2oj0Pl0Gooooo0_ooO`03ooooo`;oogl00_nP8?09ooooo`CoX23`00Co0000oooooooo
O`3oogl01_ooool2oomo00;ooooo0_nP8?02oomo01gooooo00?o0000ooooooooool02?ooool000Co
oooo00?o0000ooooooooool0C_ooool3o`0001kooooo00?o0000ooooooooool0C?ooool2oj0Pl0;o
oooo0_nP8?05ooooo`;oogl00oooool2oomo00;oX23`1Oooool2oomo00Oooooo00?o0000oomo0?oo
O`002_ooool2oj0Pl0;oogl01?ooool3oomo00Kooooo0_ooO`02ooooo`;oogl02oooool00ol0003o
ooooooooo`07ooooo`001?ooool00ol0003oooooooooo`1;ooooo`?o00008Oooool00ol0003ooooo
ooooo`17ooooo`;oX23`4Oooool2oj0Pl0Wooooo0_ooO`03ooooo`;oogl00oooool00ol0003oX23`
ooooo`03ooooo`;oX23`00?ooooooomo0?ooO`001_ooool2oomo0004ooooooooO`3oogl0oomo00Ko
oooo0_ooO`02ooooo`;oogl02oooool00ol0003oooooooooo`07ooooo`001?ooool00ol0003ooooo
ooooo`18ooooo`?o00009?ooool00ol0003oooooooooo`17ooooo`;oX23`4Oooool2oj0Pl0kooooo
1?ooO`02ooooo`03o`000?oooooooooo00;ooooo0_nP8?03oomo00Gooooo0oooO`09ooooo`;oogl0
4?ooool00ol0003oooooooooo`07ooooo`001?ooool00ol0003oooooooooo`14ooooo`Co00009ooo
ool00ol0003oooooooooo`1Eooooo`;oogl00onP8?0Booooo`;oogl000?ooooooomo0?l000001Ooo
ool00oooO`3oX23`oj0Pl006ooooo`;oogl02_ooool2oomo013ooooo00?o0000ooooooooool01ooo
ool000Cooooo00?o0000ooooooooool0@Oooool3o`0002_ooooo00?o0000ooooooooool0Boooool2
oj0Pl0?ooooo0_nP8?03ooooo`;oogl01?nP8?03ooooo`;oogl000?ooooooj0Pl?nP8?001_ooool2
oomo0004oj0Pl?ooooooooooooooo`;oogl000?o0000ooooooooool00oooool2oj0Pl0Cooooo0_nP
8?06ooooo`;oogl05_ooool00ol0003oooooooooo`07ooooo`000oooool00ol0003oooooooooo`0o
ooooo`?o0000;_ooool00ol0003oooooooooo`1;ooooo`;oX23`0oooool2oj0Pl004oooooonP8?3o
X23`ooooo`;oogl00onP8?03ooooo`;oogl000?ooooooj0Pl?nP8?001Oooool3oomo0003oj0Pl?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool2oomo0004ooooooooO`3oogl0ooooo`;oX23`
1Oooool2oj0Pl003oomo0?oooooooooo01Cooooo00?o0000ooooooooool01oooool000?ooooo00?o
0000ooooooooool0??ooool3o`00037ooooo00?o0000ooooooooool0D?ooool2oj0Pl004oooooonP
8?3oX23`ooooo`;oogl000Cooooooj0Pl?nP8?3oX23`2Oooool5oomo00Kooooo0_ooO`000ooooooo
0000ooooo`05ooooo`;oogl01oooool3oj0Pl1Oooooo00?o0000ooooooooool01oooool000?ooooo
00?o0000ooooooooool0>Oooool3o`0003?ooooo00?o0000ooooooooool0Eoooool2oomo00KoX23`
1oooool2oomo00;oX23`0_ooool2oomo00;oX23`00?ooooooomo0?ooO`000_ooool00ol0003oX23`
oj0Pl00<ooooo`;oX23`00?ooooooomo0?ooO`005_ooool00ol0003oooooooooo`06ooooo`000ooo
ool00ol0003oooooooooo`0eooooo`Co0000=_ooool00ol0003oooooooooo`1Iooooo`;oX23`00Co
oooooomo0?nP8?3oX23`1_ooool2oomo0003oooooonP8?3oX23`00;ooooo0_ooO`02oj0Pl003oooo
ooooO`3oogl000;oX23`00?oooooo`000?nP8?000oooool2oj0Pl0[ooooo0_ooO`06ooooo`;oX23`
3_ooool00ol0003oooooooooo`06ooooo`000oooool00ol0003oooooooooo`0booooo`?o0000>_oo
ool00ol0003oooooooooo`1Dooooo`;oX23`0oooool2oj0Pl0;ooooo0_nP8?06ooooo`;oogl01ooo
ool2oomo00?ooooo0onP8?000ol0003oogl0ooooo`02oomo00CoX23`0_ooool4oomo00?ooooo1?oo
O`03ooooo`;oX23`00?oogl0ooooooooool02oooool00ol0003oooooooooo`06ooooo`000oooool0
0ol0003oooooooooo`0_ooooo`?o0000?Oooool00ol0003oooooooooo`1Booooo`CoX23`0oooool2
oj0Pl0;ooooo0_nP8?02ooooo`;oX23`1_ooool2oj0Pl0?ooooo0_ooO`000onP8?3oooooooooo`02
ooooo`04oj0Pl?ooO`3o0000ooooo`;oogl000Cooooooj0Pl?nP8?3oX23`0_ooool4oomo00?ooooo
1?ooO`03ooooo`;oX23`00?oogl0ooooooooool02oooool00ol0003oooooooooo`06ooooo`000ooo
ool00ol0003oooooooooo`0/ooooo`?o0000@?ooool00ol0003oooooooooo`1Booooo`;oX23`3Ooo
ool3oj0Pl0Gooooo0_nP8?04ooooo`;oX23`1oooool00ol0003oX23`ooooo`06ooooo`;oX23`0_oo
O`09ooooo`03oomo0?nP8?3oX23`00kooooo00?o0000ooooooooool01_ooool000;ooooo00?o0000
ooooooooool0:Oooool4o`0004?ooooo00?o0000ooooooooool0H_ooool4oj0Pl0;oogl00onP8?0;
ooooo`;oogl000?oX23`o`000?nP8?001_ooool2oj0Pl0;oogl02Oooool00oooO`3oX23`oj0Pl00>
ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03o`000?oooooooooo02Kooooo0ol00017oooo
o`03o`000?oooooooooo06Cooooo0_nP8?02oomo00?oX23`2oooool2oomo0003oooooonP8?3o0000
00Oooooo0_ooO`04ooooo`;oogl01Oooool2oj0Pl0Cooooo1?ooO`06ooooo`03o`000?oooooooooo
00Kooooo0002ooooo`03o`000?oooooooooo02?ooooo0ol0001:ooooo`03o`000?oooooooooo06[o
oooo0_ooO`001?ooooooX23`oj0Pl?ooool2oomo00Kooooo0_nP8?001?l0003oogl0oomo0?ooO`02
ooooo`;oX23`0_ooO`04ooooo`;oogl02?ooool2oomo0003ooooooooO`3oogl000;oogl01oooool0
0ol0003oooooooooo`05ooooo`000_ooool00ol0003oooooooooo`0Pooooo`?o0000COooool00ol0
003oooooooooo`1Zooooo`;oogl000Cooooooj0Pl?nP8?3ooooo0_ooO`06ooooo`;oX23`00Cooooo
o`000?ooO`3oogl00_ooool2oj0Pl0Gooooo0_nP8?05ooooo`;oogl00_ooool4oomo00[ooooo00?o
0000ooooooooool01Oooool000;ooooo00?o0000ooooooooool07Oooool3o`00053ooooo00?o0000
ooooooooool0K_ooool2oj0Pl0;oogl01_ooool2oomo00;ooooo00?o0000ooooooooool02?ooool2
oj0Pl0;ooooo0_nP8?000oooooooogl0oomo0002ooooo`;oX23`0_ooO`000oooooooX23`oj0Pl007
ooooo`03o`000?oooooooooo00Gooooo0002ooooo`03o`000?oooooooooo01Wooooo1?l0001Coooo
o`03o`000?oooooooooo06Kooooo00?oX23`oomo0?ooO`001Oooool2oj0Pl0Oooooo0_ooO`04oooo
o`03o`000?oooooooooo00Gooooo1?ooO`001?nP8?3ooooooj0Pl?nP8?05ooooo`;oX23`00?oogl0
ooooooooool00_nP8?07ooooo`03o`000?oooooooooo00Gooooo00000ooooooo0000ooooo`0Hoooo
o`?o0000Eoooool00ol0003oooooooooo`1Vooooo`04oj0Pl?ooO`3oogl0oomo00gooooo0_ooO`05
ooooo`03o`000?ooO`3ooooo00Cooooo1?ooO`000onP8?3oooooooooo`04ooooo`;oogl000?ooooo
oomo0?ooO`002oooool00ol0003oooooooooo`05ooooo`0000?oooooo`000?ooool05Oooool3o`00
05[ooooo00?o0000ooooooooool0Hoooool2oj0Pl0?ooooo0_ooO`0Dooooo`03oomo0?l0003oogl0
00;oogl02oooool4oomo0003ooooooooO`3oogl000_ooooo00?o0000ooooooooool01Oooool00003
ooooool0003ooooo01;ooooo0ol0001Mooooo`03o`000?oooooooooo06?ooooo0_nP8?03ooooo`;o
ogl00_ooool4oj0Pl0Oooooo0_ooO`06ooooo`04o`000?ooO`3oogl0oomo00Sooooo0_ooO`001?oo
ooooogl0oj0Pl?nP8?02ooooo`;oogl02oooool00ol0003oooooooooo`05ooooo`0000?oooooo`00
0?ooool03oooool3o`00063ooooo00?o0000ooooooooool0J?ooool2oomo0003oooooonP8?3oX23`
00?oX23`1oooool2oomo00?ooooo0_nP8?02ooooo`04o`000?ooO`3oooooooooo`;oX23`1Oooool2
oomo00;ooooo0_nP8?02ooooo`;oogl02oooool00ol0003oooooooooo`05ooooo`0000?oooooo`00
0?ooool02oooool4o`0006?ooooo00?o0000ooooooooool0Joooool2oj0Pl0Cooooo0_ooO`02oooo
o`;oogl01Oooool2oj0Pl0;ooooo00Coogl0o`000?nP8?3ooooo0_nP8?02oomo0003ooooooooO`3o
ogl000Sooooo1?ooO`0:ooooo`03o`000?oooooooooo00Cooooo00000ooooooo0000ooooo`08oooo
o`?o0000Ioooool00ol0003oooooooooo`1[ooooo`;oX23`1?ooool2oomo00;ooooo0_ooO`0:oooo
o`03oj0Pl?l0003ooooo00;ooooo0_ooO`000oooooooogl0oomo0003ooooo`;oX23`1Oooool2oj0P
l0[ooooo00?o0000ooooooooool01?ooool00003ooooool0003ooooo00Gooooo0ol0001Zooooo`03
o`000?oooooooooo06kooooo0_nP8?06ooooo`;oX23`0_ooO`03ooooo`;oogl01?ooool00ol0003o
ogl0ooooo`08ooooo`03oj0Pl?ooO`3oogl000Cooooo0_nP8?0:ooooo`03o`000?oooooooooo00Co
oooo00000ol0003oooooooooo`02ooooo`?o0000KOooool00ol0003oooooooooo`1Xooooo`;oX23`
1?ooool2oj0Pl003ooooooooO`3oogl000;oX23`00?ooooooj0Pl?nP8?000_ooO`03ooooo`;oogl0
0_ooool2oomo0003o`000?ooO`3ooooo00;oogl000?oX23`oomo0?ooO`001?ooool2oomo013ooooo
00?o0000ooooooooool01?ooool00003o`000?oooooo000000;o0000L?ooool00ol0003ooooooooo
o`1Xooooo`;oX23`1oooool2oomo00?oX23`0_ooO`02oj0Pl003oooooonP8?3oX23`00Cooooo0ooo
O`001Ol0003ooooooomo0?ooO`3oX23`00?oogl01_ooool2oomo00;oX23`00?ooooooj0Pl?nP8?00
2?ooool00ol0003oooooooooo`04ooooo`000_l0001cooooo`03o`000?oooooooooo06[ooooo0_nP
8?09ooooo`;oX23`00Coogl0oj0Pl?nP8?3oogl00_nP8?05ooooo`;oogl000?oooooo`000?ooool0
0oooool2oomo00Kooooo0_ooO`02oj0Pl003oooooonP8?3oX23`00Sooooo00?o0000ooooooooool0
1?ooool000;ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`1Pooooo`;oX23`2?oo
ool2oj0Pl0Sooooo0onP8?04oomo00;ooooo0_ooO`06ooooo`03oj0Pl?l0003ooooo00Sooooo0_oo
O`0?ooooo`03o`000?oooooooooo00Cooooo0003ooooo`;o0000L?ooool00ol0003oooooooooo`1P
ooooo`;oX23`4Oooool5oj0Pl003oomo0?oooooooooo00;ooooo0_ooO`05ooooo`;oogl000?oX23`
o`000?ooool01?ooool5oomo00Oooooo0_ooO`07ooooo`03o`000?oooooooooo00?ooooo0005oooo
o`03o`000?oooooooooo06gooooo00?o0000ooooooooool0Loooool6oj0Pl0Sooooo0_ooO`001_nP
8?3oogl0oj0Pl?nP8?3oooooo`0000Cooooo1_ooO`06ooooo`;oogl01oooool00ol0003ooooooooo
o`03ooooo`001_ooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo07Kooooo00?oogl0
oj0Pl?nP8?002?ooool2oomo00CoX23`00?oooooo`000?ooool01?ooool2oomo0004ooooooooO`3o
ogl0oomo00Cooooo1?ooO`06ooooo`03o`000?oooooooooo00?ooooo0007ooooo`;o0000K?ooool0
0ol0003oooooooooo`1iooooo`;oX23`1?ooool2oj0Pl0Cooooo0_nP8?02ooooo`04o`000?oooooo
ooooooooo`;oogl00_ooool5oomo0003oooooonP8?3oogl000?oogl01_ooool00ol0003ooooooooo
o`03ooooo`002Oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo07Wooooo0_nP8?04
ooooo`;oX23`1?ooool2oj0Pl004ooooooooO`3oogl0o`0000;ooooo0_ooO`02ooooo`;oogl000Co
oooooomo0?ooO`3ooooo0_nP8?000oooooooogl0oomo0006ooooo`03o`000?oooooooooo00?ooooo
000:ooooo`;o0000JOooool00ol0003oooooooooo`1iooooo`CoX23`0oooool2oomo00Gooooo0ooo
O`000ooooooo0000ooooo`07ooooo`;oogl03?ooool00ol0003oooooooooo`03ooooo`003?ooool0
0ol0003oooooooooo`1Vooooo`03o`000?oooooooooo07;ooooo0_nP8?06ooooo`?oX23`00?ooooo
oomo0?ooO`000_ooO`05ooooo`;oogl000Gooooooomo0?ooO`3o0000ooooo`02oj0Pl0Coogl03_oo
ool00ol0003oooooooooo`03ooooo`003Oooool2o`0006Gooooo00?o0000ooooooooool0Loooool2
oj0Pl0Oooooo1_nP8?04ooooo`;oogl00_nP8?001Oooooooogl0oomo0?l0003oogl000;oX23`00?o
ogl0oj0Pl?nP8?001?nP8?001?ooooooX23`oj0Pl?ooool4oomo00Cooooo00?o0000ooooooooool0
0_ooool000oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1mooooo`SoX23`00?o
oooooomo0?nP8?000_nP8?001Oooooooogl0oomo0?oooooo000000;oX23`00?ooooooj0Pl?nP8?00
1?nP8?001?ooO`3oX23`oj0Pl?ooool4oomo00Cooooo00?o0000ooooooooool00_ooool0013ooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`1mooooo`?oX23`00?ooooooj0Pl?nP8?00
0_nP8?02ooooo`;oX23`00Cooooooomo0?ooO`3oogl00_ooool01Ol0003oogl0oomo0?ooO`3ooooo
00;oX23`0_ooO`05oj0Pl003oomo0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0017o
oooo0_l0001Qooooo`03o`000?oooooooooo083ooooo2onP8?000oooO`3oooooooooo`02oomo0003
o`000?nP8?3oogl000?oX23`0_ooO`05oj0Pl003oomo0?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool001?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`20ooooo`_oX23`
0oooool01OooO`3oX23`oj0Pl?l0003oogl000GoX23`00?oogl0ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`005?ooool2o`0005kooooo00?o0000ooooooooool0P?ooool;oj0Pl0Coogl0
0onP8?000ol0003oX23`oj0Pl003oj0Pl0?oogl00_nP8?02oomo00Gooooo00?o0000ooooooooool0
0_ooool001Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`20ooooo`_oX23`00?o
ogl0oj0Pl?ooO`001?nP8?000ol0003oogl0oomo0006oomo00;oX23`0_ooO`05ooooo`03o`000?oo
oooooooo00;ooooo000Gooooo`;o0000Foooool00ol0003oooooooooo`22ooooo`_oX23`00?oogl0
oj0Pl?nP8?000oooO`000ol0003oogl0oj0Pl002oomo00?ooooo0_ooO`08ooooo`03o`000?oooooo
oooo007ooooo000Iooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0QOooool7oj0P
l0Coogl00_nP8?02oomo0003o`000?nP8?3oogl000Googl00_nP8?07ooooo`03o`000?oooooooooo
007ooooo000Jooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0Q_ooool2oj0Pl0?o
ogl00_nP8?03oomo00?oX23`00?oogl0oj0Pl?l000001_ooO`03oj0Pl003oomo0?oooooooooo00?o
oooo00?o0000ooooooooool00Oooool001_ooooo0_l0001Gooooo`03o`000?oooooooooo08Oooooo
0_nP8?03oomo00;oX23`0_ooO`02ooooo`CoX23`00Go0000oooooooooooooooooomo0004oj0Pl003
oomo0?oooooooooo00?ooooo00?o0000ooooooooool00Oooool001gooooo00?o0000ooooooooool0
E?ooool00ol0003oooooooooo`28ooooo`?oogl02_nP8?000oooO`3o0000oomo0003oomo00CoX23`
00?oogl0ooooooooool00oooool00ol0003oooooooooo`01ooooo`007_ooool2o`0005Cooooo00?o
0000ooooooooool0Roooool9oj0Pl0?oogl000Co0000oomo0?ooO`3ooooo1?nP8?06ooooo`03o`00
0?oooooooooo007ooooo000Pooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool0R_oo
ool2oj0Pl003oooooonP8?3oX23`00;oogl00onP8?02oomo00;oX23`00?o0000ooooooooool00_nP
8?08ooooo`03o`000?oooooooooo007ooooo000Qooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0R_ooool3oj0Pl004oooooonP8?3oogl0oomo00?oX23`0_ooool2oj0Pl003ooooool0
003ooooo00?ooooo0_ooO`000oooooooogl0oomo0002ooooo`03o`000?oooooooooo007ooooo000R
ooooo`;o0000D?ooool00ol0003oooooooooo`2;ooooo`;oX23`0_ooool2oj0Pl0;oogl01?nP8?03
ooooo`04o`000?ooO`3oogl0ooooo`;oogl000?ooooooomo0?ooO`000oooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2>ooooo`?oX23`0_ooool6
oj0Pl0;ooooo00?o0000oomo0?ooool01?ooool3oj0Pl003ooooool0003ooooo007ooooo000Uoooo
o`;o0000COooool00ol0003oooooooooo`2>ooooo`;oX23`1_ooool00oooO`3oX23`oj0Pl002oooo
o`03o`000?ooO`3ooooo00?ooooo1?nP8?000ooooooo0000ooooo`01ooooo`009oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo09?ooooo0_nP8?03ooooo`;oogl000?ooooooomo0?l0
00000_ooO`000oooooooogl0oj0Pl003oj0Pl003ooooool0003ooooo007ooooo000Xooooo`;o0000
B_ooool00ol0003oooooooooo`2?ooooo`;oX23`0_ooool2oj0Pl0?ooooo0_ooO`03ooooo`04o`00
0?ooO`3oogl0oomo00CoX23`00?oooooo`000?ooool00Oooool002[ooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`2?ooooo`CoX23`1Oooool4oj0Pl0;ooooo00?o0000oomo0?ooO`00
0_ooool2oj0Pl003ooooool0003ooooo007ooooo000[ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0TOooool2oj0Pl0Gooooo1OnP8?02ooooo`04o`000?ooO`3ooooooomo00?oX23`
0Ol00001ooooo`7ooooo000/ooooo`;o0000A_ooool00ol0003oooooooooo`2Gooooo`KoX23`0_oo
ool00ol0003oogl0oomo0004oomo007ooooo0Ol00001ooooo`00;_ooool00ol0003oooooooooo`13
ooooo`03o`000?oooooooooo09Oooooo1_nP8?001?ooO`3ooooooomo0?l00005oomo007ooooo0Ol0
0001ooooo`00;oooool2o`0004?ooooo00?o0000ooooooooool0V_ooool2oj0Pl0;oogl00_ooool0
0oooO`3o0000ooooo`04oomo007o00000Oooool0037ooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`2Jooooo`;oX23`0_ooool2oj0Pl0;oogl000?o0000oomo0?ooO`000_ooO`01o`00
007ooooo000booooo`;o0000@?ooool00ol0003oooooooooo`2Nooooo`;oX23`0_ooO`001_oooooo
0000oomo0?ooO`3oooooo`00007ooooo000dooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0VOooool2oj0Pl0?ooooo0_nP8?04ooooo`04o`000?ooooooooooo`00007ooooo000eoooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0VOooool2oj0Pl0Wooooo00Co0000oooo
oooooooo00000Oooool003Kooooo0_l0000kooooo`03o`000?oooooooooo0:Kooooo00?o0000oooo
ooooool00Ol0000003Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2Wooooo`7o
00000Oooool1o`000000>Oooool2o`0003Sooooo00?o0000ooooooooool0Z?ooool2o`000000>ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo09oooooo0_nP8?06ooooo`?o0000000l
ooooo`;o0000=Oooool00ol0003oooooooooo`2Oooooo`;oX23`00?oooooo`000?l000000ol00003
ooooo`00?_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo09kooooo1?l00008oooo
o`00?oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo09Wooooo1Ol0000<ooooo`00
@?ooool2o`00037ooooo00?o0000ooooooooool0UOooool4o`00017ooooo0012ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0TOooool4o`0001Gooooo0013ooooo`;o0000;_ooool0
0ol0003oooooooooo`2<ooooo`Go00006Oooool004Gooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`28ooooo`Co00007_ooool004Kooooo0_l0000[ooooo`03o`000?oooooooooo08?o
oooo1Ol0000Rooooo`00B?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo07oooooo
1?l0000Wooooo`00BOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07[ooooo1Ol0
000[ooooo`00B_ooool2o`0002Oooooo00?o0000ooooooooool0M_ooool4o`00033ooooo001<oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L_ooool4o`0003Cooooo001=ooooo`;o
00009?ooool00ol0003oooooooooo`1]ooooo`Go0000>?ooool004oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1Yooooo`Co0000?Oooool0053ooooo0_l0000Qooooo`03o`000?oo
oooooooo06Cooooo1Ol00011ooooo`00D_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo063ooooo1?l00016ooooo`00Doooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
05_ooooo1Ol0001:ooooo`00E?ooool2o`0001gooooo00?o0000ooooooooool0Eoooool4o`0004oo
oooo001Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D_ooool5o`0005?ooooo
001Gooooo`;o00006_ooool00ol0003oooooooooo`1>ooooo`Co0000F?ooool005Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1:ooooo`Co0000G?ooool005[ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`15ooooo`Go0000H?ooool005_ooooo0_l0000Fooooo`03
o`000?oooooooooo047ooooo1?l0001Uooooo`00GOooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03cooooo1Ol0001Yooooo`00G_ooool2o`0001?ooooo00?o0000ooooooooool0>?oo
ool4o`0006kooooo001Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool5
o`0007;ooooo001Qooooo`;o00003oooool00ol0003oooooooooo`0`ooooo`Co0000Moooool006?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0/ooooo`Co0000Noooool006Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`Go0000Ooooool006Gooooo0_l0
000;ooooo`03o`000?oooooooooo02?ooooo1?l00024ooooo`00Ioooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01kooooo1Ol00028ooooo`00J?ooool2o`0000Sooooo00?o0000oooo
ooooool06_ooool4o`0008gooooo001Zooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool5o`00097ooooo001[ooooo`;o00001Oooool00ol0003oooooooooo`0Aooooo`Co0000
U_ooool006gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`Co0000V_oo
ool006kooooo00Go0000ooooooooooooooooo`00000:ooooo`Go0000W_ooool006oooooo0_l00000
0ooooooo0000ooooo`05ooooo`Co0000Xoooool0077ooooo0_l000000ooooooo0000o`000003o`00
0:Oooooo001booooo`;o0000[?ooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {311.562, 0}} -> {0.0486402, -4.05116*^-5, \
0.00298809, 0.00298809}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EM experiment #1: object 1 (Kellogs car)", "Subsection"],

Cell[CellGroupData[{

Cell["Normalize 3d data", "Subsubsection"],

Cell[BoxData[
    \(\(d3d1 = \((data1/255. )\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d3d1\  // \ Dimensions\)], "Input"],

Cell[BoxData[
    \({11755, 3}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 4;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull3D[d3d1, k];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[d3d1, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({3.1200000000000045`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsubsection"],

Cell[BoxData[
    \(\(model1 = \ em\  // \ Last;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, d3d1];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0529101 -0.00720955 2.04308e-05 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -9 -9 ]
[.15608 -0.0125 9 0 ]
[.28836 -0.0125 -3 -9 ]
[.28836 -0.0125 3 0 ]
[.42063 -0.0125 -9 -9 ]
[.42063 -0.0125 9 0 ]
[.55291 -0.0125 -6 -9 ]
[.55291 -0.0125 6 0 ]
[.68519 -0.0125 -12 -9 ]
[.68519 -0.0125 12 0 ]
[.81746 -0.0125 -6 -9 ]
[.81746 -0.0125 6 0 ]
[.94974 -0.0125 -12 -9 ]
[.94974 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09494 -24 -4.5 ]
[-0.0125 .09494 0 4.5 ]
[-0.0125 .1971 -30 -4.5 ]
[-0.0125 .1971 0 4.5 ]
[-0.0125 .29925 -30 -4.5 ]
[-0.0125 .29925 0 4.5 ]
[-0.0125 .40141 -30 -4.5 ]
[-0.0125 .40141 0 4.5 ]
[-0.0125 .50356 -30 -4.5 ]
[-0.0125 .50356 0 4.5 ]
[-0.0125 .60571 -30 -4.5 ]
[-0.0125 .60571 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.15608 0 m
.15608 .61803 L
s
.28836 0 m
.28836 .61803 L
s
.42063 0 m
.42063 .61803 L
s
.55291 0 m
.55291 .61803 L
s
.68519 0 m
.68519 .61803 L
s
.81746 0 m
.81746 .61803 L
s
.94974 0 m
.94974 .61803 L
s
0 .09494 m
1 .09494 L
s
0 .1971 m
1 .1971 L
s
0 .29925 m
1 .29925 L
s
0 .40141 m
1 .40141 L
s
0 .50356 m
1 .50356 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(2.5)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(5)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(7.5)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(10)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(12.5)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(15)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(17.5)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09494 m
.00625 .09494 L
s
[(5000)] -0.0125 .09494 1 0 Mshowa
0 .1971 m
.00625 .1971 L
s
[(10000)] -0.0125 .1971 1 0 Mshowa
0 .29925 m
.00625 .29925 L
s
[(15000)] -0.0125 .29925 1 0 Mshowa
0 .40141 m
.00625 .40141 L
s
[(20000)] -0.0125 .40141 1 0 Mshowa
0 .50356 m
.00625 .50356 L
s
[(25000)] -0.0125 .50356 1 0 Mshowa
0 .60571 m
.00625 .60571 L
s
[(30000)] -0.0125 .60571 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .13581 m
.00375 .13581 L
s
0 .15624 m
.00375 .15624 L
s
0 .17667 m
.00375 .17667 L
s
0 .21753 m
.00375 .21753 L
s
0 .23796 m
.00375 .23796 L
s
0 .25839 m
.00375 .25839 L
s
0 .27882 m
.00375 .27882 L
s
0 .31968 m
.00375 .31968 L
s
0 .34011 m
.00375 .34011 L
s
0 .36054 m
.00375 .36054 L
s
0 .38098 m
.00375 .38098 L
s
0 .42184 m
.00375 .42184 L
s
0 .44227 m
.00375 .44227 L
s
0 .4627 m
.00375 .4627 L
s
0 .48313 m
.00375 .48313 L
s
0 .52399 m
.00375 .52399 L
s
0 .54442 m
.00375 .54442 L
s
0 .56485 m
.00375 .56485 L
s
0 .58528 m
.00375 .58528 L
s
0 .07451 m
.00375 .07451 L
s
0 .05408 m
.00375 .05408 L
s
0 .03365 m
.00375 .03365 L
s
0 .01322 m
.00375 .01322 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09494 m
1 .09494 L
s
.99375 .1971 m
1 .1971 L
s
.99375 .29925 m
1 .29925 L
s
.99375 .40141 m
1 .40141 L
s
.99375 .50356 m
1 .50356 L
s
.99375 .60571 m
1 .60571 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .13581 m
1 .13581 L
s
.99625 .15624 m
1 .15624 L
s
.99625 .17667 m
1 .17667 L
s
.99625 .21753 m
1 .21753 L
s
.99625 .23796 m
1 .23796 L
s
.99625 .25839 m
1 .25839 L
s
.99625 .27882 m
1 .27882 L
s
.99625 .31968 m
1 .31968 L
s
.99625 .34011 m
1 .34011 L
s
.99625 .36054 m
1 .36054 L
s
.99625 .38098 m
1 .38098 L
s
.99625 .42184 m
1 .42184 L
s
.99625 .44227 m
1 .44227 L
s
.99625 .4627 m
1 .4627 L
s
.99625 .48313 m
1 .48313 L
s
.99625 .52399 m
1 .52399 L
s
.99625 .54442 m
1 .54442 L
s
.99625 .56485 m
1 .56485 L
s
.99625 .58528 m
1 .58528 L
s
.99625 .07451 m
1 .07451 L
s
.99625 .05408 m
1 .05408 L
s
.99625 .03365 m
1 .03365 L
s
.99625 .01322 m
1 .01322 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.07672 .31218 L
.12963 .41556 L
.18254 .4937 L
.23545 .53203 L
.28836 .55358 L
.34127 .56877 L
.39418 .57863 L
.44709 .58578 L
.5 .59126 L
.55291 .59531 L
.60582 .59817 L
.65873 .60004 L
.71164 .60127 L
.76455 .60209 L
.81746 .60264 L
.87037 .60298 L
.92328 .60319 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.07672 .31218 Mdot
.12963 .41556 Mdot
.18254 .4937 Mdot
.23545 .53203 Mdot
.28836 .55358 Mdot
.34127 .56877 Mdot
.39418 .57863 Mdot
.44709 .58578 Mdot
.5 .59126 Mdot
.55291 .59531 Mdot
.60582 .59817 Mdot
.65873 .60004 Mdot
.71164 .60127 Mdot
.76455 .60209 Mdot
.81746 .60264 Mdot
.87037 .60298 Mdot
.92328 .60319 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`009_ooool2o`0001Oooooo1Ol0
0003ooooo`03o`000?oooooooooo00;ooooo0ol0000Iooooo`?o00006Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo0ol0000Fooooo`?o00001?ooool2o`0001?ooooo0ol0
0002ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`?o00004_ooool3o`0000?ooooo0ol0
000Cooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`009Oooool01?l0003oooooooooool0000Gooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`00000Gooooo`05o`000?ooooooooooooooool000006?ooool00ol0
003oooooooooo`07ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000004_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`009Oooool01?l0003oooooooooool0000H
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`01ooooo`009Oooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`009Oooool01?l0003ooooooooo
ool0000Fooooo`05o`000?ooooooooooooooool000001oooool4o`0001Sooooo1?l0000Kooooo`03
o`000?oooooooooo00Gooooo1?l0000Gooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00004oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool4
o`0001?ooooo00Co0000oooooooooooooooo1?l0000Dooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool4o`0000Cooooo000Uooooo`04o`000?ooooooooooo`0001Kooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool05oooool2o`0000Co
oooo00Co0000oooooooooooo00004_ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooooooo01Cooooo0_l00003
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`05ooooo`009_ooool2
o`0001Sooooo0ol00008ooooo`Go00005oooool5o`0001Kooooo1Ol00007ooooo`Go00005_ooool0
0ol0003oooooooooo`03ooooo`;o00005?ooool00ol0003oooooooooo`02ooooo`?o00002?ooool5
o`0001;ooooo00Co0000oooooooooooooooo1Ol0000Cooooo`04o`000?ooooooooooooooo`Go0000
1oooool5o`0000?ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7o
oooo000Qooooooh000000Oooool0027ooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`0300000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00`00003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`4000000Oooool0027ooooo00<00000ooooooooool00_ooool30?l001oooooo00?o0000
ooooooooool07oooool00`00003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00<00000
ooooooooool07oooool00ol0003oooooooooo`0Nooooo`0300000?oooooooooo01oooooo00?o0000
ooooooooool02Oooool10000007ooooo000Qooooo`0400000?l0003oooooooooo`D0o`007_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`08ooooo`7o00000@000001ooooo`008Oooool01000003oooooooooooooool5
0?l001kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`0400000?oooooooooo
ooooo`D0o`007_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000oooo
ooooool00_ooool30?l001oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`03
00000?oooooooooo00?ooooo00<00000ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`40
00000Oooool0027ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`0Mooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003o0000ooooo`04ooooo`0300000?oo
oooooooo01gooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool02?ooool1o`00004000000Oooool0027ooooo00<00000
ooooooooool01?ooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001
ooooo`008Oooool00`00003oooooooooo`04ooooo`0300000?oooooooooo01gooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo00Cooooo00<00000oooooooo
ool07Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000ooooooooool0
1?ooool00`00003oooooooooo`0Mooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`008Ooo
ool00`00003o0000ooooo`05ooooo`0300000?oooooooooo01cooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02?oo
ool1o`00004000000Oooool0027ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0L
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`05oooo
o`0300000?oooooooooo01cooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`03
00000?oooooooooo00Gooooo00<00000ooooooooool07?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`40
00000Oooool0027ooooo00<00000ooooooooool01Oooool00`00003oooooooooo`0Looooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003o0000ooooo`06ooooo`0300000?oo
oooooooo01_ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool02?ooool1o`00004000000Oooool0027ooooo00<00000
ooooooooool01_ooool00`00003oooooooooo`0Kooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001
ooooo`008Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo01_ooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool02Oooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o
00001Oooool00`00003oooooooooo`06ooooo`0300000?oooooooooo01_ooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool02Oooool10000007ooooo0006ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`06ooooo`0300000?oooooooooo01_ooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Ooo
ool10000007ooooo000:ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000o`000000
07l01P0007l00`000000001o0000O`3`0000O`7o00000@000001ooooo`002_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool06_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`09ooooo`4000000Oooool000Kooooo1?l00003ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo00Oooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`400000
0Oooool000Kooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`07oooo
o`0300000?oooooooooo01[ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo0006ooooo`Go
00000oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`07ooooo`03
00000?oooooooooo01[ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`030000
0?l0003ooooo00Oooooo00<00000ooooooooool06_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`08ooooo`7o0000
0@000001ooooo`008Oooool00`00003oooooooooo`07ooooo`0300000?oooooooooo01[ooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo00Sooooo00<00000
ooooooooool06Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000oooo
ooooool02?ooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001oooo
o`008Oooool00`00003oooooooooo`08ooooo`0300000?oooooooooo01Wooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool02Oooool10000007ooooo000Qooooo`0300000?l0003ooooo00Sooooo00<00000ooooooooool0
6Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`08ooooo`7o00000@000001ooooo`008Oooool00`00003ooooooooo
o`08ooooo`0300000?oooooooooo01Wooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Q
ooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool06Oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09
ooooo`4000000Oooool0027ooooo00<00000ooooooooool02Oooool00`00003oooooooooo`0Hoooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`09ooooo`03
00000?oooooooooo01Sooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`030000
0?oooooooooo00Wooooo00<00000ooooooooool06?ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`400000
0Oooool0027ooooo00<00000o`000?ooool02Oooool00`00003oooooooooo`0Hooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo00Sooooo0Ol000010000007ooooo000Qooooo`0300000?oooooooooo00Wooooo00<00000
ooooooooool06?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000oooo
ooooool02_ooool00`00003oooooooooo`0Gooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001oooo
o`008Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo01Oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool0
5oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000o`000?ooool02_oo
ool00`00003oooooooooo`0Gooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Sooooo0Ol000010000007ooooo000Q
ooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool05oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09
ooooo`4000000Oooool0027ooooo00<00000ooooooooool02_ooool00`00003oooooooooo`0Goooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo00Wooooo0@000001ooooo`0000Coooooo`000?l0003o00001?ooool2o`00
00Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool02oooool00`00
003oooooooooo`0Fooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`000_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
2oooool00`00003oooooooooo`0Fooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`000_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000
o`00000007l02`0007l00`000000001o0000O`3[0000O`7o00000@000001ooooo`000_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool02oooool00`00003oooooooooo`0Fooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`00
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool02oooool00`00003oooooooooo`0Fooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@00
0001ooooo`0000?oooooo`000?l000001?ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo00_ooooo00<00000ooooooooool05_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09oooo
o`4000000Oooool000;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00004ooooo`;o
00001?ooool2o`0000Gooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0Eooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003o0000ooooo`0<ooooo`030000
0?oooooooooo01Gooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool02?ooool1o`00004000000Oooool0027ooooo00<0
0000ooooooooool03?ooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@00
0001ooooo`008Oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo01Gooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo00cooooo00<00000oooo
ooooool05Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000oooooooo
ool03?ooool00`00003oooooooooo`0Eooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`00
8Oooool00`00003o0000ooooo`0=ooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
2?ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool03Oooool00`00003ooooooooo
o`0Dooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`0=
ooooo`0300000?oooooooooo01Cooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qoooo
o`0300000?oooooooooo00gooooo00<00000ooooooooool05?ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09oooo
o`4000000Oooool0027ooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0Dooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`0=ooooo`030000
0?oooooooooo01Cooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`0300000?l0
003ooooo00kooooo00<00000ooooooooool04oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`08ooooo`7o00000@00
0001ooooo`008Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01?ooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo00kooooo00<00000oooo
ooooool04oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000oooooooo
ool03_ooool00`00003oooooooooo`0Cooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`00
8Oooool00`00003oooooooooo`0>ooooo`0300000?oooooooooo01?ooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
2Oooool10000007ooooo000Qooooo`0300000?l0003ooooo00oooooo00<00000ooooooooool04_oo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`08ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0?
ooooo`0300000?oooooooooo01;ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo00001?oo
oooo0000o`000?l00003ooooo`?o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool0
0`00003oooooooooo`0?ooooo`0300000?oooooooooo01;ooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool1
0000007ooooo0002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool04_ooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`09ooooo`4000000Oooool000;ooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`0300000?oooooooooo00oooooo00<00000ooooooooool04_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`09ooooo`4000000Oooool000;ooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`02ooooo`0300000?l00000001o00l0001o00<000000000O`0007l0
i`0007l1o`00004000000Oooool000;ooooo00Co0000oooooooooooooooo1?l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004
ooooo`0300000?oooooooooo00oooooo0`3o000Booooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001
ooooo`0000?oooooo`000?l000000oooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo00kooooo1@3o000Aooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`000_oo
ool01?l0003oooooooooooooool5o`0000?ooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo
00<00000ooooooooool03_ooool50?l0017ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo
000Qooooo`0300000?oooooooooo00kooooo1@3o000Aooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@00
0001ooooo`008Oooool00`00003o0000ooooo`0?ooooo`<0o`004_ooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`08
ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0Aooooo`0300000?oooooooooo
013ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo01;o
oooo00<00000ooooooooool03oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo
00<00000ooooooooool04_ooool00`00003oooooooooo`0?ooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo
0@000001ooooo`008Oooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo00kooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool02Oooool10000007ooooo000Qooooo`0300000?l0003ooooo01Cooooo00<00000
ooooooooool03Oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`08ooooo`7o00000@000001ooooo`008Oooool00`00
003oooooooooo`0Dooooo`0300000?oooooooooo00gooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`00
07ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000
007ooooo000Qooooo`0300000?oooooooooo01Gooooo00<00000ooooooooool03?ooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`09ooooo`4000000Oooool0027ooooo00<00000ooooooooool05Oooool00`00003ooooo
ooooo`0<ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003ooooooooo
o`0Fooooo`0300000?oooooooooo00_ooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Q
ooooo`0300000?l0003ooooo01Kooooo00<00000ooooooooool02oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`08
ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0Gooooo`0300000?oooooooooo
00[ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo01Oo
oooo00<00000ooooooooool02_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo
00<00000ooooooooool06?ooool00`00003oooooooooo`09ooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo
0@000001ooooo`008Oooool00`00003oooooooooo`0Hooooo`0300000?oooooooooo00Wooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo01Wooooo00<00000
ooooooooool02?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001o
ooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000o`00
0?ooool06Oooool00`00003oooooooooo`08ooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Sooooo0Ol000010000
007ooooo000Qooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool01oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`09ooooo`4000000Oooool000Go00000oooool2o`0000Cooooo0_l00004ooooo`;o0000
1?ooool2o`0000Gooooo00<00000ooooooooool06oooool00`00003oooooooooo`06ooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo00Wooooo0@000001ooooo`0000Goooooo`000?ooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool06oooool00`00003ooooooooo
o`06ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`000_ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool07?ooool00`00
003oooooooooo`05ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`00
07ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00`00003o0000
0000O`0L0000O`030000000007l0001o0=X0001o0Ol000010000007ooooo00001Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`0Mooooo`<0o`001?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0
001oooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool00005o`000?oooooo
ooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo01cooooo1@3o0003ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`0000Coooooo`00
0?l0003o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000
ooooooooool07?ooool50?l000?ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qoooo
o`0300000?oooooooooo01cooooo1@3o0003ooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001oooo
o`008Oooool00`00003o0000ooooo`0Mooooo`<0o`001?ooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`08ooooo`7o
00000@000001ooooo`008Oooool00`00003oooooooooo`0Pooooo`0500000?ooooooooooooooo`00
07l08Oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool02Oooool10000007ooooo000Qooooo`0300000?oooooooooo023ooooo00D00000oooooooooooo
oooo0000O`0Qooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`09ooooo`4000000Oooool0027ooooo00<00000ooooooooool08Oooool01000003ooooo
ooooo`0007lQooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`09ooooo`4000000Oooool0027ooooo00<00000ooooooooool08_ooool00`00003ooooo
0000O`0Qooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`09ooooo`4000000Oooool0027ooooo00<00000o`000?ooool08_ooool00`00003ooooo0000
O`0Qooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooooooo
o`08ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0Sooooo`030000000007oo
oooo023ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooo
oooo00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Tooooo`0300000?oooooooooo01oo
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wo
oooo0@000001ooooo`008Oooool00`00003oooooooooo`0Tooooo`030000O`00003ooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo
0@000001ooooo`008Oooool00`00003o0000ooooo`0Tooooo`030000O`00003ooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0
001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Sooooo0Ol0
00010000007ooooo000Qooooo`0300000?oooooooooo02Cooooo00<0001oooooo`0000007oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool1
0000007ooooo000Qooooo`0300000?oooooooooo02Cooooo00@0001oooooooooool000007_ooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool1
0000007ooooo000Qooooo`0300000?oooooooooo02Cooooo00@0001oooooooooool000007_ooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool1
0000007ooooo000Qooooo`0300000?oooooooooo02Cooooo00D0001ooooooooooooooooo0000000M
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0O
ooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09
ooooo`4000000Oooool0027ooooo00<00000ooooooooool09?ooool00`0007ooooooooooo`02oooo
o`0300000?oooooooooo01[ooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003o0000ooooo`0Tooooo`03
0000Oooooooooooo00;ooooo00@000000?l0003o0000o`006Oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool02?ooool1o`00004000000Oooool0027o
oooo00<00000ooooooooool09?ooool00`0007ooooooooooo`02ooooo`D0o`006?ooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007o
oooo0005o`0000;ooooo0ol00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`030000
0?oooooooooo02Cooooo00<0001oooooooooool00_ooool50?l001Sooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`0000Oo
ooooo`000?ooooooooooo`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool00`00003oooooooooo`0Tooooo`030000Oooooooooooo00;ooooo1@3o000Hooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Ooo
ool000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`03
00000?oooooooooo02Cooooo00<0001oooooooooool00oooool30?l00003ooooo`00003ooooo01Ko
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wo
oooo0@000001ooooo`000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00<00000o`00000007l0;`0007l200000<P0001o0Ol000010000007ooooo00001_l0
003ooooooooooooooooo0000ooooo`Co00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Toooo
o`030000Oooooooooooo00[ooooo00<00000ooooooooool04_ooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Noooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo00001ol0003o
oooooooooooooooo0000ooooool000001_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0Tooooo`03
0000Oooooooooooo00_ooooo00<00000ooooooooool04Oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo00001?oooooo0000
o`000?l00002ooooo`Go00000oooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003o
ooooooooo`0Tooooo`030000Oooooooooooo00cooooo00<00000ooooooooool04?ooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007oo
ooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007o
oooo000Qooooo`0300000?oooooooooo02Cooooo00<0001oooooooooool03Oooool20000013ooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo
0@000001ooooo`008Oooool00`00003o0000ooooo`0Tooooo`030000Oooooooooooo00oooooo00@0
00000?l0003o0000o`003?ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo
00<0001oooooooooool02?ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool09?oo
ool00`0007ooooooooooo`0?ooooo`D0o`002oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qooooo`0300000?oooooo
oooo02Cooooo00<0001oooooooooool03oooool50?l000_ooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00
003oooooooooo`0Tooooo`030000Oooooooooooo00oooooo1@3o0002000000Wooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001oooo
o`008Oooool00`00003oooooooooo`0Tooooo`030000Oooooooooooo013ooooo0`3o0003ooooo`<0
00001_ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool07oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001ooooooooo
ool02Oooool10000007ooooo000Qooooo`0300000?l0003ooooo02Cooooo00<0001oooooooooool0
6Oooool3000000;ooooo0`3o000Oooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
7oooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
2?ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool09?ooool00`0007oooooooooo
o`0Looooo`030000003o0000o`0000<0o`007_ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooo
oooooooo00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Tooooo`030000Oooooooo
oooo01gooooo1@3o000Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool0
0`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool1
0000007ooooo000Qooooo`0300000?oooooooooo02Cooooo00<0001oooooooooool07Oooool50?l0
00<000006oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01oooooo00<0001ooooo
ooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Wooooo0@000001oooo
o`008Oooool00`00003oooooooooo`0Tooooo`030000Oooooooooooo01kooooo0`3o0004ooooo`<0
00000oooool30?l001;ooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Oooooo`03
0000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`40
00000Oooool0027ooooo00<00000o`000?ooool09?ooool00`0007ooooooooooo`0Oooooo`030000
Oooooooooooo00Kooooo0P0000050?l0017ooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07oooool00`0007oooooo
ooooo`08ooooo`7o00000@000001ooooo`008Oooool00`00003oooooooooo`0Tooooo`030000Oooo
oooooooo01oooooo00<0001oooooooooool02?ooool50?l0017ooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool07ooo
ool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo00<00000ooooooooool09?ooool0
0`0007ooooooooooo`0Oooooo`030000Oooooooooooo00Sooooo1@3o0005000000Gooooo0`3o0004
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0N
ooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo000Qoooo
o`0300000?oooooooooo02Cooooo00<0001oooooooooool07oooool00`0007ooooooooooo`09oooo
o`<0o`001_ooool4000000D0o`000oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo
00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Tooooo`030000Oooooooooooo01oo
oooo00<0001oooooooooool05_ooool50?l0000400000?oooooooooo0000O`Gooooo0`3o000Ioooo
o`030000Oooooooooooo01oooooo00<0001oooooooooool07_ooool00`0007ooooooooooo`0Ooooo
o`030000Oooooooooooo00Wooooo0@000001ooooo`008Oooool00`00003oooooooooo`0Tooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool05_ooool50?l00003ooooo`000000000000D0
00001@3o000:ooooo`<0o`002oooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01ko
oooo00<0001oooooooooool07oooool00`0007ooooooooooo`09ooooo`4000000Oooool0027ooooo
00<00000o`000?ooool09?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01Oooooo
0`3o0004ooooo`030000Oooooooooooo00;ooooo1@3o0005000000Cooooo1@3o0009ooooo`<0o`00
8?ooool00`0007ooooooooooo`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool0
2?ooool1o`00004000000Oooool0027ooooo00<00000ooooooooool09?ooool00`0007oooooooooo
o`0Oooooo`030000Oooooooooooo01kooooo00<0001oooooooooool00_ooool50?l000Gooooo1000
00050?l000D000000oooool50?l000Wooooo0`3o000;ooooo`<0o`001Oooool00`0007oooooooooo
o`0Nooooo`030000Oooooooooooo01oooooo00<0001oooooooooool02Oooool10000007ooooo0000
1?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Ooo
ool00`00003oooooooooo`0Tooooo`030000Oooooooooooo01oooooo00<0001oooooooooool07_oo
ool00`0007ooooooooooo`03ooooo`<0o`002_ooool50?l000Gooooo0`0000050?l000D000000ooo
ool50?l000Wooooo1@3o0004ooooo`030000Oooooooooooo00;ooooo0`3o000;ooooo`<0o`002_oo
ool30?l000[ooooo0`3o000;ooooo`<0o`001Oooool00`0007ooooooooooo`02ooooo`<0o`001?oo
ool10000007ooooo00001Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00001?ooool00`00003oooooooooo`0Tooooo`030000Oooooooooooo01oooooo00<0001o
ooooooooool07_ooool00`0007ooooooooooo`0Aooooo`<0o`002Oooool50?l000Gooooo0`000005
0?l000T000001@3o0005000000?ooooo1@3o0009ooooo`D0o`002?ooool50?l000Sooooo1@3o0009
ooooo`D0o`001?ooool0100007ooooooooooooooool50?l000?ooooo0@000001ooooo`001?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000oooo
ooooool09?ooool00`0007ooooooooooo`0Oooooo`030000Oooooooooooo01kooooo00<0001ooooo
ooooool07_ooool30?l000Wooooo1@3o0009ooooo`D0o`001?ooool0100007l00000000000000005
0?l000T000001@3o0008000000D0o`00200000050?l000T000001@3o0008000000D0o`000oooool1
0000007ooooo0002ooooo`;o00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?l0003ooooo02Cooooo00<0001oooooooooool07oooool00`0007ooooooooooo`0Nooooo`03
0000Oooooooooooo01oooooo00<0001oooooooooool02Oooool30?l000_ooooo0`3o0005ooooo`04
0000Ooooooooooooooooo`D0o`002Oooool50?l000Sooooo1@3o0008ooooo`D0o`002Oooool50?l0
00Cooooo00@0001ooooooooooooooooo1@3o0002ooooo`7o00000@000001ooooo`001?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00<00000oooooooo
ool00oooool00`00003oooooooooo`0Nooooo`0300000?oooooooooo01oooooo00<00000oooooooo
ool07_ooool00`00003oooooooooo`0Oooooo`0300000?oooooooooo01oooooo00<00000oooooooo
ool00_ooool30?l000_ooooo0`3o000:ooooo`<0o`002_ooool30?l000_ooooo0`3o0005ooooo`03
00000?oooooooooo00;ooooo0`3o0004ooooo`4000000Oooool00005o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo00?ooooo
00<00000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00`00003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00<00000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00<00000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool10000007ooooo00001?oooooo0000o`000?l00004ooooo`;o0000
1?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooooon0000007ooooo003oooooob7ooooo003o
ooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.92126, -2631.64, \
0.074497, 192.927}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["EM experiment #2: object 2 (Tide car)", "Subsection"],

Cell[CellGroupData[{

Cell["Normalize 3d data", "Subsubsection"],

Cell[BoxData[
    \(\(d3d2 = \((data2/255. )\);\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Choose number of Gaussians in mixture model", "Subsubsection"],

Cell[BoxData[
    \(\(k = 4;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Assumes full covariance matrices", "Subsubsection"],

Cell[BoxData[
    \(\(initFull\  = \ EMInitializationFull3D[d3d2, k];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Compute EM algorithm", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(em\  = \ EM[d3d2, initFull, 0.001];\)]\)], "Input"],

Cell[BoxData[
    \({4.75`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save solution", "Subsubsection"],

Cell[BoxData[
    \(\(model2 = \ em\  // \ Last;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Plot log-likelihood of data given the model as a function of EM \
iteration\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(PlotLogLikelihood[em, d3d2];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0453515 0.174862 1.15109e-05 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.25057 -0.0125 -3 -9 ]
[.25057 -0.0125 3 0 ]
[.47732 -0.0125 -6 -9 ]
[.47732 -0.0125 6 0 ]
[.70408 -0.0125 -6 -9 ]
[.70408 -0.0125 6 0 ]
[.93084 -0.0125 -6 -9 ]
[.93084 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .05975 -36 -4.5 ]
[-0.0125 .05975 0 4.5 ]
[-0.0125 .17486 -6 -4.5 ]
[-0.0125 .17486 0 4.5 ]
[-0.0125 .28997 -30 -4.5 ]
[-0.0125 .28997 0 4.5 ]
[-0.0125 .40508 -30 -4.5 ]
[-0.0125 .40508 0 4.5 ]
[-0.0125 .52019 -30 -4.5 ]
[-0.0125 .52019 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.25057 0 m
.25057 .61803 L
s
.47732 0 m
.47732 .61803 L
s
.70408 0 m
.70408 .61803 L
s
.93084 0 m
.93084 .61803 L
s
0 .05975 m
1 .05975 L
s
0 .17486 m
1 .17486 L
s
0 .28997 m
1 .28997 L
s
0 .40508 m
1 .40508 L
s
0 .52019 m
1 .52019 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.25057 0 m
.25057 .00625 L
s
[(5)] .25057 -0.0125 0 1 Mshowa
.47732 0 m
.47732 .00625 L
s
[(10)] .47732 -0.0125 0 1 Mshowa
.70408 0 m
.70408 .00625 L
s
[(15)] .70408 -0.0125 0 1 Mshowa
.93084 0 m
.93084 .00625 L
s
[(20)] .93084 -0.0125 0 1 Mshowa
.125 Mabswid
.06916 0 m
.06916 .00375 L
s
.11451 0 m
.11451 .00375 L
s
.15986 0 m
.15986 .00375 L
s
.20522 0 m
.20522 .00375 L
s
.29592 0 m
.29592 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.38662 0 m
.38662 .00375 L
s
.43197 0 m
.43197 .00375 L
s
.52268 0 m
.52268 .00375 L
s
.56803 0 m
.56803 .00375 L
s
.61338 0 m
.61338 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.74943 0 m
.74943 .00375 L
s
.79478 0 m
.79478 .00375 L
s
.84014 0 m
.84014 .00375 L
s
.88549 0 m
.88549 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .05975 m
.00625 .05975 L
s
[(-10000)] -0.0125 .05975 1 0 Mshowa
0 .17486 m
.00625 .17486 L
s
[(0)] -0.0125 .17486 1 0 Mshowa
0 .28997 m
.00625 .28997 L
s
[(10000)] -0.0125 .28997 1 0 Mshowa
0 .40508 m
.00625 .40508 L
s
[(20000)] -0.0125 .40508 1 0 Mshowa
0 .52019 m
.00625 .52019 L
s
[(30000)] -0.0125 .52019 1 0 Mshowa
.125 Mabswid
0 .08277 m
.00375 .08277 L
s
0 .1058 m
.00375 .1058 L
s
0 .12882 m
.00375 .12882 L
s
0 .15184 m
.00375 .15184 L
s
0 .19788 m
.00375 .19788 L
s
0 .22091 m
.00375 .22091 L
s
0 .24393 m
.00375 .24393 L
s
0 .26695 m
.00375 .26695 L
s
0 .31299 m
.00375 .31299 L
s
0 .33601 m
.00375 .33601 L
s
0 .35904 m
.00375 .35904 L
s
0 .38206 m
.00375 .38206 L
s
0 .4281 m
.00375 .4281 L
s
0 .45112 m
.00375 .45112 L
s
0 .47414 m
.00375 .47414 L
s
0 .49717 m
.00375 .49717 L
s
0 .03673 m
.00375 .03673 L
s
0 .01371 m
.00375 .01371 L
s
0 .54321 m
.00375 .54321 L
s
0 .56623 m
.00375 .56623 L
s
0 .58925 m
.00375 .58925 L
s
0 .61228 m
.00375 .61228 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.25057 .61178 m
.25057 .61803 L
s
.47732 .61178 m
.47732 .61803 L
s
.70408 .61178 m
.70408 .61803 L
s
.93084 .61178 m
.93084 .61803 L
s
.125 Mabswid
.06916 .61428 m
.06916 .61803 L
s
.11451 .61428 m
.11451 .61803 L
s
.15986 .61428 m
.15986 .61803 L
s
.20522 .61428 m
.20522 .61803 L
s
.29592 .61428 m
.29592 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.38662 .61428 m
.38662 .61803 L
s
.43197 .61428 m
.43197 .61803 L
s
.52268 .61428 m
.52268 .61803 L
s
.56803 .61428 m
.56803 .61803 L
s
.61338 .61428 m
.61338 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.74943 .61428 m
.74943 .61803 L
s
.79478 .61428 m
.79478 .61803 L
s
.84014 .61428 m
.84014 .61803 L
s
.88549 .61428 m
.88549 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .05975 m
1 .05975 L
s
.99375 .17486 m
1 .17486 L
s
.99375 .28997 m
1 .28997 L
s
.99375 .40508 m
1 .40508 L
s
.99375 .52019 m
1 .52019 L
s
.125 Mabswid
.99625 .08277 m
1 .08277 L
s
.99625 .1058 m
1 .1058 L
s
.99625 .12882 m
1 .12882 L
s
.99625 .15184 m
1 .15184 L
s
.99625 .19788 m
1 .19788 L
s
.99625 .22091 m
1 .22091 L
s
.99625 .24393 m
1 .24393 L
s
.99625 .26695 m
1 .26695 L
s
.99625 .31299 m
1 .31299 L
s
.99625 .33601 m
1 .33601 L
s
.99625 .35904 m
1 .35904 L
s
.99625 .38206 m
1 .38206 L
s
.99625 .4281 m
1 .4281 L
s
.99625 .45112 m
1 .45112 L
s
.99625 .47414 m
1 .47414 L
s
.99625 .49717 m
1 .49717 L
s
.99625 .03673 m
1 .03673 L
s
.99625 .01371 m
1 .01371 L
s
.99625 .54321 m
1 .54321 L
s
.99625 .56623 m
1 .56623 L
s
.99625 .58925 m
1 .58925 L
s
.99625 .61228 m
1 .61228 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06916 .44915 L
.11451 .48629 L
.15986 .50942 L
.20522 .52133 L
.25057 .53574 L
.29592 .55042 L
.34127 .56346 L
.38662 .57075 L
.43197 .57595 L
.47732 .58078 L
.52268 .58572 L
.56803 .59059 L
.61338 .59451 L
.65873 .59741 L
.70408 .59952 L
.74943 .60097 L
.79478 .60193 L
.84014 .60254 L
.88549 .60292 L
.93084 .60316 L
.97619 .60332 L
s
1 0 0 r
.02 w
.02381 .01472 Mdot
.06916 .44915 Mdot
.11451 .48629 Mdot
.15986 .50942 Mdot
.20522 .52133 Mdot
.25057 .53574 Mdot
.29592 .55042 Mdot
.34127 .56346 Mdot
.38662 .57075 Mdot
.43197 .57595 Mdot
.47732 .58078 Mdot
.52268 .58572 Mdot
.56803 .59059 Mdot
.61338 .59451 Mdot
.65873 .59741 Mdot
.70408 .59952 Mdot
.74943 .60097 Mdot
.79478 .60193 Mdot
.84014 .60254 Mdot
.88549 .60292 Mdot
.93084 .60316 Mdot
.97619 .60332 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00:oooool2o`0003Kooooo0ol0000booooo`?o00001?ooool2o`0002oooooo0ol00003oooo
o`?o0000;_ooool5o`0000?ooooo0_l0000?ooooo`00:_ooool01?l0003oooooooooool0000doooo
o`05o`000?ooooooooooooooool00000<_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02cooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000>ooooo`00:_ooool01?l0003o
ooooooooool0000hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000kooooo000Zooooo`04o`000?oooooo
ooooo`0003Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0002oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0^ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`0<ooooo`00:_ooool01?l0003ooooo
ooooool0000dooooo`Co0000<oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
02oooooo00Co0000oooooooooooooooo1?l0000^ooooo`05o`000?ooooooooooooooool000000_oo
ool01?l0003oooooooooool0000>ooooo`00:_ooool01?l0003oooooooooool0000dooooo`03o`00
0?oooooooooo03?ooooo0_l00004ooooo`04o`000?ooooooooooo`0002kooooo0_l00003ooooo`03
o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000kooooo000[ooooo`;o0000=Oooool5o`0003;ooooo00?o0000ooooooooool00oooool2o`00
033ooooo00Co0000oooooooooooooooo1Ol0000^ooooo`?o00001?ooool2o`0000oooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Woooo
o`0300000?l0003o00000?Co00000@000001ooooo`009oooool00`00003oooooooooo`02ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool10000007ooooo000Wooooo`030000
0?oooooooooo00;ooooo0_oo000gooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0
=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009ooo
ool01000003o0000ooooooooool4ool003Kooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03Oooool1o`0000400000
0Oooool002Oooooo00@00000oooooooooooooooo1?oo000fooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo
0@000001ooooo`009oooool00`00003oooooooooo`02ooooo`;oo`00=oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0>ooooo`4000000Oooool002Oooooo00<00000ooooooooool00_ooool00`00003oooooooooo`0f
ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0e
ooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003oooooooooo`02oooo
o`0300000?oooooooooo03Kooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`03
00000?oooooooooo00?ooooo00<00000ooooooooool0=Oooool00`0007ooooooooooo`0eooooo`03
0000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`40
00000Oooool002Oooooo00<00000o`000?ooool00oooool00`00003oooooooooo`0eooooo`030000
Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000
Oooooooooooo00gooooo0Ol000010000007ooooo000Wooooo`0300000?oooooooooo00?ooooo00<0
0000ooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000
ooooooooool00oooool00`00003oooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001o
ooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001
ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005oooo
o`0300000?oooooooooo00?ooooo00<00000ooooooooool0=Oooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>oooo
o`4000000Oooool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00004ooooo`0300000?oooooooooo00?ooooo00<00000ooooooooool0=Oooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0>ooooo`4000000Oooool000Go00000oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l00`0007l00`000000001o0000O`3]
0000O`7o00000@000001ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool00`00003oooooooooo`0eooooo`03
0000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`03
0000Oooooooooooo00kooooo0@000001ooooo`002?ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool00oooool00`00003ooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`001oooool2o`0000Cooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`04ooooo`0300000?oooooooooo
03Cooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo
03Gooooo00<0001oooooooooool03_ooool10000007ooooo0008ooooo`03o`000?oooooooooo00?o
oooo0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00Co
oooo00<00000ooooooooool0=?ooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Go
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo
00<00000ooooooooool01?ooool00`00003oooooooooo`0dooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo
0@000001ooooo`009oooool00`00003o0000ooooo`04ooooo`0300000?oooooooooo03Cooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool03Oooool1o`00004000000Oooool002Oooooo00<00000ooooooooool01?ooool0
0`00003oooooooooo`0dooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool0
0`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00
003oooooooooo`04ooooo`0300000?oooooooooo03Cooooo00<0001oooooooooool0=Oooool00`00
07ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000
007ooooo000Wooooo`0300000?oooooooooo00Cooooo00<00000ooooooooool0=?ooool00`0007oo
ooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oo
ooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000ooooooooool01?ooool00`00003ooooo
ooooo`0dooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003ooooooooo
o`04ooooo`0300000?oooooooooo03Cooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000W
ooooo`0300000?l0003ooooo00Gooooo00<00000ooooooooool0<oooool00`0007ooooooooooo`0e
ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0=
ooooo`7o00000@000001ooooo`009oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo
03?ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo
03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo00Go
oooo00<00000ooooooooool0<oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Go
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo
00<00000ooooooooool01Oooool00`00003oooooooooo`0cooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo
0@000001ooooo`009oooool00`00003oooooooooo`05ooooo`0300000?oooooooooo03?ooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?l0003ooooo00Gooooo00<00000
ooooooooool0<oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001o
ooooooooool0=Oooool00`0007ooooooooooo`0=ooooo`7o00000@000001ooooo`009oooool00`00
003oooooooooo`05ooooo`0300000?oooooooooo03?ooooo00<0001oooooooooool0=Oooool00`00
07ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000
007ooooo000Wooooo`0300000?oooooooooo00Gooooo00<00000ooooooooool0<oooool00`0007oo
ooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oo
ooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000ooooooooool01Oooool00`00003ooooo
ooooo`0cooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003ooooooooo
o`06ooooo`0300000?oooooooooo03;ooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000W
ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0<_ooool00`0007ooooooooooo`0e
ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>
ooooo`4000000Oooool002Oooooo00<00000o`000?ooool01_ooool00`00003oooooooooo`0boooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo00gooooo0Ol000010000007ooooo000Wooooo`0300000?oooooooooo00Ko
oooo00<00000ooooooooool0<_ooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Go
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo
00<00000ooooooooool01_ooool00`00003oooooooooo`0booooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo
0@000001ooooo`008?ooool2o`0000Gooooo00<00000ooooooooool01_ooool00`00003ooooooooo
o`0booooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`007oooool01?l0003oooooooooool0
0004ooooo`0300000?oooooooooo00Kooooo00<00000ooooooooool0<_ooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0>ooooo`4000000Oooool001oooooo00Co0000oooooooooooo00001?ooool00`00003ooooooooo
o`06ooooo`0300000?oooooooooo03;ooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000O
ooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`00000007l01P0007l00`000000001o0000
O`3Z0000O`7o00000@000001ooooo`007oooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo00Oooooo00<00000ooooooooool0<Oooool00`0007ooooooooooo`0eooooo`030000Oooo
oooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Ooo
ool001oooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`07ooooo`0300000?oo
oooooooo037ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooo
oooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Pooooo`;o00001Oooool0
0`00003oooooooooo`07ooooo`0300000?oooooooooo037ooooo00<0001oooooooooool0=Oooool0
0`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool1
0000007ooooo000Wooooo`0300000?oooooooooo00Oooooo00<00000ooooooooool0<Oooool00`00
07ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`00
07ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000ooooooooool01oooool00`00003o
ooooooooo`0aooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oo
ooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003o0000
ooooo`07ooooo`0300000?oooooooooo037ooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03Oooool1o`0000400000
0Oooool002Oooooo00<00000ooooooooool01oooool00`00003oooooooooo`0aooooo`030000Oooo
oooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooo
oooooooo00kooooo0@000001ooooo`009oooool00`00003oooooooooo`07ooooo`0300000?oooooo
oooo037ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooo
oooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo
00Oooooo00<00000ooooooooool0<Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo
03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oo
oooo00<00000ooooooooool02?ooool00`00003oooooooooo`0`ooooo`030000Oooooooooooo03Go
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00ko
oooo0@000001ooooo`009oooool00`00003o0000ooooo`08ooooo`0300000?oooooooooo033ooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool03Oooool1o`00004000000Oooool002Oooooo00<00000ooooooooool02?oo
ool00`00003oooooooooo`0`ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Ooo
ool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool0
0`00003oooooooooo`08ooooo`0300000?oooooooooo033ooooo00<0001oooooooooool0=Oooool0
0`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool1
0000007ooooo000Wooooo`0300000?oooooooooo00Sooooo00<00000ooooooooool0<?ooool00`00
07ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`00
07ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000ooooooooool02?ooool00`00003o
ooooooooo`0`ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oo
ooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003ooooo
ooooo`08ooooo`0300000?oooooooooo033ooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo
000Wooooo`0300000?l0003ooooo00Sooooo00<00000ooooooooool0<?ooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0=ooooo`7o00000@000001ooooo`009oooool00`00003oooooooooo`08ooooo`0300000?oooooo
oooo033ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooo
oooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo
00Wooooo00<00000ooooooooool0;oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo
03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oo
oooo00<00000ooooooooool02Oooool00`00003oooooooooo`0_ooooo`030000Oooooooooooo03Go
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00ko
oooo0@000001ooooo`009oooool00`00003oooooooooo`09ooooo`0300000?oooooooooo02oooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo00Wooooo00<0
0000ooooooooool0;oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000
o`000?ooool02Oooool00`00003oooooooooo`0_ooooo`030000Oooooooooooo03Gooooo00<0001o
ooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00gooooo0Ol00001
0000007ooooo000Wooooo`0300000?oooooooooo00Wooooo00<00000ooooooooool0;oooool00`00
07ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`00
07ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000ooooooooool02Oooool00`00003o
ooooooooo`0_ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oo
ooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`001oooool3o`0000Cooooo
0_l00004ooooo`;o00001?ooool2o`0000Cooooo0_l00005ooooo`0300000?oooooooooo00Wooooo
00<00000ooooooooool0;oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool000Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oooooo
oooo00Wooooo00<00000ooooooooool0;oooool00`0007ooooooooooo`0eooooo`030000Oooooooo
oooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool0
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03
00000?l00000001o00X0001o00<000000000O`0007l0iP0007l1o`00004000000Oooool000Sooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool0;_ooool00`0007ooooooooooo`0eooooo`030000Oooo
oooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Ooo
ool000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004oooo
o`0300000?oooooooooo00[ooooo00<00000ooooooooool0;_ooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>oooo
o`4000000Oooool000Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool02_ooool00`00003oooooooooo`0^ooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo
0@000001ooooo`002?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool2o`0000Cooooo0_l0
0004ooooo`;o00001Oooool00`00003oooooooooo`0:ooooo`0300000?oooooooooo02kooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo00[ooooo00<00000
ooooooooool0;_ooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001o
ooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000o`00
0?ooool02_ooool00`00003oooooooooo`0^ooooo`030000Oooooooooooo03Gooooo00<0001ooooo
ooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00gooooo0Ol000010000
007ooooo000Wooooo`0300000?oooooooooo00[ooooo00<00000ooooooooool0;_ooool00`0007oo
ooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oo
ooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000ooooooooool02_ooool00`00003ooooo
ooooo`0^ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003ooooooooo
o`0;ooooo`0300000?oooooooooo02gooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000W
ooooo`0300000?oooooooooo00_ooooo00<00000ooooooooool0;Oooool00`0007ooooooooooo`0e
ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>
ooooo`4000000Oooool002Oooooo00<00000ooooooooool02oooool00`00003oooooooooo`0]oooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003o0000ooooo`0;ooooo`03
00000?oooooooooo02gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`03
0000Oooooooooooo03Gooooo00<0001oooooooooool03Oooool1o`00004000000Oooool002Oooooo
00<00000ooooooooool02oooool00`00003oooooooooo`0]ooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo
0@000001ooooo`009oooool00`00003oooooooooo`0;ooooo`0300000?oooooooooo02gooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo00_ooooo00<00000
ooooooooool0;Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001o
ooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000oooo
ooooool02oooool00`00003oooooooooo`0]ooooo`030000Oooooooooooo03Gooooo00<0001ooooo
ooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001oooo
o`009oooool00`00003o0000ooooo`0;ooooo`0300000?oooooooooo02gooooo00<0001ooooooooo
ool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001ooooooooo
ool03Oooool1o`00004000000Oooool002Oooooo00<00000ooooooooool03?ooool00`00003ooooo
ooooo`0/ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003ooooooooo
o`0<ooooo`0300000?oooooooooo02cooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000W
ooooo`0300000?oooooooooo00cooooo00<00000ooooooooool0;?ooool00`0007ooooooooooo`0e
ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>
ooooo`4000000Oooool002Oooooo00<00000ooooooooool03?ooool00`00003oooooooooo`0/oooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003oooooooooo`0<ooooo`03
00000?oooooooooo02cooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`03
0000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`030000
0?l0003ooooo00cooooo00<00000ooooooooool0;?ooool00`0007ooooooooooo`0eooooo`030000
Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0=ooooo`7o0000
0@000001ooooo`009oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo02cooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo00cooooo00<00000
ooooooooool0;?ooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001o
ooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool000Kooooo1Ol00003oooo
o`;o00001?ooool2o`0000Cooooo0_l00004ooooo`;o00001Oooool00`00003oooooooooo`0<oooo
o`0300000?oooooooooo02cooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo0007ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003o
ooooooooo`0=ooooo`0300000?oooooooooo02_ooooo00<0001oooooooooool0=Oooool00`0007oo
ooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007o
oooo0008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001?oo
ool00`00003oooooooooo`0=ooooo`0300000?oooooooooo02_ooooo00<0001oooooooooool0=Ooo
ool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_oo
ool10000007ooooo0009ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`0300000?l00000001o00d0001o00<000000000O`0007l0h`0007l1o`00
004000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool03Oooool00`00003oooooooooo`0[ooooo`03
0000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`03
0000Oooooooooooo00kooooo0@000001ooooo`001_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`0=ooooo`030000
0?oooooooooo02_ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000
Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo0007ooooo`?o00001?oo
ool2o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool03Ooo
ool00`00003oooooooooo`0[ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Ooo
ool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool0
0`00003oooooooooo`0=ooooo`0300000?oooooooooo02_ooooo00<0001oooooooooool0=Oooool0
0`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool1
0000007ooooo000Wooooo`0300000?oooooooooo00gooooo00<00000ooooooooool0:oooool00`00
07ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`00
07ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000o`000?ooool03Oooool00`00003o
ooooooooo`0[ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oo
ooooooooo`0eooooo`030000Oooooooooooo00gooooo0Ol000010000007ooooo000Wooooo`030000
0?oooooooooo00kooooo00<00000ooooooooool0:_ooool00`0007ooooooooooo`0eooooo`030000
Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`400000
0Oooool002Oooooo00<00000ooooooooool03_ooool00`00003oooooooooo`0Zooooo`030000Oooo
oooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooo
oooooooo00kooooo0@000001ooooo`009oooool00`00003oooooooooo`0>ooooo`0300000?oooooo
oooo02[ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooo
oooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo
00gooooo0_oo000/ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`00
07ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003o
0000ooooo`0<ooooo`Coo`00:oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Go
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0=ooooo`7o00000@000001ooooo`00
9oooool00`00003oooooooooo`0<ooooo`Coo`0000<00000ooooooooool0:?ooool00`0007oooooo
ooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooo
ooooo`0>ooooo`4000000Oooool002Oooooo00<00000ooooooooool03Oooool2ool000;ooooo00<0
0000ooooooooool09oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<00000
ooooooooool04_ooool00`00003oooooooooo`0Vooooo`030000Oooooooooooo03Gooooo00<0001o
ooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@000001
ooooo`009oooool00`00003oooooooooo`0Cooooo`8000009_ooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>oooo
o`4000000Oooool002Oooooo00<00000ooooooooool05Oooool00`00003oooooooooo`0Sooooo`03
0000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`03
0000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003o0000ooooo`0Fooooo`030000
0?oooooooooo02;ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000
Oooooooooooo03Gooooo00<0001oooooooooool03Oooool1o`00004000000Oooool002Oooooo00<0
0000ooooooooool05oooool00`00003oooooooooo`0Qooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00kooooo0@00
0001ooooo`009oooool00`00003oooooooooo`0Hooooo`;oo`008Oooool00`0007ooooooooooo`0e
ooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>
ooooo`4000000Oooool002Oooooo00<00000ooooooooool05oooool4ool0023ooooo00<0001ooooo
ooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001ooooo
ooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo01Oooooo1?oo0002000001ko
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Go
oooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo01Sooooo
0_oo0003ooooo`8000007?ooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oooooo00<0
0000o`000?ooool07oooool00`00003oooooooooo`0Iooooo`030000Oooooooooooo03Gooooo00<0
001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00gooooo0Ol0
00010000007ooooo000Wooooo`0300000?oooooooooo023ooooo0P00000Iooooo`030000Oooooooo
oooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooo
oooo00kooooo0@000001ooooo`009oooool00`00003oooooooooo`0Rooooo`0300000?oo003oo`00
01Kooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo
03Gooooo00<0001oooooooooool03_ooool10000007ooooo0007ooooo`?o00001?ooool2o`0000Co
oooo0_l00004ooooo`;o00001?ooool2o`0000Gooooo00<00000ooooooooool08_ooool4ool00003
00000?oooooooooo01;ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`03
0000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo0006ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`030000
0?oooooooooo02;ooooo1?oo00000oooool00000000000020000013ooooo00<0001oooooooooool0
=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0
3_ooool10000007ooooo000:ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00_ooool00`00003o00000000O`0S0000O`;oo`001P0007l3000000030000Oooo003o
o`000<80001o0Ol000010000007ooooo0008ooooo`;o00000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooo
ooooool00004ooooo`0300000?oooooooooo02kooooo1?oo0009ooooo`030000Oooooooooooo03Go
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00ko
oooo0@000001ooooo`002_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00;ooooo00<00000ooooooooool0;_ooool4ool000@000001Oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007oooooooooo
o`0>ooooo`4000000Oooool000Kooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0;oooool2ool000Gooooo10000002
ool003Oooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooo
oooo00kooooo0@000001ooooo`001oooool3o`0000Cooooo0_l00004ooooo`;o00001?ooool2o`00
00Cooooo0_l00005ooooo`0300000?oooooooooo03Wooooo1?oo000fooooo`030000Oooooooooooo
03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Oooool002Oo
oooo00<00000ooooooooool0>Oooool4ool000<00000<oooool00`0007ooooooooooo`0eooooo`03
0000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`030000
0?l0003ooooo03[ooooo0_oo0004ooooo`<00000<?ooool00`0007ooooooooooo`0eooooo`030000
Oooooooooooo03Gooooo00<0001oooooooooool03Oooool1o`00004000000Oooool002Oooooo00<0
0000ooooooooool0>oooool00`0007ooooooooooo`05ooooo`8000000_oo000/ooooo`030000Oooo
oooooooo03Gooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`4000000Ooo
ool002Oooooo00<00000ooooooooool0>oooool00`0007ooooooooooo`06ooooo`Coo`0000<00000
ooooooooool0:?ooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo03Gooooo00<0001o
ooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo03_ooooo00<0001ooooo
ooooool01_ooool4ool00003ooooo`0000000000008000009_ooool00`0007ooooooooooo`0eoooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`03
00000?oooooooooo03_ooooo00<0001oooooooooool01oooool2ool000Kooooo0`000002ool0027o
oooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000Oooooooooooo00ko
oooo0@000001ooooo`009oooool00`00003oooooooooo`0kooooo`030000Oooooooooooo017ooooo
1?oo0002000001kooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0eooooo`030000
Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003o0000ooooo`0kooooo`030000Oooo
oooooooo017ooooo1?oo0002ooooo`D0000000?oooooool00?oo00005_ooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Gooooo00<0001oooooooooool03Oooool1o`00004000000Ooo
ool002Oooooo00<00000ooooooooool0>oooool00`0007ooooooooooo`0Booooo`;oo`002?ooool4
ool000D000001?ooool2ool000[ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0e
ooooo`030000Oooooooooooo00kooooo0@000001ooooo`009oooool00`00003oooooooooo`0koooo
o`030000Oooooooooooo01cooooo1?oo0005ooooo`<000001?oo0005000000?ooooo0_oo000goooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`03
00000?oooooooooo03_ooooo00<0001oooooooooool07Oooool2ool000Wooooo1?oo0005ooooo`80
00001?oo0002000003Cooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`0>ooooo`40
00000Oooool002Oooooo00<00000ooooooooool0>oooool00`0007ooooooooooo`0Yooooo`;oo`00
2?ooool4ool000;ooooo1@0000000oooooooo`00ool0000/ooooo`030000Oooooooooooo03Gooooo
00<0001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo03_ooooo00<0
001oooooooooool0=?ooool2ool000Sooooo1?oo0005000000?ooooo0_oo000Qooooo`030000Oooo
oooooooo03Gooooo00<0001oooooooooool03_ooool10000007ooooo000Wooooo`0300000?l0003o
oooo03_ooooo00<0001oooooooooool0=Oooool00`0007ooooooooooo`06ooooo`Coo`001Oooool2
000000Coo`001@000004ooooo`;oo`002Oooool2ool000[ooooo00<0001oooooooooool0=Oooool0
0`0007ooooooooooo`0=ooooo`7o00000@000001ooooo`009oooool00`00003oooooooooo`0koooo
o`030000Oooooooooooo03Gooooo00<0001oooooooooool01oooool2ool000Sooooo1?oo0005oooo
o`<000001?oo0005000000;ooooo1?oo0008ooooo`;oo`002Oooool2ool002cooooo00<0001ooooo
ooooool03_ooool10000007ooooo000Wooooo`0300000?oooooooooo03_ooooo00<0001ooooooooo
ool0=Oooool00`0007ooooooooooo`0Booooo`;oo`002Oooool4ool000Gooooo0P000004ool000L0
00001?oo0007000000Coo`001@000004ooooo`;oo`002Oooool2ool000Wooooo0_oo0009ooooo`;o
o`002_ooool2ool000Cooooo0@000001ooooo`009oooool00`00003oooooooooo`0kooooo`030000
Oooooooooooo03Gooooo00<0001oooooooooool07_ooool2ool000Wooooo0_oo0008ooooo`Coo`00
1oooool4ool000Gooooo0`000004ool000L000001?oo0007000000Coo`001`000004ool000P00000
1?oo0003ooooo`4000000Oooool002Oooooo00<00000ooooooooool0>oooool00`0007oooooooooo
o`0eooooo`030000Oooooooooooo03Cooooo0_oo0009ooooo`;oo`002Oooool4ool000Oooooo1?oo
0007ooooo`Coo`001oooool4ool000Sooooo1?oo0003ooooo`4000000Oooool002Oooooo00<00000
o`000?ooool00_ooool00`00003oooooooooo`0fooooo`0300000?oooooooooo03Gooooo00<00000
ooooooooool0=Oooool00`00003oooooooooo`0Cooooo`;oo`002Oooool2ool000Wooooo0_oo0009
ooooo`;oo`002_ooool2ool000?ooooo0Ol000010000007ooooo000Wooooo`0300000?oooooooooo
00;ooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00`00003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00<00000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`0300000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool10000007ooooo000WooooooP000000Oooool00?oooooo
8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-4.00444, -21484.9, \
0.0889919, 350.617}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Image classification", "Subsection"],

Cell[BoxData[{
    \(\(lpdf1 = 
        Log[MixtureLikelihoodNative[{x, y, z}, 
            model1]];\)\), "\[IndentingNewLine]", 
    \(\(lpdf2 = 
        Log[MixtureLikelihoodNative[{x, y, z}, model2]];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(class1 = 
        ClassifyImage3DAugmented[obj1, lpdf1, lpdf2, 255. ];\)\), "\n", 
    \(\(class2 = 
        ClassifyImage3DAugmented[obj2, lpdf1, lpdf2, 255. ];\)\), "\n", 
    \(\(Show[GraphicsArray[{{obj1, class1}, {obj2, class2}}], \ 
        ImageSize \[Rule] 400];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55495 
%%ImageSize: 400 221.978 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.013213 0.47619 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.013213 0.477324 0.264889 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7E7E5CBCCC7D1D2CDECECEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F8F7F3DCDBD7B2B1AF7E7D7B4C4B472E2D2935343053524E
777672A5A6A1CCCCCAE9E9E700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00DCD8D59C999466635C3F3C3527241F2D2A25282421302C29322F2A2F2C27
2926212827222E2F274748428B8C86EDEEE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F6F7F2AEADA943403B221D17211E15302D243C3731433E3A443F3B4C4441524B45554E48
544F494D4A4137342B2222181B1B135E5F59D0D1CC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E0E1DC
7D7C7734312A1D181228241B353128413D3440393339312E3D3532423836473E3949403B
4D443D50493F494238433F363532291D1D153E3D39ADACAA00FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3E3E15F5E59
28251E2521181F1B1237332A403C333B372E37302A342C293F3533403634433834443933
3F342E3F362D483F364A43394B473C3C39302825202A2925A5A5A300FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F4F4F27B7A7525251D
2C2920242017322B21463F353B342A4740363D342D342B26362F29352E283C332E393029
3B322B4A41384F473C423A2F433F334A483C37342D1F1E193C3D38D6D6D400FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A3A09B28251E26231C
2F2A24261F17342B244A4138372E253F362D494039393029302722382F2A3D342F362D26
433A31534A414F453B40362C403A2E4A463B46433A2827221E1D196E6E6CF4F4F400FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFF5F4FFF6F3FFF4F0FFF4F0FFF5F2FFF5F2FFF6F2FFF8F3CBBEB83C332C2017122A231D
312A242A231D2D221E463B37392E2A2E231D4237333F34303227213B302A443933382D27
3E342B4F453C493C343A30273A3128453E34514D442B2A2523221E21211FABA9AA00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFEEE8E8D1CBE1C9C5D8C3C0D4C2C0D5C3C1DBC9C7D2BDBCD5BBBCDEBEBFD1AAABC09495
CC9A99CB9894C48F89B9847EB7857EAF7E77A0756E92706760453C27150B251812312823
2E24222A201E291E1C382D2B4136322F2420372C283A2F2B3A2F29423731514640433832
3F362D4A4037362C2330261D372E25474038443F392B282326221F1B1716484242E7DEDF
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDEDEDAFAFAF6A6A68
6565636566616565636667626768636A6B668E8E8CBBBBB9D3D3D1E8E8E600FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FCD5CE
BF897F894D42A47065A97C76825D5783625DA4817FA27A78A47474B37978A55D5E8F3E3D
A34A46A64741A6453C9F3F33A34539953D3186382B7A3C2F5F332633150B28150E352724
3329272E24222A201E2C2220342A28372D2B382D293D322E393029443B34534A414F463D
4740363E372D302720281F1841383148413B372F2C2D2523251C1D271B1B251214887473
DCCAC6E0D1CAE6D9D1E9DFD6F1E7DDF8EFE6FFF6EFFFFDF500FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEECACAEAB5959572525231A1917
1716121918131B1A161E1D181718120F100A1A1B1623241F2C2E29474944646663878986
AEB0ADE2E4E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFEAE7E5AEA9B26960
9C493B903D2DD08B7CBD83789867608E635D9467629A6764A96C6BC37978C86E6DA9413E
BB4A44BE473FC84D45C54B40C54D3FBD4C3EA33F2FAB584881433442180C2C0F0934211D
3729263328263126242E24222B211F2F2523382D293A2F2B3A312C3F362F423932403931
3F3B3239352C37302A3F383238302D362E2B312927281E1D2D1F1F3420222B0E1040211E
513329593C2E6D5241644E396D5941745F4A7B6955806D5C897665917E6DA18C7BAE988A
BAA496C8B2A5D5BDB3DBC4BCE0CBC6E6D3CFECDAD6F1E2DFF4E9E5FAF0EE00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00F2F2F0AFAFAD5757551E201B1516111F1E1A201F1B
1C1B161C1B162926212828201D1D151D1E161D1E18181913161711161912151712161815
1719164E504DD6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F5FFCECAD0837DB64F46BA4A3E
B045359C3D2BE29585C6887BB48075976860A3736FB27C7AAD6D6BCA7C7ADC7E7CB44845
C34E47C24740D3544DCE4E45CF5145CA5043AE3E30BE5D4D964A3C50160A360E06391D19
3723223424243A2C2B2F24222F2420302521342623332824372E29372E2938312B3A332D
3E393336312B362E2B372F2C2B23212B23212B2122302222352123381B1D320A0B552521
6A392B6B3B257A4D305E36125F391258350B5B350E5B3510552F0A59330E5C3410693E1C
5C2D1168341E672E1B632A19672F226E3A2F73473E734C4576554E7A5D578265618D6F6D
957673A58683AF908DB99A95C4A7A3CFB3AFD9C0BCDDC8C5E2CFCBE7D5D1EDDEDBF3E4E1
F9EBEAFEF3F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00C6C6C465666123241F171813151611191A15201F1B21201B
2F2C27302D26342F2937342D37342D39392F33332B26271F1C1D15181911151811131510
1217131015114A4C4BD2D4D300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F4DBAFACB4615BB6463BCB473BD04B3C
BF4635A83F2CE89583CB8878B97F73AB756BAF766FAA6D689D5652B6615EDB7873BF4E48
C94E47CC4B45D24D46D55047D14C43D04D43BC4034C25143BB5B4D6D1F124307003F120D
3F1D1B3A201F3723223523213A2B283A2B283D2E2B3B2D2A3328263026242E24222F2724
332B282C24212A222029211F2920212B21222D1F1F331F213E2123381112390605652A24
7D3F307C4026915B37794A1E794D1E754B197E5221805423764A197446157545177F4A1E
6F330E77351585391F873B247E35247A362970372C5A2A20542C244B261E4A231E4A2220
502723542B27542B25572E28532C254F2A224C2B24563732593C3660453E684C496F5652
745C587D6561866E6A937B779C8782A9948FB5A09DC1ACA9C9B4B1D7C2BFDEC9C6E5D0CD
EAD7D3F0DDD9F6E7E2FBEEE8FEF5EEFFFDF2FFFFF4FFFFF3FFFEF500FF0000FF0000FF00
00FF0000FF00E2E2E08888863435301C1D181A1B161C1D18191A151617122A2924393631
403B3538332D322D27322D2734312A38352C33302731312734342A2E2F2722231D13160F
171914161815181A19505251D6D6D600FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FCD3CFA15650BC4A40D24A3ED44537D24635
C64736AC3D2AE68E7AC77C69B97465A76356904A40A65B559D4843C0615BE87B74C14840
CE4D47D14A44D64D47DB5049D84D46D54B41CB4136C94539D55D4FAE4436731910540B04
49120D451C183C1D1A381F1B3A25203C292542302E40312E3A2F2D3E33313429272D2321
342A2933292831272833292A302426312323341E203A1C1E441C1D3E0B0A480806753128
8A46338D4D32AB775294673D855C2E845E2D8A653198703D926A37956C389567369C693A
975C309B57308D3E1D8F3F249247308C4A3A6731275A2F288A685E85645B7C5953835D5A
8259555C302D643933653D35522C23542F2657352C59382F502F26502F264D2A264C2925
4F2C2848251F4E29234E2923502922532C25502922522923562924602D29682E2A6F342E
773E377D493E805044825B4A7F634E7F6B508D8262948E6C9D987AA7A58CADAC9ABBBBAF
C2C3BBA8A9A34D4E491D1E191C1D1721221C1D1C181E1D191F1E1A26252143403B312E29
2C2723302B2728231F2B26202F2A24312C2628231D28231D302D2633332B31302B23241E
1718131516111C1C1A191917505050E0E0E000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF6F3DCA098A7453AD04C40D64234D74132D54433
C74231B13928E27B68EB907DCC7466B75F53B55B52C5645DD16A63F0817ADF645DCA473F
D54C44D84B44D74840DD4E46DE4F47DD4D44D7443ACC3C31DD5346D25245BA453B8C271D
5F0F0653130A4B1610461914411C16401F1A3B1D1B3B212039211F3C2726372322362221
3A2828362424301C1D372123391F223C1C1F3E16174715164D0F104E040365120C903C31
9746339E563DAE76538F5F3782572D7852256B4518724C1D744C1B895F2D865A2B8E5B2C
884F229E5D33A45834974A2C954D358A4B3A55231A835D54AD8C83A1837BA88581B8928F
976E6C59302E633A36502922805B5298766C97756B916F658D685F8C655E8A615B875C56
865D577D544E774F47734B436C443C663B326539305B2A23692F2B6B27247C2E2A802D27
7D2A227B2D20722B19682E165227055C3F1567562260551F5A52235B562E5D5A3B5F5E49
3D3E301011091516101E1F1920211B1F201A201F1B1F1E1A1A19153A39353A3732292621
29262127241F25201C322D292F2A242B26202C24212B26222C272326231C2B282335342F
23241F191A151C1C1A1D1D1B16161689898900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFE7E3B76861BE4C41D3493CD64031D73F31D03D2D
D44736C23D2CDD6453FD8A78F38176E8736AE66D65DD605AD85952D8534CCD443CD3463D
D84A40D7473EDC4941DD4841E14C45DD493FDA433AD74035D94539DF5042DE5447CF5143
B1413389271A6B140A570D0453120C511713481512491917441B194921213A13143C181A
3E1A1A3C181841191A4115164715184B1012530D0F5807066607057A110D9F322BAD4336
AA4B379E4C34B26F5299614083512E885A387448255E340E6F451B7D52276D40177A4920
743E12995B32A86240944D3195533D7B41336C3D35B08B83B19089AE9088B59290BE9798
724A4B5B3435512E2C674641B3928BAC8E84AE8D84AA887FB68D87B58883A77672A77671
AB7E78A98179A38178A080759A7C7199796E96746A976C65A7726E7B37347B2725963934
97342E94342689341F8039196C380988642A856C29786721766B2B79723B817C528E8D6F
65645208080016160E23221D24231E21201B27241F201D181A171243403B2B2A25201F1A
2625201E1D18231E184B443E35302A25201A2D28242B26222A2521231E1A2A252135322D
3C3B361B1C171616141D1D1B181A1740423FE4E4E400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECC3BFAC4F47C84A3ED94B3DD64031D94133D43E2F
DE4B3BD84B3ACC4434DE594AD85247D95048DA4F48D4473ED4453DD24239D6433BD8443A
D64238D9453BD94239DC453CDF463EDA4237DA4139D84035DC4236E0483AE95345E45746
D85344CB5040AF3D328F291D72140C610C075B0C08570D0A5912105612114E0C0D501011
4D0D0E521011520E0F52080959090C5F06086C080A8212119F2522B4352EC5453CBE4638
B04734A54A35B86C54AE6C52A1654BA56D549761478350338B5A3A885736804E2D8C5634
7F4422B57655B372549151388E5341632F228F645DC8A39DBD9A94C09D99CDA6A7AB8286
62393D663F424D2B2A997A77B79893B1938BB4918BBE958FC796928D5653854A46864C48
8150497B50497D5B52A5897EA58A7FA4897EA4867CAC857EBD8785702C2B7D27269E3C39
9A332C9D392A943A22883C18793F0D9B72328D71278170227E712B8B8247948D5F9E9B7A
7978640E0E0217170F26252025241F221F1A27241F23201B201D18403D3835342F1E1D18
20211B191813231E1859544E35302A241F192A252126211D241F1B26211D25201C2C2924
41403B23241E191A151B1B191F211E20221FAFAFAF00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF4F2C68F8CAE4740CE4940D64739DC4638DA4235DB4335
DE4839D84436DA483BDD4B3EDE4C3FDF4C42D9453BDA463CD9453BDC453AD94136D94136
D84035D94136DB4338D84035DA4036D83E32D93F35DC4236D93F33E2483CEB5346E55143
E05141DE5243DE584CD8584DCC5046B53E36A3322C8E211C8317147B120F78100F740C0B
700A08740C0B7D13138115158D1A1D9E2627AE2E2DC8413ED24440D84B42CF463CC84A3C
B74837AC4B3AC57260AC6352A05B4BA461519B59499F5E4CA46651B1735E9F5E4AA96854
A3614BB1705CAC6D5B995E4E774336603129966D67AF8A84AF8986B6908FCAA0A4895C63
673C4360373B664242C19F9DC1A09BC09D97C29995DDABAAB2757477312F944A4797524D
8D544D6839316B443DB0928AAC8F87AB8E86AE8D86C39A949F69676622218E3A389C3F3A
9C3B329D402F98442A863E1886511DA1793B8E732C8A7830807533968D549B9468A8A383
89867316140817140D29262125221D25221D26221F24211C21201B33322D3E3D3921201C
1C1B1712110C27241D57524C433F361F1A14211E1724211C26231E221F1A1E1B142D2A23
45453D22231D22231E1D1D1B1B1D1A17191668686600FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FEDBD7A45F58BA4941D2483ED9473ADC4638DF4539DE4438
DB4335E0483BE1493CE1493EE2483CDE4639DE463BDE463BDF473ADD4538DD4337D93F33
DB4135DF4539DB4137DA4036DB4135D93F33DD4337D93F33DC4335E1483AE85042E95143
E85243EE5B4BE85649E9594EE95D50EE6459EA6459E46157E15E56D34F4ACF4E48CC4B46
C2423FBE3E3BC44443D95757D75253DA5050E15150E34F4BE74F4ADE4942D7493FC94739
B74636AC4B3AC87565B86F60A15C4D9B594B854335884638935143A56355955345975547
955647985A4D885043B17F745A2E257E5750B8938DAD8A86B28C8BB99192AD8085693C43
70464A50292C866262AB8987A88782B08B85BB8B8BD096958E46478333329E4D4A9D524D
91544F5F2E27916A63C2A19AB99C94BA9D95BF9E97CEA7A2794645713433934747994844
9A483D9548368F472F804422916234A8854D977D408F7D3F8C7F489C9463A19972ACA789
9996831F1D1113100928252027241F26231E27232021201C25241F23221D33322E393836
1918140B0A05312E274C494249453C1F1B121D1A13211E17221F1A1E1B161D1A133A3A32
3E3F3721221C21221D1B1B1919191713131130302EBABAB800FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF7F5DFAAA49F483FC44B40D64A3DD84637DD4738DF4539E3493D
E95144E85043E3493DDC4236E2463ADE4438E0463AE2483CDE4438E3493DE4483CE2483C
E04739DF4739E2483CDE4438E1473BDF4539DF4638DE4537E04737E14838E64D3DE64F3E
EB5544ED5746F15E4EED5B4CED5B4CEE5C4DEB5C4EEE6052ED5F51ED6154EE6157F3665D
EC615ADE554FE55E5BF66E6EF16767E55658EB5757EB5350E54D48E04B44D44439CA4639
B74636AB4C3AAE614FA36250995E4C9C65519A634F9F6756955D4E9961549860539B6559
9561548E5E527F534AA67E7663403AA98883C19F9DBB9997C6A09FD8B0B18D636763393D
623B3C563433B49592B69794B79691B8908ECD9797BB76797E2D2C9B43429F4A479B504B
7E433D62332BAB867EB08F86B0928AB4968EBE9D98A8827F6D3F3F875453905654915650
965C51925A4B8F5C4983573C9672509D8058947D51917E538F82589C936CAAA18298927A
B6B3A2413F330C0B0623221E28272324231F24231F22211D2524201F201B22222033342F
34332E24241C2F2C2535322B3C3930221F161E1B1217140B19191120201832312C3B3C36
2728221F201A201F1B21201C1C1B171A19151716122C2D28858583A4A6A3D1D3D0EBEDEA
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF0ECB9766EAA453BCE5044D44638DC483ADA4435E85043F0584B
EA5245E44C3FDB4336DE4639E0483BE1493CE24C3EDE483AE34B40E1493CE0483DE34B3E
DF493BE14B3DE0483DE34B40E1493EE1493CE1493BDF4837E34C39E14C38E24F3BDE4E36
DE5136E85C41EE6249EE6249EC6047EA5E45EE624BE95E47EE624BEB5E4AEB5E4CEC5F4E
EB5C4EE95B4FEB5E55F96B67FA6B67EB5A57ED5854EB534EE74E48DD463FD44137CB4539
BD4A38AF4E3B8A3C268F4E38894F378B553D834F378A583F8E5C458757418556428A5D4A
8F66548B665484635487675C6C4F47B29591BFA09DC09E9CCDA6A7C9A1A2683F456D4649
4E2C2B896A67C6A9A5BC9D9ABD9B99CB9F9EE5A9AB974C50832B2AA64B4AA14B4A9B514E
5D2621865B54BD9890B19089B89790B89591CCA4A27C525367373782504F65322F703D39
68382E75473A693F2F623C297250375B3D21684D2F58412279664887785B7F7359948C77
BAB5A299978A1C1C1416151022211D25242027262221201C22211D1D1C1822211F282723
28272233332B3A37323C393239362F312E25312E2527271D33332B3837323A3B35262721
22231E1F201B22211D2625231D1C1A201F1B1716141313115F5F5D6163606C6E69858681
A3A49FC9CAC5E7E7E500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00EECDC8A05248BF5045D14D41D94A3CDB4739E44E40EB5547ED5749
E54F41DD493BDE4A3CE14F40DB4C3EDA4B3DDD4E40DC4D3FE14E44E35144DE4B41DE4C3F
E04E41E04E41E14D43DF4B41E14A41DD463BE04A3CE04A39DF4E39E0543BD44D2FCD4D2A
CF512BD1562DDC6138E1653FE86C46E46844DF6341E06442E16241E56444E76446EE664C
EC614AEC5F4BEE5F4FF26355FA675DE9564CE8514AE75049E14A41DD463DD6433BCD4539
C74D3EAC45328A341DAC6247AF6C4FA96C4D8C543395603E8C5A3981533181563485613F
7F5E3D674D2C6F5638725A42593F309E8277C3A29DC4A19FD9B2B39F7778633C41633F43
4E2E2FB69896C2A4A2BE9F9CC29C9BD8A6A7D08E907C2C2F95393AAB4D4DA25150823E3B
5B2824AF8682BE9B97B69590BC9995C9A09EC191915C282A763B3DAA706E8C524E97605B
9E6C659869618E6257865C508D66577F5A4894715D664631846853A2897375634DA89C86
B7B09DCDCAB98583771C1C141516101F201B29282425242025211E25221D211D1A1D1C17
1F1E1A2625202C2B272F2E2931302B32322A32322A34342C34332E2B2C2626272221221D
1F1F1D1A1A182624252624251B1B1B20201E1515151313116E6E6C6F706B6B6C6677776F
77776F75776C7E7F77999C93BCBDB7E1E2DCF5F6F100FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FFF7F5C1948F9B4339C84F44D1493DD7483AE24E40EC5647EF594AE85244
E24E40E65445E05141DC5041D54C3CE1594BEB6154E85C4FEB5D51ED5F53E85A4EE4564A
E6584CE5574BE5554CE5554CE45449E35046E65447DF503FE45944D85539DE6342E7734C
D56639D96D3ED5693AD86C3EE27648E4774CE07348D86B40EC7D50D7633AE16B43E76D48
E76646E86245DF573DE45942E25541DE4F3EE14F40DF4B3FE34C41DD463DDC483ED2453B
CC4C3FC04C3DAD4834CC7258C06C50BC7050AE6544AB69469B5F3BA16B45986842906942
8D6D477F6540836C4C806B5069503C94766BCAA7A3CCA5A6D7AFB0734A4E6F484D502D31
7A5C5CCCAEACBFA19FC5A3A2CAA2A2E0AEAFA66468752629A54C4EA650519F5554612524
805350CBA5A2B99795BE9B99C29997D9A9A99C61656624268E4848C27B79B26F69BB7A74
AB706AA56C65A26B64B58078BD8880B17F74AF7D729C6E5FA98271A3826F937A66B2A18D
B6AE99D1CEBBE2E0D366665E1415101515131D1C1A2625232C28252D2A2526231E1F1C17
1D1C1822211D26252122211D26252024251F25251D23231B1F201A21221D25252321211F
1D1D1B1919171F1D20211F221D1D1F2626281212141F1F218787877A7A7871706B808076
84847876766A74766977796E727469777870909189B4B5AFD7D8D3EEEEEC00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FCE0DD9C635CA44237CD4F41D2483BDA4839E6503FF15A49EB5544E65041
E95646E65747E25645E96453FA786AFC7D6EFC786BF0685AEE6457F26657F4685BF3675A
F56B60F2685DF3665CF2655BF1645AEE6157EE6255E96050E5604DD2563EE17052F98E6A
DA754BF49265F39164ED8C5FF19264EC905FF59968F39562F69864DC7C49E5814FDE7546
E5764BE5714AD55D38D85C3AD25332D65337D74C35E25140E14B3DE34C41E04C42D8483F
D54B41D65447DA5F50D5624FCC5F4ACC664DCA684DC76C51CB7A5DC37C5EAB6E4FAD7A5B
A9826387684B9E8368987E678366569F7F74CDA7A4DEB6B7BB919562373E6F484D522E32
AF8F90CCAEACC5A7A5C7A8A5D6AFB0D4A3A67B3E438A4347A15559A0585B894D4D562624
AD8784CBA9A7BF9D9BC49E9DD1A0A3D89DA17B3239873539A34D4CC8706CB05D55BD6F65
A55B529A514A9C564EB8726AC68078A25E55A25E55995B50905B4B8D6251A3826FBEA996
B9AE9ACBC6B3F3F1E4AEAEA631312F454547282629171518201F1D322E2B332F2C2D2926
27232027232024201D231F1C22211C1F1E1924251D23241C1B1C161D1E19222220222220
1E1E1C1E1E1C1F1D202220231F1F211F20240D0E135B5C61A2A1A67C7C7C7A797486867C
8A8A7E8182748384768082757E80737A7C6F75776A7173686B6D6286877FA2A39BC7C8C2
E5E6E100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00E4C1BD8A473FB1493ECF4D40D84A3CDA4737EE5847F05946E95342E54F3E
EA5747E65746E15544F26D5CFB7969F07162F97568EC6758EE6656EB6252F3675AF3675A
EE6459F46A5FF3665CF66A5DF46A5FF46A5DF2685BF36B5DF36E5DEF715BEA765DF68769
E87D59F48C65FA926BF79169FC9B71F49569FC9D71F99A6CEA8E5DED8F5CEA8A58EB8756
F98E62ED7E53E7734CF9835DEA724FFD8060E9634AD64834E24E40E34C41E04C42DF4C42
DC4C43E3564CDD5348DF5A4BE05E4ED45A45D45D47CE6049CE6A52C97159C0765DAF735B
87574198725DC8A592C0A091B39187B48F89D6AEAFE8BBC093646C71444B663D436E4A4C
D2B0B1CEB0AEC8ABA7CCAFABD9B7B6BD9395562427743C3F884D4F854F4F603232613B38
CAABA8C6A9A5C2A09FCBA1A3E7B0B5BD777F772229A14246AF4D4AA7463F993F369E473E
A7544CA4544BA75750A95A53A859529D4E47AC5D56A25950A2635493604FA6816FC4AA99
BAAD9AC3BDADE6E2D7E4E3DE3C3A3B3F3E435B585F58555C3C3A3D1A1917181715272322
302C2B403C3B29232328242127262223221D23241E23241F1A1A181C1C1A222222242424
2121212121232422272221261213180C0C140F0F1783838BABAAB0838383807F7A8C8C82
8C8C808B8C7E88887C898B7E888A7D8A8C7F888A7D83857877796C797B7075776C6F7166
7B7C74989993BABBB6DEDFDAF5F5F300FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00DAB1AB8F463DBC4D42D44E42D94A3CE65041EF5948EF5948E74F41E54F40
F15B4CE85545EA5B4AED604FED6454E75F4FE96151EA6252E86050EC6353F06455F16558
F1645AF5675DF6665BF06153F36559F26456EF6354EF6354EE6253F16A57EC6754EE6D57
EB6D54E66A4EEE7256EB7255EE7759EB7859ED7A5BF0825FF0865FFF9870FF956EED8059
F4825DED7753EA7250EF7455EA6E52FF8468F46D57D94C3AE35142DE4A3EDF4B41E24E44
DC493FDE4E43E15146DC4D3FE35645DE5241DB5441D95A47CF5C49CB6654BC6957A66152
72392EBB8C84D6ADA7D0A9A4C8A0A0CBA1A3E4B7BEDCAAB378445083515C5F343BA57E81
DCBCBDD2B4B2CCB3AFCDB4B0D5B7B5C8A9A7866262734F4F734D4C674442674845AB8F8B
CCB3AFC7ABA8CDA9ABDAABB1ECADB69747528E2F35B54E51AF4945A6433DB3564EB45B53
B56059A4514BAE5D59994844B86861AF5F58AA5A539F524A995548793F31946958CBAE9C
BEAD9BC2BBABD8D1C7F4F1EC7F7D801E1B223D3A4559565F615F64838184575558262425
2725262422231511122521202D2C2A2928262323212426252021231E1F2128292D292A2E
1B1C2018191E21202815131E30303C4D4F5B23232F666670B1B0B68B8B8B8988838A8A80
8E8E8291938690928781847964675E7E7F7783837B85857D7A7A728B8B818C8C82838377
8183787A7C716E6F67707169878882A8A9A4D2D2D0F0F0EE00FF0000FF0000FF0000FF00
00FF0000FF00
00FF00FFF9F3D1A59C96483CC05044D24C40DB4C3EE75143F25C4DEA5443E54D3FEB5345
EB5546ED5748EC5949F36152E85B4AEC604FEE6555E75F4FE25A4ADA5244E1594BE1574A
E1574CE95D50EA5C50EE6052EF6153EE6253F06455EE6253F16556F06455F16556F36756
EE6552F06955EF6653EF6854EC6853E96751E76650E46850E16A4CE26D4CEC7555EB7253
EA6F50EF7256EF6F54EB6B52E86A53EC6B55ED6653E45B49E95B4DE15146E5554AE25247
DF4F44E15146DF4D40E14F42E24E40E14F40E25345D95040D65748CD5C4CC964589F483F
904540E6A5A3EAAEAEE5AAAEE8ADB3EEB3B9FEBFC8C5838D7F3B468F4D576D343BDAA7AC
EDC1C2E1B9B9E2BCBBDEBABADCB8B8D9B5B5CEAAAACEACABC8A6A5C1A2A0C9ABA9D2B4B2
D3B5B3D4B2B3D9AFB3F3BAC3E294A1862934B4474DBE4C4CBF524DC45C53C5625CCB6C66
C26762AA514BBD6561B35E59BE6964B9645DD27E74B06154AC6354834633A57861CFB199
C4B29CC4BCA9CAC4B8E6E3DECAC8C92B282F36333E413E493E3B44B0ADB4D3D2D76C6C6E
7472754D4B4E5856574442433636361C1D1F23262B24292F1F232C1D212A1E212A191C25
2D2D3712121C201F2D21202E373946555764595B6873737DA9A8AD908F8D928F888F8D81
9192849193869B9D927B7E7540433C5B5C565B5A554E4D484F4E4957574F606056727268
83857A797B708183787C7E7372736B696A6261605C7776728D8C88CECDC900FF0000FF00
00FF0000FF00
00FF00FFF7F2C9998FA04E42C05042D24D3EDB4C3EEF5B4DEE5849EB5546E54D3FEF5749
EC5648EE584AF55F51EE5A4CE75848ED604FF56C5CFE7668F87465F77366F57164F26E61
EE6A5DE56152E76253E96153E25A4CE25A4EE45C50E75F53E95F52ED6152ED6152EE6251
EE6553ED6452F26655F16554F26655F26957EF6654F36C58EC6851EC6851EA664FEB6750
E96550E8644FF06C57F06C57EE6956EE6958F0685AF76F61F46C5EF3695CF06457EC6053
E65A4DE25649E6584CE15146E04D43E24F45E04D43E05246D85042D85649D25950B3433F
A94140B65658B75B60B85D64BC626BC76D76D27780AA4D57A0434BAE535A87353BD2858B
EBA4AAE7A6ACE7AAAFE9AEB4EBB2B8ECB5BAEAB6BAF0BEC1EABCBEEBBFC0EBC1C2E8BEC0
E9BCC1EBBAC0F0B7C0FFB9C4BC5F6A9B2C35CA4F52CC4F4DC94F4AC44F48D96965DA716D
CD6763B1504AC66763CD7069BF655DC1695FEE9688B1604BB3694E925634B78B66CFB18D
CDBD9CCBC4A8C3BDADD3D0C7EAEAE85A595E2E2D353E3C4733313C78777FEDECF25E5D62
383639484649BBB9BABBBBBD5D5E63565A63555B69484F61464E61424A5D21283A2C2F40
A6A8B72D2F3C2C2D3F3031433235442125313133405656609D9D9FA1A09C97948D979589
9495879395889EA0957C7D75555650767570706F6B4C4B474E4F4A4F504A2526205D5E56
484941393B307E807584867B7D7F747F7F777F7C757974704C4741524F4AE4E3E100FF00
00FF0000FF00
00FF00FFF5F1C18B81A75144C55144D24D3EE35446EF5B4DF05A4BE65041EA5445EE5849
ED5749F15B4DF35C51F15A4FEE5C4DEF6050EB5F50ED6356EF6A5BEB6758EF6B5EF36F62
F27060F57461F47360F67562F57260F16D5EF47061F16C5DEC6454E86050ED6452EA614F
E85F4DE75E4CE95D4EE95D4EE75B4CEA5E4DED6150F36756F26754F26754F16653F26655
F26655F36A58F36A58F76E5CF26959F16959F2685BF46C60F56D61F1695DF2685BF46A5D
EF6558F46A5DEE6457F4685BED5F55E85A50E6584EE15349E2544ADB5146D9534ACD4C47
C94D4BC24B4DBD4A4FBE4F55BA4D52B3464CAF4047AD3E44BF5154C85B5EB24B4EAA4A4C
AA4E53AA5359B25D64B05F65AF6066B3666CBA6F74BE767AC47F82CC8A8CD39193D69599
DD9AA1EAA3ABF1A1ACD1767F9F3037C24549D24D4ED24B47D8554DC3443DCF544FD25C58
D3605BCC5D56E27570DA7269D67165D17260D17A5FB56540C37F50925B25A98048CAAF7A
D6C89BD4CEAACFCDB6CCCCC0E7E8E38E8F9124232B4947523C3A4746444FDCDBE1B0AEB3
5C5A5D4F4D509F9D9EEBEBED6D6E73262A3321273720283B253044343F553A4058373C52
BFC2D33D405125263A292C3F9FA5B56A6D7C191B28292933706E71B3AFACA6A39CA19F93
9E9E92A2A296ABADA272736B61605B878681807F7B8485808A8B868C8D8876777182837D
55544F4F50488989818C8C8484847C807D76827974857A767C716B3D342FC3BEBB00FF00
00FF0000FF00
00FF00FFF5EFB97D73AC4E42CC5446D74D40E75548F25C4EE85243E75142ED5748E95646
EE5A4CF35D4FF35C51ED564BF35D4FF35F51ED5E4EEF6251EE6251EF6654E96151E96453
E76450E3624DE86751E4664FEB6A54E86751EE6D57EE6D57EF6D57F2705AF16D58F36F5A
F26D5AF26D5AF06858ED6454E96050E55C4CE55C4CE55C4AE45847EA5D4CE95B4DEA5C4E
EF6153EC6051F16554F26655F46857F36A5AF5695CF06659EF6558F3675AF26659F4685B
F1675AF66C5FF46B5BF1695BF06A5EEC665AEC6359E75F53E05349E6584EE15349E1544B
DD5650D95853DA5E5CDB6362D86464D46060D35D5DD25C5CD1595AD25C5ACF5B5BC95756
C45655C25656C3595BBA5052B44C4DB74F50B44D4EAC4848AD494BAF4D4EAD4A4DAC494E
AE494FAD454CB2434AAF383EC13F41D64E4ED84D48D84B44D94F45D64D45D24B45D5504B
D7544CDA5A51E2665CE26A5CDB6B57D16A4BC26A3CBF7538A66C23805506B39442C0AD61
DAD093DDD9ACD7D6BAD0D2C4E0E2DDBFC3C427272F54525F4B495735313FABA8AFF0EBF1
E3DEE2D6D2D3CCC7CBEBE9ECDAD9DE888B9060646D444A562831421E263D3D425F4E526D
A7ACBF70768615182B262B3E8B91A1787B8A1A1C2925252F38363B928E8DB0ADA8A6A39A
A5A59BA4A69BA9ABA072736B77787262635D6465606A6A686667627475708988849B9A96
9A969383827D8A8782999691999490988E8C988888927E7D998481614E4A988D8B00FF00
00FF0000FF00
00FF00FFEEEAB26F67B55046CD4F43DE5245EE5A4EEF594BE85244E54F40F05D4DEA5747
EF5B4DF66254ED564BF35D4FF05C4EF26150F16251EE614FEC644EEB644EE8664EE7674E
E76B4FE0694BE06B4ADD6B49E06E4CDD6B49E16E4FDE6B4CE16B4FE1694EE66D52E5694F
E66A52E96B55EE6D5AF26D5CF36B5DF66E5EFA7161F46B5BF46756F36655F06254EA5C4E
E95B4DEA5C4EE55847EB5F4EE35746E75B4CEA5E51E85C4FEB5F52EB5F52EC6053EF6356
EE6459EE665AED6859EE6A5DE66659E9695CFB796CF77166ED6056EB5B50E9564CE35348
DC5248DA574FDB625AE1706ADD706BDD716EDF726FDB6E6BDD6D6BDA6867D96663DB6865
D96864D96965D76765D56362D36160D2605FD56561D0605ED0605ECF5F5ED05D60CB585B
C95558C85153C94C50D45254D95350D64D47DA4F48D64C42DB5147D3493FDD5049DF5249
DC4F45DD5348DA5246DB5949D25A42C85E37B55C24CF8B40D5A448BF9D3BC7AF4BC2B356
D8D087E2DFAADEDDBED9DACADCDDD8E8E9EB515159363441555361484452807D86F2F0F5
F3EEF29994986D686CB2ADB1EEECEFE5E6EADFE2E7D5D9E2CFD5E3596073313550545571
84879ACCCFDE434655181B2A23273325273319192521202819171C64605FB9B5B2ACA9A2
AAAAA2A8AA9FA9AAA283847C74736E6667618F8E8A72736E50514C51504C5756526B6764
74706D5C5855696562A098969A8E8EAB9798B99B9DBF9B9DCEA8A7A684827B635FF9EBE8
00FF0000FF00
00FF00FEE5E0AF665FB84D43D24F45E5554AF15D51EF574AE24C3EEF594BEC584AED594B
F36251F05F4EEF5B4DF15F50ED5E4DEF624EEA624CEA664DE7674AE16849E26D4ADF724B
E0764CDA7549DD7D4DDA7B4BD67A49D37748D97C51DA7A52DA7853DC7854DE7555DE7353
E17256DF6D52E46C54E56751E86553ED6555EE6555F46857EF6251F36454F56857F7695B
F66A5BF36758F36756F16554F26657F26959EC6255EC6255EA6053E55B4EE55B50E75F53
E55F54DF5B4FE36358E36559DE6459E1675CFA7A71F26D64F0665BED5D52EC5A4DE25446
D65245CF594BB95146AD5048B35E59B4635FB5615FBD6766C56B6ACA6C6CCD6B6AD67270
DE7874DB7571E07A76DE7673E07974DC7570DD7470DA716DD86C69DA6D6ADB6B6ADB6968
DC6868DC6664DE6463DC605EDC5D57D95852DC5C53D9564CD8534ADD574EDD524BE05349
E05045DF5143E05447DB5643D3573DCA5E37AF591ECC8A3CE9BD5ADABE50D4C252D1C65D
D9D37FE8E4A7E8E5C2E1E0CEE0DFDAF4F4F69A99A1201E2B454351555361595762DDDCE2
D8D6DB57555A656368838186EBEBEDEDEDEFE6E7EBE3E6EBF5F9FF979AA9232439484860
69687AE7E6F4C8C6D18281895A595F4443482A292E1A181D29272892918FBEBAB7B3B0AB
B0B0A8AEAEA6ABABA3A8A8A0A29F989E9E96ABA8A1A0A09896968E8F8E89807F7B61605C
4E4D484D4C475E59569D91919E8588AB878BDBA6ACEFB3B5F6B9B8C38C89714842E7CEC9
00FF0000FF00
00FF00F8DCD8AE635DC05148D65148E5554AF25E54E85146E65042EF594BEA5648EF5B4D
F36251EC5D4CEB5C4CF06351EC644EE6644AE56A4BE16C49DE724CD8754CD2754CD27B50
CF7E51CC7F51C87E4FD18959CA8355C27E51C67E56C67D5AC77C5CC67758C87458C77156
CB7159CB6C56CF6855DE6F5CE56D5CE86958E96453EB6451F06552ED604EF16453F16453
EF6153EE6253EF6352F26655F06455F26657F4685BF5695CF86C5FF46A5DF46A5FF36D61
EC6A5DE4685EE06B61DD6D62C4584EB7483FD7605AEA6B64ED675EE95C52EC5D4FE55C4C
D95A4BCF604F8F33247226197131286C312D6A2E2D7032337A38397A34348A403F924442
9B4C489F504CA04F4CA95854B05D57B4615BBE6964C46C68CA716DCF746FD27371D16F6C
DA7772DF7975DC7370DE726FDA6F69DD7069E3746DDD6C64DF6862E46761E96560E75E56
E05349E25649DB5144DA5848D35C44CE6842BD6C37BA7B34EEC367E3C85FD7C559D8CC68
E0D988D1CD90D7D3B0E0DDCEE1E0DCF0EFF4DEDCE7403E4B3330414744554D4957B7B4BD
D8D5DC3F3D4238333A8E898FF2F0F3EAE8EBE6E6E8E2E3E5EEF1F6C5C8D127283A403E54
454255BFBDCBE9E6EFD5D3D6C8C6C7BBB9BAAAA8AB989697A8A7A5C2C1BFBFBBB8BBB7B4
B4B3AEB7B6B1B6B3AEB3B0ABB1AEA7AEABA4AAA7A0A8A59EA9A9A1A6A69EA8A7A29C9B97
91908B8887827D7573978486AA878DB68189CC838AD88388CE7879AB5D598A4F49CEA9A1
00FF0000FF00
00FF00F1D4D0AA5D55C25348D75249E7574CF25E54E85448E85446EB5749EF5B4DF15D4F
F46253E65948ED6451E46049E66A4EDC6A46DD7349D8794BCC7A4AC88251C18458BE8760
C18F6CC08F6FC29473C49577CD9E82DAAC92E4B49EE3B39FDBAA99E7B3A5EAB1A6ECB0A6
EDADA4EFABA2E79E97D58176CD6959DF705DEA715CE96B54E7634CED654FF06351F06352
F16453EC5F4EF16355EF6052F26355F16254F16355F16355EF6153EF6354EE6255EA6458
E4695ADD6D61D57368CB7169A24B447C211E9B3332C75353E76862ED645CE95C52E86054
E16354CC6151822F1F5A1B0C56261C4C251E4A27254A26264F2829542A2C5A2C2E5E2E2E
5A2A285F2F2B61302C612E2B6B383464312D743F39733C37763B377D403B82413F823E3B
8E4745944A47984D4A994B47994B47A2534FAF5B59B05655B65755C75E5BD35D5BDB5B58
D6514CD6514AD05148CA5446C55C49C66C51BF754EB07440E1B671E7C876DDC771D9CA77
F0E7A2B1AB797E7A5F88867A969696ACACB4BFBFCB5655653D3C4E423F52453E508B8593
F5EFF9BBB6BDA69FA6E2DBE2F1EBEFEBE6EAE6E4E5E1E1E3E7E8ECE5E8EF41435228293D
2B293E797687E9E6EFD9D4D8D1CFD0D3D2D0CBC9CACCCACBCCCBC9CAC9C7C8C4C3C9C5C2
C3BFBCC2BEBBC0BCB9BDB9B6BAB7B2B8B5B0B3B0ABB4B1AAB1AEA7ADAAA3ACA9A4A3A29D
ADACA7B5B2ADB8AEADB89FA2B58A91CA8991AB5059B74E55C35757BE5D57A75D54B08179
FFF2ED00FF00
00FF00E7C8C5A3544DC35348DB574BEA5A4FEE5C4FE85446EE5A4CEB5749F05E4FEF604F
EA5F4CE7604AE7674EE06949DC7147D47442D17F47D08A4FC99158BF915FD3AD86E7C5A9
E8C9B4E6C9B7EACDBFEFD2C4EFD1C6D2B4A9C5A79FC2A39EF2D3D0BFA09EAF8B8DB1888C
B2888CAD7F82CE9A9CFDC0BBDC8F7FCA6E57E1785BE67354EA7152E8684BEC654FED624F
F26655F06352EF6153F26355F16254F16254F26355EE5F51F26456ED6152EF6558E76557
E06C5DDF7A6EA35146D18D8494534F5D17156716158F2D2EC65453E66965E8615BE55F56
E16355D9695B9D4434611E0E48180C411F163A211C372221351F213B25273A2222402627
4026254229254A2C2A452725503230492C2850312C4B2A254F2C284F2926552C2A592D2C
5D302D5F2F2D62312D67363263302D67312F662C2B723232772B2D893032932B2CC14D4D
CB4F4DC94E49BF4C45BF594DB55D4F934A377A3E246F411D886434846A317D692C807136
8B835279755058554255544F56555A5C5C665756643D3C4C3F3E503E3C51413E515D596A
A8A4B2ACA9B4C3BDC9D4CED8DFD7E2E6DFE7E7E2E8E4E2E7E1E2E6F1F4F9848692111320
14132142404DD7D4DBE1DFE2D8D6D7D7D6D4D5D3D4D4D2D3D3D2D0D4D3D1D5D1D0D2CECD
D0CCCBCFCBC8CDC9C8CAC6C5C6C2BFC5C1BEC4C0BDBFBCB7BDBAB5BAB7B2B6B3AEAEABA6
B1B0ACBBB6B3C5B9B9CDB4B7C99AA2D48D95B34F59B23F46C85052C15451B05C52915B4F
EED9D400FF00
00FF00E3C2BDA3534AC35146DC564AED5E50EA5849E55242EB5A49F46352EE5F4EE9614B
E56349DE6546DE6E48D57140D68045D28945CE9249CE9E56C9A567DABF90F0DBBEDFCCBD
BEADA6B3A19FF0DDDFDBC7C9907C7E6F595C5843486D585FD5C1CA6B576268525F6A5262
6C505F6747545E3940C49895FAC2B1C27D5ED07B52DB7A4DE0764CE7764EEA6F4EE7654B
EC6551EB624FF16453F16453F16453F16453F06352F06352ED604FF26657EC6758E36859
E2786AC66E6279362D89574EA47973A67974703634631C1A842928C35554E46866E76660
E46157E1675ACE6353933A2A5F1D0F4315083A1C14301D172E1E1E2D21212D1F1F2E2020
2B1D1D2E201F39272733211F463432392723402F283A27214B36313924213A25223B2623
402826422A28402723482C29402423482A2A442221512728511A1D611B1D691012B34B4C
CA5A58C95955CB6560BB645B9B584F5F2E20441F0F452A154731194435163F35123A3414
3433172A2B193C3C3440404044454A45454F3A39472F2E3E3130423132463A3C5146495C
5455674D4E60535166615F7474718284808F9B95A1DBD8E1E1E0E5E7E8ECC8C9CE7E7F84
65646A545358B8B8BAE5E5E5DBDBDBDBDBDBDADADADADADAD9D9D9D6D6D6D7D5D6D7D6D4
D6D5D3D4D3D1D4D2D3D2D1CFCECDCBCDCCCACBCAC8C9C8C6C5C4C2C5C4C0C2C1BDBCBBB7
ABAAA8A8A4A3B8AEAFC1ABAEC499A2DD9AA3B2535BA33238C24A4CC65652B75D5483473C
CAB1AA00FF00
00FF00E1BEBAA7544CC45247DF594DED5E4EEA5849E04F3EE65746EA5D49E65F49DF5F42
DB6442DB7046CF6F3CD27E40D18941D19646D7A858DBB76DCDB579E7D8AFD8CBB8E3D8D4
C6BBBFBCB2BAE8DCE68175816759665D4F5C392C36B3A5B2988C9A574A5B56495B4E3F54
564359675062452A33957270FFDAC5DCA47FD48E5BD28149DA7F48DE7A48E7784DEC7451
E9694CEB644EED624FF16453F06352F06352F36655EF6251F26554EE6555EA6858E26E5F
D9796BA2584B6430254F2A2272554FB59892B6918B6C393657110F862E2CC35B5ADF6967
E36660E0645ADB6559CB6153913E2E5B1C0D3F130832170E2C1A16271D1B271F1D261D1E
241B1C261D1E312726291F1E3A302F2E2422352C273229243A2F2B3025212E2422342A28
332927372D2B3628272F21202E201F423232352122472A2C4117195C1E21640F12AD4949
CA5A58CC5C58C8655FB161588E554C48231A30180E30221731271B362E21322C1E2C2A1D
2D2D231F201A2929272B2C2E32313735343C36343F2C2A372C2B392A2C392124331A1D2C
2326353235443437483C3D51474658484556464250BCB9C2E6E5EADADADCDDDDDFDBDBDB
DADADAD1D1D1D5D5D5DEDEDEDDDDDDDEDEDEDEDEDEDDDDDDDEDEDEDBDBDBDCDADBDDDBDC
DDDCDADCDBD9DCDADBDBD9DAD8D8D6D6D6D4D7D5D6D4D2D3CFCFCDCFCFCDCFCECCCBCAC8
B7B6B4A09C9BA69DA0AD9A9EC5A0A7E5A8B0BA5F689A2B32C54D4FC65551B85C5188483C
A0857CFFF8EF
00FF00E1BAB5AA574FC7554AE25C50F16252E75546E45544E65B46E35F48DE6143D3613C
E77E4FD77A41D48341CD8539D1933EE2AE58EDC06FD7B470D5BF8DE0D1B2CDC1B5E1D8D9
BCB6BAE8E1E9C0B8C5645C6B5C5461423745706671D4CAD56E6373453C4D5F5667706478
4739506350633B212CB18E8AFFD3BCECB58CF7BA81E7A261D18440D37E3DE08046E67A4B
ED7751E76848ED654FEF6250EF6251F06151F26355F16355ED6150EA6554E26958E37969
C473626F342653281F4A2D2544302959443F9F8681BF9E996E3E3A521512823432B45656
D76A67DD6763E36861DB655BCB6153984032601E103D110630150E291A15271D1B241C1A
292323241E1E29232325201D3C34322A221F352D2A2D26202B241E2A231D362E2B2F2725
322D2928231F271D1B2E2422251B19352A283123223D2427370D1158171B6A1012B54947
D55B56CB5249C05649B4615390584B3F1D132A1710261D1626211B27241F24231E1F1E19
2626241F1F1D1C1C1A1E1E1E211F222321262C272D2621282522291411183F3E43636267
4A4B4F363A3D1E23271F222B2424301D1B281D1A2584818AE9E8EDDBDBDDDAD8D9DBD9DA
DDDBDCE0DFDDE2E0E1E1DFE0E1E1E1E1E1E1E1E1E1DEDEDEDEDEDCE0E0DEE0E0E0E0E0E0
E2E2E2E3E3E3DFDFDFE0E0E0DFDFDFDFDFDFDEDEDEDDDDDDDCDCDCDBDBDBDCDCDCD9D9D9
D3D3D3C9C7C8C5BFC1D2C2C5E2C5CAF6C3CABE6B7391282DC34C4EC4534DBC5E548D4B3F
8C7065FFF6EC
00FF00DDB4B0AC584ECC574DE35D51ED604FE45545E15442E4604BDF634BDA6B4DD26F46
E18755DE8E4FD68E44D99846E5AC55F2C06BE2B86EA8884DDBC59EDBCFB9E3DAD5C1BBBF
CBC6CCEBE5EF777382524E5F413D4EA7A0B0F3EBFA958D9C453C4F3E3749D4CCE1D1C9DE
50445A4C3D50422B35E1BEBCCE9B88BC7D5AF2B07CFFBC7BF1AB63D98C44D6813EE08044
E27645EF7850E96849ED654DEF6250F26353F26355EE6052EF6654E56653DF6E5CD87B69
9E59495C2C1E45271C3D2922402E2A3E2F2A4C3935A9918DC4A5A0683F3B521A19772F30
AD5554CF6766E16B67DF665EDF695DCE64569F493A5F20113C11083017102D1B17261C1A
27221F262221221E1D272322332E2B26211E322D2925201C2A252126211D312C282A2521
2A2722282520221D1A352D2B2A221F342C29312525361D203B11155715196F1014C24E4E
D4554ED15347C65849BB64539157493D1D1026150D211C181D1C181F1F1D1D1D1B1F1F1F
2020201A1A1A1B1A181F1B1A1D1918211D1C251F2121181B140E103E3838B0ACABDCD8D7
C7C7C5B8BAB7A2A6A59094957E7F8466656D4B484F646168DCDBE0DFDFE1E0DEE3DFDDE2
E2E0E3E6E4E7E5E3E6E3E1E2E1E1E1E1E1E1DFDFDFDDDDDDDFDFDDE2E2E0E2E2E2E1E1E1
E5E5E5E6E6E6E0E0E0E2E2E2E4E4E4E1E1E1E0E0E0E2E2E2E2E2E2DFDFDFDFDFE1DFDFE1
DFDFDFE0DEDFE1DBDDE6D7DAF0D7DDFFD7DEC87B83852227BC4849C04F4BBD5F55914F41
8D6F64FFF5EC
FFF7F4DAAFA9AD564CCC584BE76253EA5D4CE25544E45B49DE614DD96B52D07155C87450
D28857DA9659DC9C54EAAD5DF5BA6AE9B5699E7537BD9E70E6D5B9DDD3C7DFD6D7A7A0A7
EAE5ECBFBCC7595669504D62403D52948FA3AAA5B95850654840584F475FA39AB57C748C
50445A352738816B77F6D2D6AD7169B56854CE7A55E3905CFFB672F9B469DF9347D9873D
E28343E67B45ED734CEB684AEF674FEF6250EE6150F06455EB6353E46957DD7461C57461
79402F4C281A3C261B382922382A273527243D2E294E3B35937B77BEA29E8E686550201E
692929A35251CD6765DE6D69E26960DC685BD0695AA34D3E5D1F103C1206331811291A15
251B19231E1B272320282421302C29221E1B312D2A25221D2E2B262C2924322D292D2824
27241F2C292225201C312C2827221F372F2D25191B3A1F244114195A1319761316C54D4E
D8544FD25245CA5B4ABC63518C53423C1C0D23120A221D191D1D1B1618171A1A1A202020
1E1C1D1D1918211C191C17131F1A16241C191C1210251A18746A68CFC7C4DAD5D1D7D3D0
DBDAD6D8D8D6DBDBD9DCDCDCDDDDDFDEDCDFD3D1D4CBC9CCDEDDE2E1E0E6E5E2EDE7E3F1
D9D7E4BDBBC6B7B6BCD9D9DBE0E0E0DEDEDCDCDCDCDDDDDDDFDFDDDEDEDCDFDFDDDEDEDC
DEDEDEE0E0E0DFDFDDDFDFDDDFDFDDDEDEDCE0E0E0E0E0E0E0E0E0E0E0E0E1E1E1E0E0E0
DEDEE0DFDDDEE1DBDDE6DADCF2DBE1FDD4DAC17A82B25359B24143BE4E4ABC5B52975346
937368FFF4E9
FFF7F2D5AAA3A65247CD5C4CE56152E95D4CE25645DB5A47D86854CB6B55CB7B64DD987B
E1A37CE0A470E5A869F5B973F2B771B38041A07847E3C9A8DDCCBAE3DAD3C9C0C3CCC5CC
F9F4FB88828E4E495D504D624D485E5A55695C5469574F64544C64534B635D536C574D65
4237482F2130D1BDC8FFE0E7E9B1B2BE756EBC6A55BD6945D88F58FDB873FBB669DC9346
D58139E58344E77747F1754FE76448EB634DEF6352EE6555E86553DF6A58DB7A67AB6251
5E2F1F40231536251B31262031262231262440322F3D2E2942302C83706AC1A9A5987674
5427246D302F954441C5645EE06F67E16C62DE6D5FCC6657A14E3E62231445160C381710
2A120E2C1A163224212B201E332927271D1B362E2B2C24213029232D26203029232E2721
241F192E2923241F1B2D282429242130282627181B3E212543121860171E7A1317CC5251
D9544DD45245C85745BF67538A513E3D1D0E25140C211C181C1C1A1717171D1B1C201C1B
201B18231B18251A161D130A1D13071910014B3F33A99C93DCD2C9C5BEB88C8783B0ACA9
E2E1DDDDDCDADDDCDAE0DFDDE2E0E1E4E2E3E8E6E9E8E7ECE9E9F1E5E4F2D1CFE4A7A5BB
6E6C814F4E5E514F5AB1B0B5EFEFEFE2E2E2DEDEDEDDDDDDDEDEDCDFDFDDDFDFDDDFDFDD
DFDDDEDFDFDFDEDEDEDCDCDADBDBD9DBDBD9DDDDDDDADADADCDCDCDBDBDBDBDBDBDCDCDC
DCDCDEDDDBDCDFD9DBE3D7D9EED9DEF5CDD5CD878FDC7F87A33538BD4D4BBB5A519D574B
99776DFFF5EA
FFF8F2CFA79FA65448CA5A4CE56355E35B4BDD5847DD6453CC6657CA7769C17F73AF7567
D09881ECB491F8BB8CF8BC86D89C68A87546C7A582EFD9C4EBDAD2DCD1CFC4BABBE0D5D9
EEE5EA918790362D3E40374A443D4F484151463D4E443B4C443B4C43374B3F324436293A
3426338D7D87F8E3ECFDDFE7FFDCE4FDCBCED59691A35B4CB26845D38C58FCB877FBB76E
E1954ADC8540E67F45EC794CF07150EF6950ED6452ED6857E06351DE715DD47B69914E3D
5126163E241738271F2C211B2E25202F2523372E293D322C42352F473831705D57A68F89
8667646F43406B302C8F443EBE6058DC7167E37166DA685DCD6558A84C3F6F2115511108
3C09053B120E43211F361A173D25212E1B1533221B35261F32251F2D201A32251F362B27
281F1A332C2628201D362E2B261E1B3227252E1B1D4324294510185F12187D1418CE5250
DA544BD25042C75844BC6551874E3B3E1E11291810211C181D19181B1718231A1B231918
2A1C192B1C1528160C1F0E002B1D02706343CCC1A3C9BFA67973638F8B82AAA7A2D0CCCB
DFDEDCDEDDDBE1E0DEE3E2E0E7E5E6EAE8EBEAE9EFE1E1EDBEBFD38C8EA7606180565678
6667855E5E76343341747379F0F0F2E6E6E6E1E1E1DFDFDFE0E0DEE1E1DFE3E1E2E4E2E3
E9E4E8E8E6E7E4E2E3E3E1E2E2E2E2E2E2E2E1E3E2DEE0DFDFDFDFDDDDDDDEDEDEDDDDDD
DBDDDCDDDDDDE0DCDDE4D9DDEDDADEFCD4DCD8929ACB6E76A03235C0504EBB5A519B5549
9C7A70FFF3EB
FFF8F2CDA59DA6574ACD5F50E36556DE5B49DA5D4BD46554C26A5ECA847C9F686562312C
8C584DE3AC97F9BD9BDBA078B67F58B28663F2D3BEE6D4C8F1E3E0CABEC0E0D4D8B5A9AD
BFB2BBDED2DC817485605566514958534B5A5E5363625765675C6A655A686C5E6D817380
C3B3BDF5E4ECF9E4EDF9DFEAFBDDE9FFDBE6FFD0D6E2A8A6D69382B56C4BD6905CFFBC79
F9B469DE9046DF8342E87E4AED764EEB6C4CEA6651E76653E36B5ADD7663C1705F773C2C
4C2619422A1E3829222D241F2C24212D2522332C26362D28352A244237314435305A4942
6E59549A7D79A37A747E47408B4138B95F56D87067E5756ADD6B60D16356B853478F352A
6717105E1711662521511612541F1947160F4F231A471F17421D153A180F43201A43241F
371A143F231F3418154024213118143E22213B191A491C2154161B630E138B1A1CD65653
D94F45D65142C95643C469548745353F13082E110B2A15122812142C1316301413331612
381A123114042E1400523C159E8C5AB3A6719086558179529A967DDEDACEE4E1DCE3DFE0
E2DEDFE2E0E3E9E5E6EEEAEBE5E3E6CBCAD0A1A1AD696A7C464861464968595C7F6D7093
5B5C7A3E3C542C293A4E4B54E3E1E6E9E7EAE1E1E3E0E0E0E0E0E0DFDDDEDFDBDCE3DEE2
EAE4E8E7E2E6E6E2E3E1DFE0E1E1E1E2E2E2E1E3E2E0E2E1E2E2E2DFDFDFDFDFDFE0E0E0
DEE0DFDEDEDEDFDDDEE5DCDFEBDBDEFFDBE2C9868FC3666EAD3E44BC4A4ABD5A549D544B
9E7C73FFF3EB
FFF6EFC59D95A8594CCA5F4DE36856DD5E4BD35B4ACF695AB96D60B77E77C6989AB98F91
814F4ED29990F0B29DC08367946345CAA68CE3CDBFDFD2CCE7DBDBC4B7BEF2E2ECDCCCD6
DCCCD9F0E2F1E4D7E8D6CBDCC9C0D1C7BFCEC9BECEC8BDCBC1B6C4BFB5C0D2C4D1CEC1CB
C9B9C3C5B4BEC6B2BDB8A0ADBBA1AEB496A294737EEEC5CBEFB8B5AC6956BA6F48E3985F
FFBF78F2AD60E9974EE18144EA7C4BEC744FE8684DE66955DE6E5ADB7C68A75E4D622E20
4E2C203E2A213528203229243028252D28242C272129241E302923332C263E332F473A34
4C3D3865524C9E827EC7A29AA8736DA55E58B75E58D7726AE7786FDF6A60DA6659CF5E50
BC4C41A73B319B30288D261F88261D7B1D13721A0E6D190E6012065E140B5D140D5F1A13
55120C61221B50110C591C195217135B1F1E5416195E191C610F156E0B0E991E21DB5451
DC4D45D84E41D35848C861508F3D2F4E0B02450B09420F0E3F080B480D0F490C0B4B0F07
4B1302582A08926E34C6AB64B19E52887A31938A49CEC793E9E4C4E9E3D3E9E4E0E8E4E5
EAE5EBE7E2E8D6D1D8ACA9B077767E50505A4042513C3F5243485E4B4F6A656986686985
3F3D552E293D261F2F342C39C9C4CBF0EBEFE2E0E3E1E1E3E0DEE1DFDADEE6E0E4F0E9F0
AAA0A88D878BE9E5E6E5E3E4E0E0DEE0E0DEE1E1E1E1E1E1E1E1E1E0E0E0DFDFDFDFDFDF
DDDFDCDDDFDCDFDDDEE5DCDFEADBE0FFDFE6B87680BA5F68BB4951B94649BC5954A15851
9A786FFFF5EC
FFF6EFC19991AB5C4DCE6351E16654DA5D49D46450C46756C17D7292615DDDB4B89E767E
68353AD49A98DD9D93AB7060A17663EBD0BFCABBB4D5CBCAC4BBBED6CBD3EDDFEC9F91A0
9A8D9E988D9E8E8296898093847D8F867F917C75877E7787716B79716B7779717E7A707B
7A6E7A887A878C7C8987737F8C7683745E6A7D6773F6D8E0FFD8DAC88D85BB6F55C57749
F1AD6EFEBC72EEA459E58E49E68149EA794FEA7152E06850DD725ED47B69995A4B4C2013
452A1F3B2A22372C262F2822332B282E292527221C25201A2A251F2A251F342D2739302B
4439354A3C3955443D806762BC9590CE9794C57C76C86D68C9605AED7B71E47063D76153
D15B4DD15B4DD1584DCD5449C34A3FC14B3FB14032A6382B9E3427912B1F8F2A2089281F
7E20187E211A791F17741B156E17106D18136C14136F13146F0B0D770608A02021DC5250
DB4C44DD5144D25344CF5B4C9A34286A0D065E09065E0A08630B0A660C0B6D1009792012
7C2F15A06233E8BC73EED07AAB953F645502A49C54EEE7B0F3EDC9F1ECD9EDE8E4DFDADE
B7B2B98380895C566047444D46464E454851474B573F425344495C52576A5A5B6F3F3D52
322E3F2B24342D22322B202EA79DA6F4EFF5E3E1E4E0E0E2E2E0E3E3DEE2F5EFF3D4CBD0
261F262B2529D7D1D3F0ECEDE3E2E0E1E0DEE2E0E1E1DFE0E1E1E1E0E0E0E0E0E0DFE1E0
DEE0DFDDDFDEE0DEDFE2DCDEE9DADFFFDEE5BA7B84AF555FBE4F58B54247C05D58A25952
99776EFFF5EC
FFF4EFBB938BA65446D06553E16654D85E49D36652C06958BE7F76906360D8B1B68F666E
A67177CC9092C687829C665CD8B3AAE2CEC7DCD0D0CEC8CCB0ABB1F2ECF6B7AFBE635C6C
6B667A615E735C596E57556B5A586E5C5A705D5B71615F746263776364766B6A7C6F6C7D
6E6A797872807D72827B6F7D736670544750BDADB7FCE7EEFFDFE4EDBDBBBF7A6AC77B59
D89560FFC17FFCB86FF2A55FF19356F48859ED7857DC6A52D7725ED382719C64574E2920
39251C352A242E27212E2623332C262F28222E26232A25212C27232C27232D2522352D2A
3C3431413833463B37523F3B6B4C499F726FC88888ED9E9ACC6D67C05950E68072EF8B7B
E3826FD77461D06555CA5A4CCF5B4CD35D4FCF594BD35D4FD25C4ED35D4FD05A4ECB554B
C44F45BF4D43BC4A40B34338B14237A93A31A33631A1312D9F2C299C2221B63230D54E4A
D64D45D74F43D34F42D05043BE4439A32C249E2721A02923A12A24AC332AB0372CBF4F39
BD5B38B16430F2C175F7D782A9903E8E7E31D7CE8BECE6B2DFDABAC4C1B094908F67646B
4B485145444C4A47504B4A5247474F3F42493C3F463B3E47393C45393C4533313C2C2934
322C382D25322F23312719288F858EF6EFF6E5E0E4E2E2E4E2E2E2EBE9EAE3DFE06A6466
6560643D393AB7B1B3F4EEF0EBE5E5E9E3E3E6E2E1E5E1E0E3E1E2DFDFDFDFDFDFDDDFDE
DFE1E0DEE0DFDFDDDEE2DCDEEADBE2FFDEE7BE808BA9535CBC5159B8474BBD5C56A35A51
9A786FFFF3EB
FFF3EFB78C85A75547D26755E26956D85F4CD26755C06A5BC0847AAB7E7BC29B9EBD9299
C69197C3888AAA706EAA7A76F0D3CFDCCDCAD3CACFBAB5BCD3D0D7ECE9F47D7988636073
615E734D4B603E3C51323045312F452F2D4337354B43445952536855586B424355373948
343341403C4A4B45514C444F3F353D685F64EADFE3F4E5E8F8DFE5FFD8D8CF9186C47D61
C78352FABA7AFFC277F3AE63E78D4EF18956EC7C57D5694FD67765C175679F6B607F5E55
5948403E352E312A242A251F2F2822312A242F2724352D2A2A25212C27232E2623312926
302B27322D294036344738355238375E34357E4242BA6C6CB85955BB544BE88274FD9C8B
FFAF9DFFA894FC9584ED7F6EED7E6DE87765DB6A5AD56454DC6957DA6554E1695BE1695B
E46C5EE86F64E16B5FE26E61DD6C5ED56557D56559CE5E53D05E54CF5A51D35650DB5C55
DF5C52E36154DD594DE05A4FD9534AD9534AE25951E45B53E1584EE05A4EDA5647D65E46
D06946B36332E5B271EDCC85C8B16DBAAA6EAFA57089865D6C6A5158564A4745464B484F
4A49514241494241473C3B4137363B2F303433323726252A27282A2727292B2A2F2C2A2F
2F2A312F252E2C1E2D2315248B7F89F8EEF6E5E0E4E3E1E4E2E2E2F5F5F5A19D9E706A6C
E8E4E57A7677ADA7A9BAB4B6B6ADB0DFD6D7E9E3E3EBE5E7E8E4E5E3E1E2DFDFDFDCDEDD
DDDEE0DDDEE0DDDDDDE2DCDEE9DAE1FFDEE7C38A939A4952CA6168AE4043BD5C55A0584C
9A786FFFF4EC
FFF1ECB1867FAB594DD26757E36A57D9604DD06553C56F60B77B70B98C87C69C9EE2B8BC
C79397B683829D6D6BE1BBB8E4CFCEDED2D4CEC4CCB7B1BBF2EFF8B3AFBD5653645C596C
4440517C78879F9BAA94909E8F8B99908C9BA5A2B35F5C6F535065403D504A4856A9A7B2
A19EA5A6A1A7AFA9ADB5AFB1B8B2B4D2C9CAF1E9E7F0E4E4F4E1E3FFE2E0E3AFA4B27257
BA7846EAAB68FFC778F9BA6ADA8542DA7740E0744DD97156CE7662AD65576F3D347A5952
86756E7E756E5E574F3F3832342F292D2822292420302B272D2522322A273028262B2321
312C28302B27382E2C3D2D2D482E2F5A30326725297D2426A43B38E37069F48277F9897B
FE9484FF9787FF9281FB8D7CFF9583FF9C89FF9E8BFF9E8BF5927FE88371E47A6ADF7565
DD7363DC7264DC7566DA7666DC7D6BDE816FE68978E98979E78676E98575E67A6DF18175
F47C6EF5796DF9796EF57067E75E56EF645DFD7069F1675DE95F55E66255DC6151D66753
CA7153B5714CB3875A977B4C6E5B315D502D4E492C44422D4E4E424B4A46464646424146
37353A3432373634372823272823272B262A2A28292321222929272727252929292A2A2C
2E292F2A232B3024322A1C2B827680F4EAF2E7E1E5E4DFE3E8E6E7E9E7E8928E8DA39D9D
877E7F867D7EC7BEC182797C433D3F585254857F81ABA5A9C6C0C4D8D3D7E1DFE0DEDEDE
DDDFDEDCDEDDDDDDDDE2DCDEE9D8DEFEDDE6CC949F8A3D47D46C75AC3F42B857509D5549
9B7970FFF5EC
FFF1ECAA7F78A8564BD46959E36A59D65D4AD36554C26957C68476E0AEA3AB7E79C39794
B88B86A97E78AA8781EFD3D0E0CECED6CACEBEB3BBE1D7E0EEE6F17E78865B5768524D61
3B3748C2BBCBF1E9F8E7DFECE6E0ECF0EAF8D7D3E26763744B465A242031A8A5B0F8F3FA
EBE6EAECE8E9ECE6E6EDE7E7EFE9E9F0E8E6EFE7E5F2E6E6F7E7E8FFE3E2F7CBC2B27A61
B37343D59653FEC775FCBF6EDC8C45CC6C32DE774ED77254CD7662AB655965352B52312A
594640776C66918881857C756A635D453E38342C2929211E28201D332B282F27252F2A27
2D2824312C28352B2A3E2C2C44272957262A63181D7C1C1EC75554E86D66E96D63EC7265
E87264EB7567E97161EE7968EB7A68F08573F48D7AF5927FFF9A88FF9887FE9484FF9484
FB9181FD9383FB9684FC9986F99A86FDA18CFFA694FFA694FFA290FF9B8BFD9687F98B7C
F37D6FF07468E9695EEF6960EC635BEC6258F2655CE95F55E86257DF6455D76759BF6250
A159438A573C6C482E513C2142361E463F2C433F333A3A323E3E3C383A39323234333237
28272C27252A2C2A2F262125292428292428292526292524262521282924252523232321
262427251E262E22302C1E2D796D77F5EBF3E6E0E4E4DFE3EEECEDDBD9DA9791917D7777
89817F83797ACDC4C7D3CACDD2CCCEBBB5B78882842C26283E383A9B9597E8E4E5E2E2E2
DEE0DFDEE0DFDEDEDEE2DCDEE8D7DDFEDDE6D29DA7853842D9717AAC3F42BB5C56995349
9F7E75FFF5EC
FFF2EEB28780A65449D5675AE66B5BDD604ED86552CF6F59D08570BD84718455457C5544
A88474AD9080D3BBAFDBC8C2EAD8D8CEBEC1CCBBC1F8E9F0CCC1C95E566160596B524D61
49445A736E82827B8D7D7688857E908B84967770825B5466393242453F4DE4DFE6EDE7EB
E9E3E5EAE4E4ECE3E4ECE3E4EDE4E5F1E6EAF3E8ECF6E7ECFAE7EBFCE2E3FFDAD3BC8A73
B6774BC48444FBC474FBC16FE1934BCD7033DD784CD77455CE7763A6615265342D54332E
4D38354D3E3B5B4D4A786D699186829085816E65604F4842362F292A251F27221E2B2622
2C27232F2724352A283E282A462226551C2265101793292DDD6362EE6A65ED685FF26E62
EF6D60EC6A5DEE6A5DED695CED6B5DED6F60EA7160EC7463EE7666ED7364F07669F47A6D
F47C6EEE786AF27F6DF38270F48675F88D7BF88A79F78978F98B7AF9897BFA8679F67D72
F2766AF37368F57165F56C62F3695FF2685EEE645AEC665BE36557DD6D5FBE6255873F31
6231224F2F204734263D3327332F242F2C2531302C2F2F2F2B2C2E25292C26272B2A2B30
26262E26263027242F28252E27242B2A282D2D282C2C2827272622242520242520252523
2725282A232A291D292A1C2B827680F5EBF3E6E1E5E3E1E4F0EEEFCFCECCA09A9A4D4747
6F67657F7775C8BFC0918889B0A7A8B0A8A6C7BFBDB1A9A7C3BABBDBD5D5E4E0E1E0E0E0
DDDFDEDDDFDEDFDFDFE2DCDEE9D8DEFDDEE6D39EA8833640DA727BAF4245BB5C5697534A
A6857CFFF6EE
FFF7F3C59E97A25249D4685BE66859DE5D4ADB624DD46C53DD896FC17F6588553A795439
BD9F85DAC5B0DCCCBDDCCDC6E4D4D5CBB8BCE9D4D9D1BEC4D6C5CD594D574A4251514A5C
4F475C5850675D556A5D5668625B6D645B6E5C53664E4556261E2BA9A1ACF4EDF4EAE4E8
EBE5E7ECE6E6EDE4E5EFE6E7F0E7ECECE1E9EFE4ECF1E1EBECD8E1F5DCDFFFE0DAC89A83
B97C50BA7A3CF6BE71FFC473E5974DC96F31DB794CD17050D07B669E5A4D63342C50312E
4B36334D3E3B4537344C3E3B594B4872676391868291888379726C55504A3B33302E2925
2A25212D25223628273E2626461C205413196A0E13AE3D3FE96966ED6660F1675DF46A5F
F3695EF2685DF2655BF5685EF1675AF0685AF16C5DF26E5FF36F62ED695CEE6A5DED695C
EC6A5DEF7061E96A5BF07263EB7061EB7162ED7263ED7263EC7064EB6F63F17367F27267
EF6C62F56F64F36A60F46A60F3665DF2655BEF6258E76155E16657D76D5FB9655A6E3227
4520173A261D2E231D2C29242B2A2826262627262B292A2F22252C20242D20242F242833
242736292B3A2726362C2A382D2D392C2B332A282D2A2829292728262523272725272727
2A25292E272E2A1E2A2D1F2C8F838DF7EDF5E5E0E4E4E2E3F2F1EFC1BDBC959190464040
655D5B958D8BD0C7C8675E5F534B49342C2A7C7472ADA5A3C3BBB9DED8D8E4E0DFDFDFDF
DEDEDEDEE0DFE0DEDFE1DBDDE9D8DEFDDEE6D4A0AC823640DA757DA83B3EB0534E98554C
B0928AFFF5EF
00FF00D9B8B39E544BCE6457E7695BE05D4BDC5F49DC6D52DB7E5FC77C5CAA724FBC9672
D1B698E5D5BCDCD0C2E5DAD6CBBBBCD9C4CBD3BAC0886F75E0C9D1B8A7AF504450382D3D
312839382F423F3649403748413948423747403543443A458C828BF0E6EEF3EAEFF1E8ED
EFE6E9EEE5E8EDE7E9F6F0F4C8C1C98E8693A497A897899883717DEBD4DAFFE4DFCC9F8A
BB7E51B57434F3BA6BFFC473E7994FD07638D8774ACE7150C97B65925447562B244C302C
483632483D37483D39453A36473C3A4136345449476C6260887F7A948D87847B76655E58
463E3B372D2B3020203B2122481B1E56111478181ACB5456EA6662EE635CF3665DF1645A
F2685DEF655AF26659F4685BF4685BF06659F36A5AF46A5DEF675BF26A5EF0665BEE6457
EF655AF1695DEE665AF0685CEF695DEC665AEB6559EE685CEB655AEA6459EF665CEF655B
EC6258EF6259F06159EE6056EE5E55EB5B50EB5D51E86054DF6153DA6F5FC06A5D6A2E23
3D181034211B2F2724292826262628292A2E26262E21232F2127331D243421283B2B3348
292F4532374D393B52373A4D36384725273323232B26252A2B2A2F26262827272929292B
2B262C29222A30232D2C1F29988C96F6EFF6E5E0E4E4E2E3F5F1F0ABA7A68884835A5454
706866A39B99E7E1E1D9D3D3DBD6D3BCB7B475706D332D2D5F5959C3BFBEE7E6E4E0E0DE
DFDFDFDCDEDDDEDCDFE2DCE0E9DAE1FBDDE5D8A6B1863E49D4737A9E3637AD524D97574E
B89B95FFF7F3
00FF00E6C9C59F5951CD675BE66A5EE25D4EE05F4ADF694FDD7959CB7B58BC825CC9A27B
E0C7A8DBCBB2EADED0DED1CBC6B6B7EBD6DDD8BDC6CBAFBBE2CBD5F8E4EFDDCDDAB5A8B9
A59AABA299ACA097AAA398A9A095A5ABA0AEBCB0BCCEC2CCEFE4ECF3E8F0E0D5DDE1D6DE
F0E7ECF3EAEFF2EBF2F6F1F89C96A4736C7C7E72865F5063948393FBE4ECFFE0DCCA9A84
BC7D51B67535F3B86AFFC171E89A50D1783CDA7B4FCA7151C67E68834B3E4B261E48302C
483934443B364B423D4138333F3533403634433937483E3C4B423D675E59817873958C87
8C8280786D6B5B49474F3131522021550D0E882122D95F5EEF6A65F0635AF06258F16359
F1645AF1675CEF6258F4675DF2655BF06359F3665CF2655BF4675EF1645BF3655BF3655B
F1645AF4675DF2655BF1645AF1645AF4675DF4675DF06359F4675EEF6259F2635BF06159
EF5F57F16159EE5E55F25F57EF5C52EF5C52ED5D52E95F52E26255D7695AC56F626D3126
3D1B123624202F272529292B27282D2F2F37292B37292D39272D3D293043373F563D445E
3B425C3C425C3B3F583E435732354625273424242E22212929282E25242A21202529272C
211C23241A23281B2530232DA0949EF4EDF4E4DFE3E5E3E4F3EFEE9D9998938F8E585252
8D8787B0A7A8CEC8C8B9B3B3D2CAC8C9C1BFC1B8B9BCB6B6DAD4D4E3DFDEE4E0DFE2E1DF
E0E0E0DDDDDDDDDBDEE2DCE0E9DAE1FBDDE5D6A7B1823C46D6777D9A3636A9544D91554B
C1A5A100FF00
00FF00F1D9D5AA6963C6655CE2675FE05C4FDF5B4CE16853DA7257D27F5FB17752CDA783
D7BE9FD3C3AAE5D5C6C9BAB3E1CFCFEAD5DCCFB7C4A890A0AB94A6A893A6A18FA5A092A9
998DA5998DA593879D988AA1978A9E9D90A27F7381988C98F2E6F0B0A4AE837582847884
B2A8B1F0E9F1FAF4FEC9C6D1716D7E726D81675E73504357D7C4D7FEE3ECFFD7D6C88F7B
C27E51BF7A39FABF71FDBE6EE19148DA8044D3764BCA7558BC796677453A4D2C2548352F
3F3430433B3849413E443C393F37343C3431413936453D3A3E3731433C36443A38594F4D
6E605D8C7A78977F7D926F6D8C54537F312FA33B38E56A65EB655CF1645AEE6056F26458
F3675AED6056F3655BF2635BF3645CF1625CF1625EF36460F1625EF46561EF605AF1625A
F5665EF06159F4655DF1625AF2635BF2635BF1625AF2635BF1625AF2635BF16159F06058
F15E56EF5C54F25F57EF5A53EF5B51F05C52EF5C52E85E51DF5F52D86A5BC9736673372D
3D1A143826242D27292E2D332D2D352C2C362F313E3134433A3F5241465A454962434760
4347603F445A3D42584042572E2F412224311C1A271C1A251E1C2723222A1F1C232C272E
3E373E5349526D606A60535D9F939DF3E9F1E3E1E6E2E2E4F2F0F17E7A79BBB5B7C5BFC1
837D7FCFC9C9A49E9EA79E9FD4CACBD7CBCDD9CACDDFD3D5CCC2C1D6CECCE6E2E1E1DFE0
DFDFDFDEDEDEDFDDE0E3DDE1E8D9DEFADFE6D3A1AC7E3840D2787A983B36A6584C8B5549
C4ADA700FF00
00FF00FEEBE7B17670BC6259DD685FE16156DE5F50E26B57D87259CB7C5EB87F61E4BD9E
E7CDB2E0CEB8E5D4C4E6D5CDDCCAC8EFDCE07D69755C47585C495C5443565041564C3E55
4C3E55473B5146384F493C504D40524F42532B1F2DACA0ACF6EAF47D717B6153606A5E6A
594F5ADCD4DFF3F0FB908C9B63607366617740364E8F8095F8E3F4FDDEE6F6C3C0C4836D
BE7749CC8746FFC277FBB96BD98640E2854CCF734AC57457B778666B3F344C2F29493733
3C32303D38343F3A36403B37433E3A3E39353934303A35313C37314039333D3532433836
4436334C3935674B48885C5BAA6A68AD5855C75C56E46860EC665BED6154F16357F06256
EF6356EF655AED6359EE655FEA6560E76563E76768E56468E86869E96769EC6667EA6262
EB615FEE6360EC615EEE6360EE6261EC6260ED6361EB615EEE6360EA5F5CF06260EC5E5C
EB5D5BEB5D5BEB5B5AEE5F5BED5C59EA5954ED5E58E75D53E16156D6665ACA7369783C32
3D1A163E2C2C322C302D2C3230303830303A3434403032413A3D4E373A4D303146323348
34374A282B3E2526381E1F31201F2D24222F2E2B36423F485A57606B686F716C73756E75
777077746A72645761382B35A296A0F3ECF3E3E1E6E3E3E5F6F4F57C7B795A5657544E50
8B8788F6F2F386808062595A5F53555F5053605053635356443838BAB2B0EDE7E7E1DFE0
DEDEDEDEDEDEE0DEE1E2DCDEE8D9DEFADFE4D09FA5813C41CB7274933C35A560517F5142
CDBAB400FF00
00FF00FFF4F2BB8680B46257D76B5FE66C5FD75D4EDF705DDC7E65BF755CBD876FD4AE97
D9BDA8DFC8B8F2DFD1CFBEB4C7B8B3E5D7D782737A7A6D77766875746675726674756879
7467786F62736E6071695B6A695B6A4F414E71656FF1E6EEFBF1F9C1B7BF6D626A544852
746D75ECE6F0C4C0CE696677676278574F663D3147D6C5D7F9E1EFFFDBE0E6A7A0C67E65
B87241E4A061FFC37AF9B36BD37B3CDE7E4BCE724DC7775CAF7561643C30482F28443530
4036343E3634403836423A37473F3C443D373D35323B33303C34313B333039312E403634
42333047322F52302F5B2928691F1E8A2C2AD4615CEA6A61EA6458F26657F16355EF6153
F16558ED6559E8655DE56A65DB6B69BD5556B24F54B15059B2515ABC545DD25E6BDC606B
E4626CE6636BE6636BE15F67E3616BE3616BE3616BE36169E36066E66067E66069E45E67
E45E67E45E67E7616AE65F66E85F67E75C63E75C5FE8615EDF5E58D7675CCB746A80443A
3D1A163F2F2F322C3026252B2A2A3228283026263024242E272733232230201F2D2B2A38
3434403C3C484A48555A586367646D6F6A717D767E827B827A737A6C676B5751554D474B
3B3539362C342E242D291F28B6AFB7F1ECF2E3E1E4E3E3E3F2F2F2B8B8B82826275B595A
D0CFCDEEEDEBD3CFCEDBD5D5857B7AB0A4A6D1C2C5CEBFC2A89C9CD6CECCE8E4E3E1DFE0
DEDEDEDDDFDEDFDFDFE2DCDEE8D9DEFDE0E4CB989D843F42C16D6B924239995E4E795444
D6C7C000FF00
00FF00FFF7F4CB9E98AD6358CE685CE06F5FE37463D26D5BD27F6DA1604EE3B5A6DFBFB4
DFC4BDDDC9C2E5D4CDE0D2CFE4D8D8E7DCE0DFD5DDE0D6E1DED4DFDCD1DFDFD4E4DCD1E1
DED3E3DED3E3DDD0E1DCD0DED8CBDCCABECCD0C6D1E5DBE6DFD8E0E6DFE7DBD1DCCFC7D2
E9E3EDEEEBF6888495635E72665E7534283E857487FFE7F7FFDEE7FBC9C8CE8979C97D5B
BD7743FAB977FFBF78F0A561D97A42D67445D17452C4785EA66F5B5F392C4B342E443532
4238374038363E36343F3734453D3A453E38453C373F36313D35323D35323A322F3C3230
40312E472F2D522B2C5B2324691719993331DE6761ED6A60EF6759F06455F06453EF6354
ED6557E9695EDE675FE27975A44C4AA5595BD8929AC37F8AB56E7CB26472C5687BB34C5F
D36776D76B78B74F5AAC4651A94551A3424DAA4652A94551AD4752AC444FAF4752B9505E
B64D5BB74E5CB54C5ABC505FBE4E5CC04C59C95059D75A5EDF6361D4655ECF786F82463C
3D1A162F1F1F27212523222826262E33333B36343F403E494E4C595D5B68615F6D6F6D7B
7775827D7B8673707B6B6871615C62524D514741453C3638322C2E312B2D2C26282E282A
2E282C2C262A2E242C362F36CBC6CCEEECEFE2E2E2E2E2E2E5E5E5E5E5E5B0B0B0C2C2C2
E5E5E3E4E3E1ECE8E7FDF5F3786E6D685C5C7F7073786C6E6E6465DCD3D4E9E5E6DEDEDE
DEE0DFDCDEDDDEDEDEE1DDDEE8D9DCFFE0E5C59195894544B8676392483D915C4C856556
ECE2D900FF00
00FF0000FF00DAB3ACA76559C86B5CD86F5CEC8775D17868A35F54BC8B84E8C8C97E696E
83727A8578818D818B877D86978F9A958D9A827C8A817D8C7C78897F788A7D758A786F84
7A71867D74897B72877A7184766E83766F817F788A8B8496867F918780928F88989891A1
A5A1B29893A76E667D6B61795749603C293DD7BED3FFDFEDFFD0D5DD9D93CF8467BF7244
D8985AFFC178FAB46CE18E4CDB7743DC774DD07556C97E679863515B392D4E3632463837
3E3232473D3E3C3231403634413936463F39453E38433C34413A343E37313B312F3B302E
40312E492F3051282C5F212672191BAA3E3CE56864EF6960EE6457EF6354F06455EB6355
EA685ADF695FD9736EC77371713433CD9FA1FFDEE4FCD4DDFAD0DEFFD4E5E8A5B7964B5F
C175828B434F9E626AD6A1A9DFAEB4CFA0A6C997A0C3919ABF8C93B27F86A9747CAA757F
A06B759B636E9A606C965865A25B6BA95867B45664AE444ED05E5ED66A67C570698A4E46
5C39355C4A4A5E585A605F6566666E6D707971717D6F6E7C6E6D7D6E6D7F5C5B6D525163
434051403E4C34303E302D362E292F2F2B2C2B27282A2625322E2D2D29282E2A292B2726
2C28292924282620243E383CD9D7DAECECECE1E1E1E3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
E4E3E1E6E2E1E1D9D7EFE3E3CCBEBDB4A4A4B1A3A3AB9FA192898AE3DDDDE4E2E3DFDFDF
DEE0DFDEE0DFE0E0E0E3DDDFE9DADDFFE1E3B98184964F4DA85851A0584C8757499C8275
FEF5F000FF00
00FF0000FF00E9C8C1A1675CC7705FCF6A58EA8B79BA6B5CA97067F7D1CEB1989E685863
6A5C6B685D6D6D6272675F6E6E66756C66745E5A68605C6B615D6E615D6E5E566B60576C
60576C61586D635A6D5F586A5C55675D5668615A6C665F716A6677666273635F70656275
68657A676279675D766A5A74402A3F937486FFD8E8FBC6CCDD9A92CD836ACA7D53C47C42
F9BA73FFC076EFA159D4773ADF7646E07853D67B5EC77F6795645355352A4B3631453736
413535453B3C403635423837413936403933453E384A433B40393137302A3F36313E332F
40312E462C2B53262B5F1E22791D20BE4E4CEC6D67EB625AF16558EF6354F06757EA6659
E46A5DD76F66CD7875995959885E5FF9DCDEF5DCE0F2D8E1F9DAE9FFD9EB99647892596A
885260956771FAD9E0FADFE6F8DFE5F7DEE4F8DDE4FBDDE5FFDEE7FEDDE6FBDCE4F7D9E1
F2D7DEF1D6DFF0D2DCF5D1DFF7CBDCFFC8DAFFBDCDA74753C25457D06764C8736C8E4F48
623F3B6C5A5A5F595D53535B4C4F584345514042514142563D3E5238394D3A3B4F3C3B4D
3A374838364434313C302D34332E322B27262F2B2A2F2B2A2D29262C28252F2B2A2C2827
2925262B2527211B1F544F53E5E3E4E8E8E8E1E1DFE3E3E1E1E1DFE1E1DFE1E1E1E1E1E1
EDECEAD9D3D36F6566C1B3B37E6E6E8A7A7A8C7C7D8377778E8586EDE9E8E2E0E1E1E1E1
DEE0DFDFDFDFE0DEDFE5DCDFEBDBDEFFE0E3A96E70A55B5AAA5D559E5E527D5647C5B1A6
00FF0000FF00
00FF0000FF00F6DAD6A47269C06D5FCC6B5ADD806EA05444CB9B8FD1B2AD52373C66515A
5C4C575F525C5C505A5B515A5A50595C555D58515958505B59515C5A525D5B505E5B505E
594F5A594F5A5E545F5B535E574F5C564E5B5A525F5B53605B5561595661585664585566
5D59706058706757715A425A513043E7B9C4EFAEB2DA9087D6866BCE7F54C88247F3B06A
FAB86CF6AC63EC9253DB7640E17449DF7452D4795CCD856D956654513328493630473938
463A3A403635453B3A443A39423A373F37343F3A36423D37443F393C37313C352F39302B
3E2F2C4529285325285A15187C1E1FD05E5DEA6964EF665EEE6255F16858ED6557E7695B
DE6F64CF756DBC7877724144CCAFB3FCE7ECF1DAE0F3D9E2FEDFEEE2BCCB8350619C6978
6D4550DFC0C8FEE7EDF2DDE4F4DDE7F5D9E5FDD7E6FACEDDF2C2CEF4C6D1F3CBD6F3D4DC
F6DFE7F1DDE6F0DBE4F5D9E7F8D6E6FFD4E5F6ACBB963642C95B5ED56967CB736F81423D
4C292740303338333A31313D333542383B4C3B3D5242445B494B6245475C414256414050
3C3A473130382E2B322E2C2F2E2A292925222F2A272E29262B27242A26232925242E2828
2A24242C2626211B1D615D5EECEAEBE4E4E4E2E2E2E2E2E2E2E4E3E0E2E1E1E1E1E2E2E2
E8E6E7DDD9DAB3AAADD6CACCAA9A9BAA9A9BA898998C80809A9494F2EEEDE1DFE0DFDFDF
E0E0E0E0DEDFE1DDDEE5DADEEDDAE0FEDBE193585CAA6462A46055965E4F856558E8DACF
00FF0000FF00
00FF0000FF00FEEBE7A1766FB1675ACD7260C76A58AB5846FEC2B7CD9E989E72738E676C
664349614247583B3F51373A4A31344F36394C37364935343E2B27412F2B46332F49342F
4B332F4E36324E36324C3432483030452C2F442E3148343647373A44393D48424C4D4B59
544F655E526A67546A4125349F777FEDB7B5C37A6BD28163CF7E4FC87E41FAB771FFBE74
F6AC63F5A05DED8850F38456EC7A55DA6F4FCF7459CB846EA97C69573B2D3C292240322F
433836403634473D3C3D33314238363F37343D3834413C38433E3A3F3A343B342E39302B
3F302D4529285726295A1416862725D86560EC6B65ED645AEF6558ED6557EB695BE36D61
D27067CF827C925C5C815E62F7E2E7F1E0E6F0DBE4F6DAE6FFDDED9E75858C5D6D7C505D
8C6E76FAE5EAF3E0E6F1DCE5F5DBE8FFDAEBF2BBCEB57586A46270AB6D78A16F7A94707A
E8D1D9F1E0E8EEDAE5F0D8E5F7D7E6FFD4E3BF6E7D9A343FDA676AD36663CE76727F403B
5531314130363F39433635433638473A3D503B3D523D3F564A4C63424459444557373743
2D2C342E2D322624272725262C28272A26232C28252D29262A2623282421251F1F2B2525
2B2223342B2C201A1C6E6A6BF2F0F1E4E4E4E2E2E2E2E2E2E2E4E3E1E3E2E1E1E1E1E1E1
E2E0E1E5E1E2F6F0F2CEC3C77C6D7095878794888A7B7172B1ABABEEEDEBE0E0E0E0E0E0
E0E0E0DEDCDDE3DDDFE6DADEF1DCE3F4D1D791595AB2716D9C6055895B4C968073FCF3EC
00FF0000FF00
00FF0000FF00FFF7F5C1A29D9D5F54C87263CB6757BB5546EC9486FDADA2F4A7A1F2A8A5
EFAEAAE8ABA8E2A7A3DDA49DD9A29BDAA69BD7A799D2A794CAA58BC6A387CBA689CAA384
CC9F80D0A183D29E86D29E89D49F8FD19D8FD1A092D4A89DD2B0A6CCB5AFD7CBCD8E8691
5044586051665A42524F2F34ECC2B6D19B81BE7950C27942D09049F7B86BFEBA6FF3A960
F49F5EF18E55F28355F27C56E66F4FDD6F54CF735AC67F69AE816E896D5F67554B42352F
3328243D322E433836403533413634433937423A38453D3A433B38473F3C3D33313E332F
43312F462A29552427601A1A8E2F2BDB6861E96960F1695DEC6456EC6859E4685CDB6F65
CF7871BB7B796F4748CAB1B5F9E6ECEEDDE5F1DBE7FDE1EFEBC4D6865B6C976D7B613D49
D0B9C1F6E5EBF0DBE4F3D9E6F9D8E9FFD0E5B3667AA95062CB717DC97982AC70786C434B
DCC2CBF6E2EBEFD9E5F1D5E3FED8E7F8BBCA963944C35258DD6765D66964CA756E7B3E3B
532F314231393C3441383745393B4A393C4D36394C40415545465A3F3E4E3838442C2B33
28272C2C2A2B252422252422282723282723282725282725282725282423251F1F292021
3026273128291D1719817D7EF5F3F4E5E3E4E2E2E2E1E1E1E2E2E2E2E2E2E2E2E2E2E2E2
E4E3E1E8E7E5F7F3F4D8D2D45E53576A60617D74775D5757B3B2B0EAEAE8DFDFDFE0E0E0
DEE0DFE0DEDFE6DDE0E8D9DEF5DEE4E6C3C7824C4CB479738C5B4D825E50B8A79F00FF00
00FF0000FF00
00FF0000FF0000FF00FAE7E3B1827AB46C60CF6F61C5594CD96F61E57B6ED26A5FD87369
DF7E75E0837BDC8279DF877BDE8879E59481E29780E4A184EAAE89F7C195FBC797EFBA88
D99F6DCC8E5DCA875CD38E67D28C68D79271D89578D49A82BE917EB4968BF3E1E17B6F79
53465863506343293297746EE2B69B9A6438C68649E7A45DFFC172FFBE6EF1A75EEC9756
F18E57F18254F17954EE7153E56951E0705AD57964C5816C885B48674D3E88766C8D807A
6459553D322E362B273C312D403533483D3B443A38443C39443C3948403D413735413634
412F2D4729295220216019179F3E38E16F64E9695CEB6657EC6758EA685AE26C60D47269
CE837E8C59587B5D5FF5E2E6EFDEE4F0DCE5F5DDEAFBDCEBA77C8D90647377515E8B6D77
F9E6ECEFDEE4F1DCE5F6D7E6FFD7EAE0A1B6A14457D66D7CDA7680D48288A0636A885F67
F6DCE5F1DDE6EFD5E2F6D4E4FFD6E6C17987A33840DE6366DC655FD46961C6736B723834
502E2F402F373B333E3A38453A3C4B3436453334463D3C4C403F4D3A38452D2C34262429
2624252827232726222524202726222827232928262625232322202A2625282222281F20
2D23242F2428271E21A29C9EF3F1F2E3E1E2E3E3E3E1E1E1E2E2E2E3E3E3E3E3E3E2E2E2
E4E3E1DFDBDAF7F1F19E9596867C7DF8EEEFF4EBECE1DBDBDEDDDBE2E2E0E0E0E0E0E0E0
DEE0DFE0DEDFE6DBDFE9D9DCFAE1E5D1ADAF73403DB38178855E4F7D6656DDD2CC00FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E7CEC7A37369BA6A5FC66054DD685EF2766CEA6C60E86A5E
EB7166E76E63E87062E77163DF6E5CE37661DB755CDB7E5DDB865DE39766EEA970F8B679
F7B676E5A462D48E50C98146C47940C47844C57D4DBD7F588B5D43D6B6A9C5B1B2574A54
5F51624A3844503B38F0D1BDD0A47DCF9B62FCBF7CFFC076FBB367F0A059EC9253ED8852
F38457F07855F17156EB6953E86956E3705DD27563C985728557484E3427513E376B5E58
877C788C817D70655F4A3D37372C283C312D433834443B36433A35463D38463C3A413332
412D2E49292A552221671D1AAB4940E57164E66758EF6A59EB6657E96B5CDE7063D2786F
BB7C776D4442D2B9BCF8E7EDEDDCE2F0DBE4FCE0EEE0BECC8051619C707D63424BD7C0C6
F7E6ECEEDDE5F4DAE7FBD5E4FFC9DBAE5D6EBC5161DE6E7AD47478C77B7F7E4C4FCCACB1
FCE5EDF0DAE6F1D5E4FFD4E7FCBBCF9C4150C55056E46765DC655DD56F63BC6F6567322A
4C2D2B3B2B2E362F3635343C3C3A473939453838443D3B483D3C443431382E2C31262223
26221F2A27222F2C2724211C26231E26231E2A262326221F231F1C2A25222D24252B2223
2D22262A1F252D2228C0BABEEEECEDE2E2E2E2E2E2E2E2E2E2E2E0E2E2E2E3E3E3E7E7E7
E8E7E5746F6C887E7D564A4A736564998B8A8B807E827876DFDAD7E6E5E1DFDFDDE0E0DE
DEE0DFE0DEDFE6DBDFEBD8DCFCE2E5AF8B8B72433DAE8476775C498D806FF4F0E700FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF8F4C7A9A1995B50B85E53D9675DEF6C62F2695FEE6459
F76D62F56D5FF36B5DF57061F3705EF1725FE76F57E47557E37B56E28355E48F59E9995C
F4A968FDB470FFB571FFB874F9AC68EDA261E49E63BD8353B88D6DF5D8C88A7574634F58
6A56613520259E8378FEDBBFEEBB8CF9BD81F6B36FEA9F5BEA9554E6884BEA824FF28157
EF7453F17156EE6A55F16C5BE76555E06D5BD57866C6826F855A4A51372A493830493E38
4D443F6B625D887D799186827B706C5348443E332F392E2A3E35304239344238363C2E2D
412D2E4F2D2E561E1F702220B14C44E56F63EA6B5AEC6957EB695BE16B5FD9746AD0817A
8A55518D6B6AFAE6E8F1E2E7F1DEE4F3DCE6FFDFECA6808F9264717B515D8F747BFBE8EE
F2E1E7F2DDE6F4D8E6FFD7E7E69DAE923442D86972D96A71D87E809E5A5B895F61F8DDE2
F3DEE5F0D8E5F4D5E5FFD5E8CF7E91982F3DE3666AE2615CDB665CD06F5FB87062633128
4628263A2A2B3329312D2A31322F383B39443A38433E3D453D3A413432352F2B2C282423
26221F2926212B282324211C2A27222A27222A252227221F25201D28222230272831262A
2D2027291C23382D33D7CED3EEECEDE2E2E2E2E2E2E2E2E2E3E3E1E2E2E0E3E3E3E6E6E6
E8E7E59D9895968C8B948685A0918E9687848C7E7B908583EBE6E3E7E3E0E1E0DEDFDFDD
DDDFDEE1DFE0E8DCE0EED9DEFEDFE4926C6B9469629E786B6B5945A7A28FFFFCF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F9E6E0A57970A1584FCA6259E66A60F06A61ED6056
F4675DF96D60F86C5FF46B5BF56D5FF67263EF6E5BEC725BE67356E47756E78159E58658
E78D5BE58E58F09C60F3A263F6AB6AF9B473F6BA7EDFAF7EF8D8B2AF9680472E29533A3D
462E2E553832EFC9B6E9B796E29E71EA9A65E8915BE88A54E6804FEF8355EE7854F27557
EF6D55F06C57F26A5AED6859E96757DE6B59D47765CB877483584750392B46382F49423C
4C4441473F3D4B43405F5651827773988D89847975655A56463D3838312B362C2A3B2D2C
3F2B2C4E2A2C581D1F762625BB544DE86F64EA685BEB695BDF6558DB6F65D27975B97876
683C3DCCB2B3F9E5E7EFDEE4F0DDE3FCE2EDE1BBCA7F54659E727F603A45CEB7BFF6E5EB
F0DDE3F4DAE5F9D9E8FFD0E0BA6373B54B55DF6E74DB7276C77778794142CAA7ABFBE4EA
EFDAE3F2D8E5FCD7E9FFC4D8A34756C34E57E76567E4635DD56456D27564AB68585E2F25
432724392B2B372C34342D3537313B39363F3B3843403D463B383F2B292C2824252D2928
2B272429262128232027221F2C27242C27242C2324281F20251C1D2E252632272B30252B
2B1E27271A234B4048E1D8DDEDE9EAE0E0E0E2E2E2E2E4E3E0E0DEE2E2E0E3E3E3E2E2E2
E1E1DFEAE9E5E4DFDC8C8280998E8A9688859B908EA39997A49C9A7F7B7AE1DFE0E3E3E3
DFDFDDE3DFDEE7DBDDF1DBDEF5D5D886605FB0857E846256665647CECABE00FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E5C8C298635BB8645AD16559E86C62EA665A
EA6256F2685BF3675AF56C5CF56B5EF46C5EF46C5EF06D5BEE705AE66C54EA775AE77958
E67C55E68155E58352E68854E18A54E1925AD7925BDAA273FFDDB7D1AC92B88E82B1867F
AB8079DDAD9FFAC0A8D58E6EE58D67EB8A5FED8359EB7E55EF7B56EF7657EF6F54F16D58
F16A57F46C5CF1675AF0685AEB6758DF6A59D57662CC85718E614E543A2B473930443D37
47423F45403D48403E473F3C453B39584E4C796F6D9389879088857068654E44423A2C2B
301A1C4521235B1F217A2928C05753E66F67E86A5EE3695EDE6F66D0736EC88081824E50
927275F9E5E7F1DEE2F1DEE4F3DEE7FDDFEBA97E8F93677681596496777FFAE7EDF1E0E8
F1DCE3F7D9E3FFD9E7E2A4B3983844D6676EDB6E71D67878A25E5D835557F4D9DEF2DEE7
F1DAE4F5D5E2FFD6E7D18A9C9A303CE2636AE86261E16158D66658D178689A5B4A4F271B
41292535292B372D35352D383A343E3B35413D3A453B3841302D3429272A232122272624
2925222622212824252C28292D27292C26282920232920232E25282E252831282D31262E
2C202A1E121C5B5159EAE4E8EAE5E9E1E1E1E2E2E2E1E3E2E3E3E1E4E4E2E3E3E3E2E2E2
E1E1DFEEEDEBCDC9C8696461877D7B796E6C817674635958847E7E6F6B6AE8E6E7E4E4E4
E0DFDDE1DDDCE8DCDEF5E1E3DEC0C264413FBF9A916F53477D7367ECE9E000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF7F4C5A6A1995F54B96759D26C5DE06A5C
E7695BE45E52E96153E95F52EC6255F06457F4685BF3695CF36B5BF3705CF1705BEB6D56
EC7358EC7557EA7854E87852E97D56E88359DB7B53DA855EF1A686F1AA8EF0A892F3A797
F2A998F8AA96E18971E07E63EB7F62EE7B5CE97254EF7357EB6D54EF6D57ED6855F16A57
F16858F16858F76B5EF1675AED675BE16959D97865CE8572916250573A2A49382E463D36
49413E443F3C443F3C46413E453D3B463E3C4139374E46446B6361867E7B958B898A7C7B
6B565550292A531719701F1EC05656E6706CE16A62DE6F66D67972AF65628F5B5D5C3A3B
D3BDC0F6E7ECEEDDE3F1DCE5FCE2EFD8B6C675495AA074835E3D46D4BBC1FAE7EDF1DEE4
F5DBE6FBD7E3FFD1DEB56B78AF4954DB6E74D57173C87776794343C8A6A7FCE5EBEEDAE3
F2D8E5FAD4E3FFC7D6A85161C04B54E86165E7605CE4665AD36858D17E6C89503F472519
37261F3128293932393B353F37343F3A3742413B47322C362D2A312C2A2F282629252525
26242527252828262B28252C2A252C2D262E2B212A2A20282A2126251F23251F232B2129
3329322D262E736E74F0EBEFE6E4E7E2E2E2E0E0E0E3E3E3E4E4E4E2E2E2E1E3E0E1E3E0
E3E3E3F2F0F1B6B2B3736D6DD9CFD0D9CFCE9F9594A69D9EEDE9E8DBDAD8E2E2E2E1DFE0
E2DEDDE3DDDDE8DCDEFAE7E9B89E9D5A3E3AB59D91635346A8A19900FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F8E9E499786F8D594CB0685AC56D5F
D26D61DA6C5FDC665AE56B5CE06053E26052EB6559EF6759EF6759EE6656F16959EE6958
F16E5AF2715BED6F58EF7359EF7357EB7456EA775AE5785BE37E62DF7D62E07C64DD7962
DA7762E07A64E4765FE8745DEC725BEE705AF06F5AEF6C58F16C59F06858F16858F66D5D
F16858F2685BF4685BF2685BEE685CDF6556DA7563D1836FAB73645E382B4D342D4A3B36
483E3C423D3A433E3B443F3C423D3A453F3F423C3C413B3B473E3F48403E58504E7B6D6C
9F8689A87F83A264678D3B3DBF5756E2726EDB6E67D7766FBC716C753D3CC8A4A6D2B9BD
F1E1E4EFE0E5F0DCE5F8DEEBFFDFEEA982948F60727B515F95777FFAE5EAF3E2E8F0DDE3
F5DBE6FFD8E6E0A3B28C3C49C8646ED87077D57C7EA05A5C835659F6D9DDF6DFE7F1D9E6
F5D6E5FFD5E5E096A5932F3BE16367E95F5DE66057DF6558D46D5EC97A6B7A4638402217
31221D2B25252E2B32322F3A3632403834423C3642302A3429262D26242928272C28282A
28272C26252A1F1E24201D261E1B241F1923251D28302931302A2E3832364D464D5F585F
726B735550568A888DF3F1F4E4E4E4E3E3E3E2E2E2E3E3E3E3E3E3E2E2E2E1E3E0E0E2DF
E3E3E3EAEAEADDD9DA7872725B5253574E4F746B6CD3CDCDEDE9E8E4E3E1E0E0E0E2E0E1
E1DDDCE5DCDDE8DCDEFCEAEA8B7371776058A69687655B4FDEDBD600FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E3D6D0C0A9A1B29087AD7E74
AF756AB97367BF6D61C96D5ED36D5EDC6E5DE16C5BEA6F5FEB695BE86455EC6758EB6655
EA6552E96451ED6857EF6A57F06C57EF6D57F06F59F47660F17762EF7661EE7763EF7864
E8705FEC7362F17462F1705DEF6C5AF06B5AF06B5AF36B5BF06858F2685BEF6558F66A5D
F1675AF2685DF4675DF1645AF26A5EE46658DF7162DA7E6FB672676E3C335635304E3938
493B3A443C3A413B3B423C3C423E3D413D3E423E3F423E3D453F3F45403D433E3B463A3A
533A3E774E54A86A6FB9676BC76363DA716DD3706AD7847E7B3F3E9D7575FFE7EAF2DFE3
F0DDE3F2DDE4F3DCE6FFE1F0DBB2C48152669C6D7F633D4AD6BFC7F5E6EBEFE0E7F0DCE5
F5DDEAFCD3E1A1616FA04E5CD0757ECE757BC4797D743C3FBF9CA0FDE4EAF1DAE4F3D7E5
F8D6E6FFCFDDB65C68B9464DEA6465EB605BE35E55E0685ACF6D60C2786B6A3A30351A13
2B201E2B262A29262D29273232303D3634413733412A27322E2B3428252C252229262429
1A171E1F1C232A273035323B413E475C575E6E69706E696F726D716F6B6C696367565054
443F452C272DA09EA3F3F1F4E3E3E3E2E2E2E2E2E2E3E3E3E3E5E4E2E4E3E2E4E3E1E3E2
E2E2E4E9E9E9F2EEEDA49F9C473F3D534B49C4BCBAF1ECE9E3DFDEE1E0DEE0E0E0E1DFE0
E1DBDBE4DADBEFE1E1F0DEDC614A44AB998D84786A8B877BF9F8F300FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF4F0F6E5DE
ECD1CADAB5ACCC9D93C0867ABA7669BF7164C46C5EC96959D66F60DB6B5DE36F60E66E5E
E56A58E66957E46254E76354E86352E45F4EEE6656EB6353F26D5CF16C5BF36E5DF4715F
F36E5DF67160F46C5EF66E5EF16959F06858F56B5EEE6457F3695CF1675AF4685BF3675A
F1675AF1675CF5685EF3665CF1695DE8695AE26C5EDE786CC8766B793A335D312E543837
4E3C3C473D3C483F40423C3C403A3A3F3B3A433D3F453F3F433D3D403A3A464040473B3B
4F363A5A313762232B823036C76363DB7370D97872B665618A4E4DF4CACBFFE2E5F8DBE0
F8DAE2F8D9E1FEDAE6FFD7E5A66F82975E6F81515F9B7580FDE6EEEEDFE4EFDEE6F0DCE5
F9E2ECF0CFDA743C498A46519F58609D5A617541458D6468F5DADFF2DDE4F3D9E4F5D5E4
FFD7E8DB99A799313ADF6164EA605DEB6258E46457D56557CF7668AD6B5F582D27311917
2B21202523262B282F2A2931302D382E2B362A27322F2C35302D342D2A313533384B464C
5A555B6F6A70807D84838087807E837573786560644843473C3839363233302A2E2D262D
27202739343AD3D1D4EDEBEEE2E2E2E2E2E2E2E2E2E2E2E2E2E4E3E1E3E2E3E5E4E2E4E3
E5E5E7EEECEDB2AEAD888481A39E9B918C898B8683E2DEDDE6E5E3E1E0DEE0E0E0E0DEDF
E3DDDDE6DADAF4E4E5C9B7B35E4C42B1A1946B6557D1CEC500FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF5F0FBE6E1EED3CCD8B6ADC79C93B9877CB5776AB87061BE6F60C76E5C
D06F5CD66D5AE06F5FE46C5CE86D5DEB695BE96455EA6252EA6151EB6250EE6553EC6351
F26655F06453F46859F86C5DF66A5BF36A58F66A5BF66A5BF26657F46859F26959F16858
F36A5AF1675AF5695CF4685BF0685AEA6657E6685AE47468DC7B728C4239531E1A4F2C2A
432E2B413332463C3B3E3838443E3E3F3A37453C3D443B3C443B3C433A3D413B3D413537
493336593237602129752329C35F61DE7572DA726FAB4E49B56969FFC3C4FEC6C9FECBD2
FFCDD6FFCDD9FFD3E1E4A7B6914957B06A75804B55E9C1C9FEE3EAF3DEE3F1DEE4F2DDE4
F4DFE6F6DDE3C6A3AAB28A92AC858A967377A08689E0CCCEF7E4E8F0DBE2F3D9E4FDD7E6
FFCBDCA55361BC4851EB6566E9605AE76357DF6757D26C5DC97B6E91584F44211B321E1D
281F202321222E2C2F363437413C424D484E534E546560646E696D7A76777D797A807C7D
777374676364585357474246383637302E2F29282624232122211F2824252922292E242C
2319216B646BF1EFF2E4E4E4E1E1E1E4E4E4E2E2E2E2E2E2E4E4E4E3E3E3E3E3E3E4E4E4
E9E7E8E6E4E58A8687D0CCCBD7D1D1C8C2C28B8786D6D5D3E6E5E3E1E1DFDFDFDDE1E0DE
E6DDDEE8DCDCF9E9EA93817D8072678D8377827E75F7F6F100FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF5F0FAE6DFEFD1C7D9B3A8C6988BB77F72
AF6D5DB96D5DBD6A5AC96D5ED0695ADC6B5DE66B5CEE6A5BF36B5BF46B59F56A57F46956
F26752EC614CEC5F4DF06351EF6352ED6150EF6354F36758F36758F66A5BF5695AF36A5A
F16858F36A5AF26659F66A5DF06757EF6759EE6A5DEA7063EB7F72AF574B5D1A11501F18
401F18321A16372825382D2B3B313038302E403635433938443A3B433A3D42393C433739
4C383A542F365D212974252BC15F60E17573DE6E6ACD615EC46561CA7270C97779D28388
D78A90E1949CED9DA8B05D67B45761BE676DA55E64FFCACDFFD1D4FCD3D9FCD5DAFED6DE
FDD9DDFDD9DDFFDCE1FFDEE2FFDDE1FCDDE2FBE1E4FDE2E7FBDEE3FBDAE3FFD7E2FFD4E2
DF93A09B3743DE6064EE6261EC6258E46254D96858CB705EBD796C825349654A43695B58
6A6464706E6F7975767E7A7B807C7D7C78797571726A66675B57564C484744403F3C3837
2A26252E2A292E2A292B2726322E2D2C2B272A29252A2925252422262223261F262C222B
2319219F999DF4F2F5E4E4E4E3E3E3E5E5E5E2E2E2E3E3E3E3E3E3E3E3E3E3E3E3E3E3E3
E5E3E4F0ECEDCECACB938D8F544E4E6D6767AEAAABE9E7E8E1E1DFE2E2E0E1E1DFE3DFDE
E5DCDDEBDFDFF4E4E462534E9C90847F796BBDBCB700FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF8F5FFF1EDF5E1DA
E6C9C1D1AFA5BB9389B48073B16C5DBF6759D06658E06858E36451EC6A54EB6750EC684F
F06D51EF694EF56B51F46952F16450EE614FEE6150ED5F51EE6150F06352EC5F4EEA5E4D
EB5F4EED6152F16558F06457F26659F2685BEE6457F16F5FEA7564D66F5E863021611D10
532214431F133A1F182C19132A1C192D22202F25242E2423352C2D3B32333A3132403436
4B37395330365D262C74292EBF5F60DF726DE36E67E46B63E9726AE9766FE3746DDF7370
DC6E6DD86A69CF6162C85759DE6C6CDB6F6DBF5D5EDB8181DC8A8CDF9093E0959AE39B9F
E29BA1E8A3A8EFADB1F1B0B6F6B9BEF7BEC4FDC6CCFDC8D0FFC7D0FFC8D1FFC3CFEF9FAC
A43F47C54E52EB6564ED6059EC6458E26455D46B58C87563AB73627854466E5A516D645F
635E5B585453575153464243403C3B3433312F2D2E2725262A29272625232D2C2A2C2827
2C2825312D2A2F2B282A26232F2B282A272226231E2B27242C28272521222822262A2028
332C33CDC8CCEEECEFE3E3E3E3E3E1E3E3E1E4E4E2E1E1DFE2E2E2E3E3E3E3E3E3E3E3E3
E6E4E5F1EDEEC5BCBF70676A685F60A49E9EE8E4E5E5E3E4E1E1DFE0E0DEE1E0DEE3DFDE
E5DDDBF2E6E6D1C1C1463835B9B1A69E9C8FEBEAE600FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFF4EEF9E2DACCA49AA2685AB86B5BC86957D66C56E47059E87057F07458
EF7455EC6D4DE46143F06A4FEE664EEF6751F46956F36A58F46B58F26B57F16C59F16C5B
ED6A58F16E5CE96556E66253E35E4FE56051E76253E36151DF6653E87965BD5A47913A29
6E26175F24165323174721183C1B162F1612331B19301C1B2C1C1C2A1C1B302021332022
3C23264824285922286E2327B15250E3746DE66B63EB6B60F16F62EF6D60F17367F2736A
F07168F17168EB6A64EE6D67E96A64E86D66E9736FE2726EDE726FD66E6DD46D6EC96567
C26263BF6162C06263C06668BA6467C06B6EC9747BC6747AC6747ACC757DC76A74B64E55
CB5355EA6664E95E59ED6057EB6559DF6556CF6B5BC67D6C9D6E5E52382B40312A3A3531
34302D2B2726302C2D2A26272C28272F2E2C2726242827252B2A282B2A282726242C2B27
2B27242E2A27292522282421342F2B2C272328231F2723202F2B2A2C28292A24281F181F
615A61EFEAEEE6E4E5E4E4E2E3E3E1E3E3E1E3E3E1E3E3E1E2E2E2E3E3E3E4E4E4E3E1E2
F0ECEDCFC6C77A70719E9495C2B8B9A39D9DAEAAA9EBEAE8DFDFDDE1E0DEE2DEDDE4DFDC
E6DEDCF7EDEB998E8A574E47BCB8ADD0D0C600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FFF0E9B3988D89604EA96F5BBB7059CD735BD06A53E6785D
E17052F07A5CF37A5BF57A5BF06F52EF6D53EC6851E9674FE86A53E76D56E56E58E6715D
E67360E5725FEA7764E97462E76F5EEA7261E86F5EE16A56DA6551DB6B57DB6E5AD36A57
AA49368E35237C2A1C722A1C6E3025511D124B1C16441D183A1B1634181533191835181A
3414173F15194F1219621318A74544E5746EE76B61ED6B5DEC6859F06C5DEF6B5EF16D60
EF6B5EEE685CEF695EEF6B5FED685FEE6B61EF7067EC7066ED726AEF766DEA7169EA736D
EB746EE6706CE7716DE16E6BE16E6BDF6C69E36F70E16D6EDC6869DF6969DC6163E26563
EB6562EF645FEF6259EA6055E96559DD6759CD7162C684767E564A432F263C332E373330
373634312F302B292A2E2A2B2925242B272426221F29242126211E2D2825292522282520
292621292621262520272621332F2C2D28252924212C26262A26252D292A2A2529221D21
989699F5F3F4E2E2E2E3E3E1E5E5E3E4E4E2E2E2E0E3E3E3E4E4E4E3E3E3E4E2E3E7E3E4
F7EEEFB4AAA9A09292D0C2C2CBC1C095908DB8B4B1EBEAE8E0E0DEE2E1DFE4E0DDE4DFDC
EAE2DFEDE6E07F7B709492869A9A90E9EAE400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00EEE7DFA391838A6D5B946754A76D59B56D57C16F57
BE674BD07256DE7C5FDC7759DE7558D76B4FD86E54CF674ECF6D54C0644DC26A56C6715D
C26F5DC3705EC56F5EC6705FCB7260D17663D07361CD715CD0745FCC7059D2735DD37762
C56954C16953B15C48A65544944B3A7E3B2B692B1E581F144C1A1144150D3E110C3E0E0C
400D0C480C0C52070B5D0305A23936E8716BEB6D61EB695BE86553ED6857EF6759EF6759
F26A5AF06858EF6759EE695AEE685CED695DF26E62EF6B5FEE6C5FF27063EF6D60F06D63
F06D63F26F65F06D63F26F67EF6C64F26F67F5706BF26D68F26D68EE6763F16862EF645F
ED6059F3665DEE6157EA6256E66659DB6B5DD07A6DB97D725F3D343D2C253B3330343331
3433312C2A2B2927282A26252824212925222B262327221F2D25232E29262E292528231F
28252026231E27241F27241F2723202824212822222F29292822222E2A2B2F2A2E2E292D
C6C4C5EFEFEFE3E3E1E2E2E0E4E4E2E5E5E3E3E3E3E3E3E3E3E3E3E4E2E3E7E3E4E5DFDF
F4EBECE6DADAA59796726463675D5B8F8A87E6E5E1E5E4E0DFDFDDE1E0DEE2DEDBE3DEDB
F2EDE9CBC8BF8587797B7F719EA19800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F2EEE2D9D2C3B2A89F887A92715E946B55
9E6F55AA745AB1735AB07055B67359AE6D51AE6E53B1755DB27F6ABD8F7FBE9486B89084
B28C7FAE887BA98175A47A6CA37868A67868A0715FA1715DA27059A6745BA47058A77157
A86E56AA6E54B2745DB3725CB26F5CB06C599A51408940317D3425772D206D201667190F
67170E69120B6D0E0A72060397201AE0645CEE6E63FB796BF4715FF4715DEF6A59EF6A59
F06B5CEB6657EE695AEB6657ED695AEB695BEA685AED6B5DEE6A5DEF6B5EED695CED695C
ED695CEE6A5DEF6B5EED695CEE685DF16B60F36A62F56C64F0655EF0665CF2655EF0635A
F2655CEF6258F06359EB6559E26859D66F60CD7F72A36D614D2F2741322F3E3634353130
302C2B332F2E2D29282B27242A26232925222C26262A252227221F2B26222C24222D2523
2C27232A252128232026221F1F1B1825211E2723222925242721232B25292620244C474B
E5E3E4E8E8E8E3E3E3E3E3E3E2E4E3E3E5E4E2E2E2E3E3E3E4E2E3E7E5E6EFEBEC908A8A
968D8E998F8E9F9492978C889A938D97948FDAD9D5E7E8E3E1E1DFE1E0DEE1DDDCE4E0DD
EFEEE9B1B3A88E94866B7366D7DCD500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F5ECE4DACEC4B4A4
AD9887B39A86BA9B89BC9B8AC3A08DBE9E89C0A18DD8BDACF1DED0FFF2E8FFF6EDFDF3EA
F8EEE5F2E9E0F2E5DDEDE0D8EBDDD2EADACDDDCBBDCFBCADC3AE9DB8A390AA947FA28772
95796391715C8E68559166539665549B6654A36858A76857AB6858A86353A155479C4E41
9C4A3EA24A3EAB4D43AC453CB6463BD86457DF6759E56B5CE96E5CEE715DED6E5DEF705F
F07160F17261F47262F57363F27060EF705FF27062F16F61F36F60EE6A5BED6859F06B5C
EE6A5BED695AEC6756ED6859EF6759EE665AF2695FEA6056EF655AF06359F06359F16359
EF6157F26659EE6255EC6859E06657D77061CB7D708F564B4F2A22472F2B40312E3B302E
342A28352D2A2F2A272E29262D2926302C292C28272925242E2A272D28252C23242B2223
27221F2D28252C27242B26232824232622212624252725262722262B242B1C151C928D93
F3F1F4E5E5E5E3E3E3E4E4E4E4E4E4E5E5E5E3E3E3E4E4E4E4E2E3E9E7E8EAE8E9979392
817B7B7D75737E767381797679767163625DDCDDD8E5E5E3E2E2E0E1E0DEE2DEDDE9E5E2
EBEBE3A0A398626A5D8E968BF6FBF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FFFBF5FFFBF5FFFBF5FFFAF5FFFBF4FFFAF300FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDF6EEF5EEE6
EDE4DBE7DDD3DDD0C7D0BFB5C1AFA3B4A193AB9387A4887C9F7F729E786B9A6F5F9D6C5D
AB7364AA6D5BB57061BC6E61C06A5BC76A59CC6858D06958D36854D76855D86755DE6B59
E36B5AE16857E46959E56758E96C5AEA6D5BEE6F60F37463F3725FF47360F26F5DF87563
F67361F77462F77364F67263F67162F67162F16B5FF36B5FF0685CF66E62F4675DF4665A
F36559EF6153F16556E96455E06556DC7063CC76697E3A2F521D154B231B3F21173A2218
3320192F221A2E272128242124231F2726242523242422232625232A26252C26282C2628
2E282A2B25272C23262B25252C2829201E1F211F2228262B2621282520273E3940D9D4DA
EEECEFE5E3E6E4E2E3E5E3E4E4E3E1E4E3E1E4E3E1E4E3E1E2E2E0E3E3E1E1E1DFE3E3E1
E5E4E2E5E4E2E7E3E2E7E3E2E4E3DFDADAD8E3E3E1E2E2E0E2E1DFE1E0DEE4DFDCF2EDE9
C1BEB5787A6F646A60CFD4CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFFAF4FBF2EBF5E8E0EFDED4EAD6CBE3C9BC
DDBDB0D0AC9ECCA093C79688C68E81C38576C27F6FBE7566BF7363C07160C16E5EC46C5E
C76B5CC76A59CC6B5BD06C5DCD6758CF6857D46959D46657D76855D56452DB6A58DB6856
DA6554E16C5BE06858E36B5BE26859E56A5BE56A5BE76C5DEB6D5FED6D60EC6A5CEB675A
E76253E56051E66152E46252DD6354DC6E5FC165567325185E1C0C511C0A461C063E1E07
361D07291806190F03100C030B0A050B0C070C0A0B0D0B0C110F10100C0D100B0F171216
1B1519161014120C0E140E101D1B1C2A282B2F2E342F2E36302F373E3D4598979FDEDDE3
D7D6DBE0E0E2E4E2E5E7E5E6E7E5E6E6E5E3E5E4E2E2E1DFE0E0DEE1E2DDE0E0DEE2E2E0
E3E3E1E3E3E1E2E2E0E3E3E1E1E1DFE2E2E0DFDFDDDFDFDDE0DFDDE1DDDAE9E1DEF3ECE6
6E6A5F64645894978EF6F8F300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFFAF5
FFF9F5FFF9F5FFF7F2FFF3EFFFEEE8FAE3DDF6DDD6F2D5CDEBCDC3E3C1B7D9B3A8D0A59C
C79890C09086BF8B7EBB8678B67B6DB47566B87467B76F61BA6E5EBB6E5CBC6B5ABF6C5C
C26B5AC16654C26554C1604FC66252C86152CB6455CD6355CA5F4FD16153CE5D4DD25E4F
D25D4CD5604FD76250D76251D2614FCE6351BE5D4AA551399C5537894D2977471F6E4B21
61451D4F3D19797053837E6A7D7B6F75746F807C7B7975767975767874757772766D6B6E
7672737F7B7C858182908C8DA6A4A7A1A0A672727C4B4D59474B564A4E576D717A74797F
787D838F94989DA0A5B0B1B5C0C1C3CACACADAD9D7E9E8E4E4E3DFE4E3DEE5E4E0E4E3DF
E5E4E0E4E5E0E3E4DEE2E3DDE3E4DEDFE1DCE1E3DEE0E1DCE1E0DCE3E0DBF1EAE2DED8CC
423F30807E71D2D3CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3FFF9F3
FFF6F2FFF0EAFDE9E2F9E1D7F5D8D0F2D1C8F0CBC2EEC6BCE8BEB2E6B8ABDEAEA2DBAA9C
D9A397D49A8ED59A8CD29286D18D80CD877BCD8579C77D72C87C6FC5776ABE6F62C16F61
BD6A5CC46E5FBD6758C0685ABA6455B66353B26553AE684FA76A4BB3825AD0AA7BC5A775
C0AC7AC7BA8EE9E0BFEBE7CEE7E3D7E9E6E1EAE6E5E6E1E5E5E0E4E7E5E8E6E4E9E2E0E3
E4E2E5E7E5E6C2C0C19B999A757678393D4022272D2F363C3740453A4446424C4E485254
4C56584D5758535B5D51565952585850545370726FE3E4DFEEEDE8E6E5E0E5E4DFE3E3DB
E4E3DEE4E5DDE3E4DCE0E3DAE3E6DFE2E5DEE1E4DDE0E3DCE0E1DBE7E4DDE4E0D7A39F93
484536A2A094F6F5F100FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F5
FFF8F4FFF8F4FFF8F4FFF2EFFFEEEAFFE9E4FFE6E1FDE1DDFCDFDBF9DAD5F4D5D0F3D2CB
EECCC3ECC7BEE3BDB4E0BAB1D5AFA6D1ABA0C9A599C09F8EA98D75B09979A8966EC6B98D
D1C89DA09B75A6A285D7D4C1CCC9C0A6A5A1B4B2B3DFDDE2D1CFD4B0AEB3B8B5BCBEBBC2
E7E5E8E7E5E89A98997577767379777F88854C5753333F3B45524B45524946534A48554E
48554E4A56524F5A564C575349545047524C495049ACAEA9D2D3CDC8C9C1C6C7BFCCCEC3
C9CAC2C8CBC0CACDC2C9CFC3C7CDC3C9CFC5C8CDC6C4C9C2C5C8BFC1C4BB9B9C947A7A70
8B8B81D3D2CD00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFBF500FF00FFFAF4FFFAF4FFFBF1FCF3E4DBD5BF9F9A7D9A9778
908F70616145373923A4A698BDC0B7414340404143A0A1A5C0C1C53034374142475B5C60
9C9D9F9698977C7E7D646867737975B8C1BCABB4AF89948C909C92939F959FABA19FABA1
A0ABA3ACB7B1B0BBB5AFBAB4B7C2BCBCC7C1BFC5C1D1D6D0DFE2DBDFE0DADEDFD7E3E4DC
E0E3DAE0E3DAE4E7DEE4EAE0E5E8E1E7ECE5EAECE7E7ECE6EDF0E9F0F3ECEEF1EAF4F7F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8F8F0DDDFD4
ACB0A1838A7A5860515A6459657167303B35333C39505B57C2CDC939444035413F3D4945
47524C4C5550464C48797E7AC9CBCAF5F7F600FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00E8EFE8CED5CEBAC4BCA5B0A895A09A87928E76817D9FAAA458655E4B575348554E
5D6A639EA9A3D5DBD700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00ECF0EFE3E9E7DAE0DCD2D8D4
DAE0DC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.013213 0.97619 0.264889 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.0119048 0.00523286 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .0119 translate
.95238 .4762 scale
546 string
182 91 8 [182 0 0 91 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF800000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF800000FF00
00FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF00A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
00FF0000FF00
00FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF800000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF800000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF800000FF00
00FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF800000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF800000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000
00FF0000FF00
00FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000
00FF0000FF00
00FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
00FF0000FF00
00FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF800000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000A020F000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF800000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.290056 0.477324 0.541732 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F5F5DCDCDABEBEBC959593767674
898B86B6B8B3D7D9D6F0F0EE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEECD3D2D0AEADAB8786845D5C5A3E3F3A2425201E1F1A1C1D18
23261F23261F3A3C375355507C7D77A9AAA4E0E1DC00FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00D4D3D15D5C5834332F1F1E1A24201D1D1C181D1C171B1A15201F1A20211B
22231D1C1D151B1E17181B1421221C22231D54554FC6C7C200FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00F3F2F0726E6B211E1923221D25241F27262125241F22211C221F1826231C292621
23201B23221D201F1B22211C26272123241E22251E3D3F3AA7A9A6F6F8F500FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A5A4A02F2C2725221D29262126252024231E2926212D2A2535302C3A3531393430
35302C37322E36312E2C282529282323221D2627211E211A2527227D7F7CE8EAE900FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D0D0CE41403C23221D27241F25221D23201B2A272238332F3B3632423A38433B3939312F
3C3431433B38423A374139363C37332F2A262926211E1D181E201B1A1C19797B7AF5F7F6
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E8DAD9D1BFBDD8C6C4DDCBC9E5D3D1EAD8D6
EEDFDCF6E7E4FBEBEBFFF1F0FFF7F5FFF6F4FFF7F500FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F0F0EE
6C6D681D1E1922211C25241F211E19211E193B36323D383435302D39312F393031332B29
372D2B3B312F3F35333E3432443C39423D393D383425241F1D1E191B1D18323431CDCFCE
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00ECD7D47C5751582B2561302C6534306D3C376E3F39
784B467F544E865D598D6661916B6892716C987974A68985AB8D8BB59996BB9F9CC5ACA8
CCB3AFD7BFBBDBC3BFE1C9C5E4CFCCE8D6D2ECDDDAF2E4E3F4EAE8F7EFEDFAF6F5A6A5A3
2F2E2A25241F24231F22211D1C1B162B2A25413D3A2F2B28312D2A2F2A272F2A27312C29
37302A342D273C332E3B322D3B342E3D383245403A35352D24251F23241F232321878785
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F7DFDD8D64606B302A75302973292670262370292369241D
6A272164251E6A2D287E433D733C376C3A336A3934683B366236336438355B322E5C332D
5B342D5A332C5530285D3832623F3963423D6B4E4A6C534F6D5A565E504D554D4B37322F
26221F272621262521231F1C19161137342F423D3A27221F2C28252B2724282320302B27
332C262F2822382F2A3B322D362F2939352C38332D43403938373221221C23241F40403E
DCDCDA00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAE6E59D706D75312E873633872D2C862D29832A26812927812C29
7F2C287A2B267729257D33307A372F7B3C357136306B322B68312C713C3667322C6D3830
6D3B327242386F3E376C3B3471403974453F673A34562D2753352D2F1812130502211916
2E292625211E26221F221D1A221A173A322F463C3B261E1C36312D312C2827241F292621
2A25212D2522332927372D2B362F2938332D2D28243F3C3740403828292323221D21201C
91918F00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FFEFEDA88281702F2D87322F8829278C282896302E8925238E2C2B8F312F
882D2A882E2D832E2B81302D7A2F297C362E77342C692A237539317A3F376F342C70372E
69332969352A6E373070393278413A8F564F7C433C622D276F443D47261F1F0A05271C18
2E262326211E28232025201D221816352B29493E3C2F252338312B39342E29241E27221E
26211D2B23202E2624352D2A342D2739342E26211D34312C44443C30302823221D1F1E1A
424240D8D8D600FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5BC9693692E2A8938359B3C3AB34B4AC65C5C9D3534932D2B9836359E3E3F
993B3B9C4241933B3989363280312C7F362F8C474073332A7C40388449417F463F763F38
7C473F744239713C366C37316F3531753833793A356D302B7D48406237302E110B2D1B17
2F24202E26232A252227221F271D1B2F262144393540352F382F2838312930292329211E
2B2320261E1C2A221F2E2623342D27453E382A252138332F4B48432F2E29252420272622
26262480807E00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00C6AAA7662F2A732521A14341B74F4EBC5252B94F4FA03837A94543A64445943435
943636903534943A398F3A378637327C312B742F2875362F6A2F297039327A453F7A453F
84524B814F48723D37753E39743734712D2A762F2B752E2A8946407C433C4C1F1A3A1914
361E1A3526232E23212B23202D23212B221D3027223C332C443B343E352E312A242F2822
322A27271F1C231B18302923413A34423D372F2A26423F3A413E392A292424231F292824
2A29272F2E2C706C6DA6A0A0CFC9C9F0EBE800FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
D2B9B4693C3669201A89302CAB4541AA413EA8403DA33D399634318E2F2B8A2C2C882A2A
892B298A2F2C8D32318A32308736326D241E8A49439A5F59753E3979464285544F895853
8A5753925D5987504D8B4F4E904F4D843A3981302D83302C8C3935984944813E38561F1A
3B120C3A1D1735221E2E231F2B211F2A231D2A231D2B241E4138334A413C49403B3D342F
3D3630332C26322D2739342E3D38323D3A33423F3A3E3B3634302D2A29252524222A2927
242321201A1A1E14151D0D10422E2F715B5D877173B6A4A4D9C9C9F4E9E700FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E7D5D1
7249435F20197D28239B3735A63E3BA23A379C363293302B8A2B27842624882A2A8B2B2C
8C2D2B8B2C2A89292A872C2B822D286C211B92514BC58B87AB767094635E92615D93625E
A3706CA5706C9A6261935757945253863C3D8A3636862C2B8E302EA04240A149478B3D39
5E221A4819133D1A16361E1A2F201D2E252029221C2B241E2D241F382F2A453C3747403A
47403A47403A47423C46413B423F3843403943403B2F2E292A29252A29252B2A28262221
261D1E271B1D230E1326090E3F1F225E3C3D5737384A2C2C4C332F65504B897871B8ABA3
DBD0CAF5ECE700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00B19591
622B2671241E9132309F3937A33D3B9F3937932F2D8F2D2A8F2D2C8E2C2B8C2A2B8D292B
922A2B8C242591292A8D2B2A8E332E8030296D28218A4D48BB867EBC8A8394615D895653
B07D799C6763AA72719A5E5E7F41426F2B2C7526297C26278F2F30A23E3EAB4543AA4B47
9B433F762D27551B174519163C1E1C3724203325222E23212C22203228262C2421322D29
312C283B3632403B373C373339363136332E2C2B262A29242928242726222B2623291F1E
2A1A1B341B1F2D0C133910184C1F245F32358E6465916B687D5B5265453A5639294D3221
5B41306F5848957F72C1AFA5E3D2CAFCEFE900FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FBE9E5835E58
65221C842B279F3937A2383898302F9D3735993331952F2D902A288C2425942A2C972A2D
962829962527962829992F2F922F2A8A312B7C312B81403A8D564FBC8A83C79491875451
A26F6CC18E8BB67E7F9A5F61A66A6CAA6A6BA75F629242458933348E32339D3D3E973939
933B39984A4882413F5C29263B15143D211E4028283A26273323233325242D2220312725
352B292F25232F2523362C2A2F2724332B282A25212D28252E26242A201F2D1D1E2C1618
38191E38101834050D4D1A215A252D5C282C7141419A6F69AB83799A756397745E907155
8265476E51335A3F2450361F573E2A6E5948938175BFB1A8E2D5CDFAEFEB00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DBC2BD653630
70221E90312DA13835A537369C3030992F2F9C302E982A299729289A2A29A02C2DA32C2E
A22B2D9E2729A52E30A43031A133328B282395403BEDA6A0C88D87915F58D29F9CAB7978
703E3FDBA7A9D49DA26E353BB77F82DB9FA1C8878BB16F71AB696A894546B97375D99395
BE7C7D8E5051793F3E734140653D3D4927264E2C2D48282B45282A43292C3D27293B2729
3523233422223323233626263424253222232E1E1F311E22311C21361B2039141B390E15
410E15430C12561A226B2E36682C34652E33643032764642A27A6EA27F6B937457937752
9880529A7F509D805495784E80623C6F512F5D3E2253351D593C2A725849978176C3B1A7
E3D4CDFAEFE9FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE8D88602622
7D2A269C3836A33735A13130992B2C99282A9D2A2DA12D2EA83435A42D2FA62E30A92E30
A92E30AA2F31AE3336AB3335A733349F3130842221B86561F2ADA8CD928EA06966D7A4A3
926063D6A3A8F1BCC26B363C935A60DFA4A8B07378BB8082905A5AAF787BF0B9BCF8C1C4
F0BCBEDDABAC916161CCA09FF0CAC9BC98985D3639553133502D3140202548282D523237
4525284022243E2123381E213C21263B1E233A1B2334131C3B152043152048101B4C0D18
53101964212A7330396D2E36894D5570393E6935375727237B5349A98672A5876B8E744F
8D7545917A44957C449D824BA1834FA384559D7C5193714B8463426A4B2E593D254A311B
543F2C716050948477C2B5ACE3D8D2FAF2EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F8EAE7825B5663241F
883231A23B3CA336399D2C2E99262BA02C2FB94246B94045BD4449BE4648B73F41B1393B
A93133AB3335BA3F44AF3437B2373AAE3739A431348C2624A44C4AEBA29CCC8C8AC08887
D5A3A6BC8B8FEBB9C2925F685E272DCB9298AB7076CC9497AD797B875556F0BEC1EAB9BC
956769BE9495EBC3C3F9D6D4F8D9D7E8CAC8856566D0B0B3D8B8BDA8858B5C333B5C2D35
602F3557292C471E223D161B4118204B202A481826440F1F511628591627681B2B792636
7E2E397D313B78353C70353BA77278916064774649693B3B5D342E7E5A4CB1917CA68B6D
90794F8B7543917B42968044947E42957D41997E47A28752A78D5AA38958A2875A927950
8167426E5433583E234D351D5A4331705D4FA18F85C9BAB3E8DAD7FEF4F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D9C6C26B3C36722B27
9439389D34389D2F32AA393D9B2A2EAC3B41B7484EA9383EBB484DC45156DA6669E67273
E36C70D2595ED55A5FCA4F54CC4F55C3464ABD4245B541429F39379E4541D58783E7A6A4
FBC5C5C49397A27379EDBBC4AC79807B444AB57C83E3AAB0EDB5B8804C4EDAA9ACEEC2C3
D4AAAB855F5EC09E9CFFE3E1E9CDCA9D817E856968F2D4D6F8DBDFFDDCE3E2B9C1976870
79464D6F3E429B7175C79EA69A6F79623441834E60C1869CA36278BD74888F3A4F9C4153
98404E86353E833C42A96C71A87174A37174966666956767986C697A544B967264B99A85
A58B6A8C754B8069378A743B927940967C419B7E449B7E469E844B997F469E834CA58A55
AA8E5CAB8F60A78A609476507D6040654B305B422C4D36245946386F5D539E9087C9BFB6
E8DDD7FEF5F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00AE918D6B302C85312F
9B37399E31349D2E34A6373D9D3438B55255BC6166B85D62AF4C51AB4447AE4144BE5051
D66368D96268DF666DEC7176E3666CD95A61D6595DD2575AC65253B64D4AA54644BF6E6B
F1B1B1FFCBCD98676A96696CF7C8CED29FA4935A61A4656DCA878E7C3E43C79598EAC0C1
C39D9CCAA9A4977873ECD0CCFEE5E1DFC7C5A98C8EE7CACEFADFE4B6999EDDBEC4E4C1C7
654145AE8A8ED0B0B5DDBEC6F4D3DEBC98A6906377EEBAD1DCA2BAD38FA6C16F86A0475B
A74C5D822C37B0636BCE8C8EA46868AE7675A06A6A996766A3736F996C66986D66A98376
B99984B193777D613C583B11714F22815D2D8C6335976F3E9E7A489F7E4B9F804A9E8149
9E844B9F864D9F864DA58C54A58E5AA58D5DA0875E957B587B604362462E4C311C472D1C
573D2E735D50A08C83CCBBB3EADDD7FDF4EF00FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAE8E6845C5A77302E943636
9A2D30AE3B40B64147BE4F55A43D41AA4E51EE9FA4FFBABFEB9296DB7C80CD6A6DBB595A
A94448AA4146AD4046BA494FC45158CD5860D96268DA6166DA6365D56363D16563BB5C5A
BE6E6DF7B3B2FBBFBF8C5656B17D7FFFD1D5F4BDC3995C638A474E88464A8C5457F6C8C8
BB9592B1928DBA9B96B39793F9E1DDF2DAD8E1C4C6D4B7BBFFE2E6CFB2B6A88B8FF3D4D9
997B7DE2C5C7FFE5EADFC4CBECCED8FFDEECC79DB1B2859AD8A4BBEAAFC5E69EB49E4C62
A750618E3845A3525BC87D829D595AB87878B07372AE7271AB716FA26B6897625C7E4E44
A97F71CCA794AF8B717B583869411D7C50297F52298051277F5429875E30936D3C9B7743
A3844DA4874D9D8346A38B4DA28A4CA28C52AA915BAB9160A88D62A48861977A5A826448
694B31563A24452C163D26145441327563579F9089C9BEB8E9E0DBFDF5F200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00E1C5C2753F3D832E319E3438
A42F35B93E43BA3F44B84349B0464A95393ED98C92F6ABB0C0696FC56A6FD98384DB8B8C
E3979BD08186C56E74B55860A2454D9E3D44AB4249BC4D54C55458C75457D05E5ED26463
D36B6AD77977FAA6A4DE9292AD6664D39695FFD9DCFCCBCFB77C82A26467884849BA807F
F3C8C2A3807ACBACA7BCA09CE2CAC8D2BABAD9BBBDE6C6C9E4C4C7FFDFE3DEBBBFF0CDD1
D5B7B7CFB2B4FFE7EAC4A7ACC2A3A9FFDCE6D1ABBAAD8496BA8FA2D5A4B7FCC1D5B36E81
88394C8C384886323F903F4686373A8D3E41AC6062AF6566B3696ABF7876B6716CA3625C
7A4136BE8F7FC99F89A880667D553270462083532B87562E84532B87562E84502B86552D
885B31976E40AC8854AC8D54A58B4EA58D4FA48F50A28E51A08D559B8A56A08B5EA18B62
A38B659E8660957D5979613F664D2E4E34193D220D3E2413533D2F78665AAA9C93D0C6BD
EDE4DDFFFAF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00E9E8E4D4D3CFC3C2BEA7A6A28B8A886C6B67
65616063625E69686465645F62635D767771B7B8B3E9E9E700FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00BA94917232328F3034A43138
B63A42C24048B43338B93E43B14449983C3FE19A9EE1A0A48F474AA65C5D914B4B935655
FFCACACE9697C18182D79295D79096E99CA4CE737CCA656DBB4E54B54448BD4B4BB84645
C14F4EC55957CC6868C96B6BC66E6CAE605EDEA3A5FFD9DBFFC9CCBD7D7EAC6263A15A58
D99F9BE6B7B1DAB5AFE8C9C6C0A2A0EBCDCDB99798E4C0C4D4ADB2D0A6AAF4C1C6F1BDC1
FDCCCFEDBFC1FFD8D9E0B8B981585CDFB6BEE0B6C0A37985F6CCDAE2B4C1DCA7B7DC9FAF
9952647E31417B2D3A7E2E37792A2F7B2C2F9141448331359D4B4DA55053AA5656A25450
6F2A238C5246C39482C79D84A47D5C7E583173491F774A20794A207E4D25854F2B854F2D
844F2D784621805028906538A27D49A98A51AA9053A49053A39459A69B63A195639D9063
998A5F9E8D629E8B619E885FA28A649A805D8B7150785D40664C33472E1835200D362513
5040307A6C5FA89B92D3C9C0EFE6E100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00EAEAE874757048474232312C2625212F2B28322E2B302C29
312C2939353239363137342F32322A2C2C242F2E294D4C4890908ED4D4D200FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00F9E7E58F625F782E2D983337B13A40
BF4047C03A43BC363FC14249B7494C893130EFB3B2F1C4C1AB7A767D4A4661322CC79C95
FFDDD7ECC9C37C504D704242DEB1B4FFD3D9D58892E48791F28A91EF8285E27676D26463
C65857BC4E4DBD5053BF5557C86061AD4D4E934143E8A0A3FFD0D4FCB8B9D37F7FC66E6C
B2635ED7948CFECBC7FFD9D3C39C97D2AAA8E5BDBEB48A8EEABDC4C28B91D98E95E48F96
EA959AD98789CF8584EEADABDFA5A4C08C8EFBCAD0B4858DC6949FF6C2CEBE8895D9A1AC
E6AAB6A7697472333CA3626AAB696D934C527B2E348332388D363C92373C8F3034903636
883734702C23925D4DD0A68EBB9878A181588E6F408665327C58267C542376471D75411C
824A29854A2C82462A8247297E48248C5D339E7847AA8F5AA3925CAFA570A39D6D959267
9A96709C96729C946F9A916A9C8E679C8D649D8B63A08D659F8C64947E57806947664F2F
50391A452D11381F093B241258423478665AA99A93D2C7C1EEE7E1FCF9F400FF0000FF00
00FF0000FF0000FF0000FF00898A85191A141D1C1723201B2825203B36323E39363A3532
3F3734473F3C473F3C453D3A403B353C37313B3831312E291D1C1731302B8E8F8AF4F5F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00DCC4C277403D843330A1373BB73E45
C1444CBB3C45BF4049BD464CB44D50742521D2A099FBD7CBFED9C9BC9785A7826FF3D3BC
BDA18BF4D8C2C0A18DBB9B8CF7D6CFFFD9D8C27B83AA4F58CB6068D8656CE57275EF7C7F
F58182F27E7FE67275D86467C75457BB4F4FA23E409C4443D6878AEE9E9FCD6D6ED16D6B
D77874D07D77DD9A94FFC7C3DAA5A1925F5CE2B2B2DDAFB1F8C7CDEBAEB6BB646DC65E67
C55A60BE5559A24444CA7473F6AAAAE39FA0E5A7AAE8ABB09C5D65E6A7AFC1848C8A4F55
E7AAB1C68990A96B70DB9DA2DD9FA2D29195C47F848F424A852E3690333B902C34903034
8F35357B2C276F2F25C79783DEB99CB99C74A68A5A957A457B5C26906A3997683C905A34
85482B803C2589402F8E4534813D287C3F2378441F90693EA28A5AAA9C6B9D996A68693F
6365407A7B598A8A689895729B95719C946DA1956D9E9167998A5F9D8C619E885F927B52
93775087694574533461422654361E3B200B2C15053A2719544437766A5EA9A097D0CCC3
EFECE500FF0000FF00B6B7B22A2B251B1A152E2B2627241F39343045403C3C343239312E
3C34313B33304E44424D443F3B322D3D342D433C36433C343431281C1C12212119979892
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00B59693793937913736A93C3FB84147
B94248B23F46A3363C9532379945455B1812C5998CD0AD97BC997BEFCCA6FBD9ACD0B081
AE8E5DD2B281FCDDB1ECCEA8B8987FFBCDC0E39D9DAD5058CB5561D04E5ACC4951D55258
D45358E16367EE7175F2777AF37C7EEB7979E17372C25A59AE4C4BC15D5DB64C4EC45858
BA5050B65451B25D5ACA7C7ACE8785B87775AF7372EBB5B5FFD5D8FFC6CCC77079C95F69
D36268D05F63C65C5EDF7B7DDD7F80C86E70B76164E28D92A65156AD5B61EBA0A5B87074
BE7679EEA6A9A75C60DD9598D391927D3F40D09297CD878F8A3942AF545DB14D57922D33
8E2B2E892F2F6F241F854A3CD0A38CCDAA8AAF8F66AB8C5D7B59295E330679451D8D512F
A35D439548347D2B1F8B372D8B392E873A2A7C3823763F21805A339C8657A69B6D8F8E60
50552D4B532E555A3A5E61446C6B4F817C5F938A6B998E6E9D9370A3967394855E947E57
9A7E5686663F7C5A3484613B83613E81603F7152355E4026492F1638220A311F093B2E1B
544D3D7B776CA29F984948431F1F1725251D2A27222C272345403A403B35362E2B372F2C
3A302E332A255449454E433F382D273B312845383242382F4841373D392E27241B32322A
B0B1AC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9EAE78C64627B3432983637B64549B43D43
AD3C40A73E42B85E60A85A5AA8635E854D40D7AD95D7B391C7A172D6AF76D5AF6EC6A059
EBC57CCCA760D5B771C8AB6FA98A5BE5BC9EF9BBB0A85454C1535CCE525DD1525DD04E58
D14D58CE4B53D24F57D45358D5575BDF6466E97172EE7A7AEE7E7DF18382EA7E7EDC7272
CB6765C16361AE5A58A35956A35F5CAD706DB07473A3686AE1AAADFFC8CCDE838CCA5C65
CE5961D05B61C95B5ECB6364C9696ABB5F60BB6264BA6467B65D61A44B4FA65458D18184
DA888AE69496BF6D6F954747DB9796A26564A1666AF4B5BDA0505B9A404AA23C4790272E
972E35912C30872D2D691E18925948CDA188BF9B79AC8B62A58258693E1466300A7C3B1B
893D258A37277F251D8D302B8D322D8D342E86372A803C276D3A1B68451D907B50A8A173
83845A484E28424727676A4F7D79606B634C6B5F4770604676674A8677568474509A875F
947B5281643A7F603477562B73522785643B75532D71512B785832745833614A28534224
372B13231C0A1912081C1912201D1625221D26211D27221E4A453F39342E3028252F2724
2C251F332A254C433E473C382F241E372C2641342E3D332A433A314541363E3A2F24241A
3B3C36C0C0BE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00DAC5C27747457E2E2DA63D41B84147B53C43
A6353999393AEDA3A0FFCCC4F4BFB1ECBCA5F4C8A5C49A68D4A869EDBF74E4B460DEAC53
E1B457F2CA6BBD9C3FDDBE6BCBAE68C9A873FFD6BAA466598C38369F3E45A9414CB44452
C54B58D04D5BD54D59D54C54D64D54D24B51CB484DD05255CE5858CF6160CF6B69C86F6B
BA6B64BD7A72B67D76B1827CAF8682BA8E8BC89697B2777BA56367D7868CC25D65C45359
C64F55C14C52AE4446BA5C5CCC7B78B9726EB57170B06C6DB3686CB7686DB35E63A85157
BD6267B15759AF595A803031894343BD7F80D4999FFFC1C9A85C68872F3BA139449D2E37
9F2D37982930942B2F852A276A2118A56C5BDAAE95B4906EAC89639E744C6C3813773618
893B258A32248E2F298F2D2C9331309132308E342C88392C7B392366331464421C8D7A4F
ACA5777F805440401A535031A1977E93816B7A5F4C866A54775C41705738604A25746137
7C673C7D683B826C3D7D6537816639937748795A2C70512378592B7E6233604A1B655228
746544574D3421190C1B140C27221E27221E27221E221A17433E3839342E201B17211C18
241F19362F293B33303B312F3128232E2520332824382F283B342C3A362D454138282820
1C1F165B5D58F2F2F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00B19391703837872E30AC3F44BB3F47B6393F
B5424592302F904943FAC4B8D5A692BC9171DBAF80CB9D61E7B76FDEAC57DCAA4BCA9932
BC9025DCB347CBA93DDBBB56E3C56DB5974FFFDAA9EEC09FD59A88CB867FBB6C71BA5E6B
C65767C84A58D34B57D54851D44950D44D53CF4E52C85153C85C5CB55755A554509A574F
A97369C09489B9978EBB9E96B39A95AA8D89AE8887BD8B8EBC7B7FAD5B61C25D63C15056
C24B51C04C4FAF45479C4140B46963B67A72AD7874A87773AB7374AF7174BD767ABB7074
B9686EAE5E61A95D5F7933359E6262A87073B0757BFEBDC5DB8F99A349559F3541A93540
A32B35A42C359D2A2F9830317A221E732D23C18978DBAF96B7906FAF8763A573506F3213
782D168C392990332B8F302C8E2F2D8E302E913830873529823B27753D2258300D61481F
9C8E5DABA573706D403C38126E6347A8937E77584665422E815D457C5B3C7456326F562D
664F236D5829725D2E76602F7E68378A73419379468E733E876C37866D37614A165F4A1B
8071486E6345271E0D1910072E27212B2622261E1B271F1C362F2945403A2F2A26211C16
25201A2F2A243D36303B342E342C29241D172C231E2D241F39322A39352C49463F33332B
1E211843463FE5E5E300FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00F7ECEA8F6968763636933438B23F46B3343BB8373C
BE4346B14747802D29AC6E61F2C4ACCAA37CE6BB86EEBE7CEFC072BC8D35B58926C59C30
D2AC3DC5A22EB3901CB69524EDCC65C9A74ED6B46AE4C084F0C69CF2C6ADFECCC5FFCBD2
F08E9BC04756D34C5AD44851D44B52CE4D51C85558BB5958A6575395564FA4736CBA948B
BB9D93AF978DAC988FB3A099A5948C9D8A84A18884A78383C28E92C37C82B95E65C1565C
BD484EC14A4EC251539C3A37944741AA6E66A1746E97746E9876749B77779F7778A67A7B
AF7D80AC7A7BA47275956467F1C7C9F4C7CC93575FB8727AF3A3ACD47982A3353EB03841
A93037A92E33A72E339F2E30932D2B7A221E874338DFA796D4A88FB28969B18560A06C47
6A2B0C7E331C8936268B3329893229822E247D2F2277301C76361B754021653C1E422400
8B7A46A69C61ABA8715D5B2B3D3413827259B0958266432F774E388C6045825A3775522A
6243175B4011674F1F523C0B564210634F1C705B2677622B786229836D347C672E776330
8173466F624021190621190E2F281E2F28202D241F261F192A231D3B342E453E38332C26
27201A2E271F403931463F37372E29261D16281F18292019362F273A362D48453E33332B
24251F3C3D38D9D9D700FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00DBC9C77345457D3536A23F44B03B43B4353CB93B3F
BB4748AC464480312A6E3323EBBFA2E7C194C29659E6B86DB0822DB78B2CEBC259F1CB5C
F1CE5AF3D058F0CC54D1AC37BC982ADBB955D0B157DDC074CCAF75A5855EF7D2C2FFC5C7
BE616CC44E5ECC4957CD4A52CB4E52C55456B25454974E4897605BB08A81BEA199A9958C
9E8D859B8D84A1948CA59890AB9E96AEA199AB9995A58B8AB08889CC9195C27379BC5B62
C6575EC14C52BD494CB64C4C933E399A5A51A4756F95776F8C756F8D7A768C7474907677
957978997B7B967677957779CFB2B6F7D3D7BD8890A36069B86871BB6067B74C54B34047
AF3A40AC373DA9363BA436399D353695373571221DA9695FE8B8A4CDA488AF8763BA8E67
97633C6C2D0C82381F8A39268736257425147A2F1C8B473079391D70391A5D30114E2B05
997E479F8D4FADA567AFAA73534E24483D1F947E67AF8E7B6136238858429F6D52956746
7F552F724D238562385C3D115034055D43125D4310634A145D440C5A410870581C89733A
76643261532C221800231C0A2A2414312B1F332A212E251E271E172C231E3A312C49403B
40393130292139322A342D252F261F2B221B2A211A2B241C38342B3F3C353E3E362D2C27
1F1E19343530CFCECC00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00BFA7A76C3636883839A63D42B13A40B1363BB74344
A33F3F81312AA3675CDAAB97E8BD9AC9A16ED8AD69E2B564A37619EBBE57F3C95DF3C959
E5BE47D0A930F5D157F8D35ED3AD40A7841ED9BB5BF2D683AF9451D2B385FFD6C3C28081
B95561CF5667C94B59C54C55BA5052AF5554924F49A06F68C8A7A0BCA59DA291899A8B84
988B83998F869B908A9A8F899D928CA49993AFA19EB3A09CAA8C8CBB8E91D19096C06A73
C45C65C8545DBE474DBC4B4DAA4847863732A46B64A37C759178718A79728977758A7A7A
897A77897A778B7977897576877374A4878BAC8188B97D87CA7E88C06971B34F57B0474C
AE474BB14C50B04D52A64348A24244A145468935336F2A23D7A195EBC2ACC09E7BB49167
BC9262925F326A2B0880391B8B3E227E2E13792B14994F36A560439D5E3D935B38996A40
A9824BA185449F8D4DB6AC6F8C895648431B53452AA98F7E956E5F8A594B98604F8F5541
9A61469D6647A671518D5D397F522B7F552B6C471A6947175C3B086E4D17866727866828
674E15635121312402221B01251E0B302A1A332B20372E25342B222D241D2A211A2D261E
433A3349403941383339302B322B25332C2638312B3C3731413C363E3B36302F2A282722
1D1C172C2B26C7C3C000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A88C8B7137368F393CAB3E43B43B40B63B3EAF3B3C
A13F3CE2938CFFD6CAE2B49DB38865DDB381F6CA8BCEA052B18427E7BA53D9AD44B28717
D6AC36E1B93FDFB73EECC550F8D265B59028D5B352DDBF69AB9147FEE0ACF3CBB1965954
AC4F59C75868C3505DBF545CA74F4E96514CA6756EBB9A91C8B4ABA79A919B8E86988D87
978C869A8F899B928D99908B998E889B908A9B908CA69794B19C99B59394C9969BD18A92
C36772C15660BD4952B9464BBD535599403C914C47A3726B977971907C758B7C778A7F7B
877D7B837977827775867A7A8373748D74789C747CA7727AC37A83B15B64A3484D9B4143
9C474AB96A6DB4686CAC6064A4555A9F50539B51526829249A6A60F9D4C2E0C3A5B89B73
BD9C67C59E677D4D1D652A007C390F8139137E33147F3518843A1D8039198442208E532B
96612FA1773D9C7E42A18E53B0A7707F784A3D3212594731AE8E81A67C70915D50814739
8B503E7C3F2A824832A0684FA76F549462418D5D3990643D8B62368B66319B78388A6C24
6348018C7937796C37271E00241D0028210E312A1A3D33293F352B42382F362D262F261F
281F183027203C332E463C3A4038353E39353E39353F3A363733302C282526221F24201D
201B172E26239F9892F2EBE5FFF8F500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FFF5F3937472793C3B973E40AD3E44B3363CBA393EBE4244
A0302EBA5D56EBA299FDC5B4E7BA9DD6AC84DDAE7AD3A25FB2842FF9CD6EDAAF499C7003
E8BB46E0B43BB58811CFA433F5CC62CDA742AE8728E9C56FC9A95ED7B87FFCDBBAE4B4A8
A35B5FA24A56B65661AD545A96504EAA7871B08E85AE968CBCABA1B4A79EA89B93A1948E
9D928C9C918D9A8F8B9B908C9A8F8B988D89998C869D8E89A59391B59B9AC29B9ECF989E
CB7F89BE616BB84D57BD4B53C05356B2504F9445419A5D589E756F977C75907F788C817B
877E79897F7D867C7B84787887777A8F767C987079A46F77B86F789F4E549C4A4C8A3E3E
9C5F5CAA7774A77777A37577A67477A16F709E6C6D855855714C46E7CABCFFE5CED6BE9A
BCA06ECCAE72B49253764E116B3A02672F006628016D2B097730107E33147C2F117D3212
7B360F76390D71421491713EB19D68B1A573695D374436196C5A46927668906C5E8C6053
8C5C4E774335764133824A3B8E564589503D8A533E925F44865834926A39A27F3F987B2D
967E24B7A448BFAF5A70631F281C00251B022E2311332A1B392F234B41374E443B443B34
3B322B2B221D2B211F291F1E2B232127221F2923232B2726251F1F221C1C241E1E2C2422
2C222032251F37261F6B594FB5A399DBCAC2F7EAE400FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00F4E5E286605D7F3B3A9E3F43AE3B42B13239BF3940C13C3F
B83E3DA338328B372DB67768E9B9A3F5CCACCEA275E0AF75B4843ADBAD57FDD170D2A63D
EBBD4DCFA02CB68715E9BB4CF8CF65C69F3AB68F32EFC974ECCC83AE8F58C3A281FFDBCE
F7B9BCA65D68A5555E91494DA16C68BA958DA48980A08E84A89A8FBDB0A7CDC0B8BEB1A9
ABA09AA0958F9E938D9E938D9D928C9D928C9F928CA0938D9E8F8CA4908FAF9392C2999D
CB8F97CD818BBA5F68B64E57C4595FC35C5FA74D4C8D4340A16F68A07E75957E768E7F78
877C78897F7D877D7C877B7B8676798F747B986F77AE757EAC636A98494E954B4C854543
A3736F97747093757394787796787A9779799878799576747F6662B69F97ECD7C6EBD6BB
CDB78ECAB37FCAB276C5A96AB79558A67D459464347843176F3408702F05702C0776300C
77330C7A3C13602F06633D109A804DB6A672A89C6C5F562D3E33155141287158427B5C47
8B685498725D986D5A8D604D895A488B5A498956437F4F385E3112906A3DAB8949A08431
A68F29BAA636C6B446C4B6557A6D272F2300281E002E24092E26133B3223463C3252483F
564C434D443D3E332F342A282E26242A22202620202C2626281F202920212D2322352B29
3628252B1C1528160C5E483B8D76688972649A8479B5A29BDACBC4F1E6E000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00E4CFCC764A478B3D3DA63F43AD353EB5323AC1383FC23A3E
C24040BC4642A8473E863C2F6B3825E0BBA0C9A27BDDB27FC59555B07F32F2C36BE6B856
D5A63CD4A637C39526E2B649F6CB62B18A25DAB356D2AF5DBE9F5CD5B584E1BCA2FFD2CA
FFCACFE29EA99552598D5254B58D8BA58A839C8A809E90879A8D84A39990BBAEA6CABDB5
CFC2BAC0B3ABAEA199A4978F9E948BA297919E918B9F918E9F918E9F908DA18D8CAF9294
B89194C38E94C47D85B35E65C05C64C15A5EB5555697444092534CA77B729C7E76948079
8C7F798B807E8A7E7E8A7C7C8C777C94757BA1727AB778819C51569B4C518741438B5352
A079748F736F8C77748B77768C7A7A8C7A788D79788E7A798876748876729D8C84A79587
A6947EB29F7FBFAC82CAB684CEB87FD3B97ED0B276C6A669BA9658A67E408F652B754811
6537035E32015E35074E2C005D43129F8E56B0A468877E435F5927514A1E60522B614F29
59431A745B337A5D3B8164448D6E4F96775A916F54936F558461419B7A4DAA8C4CA38932
A99123BBA72ACAB935D8C948D2C7539B91324B42002B2300302708322A15372B1B3A2E20
44382C4E443A54473F4E433D4136323F34303E3432403634372D2B332927332824352724
352822271910301E127B6859987E6F8C71608E71619474678E7065997D71AE938AD2BEB5
F2E0DCFFF6F200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00D7BBB774413E933F3FA83B40AC3038BB353EC53C43C4393E
C64041BC403EB64B45A04E43622D1FDEB8A3C09B7EE5BB93DFAF7FC08E51C39349DAAC56
E0B254F3C661F2C761E4B953C09634BB9437E4C06CD0AE66C4A56EFFE0BAEFC6B4B58480
B3767DA86972894E54AA797CAF908D9A87809B8D849B8E86998F869C9289A3968EAC9F97
BEB1A9D1C4BBD3C6BDBDB0A7ABA198A59B92A0938DA0928F9E938F9E938F9D8E8B9E8C8A
A58D8DAF8C90C59096C27C84B55E66B6565ABA5559B459589244409C6159A67B74A0837D
98857F90827F8D7F7E907D7F92797D99747BAB737CB06D76914549994F507E4041966664
9B79778C77728D7B798A7C7B857A78887D7B857A78847977867877817372887A77887974
8A7C718E7E6E9080679C8C6BAD9B73BCAA7AC7B380D1BC85D4BE84D1B97BCDB378C2A56B
B798619F804A8767346A4C18412B00665416ADA35BB5AE66A2A063706F396C663684794C
67562A6C572A70592F533C12644D236750266D542C7D643C8B6F48907442A58A45A38A2E
A9931CBEAA23D2C22FD7C934DBD13EDFD653C3BC546A6514322C00251E002C220031260A
352A143B301E3E32224234273F31263B2D243D30273A2D2435281F2E211833261D36281D
25180824140442311D7A68529F8974937865917260916D5D9974649B76668E6A5C866659
8E7368A18D84CDBCB4EDE3DAFFF7F200FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00C3A29D8045419D4142AD3C40AB2E36C03A43C23940C93E43
C43E3FBF4240BF4F4D903932834A41EEC6BAAA8372D9AF97D6A98CDEAE86D2A36FCC9C5C
C6964AB88B38C89F47B08831C09A47E8C277D8B573E6C38DA4845DDBB9A0F6CEC48D5B5C
8E5055A160689B646AAE8486A188849C8D869C8F87998E889A8F899B908A9B908A9F948E
A29791ACA299BCB2A9C8BEB5CCC2B9BDB3AAA99F969E938DA19690A196909B908C9F918E
9F8F8FA48E90B69296C28F94C37E83B25D64B45458B95659A94E4D984A46A16763AD847E
A387839A8783928080917B7E98777EA1747BB4757EA1585F9045498E4A4986504E9E7674
9379788977758A7C7B8A7E7E867A7A887C7C857979857B7A877B7B817575897E7C8B7D7C
8779768578728779708A7C6F8C7C6C8E7F6A93836A9F9073AD9D7BB9A77FC7B48ACEB98A
D6C08ED2BB85CDB77DC5B071A28F4A83752AA39B48BDBA69D2D38D8F93585E5C2C817952
80714A6D57307D62377C61327F6630776127614B116D591E69521C5941038E7525AB942E
AD981BB8A616D5C62BDAD030D4CC2BDBD63ADED949D3CF51A39F346E68123E37002B2100
231A00261D002F240835270D34251032231038271535241232231031220D30210C281A00
1F110037280770623F76674675654C8A756293796A9B7E6EA18071926E5E95705E96715F
94715E8766538367528B705DA08B7AC8B6A8ECDFD6FFF9F400FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FFF6F5AF89868645419F3F41AB363CB2333AC23C45C13840C94047
C33B3FC44244BC4445922C2AC67874FFCAC3F2B6AEF7BDB1F5BCABF7BFA8E0AE8BD3A478
E2B57EC99D60D9B26FDEB877E8C486B6915CCDA67BE7BE9ECA9D86D9A99DFFDFDBE8B1B4
9654588E5055B07D828B6767604B468B7E769E938D9B908A9A8F89988D87988D879B908A
9D928CA29992A2988FA99F96B5ABA2C5BBB2CEC4BBBAB0A7ADA29CA297919E95909E9590
9D9391A19191A58D8DB18D8FC99297BA7379BB616ABA575CB95659A34948974D4AAE7772
A7807BA48783977F7F997C7EA0777DAA757DB67078974A50984E4F7F3F3D9366619D7E7B
8E79768C7C7C8A7C7C897D7D857979867A7A857B7A877D7C887E7D837978857979867A7A
887C7C837777897B7B887A79867875887B7585787084766B897C6B8B7C679183699B8C6D
AE9E7AB7A67BC7B585D4C38BD4C486CCC078C5BC6DB9B667D1D58BC3C98B5E603158542E
918464B39F7E8A6E4984653792753B8B702B7D671C8673267D6A1E604B00897212AC9724
B09C15AF9E08C9BB1CDBD22BDFD82FD8D42ADFDC37DEDE42DEDD51D8D65BBCB75397913D
6C651D524D0D3B3200372C002F23002B1D002E20002D1F002D1F00322400382B004A3D06
6B5F239A8E527C6F3A75673A6C5B3D705E4A725B4B81675A886B5D9B7A6BA480709F7C69
9070598C6C538F70549D7F6390775976614672604C867667BCB2A8E9E2DAFDFAF500FF00
00FF0000FF00
00FF0000FF0000FF00FEEEEE9C706F853F3DA43F43AF383EAF3037C23C45C0373FCC434B
C63D44C53C43C74046B4363AC55255D56D6CD77371DA7D78D8847AD38B7DF4BDA9D4A88D
E4B999D2AA86B6936DCEAC87DBB898AC876DFCD1C1F5C0B8EFABA8F5AEACFCB8B9FFC6C7
BB797A884E4DB9908EA789876C5953554842716660968D869D938A998F869C8F879B908A
9C918B9C918B9E938D9F948EA49993ABA09AB9ACA4CEC4BBD2C8BFB7AEA5A9A099A19891
9D948F9E938FA2938EA8908EB79091C99297BD7078BB6069BC575DB654559B43419F5650
AE7770AB827CA17E7CA17A7BA9767BB97B80AB606796474C904849854A46A07773957975
8D7B77897B7A877B7B897D7D847A79857B7A897E7C877C7A867C7B857B7A857979857979
877B7D82767885797B857979867A7A857979857A78877976887B7582756D86797085776C
897C6C8C7C6C93846D9D8E71AD9E77C2B483C9BE80C5BE7AC6C781E6ECAC9CA37043451E
6D684BDBCBB2AA8C726E4A26B9945DBD9B51957A219D87248B7714705D00A28F19B5A21F
B6A414B1A106BDAF0ED0C51EDDD52CE0DC32E6E43AE4E541E3E546E4E44EE6E559E2E260
D9D95FCECD59B6B244A7A33897922C8B862289811F8B812090862499902BA89B35B5A840
BEB14BC4B759A494476C5C21624E2968523B816758866A5F7F635787695E7D6153987E6D
87715A8C785D8C7959937F5AA08D63A9936A9E88637C674858442B625340867C70C4C0B7
00FF0000FF00
00FF0000FF0000FF00F0DEDE906060883C3CA63F43AC353BB8363EC13B42C43E47C64049
C03A43C33B45CA3E47CC4049BA3339B02D32B23638AF3B3BA33A367D241EBC7E73EEBEB0
AB8070CBA191F2CDBBF3CEBEA27C71C19892FFD5D7BF7C839A4147A8484CAB5254C17371
A15D5A9B6662B5908AA68F899D8E897F746E584D47574E477D726C9C9289A1948E9E918B
9E938D9B908A9F948E9E938D9F948EA0958FA2958DA99F96C2B8AFCBC2B9BEB5AEB0A7A0
A59C95A09790A19690A69490A88E8DBC9397CE8F97BC6C75BE5F67BB565AB4545599413F
A66058B47971AF7C78AF7979B77778C27A7DA351579B4B4E853F3F915C58A4817D937B77
8B7C79887D7B897D7D897D7D867C7B857B7A887C7C877D7C867C7B867C7B877B7B877B7B
84787A85797B877B7D84787A867A7C867A7C85797B85797B867A7A867A7A837876857A78
877978897B7885766F8676678B7B6196875E9F9059A39A55BDBE72DCE29AE1EAB36C7148
3D3C1EB4A892EBD0BD65422498703CE3BD72CBAE4AC3AE3BB9A930AB9C1DB8A821C3B322
BFB019C1B314BBAE0ABFB40CD3CB20DDDA2DE6E439E7E63CE2E43BE2E53EE7E946EAEC4D
EAEB51F0F05AEEEE5CE9E85ADDDE54DADA54DAD756D6D151D6D151D6CD4CD7CD49D5C845
CEC043C4B745B09F47927D3C5E471D5A3E266E51417A5C518362598A6C6281675A836D5F
705F4B897D63978C6E9D906D9C8F6599885CA18F61AF9970A5916E7362443B301C746E60
FAF9F500FF00
00FF0000FF0000FF00E2CDCC8451508B3D3DA73E43AC333AB7393DBF3E43BC3D44BB3E46
B73D48B23641C53F4AC73E48C93D46C93E45CD4549C94749C54D4CAC4441843731EFB4AE
D8A9A3FDD2CBF5C6C0ECBDB7DBAFAEE9B8BBFFC7D0B4616BB84952C54E54B44848B05250
954E48B27D77AE8D869E8A839B8E889D928E988D89726763514642574C468274719D8F8C
A39894A0958F9F948E9F958C9F958C9D938A9E938D9E938DA49A91ACA299B7ACA6BEB3AD
C1B7AEB6ACA3A89B95A2938EA38F8EAB8F8EC3949ACD8E96BA6970B5595EB75457B65453
A04743A3534CBD6F6BC47674CA7978C77172A74E50A05051834240A1706CA0817C907D77
8C7E7B867C7A8A807F897F7E8C817F877B7B877D7C8B81808A807F867C7B887C7C8B7F7F
857B7A867C7B887C7C887C7C867A7A877B7B897D7D857979857979877B7B867A7A867A7A
8579798C7E7D8C7D788B7B6E907F659584588B7B3D94893AC4C369CDD27EEAF3B0B4BA8A
53523379715CF4E2CEB7997D744F1BD9B569E0C85ED4C244C9BD35C9C130C7BB27CABF25
CBC124C8BE1EC6BD18C6BE15C9C317D6D324E2E033E8E83AE0E236DDDF34E3E53CE2E43B
E2E33DE1E23CE5E640E5E843DBE03EDCE045DBDD4BE7E658DEDB4ED8D246D8CD40D3C73D
D0C340C1B23DAF9C4098813D71542860412584614E7A564A643E357A584E7E60567D6559
77675868604D736D57A09A80AEA888A59D769B9063998C5FA89B6FB9AD856760436E6C57
F9F8F300FF00
00FF0000FF0000FF00D0B8B87C4644903E40A93E44B0373EB93B3FBD3F43B63B40B13942
F68790E77481BB3D49C9414DC93D48CA3D45CB3E46C73F43C54345BE4A4B852624C77977
FFD1D1F9BCBBA66060874143E8ACAEFFCED4FAAAB5AD4955CB4F59CA494EC14B4BAE4C49
9A534DB98881A688809D8A849C8F89968D889A8F8B9C918D958A866A5F5B4E403D5A4F4B
8075719A8F8BA297919D938A9D938A9E948B9C918B9D928CA39990A39990A79C96A99E98
B8AEA5C7BDB4D1C4BEC1B4AEAE9F9CAD9897AF8B8DCD989EE39AA1B55E66BD5D61BE5A5A
C96A66C56863AD524FB25756CA6A6BC06061B557579D4746964F4DAD7673A37C77997D79
927D7A8F7D7B9384818E807F8F81808D7F7E8C80808D8382897F7E877D7C8A7E7E8C8080
8B7F7F897F7E867A7A897D7D877B7B8A7E7E8B7F7F877B7B8A7E7E887D7B8B7D7C8B7D7A
8C7F798E807790807190806796845C9281498D7D32ADA14BCDCA6DC3C571DCE19FE1E4B7
7473576F6856D6C6B7EED6BE7E5D32B79651F5DD7BE3D35ADDD14BDBD344DAD03DDBD13C
D3CC35D2CC30D1CB2DD2CC2CD2CD29CDCA23DAD730E2E139E3E43EE2E33DE0E239E1E338
E1E337DFE233DEE132DFE334DEE236DBE139DDE142E6E74DE3E24ADAD440D1C732D6CA3A
CEC137BEAE34B5A13E7E671B6B4D196D4C29947056754F3C7D564775514367473A5C4235
6150405F5241675F486A644A827D5DAFAA84B6AF83A59D6E9B9364ACA5799B997386866E
F9F9F100FF00
00FF0000FF0000FF00B89C9B814745903C3CAC3F44B0373EB73A3EBE4145B43B40AD3A41
F78D97EC828EB23A46C4414FC8414FC83F49C43B45CA4149C94248C7464AAB373AA73D3F
F79497BA575AB44A4E9D3438973B3EFFA6ABE9848CB9474FCD4F53C7494ABE4C4BA24742
9F5F56BA8F88A286829C8A869E908D9A8F8B9B908E9A8F8DA09591A196928D8280695E5C
4A3F3D59504B867D78978E87A0958F9D928C9D928C9E938D9B908A9D928C9F948E9F948E
A59A94ACA19BC5BAB6D9CBC8D4C5C2CEB9B8BD9B9CC69599E39EA3BF6D73D77B7EC56566
C76967D27772C96B69AF504EB85454B75051BF5859A64846AA5654BA736FB07571A97975
A47D789A7B769A7E7B99817F927F7B917F7D91827F9082818F81808C817F8F81808A7F7D
8E83818C817F877D7C897F7E897F7E897F7E8A7F7D8B807E8D7F7E8B7D7A8E7F7A8F8178
92817195846A97855F94834F948240928234AB9D44C3BA5DCCC86FC9C77CDBDBA7E0E0BE
918C798B8279B3A29AE8D1C1876A4AAA8A57FAE093F2DB7BEFDD6DEEDE65EBDE5EEAE05C
E4DC55E1DB51E0DA4ED6D443D8D645DAD943D7D63EDAD940DBDC42E6E74BE1E344DEE13C
E2E63ADFE334DCE031DFE334DEE235E1E539DCDF3AE3E441EBE748E0DA3CD7CE33D2C72F
CCC02EBDAF2ABAA83A78630A573E008163317C5C33603D1D8A664C6A473193725F7F634E
6047315540255D4A2A6F613E695D3770693D9E9769B7B384B2AE7F949367AAAA84A9AC91
F8F9F100FF00
00FF0000FF00FFF6F49C7E7C844744953F3EA93C41AD3439B83D40BB4045BB444AAF4248
D5717BDD7985A93B48B74252BB4251C04351BE404CC3444FC2404AC2434AC2474CAB3239
BC474DBC434ACC4D54CC4F559D282EC55259D45B62C94C52CF4E52C44A49BE524F99443D
AE736BB590889D8581998A879A8C89998E8A9A8F8D9A8F8D9A8F8B9D928E9F9492A19795
897F7D5E545248413B58514B847B769F948EA196909D928C9B908A9C918B9A8F899F948E
A39892A29791A89D99B1A3A0C3B1AFE3CBCBEBC4C7E3AFB3CD868CB25D62CE7275CF6F70
DB807DE58A87F09290DA7B79C86464C35C5DC0595AB85454A94B49A85350AA5C5AA96361
AF726FAF7875A97874A87C79A37D7A9E7C7AA18480997D7A99807C977F7B95807D927F7B
93817F9283808D7F7E9385858C817F8E83818E807D8F827A95847A90807197867494846A
98866294825490804492843DA59547B0A450C7BD68D2CB7BDDD894D7D49DC5C29FABA994
9C958DA29897A39594C3B0AA6D5342694F2EA58957BFA260DEC171F0D57AF4DA79F3DE75
F0DE70EFE36DEDE36AEBE366E9E162E7E05EE3DF59DFDB53D7D449EBEA5AE7E753E0E147
E1E340E2E53CE1E539DFE337DEE235DDE135DFE138E0DF39E6E33EDFDA36D5CD2CD3C92A
CCBF25C9BA2BBEAF30A99729806B107D6618836A27785E239F8353775A308266419A805D
745A37765F36816B3C6A562362521E6A5E2A766C3B847E4EABA778A6A579A8AA83B3B69B
F8F9F100FF00
00FF0000FF00F7ECEA8A6B688144419B4341A53B3DAA3337B63E40BA4347BA494FAA4249
9A3B43B0545FA44654A84758AF4A5CAD4657B04555B14554B2424EB7454FB94550B8434C
BE454EC4454ECD4750CA444DC9434CC23C45CF4751D04950CB484DC04A4AAE4A48974843
B9847EAC8B849E8984978A84978C889A8F8B988D899A8F8B9C8E8B9A8F8B9A8F8B99908B
9D948F9D96908C8481574F4C483E3C665B578C817DA39592A49791A396909E948B9D938A
9E938DA29791A49693A79895B09B9ABC9C9DDEADB1F4B3B9C17077B2555DAB4B4FB55255
DE8080FA9F9CF79C99F29794F69B9AE58787D17270D37170BF5B5BB35150AA4A4BA24746
9D45449F4B49A65554A95D5DB16B69B0706EB57B79AD7A77AD7C78A77B78A27C79A0817C
9D807C9B818097828199858693817F907E7A93827A9C8C7C9A896F9886629A875C94834D
8F7D3D94833BA09344B1A656C0B76AD5CC87E0D79CD8D0A1C1BB97AAA68D9F9B8F9D9A95
9F999BA09A9EA399A1B3A7AB8D7B795138316546346B462B875B34B18352DAAC71E8BB77
EFCA7AF4D57BF4DA79F9E37DF4E178F4E475F2E573F3E872EEE66AEDE868E8E65FE5E456
E0E34CDCE043E4E643E2E540DEE13AE2E53CDDDF36DCDE35DBDA32D6D32CD4CD27D5CC29
D0C325D3C62CCFC331CBBE34B9AC2CAA9B26A08F259C8C2D9C8A368E7C34715D1E7A672D
77642A766225B09E56B8A65A8B792F5E4D0866551D756736797142C3C095B0B28DADAF97
F8F9F100FF00
00FF0000FF00E5D7D47B5A55864742953D3BA53B3DAB3438B84042B84447B04348A03B41
AE535CB15B66B46471B66876A65969A254649342517F2D3B8F3B488B333F983B46A13D49
B3434FBB434FC64450CE4650CD414ACC3F48CD3D47CF434CC8454ABE4A4BA849479D5650
BD8E88A2857F9E8B859B8E889B908C9A8F8B978C88998E8A9E908D9B908C9A8F8B99908B
99908B9B948EA099939E9791897F7D5E55504A3F3B685A578B7D7AA2958FA398929E938D
9C918BA29791A49693AA9695AF9294B98F93D4959DD5858EC86770C75E65AE41479C3236
9B3435BD5B5AD47573D97B79E08282E48686E68785EA8684E7817FE47C7BD87071CA6364
B85152B65252A541439F3F40A14343A24848A85452AB5B5AB26867B26E6BB67976B27B78
AD7C78AB7D7DA88081A17D7D9E817D9980799A84769E8A719A886092814D917E439D8C46
A69649B6A95AC5BC6FD8D189DAD496D2CC9AB8B290A8A28CA19B8FA09B97A09C9DA09BA1
A19CA39F9AA1A199A4A89EA7B7AAB36F5C6046292B65423E71473B71422EA7785AB0835C
A37947BB975DC9A767DABC74E9CE81EED583F1D983EFDA7FF0DC7BF0DF77ECDF6FEFE56C
EAE160E4DE54E3DC4DE4E049E3E047E2DF42E1DE41DFDD3DDAD838D9D536D7D133D8CF34
D3CA31D5CA32D2C832D5CB35D0C633C7BF30C8BE38BAB034A99E2B9E932A8E832782771E
7A6B166E6008A49635E1D26DE8D974C0B1547B6B1E635516786F38BBB788B2B28CADB095
F8F9F100FF00
00FF0000FF00DBCDCA73524D844540973F3DA73A3DAE373BB94045B94248AD3E44A23D43
B35C64B66973AC6873965D66935F6BAF7D89B5838EB2808BCC9AA5AC7884B87E8ABD7986
903C4B9E3947BD4753C6444ECC454CCD4048CD3D46CE434AC7464ABE4C4C9E4443A96864
B38A849F867F9D8C85968B859B908A9A8F899B8E889A8D879B908C998E8A9A8F8B99908B
9B928B9B928B9E958E9D948DA198939F96918279745C514D4638356557549183809F9490
A0958FA0958FA3948FA8908EB58E91C38A90DD8D96C2616ACA565FDB5F67CD5056C74A50
B0393DA63336A03434A93F3FB95351D46E6CDD7775E07A78E47E7CE8827EE98381E27C7A
E47E7CE47C7BDF7778C55D5EBA4D50BF5154B24548B14749B24B4EA64445A74B4CAE5655
B26160B76B6DBA7677B67A79B2817CA781769C7D69977F5D927E4CA09052A99B54BBAF65
D1C57DDAD190DAD39DC6C197B2AD8DA09E899D998DA19E99A09C9DA09BA19F9CA39E9BA2
9C99A29A97A09F99A39F97A2B7ABB597879139262C402A2D4026253A1E1A957A6FEFD5C6
CBB09DBA9E88A98970A07F60AE8E68B6956AC7A373D4AF78E2BC7EEAC57FF2CE80F2D27B
F2D673F0D86CEDD863ECDA5EEADC59EADE58E4DB52E4DD51E3DD51DFD94FE0D851D8D049
DAD24BD4CC43D4CD3ED5CF3BD4CF37D5CE35D5CE37D2CC38CAC335C5BE39B6AE31A59C25
A097228B820D9E9419D3CA49EAE15EEAE065E3D86E8E842B605915BBB883B1B288ADB093
F8F9F100FF00
00FF0000FF00E9DBD87B5C577F444096403FA73D3FAC3539BA4146B63F45B5444AA13C42
AD565EB96E759A5D6498676DE3BBC4EDCAD1E0BFC8E6C5CEF1D2DACDADB8E6C2CEAF7F8D
7C3A48842D3DB24854C44A55CA444DCF434CCC3F47CB4249C6484BB7494A9E4A48B27570
AE8983A18A849D8E879A8F899A8F899C918B9E918B9D8F8C988D899B908C9E938F9A8F8B
988F889C938C9A918A9B928B9E958E9D948FA097929C938E857A765D524E4B403E645955
897E7AA0958FA99795AC908FB7898CD39097D57984B84854CA4D55D44E55D64D54D75056
D04D52C84A4DBC4144B13A3CA63233AB3B3AAB3B3ABE504FD06462D96D6BE07676DB7171
D96F6FE47A7AE87E7EEB7D7EE37073E16A6ED2595EC75054C75457BF4E50B34649B04849
A94547A54748A04847A3555394554EB08072D3B09ABDA583B39E6FBDAE75CEC385DDD396
D6CC97C0B78CAAA4849F9A86A19D929D9A959D999A9D9BA09C99A09F9CA5A09AA4A09AA4
A09BA29D989F9F9AA19F98A0AAA0A9B3A8B04B3E472E1F262A1B1E2F21214B3D3CF1E3E0
F8E9E4FAE7E1F7DFDBEDD4CDDFC3B7C8AB99B79780AF8C70A67F5EA88359BB9566C3A068
D5B272DBBB70E3C471E9CC70ECD06FEED56EF2DA70F0DA6DEFDB6BEFDB6BEFDD6FF2E072
F4E473E5D65FDBD054DCD24ED9D043D8D03DDDD640D8D13BD6D03CD5D040C5BF33BFB931
C8C13CBBB52DBCB529B6AF20CCC634E5DE52EFE76BE2DB73726B1DABA96EB1B384A9AC8F
F8F9F100FF00
00FF0000FF00EEE3E17E625E79423D934440A03C3EA73439B63D42BA4148B7444BA83F44
A1464DB96C729D5F6488575BF3CBD3F0D0D58F6E758A6B71C3A5ADBFA4ADCAAAB7A27987
A76D7C984B5BA34150BC4855C74853C8404AC94048CA444BC2474AB34B4A964844B78079
AA87819C88819D8E899E938F9A8F8B9A8F8B9C8E8B9B8D8A988D899A918C9A8F8BA09591
958C879B928D9A8F8B9B908C9C918D9C918D9B928D9E9590A39A959B928D857C775E534F
4C413D685A57917B7DB08E8FC18A90DC8F97C5616BC14C55CD4B53D44B52D5484EDA4E51
D74C51D54D51D44B52CE494ED14E53CB4A4EBC3E41B5393BAE3637AE3838B33F40C15150
CF6361D86C6AD66A68DA6C6BD76766DA6868D56164CD5A5DCF5F5ED66867D86E6ED36B6A
C96162C0595AC35F5FB25955934A41A97464FDDAC6F2DAC0D6C6A4D1C3A0CCBF9DBAAF93
A89D879F9685A49B92A29A97A19B9BA49EA0A09A9EA29DA3A09BA2A39EA59E979FA29BA3
A29BA29E979EA19AA1A099A09E979EB8AFB45C5358291E222D23242E24232B2622D8D3CF
F1ECE6ECE4E1EEE4E2F0E6E4F1E8E3F2E7E1F3E4DDEDDCD2E3CFC4D6C0B2C3AD98B29A82
AD9072A48360A38056AC8453B48952C99D60CEA15EE4B56FEEBF77F1C57AFBD283FFDA89
FFE089FFE286F9E17FF3DE75EBDA68E4D45AE1D452DBD14BD8D047D3CD43D8D049CEC63F
D0C83FC7C032CEC836C4BE2ACBC330E5DE50E2DB59F4EE808C8534A09E61B2B483A5A889
F9FBF000FF00
00FF0000FF0000FF00B8A39E73484281403A933A3CA0373BB34045B74046BA454BB4474C
A14145B16164A66569804E51E1B8BCF9D9DCA38386371A1E80656AD7BCC59F818DBC96A3
E1ACBC924E5D953D4DAD4453BF4753C44550C7434EC3444BBF4B4CAC4846944B45B7857E
A688809D8A849A8B869A8F8B9B928D9A908E9B908E998E8C9A8F8B99908B9B908C9B908C
99908B9C938E9C918D9A8F8B9C918D9C918D9A918A9990899F98929C958F9E95909D948F
8E83816F5F5F684E51795054B1727AD57F88B84E58C95057CA4C4FCE4A48D24C49D34E49
D34C49D54B49D44A4AD74D4DD4494CD64E50D54D51D14C4FCC4A4CBF4142BD3F42B3383A
AF3939AC3839B03C3DC24E4FD56162D15F5FD25E61D05E5ED06261D06462DC7370E8807F
EC8483DF7774CC6461B85953B2645A995E50EFCAB8ECD6C1C5B4A0AA9D8CA09486A59B92
A69D98A19997A79EA1A2999EA29CA0A39DA1A19B9FA49EA2A19CA2A19AA19F98A0A1979F
9E989C9D979B9E989C9C969A999397AFA9AD736D712C2628362D2E2A2522201D18C5C4BF
F2F1ECE6E5E1EAE6E5EAE6E5EAE6E5ECE7E4EDE5E3EEE4E2F1E6E4F2E7E3F5E6E1F7E6DE
F1DDD2EAD3C5E1C4B4D0AD99BD987EB48B6BA0745195653FA7764DA6754AB18352C79C67
D5AB71E4BC7EEDC786F6D18AF8D584F4D57BF6D876EFD76BE8D360E9D65EEBDB61E1D452
DBD249CCC336DDD546D0C839D2C63CE1D754DAD057F2EB819992418D8C4BB3B583A4A887
F8FAEF00FF00
00FF0000FF0000FF00E7DCD879625A7E534A904C4B913739B04349BD4850BC454BBC494E
A84144A85253B26E6F8D5757A17778F6D4D3E7C9C9674D4EA68D91F9DEE5A88792B68C98
A773807A3A4ABA6C7CA84C5BAC4351BB4754C44853C1484FBE4D4FA8494598534CBA8B85
A586819D8A869A8B88998E8C9A908E9B918F9C918F9A8F8B9B908C9B908C9C918F9B908E
9A8F8B9A8F8B9E938F988D899D928C9F948E9B928B9C938C9E95909B928D9D95929E9693
A59B99A49494A285878C5D63B16A70C1666DB84950C85153C04B42B94536B2412FBF4C39
CC5342D05243D25043D14B42D44A47D64A49D5494AD74D4DD44C4CD64E4ED64E50CE4849
C84648BF3E42BF3E43AE3034B73C3FB33B3DB84143C14F4FCB5E5BCE6561D46C69D6706C
D56F6BDC7672D06A66BA5B55CA7A71AE6E64C59B8FBA9E93A6938CA598929E9492A2999A
A09A9A9F999BA59FA39F999D9F999DA09A9E9D989C9F9A9EA09A9E9D979B9C959C9C969A
9B95999C969A9E999F9C979D99949AABA6AA847F833531322E2828282421161510B3B2AD
F5F1EEE8E4E1EAE5E2ECE4E2EEE3E1F0E2DFF2E3E0F3E4DFF2E5DFF0E5DFF1E6E0F1E6E0
F1E8E1F1E6E0F3E8E2F5E8E0F6E5DDF0DED2EAD7C9DDC6B8D0B3A3BE9D8CA4816E8E6853
8B5F469061459E694AAB7350C48B60CE9462DBA368E5B06CE8B768ECC369EBCB64E3CC58
E3D453CBBD38DACC45E0CE4EDDC7579A87209D902AFAF194AAA353848340B7BA85A2A685
F9FBF000FF00
00FF0000FF0000FF0000FF009C928963483F9A6964A258599E3E42B8464EC0494FBA454B
B24A4BA34748AD6364A26666835150C89E9FD2AFADC6A6A7BEA0A2E1C1C6A07B83C398A2
A7737F894C5B8C4555DD8A9A9A3A48AA3E4BB33D49BC454BBE5051A04540A15E56AE817B
9477739B8884988A87988D8B988E8D988E8C9B908C988D899B908C9D928E9C918F9B908C
998E8A9A8F8B9C918D978C889F948E9C918B9B928B9D948D9C938E9C938E9E94929C9290
9E9391A59192B08D91C28B91D88891B7535BC14E53C7514FB7493CAC4830B55B39984018
9A3D14B04D26B94E2CC65439CB523FCF5142CF4D40D24D44D55047D34C46D54C46D84D4A
D34949D34B4DD44C50D24B51CB484DC24146BF4145B4393BB23C3CAB3938C75756CF6160
CF6160D86C6AD56966C3605BB560599C584F906159AD8E89A59190A39797A09599A0979C
A09A9E9B969A9993979E989C9C96989B95979B969A9E999D9E989C9C969A9F989F9F999D
9E979E9B969C9A959B9D989F98969BA5A3A89893993C373B2A262726222114100DA4A09D
F6F1EEEDE3E2EFE3E3F1E1E1F4E1DDF8E0DCEBD2CDECD3CEF6E2DBF6E3DCF7E6DEF4E7DF
EEE7E1EBE8E3ECE8E7EBE9EAEEEAE9F0EBE8F2EAE8F5EAE6F6E7E4FAE7E3F9E1DDF2D5D1
EBC8C2D7AFA7BF9088B07F71A16C5A89513A84482C763C168149168B5A17BD9840DEC358
E3CF56CFBD3DDAC64BE6D060AE9435594100948327FBF096B7B05F7E7E38B3B67FA2A683
F8FAED00FF00
00FF0000FF0000FF0000FF00D3CEC8594B4274534CD39C999C474AB0484FBB484FB9464B
B54B4DA9494BA35155AF696B7E40415820218C5958EDBFBFEBC1C2D7AFB07A4D52B28389
D7A5AE9C6771874853E69AA7AF5360B94F5BA02B34B33C40BB4F4DA54B43A15E56B98D84
6E514B705F58948582998E8C9A8F8D988D8B9B908C9B8E889C8F899E918B9D8F8CA19390
988D899B908A9D928C9B908A9B928B9990899D928E9E938F9D928E9C918D9F94929D9290
9D8F8EAA9194B1868DCD8E97D57B87BC4E59C84F54C9524EAF48399F4A2BF8B682E7B270
C59044A1651C8D490893460EA0491CB1512BBB5232C65439CB533ACC4F39D34F40D24A3E
D44942D64B48D5494AD5494CD84B51D54A51D3484FCF464DD14A50C74247C23F45BD3C41
B93D3FAA2F31AC3636AF43419B403B89403A8D5A56B2908EA28E8FA19597A0959BA0969E
9C969AA09A9E9A94969D97999C979B9893979B969C9D989E9691979B969C9B969D9B969C
9E99A09B969D9D97A19E9BA49A979EABA9AE9792982E282C2C26282A2426161010A19899
FCF0F0F1E1E2F4DEE0F9DFE0FFDDDCC8A29F744B47B8918AFFDBD3E9C8BFB7998FBCA39C
F2E3DCEEE6E3EDE9E8ECEAEBE7E6E4E8E4E1EAE5E2EFE8E2F4EBE6F4E9E3F1E6E0F2E5DF
F2E5DFF4E5E0F9E6E2F8E3DEF2D9D4EDCEC9E0BAB1C89D8CCDA1847C5423B8944AEDD16E
E5CE5AD5C148E2CB5BA48B277C620E5B4200AC9C3DF8EE8DBEB95E7C7D31B0B57B9EA480
F9FBEE00FF00
00FF0000FF0000FF0000FF00F5F6F17F787055423BD1AAA39753529D4448B34A4FB8494F
B3494BB34F51A1484C9342489145496D25298D494AC88888E5A9A9C08587692B2E8D5055
E7ACB2E8ABB2D6959DA85B658F333EA13741A22A33B53E42BE514EA34941A36058BE9289
A0837D725F595A4B487769689486859C918F9B8D8A9C8F899C8F89A0938D9F918E9F918E
9D928C9E938D9E938D9F948E9A918A9D948D9D928E9C918D9D928E9C918D9E93919F9190
A59393A98B8DB9888ED78F9AC86371BF4955CE4D52CA4D4BC3574A7C2708CE955EFBD185
F0CD71F1CF6DE3BA5ECB9B47B1792E93520E954B0C9B4911AA4E1BB55024C35731C55233
CC523BD14F3FCF4B3FD34A44D74948DC4B50D9484FD7464DDA4A53D6464FD94952D2454D
D1484FCC474AC24447BA4646AE4C49924440915A57B69391A59192A095999E959A9E979E
9A94989C969A9B95999A95999E999D9B969C9C979D9893999C979E9E99A09C979E9D989F
9F9AA19F99A399969F9C99A2A09DA4B6B1B7918A912923272C26282E2528180F129F9395
FCECEDF3DADDFBDDDDFDD7D6B98D8C7B4B47B2817CEDBEB8BD908A704840542F26856860
F6E5DEF3EAE5F0EAEAD3CFCE8F8B8A716D6A625D5A76716D9B948ED3CCC6EFEAE6ECE7E3
EAE5E2ECE8E5ECE7E4ECE7E4F0E8E6F4E4E5F8DEDFFFDED9FFE2D286623EBD9C59F3D678
E6CF5BE5D059BDA83F715A00796109846F14E1D36AEBE378CBC766797B28ABB1759CA27C
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF00BEBDB84D453A9E887D895A54843E3E9C4244AC4548
AC4445B14A4DA44448983B43963C459C424B8B32387B22267C26297A2427852A2F792326
A15154DA8B90B8696E8732398E2A34BA4B54C1484FC3484DBE4C4CA849459E5751BE8D86
A68782A48F8C8775736052515143427668679687849F908D9D8F8C9C8E8B9E908D9F918E
A398949E938F9C918D9A8F8B9B928D9A918C9C918D9A8F8B9D928E9C918D9E908FA19191
A5908FAD898DC1888FDA8A95BE525FC84A56D14A51CD4849CE574F94341CA15D2EFFCF8C
EFCC70EACF64EFD868F3DC6AF1D769DDBE54D8B551BE9335A2701B925709924C0799490E
AB4F20B34B24C55233D0523CD54D41DA4C48D74649DB484ED9464ED94650DA444FDA474F
DA474FD6474BD44C50C84E4DBF5754A4534F97605DB59191A69294A095999B95999F989F
9C959C9C959C9C979D9C979D9F9AA09B989F99969D99969D9F99A39D97A19A979E9B989F
9D9AA3A09DA69C99A29C99A0A7A2A9B5AEB5857F81292023342B2E32272B1C1012A19194
FAE6E8F8DBDDF8CFCDA97874905D59F3BEB8E1AEAAA3746E784D46A17A73CFB1A7F2DBD3
FBECE7E5DBD97A72706F676598938F9A959189848177726F46413E56514EA8A09EEBE6E3
E8E3E0CDC8C4D8D5D0E5E2DDE8E3E0EDE3E2F5E1E2FADEDBFFE1D6795837B99A59EDD374
E5D059EDDD63A0912A625400938518D3C751E6DE61E4DF67D7D26A7F7F29AAAF6F969A75
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF00F0F1EC89867D655B516A4F467A4B45914D4C974645
9B403F9838399F3C3F98353A98333BBE565FA83F46A4393F972A3094272DA6373EA83B41
9D363AA0404286272DD26E76A33840B13C44C64951C6474EBD494CAC48489F5451BD8884
A5827E9F8A85A3918F9A8C8B7668674F41405446457F716E998B88A19390A193909F918E
9F9490A196929E938F9B928D9B928D988F8A9E938F9B908C9D928E9C918D9E908FA89696
AB9192B38A8EC88992D57F8AB54551CC4A56D2474ED3484BCF504AB34433923718E29A68
F5BD73F6CA71F3D06AF5D769EED465ECD563F3DC6CF3D96AEFD368E5C45DD4A94AC49138
B172259F510FAA4C18C0522DD1533CD54B40D54544D84649DC464FD9434ED63F48DE4750
DD464DD8454BD24649CA4C4DBB524FA4534F955E5BB39190A69294A2979B9D979BA39EA4
A099A0A19AA19F9AA19E99A09D9AA19C99A09D9AA199969DA09AA49C96A09C99A29F9CA3
A19EA79F9CA39D9AA1A6A1A7A59EA5B5AFB3746B6E261D1E342A2B332729231314B7A4A6
FFEAECE3C5C58357545D2A26AA756FD09B95C28D89DBA8A4F2C3BDF5CCC6F7D9D1FBE4DC
FEF1EBB6ACAA1B110F887E7CF7F0EAF3ECE6F4ECE9EFEAE7DFDAD7938A8B3F3637B0A8A6
C1B9B78A858187827E8E8B8686827FB8B0AEFAE7E9F6DEDEFEE2D77C5D40B7975AF1D67B
E4D15BEBE062877B0B887E0BDBD251DCD64CDCD94EE7E463DAD86B81812BA6AB6B91966E
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF00EEEDE9C6C3BC958B8277635A744F497E4943
914E489E4D4A9D42419C35389D3035AE3B42B13A40BC434ABD4149BD4048C2434EC2444F
C0474EC24D53B13D46C14D569C242DB2353DC94550CA4852C1484FB34A4E9D4C4BC08483
A9817F9E86829E8F8A9B908C9E938F9388866C615F4B3D3C594B4A857776988D899F9490
9E938D9F948E9D948D9B928B9D948D99928A9D948F9B928D9C938E9E938F9E908FA59393
AF9294B18489D28F98C86E78BA4852D04D55D1464DD6474BD44A48D04C47B3392EA33420
AC4A27C87241E89E61FABC73FDC975FCD173F7D46EF2D466EDD460EBD55DEED85EF0D65D
F0CF5EF3C361E19F53A04611CA5836D44F3ED54642DC474BDA474FD9464ED64049DA444D
DA454BD54449D4494EC94D4DBD55529F504B96635FB29391A59393A4999DA09A9EA29BA2
9E979E9F989F9E999F9D9BA09D9AA19C99A09D9AA39A97A09F9CA79E9BA4A09AA4A39DA7
A49FA6A49FA6A39EA5A19CA2A59EA5B1ABAF645B5E2B21203125252C1E1D301E1EDCC8C7
FFEDEAC5A9A6AD8784DAAEABE9BCB9C99894AE7473B478778E57547948438B6960AF968F
FAEBE4E6DDD8BAAFABDFD4D0D4C9C3BFB6AFC8BFB8E0D9D3FFF7F4D0C8C62016158F8584
A39998CCC2C1877F7DA49F9CCAC4C4CDC3C4F7E4E8F5DDDDFFE3DB917357AD8E57F2D883
E1CF5FDFD552A69E19CEC73BD6D03AD8D53CDCDA47E2E25CDEDE707D7F2B9FA5678A906A
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F9F8F3E3DCD4B6A59E8D706A
815650905652944A47A14B4AAD4B4CAB4145AB383DB43B40BD4046BF3D45C8444FC9434E
CA4651CD4B55C4454EBE3F48B6343EC33F4ACB434FCB4752C64951B94B4E9F4545B67271
B285829E827EA08F88978C869A8F8B9C918DA095938D81816759584C413F5F5450847975
9D928E9F948EA196909D948D9C938C9A938B9D948F9B928D9C938EA196929D8F8E978281
AF8F92B6858BD68E99BE616BC04C55CF4C52D4474DD44348D44547D04443D54B49C94540
B73F2FA63A209A39169D491AB46D2FD2944BE7B35FF4C96BF3D36CEAD35FE3D550E4D74B
EBD953F1D45CFFD175AC6621B94F27D1533DD84B42D94748DA474DD7444CD7414AD7414A
D9444AD7464BCF4449CA4E50BD5755984A469C6B67B39593A39394A39A9DA19AA1A49DA4
A099A0A19AA1A09BA1A09EA39E9BA29D9AA39C99A29C99A49D9AA59A97A29B95A198929C
948E988D888F8681887873796D676B7C767A4C43462D21213626262C1817503836F2D8D7
FBE2DEFADDD9EECCCABA9795A27A7AE5B7B7E2AAABCB8F8FCD9391C49490C1A0997B6760
F0E5DFD6CFC9968B87887D796C635C685F585049434E4741857D7AA59D9A857B7AC7BDBC
948A89A89E9DA9A19FD3CDCDE8E2E4F0E5E9F0DFE5F2DCDEFFE5DEB3947F937344F4D88E
E0CD66DCD153C0B92DE1DB45D0CC2DD5D333DEDD45E0E05AE2E1776D711D8E94568C926C
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6EBE7
D2C0BCA88C8887605B834E4A96524FA45551AC5150AE4647B24143B83F44BB3C43C03C47
C6404BC9434EC8404CCF4753CF4753CD454FD04751CD4750CA4850C24E51A54143AC5E5C
BC8783A07F7A98847D9A8D87998E8A9B908C9A8F8D9D9290A196948D82805F545249403B
665B578B807C9E938DA0958F9C938C9E958E9E958E9D948D9D948DA0958FA3918FA3898A
B28B90BF868DD88B95B7565FC34E56CD4A50D3484DD44549D64548D64749CF4543D04C47
C94F44C45542B74F36A14321983F138C3A0892470EA06324B08139E2C164EBD75CE3D649
E8D94CE9D250FFDF74C98E40A54714D25A3FD34E3FD44642D54344D9464CD8424BD9434C
DA474FD8474ED1464BCA4E50BD5755994B499D6C68B294929F8F909F9699989198958E96
928B928C858C878289817C837C768077717B6E6B766864725F5B6A5D59685A54624F4955
47444D423F464B464D4A454B4F4A4E5C565A382D313626293B2225321414826361E8C6C4
C2A09E916F6D694A488A6A6BEBC7C7F1C7C8EBB9B8D9A3A1AD7C78C29B96FFE8E4F1E4DE
E8E0DD44413C3E36339D9592B0ABA5BCB7B1AFAAA68D8884615C5967625FBCB4B1F6EEEB
A199967F7A77847F7C6B6766747071F3EAEDF0E1E6F2DEE0FDE5E1D9BCAC795531E8C689
EED47DDECE5DC2B834DFD947C6C326D5D235DCDB43E0E05AE4E57F5C61117D85498E966F
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF5F3E7D5D1BDA19D966F6A824F4B8E4F4A954A45A44E4DA94B4BAB4447992C31
A53039B93D48BD3946CB434FCB434DCB434DD04751CC444ECC464DC74C51B94C4F9F4746
BD7D7BAB807A957A7397867F978A849B908C9A8F8D988D8B9C918FA398969F9492857A78
594E4A473C38655754897E789F9490A39A93A198919D948D9C938C9F928CA69291A98B8D
B5888DC5868ED7818CB74F5AC54C55CF4950D3484FD3444AD5464AD14747C94843C85248
C05744A5472B8C37108939088E41098841037F3B00753C005327009E7F25F1DF63E3D747
E6DA46E7D54BF3DA64ECBD619A480EC35733D2513CD2483ED64645D64447D84349DA444D
D6434BD6474DCF474BC84D4FB85454974C49A27270947877685A5A5953575750574E474E
474047443D4446414746414848434A4A444E4D475354505E595563635F6D66606E6A6470
74717A7C7980837E858B868CA29DA1928C8E352A2E3C2C2F41282C3214167858597F605D
5D3B397F5D5BCCAEACFFE2E0D2AFAD956C6AEEBCBBBF8E8A8B5F5C805F5AFBE8E4F9F0EB
E3DEDA34312C615C58D9D4D0EDE8E4F0EDE8F0EBE8EFEAE7EBE6E3807B787E7975F6F1ED
F8F3EFF1ECE8FAF6F38A8685878384F4EEF0ECE1E5EFDFE2F6E2E1F8DDD489654DB28D63
F7D895E3CB71C0B03FDCD350CFCA3BD6D441DFDD4CDFDF5BE5E8815F66187880448D956E
F7F9EC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00F0E5E1CDBCB599807B75544D7E534C895851834945C58180
AB565B99353DAF3945B93A45BF3B46C43E47CA424CCC444ECE474ECC4B50C24E51AB4747
AC5E5CBF85819C7771937C7693817D958784968B87988D89998E8A998E8A9D928EA09591
9D928E847975564B47423733685D5B918682A196929F94909D928EA39592A4908FAD8D90
B6838ACE8691D47684B84856CA4C57D34B55D4474FD4454BD14649CD4D4AC35348B65741
7B360F7B470EAB8032C29D42CBA844C7A43CBD9D36AF922C88700E7B6900DDD14BE8DE4B
E4DA44E2D646ECD958FDD66DAB6621AE4D22D0573CD64E40D54743D84647D84349D9444A
D7444AD34448D1494DC1494AB95A5889443F9F73709A82807C7070756F737C757C7D787E
827B828781858B868A8D888E918A919792989A959C9F99A39C96A09C96A09D97A19E99A0
A29DA49C979D9D969D979195ABA5A9837D7F31282B362A2C36272A322020CFBBBAD7C2BF
DEC5C0FCE0DCFFE6E2FFE3DFE3B7B4C49490EBB8B5E6B6B2A47F79C8ACA8F9E7E3F0E5E1
FEF7EFC3BFB65750483F383257504A97928CD8D0CDCCC7C39B96933A35326A6762E9E6E1
E1DCD6E1DCD6D7D2CEB0ADA8D6D5D1EDECEAE9E3E5EBE0E4EFDFE2FCE4E4CBA8A26A4431
D2AC85EDCD90CAB15DE6D770DCD35ED3CE4EDAD650DEDF5FE6E982666E1B777F43848C65
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F9F4F0DBD2CBB1A29B8E7A71644942C7A29C
FCC6C6B06569B15057BE4F56BB434CB93C44BE3C44C13B44C63F46C9464CC74A4EBE4D4F
A14343BA706DB47F7B997672937A76907E7A938582928783988D89998E8A9C8E8B9C8E8B
9C918DA59A969F94927F7472584D4B473C3A6C615D908581A09591A49693A28D8CB08D91
BA828BD98B98D26C7ABD4755CA4653D24651D6464FD2454BCE4849C64F49C25E4F7D3213
8F6028E3C676F0DD74E9DE62E9DC59EBDF59EEE15EEEE161EADB64D7C94FE2D552E7DA4E
E4D74AE6D94FE9D656FFDE73D99F55984211CC593CD34E3FD84A46D34343D84347DA454B
D8454BD7484CCF484CC34D4DB055528B4A44A57E79AB9894A298979D979999949A9E999F
9E989CA29CA09D979B9C969AA09A9E9C959CA19CA29E999F9C979D9B969C9C979D9B969C
989399959094979195979193AFA9AB635D5F292021362C2D271D1E4E4242F4E4E4FEE9E6
FFE6E2FADBD6E0BDB7D8AFA9EAB9B4D29F9BC08D89996C678E6D66FBE4DEF4E5E0F1E8E3
C7C0B8C9C2BACFC8C298918B5E5751615A5499908B81787349413E817976E1DCD677726C
3D393089857C4A453F9A9792EBEAE5E8E9E4E5E3E4E8E2E4EBE0E4F2DFE3FDE0E4A68580
67422FBA9873D0B27CD8C47D998A35979028D9D55AE1E167E4E7806C741F7A8445838B64
F8FAED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EDE8E4BBB2AD93827B
B396908E5E5A8A4645A65051B75054C25157C44B52BF4047BA373FC44149C34247C84D50
B44647A94B4BC17774B47F7B9A77738F777392807C8E817B8E837D938882988D89998E8A
998E8A9B908CA196949F94929E94927E74725D52504D42406D6260908080A38A8DB28B90
BD7F8ADE8A99CA5E6EC54858D24C57D2464FD4444DD3484DCC4A4AC5524BB45849672502
D4B066F0DD76E6DB5BE2DC4AE1DB45E5E048E4DD47E8DD4FE8DA55ECDA5CE9D55AE9D55C
EAD65DE7D25BECD261F7D571FCCB7F9E5522BA4E31D25043D54A47D64548D84349DC474D
D74548D34748D04B4CC14F4EA8514A884C44AB8884A3918F9E95969F9B9C95909699949A
9994989D979B97919598929699929999949A9D989E96919799949A989397999498999498
948F93969195958F939B9597ACA6A84842422C2324352B2C211515827272FBE7E6F8DCD9
D2AAA8AF827DCB9C96E2B1AAE9B4AE996662B4857F956C66694C44F5E1DAF4E9E5E8E0DD
494440423D3956514D51494659524C5F56516D625C968983C4B7B1DDD2CCF9F0E7C1B9AE
8A81788780763A352FC1BEB9F1F0ECE6E6E4E4E4E4E5E3E4E8E4E5E6DDDEEEDEE1F9E0E3
A487837E615394765C6149233625006E6218E2DB71E0DD6ADEE37C6B731E7682427A855B
F9FBEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F5F0EC
DACDC7B097928A615F894F4E8D4344A1484AAF4D4EBB4E51C24D53C1464BC2434ABE4044
BD4547B14545AE5352BF7876AE7B779976709279748E7B758C7D788D827C928783958A86
978C889A8F8B9C918D9A908E9F9593A29896A095938479775F5452554545775D60A1767D
BE7C88E28A98C55565C64655D04854D2454ED3434CCF4449CF4D4DC3524AAD544475350F
ECC978EBDB6AE4DD51E2DF44E3E13FE3DF3EE5DC41E3D445EFD658F6D466F3C965F3C669
F7C971F7C971F8CA74FAC778FFD394CB7E52A2351ECE4E45D54B49D34247DB484EDB484E
D34245D34949CB4B4CC45655A4514B8A514AB0918EA191919F96979C979B97929699949A
9B969A9994989892969892969691979893999A959B9792989792969A9599979296969195
969195969195958F91A7A1A3A09A9A3930312E2425362A2A221414B4A2A2FFEDEDBB9998
5A2A26BB847FEAB1AAD09790CE9490E6B1ADFCCBC788615CAB9089FAE9E2FCF3EECCC7C3
2C2825B5B1AED1CCC9BEB6B3524A47261D186356505E514B56494170635BD7CDC3BBB3A8
C8BFB6C9C2BA827D799D9C98F1F0EEE6E6E4E4E4E4E4E4E4E4E4E2E4E0E1E4D9DDF6E3E9
FFE7EBA98D8A5C4034381E07352300776C2EE3DB78DEDC6DDEE37D717B2471803F758257
F7FBED00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FFF6F5EBDBDBC9AFAEA07A77885552834240924241A54748B54B4FC0494DC6494F
C74A50C0474CAE4144A94D4EBC7573B8837D99746C90756E8C79738C7F798D827E8E8580
918883958C87988F8A988F8A9D948F99918E9E9492A096959C92918A7A7B785B606F414B
995260E38796C55062CB4858D24855D44750D1414AD0454ACF494AC8514BB75749742F08
E4BD70EBD969E0D74CE3DE44E3DF40E4DB3EE6D843EFD655F2C663CA8F43B36729B55F2C
BE6638C86F43D98354E18F60FCAD86FDA486AD392ACB4743D54A4DD7484ED5424AD9464E
D54449CE464ACA4C4FBD53539F4F4E945C5BB09091A191929D92969A94989A94989A9498
9B969A9A95999C979B9893979893999A959B979298989399959094948F93959094999498
969293959192979394AAA4A687818333282C36272A382829342123E3CECDFFE9E8E5C2BE
C08F8BD19692BD7E79CC8C8AD19191C58B8A9A64628B625EF6DDD8F4E7DFF6EFE9E7E4DF
6A65615D5854978F8C9B9390322A27251B19A09593DBD0CCD2C7C1D2C9C2E4DBD4736C64
221B155D5854807C79BBBAB8EDECEAE5E5E3E5E5E5E4E4E4E3E3E3E9E5E6ECE1E5EFDFE2
FEE8EB9C837F543A2D442C123A2800837838DED876E1E171DDE47D6F7C2469793874835A
F7FBEC00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBECE9E1C8C4B6938F8E5D5981403E91403F9D3A3DAC3F44
C14952C74F58C35057B64F52A65252B4736FA7787295726C9175718C77728B7C778E817B
8C817B8D827C8E857E938A8398918B9A938D9B918F988E8D9E9493A59596A78A8EA6777F
AA626ED87A8ABE495BD14C5DD24857D34551D64650D0434BD1494BC64B46C55B4E792908
BD8A48F6DA77E3D453E7DF4CE6DF46E5DC43E8DA46FCE365BB8C32833F00AA4F22AA4121
A6361EA6331EA0301A9E311AA03A24BA4F3FA52921C74140D64B4ED5464CD6454CD8474E
D4454BD0494FC24A4CBA5356964A4C9C686AAF91939F8F929D92969B95999D979BA09A9E
999498948F939C979B9893979A959B9B969C969197999498989397938E92969195989397
959192979394979394ADA9AA6A64662A20213D2D302B181A624E50F6DEDEF6D6D7DBB3B1
CD9D99D19A97E4A8A7DFA2A1844647AC7271B37D7D633A38E4CCC8F6E9E3EDE5E2EFEAE6
DFDAD688807D5C534E4C433E7C736E7B726D453A384A403E978E89E4DBD4958E88716A64
514C49696461D3CFCEE7E6E4E5E5E3E5E5E3E4E4E4E4E4E4E4E4E4E8E4E5EBE1E2EFDFE0
FCE8E98F7773503627472F13382700887D3BDFD977DBDD6FDEE4806D79255261267D8B67
F8FCEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00EEDBD7C4A5A29A6D6AA665639F4D4F
96353C9A303AB0424BB44C53B3595B9C5251975F5EA579789B75749778758D74708F7A75
8D7C75897C768B807A8C837E8E8781968F8998908D9A908E9A908EA09090A98C8EB5868C
C8808BDC7C8AC0495CCE495AD14756D24450D4444ED3464ECF4449CA4848CA534BA34029
8A4315EABC6FF1D769E2D650E4DC49E5DE47E2D843FCE966C19D3C783F00AF5D2DC05C3A
C4553AC74E3BCC4E3FCA4C40BC4036BA3933CA4340D24647D4484BD6474DD3444AD4454B
D1464BCA494DC14E51B355568E484AA57477B19395A090939E93999D939B9A939A9C959C
9C969A9993979B949B9B949B9A94989A9498999498969195948E92948E90969092999395
959094948F93989697A7A5A6453F3F2D23243B2B2E271416978385E9CFD28F6B6F7E5657
D0A4A3D4A6A6D3A3A3D2A09FE3ADABFFCDCBE7B5B4B99191F2DAD8F8EAE9E5DDDA645F5B
7A726F978E89A19690BEB1A9D7CDC4E8DDD7D6CBC78C82804A413CA7A09AA29994D8D1CB
E7E2DFA39E9B918D8CEAE8E9E7E7E7E6E6E6E3E3E3E4E4E4E5E4E2E7E3E2EBE1E2F0E0E1
F7E3E2866D68523829452D113425008C8340DEDA79DCDF74DEE586606C204F5B2BBCC6AB
FBFEF500FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F4AD9893A6817BB27D79
D48E909D4B4F973C4393383D9B46497B3132B87D7FE9B9B9A6787A926667A07878967472
8F726E8C74708E7B778B7C778A7F798D847F918883938987988D8B9E8F8CA78D8CB4878A
CC8690D67886BC495ACB4B5ACF4755D24450D1444DD2454DD1444ACD4547CE4C4AC65547
8A2F149A5723F2C572F2D669E9D757E6DB4EE2D749EDDF5AF6DC6EB68D358C4D08954510
B15127BE5333C7553BCA533FCA4F40CD4F43D14E46D04B46D44A48D04646D24649D04548
CE474BC74B4DBE5154AC56578A4C4DAB8383AB92959F90959E93999C959C9D969D9C959C
9A939A9B949B9A939A9C959C9C969A9892969893979691959690929690929A9194958F91
989296959192A19FA09C9B99353130302826372B2B261617C6B6B7D1BBBE6F51538D6B6C
BA9897BE9B99E7BFBFDCB0AFB585819665619A6D6ADDB7B6FBE3E1F5E7E6EDE3E1726A68
352D2A1A100E1F1410312620483D37524743685E5C7E74728D8680A099936D645F5F5852
7B76727E7A77989795F2F0F1E4E4E4E4E4E4E4E4E4E4E4E4E5E4E2E6E2E1ECE2E3F1E3E3
F2DDDC7B625B4A301F432C0D35270089823CE2DF7EDDE077D8E1884D58147A845FF1F8E6
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00C1BAB277695E786153
DAB5ACD09F98D29695A36162985455642424976161FFD4D5E6B4B78A565A8D5558AA7376
A0727298706E9273708F76718F7C768E7F7A90837D9186829287839D8E8BA58B8AB08688
CA8C91CF7982B74B58C94C5ACE4A57CF4650D1444DD54850D1444AD2454BCD4547CE4F49
C2504585250CA35B29F0BC73FBD776F2D963E7D857E6DA54E9DA59F6E16ADDBC55A97B25
90560C8741039A4A17A2491FB0502ABD5635C25538C45039CD503ECF4D40CF4844D04848
CF4A4DC44C4EBA5658A05252885655AC8E8EA390949F949A9A939A9A939B9D969E9F98A0
99929A9891989F959D9F959D9D969D999299999397969094958F91979191989292958F8F
988F92958C8FAEA8AA8783822E2828312C29342C2A2D2522DDD5D2F1E7E5E9DBDAEAD8D8
F3DEDDFFE5E2D5B2AE99706CC59C96BC938D522B26B79593FDE8E5F7E8E5E1D6D4D5CBCA
D3CDCD8F89893D393A272324514849968D8E9E9493756B698B827D8C837CC3BAB57F7872
A9A4A055514E8C8B89F2F1EFE4E4E2E5E5E3E4E4E4E4E4E4E4E4E4E6E2E3EBE1E2F0E2E2
ECD7D46F564F482F1B412A0A362900979147E1DF7ADEE47AD0DA84555F23C7CDB300FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00DDDED8716F624E4737
766656C8B1A1F6D1C8D1A49EC18E8AB17B79835150BA8889F3BFC3DAA1A7884B507E4146
8F57589A68679E70709C7472937471927672947D77917E7890817A9885819C8281A98182
C2878BCA7B81B54F5AC6505CC84954CF4751D1454ED2454DD2454BD2454BD4474DCF4749
CF4D4DC5504796321B94421ADB9B5BFACA76F7D470ECD263E6D259EBD85FF0DB68F4D96E
ECCA68D4AB51B58533A1691E9554108D460694430B973C0DAF4722C65338CE5041CE4E45
C64947C25050B35758914D4E936B6BAA95949B8F939C959C99949A99949B9C959D9D969E
9891999B949B9F959D9B949B9C959C9992999993979D979B948E90979193979193948E90
958C8F999091B3AAAB635D5D302B28332E2B1E19155C5753F0EDE8EBE8E3EDE5E3F0E4E4
F4E4E4F9E1DFD3ADACE2B6B3E3B8B2A87F799A756FF5D6D1FDE6E0FFEFE8A697944C4240
5B5555716D6E4846492523262924284E484A9C9394D6CCCBF3E9E7ADA49FA09694CEC6C3
E8E3DF85817ECCCBC9ECEBE9E5E5E3E5E5E3E5E5E5E5E5E5E4E4E4E7E3E4E8DEDFF5E5E5
E4CFCC664E42452C16422E093B3100A5A251DFE277DFE67EC1C97C969E6DF6FAE900FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F8F3B1B2AA636456
4D4A37887D69CEB9A8CDB0A2B38D84D8ADA7BC8F8CA77777AE7C7FDBA7ABC89196B37A80
B57D80A86D718E53599C6467A26F6EA0736E9C776F95776F927972967F79997C78A37B7B
BA8187C3787FB4535EC2505AD25660CB4850D04950D1464DD2474ED4474FD2454DD1464B
D4494ED24D4ECE514DA83729922C13B55D37E49D67FBC27DFACD78F1CF6DEED368EDD666
EBD661F4DF6AF4DD69EFD866E5C95CD9B851D1A94ADDA656B4692F9F4217C9573CCB5241
C64F47BA514EAB5A57814948A0817FA69898988F9298939999949A9B969C99949A979298
9992999A94989A94989A9498999299948F9596919799949A969195969195948F93918D8E
948E90A09A9AA79E9F3C3432332B29342C2A1813109D9895F7F4EFE9E6E1EBE3E1F0E2E2
F5E3E3F3D7D6A97D7EDBA8A7D19B9BD9A9A7FED7D2F9DBD3E0C5BCA79088B7A69FC7BCBA
9F99998C8889716C704E494D3A34382822241B1517473E3F7D75735A5250534B498D8583
CEC9C66B6764E9E8E6E8E7E5E4E4E2E4E6E3E4E4E4E3E3E3E5E3E4E6E0E2E8DEDFF9E9E9
D8C4BD5D463848321A3D2C014B4200C8C86ED9DF73E2EA87C6CF90E1E7C5FDFFF500FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00D5D6CE
7E80725C59487165557968585D4539D0B2A895706ACCA39FC19594BE9293D7A9ABDCABAE
EDBBBCC08C8EAC71779D62668751517E4D498D625B9D7B71987A70987C71987770A07773
B67B7DBE7378A94A52C0525BC44F57C94C52CD4C51D04B50D14A50D0494FD1484FD3484F
D5484ED64B50D34B4FD55053C34745A12F24922E17AC5732D48B58EFB26FFAC776F8CF73
F4D16BF2D668EFD662EDD863EFDC66EFDA67F4D86DFFDC7FEFB66F914511C05936C6563E
C35548B5574F9F5854885856A98F8E9E94959B959996919799949A9A959B99949A9D989E
9B949B9B95999891989C959C9A959B979298969197959096959097989399938E94908B8F
8A86879E9A998C86862B2321372F2D30282626211ED2CECBF1EDEAE8E4E1EDE3E4EFDFE2
F7E1E4EFCFD2A17074D1999CAF7375BF8786F9CEC8B5948BC5A8A0705951B8A7A0FCF2F0
F0EAEAEDEBECECEAEBE5E1E2D5D1D2C7C3C4A39FA08C8889888284ACA6A6C0BABA443E3E
6864636C6865EEEDEBE7E7E5E3E5E2E3E5E2E4E4E4E5E3E4E6E2E3E7DEE1EADBDEFDEBE9
C8B2A7523B29442F123A2C00787224D9DB7AD7DE76E4ED94E1E7B7FBFEE900FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
ECEDE7BCBCB496928780786D50443888766CA78F85B89D94F2D5CDAD8F8795706AD5B0AA
FAD7D3CCA6A3916564A07473A17876A8817C86615970504582625598786BA17B70A87770
B77A77C274748D2E32A0373BBB4A4EC34F52C44C4EC6494DC7494CCA494DD04E50D34C50
D1494DD1494DD24950D14A50D0494DD14F4FC84D48AE392F952A169D3A1DB35934D68454
EBA368F9BA75FCC477FCCC77F8D071F5CF6CF3CB69F9CD74FFD38BA56630A34924BF5B41
BC5B4AAF5B5090534E946C6AAE99989F95969F999D9E989C9A94989992999790989C959D
979098928B928F8A918E8990847F86837E85807B8278737A68656E67646B625D645E5960
4341447571726C66683C36365A51522920214F4949EEEAE9E9E5E4EAE4E4EEE2E4F3DEE3
FCDFE4CAA2AA926167DBA0A4A76567A56867B786818D6860A98E85B7A69EE8DDD7EDE8E4
E7E6E4E6E6E4E6E6E4E6E6E4E8E8E6E8E8E6E9E7E8EAE8E9E6E4E5E8E6E7E9E7E89C9B99
8E8D8BDBDAD8ECECECE5E5E5E3E5E4E3E5E4E3E5E4E5E3E4E9E0E3ECDDE2EEDEE1FEEBE7
A08A7D49331C402D0C3E3300B9B85ED9DE77DCE384E6EEA5F3F6D7FBFCF400FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00EEEEE6D4D0C7A89F96A1948BB0A297D2C1B7BAA89E563E349D857B
E1CAC2E1CAC4B79B97B59996D1B5B2F3DAD6DCC3BEA58C85846C6270554A7D5D5290655C
AF7873C6827F954441913635A03C3CAF4545B34546B94747BE4A4BC24A4BC74B4DCA4C4D
CC4B4FCF4C51CC494FD14B52CE494ED24B51D55055D25052CB4E4CC04641AF3A309E311D
9A3519A24420B45D30C97944D38C4CE8A55FF3B36BF8B976FFC78EECA87B9A4121B85842
B65D4DA75D52895450A2807F96848483787C7E787C7872766D676B6861686059615A535B
4A434B4C454C4F48504A454B4B464C544F5558535A58535A5752595F5A61635E65676268
7A787B908C8D423E3F3F3939625C5C241E1E918B8BF5F1F0E6E2E1EAE4E4EEDFE2F8E1E7
F2D3D9C49BA1E9B8BCDEA6A7A366659055519E6F69C39E96D8BDB6F9E6DFF2E4E1ECE2E0
EBE3E0EBE4DEECE3DEEBE4DEE8E3DDE8E5E0E7E3E0E6E5E3E7E5E6E5E5E5ECECECDDDDDD
C7C7C5E9E9E7E5E5E5E3E3E3E3E5E4E3E5E4E5E5E5E7E3E4EADEE2ECDCDFF4E0E1F0DBD6
6E5747453013382900756E2ADDDF7CD0D770E4EB9BEDF4C0FBFEEB00FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00F7F4EFE4DFD9D0C9C3AAA39B857C738E847A
A89F96BBB2ABD2C9C4EFE5E3FFF6F500FF0000FF0000FF00F6EDE8DBD0CABAA9A2977E79
8D6C658F625C8A514A8B463F9647429A413DA2403DA8403DA73E3BB44645B64444BF4949
C54E50C34B4DC44C4ECA4F52CB4E52C94B4ECE4D51D04F53D15152D05051CD4D4CCC4F4B
C2473FB73E33B1392B9F2C199D2D179F3319A1391CB75437C2644BDD7E68A33D2EB65145
B65F569A5550906360987C7B6C5E5E5B55575D575B5B565A5C565A5E585C6258606B6169
695F67756C717C727A7F797D8781858983878982898D868D918B8F948F93959192918D8E
ACA8A78A86852D29282824212A26232C2825D5D1CEF1EDEAE7E3E0E9E4E1EFE1E1FAE4E6
EFD1D3AC8586A97C79C1908BA5746DA4786FF9D2CBF7D6CFE3C4BFF1D8D4F4E1DDF5E2DE
F7E0DAF6DED4FAE0D3FBE1D4F6E3D5F0E2D7ECE3DAE9E4DEE9E6E1E6E5E1F1F1EFC2C2C0
9D9D9DECECECE5E5E7E4E4E6E2E4E3E4E4E4E6E4E5E9E0E3ECDDE0EEDCDCFBE6E3BBA29B
4A311D402C07483E01C5C370D9E078DDE786EBF3B7F8FDDDFBFDF200FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00EEEEE6D7D7CF
E6E6DEFAF9F400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF6F2
F1E0D9D8C1B9BB9A93A1766F945F598A4D4887403C90413C97423F9D423F9D3B38A53F3D
AE4444B14543B64645BC4A4ABD494AC24B4DC74F50C84D4FCC5052CA4C4FCE4D51CF4C51
CE4C4ED14C4FD14C4DD04B4CCD4B4BC44441BB3E3CB13734A7342FA2322EB64944B95852
AE5D5A894D4C977170A58F9194888A928C8E918C90979296989296958F93988F949E959A
A1989D9B92979A91969B95979C9698969092958F939A9496958F91948E8E928E8D999594
ABA7A458545124201D312D2A16120F64605DF1F0ECEAE6E3E9E4E1EBE1E0F0E0E0F8E0E0
F8D8D9E1B9B9DCACA8CF9E97DDB1A8FDD5CDD5B0AAC5A49F674543B29391FFE2E2FBD9D7
F8CBC6E7B2AAD29C90CF9E8FE3BCADF5D9CBF6E4D8F0E6DCEAE6DBE7E4DDE8E7E2DEDFDA
DDDDDBE6E6E4E4E4E4E4E4E4E3E5E4E4E4E4E7E1E3E9DFE0EBDBDBF3E0DCF7E0D87B6454
432B113929008D8638E2E385D6DE79E6EF9CF1F6CDFBFDEF00FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FAECE9E9D6D2CAB1ADA78681926963814F48874B438D443E923F3B
9C413EA13F3CA43E3AA63D3AAD413FB24443BC4C4BBF4D4DBE4C4CC45051C34C4EC95153
CA4F51C94D4FCF4E53CF4E53D14E54D04D52CE4D52CF5155CC4F53C44D4FC15457B95D5E
9A5351814F4EA587879D8B8B958B8C938D8F928C8E948E90948E90938D8F938D8F958F91
988F92948B8E948E90958F91948E90928E8D918B8D948E90918B8D918B8B8F8989A29D9A
948F8C3934312C2724322D2A181413A5A1A0F5F1F0E8E2E2EBE3E1EFE1E1F6E2E3F5DBDA
D5B3B2AF8382B7817F743D3AC59490C59895AC8482D2ACABA6807FE1BABBFFE1E2E5AFAF
A052509A413D91383087372C8B4D409F7162CAAD9DE9D8C8EBE2D1E6E3D4E9E7DBE8E8DE
E7E8E0E4E5DFE5E6E1E3E3E1E3E5E4E4E2E3E8DFE0EBDDDCEFDED7FEEADFC2AD9C432E13
3A2800594E10CFCA6CDBDC76DDE38BF1F7B9FAFCE400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FFF8F3F5E6E1DEC7C1C6A59EA97C77915A57
8645419046438B3E3896433D9B433F9D423DA44541A4423FA94341B04646B44846B94948
BE4A4BC44D4FCA4F54CB4E54CB4C53CB4C55CD4E57CD5058CA4E56C45158BC575BB15F61
824646956D6DA58D8D948686948B8C8F898B908A8C908A8C908A8C8F898B938D8D928C8C
958C8F91888B948B8E938D8F918B8B908C8B8E888A8C86868E8888908B888F8A87A6A19E
615C592B2623362E2C251D1B3B3535DFD9D9EFE9E9EBE1E0EFE1E1F4E2E2F8E2E4BCA09F
C19E9CECC0BFE7B4B3915E5DA173737D5354AD8687D3ABACDDAFB1FFD4D6F2B6B88B4142
A74949C35F5DC36961B2655B905648673E2C604530615339797258BDBCA0EFF1D9E8EBD6
E6EBD7E4E8D9E3E7D9E3E6DBE3E4DCE7E4DDEADFD9EDDCD2F3E2D0F7E6CC826F4F3A2900
3A2F00A49F4DE5E47ADCDE79E9EFA9F6FBD2FBFDEF00FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF3F2EFDBDA
D9BDBAB695909E756F8B5C54814B4184453C8A443C954641A04844A24540A6433EA83F3C
AC3E3DB64645B94649B84349BB444AC04851C34B55C24D56C04E56BE565DB55F62975354
805252A4868698888993898A92898C8E888A908A8C908A8C8F868991888B91888B948B8E
938A8D90878A92878B94898D928C8E8C86888C86868D8787908A8A8E8986A199978E8683
372F2D3129273B32331C1314756C6FF6EDEEEEE2E4F1DEE0F4DEE0FAE0E3F9DFE2DFC1C3
CBA9A8C29C9B9B7270865E5EC8A8A9E9CBCDFFDFE6DCB1B875373CDE8F92C1686A9C3E3E
CC6F6ABF6C6495574C885E4E9F8672A99D85A09B7D858561B2B48CD7DEB2C4CDA2C6D1A7
DBE7C1DFEAC8E3ECCFE6EBD4E4E7D2E7E5D0EBDECBEEDEC4FBEBC7C6B88B433300403600
797418D5D76AD8DF6FE5EC8FF1F5C3FAFDE8FBFCF400FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FCEDE8E8D4CDCAADA5AB867E986B658A554F8C4F4A86413C8E403C984541
9C4241A04240A03C3CA63F40A63C40A93C41AB3E44AD4248B34C50AB51539B53547C4644
96736F9D8883938582938B899088868E89868E88888E88888F868791888B8F86898E8588
90878A91888B93888C8F8488948B8E8B85878D87878C86868C878496918EA29A98564E4C
2B2321372E2F32292A22191CBDB7B9F7ECF0F2E3E6F1DDDFA88B8FAE8F94E9CACFFDDDE0
EFCBCBD3B0AE967472EDCFCDFFEAEAFAE4E7FFE8EFBE939C7C333AB2565BA94245C35D5B
C77067924E439F7567E8D3C2AEA8928080647879577A7B518C8C5A8C8F5663682E5F682F
6E7B45869461B7C499C1CCA4CFD0AEE1DDBAEEE0BDF7E6BAE4D59A7C7028817722A7A23E
D3D25CDDE369DDE47AEAF3A4F8FCDBFBFCF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FFF4F3F7E5E3E7D2CFD5B9B6B79691A07974976763
8D56538847438D423D923F3B9A413D9E403EA34142A24243A048469146415F2420875C55
A0857C9A8A7D90867A8E867B8D847B8D867E8C857F8E86838C87848F89898D87878B8585
8C838690878A91868A8E83878E85868E858692898A8A8182908B88A5A09D706866302728
33282C352A2E1A1114595357E9E4E8EDE7EBF4E8ECF0DBE294767E95747BE9C5C9EAC3C6
BD9697D2AFAD7F615F927877F3DFE0F5E2E4FFE9EFD2A7B08B4249CA6B71C65D61C76562
B5685E8F5A4CE4C9B8867B696B6650918D728E8662786B3E65591F635816766F27797931
6B753067763566783E5966315F612F756D3C9B895799854894842FACA137D4CC50D5D24D
DDE156D4DD60E3EC91ECF4BBFBFFE800FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF5F2F9E4E1
EFD2CEDCB7B1C89993AD7671A0635E96524F924B478D48437C3D3669342C785046AF9387
9887759388728C866C8B856B8D876F8C86708C87748A84748A867A8D897E89847E898480
8883808C84828D83848E84838D83818A807E8D847F948B86A49B967A736D362C2A372D2C
3A3031241B1E393033D0CACCECEAEBE6E1E5EBE0E6F0DFE7F6DFE7F5D7DFB49499806063
C6A8A8E5C9C8957D7D705C5DF0E0E1F3E0E4F9E0E6FFD5DFAB5F69AF5058CB6468C86A68
A35D55A6786BB19B8D564F3DDFDAC6D7D0B671613F644F20CAB576A692499C8C3FC2BB6D
93954A6C76316D7738686E306D692A6B601E6B5911695701B1A434DAD14ECDCB38DBDE47
D6DD4FE1EA77E6EDA7F7FDD9FCFEF100FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFF5F3FBE6E3EBD2CED8B9B6BB9C998A6F68AF998EE7D7C8E9DECA
C4BFA19D9B7599976E9291638E8D5F8B8A5E87845B88866086876586866A85826F858273
8A867D837F768B827D8B807A8E81788F8176988A7DA89C8E82766A392C23392C243C312D
221A17423D3ABEBAB9F1F0EEE6E5E3E5E3E4E9E3E7EDE2E8FAEDF4B09FA5826F73BBA8AA
B7A7A8AB9D9DB8ACACE3D7D9F5E6EBF5E0E7D8B9C1E2AEBAFDAFBDB05260BC5661C06467
A15B59A77A749A837B645A4E847D6B867A6256422194794AEED390DEC77B9D8A3BB8AC60
E5DE9A7B7738666024776F307C6E257A6A15968722CCC04AD6CE45C8C731D6DA3FDAE04C
DDE665E5EF8FEFF5C7FAFEEDF9FCF500FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FFF9F3F9F5ECF7F3E7F0EFDD
D8D8BEC1C2A0B8B892AFB086ACAD81A3A4789E9D7198996F8F946C84886583866B85846F
8584727F796B8B7F719585759A88729B876EAC987D88775B3E2E143D2D1445342031220F
38301DCDC6B4FAF4E4EBE8D9E7E5D9E9E6DDECE4E1EBE3E0F0E8E6D8D0CEE5DBDAF7EDEC
ECE7E4EAE6E5F1EBEBEEE8EAEEE3E7FAE9EFD0B2BC6B3D48A86171B46070BC626EBE6B73
A569698C6663AF9C96574E45BFB7AAD2C7B35C492BA1895DECD297ECD58FA5924DB8A966
B7AB717467307F6E3682712C72600CB1A038DFD156D4CD41CCC831CECF33DBE247D8E057
E4ED82DFE6A0F9FDE200FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
F9FAF2F7F9ECECEDDDE3E5D0D4D8C1C0C4A9B4B79AACAF90A6AD8C99A07FA2A88CA7AB92
797961736B56AA9A83D4BCA0CCB08BAC8F638368394E38063F2A004B36094E390C3C2A00
A99D6DFEF3C5F4EBC2F0E8C4F0E9CCEFE7D0EFE7D4EFE6D5EDE5D8EDE7DBEFE8E0EAE5DF
E9E6E1E5E4E0E8E4E1E7E3E0E9E3E3EEE3E7F9E6ECAB8B96804C599F5F6DB06C79AF727A
8C6264745A59E8DDDB999490928E85867E7151452F746443D4C196F1DFAD897948918354
7362379582578D78436B540EB3A13DE0D257D0C73AC8C52CCCCC30DCE147D7E051E2EB76
D7DF94ECF1C8FBFDEF00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FBFEF5FAFEF0F7F9EBEAEDDADDE2CCC7CFB8B6BEA7A6AB95
71705C827B68D3C3ACBCA78A967C57A28758B7A06AB39F649D8A4F8E7C3E82702E7D6C27
C9BD73E7DB93EADD99EFE1A4F3E3AFF2E4B5F4E5BAF5E7C0F6E9C6F3E8CAF2E6CCF0E5CF
EDE4D3ECE5D5ECE5D5EAE4D4ECE6DAECE3DAF3E5E2FBE6E5D2AEB295686D8053587E5559
715554AD9E9BF7EFEDECE8E5C9C6C1B2AEA3B8AFA0AEA38DBAAC8FCBBC9BA0926FDECEAC
E6D4B0ECD7AC887034B19B46E5D460CFC63BC9C62DC9CB2CD5DB3DD9E14ED8E363DEE888
D6DDAAFBFEE900FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00F6F7F1
E8E8E0E1DED5DDD5CAB4A89894886EAEA17FCEC396DBD29BDED793DCD68AD0CA76BFB85E
BCB253BEB250B9A949AB983AAD9742BEA759C9B266D5BF76E1CC89EED89CF3DDA4F5DEAC
F6E0B7F5E1BCF7E5BFF4E6C1F3E6C4F1E6C8F0E4CCF5E6D3FFE9DBF2DCCFDCC6BBD1BDB4
DED1C8F0E9E1EAE7E2E7E6E1E9E8E3ECE9E2F3ECE4F6EEE3BEB2A4948774D4C6ACCCBD9E
E3D1AD9A86519E8936E7D567CFC33BD0CB33C6C628D2D83AD6DF48D5E15BDFEA82C7D18A
EFF4D6FCFDF500FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FFFDF4FFFCEDF7F2DEEDEACBDEDCB3D5D49ED8D898D7D78FDCD98A
DAD480DFD67BDDCF6ED1BF5BC5AF4CBAA23EAD962EA58E269F8926A089299F862CAF9541
B89E54C3AC68C9B570DDCA88E8D89AEFDEA6F1DFAFF2E1B5F5E6BFF8E8C6F9EAC9F9ECCC
F7ECD0F3E9D0EDE5D0EDE5D2EDE4D3EFE6D5F0E8D5FCF1DDD8CBB87C6D56EEDFC2E4D4B0
AA986884712CE6D470D5C848CAC334C7C62DCBCF34D8E04CD1DD55DEEC7AB7C475CBD3A4
FCFFEE00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00FDFDF5FEFEF4FCFDEFFDFCEAF9F9E1EFF0D1EAEAC6
E0DFB3D9D8A0D0CB87D3CB78E0D470E7DA68E8DA5DEADC59E4D651E0CF4BD4C341CAB83C
BBAA38AA982AA39125A4912A9B87289F8731AB9240BCA257BFA864CBB675DAC582E7D291
EFDB9EF3DEA7F4DEADF6DFB3F6DFB6F8E2B9F8E3B8FCE7BAF4DFB2E3D1A1FCECBBDFCE96
796421CBB760D8C956CAC23BC5C233C9CB39D8DF51D3DE5BDCED7BC3D37B9FA977F2F7E0
FBFCF400FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4
FCFFEEFCFFE4F1EFC6C1BF84C1BC6ACEC75FD1C851D8D04BD5CC3FDFD444E3D745EBDF4F
EBDF55ECE058ECDE59E8D95AE4D159DAC656CFB850C2AC49A9963A9E8D359F8E369D8B35
9C8736B29C50AB934DB29957C0A669C5AB6ECFB674D4BD7ADCC784E2CF8DE4D5947F702B
968638DDD070C4BD4BBFBE40CCCF4ED2DB5AD1DC62DAEA7FD1E38D829254CDD6B9FCFFF4
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FCFEF3FFFFF2EDEDD1B3B181B2AF6AC9C56CD2CE63C9C349C9C13CC8BF34CBC334
D3CB3AD9D140DDD244DED548DCD24CDFD655E1D95DE3DC68E3DC71DED973DDD777D8D274
D2C96ECFC46AC5B75FB8A853B3A250AA9844A3913B9886309787329C8D3C988C408F8639
DBD483C5C46AB3B756C6CE69CDD973CADA78C2D57BACC1746E824797A581F7FEEE00FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00E7E6D19FA0789D9C63B9B76DCCC86DD5D26BD3D05DCCCA4F
CECB4ACCC946CAC746CDC94CC8C34BC0BF4BC5C458C0C05CBDC163C0C36CC4C577C1C276
C8C578CDCA7DD6CE83D9D186DED58ADFD689DED286DDD185D7CE83D6CE86D3CB8AD8D494
BFBE7D8487427B823E8B965288975491A16280915A697A4D798869E2EBD800FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FDFDF5F5F6E8DFDFC7CFD0AEC1C296C1C289BEC17CC0C573
C5CA70C6CB6DC4C76EC9CB78CCCD81CCCD89D1D298CBCF9CC9CC9FD8DDB5E2E3C1DFE0BE
DEE0BBE4E6C1E9E6C3ECEAC4F0ECC7F1EDC7F0ECC6F3EFCAF3EFCAF2EFCCF0EDCEECEBCD
DEDFC0CACDAEC8CDAFCDD3B7D3D9BFD9E1C9E1E9D4EBF2E2F5FBF100FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FAFDECF1F5DCE3E7C4CCD2A6
AFB682B5BD84CFD3A0E6E9BCEFF1CAF2F6D5F7FBE2FBFEE9FAFEEFFBFEF300FF0000FF00
00FF00FDFFF2FDFFF2FEFEF2FDFEF0FDFEF0FDFDF1FDFDF1FDFDF1FDFDF1FDFDF3FDFDF3
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FDFFF4FCFEF1
FAFDECF9FCEBFCFDEDFDFEF0FCFEF1FDFFF400FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.290056 0.97619 0.541732 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00523286 0.013213 0.00523286 [
[ 0 0 0 0 ]
[ 1 .55495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .55495 L
0 .55495 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01321 translate
.95238 .52852 scale
546 string
182 101 8 [182 0 0 101 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000A020F0A020F0FF8000FF8000A020F0FF8000A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F000FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
A020F000FF0000FF00FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
A020F0FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF00
00FF0000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000
00FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF00FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0A020F0FF8000A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0
A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000
A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000A020F0A020F0FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0FF8000
A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000A020F0FF8000FF8000FF8000
A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0
A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000A020F0FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000A020F0A020F0FF8000A020F0FF8000A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000A020F0FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000A020F0FF800000FF0000FF0000FF00A020F0FF8000FF8000A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0
FF8000A020F0A020F0FF8000FF8000FF8000A020F0FF8000A020F0FF8000A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000
FF8000FF8000A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00FF8000FF8000FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000
FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0
FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0
A020F0A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
FF8000FF8000A020F0FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00FF8000A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000
FF8000FF8000FF8000A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000A020F0A020F0FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0FF8000FF8000FF8000A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0FF8000A020F0A020F0FF8000FF8000FF8000
FF8000A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0A020F0
A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0A020F0
A020F0A020F0A020F0FF8000FF8000FF8000A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F0FF8000A020F0A020F0A020F0
A020F0FF8000A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F0A020F0A020F0A020F0A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF800000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
A020F000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF00A020F0FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF800000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF00A020F0A020F0FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00FF8000FF8000FF8000FF8000
FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000FF8000A020F000FF0000FF00
00FF00A020F0A020F0A020F0FF8000FF8000A020F0A020F0A020F0A020F0A020F0A020F0
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00A020F0A020F0
FF8000FF8000FF8000FF8000A020F0A020F000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF00
00FF0000FF00
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 221.938},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000gB000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonA
ooooo`00oooooonAooooo`00oooooonAooooo`003_oooon/003o01[ooooo[000o`0@ooooo`003_oo
oolZ003o00030=WJeP3Ad/d0k>cZ07l00?l06_oooolZ003o00<0X23`O`00o`0@ooooo`003_oooolV
003o000;0?Sgl`3LfmL0/[6_07imN`0m?3P0=C@`05=BCP1gMW80YJJQ0<c<bP3YjNL0N`00o`0Joooo
obH00?l00P2P8?020?n000030=1@N02P8?00oh000080oh000P2P8?1k003o013ooooo000>ooooob@0
0?l000l0g=SE09bIU01VHe`0?c`e02LT7`0]:RD0;2PU038_:P0_;2L0:BHQ02PW8P0^;bL0AdQ208^<
QP3]k^T0N@00o`0Jooooob@00?l000<0X23`0?n0003oP0002@2P8?020?n000030:0Pl000o`000?l0
07L00?l04?ooool000kooooo8P00o`004P3fmo80[ZfY04=0>`0R7AL08AhE030]900l=c40@chj04Q2
?P1BBdD0EDi805A?B@1=BT40=c@[028R600K6a<0GUmI0=3Ac7P00?l06_oooolR003o00030:0Pl03o
P000X23`00D0X23`00<0d51h0?n0003oP0000P3oP0030:0Pl0030?n0002P8?000?l007L00?l04?oo
ool000kooooo8@00o`00503PhM`0OGag03@a:P0M6180:2@K03Da:011?C@0@3Tc03Ta;P10=c@0Achi
04U0>`1=A3d0D4To04U2>013?cH0=C8Y01dM5@0n?CT0[JbZM`00o`0Jooooob400?l000<0X23`0?n0
002P8?00202P8?040?n000@0X23`00<0oh00003o0000o`00M@00o`0@ooooo`003_oooolP003o000F
0>?Sh@1OGUT0:2DN02DQ600O6a80=c<Z040l<`0k=bh0=c0Z03@/:@10=S@0@cPd04@i<`0o=2h0?cH]
04Po=P1:@cT0BdLl03`i<00X9B00:RTU0:FUXgH00?l06_oooolP003o00030:0Pl03oP000X23`00d0
X23`0P3oP0030:0Pl0030?n00000o`000?l007@00?l04?ooool000kooooo7`00o`00603dm?80NgYe
02DU7@0/:B00920G038[8@16?cD0>c@Z04M0=P0m=2d0=2/V03H_:@0l<bh0>C0Y03/b:`1:@CP0CdLl
048j;`13?c<0BTPl03Ld;@0O7QT0?3dh0=KFe7D00?l06_oooolO003o00030:0Pl03oP000X23`00`0
X23`0P3oP0020:0Pl0030?n0002P8?00X23`0080X23`M@00o`0@ooooo`003_oooolG003o0003083j
NP20ngX0P?Yh0080P?Yi01`0P?]i083lNP1Vge`0L6YT02@N600X8ad0<2XT02PQ6P0a9b40B3hh03P^
:00g;BD0AS`f03`b;@0f;2H0@CLa03L]9`11=bh0DDPo04a1>00m<bX0?CH[04Q2>01<B3l0:RTT024P
7018B4H0d<o?M000o`0JoooooaL00?l02020`0000`3@D7P0X23`0:0Pl0030:0Pl0040=1@N02P8?00
X23`0=1@N0D0X23`00H0oh000=1@N02P8?00X23`0=1@N03oP0020:0Pl080d51hM000o`0@ooooo`00
3_ooool;003o000^0?o^j03XdL/0hLW50=S3`03D`/00eL?10=_9a`3B_K`0eK^l0=jn_`3AZZ/0`9BE
0<bJV@3;V9@0_hZ40;N5OP2_OWL0X7E^099`I`1PAC`09aD;02DH4P0a:2<0;R@R02XP7P0Y7Q`0>2d[
044f<P0_9200=b`X03X_:`0n<bd0DDI004<h<P0o=Rd0BT0g03H/8`0`9Qd0=bhU04M0>014?cT0:bPS
02HR7`0K5aH0B4920>ONgd400?l000`0kNg]0:n_[`1ZJVP0IFES06EVH@1UIF<0IfQS06Y[IP2>SX`0
^k^i0=?Cd@3Xj>HV003o01[ooooo2`00o`0>0?n000030=1@N02P8?00X23`00l0X23`00@0oh000:0P
l02P8?00oh000`2P8?000`3oP000X23`0:0Pl0040:0Pl4400?l000<0X23`0?n0003oP0001`3oP002
0:0Pl2H00?l04?ooool000kooooo2@00o`00=`3on?D0o=G>0;n9O`29CD80Y71U0:UlMP22GEL0Pf9M
0:B1O`2RNWP0Y7Ad0;=iN02UGEh0Schm0:=:AP2VAd40Xd8h0:=5>@2E?C40QSP[07Xl;`1O<bH0<aD;
02PE3P0e9b@0<bTW02hT8P0Z81h0;28P03@Z:00g;B/0>2dY03db;P0o=Rl0DdY104m6?@17@3H0?SL]
030W800X7aP0@CPa04Q1>`0g;b`0;BDS02DL7@0W6a/09A8D08QdL`3Lb/H0h=7:0>KId@3]hmX0n>oV
0?ofk`3ooOD0>000o`004P3^k^`0[:j[05UIE`0U9B<06QTG01LF4P0I61<06aXF01/K5@0?40X06Q/F
02<T7`0/;RT0AdU406AVH`27RHH0[[2]0>;ThB800?l06_ooool9003o0080oh0000<0X23`0?n0002P
8?001`2P8?040?n000030=1@N02P8?00X23`00@0X23`00<0oh000:0Pl02P8?00202P8?020?n000D0
X23`00<0oh000:0Pl02P8?000P2P8?080?n000030:0Pl000o`000?l003H00?l000<0X23`0?n0003o
P0002P2P8?040?n000030:0Pl000o`000?l002000?l04?ooool000kooooo2000o`00AP20mG@0iJjY
0;9YH02LBC/0T3d]0=2;O02mPgP0V6MP08iSG@2DIf80VVMT0:U/J`33NGP0b6i]0:U1?P2kBT@0_TLo
0<M<@`35CCl0_D`n0:<o;`2[F4P0PD<d048H300/3`T0=24M03LY9P0c:2H0<BHT02hT8P0[8Al0;bDS
03P]:@0j;b/0?C@^048i<P10>C40?c/b03Te;00g<2X0?cPb03P`;@0f;R/0<BTW02PN7@0]7al0=20R
02/>40108Ah0DC<Y05Tl;P1]DT40JE@m07AOBP1kJED0P6eL08UfI@2AOVd0XHak0:jHRP2jY9H0b;:U
0=Fm/`3Ka;`0h<_60>KCc`3/f]H0lN;O0?CYi@1mn7LX003o00070?;bl02_[jd0EeME01hP6`0E5Q40
7ahJ020O6`0201`K5P0<02TV8@0S8a/07AhF01dN600H6A<05QLA01HI4P0E5a805QPE01LI5P1>D4d0
e]KF8@00o`0Jooooo`P00?l000<0D91h0?n0002P8?001`2P8?060?n002@0X23`0`3oP0000`2P8?00
oh000?n000080?n000<0X23`00<0D91h003o0000o`009P00o`000`2P8?00oh000?n0000@0:0Pl003
0?n0002P8?000?l002000?l04?ooool000kooooo1`00o`00:P3om_D0j:VT0;I?AP2jBSh0/4De09`m
:`3RUHD0aXQk0;B0M@2GJ600Xg=_0;9lNP2]KF/0bWaj0=anO02dB4D0`di70<97@03ADDT0ce550<Y@
@`2^?S00_Ue=09I:?01@5PX0=Ph603TM6@0g8b80=2@T03X/:`0_9280;b@P030U8@0d9R<0<bPT03L^
:@0h<B/0>S<]03hi<`0f<B/0=Rh[03L_;080:b<Q02X0:b4R030R8P0e8B<0>1/M038:2`1E9B40JST[
06/k9@1jCC00GcPB05Pe2`1K=@h0FcD@05D_2P1I<`h0G3@@06Tn701L;A40J3@N06L^6`1S:QT0IblR
06hj;`1cAch0Lda507IECP1nHE`0SFm]09EfL`2UQX<0[i2=0;VJU@34Yj<0ck>_0=W0_03Mb<D0h/o;
0>OEd@3]g]/0lnCQ0?W[jP3nlo4H003o000G0<K6a01UIV408b@O01LH4`0E5Q406AXE020O6`0Q81/0
;b`W030]9P0d;bT0=c@]03Ti;`0c<b/09RLO01`M5@0H6A405APA01<E400B5a<041DA04Y<B`3Be=<0
8000o`0Jooooo`L00?l000<0oh000=1@N03oP0002@2P8?00103oP000X23`0:0Pl03oP00S0:0Pl0`0
oh000`2P8?030?n000H0X23`1`3oP0040:0Pl1P00?l00P3oP00C0:0Pl0030?n0002P8?000?l001l0
0?l04?ooool000kooooo1P00o`00803omO@0fjn/0;EDB`3;Ac/0d4/l0;m6=@2X?b`0j9F30<^8N02i
Og<0ZgE[0:mfK`2ZKFP0WEIB0;IQGP3KN7<0_di80<U>A`3<BdD0e4m70=5<@`3@CD<0_40d0<9A@`2k
Fdd0KAlB04<7000o4Pd0?adK03XP7`0g8b80=B<Q0P0j:bP0A`0m;R/0>bdZ038W9@0^9280;bLT03<[
:00/9240:R8P02TQ7`0Y8240:b4R02dO7`0c7b40?R4S03PA4P0i1PD0IBXT07do<01l@2H0TE/g07U<
7P1eBaT0OU8Q081D8`1fBQT0M4HE07E55`1oBQh0Kc<>07Le5@25>Al0Qc/T07he901j=RT0L3L/05XZ
801D;2@0BbDN04XR801@9b<0E2/W05@[9@1G;RP0Db`U04lZ8P1<:b@0ESLb05Tl=P1PACh0J4a906mF
DP1dG5P0OFEQ08I^JP2HPGd0ZIB?0;FPW@31[:T0bKBa0=O2_`3NbLH0iM3=0>[Gd`3`gMT0m^OR0?_^
j03nmNh0oogb0?oom03ooo<0ooke00@00?l001X0h^;P08R8QP0d=C0071dH01XK5P0L7AP06AXE01HG
4P0Z:B@0>CHa040k=@0h<bd0<RdW03<_:@0h=B`0<c0W034a9`0d=2X0;RlW028S7@0C5Pl05aTD01HH
5@0H6QT0D59A0=KFeQl00?l06_ooool6003o0080oh0000<0d51h0:0Pl02P8?001`2P8?030?n00003
0:0Pl03oP000X23`0200X23`00<0oh000:0Pl02P8?002`3oP0040:0Pl0030?n0002P8?00X23`0140
X23`00<0d51h0?n0003oP0001P3oP0020:0Pl080oh00102P8?04003o00030:0Pl03oP000X23`01D0
X23`00<0oh000:0Pl000o`007P00o`0@ooooo`003_ooool6003o001A0?cCc`2QEU00adXo0=A5=`3B
ASD0aTLf0:`m:P3VSWX0agaY0;UdI@2WHeH0T4Y00:IKE@2MB4<0`65K0>QkM031B400cTe70=5:A03I
CdP0f4e60=E;@@3;@CH0bDDi0=EMC`2^A3H0LaT@05@;10194Pd0AA`H03`M6P0h7a/0>RDP03`Y9@12
<2h0@34^03`a;`0d:BL0;B<Q03@Z:@0c:BP0<BLX03<Y:P0`92H0<B<S03@N800j71h0A1`M03h;2P18
20H0MC4X08Y6<`2=CC80ZgMB08eR=P24GRd0RVDa09Q`?@2BJSL0UF`h09EW=P2LJCX0Ue``09]G<02=
?Qd0SclT0997<02<BSX0Ic4W05X_:02:J5h0PEmG08=MFP22FED0G30]06@i<`1U?CD0DR`S05@_9P1G
=B`0FCP_0080D2lV02T0CBXV04`Y9@1?;2P0B2DO04hY8`1?:B<0Db`U050Y8P1B:B<0ERTT060]:@1X
;RX0Kc@^07Ln=`1mBCh0P514089KBP1oHdh0Of]@08f2HP2DSV`0WIQj0:ZYT`2k^jl0`/>k0:RYX`1=
CTT07AhI01`M5`0Q8Q`07A`H01hM6@0O7QX09RDQ04=0>`0a;RT0;2LS030[9`0X8al0;BPR034/9P02
02PS7@0:030]9P0c<b/0<C0[02<T7P0G61<05AHA01`L6P0I6AL0D51@0>3Ph1h00?l06_ooool6003o
0080oh002@2P8?040?n002<0X23`00@0oh000:0Pl02P8?00X23`2@3oP00:0:0Pl0030?n0002P8?00
oh000180X23`103oP0020:0Pl0X0oh00602P8?000`3oP000X23`003o000M003o013ooooo000>oooo
o`D00?l007L0ooKc0=bPV02WACX0ddLj0=M1<P3EA3<0ad8a0;4i:03RNfP0ji1m0<adIP2gGe<0]E]B
0<ETG@3AJV<0l85j0=mTG@3:Acl0eDa40=Q;A03JBd<0gTm70=e=A03GA3X0c3`a0=eCAP3BDTD0^TDk
08`W7@1O3`H0Da<:04/F40166A@0@A`F040O6P0k7A/0>b4P03/T8`0g8b80=R8Q03XX:00f92@0<1`M
03LQ8`0i7b80?1`O03hF5`175AH0C@l@04h40`1U4P`0T3`a09M6<`2NESd0[WIC08UK<P1hDRD0JdDH
079<7@1dC1/0REl]08IJ:`2>Fb`0R4lR09iM<`2TF3@0UdX/09E==@2:BcX0EB<J08=ME02]S8<0YHAn
0;RBS`2GKV`0FC0^06<j=P1@:B80P5]B09QfK02GMF/0TFmU08eXG`2<IEh0RV5K08MLEP26GEL0OEA>
07M?A`1`B400IS/b06Di<01K:R<0JBl[06/W901l;RX0P2dW07dZ8P1k;B00LR/I06P^5P1B9`D0G3lE
06MF8P1PEAl0FU8S05aH=@1OGTT0?Ch`010A2@0E5Q007QlI020Q6`0O81X081lK01lN6P0J6AD0>STe
03Xg<P0202TV8@0@02LT7`0U81`0<B`W02/V800/9240:bHR02`W8`0V8a`0:bPS03Dd;`0S91l06AXE
01`L6P0M7A/05QHF08V9RAh00?l06_ooool5003o00<0oh002@2P8?000`3oP000X23`0:0Pl00T0:0P
l0040?n0002P8?00X23`0:0Pl0T0oh002@2P8?000`3oP000X23`0:0Pl0090:0Pl0D0oh000`2P8?05
0?n00080X23`1`3oP00M0:0Pl0030?n00000o`000?l001`00?l04?ooool000kooooo1@00o`00RP3o
in<0]fQQ0;i<@@3EACL0ecla0=0m;@3DAcH0`Sd/0=eTD`3mRWP0lh5f0>QcJP3VKFD0gF1J0=QIDP3H
Dd`0cD@l0==6?@3HBT00edLn0=e9@@3QC4D0gDTo0=Y3>P3G@3D0fDDi0=m@@P3NE4L0ce530;51<`29
9aX0Ja@:05L=101C4P`0DALC04PE4P196AL0AahM03XC500l61X0?QXJ03`H60116AX0@ADF04LE601;
4180D`d?05P71P1V1`D0NQ4=09lb:`2]@cH0ZT/g09i<=02bKe80SUTg08QJ>01dB2D0GS@>06m56`1m
DRL0KD0G07Y9801d?Q80VE/b0:QR@02DCC40UE<m07]1<`1/?CD0/8^30;6@R@2bTH`0_YNH079:B`1K
=3D0DBh/06M6@@2cTX/0[8j40:j=Q02ZR7l0]Xf70;F8P`2WMW80YgIa0:]nN02YPGT0Xh5h09enL`2I
NFh0UWAZ09M/I@2WLVh0NcLd07/W9@2F>C@0Uc@^09@d9P29=1l0P3TI06`h2@28I2X0QF`Y07QW8@1f
Jb/0OGM708j=K`1UI58020P001HF3P0S8Qd092<N024P6`0W91l081dH01XG4P13@3/0:bXU020O6P0V
9B007QdH02<N6010>S@09B0J02dX900[9R80:RDQ02<N6P0Z9B40=C8]03`k=P0K71L05QHD01dM6`0H
6QL0@48o0>CTi1d00?l06_ooool5003o00030:0Pl03oP000X23`02l0X23`00<0oh000:0Pl02P8?00
0P2P8?000`3@D7P0oh000?n000060?n000D0X23`00D0oh000:0Pl03oP000X23`0?n000040:0Pl0<0
oh0000<0X23`0?n0002P8?002P2P8?040?n000<0X23`1`3oP00?0:0Pl0030=1@N02P8?00X23`00`0
X23`7@00o`0@ooooo`003_ooool5003o002:0>c3_`2/CdL0b4Xn0=Q6=`3I@C<0e3h_0=i;>`3HBcX0
c4@d0=iIBP3HDTL0fE180=Y?B03DAch0e4Dm0=92>@3F@c/0f4@j0=I2>03IAC/0fd@k0=m6?P3J@SL0
fT4i0=Q0=@3L@SH0h4Pj0>UCA@3TEdH0f5=40<]@@02_?C80SbTM078D301Q30L0F``805L=2P1H4Q40
CP`=050@4@1=3@h0DQ0A058>3`1B20T0F@T<05l6201/20X0PQ8A09lU8P2d=Bh0aDDl0;i6>02`Ac@0
YDXe0;Q/E02XJDl0YFeD09MQA`23D3<0ReXj08QG=P20CRd0S5Hd07m48P2eMUD0/g9D095A>02>Dd40
HblR08mTG@38Xid0_IZD0<NRX02[PXH0HSTm06Ho@P1=:bX0VGYg0;NHT`2aTh/0]96;0;jES`37UY80
SEIC08E:AP26C4P0PE1907]@B@1mFe80YHYo0:B9OP2TQW`0[8En0;f7Q@1`;2/0OBLV09hl>@2J<b`0
WCTZ09@j8P28?1P0NCl=09]b<P2=LBL0PG0R07ia:`2@R5<0WY]j07UhI00>3P805aL?02HU800U91l0
8QlJ02LT7`0S81/081dH040m>00e=2l07QdH020Q6`0I61<08ahH04M2?00T7aT0:RDQ02HQ7@0T7a/0
9R4M02DP700/:B@0@D0k02<T7P0I6QD06a/I01lQ7P0P8Ql0[jn_7@00o`0Jooooo`D00?l00P3oP00]
0:0Pl0<0oh00202P8?060?n000H0X23`0`3oP0050:0Pl0X0oh001P2P8?040?n000<0X23`1`3oP00?
0:0Pl0030=1@N02P8?00X23`00/0X23`00<0oh00003o0000o`006`00o`0@ooooo`003_ooool4003o
000A0?odlP36Sh`0[TM00<i9@03IAcT0fT8e0=]3=@3NB3T0f4@f0=Y8>`3MBch0gT`o0=m<@P3IAC/0
fTHl0=U5>`3LACX00P3I@CH0GP3H@3D0fD4f0=Y2=`3J@3H0f3hb0=To=@3L@SH0fClc0>98?03[DdH0
iE530>1A@@3NDT<0gUQ<0=QHC@3<D4H0]Chf0:<b;02>8A`0OaDB07P@3`1d30/0L0X807@<2`1m4a<0
PADE08dJ7@2N9RL0[Rh]0<Q1?P3BA400f4]20<m6?038BS`0]dPg0:a;>P35LV00YUm?0:AQD@2KFDT0
Wei<0:AVD@2aLeh0Wei:0:UXE02SHD/0/G1L0:a]F`2IGTh0Md<f060a:@2FKFL0[hZ40:n9QP30V9X0
REaS06Ll@`1P=c/0IT920<6OW@31X9/0`9fG0<:IU@3MZjX0/WEd07La;`2DBTL0Ue9=08eDC@1X>C40
Jd@m0:jAR@2[SXH0[Xf60<>JU02OJFL0IR8Q08hj>02L?cX0W3/b09e0;`2HA2X0QShH08IA7@2QNC/0
SW</08Yh<020MC<0VI5N0:RSP`29QW<05Q@801LD3@0Y9R4202DR7@0H02HR7`0T8A`08B0K03<b;@0n
?CT08B0L01`K5`0B4@`09b@M04e9@@0O6Q@08AhG02@Q700V8ah08QlJ01hK500]:R<0ADDm028S7@0R
8ah07AdK01/M6P0G6AH0J6QV7@00o`0Jooooo`@00?l00`3oP00P0:0Pl0<0oh0000<0d51h0:0Pl02P
8?000P2P8?060?n001P0X23`00<0oh000:0Pl02P8?000P2P8?0<0?n000030=1@N02P8?00X23`00H0
oh000`2P8?070?n000l0X23`00<0d51h0:0Pl02P8?001@2P8?000`3oP000X23`0:0Pl0030:0Pl003
0?n00000o`000?l001/00?l04?ooool000kooooo1000o`003@3nfmL0Y5mH0;Y9@@3BB3h0fdLi0=m5
>@3NA3P0fd<e0>18>`3QBC`0hDTn0>98?03NAST00P3NAS/0O@3OAcX0gDDh0=e3=`3I?c<0fd4e0=m5
>@3K@CL0fd4e0=To<`3M@cL0fClc0=a3=@3QB3X0j5120>UA@`3XDT<0kU];0>QFB@3YFDh0jEe@0>iT
F@3ZI5T0i65G0=YGD03?CTP0c4]60<92?`2n?S/0a4A30=UGE`3GDU<0fU1@0>5AD03SCd/0idm:0=i9
@P3GBCl0bDLi0;M6=P2/BcX0b7EU0:eVE`2KFD/0QD<e08Q6>02CDD<0YF=E09ECA@2GEDL0UEI709QJ
C@28D4<0/Gmd05X^9@1nEe00^9>=0:f:QP2bS8/0/hV<06Tl@`1`ATX0D2T/08IRHP2[RHL0Z8N20;2;
Q@2kRh/0d9JE08i6A`23<c80WTe:09eBC@2AE4l0GbhW095ZH`2nWiL0^YfE0;nNU`3>Yj80NDI5074d
<`2CAdL0VDQ409Y8?@2EB3H0SdL_08148P2AHS@0Z8E=09Mm@02?OCl0S7m809nGJ`2/YhT0VIJ301lM
4@0C40T0:2DP02LT7`0V8ah09b<P024P700U91l08b8M03<b;P0i>3H06APD00/:1@0a;RL0BdLo01lK
4P0M6Q<08AhG028O6P0N6aH07AXC03Xj<P0n?cL08B8L024R7@0K6aT06ATG01<C4@0`<2h0^[Zh01`0
0?l06_ooool4003o00<0oh009P2P8?030?n000030:0Pl03oP000X23`01H0X23`0P3oP0020:0Pl003
0=1@N02P8?00X23`00D0X23`1`3oP0020:0Pl0T0oh000P2P8?090?n000h0X23`00<0oh000:0Pl02P
8?00302P8?000`3oP0000?l0003o000J003o013ooooo000>ooooo`<00?l00280ooOe0=nZY02OB3l0
a4]00=I:?@3KAcP0gdDi0>=9?@3YDD@0j5130>=9?@3L@SH0hTHj0=i4>03PASX0hTPl0=i4>03SBCd0
i4Pl0>98?03PAcT0gdLi0>16>P3QAc/0gdDi0=m6>03NACL0h4Lg0>58>03VCCd0iTln0>]EA03]EdH0
lEi>0P3]Fd`0C`3^G4d0jea>0>iPDP3]H5<0kV5G0?=VG@3/HEX0gUE?0>ENF`3fKVh0lFMW0>EFF03[
EeL0je=@0>E=B03PBd@0e4@i0<Y6>@2gASH0Zd`j0:iQC`2NH4h0W6EA09YSC`2OIeH0UEe>09UQE02H
H5<0VfEI09EQE02>GU80Oe=:0:InMP1S@3X0ZHR30<6OW@2kVIL0aZ2O0;>:S01S>Cd0HS/l05Hd<`2d
UI80]YND0;NFT@2hT8h0cING0;]fN@1n;B`0Vd=209m:A`2KD4/0OT<m068c:`2[QWh0/9680;BFSP2n
WIP0Z89o06do?`27E5<0T5ID095FD02FG540TUY;08mLB@23Ec`0UW9@09f0F02DOE40TGiC08n2F02S
VWL0V99j0;JcXP11?c<030/602<R7P0X9b<00P0T8al06`0R8Ad09B@P01lP6`0R8R00<c@_03@c;P0T
91`0;b`U03Tf;P0R7aH07Q/B01LD2`0I6A40820H038a;00k?3H09bPR01lP6P0P7a/08B0L01`K5`0J
6AD05aHB02`]:025QH<0Y:JS0=kPg@0I003o01[ooooo0`00o`030?n002`0X23`00<0oh000:0Pl02P
8?004@2P8?00103oP000X23`0:0Pl02P8?030?n000030=1@N02P8?00X23`0080X23`2P3oP0020:0P
l0<0oh0000<0X23`0?n0003oP0000P3oP0030:0Pl0T0oh007P2P8?020?n000030:0Pl000o`000?l0
01L00?l04?ooool000kooooo0`00o`008@3ol>`0^GI^0:Y5>`3>D4@0e4Hh0=]6>03XD4<0l5Q;0>YB
A@3TC3l0fd<f0=i6>@3PB3/0hDTl0>9<?P3NB3X0hd]00>59?03PB3d0hd/n0=m9>`3QBcd0hTXo0>59
?P3QBC`0hDTk0=m8=`3SC3T0hD`h0>9?>`3NCSH0gU4f0>QL@@020>iRB@1K0>aPA`3ZGTD0kV9;0>UN
A`3]H4/0jei<0>aOCP3[G4h0jE]?0>]NE@3iJfL0nV]W0>]JE`3]F5@0je=>0>M>B03MASl0e44g0<]5
>@2mBSP0[dhk08Xl9P2<CcP0ReDm08=?=`2:F3l0SUa508MG@@25ET80RUe:08mVE02;IU@0Q6=D08MW
G01/CdL0/YFA0;nPW@30WY`0cJJW09U`M01]ATT0CR`[08UZI`36ZJD0_9fJ0;fKV@3;Wih0iJV[09M<
D023:bX0YT]:0:5;BP2KDDh0GBHQ08IKE02mV900]IB=0;RET@3<Y:80O59C06Lg=`22D4l0IC8_070m
>@1X>2h0MDLj06To;`1R?2T0LU0g05/m8@1XCBl0F44R07UVB023MUX0U8ag0;ZeXP2IUhX071`D01HE
400R8Ad09B@P02LV8P0Q81`08R4M01dL600R8Al0:2LS02PW8P0c<b/0>SLb03/h<@02034^9@0C02LW
7@0c<b/0>3Lb03Xk=@0V9b408R<N01lP6`0R8Ad09RDS01dL6P0P7a/05aHD01<C4@1OGed0HF=P07Uj
M@2SY9l0bL[50>OWi@0F003o01[ooooo0`00o`000`3oP000X23`0?n0000h0:0Pl080oh002P2P8?03
0?n000040=1@N02P8?00X23`0:0Pl0X0oh0000<0X23`0?n0003oP0000`3oP0000`2P8?00oh000?n0
00020?n000<0X23`2P3oP00M0:0Pl0D0oh0000<0X23`003o0000o`005000o`0@ooooo`003_ooool3
003o000D0>k=b02PDTP0_e150=5=@@3IBS`0h4/m0>]EA`3]EdT0iDm10=e9>`3NBS`0hDm00=]<?P3J
Bcd0gDi00=a=?`3QCT@0he540=i;@@3NC3l20>1>@@1X0>1<@P3QBT40gDHk0>1:?03PBST0gdhi0>1D
>`3DCBl0cDdZ0<mA:`3AERd0g64h0>5U?`3XK4H0i6Q40=mS@@3PI480hf=30>MTAP3^IT`0k65:0>aO
B`3^Gdl0lV=E0?YWG@3YET`0j55:0>M@B@3QBT40gDHm0=I3>`3=ACT0addn0:a5<P2:=1d0[VM;0:U/
C@2<E3<0UF0n08aJ>@21Dc40PEHd08EQ?`1oGSd0Idd/06mF>01bFT80FCl`09j2M`33XYd0a:6O0=Vb
/`21FUd0Hcm304h^;`2fV9H0`ZBR0;jOW032W9/0f:JW0=2>T01l;2l0UCTj0:]=C@2RDE00PShk05/X
902_QX80_Y^G0;VGT`39X9h0`I6A05`X:P1f>cd0ZW1^08aBCP2GH5/0WVaU09QYH@2>HUL0QUa@08eV
E`1oFTP0U75M06I6<@24J5<0S7IP0:RLQP2g/9d0cLZi08F3M`0L71@05AH@01lP6`0Y:2@09B@P02DQ
7P0U8Qd08AdJ01dL5`0O7QX09RDP02`[9`0`;bX2038b:P0703@d;00d<bh0:b`V02HW8P0Q8Qd07alM
01XJ600202HT9@0>01/K6`0P81h05ADE01<C4@1^KV`0Kg1[075bJ`1gMfl0MGM/07ioM`2IW9<0_;fg
0>7Rg03em_4B003o01[ooooo0`00o`020?n003T0X23`2P3oP0020:0Pl0<0oh000`2P8?0;0?n00080
X23`103oP0000`2P8?00oh000?n000020?n000H0X23`203oP00L0:0Pl0P0oh000P2P8?0B003o013o
oooo000>ooooo`800?l009/0ooOe0<6DS`2K@cT0b4m40=59?@3GB3X0ie940>mIBP3XDT@0hTi00>ID
A@3PDD40g5110=E<?03QFD/0jf5D0>QLC`3[GE40kEmC0>QJCP3TETX0iUQ<0>EGB`3UED`0i5A90>=@
AP3VE4L0ge0o0>AIA03HECT0gV=20>McC03EIST0fFdn0=EY>P3HK3h0hWI80>AgC03PLdP0f6]00>9`
A@3QJd<0ife80>MVAP3XHTD0geLm0>AI@P3RED40gTln0>5?@03OBcl0hda10=e6?@3LB3h0dTDk0<a<
?`30C3d0[DPd0<I_E02lL500[VE40:]YAP2KGc/0XF]509QX@P2@JD80SFe707mU@023K4`0P6]@06U@
?02DMV/0bZNS0<bUYP3G[k00LDU>050]<@1jG5`0c:j/0;nQW`35Xj80bZ:R0>2^[`2VI6P0MBHY0:E<
CP2VD540WeED064U9020De00bjFR0;VGU@30VYP0fJVY09aQI@1V92H0STQ80<9kN@2bKfT0^gYd0:]`
JP2UK6D0XV]T0;F0N02mR800/Gmd0:mmLP2LKUl0ZH9a09]nJ`2bXHd0]ZjI0=7>^`3Rh=<0IVIN01@E
400E5A<07A`J02HU8`0/:2D0;BXU02HS7P0O71L07A`H028Q7@0V9B4092<O02@U7`0U9Ad08b<K01lP
6P0Q8Qd09BDS024Q7`0M7A/06ATG01lM800Q7b807AdO02HV:00B4Q@07alQ08N7Q`1jNWP0NGQa08B4
N01fMVX0M7IY07MiKP1bM6T0MgQ`092AR@2d]Jl0emSC0>k^k00?003o01[ooooo0P00o`030?n003`0
X23`203oP000102P8?00oh000?n0003oP0030:0Pl0X0oh0000<0X23`0?n0003oP000103oP000102P
8?00oh000:0Pl03oP0090:0Pl0D0oh0000<0X23`0?n0002P8?006P2P8?050?n000030:0Pl03oP000
oh0000<0oh000P2P8?0?003o013ooooo000>ooooo`800?l006T0o>3M09aSG02T@SL0cDm10=98>`3J
B3T0k5E40>]EA03VD440jEI60>IGA`3RETD0jFAC0?YhJP3lOFh0o7Q[0?1XFP3^I5L0lVIG0?AXF`3c
IeX0mF]P0?9XG@3cIU`0lFAJ0>iQE`3^HUD0jF1@0>EPC@3BESh0hG1B0?V>JP3JMD/0m99U0?>AI03]
S5l0lI9T0>b@G`3eVFP0liER0>V:E`3UPDl0gWE60>EfB`3ULDX0eEdh0=QL>P3BDc80eU<g0=M<=@3R
DD00hD/m0>=<@@3PC480f4Po0=E;@@3FE4L0fUm@0=5QC@3<ITd0bVQ=0<M/D@3;NUd0`gaN0:]^C`2]
NU/0ZH9S08MXB`2NPfP0V7iW08=VEP2OOg@0cJNT0=jf]`2kTID0JD16058^<P2_Si00c:j/0<FWY@37
Z:D0eZn`0=BSYP1k?T<0RT=70:5EF@2PF5/0RDe=05HV902]Qh@0bjVW0;nMV`3;Wj00f9fQ07/b>@27
=CT0Xde<0<Q`K02`GED0_FmU0:EKDP2JDDX0W5I>0;QbJP36P7P00P2RGUD0402IFe00T5];09QbH02n
ZIH0^JjJ0<_6/`3clN@0[ZjV034a;`15ADL0:2HY01LE600P7ad0<Rh[03<_;00]:BH202LS800702@P
7@0S81`07ahI02@U7@0S91`06a`F01dN6@02028R80807QhL01H07adP028P8`0O7b407b0T00d>4`1K
G640XZ6V07alO020P7P0RXYn0862M023Q7H0P89e07j0L`1jO6l0MGMZ075cJ01[KF80QXMo0::SV`37
b<80iNKQ3000o`0Jooooo`800?l000<0X23`0?n0003oP000?`2P8?040?n00080X23`0`3oP0030:0P
l0X0oh000P2P8?090?n000040:0Pl03oP000oh000?n00080X23`0P3oP0020:0Pl0060=1@N03oP000
oh000?n0002P8?00oh006P2P8?050?n000H0X23`1@3oP0000`2P8?000?l0003o000:003o013ooooo
000>ooooo`800?l00880gkVd08e7?P2gBd00dTi10=U:?03PC3`0l5U80>QA@P3UCcl0kUU:0>MFAP3V
F4L0l6MF0?A_G`3/J5T0lF]M0>]UE@3[He<0k6=C0?9VF03bIUT0l6AJ0?EYGP3dIUX0m6QL0?=WFP3a
IUP0lFMI0?5XF03`KUT0jfmI0?9jH03ZMEL0kG]J0?B2H@3aPUl0mHUU0?27H@3eS6H0mHiV0?:?HP3e
T6<0k8AH0?N8H03]Ne<0jG=>0?AlF@3ZL540oX9T0>mXD@3HBSL0he110>5;@03PC480hDe30=a;@@3Q
DTP0ge970>1GB03IET<0f5U40=AMB03?Hdh0bVaG0;i`FP2[JUL0ODPh0:YoL@3?ZId0b:FK0;jIU030
V9H0gK>g0>:c^P26E5h0Kd9:08YTI`3G][L0d;:`0<Z_Z`3=/Zh0ekNf0<>NWP1^@dD0M4I707i=CP1f
BTT0I3dl08IUHP3;[j`0ajZW0<RUY@3OZk00ZUmY08<Y;`2[B4`0[d]80:M5?P2VBd80ZE590:iJD`2T
Dd/0ZeYE0:5AC02`HEX0YUM@0:]LE@2QETd0WUa>099SDP38[9/0_:fK0<>l[03Of/l0k>[U05iLGP0_
;C<0C4UB05UFGP1?CE40Cde>03Pf=`0W92@0;2TY038_;`0O6Q/0:BHT02HU8P0S920092DR0P0M7Qh0
800U9RP09bLY01hO8@0M7B408b4X01`J8P0Q8RX0;Bhh01TI8`1eMGh0[Zfc08N7Q`28R800SHf108j@
PP2<SH80QHQl07IiKP24QW/0QXMl08B5N`1iNVl0PX=i0862M`1iNVl0OX1f08V;PP2DUHl0YjRR08W:
Q`1YjFP0N?Qg1P00o`0Jooooo`800?l00P3oP0000`3@D7P0X23`0:0Pl00m0:0Pl0030=1@N03oP000
oh0000D0oh000`2P8?060?n000040:0Pl03@D7P0d51h0=1@N080X23`4`3oP0000`2P8?00^3Rd0?n0
00020?n000060=1@N02P8?00d51h0:0Pl03@D7P0X23`0`3@D7PC0:0Pl0030=1@N03oP000oh000080
oh0000<0X23`0?n0002P8?001@3@D7P60?n000040=1@N02XR3`0D91h052@N0H00?l04?ooool000ko
oooo0:P00?l00?oil`3AYI`0UTPl0<1@A03BC400fd`n0>MA@`3^F4P0iDdo0>]CA@3[EDH0kEM80>aI
B@3cHE80j5]:0>aPC`3^IED0iem?0>9JBP3JDT@0hEU;0>5GBP3QEd`0jEe@0>aND@3_HE<0kV9C0?1T
E@3^HU<0lFEF0?1TE@3aIEH0lfMF0>iUDP3`JED0kfIC0>mXE03/J5<0jFMA0>MVD03TJ500hVa<0>ae
E@3[LU<0jVm@0>mbEP3_Ke@0jf]B0>QZD`3/JeD0kFIC0>AKB@3YFdd0hE560>EEBP3RDTL0gdm40>5A
AP3OCD00hTm10>5?@03RDdD0fE100=IGB03=G4`0bFAH09m8?`2@AD00iZFS0>Z^[P3UZZh0j:fc0>jc
^@3n_lP0aH>=07lkAP1n@DT0fZN/0>g1`P3Q^KT0h[bk0=jj^P3L^;P0fKFe0<jZZP3>[:/0b:JU0<6R
X039ZjT0d[Bb0=>e/`3D/[<0fJnc0>^W/P26:C@0]4M=0;i<C02oDTd0a5aC0<ERG03;K6H0`VMR0:YA
B`2mIF40/eiI0;iYI02iI5d0dWid0;1QE02/He@0U5m:0<naV@34/Y`0a;bY0<[4^03Vhmh0b/S902/X
;`0f<ch0@Ci903hkA02`[K@0dm;G06a/KP1dLWD0CD]>05QFE`0m?3d071dO02<V:`0T:Bl07b</01dQ
:P0N8BX06A`U02d]=`0B4Q`081l]024P;P0g>DH0EEMT05UKJ01cLgd0ZJR]092?S@2ASXD0TI:4096C
QP2KWI80Ngie0413?01KG5H0FeYE04i=B01?CTT0EeM?061PEP1bLVP0PhEj07UkL021PgP0O7ic06i_
I`1QH5`0MgIb08f<R03>cLT4003o01[ooooo00<00?l00?n0003oP000@02P8?090?n000030:0Pl03@
D7P0oh0001@0oh000`2P8?060?n000<0X23`00<0d51h0?n0003oP0000P3oP0000`2P8?00oh000:0P
l0030:0Pl0060?n0002P8?00oh000?n0002P8?00oh00402P8?030?n00080X23`0P3oP0000`2P8?00
oh000?n0000=0?n000030:0Pl000o`000?l000800?l04?ooool000kooooo01l00?l00?oglP39VHl0
X4i20<1@@P3BCCh0fd`n0>mKC@3]EdP0iDdo0>mGB@3/ETP0kUQ:0?EOD@3^FT`0ieQ80>ePC`3eK5`0
oWIX0?QdI@3gLfH0mG5T0?9^H@3^JUd0iF5B0>QRD`3RFT`0hUY>0>ALD03WGe<0jEmB0080kF5B00h0
kV9A0>iUD`3]I580lVIE0?5UE03bIUD0lVUG0>mVE03cK5P0k6QA0>YVC`3[Ie00jFE@0>QTC`80l6aG
07P0kVUF0>iYF03`J5X0mfmQ0?A/GP3cJE`0l6AG0>aPD`3VFTd0hUI90>IHC03QCdD0hTm50>1=@`3P
DTH0f5120=QFB@3BFE00/d<o0:U1@02fEUP0]e]P0;QMI02lHV/0afef0=9gP02ZCEL0X4=;09]4B`3B
QH/0jjBZ0>NV[03WZZl0jJjd0>^b^03/]KX0j[Jj0?2n`@3Z_;h0jko00>_1`P3X_/00jKc10>^j`03`
]l00gXbG09//=@3:Ce80c4m=0<U?BP34CdP0fFUU0=YaK@3=If<0/E1:0<IWH`3=L6T0_fEM0<5YG`3^
UXP0/F1;0;=YCP2ULDd0ck6=0<fmW03;a:P0`kf]0=?@a`3Zj^P0FUUN02h]=@0n?4L0<c4l07QgO`3]
k?80GUeR03Pf>@18ATT0^kVj08b=T01FFV<0EE]Y04Q?H@16CV40@TYM024X>P0/;d00YZRg02d_?00/
;Cl0<353038eA00Q9C40<C=005IFH02MWIl0XJ2L09NER`2DUHL0TiF809jPU@1lOGD0EEI@07IeL01`
Kf/0C4]704i?BP1?D4X09BHP05eNEP18BD40>C/`07j0M@24QW/0OWmf07mlM@1iM700C4M1059?BP3T
hn43003o01[ooooo00<00?l00?n0003oP000@02P8?0O0?n000D0X23`0P3oP0060:0Pl0030=1@N03o
P000oh0000<0oh0000<0X23`0?n0002P8?000P2P8?000`3oP000X23`0?n000020:0Pl080oh003`2P
8?030?n00080X23`203oP000102P8?00oh000?n0002P8?070?n000040:0Pl000o`000?l0003o013o
oooo000>ooooo`0H003o003omO40`H^10:MAA035DD@0dTdn0>=DAP3_Fdd0jeE60>YDA@3^F4T0kEM9
0?5KC@3cG540lEY?0>iLC@3_H500jem@0>eSEP3_JU/0jfMH0>m[GP3cKf80lW1P0P3eM6402P3eLV00
lFeN0?A`H@3aK5d0k6AD0>QPD03]I580jV5?0>QOC@3WGT`20>UMCP060>MKC03ZGTd0kF5@0?=WEP3b
Ie@0lFIC0P3bIUD20?=ZF01i0?M^G03bJET0lFUI0?9XF`3dK600mFeQ0?5YG@3bJ5/0m6YM0>mUF03d
JUd0kVAG0?5TF03XFU00iUQ>0>5CB@3RE4X0fe560=UCBP3=C4L0bDe;0<9;C@2mBTl0_TmE0;Y=DP2c
AT`0[d170:dnA02oDE@0_E=F0:Y:C02ZCU<0ZU=I0;9MI02`GfD0[f1V0;=VK02jKg@0_WIj0<AoPP3<
RX`0di6C0=JEV@3MVZ40jZ>[0?6Q[02hDe/0`TE90=9=CP3BBdL0f5E=0<=4?@3?E4l0dUaH0==PF`3<
GEH0hWE`0=YbJ@3FLFD0dG9P0=5jG`2eID00`gm@09i^=`3:[gX0e/RK0=C>ZP3?cKH0c<c00>OXh`2>
Si4092<[04U7DP0l>TL0ATA?0=cKh@2`[[<0G5YM04m=D02OWIh0[:f`02HZ<`0Q9cL082Pk02D`A00d
?eD0>T1H03LlDP2o`]<0?D1A02DV>P0Y;3l0WjFe06Y]O00I6bP0:BTc071^L@2c[j`0Y:6H09jNTP2R
XYH0ZjfR079cJ`1QH5/0QhJ1081oN`24QH00RX^608b=R01fMg40PX=m05EDC`1?D4P0RHV108b<Q022
PGT0PWUd08EjMP1lLF/0?C@_0<>n^`03003o01[ooooo00<00?l00?n0002P8?00@@2P8?0M0?n000h0
X23`1P3oP0000`2P8?00oh000:0Pl0040:0Pl0@0oh0000<0d51h0:0Pl02P8?003@2P8?0G0?n00003
0:0Pl03oP0000?l000800?l04?ooool000kooooo01`00?l00?oek`2iOG<0[4i20<aDAP3GCD00ieE8
0?9LCP3XDT<0kEM80>UFAP3^FT`0lee?0?=LD@3]ET/0lee?0?=OD@3]GTh0kf9A0>iRD@3_IU@0jF5A
0>UTD`3WI500hf9=0>IWD03[JU@0j6MA0P3^KEL0103_KEL0lW1J0?5]F03cKeX20?9]FP030?1XF03]
I5@0jF1@0080iEa<0800iEa:0>MKBP3YFdd0jUa>0>mQD`3/H540lFED0?9VE@3dJ5L0lfYJ0?EYG03`
IUT0kfEH0?=WFP3bIUT0m6QK0?5WFP3fK5l0m6]K0?5ZG@3/IUX0k6=I0>MOD`3PDdT0iUQ>0>5CB@3Q
E4/0gEI@0=UHD`3JGU`0ff=R0=QTI03DH600deeM0=9LG03AFEX0dEaK0<UGEP34EUD0`UIF0<=IF`2j
D580]4a=0;M?D02dCDh0[4Q80:e9B`2_CDh0[DY=0:a9CP2^BDl0[DE<0;93BP2h?400eTi>0=Q=B03H
Bd@0fDm50=I=A@3BBdD0eE1;0=MDC03JFU40hVIL0>9ZG03KJeL0dFY;0<9Z?02oMCP0YV`S09Ye9030
[F40f]2C0=gI[03Ge[X0d=;40>3Rg@2o`l@09bL_05ABG`1;BEL0=C4o0:^X[`3`jo40hmkR0=KBd`3<
al/0hn7U08R;T01PI6d0A4YF02Pa@P0N9Sd0?D9O04iBK@2W[;l0L7J601DH:`0V:ch0Ri6Q07QkRP0J
72T09BD_03Pf>`2BSXd0ZjRQ0:FUV`2TYY/0ZJ^P079cJ`1gN780HV=M06AUH01ZJVP0IVMR07AeL029
R8@0ViZF09ZFT`23PWd0RXN209VFT@2ITHh0V8R8099nO@2IQ840HDi:09R=R`<00?l06_ooool00`00
o`00oh000:0Pl0160:0Pl0@0oh0000<0d51h0?n0003oP000403oP00>0:0Pl0L0oh0000<0X23`0?n0
002P8?000`2P8?001`3oP000X23`0:0Pl02P8?00oh000:0Pl03oP0003`2P8?0H0?n000<00?l04?oo
ool000kooooo03D00?l00?o^jP2bKfL0]E160<e?@`3NDTD0kUY>0>mIB`3WDD80l5e=0>YGA`3_Fdd0
mV9D0>eFB`3cGDl0l5a>0?9QD03aHU40kV5?0>aTCP3[I4h0j6I>0>MWCP3WJdl0h6U;0=m[BP3PKT`0
gF]90>5^C`3NJd`0hF]?0>5YCP3VKE80iFU?0>IZDP3YJeD0kVeJ0?9]G03cJed0mViN0?YaH@3dJe/0
m6MF0?1RE03ZG4h0jE]=0>YLCP3UF4L0jem>0>=GAP3WFd`0jUiA0>QLC`020>]ODP0O0>aPD`3_HeH0
kVAI0>iVFP3]J5T0jVQK0>UYG03kNF`0mg5V0>ePEP3[Fe00jEI<0>=CB03LDTP0fUM?0=]RFP3QL6X0
gG1[0=eaKP3OLVl0ffi[0=e]J`3JIfD0ffQU0=UXI03IJFD0efMU0=ESHP3CHF00dV1O0=EUH@020=1P
GP1B0<mOGP3@GF00beQK0<UEF038DE<0bDa@0=MCDP3FCDL0fTm80=I<@P3KDDL0ddTo0=e@B@3ODTT0
g4m50=eCB03JDTH0feU90=9J@P38GSL0]E`T0<n;@03EY4P0`jI30<:cEP3Hd8L0h]nZ0=kM_P3If/X0
g=gH0>SYj`1ADET0=SA105ECH@18A580P7f60?;`m@3ck_80VIBH06eXK03@cM00iNKZ0=oRi`3EfN80
cmGS05UPL`0a=E00E5Ea08B7VP3<cmh0@dIE01PK:P0S9c<09BLc01TI9@0Q82P06ALL06APG`2c[jX0
ZZZR0:RZW`2YZZ80PhAl07AcKP1VIf40Shj:079cKP1@DD`0DE1<05MFDP1[If@0M71]05aHE@1YIF80
X9RF0:>CT`2iVid0_i^M0<jXY`2VQ880Nf=O0?W[j0800?l06_ooool01000o`00X23`0:0Pl03oP01D
0:0Pl0H0oh0000<0d51h0:0Pl02P8?003@2P8?070?n000H0X23`00<0oh000:0Pl02P8?000P3oP000
0`3@D7P0X23`0:0Pl00>0:0Pl1H0oh000`2P8?02003o013ooooo000>ooooo`0c003o003niN00[fIO
0;Q=@`3BCdD0iEE:0?5MD@3_EdX0jE=50>aHBP3]FD/0lf9A0?1OCP3_Fdd0lEm@0>eNC@3_HTh0jV9<
0>YVC@3WIdX0hFQ90>9]BP3OLT/0h7I<0=YeB@3LO4`0eWY90==gB03IO540fWYB0=YhD`3LN5@0gWEE
0=icD`3QLUH0gfeB0>A/E03UIe40j6EC0>eUE@3^IED0m6QG0?5SD`3eJ5L0mfUK0?IZF`3cIeP0lfMF
0?5UE03bIUL0lVUI0080k69E07D0jV1C0>EKCP3UFe00iemC0>EOE03OFdl0hf=H0>5UF@3QIe`0nWYa
0?9]I03`IU/0kEeB0>aJC@3RE4H0eU950<mIB`2iDDH0[E180;=NF@2dHel0]F5O0;eWIP35JfX0c6a[
0=IbL03NN7@0fgEa0>1jMP3NMW<0h7Ud0=aeL03MM700fW5]0=Q/J@3JKFX0ff]Z0=]YJ03LJ6P0g6IT
0=iTH`3LGe/0fEQB0=aLD`3IET`0f5=:0=eGCP3MDT/0h5=90>1@A@3ODD<0h5A70=]F@`3CEcd0bUhg
0:mI7P3<RS`0jKeJ0=O0D@3AaUd0fM=o0>STY`3XiL80hN3>0>3OfP3dm?H0VYVQ020N:`15@e40EE=Q
05UGHP3Mg>80f=KK05MEFP1UHfP0]kJj0>g]k`3Vin/0hnK[0?Gio`2GVZT08b@i04Q8H01YJ7X0inKd
0<S6d@22PHT0FUUO04A3B00Z:Bh06QPM02TW:02BTHl0^KFa0;2`Z02^[ZH0Zj^S0:RXX02RWiP0WYjF
0:^XX@2PX9P0UYJ>08n>R@20Og/0HF1L04i=B01=C4L0GUUF09fAT@2UQXX0fjJ/0>nc]@3f^KP0`hb9
0758@P3Wc/T00P00o`0Jooooo`04003o003oP000oh000?n004<0X23`1`3oP00O0:0Pl0P0oh000P2P
8?000`3oP000X23`0:0Pl0040:0Pl080oh0000<0d51h0:0Pl02P8?00202P8?020?n000@0X23`4P3o
P0000`2P8?00oh000?n000040?n000800?l04?ooool000kooooo02/00?l00?SLf02^Hed0`5580=IA
B03UEDX0lUiD0>QAAP3[EDL0jUI80>mKC@3cHU40k5e<0>]LC03`He40k6A>0>ITBP3UJT/0hFa90=ib
C03HMD`0dWE<0=9kD03?OU40c7mA0<f4E03:PeD0`WiA0<InEP36OEX0agaL0<IgF038M5P0ag5F0<]a
F@3;K5H0cfQE0=i_G03UKE`0j6UH0>UTD`3[I540kf=@0080lFAC07d0kf5C0>iRD`3_He80lVIE0?1T
E@3bIUL0m6QK0?EYG03hK5l0m6YM0?AZG`3cKF40k6YM0>AXGP3PJf40dF=H0;M8?`3GH5X0jV]T0>eW
GP3YG580k5e?0>ELC03IFT/0cf1?08lc901b9QT0LC4X06`a;@1Z;Rd0L38c07Xh>@22>SX0TTA209]<
B02OD4`0X4m<0:UHE02`GEL0]65K0;iYI034K6P0bW5]0<mdK`3BLg40dFm/0=YgLP3ONGD0g7=`0=aa
K03ML6T0hgA]0=e/I03OJ680i6MQ0>UUH03WGUH0h5=90>9FB@3KDD@0fUQ80==LA03>J480_F`g0;Yk
=03^`fL0gLML0=S<J03PfHP0dLf@0=OC/03PgLh0hN3L0?3_m03Ng>L0@3i;03<`@@17A5D0CDUG0;Nd
_@3HeM`0?ce203Pc>P30_L40j^S[0>KVj03RhnD0k_7f0<G8d@0W:3X0@3iD04E2E@2o_L/0jNK_0=GC
eP38a/L0^kVj0:ZXZ`2HUYL0Z:NU0<;1_`2m^KH0];>^0;Nf/@2f/jh0/k2[0;6^Y`2^Zj@0ZZNP0:RU
WP2YZJ40YZJN0:RWXP2LViL0TI2;08R7PP1mMG<0UhB60;24R`3<PhX0f8>80<ihN@2[GET0RTm90<jY
X@02003o01[ooooo00<00?l00?n0003oP000>P2P8?000`3oP000X23`0:0Pl0080:0Pl0l0oh005`2P
8?070?n000L0X23`00D0oh000:0Pl02P8?00X23`0=1@N00;0:0Pl1L0oh0000<0d51h0?n0003oP000
103oP002003o013ooooo000>ooooo`0c003o003ae=00ZUeE0<9CB03GDTT0ieM<0?9NE03XE4P0jUI8
0>mKC@3aGDl0m69C0>IIB03]I540i6190>IZCP3LJTH0gG=90=QiB`3<NTX0b89A0<64F02nQf00`Hm/
0<2?K`33UGD0cIj20=Z/TP3T]9h0hk>O0=^ZV@3W/jD0j[6V0>b`YP3][J@0kj^R0>NNU`3EPGH0cFUI
0=m`G@3ZLE`0jF]D0>YTCP3`He40l6=B0?5TD`3/Gdh0lF=E0>mPDP3bHeD0lF9D0080lF=E07L0kf5C
0>mSE03^HUD0jVAH0>AYFP3MKF40eG=X0;MNE`1l8Ah0Vc<b0<MCD`3WJ680kFAL0>ULDP3XH5@0hF=D
0<aQD@22;al0FQ/<05HV701<9Ah0BRLU04XV9P1?:2T0Eb/]05h^;P1J:RP0Gbl[064`;01Q;R/0JcPd
06@a;@1d?cT0Lc`g07Hk=`1m@3/0PT4o088n>`2>AdD0U4Y709Q=BP2IBdL0XU=?0:mKF@2`EUD0]UME
0<MNF`3CGE/0fe]H0=IAC03FDDX0d5580<YDAP35G4T0aVaA0;meCP2`M400hKIa0>;8M03IbWL0l>NR
0;6[N@1nNUl0R8Ij09JFUP2/[;@0_ko;05IEI@0m?4h0@SmB04DnD02;QI<0mNoi0;^f_@2VWjH0j^?Y
0>_VjP3Vi>D0hN7S0>OXk03Uj>l0@D=B02PY?@0[:Ch0NGJ70>WVk`3Ie=P0dLo@0=?Bd03;bLX0c<[;
0<c;b@3:bLL0bLG30<>o_032_[/0`;bi0;fi]P2j]k80^;F`0;>`Z`2d/JX0/JjW0:fZX`2/ZJ@0Xj:M
0:f/Y`2e/Zd0^:j]0;ROXP30RY40Ze1I0;M>E@33EeL0_UeG0:MME02`PGT0oo;]003o000Jooooo`03
003o003oP000oh0001H0X23`2P3oP00I0:0Pl0040=1@N03oP000oh000?n00140X23`00<0oh000:0P
l03oP000403oP00:0:0Pl0X0oh001P2P8?020?n000h0X23`5@3oP0000`3@D7P0oh000?n000030?n0
00030:0Pl03oP0000?l0013ooooo000>ooooo`0a003o003Wb<D0XeA=0<=CB03KEd/0jUY?0>iLC`3X
E4H0kEU;0?1NC`3_H4l0jUm<0>MPBP3WIdh0h6U90=aaA`3DM480dGm70=2:C`39TEP0_i5O0=>]QP3W
aJT0j<Vd0>K9]`3]d<80km760=:dZ@35Yil0`Z>N0?;Cd02oX9h0[h^=0;68S02bR8`0[Gn20<jJW03m
`;/0g8mo0<Y^E`3QN5/0iW=D0>U]C`3/IDl0kF9?0?9VE@3`He80kf5C0?9SE@020?5RE01i0?9SE@3^
Ge40lVAF0>eQDP3_IEP0ifEG0>1/G@3ONVh0Xe560;=`JP1M5aD0IaHE08l];P36E5<0iVUU0>QQF`3U
GeH0hF=E0=UYF`2MA3@0HAh>04PH30117aH0>R4L03LR8@0e7b40>b@U040V9`109RD0@RTU04X/:P15
9bD0D38`04T/:01@<B`0BbXU04l/:01?:BH0EB`Z05T];01M<2d0Gbl]068a;@1U<c00Ic4_06H/:`1b
<S80Mb/]08T`<P2C:b`0`De=0<]?C@39CTT0_da50;mIC@2eGDl0TdXg07Xn901_@Ad0R6@d085Z;`20
LCH0Rh=B07UeD01HED80EEA?05IEFP1LG6H0EeIT03dlC00o?U00?SaA044nD@1MFFX0Z:Bb0:bY]033
_LT0f]?M0>KOi`3Wh^P0i>;W0>7RiP3am?T0Q8JB014C800D4b40@T1=0=ODf`3Qgn80f=KG0=OFe03E
dm@0e=;C0=?Bd03Ddm40e=3?0=3<b`3?blP0cLW80<[6a@36`[l0aL6n0<C0_@2o_;L0_KZe0;Zg/P2f
/jh0[Z^V0;6`[02k][<0aKVi0<fd]`3?U9`0/dmI0;8oAP38D580`EAA0;1LDP2AFdl0k]WD003o000J
ooooo`03003o003oP000oh000100X23`3@3oP0040:0Pl080oh005@2P8?00103oP000d51h0:0Pl02P
8?020?n001`0X23`2P3oP0000`2P8?00oh000:0Pl0030:0Pl0H0oh0000<0X23`0?n0003oP000202P
8?020?n00180X23`00<0d51h0?n0003oP000503oP0000`2P8?00oh00003o000@ooooo`003_ooool0
;`00o`00hl:m0:=CBP33DDH0g5I:0>eND03ZF4T0iE920?1OCP3^Gdh0jF5;0>ESB@3NIDH0gVi80=Ea
@03FP4D0dXU50<jBB@3>WUH0bJEW0=ZoT03`fkh0glbm0;j]YP2cXIl0i];D091lOP1_FE`0F4=806eH
G`3E`LX0JeMR06QBG`1ZDV80K51O06M7E01N>D00a9RE0?[2/@32OEh0d7]B0=]jC@3TMTd0jVm>0>MU
B`3/IE40jf9?00@0lFAC0P3`He80E`3]H4l0lVIG0>aWF03SJ5T0hWQZ0<I^HP1i=Rd0UfQQ0:IiM01`
=S@0Ha`J08@Y:033EE@0i6QV0>MVH03THEL0hFMJ0<iSD`2C>RX0Gad?04<E200j71@0<1dG02hN7P0]
8200;R0P02/M7@0^81l0>BLW03<Q7`16=380>BLS040_:00j9b40BcHa03TT8@0j9B80>bHS040X9P12
:RP0@2LS04@X9P18:RX0A28Q054W:01A6Qd0HA/M06T@4P2cBd`0bUYH0<UIE@3;IF00^fAK09]HC`1O
;R00A1l?04DZ5@17<AT0@SDD03Xd500d<aL0:R/I03`l=010@400A4E:04E5C`0j>DL0;bhn034`@P0a
<TH0>SaA04I9G01DEFL0CDiP05=AIP1[J7/0Q82?09^EX@3Kf>40hN3U0>OXk038bLh0OWn406ETJP1D
DeP0^;Rj0>GUi@020=_Kf`80f][J01`0fMWI0=KFeP3Ge]D0e]GC0=CCd@3Dd]<0d]7?0<k=b`3=c<X0
bl[80<W8aP35a<80aLC00<;1_@2l^kL0ZjZX0:RTX`2h[Zl0`J^^0=6JX`2bDe/0Xc8h0<9:C036EU80
]eeD08=7?03:/JX00?l06_ooool00`00o`00oh000?n0000>0:0Pl0P0oh0000<0X23`0?n0002P8?00
2@2P8?020?n001@0X23`00D0oh000=1@N02P8?00oh000:0Pl0020?n002<0X23`0P3oP0030:0Pl003
0?n0002P8?00X23`00D0oh005@2P8?040?n000h0X23`4P3oP0000`00o`3oooooooooo`0>ooooo`00
3_ooool0<@00o`00hKjj0:MDC034DTL0geU=0>eNCP3ZF4T0h4ln0>QJB03VGdT0gem20=]T@P3KL4H0
cfll0=9n@03ARD40dII60=NXF03K]fd0cKEi0>OH[`3HbkP0hmSD0<Jk_`2l/[X0]JVd06MIIP1MCe`0
>B`f0;>U/P2HS9X0EdYK05I9F`1>?e@0ET=I06M@HP15:S<0UG9`0?oJa@3LY7l0e8iK0=:1B@3LODP0
igQ=0>adD@3YJD`0jfA>0>eRC`3aI5<00P3`He80FP3cIUD0kf9A0?9UE03^IED0jVQH0>9^G`3INF/0
XUQ;06@`9@1Q@3T0]IRB0;JAR`1/>CH0Ea4?08H^;033FeX0gfUW0>=VH03PI5X0ffEI0<]QD`2A?Rh0
Fa`=03lC200b5`h0;1XF02LN700V7Ah091/L02HM7P0a9bH0:AlN03X`;`0^9280=B`W038Y900j;b/0
<2DQ02hT8P0d:RP0<bTW03L]:`0f:2L0;b4P048b<P0e8B80AbX/044G6@1L7R40I0lB0:e9B@3:FUP0
c5aH0<QUG`2aHEP0SUE<04PS6P0`60h0<28G034W6`0d;B00;2XM02d]8`0O81X0:BTW02//;P0b<CL0
=C@l03Hd?`0/:SL0;2/i02X/>@0Q93<06Qd/02<V=@0b=D@0=3M80492E@18AEH0AT9@0;bi`P3ViNX0
f][L0=gMg`3Kfm/0f][J0=7Ad@3EeMD0g]kN0=gMg@80g]kN00`0gMgM0=kNgP3Kfm/0gM_L0=gLfP3L
fmT0g=[K0=_IfP3Hf=H0e]KD0=OEeP3Dd]<20<o?c@0?0<o>c03;b/P0]kJd0:2LV`2VWJ00[IZN0=FT
[02jGfP0VR/b0<E=C`36EE40^5aA08Q8?02PQG`0ooS_01[ooooo00<00?l00?n0003oP0003@2P8?09
0?n000d0X23`00<0oh000:0Pl02P8?00502P8?030?n000030:0Pl03oP000oh0000T0X23`00<0oh00
0:0Pl02P8?005P2P8?020?n00080X23`0P3oP00H0:0Pl0030?n0002P8?00X23`01P0X23`2P3oP000
102P8?00oh000:0Pl03oP00@ooooo`003_ooool0S000o`00hKZe0:YGC`37EDX0hUa@0?5RDP3WEDH0
i5E40>EMA`3NHD<0df4l0>MnC`3GNT40e8=10<f5>@3ATch0hZiH0>g0K`3G]700eKn=0>3A/P3=`KD0
hMSI0;bf^P3XhNT0TXZH05aDH@12=dD0L6Ia0=C:e@1^Hg<0ACa=05mFI`1`I7P0AcU@06=@H`0k8B`0
/Hj:0?oC_03/]H`0mkZ10>NRH@3BPCl0h8160>IjB`3]Me40ifQ80>eUC`3_HU00kf9A0?1QD@3bHeD0
lF=E0>eQD03ZIE@0hVUH0>=iJ@34Lf80Kc@V05<X7`17;bL0FD@o09n6P@2oWYT0KShj058E4P22=380
]5IF0=MZI`3MIf<0hfQQ0=]UF`3;HE<0V40b060N400m4@H0<1D>02PL600T71X0:B<S02@N7P0Y8b<0
9B0M03`d<P0Z8Ql0=BdZ02dV800[91h0:R<M03H^:`0_9bD0<RdY02PS7`0W7A/0:R0N03DZ:00a8b80
?B@W03L=4@1H5a/0JQ0B0;E9A`3EFeH0be990<1FB@2dHE<0T5Q;03lM4`0Z5a009QdF02HQ6`0V91l0
7ahI02HV900O7ad071`J01hN7P0Q7b808b4V02`W;@0V8BP09B8Y01@A600o?T<0Hf9W04Y;C`0f>Sd0
7R<W028S;P0M6bP07AXU08B1RP3Yj>d0fm_M0=[Hf@3KfMX0gM_L0>3Og@3Rh>40hMoP0`3QhN40203N
g]h0g]kL0>3PgP3Ph>00h^;R0>?Sh`3Ogml0h>3P0P3Ogml04`3Ng]h0gMgM0=cLg03Kfm/0g=cL0=WI
f@3Cdm<0bLO80<Fo`@3B`/D0k<C:0;i[L`2A:2d0`da>0<ACC@2lGU@0SD/o08a`I@3om^`06_ooool0
0`00o`00oh000?n0000<0:0Pl0L0oh0000@0X23`0?n0002P8?00d51h302P8?000`3oP000X23`0:0P
l00D0:0Pl0050?n0002P8?00oh000?n0002P8?000P3oP00Q0:0Pl0030?n0002P8?00X23`00@0X23`
00<0oh000:0Pl02P8?003@2P8?000`3oP000X23`0:0Pl0040:0Pl0030?n0002P8?00X23`01X0X23`
0`3oP000103@D7P0oh000?n0003oP0020:0Pl0030?n0002P8?00oh00013ooooo000>ooooo`2<003o
003M];00[5Q>0<aGC@3SGE40kF1?0>AEA@3QE480hV9;0=Y[C@3BKdH0hHME0=j>C`3FST@0fIQ60>F/
E@3b`6/0h[Q^0:R8C@3KaIh0flni0>?Je@31^kl0blK<0>_Uk`1UHG40@Ce>0:NP/03cjoX0UHfL04Dl
C`0n=dT0e<cQ0=79gP1@A5X0C3e@048[=@3Q_[`0cY^80;amFP3b/7`0okak0>FLE03FPCh0h8140>9f
A@3_N500jFQ90>eUC@3_HU00lV=C0?9SE@3^H580kfID0>EVD`3OKU`0f7]Y09iIB@1L;1h0ABLL03l/
9P0n;bX0C3Te0:VAS@34YJ00J3lk058J6@1g;c00[EED0<mWIP3QJfL0gfIN0=mYG@3>I5H0WdTj05lP
4@0l4@P0;aTD02HL6P0W8Ql09R8Q028N7@0W8b80<bh[02HQ7P0b;BT09B0L02XU8@0V8Ad0<B`X02XU
8@0Z9b80:2DP028M6P0`:2D0=2`Y034U9@0f7B00>a4E05LE6@1_41@0`Ti>0=AECP3ADdL0aUQ90;]T
D`2AEdT0?Ad@02HE3@0Q71P07A`H01hN700O7al0820P01XJ6P0K6QP07a/J01dI600Q7A`09AlQ024H
6`0D3Q00?SPh0;2/Z`3Lf=L0alO50;Rj]`2RYZD0QhZ=06IUK@1;B4l0I65X0=cKh03Ogn40h=kS0=oM
hP3Rh><0i^CW0>GSiP3ShN820>7Qh@0<0=oOg`3MgMd0gmoM0>;Rh03Rh^80iNGU0>KViP3Ph>00h^;R
0>CTi03QhN40h>3P0P3Rh^80403Ogml0gmoQ0=oOh@3Ogml0h=kO0>7Kg@3VemX0n=ON0<QkP`258RL0
_4Q90<1?B`2mGeD0TDm108e_I03omN`Jooooo`03003o003oP000oh0000/0X23`1`3oP0000`2P8?00
oh000?n000080:0Pl080oh000`2P8?000`3oP000X23`0:0Pl00F0:0Pl0@0oh0000@0X23`0?n0003o
P000oh001`2P8?000`3@D7P0X23`0:0Pl00E0:0Pl0030?n0002P8?00X23`00@0X23`00<0oh000:0P
l02P8?00302P8?000`3oP000X23`0?n000040?n000030:0Pl03oP000X23`01h0X23`00<0d51h0?n0
003oP0000P3oP0030:0Pl0030?n00?oooooooooo00kooooo000>ooooo`2E0?ogm03J[jT0[EI<0<aH
B`3WHU<0jUe<0>9EA03TFdT0g6I@0=1aE@38M500dXQG0=ZFF@3LW5@0jZeM0?FjJP3Y]FT0WWDg0;fN
L03VeKT0gM?70=oFe`2WX:L0j^G/0;nla`1EDVH0@3eB09B?X`2ZYKT0F51U04Q0F01?Ael0XiZe07ad
S01@A5X0=BLh085[M`3fd]H0[G5Y0;EXE03>NUD0hi1L0?beKP3OTdL0fHLm0>:3@`3VNdD0kG=<0>]X
BP3_Idl0kf9@0>iQD03`I5D0jf=C0>AYE`3MM640aGAQ07U0;`1<:1X0?2HK03PZ9@0e9b@0?BhY04hk
=@2CNgL0_Z:N08iXI@1@81h0JBTY0:=BD@3=IfD0gVeY0>9YH03LJ5/0d6UJ0:==?P1M7a00>1D<02TJ
5@0U6aT08ahK02LS800X9240<2`Y028N6`0a;BX09B8M02h[9P0/:B@0<RdY02dX900W91l0;2TR02DP
700/9b@0=bl]02DI6`0j7b@0@A@I05XC6@1f4aH0aDe>0=QDC`3BDTD0bU]:0;aSD@2<Dd80?1`=02<B
2P0R7AT07AdK01PI6@0P82007Q`M01dI600Q71T071LC01lJ5P0T71T0718@02DJ601dJVP0clO40=[E
d@3Gdm00fm[F0=SHeP3KfmT0gMgN0=kLg`3CdM@0blW<0=kMhP3Qh>H0iN;]0>OSl@3Ien@0_K_60;Nf
_03IfM/0h>3P0=kNg03Lg=`0gMgM0=oOg@3Ng]`0gmoM0=kNgP3Ph>000`3Ogmd00`3Ng]`0h>3P0>3P
h0020>3Ph00?0>7Qh@3Ph>00g]kP0=oMgP3Qfmd0i][L0?SHgP31NX80/U=I0;91@`2nCTX0_5]B09MC
AP2CLfP0ooCY01[ooooo0`3oP00:0:0Pl0P0oh0000@0X23`0?n0002P8?00oh00302P8?000`3oP000
X23`0:0Pl00G0:0Pl0030?n0002P8?00oh000080X23`0`3oP00M0:0Pl080oh001P2P8?000`3oP000
X23`0:0Pl00:0:0Pl080oh00202P8?000`3oP000X23`0:0Pl0030:0Pl080oh00602P8?000`3@D7P0
oh000?n000020?n000<0X23`00<0oh00ooooooooool03_ooool000kooooo07h0ooOb0=FZX`2VDTL0
cEa<0>EQDP3YGD`0hUI50=]JA`3BJUD0bg]T0=fHN`3QXg`0h:A`0>FXJ@3e^G<0l[Ma0;>0@@2PN4L0
hlVX0=g<^P3Sf]<0bL330<c5c03im?/0R8:>04m;H01=B5h0FUEY05aDJ@1GCf@0E4aT05=;H`1MDf`0
EdeU048gB00_8C00dKg80?oPi`3Y/K80_WE^0;aZE@2mJDD0jjAV0?^fJ@3LTdH0eH4i0>F3A03WMdL0
lGE?0>MTB03[Hdd0kf=B0>iUE@3XIE<0gfYH0=]jI`2[HU40GRlO040S5@0f9A/0<BHQ034V9010<Rl0
?BhY048`;023L6X0`JVU09QfM01D9b@0KC0_09E4@@35I5h0h6mW0>5/HP3NKEl0c6IG0:5>?P1D7A00
>1L@02XB3P0/6QH0<R@Q02/P7P0c:BL09adK03H^:`0/9240<2TS02dV800`:B<0;RLQ02@O6@0^:B<0
91lK02/V8`0`:2H09aPK03hQ9@134QP0H1LN07XC5`3<DU40fEA=0=ABA@38EdD0_fMC08YA?P0m7@h0
9A@<024L600L71X06QTJ020L6`0P6aP08a/H02DJ5P0M4`X07A<701T@0@1;?c<0ZIbC0=cBb@35_[P0
S8N30;2/Z@3RhMd20=gLfP0A0>7Pg`3Th^<0j>KY0>SWk03YjO40iNCb0=7?i02WYK/0KVb104m>GP1A
CeX0/K2e0>o_k`3Rh^80g]kN0=gMg@3Ng]`00P3Ogmd0103OgMh0gmoO0=kNgP3Lg=X20=_Kf@030=gM
g@3Jf]X0g=cL0080fm_K00h0g=cL0=cLgP3Mfm`0gmWK0>?Gf@3bdmX0cHN?0=aoQ`2S=CP0_De;0;]J
D@2MEd/0VGM]0?oejQ[ooooo0`3oP00;0:0Pl0T0oh003`2P8?000`3oP000X23`0:0Pl00H0:0Pl080
oh000P2P8?020?n000T0X23`00<0oh000:0Pl02P8?004@2P8?020?n000H0X23`00<0oh000:0Pl02P
8?002@2P8?050?n000h0X23`00<0oh000:0Pl02P8?005@2P8?000`3@D7P0oh000?n000030?n00080
X23`00<0oh00ooooooooool03_ooool000kooooo01d0ooSb0<nWW`2VE4P0bUY<0>ESE@3SFd/0gEQ7
0=eTD`3;Kf00`Gmc0:meI`3@V840k;BA0?RkS03h_8H0f9aX0:QeAP37YH80kmW40>_JdP3LdLl0a;Zk
0>3Ef@3^iNX0THN@03/bA014?Dl0B45A04HmCP0204@kC01h04<gB`0o<T@0=RTj03@V<`2=OHL0n>?/
0?gOi`3og>@0oL_>0=FFT@2SFd`0`gY?0?bhM`3k]fh0hIE:0=b5@03VOdD0k7U<0?1aD03_JE00kFAB
0>eXE`3PHe40gW5M0=AkJ@2ACSd0DBHF03hT5`0h9al0;B<N02lU8`0g;RT0?C8/048e;`17>340L5eG
0:J?R@26If@0Kd=006/`;02?A3h0_V1H0=aaI`3SLFH0fVQM0<eUF02<=bX0DA4803`91@0k4Ph0@b4O
03HJ5`0m9B40;Q/E03<R6`0e9Ql0<RDO02dP6P0b9Al0=R/W02PO6P0c;2H0:20M02hV8`0b9bD0;Q/M
04<T:@1541P0Ga8H07dD603>DU00fUA;0=9@@P37F4@0_6EA08M>>`0n7Q40:AP@024L600M6AP07aTJ
02<I600Z71T0:a`E02PF300O3P00:ad2071S@`3<`J<0bKnV07UcH`2?Rh80ZZNR0=3<b`3Og]`0g]gK
0>7PgP3Ui><0j^S[0>[Yk`3QhNd0_[oC08b>Y`1PHH00EUIh06IWQ@1NGWH0=3=107AcN@3`l?80i^KV
0>7Qh@3Ogml0h>3N0>7Qg`3Th^<0jNCX0>SVi`3Th^<0hn7R0P3Rh^804`3Qhn80g^3O0=oOg`3MgMd0
g]kN0=gMg@3KgM`0gMgM0>3Lg@3TfMd0mMOM0=RBVP3;KWH0X38e0<1@CP2kFU40VeE909ajL03oln/0
6_ooool20?n000h0X23`1P3oP0020:0Pl0030?n0002P8?00X23`00`0X23`00<0oh000:0Pl02P8?00
602P8?020?n000030:0Pl03oP000oh000080oh002`2P8?000`3oP000X23`0:0Pl00=0:0Pl0030?n0
002P8?00X23`00l0X23`1`3oP00>0:0Pl0030?n0002P8?00X23`01D0X23`00<0d51h0?n0003oP000
0`3oP0020:0Pl0030?n00?oooooooooo00kooooo000>ooooo`2?0?ohlP3=YId0YUM:0<eOD03SIEH0
gU]90=YMB`3DIE@0aWM]09mXI@1R<B`0S5Q=0>>/U`3i_I/0fj1h0;IoF02bQV<0l]>n0>KDb03ahn00
b[k00>3Df02eZJd0_k:k0=kBg01aIGH0DDUH05=;FP1NDf<0HUMU06MLJP1UFVP0K5i]085cP033/kd0
mNC/0?WTk@3ignX0nmgY0?oKiP3od=H0hZRV0<J0I`3FT5`0okai0?VdJ@3NT4H0gh=20>QnBP3]MTh0
jfa<0>YVD@3WIU<0hf]J0=efH`31L5l0Mc`/04`V6@12:Qh0>2TR02dT800]9B80<b`V03H]:00e:R@0
@SLa04@e<01JBD80KUUD09YmN@2SNW@0OTM008]1>02iGeH0f71W0>EeJP3MJf00aE]?08le:P1W5a00
GQLA06HU8@1A5Q80E1lI04LF3`1?8aX0AalG048M5@0j60l0@b0J04<T7`0g6Q@0?b<O03@H5@0i7Q/0
?R8Q03/I6P197240E1HK06<>4`2;6Q`0eUIC0=U?A@3FDD80bEI30<AYE027ACD0?a<802hA2`0Z5A80
:18D02hD5@0c5Q80>1XB034D100^5000DS`E09j<FP2cYW40T8IE085iDP2JUWd0g][>0>CQg03Sgn00
h]kO0>;Ph`3YiNH0j^OY0<_:d02QXJd0JFYl04I8H@16BFP0FEao06e`T`1KG7X0?SaD02`Y>P1>Be@0
hn7V0>WWjP3QhN<00P3Ph>002`3OgMh0hMgO0>[Tj03Wh^H0i^;S0>7Oh03QhN40h^;R0>7ShP3Ph^40
h^;R0080gmoO00h0h>3P0=kPg`3Ng]h0gmgN0>GLg`3efn00bHJ?0<=VKP2]?T@0_4Y:0;eJE02ME4/0
WWac0?ocja[ooooo0P3oP0070:0Pl0<0oh00102P8?030?n000030:0Pl03oP000X23`0080oh002P2P
8?000`3oP000X23`0:0Pl0030:0Pl080oh006@2P8?020?n00080X23`0`3oP0040:0Pl0040?n0002P
8?00X23`0?n00180X23`00<0oh000:0Pl02P8?001P2P8?000`3oP000X23`0:0Pl0030:0Pl0P0oh00
:@2P8?060?n000030:0Pl03oP03ooooo00oooooo000>ooooo`0J0?ofk`33Vi<0ZU]=0<aQC`3RIeD0
g5i:0=APC@3:J5P0/G=Z0=:VZ@2/PhP0MD940=>JU03WZ9P0]WYT09]]E03K^jH0elBj0=[?b`3Fbld0
cL790?3Qk02n[k/0^jfl0<Bhb02eZ[`20:NO/0200:>JZ`2SVZT0VI6O09R@W02VVjP0Y9VS0::DW`2W
Uj<0ZINS0:2:UP2TS9T0U7Z608U]N@3bcmH0fJ:K0;]_C`3DR5@0n;Ic0?ReJ@3/WU@0hhQ70>QoBP3[
Mdl0jFe@0>=YD`3NL5`0f7aY0:1LC01G9aX0BR/P03dZ8P0f:R<0<RXU02hY9@0Z9Al09b8L02dW8@0_
:B<0>C0[040e<018>cL0F4M307YSGP2TQGh0/XAo0;YkMP2nKFL0d71Y0=Q/I@3SKf@0df1B0<MDA`2l
Bcl0]T@k0:dm=02V>2h0WS@Y098]802::Ad0Ob<G07PP5@1f7aL0M24I06XI4P1`8Q/0IAPB06@J5@1T
71T0H1DF06LF601X3A40L`T;09dO8@3LDe40g4e50=]@@`3CETH0c5i>09Di;01L30@0DPX8050=2`1A
2P/0F@h<068H3@1T8@`0O4HN0;fEE03J_Vl0[YY907IX6P2LTdl0g]NR0>kYa`3]j=H0jnKR0>COhP3A
c=80]K6i09VDW01]Jg<0BdaF04A7E00n@E<0A4UM04mCJP1PHW/0E5=/03TfBP0]9cT0:R4a030V=02h
/KT0l^gb0>?Qi03QhN<0hMoR0>7Lh03XhNH0J61W05aFFP3Pfmd0jnSY0>;Qg`3Qh=h0h^7Q0>7Ph@3Q
hN420>3Ph00>0=oPh03Nh=h0gMoM0>3Ng`3Tg=l0mMgS0;UiPP2eFV@0_DaE0;M4B02nFeH0XUUB09Yh
K`3omN`Jooooo`80oh001P2P8?000`2h>;@0oh000=1@N0020=1@N080X23`00@0d51h0?n0003oP000
oh000P3@D7P:0:0Pl0030=1@N02P8?00X23`00<0d51h102P8?020=1@N1T0X23`1@3@D7P00`3oP000
d51h0:0Pl0040:0Pl0<0d51h1`2P8?000`3@D7P0X23`0=1@N0070:0Pl0030?n0002P8?00X23`00/0
X23`00<0d51h0?n0003oP0001P3oP0020:0Pl080d51h00<0X23`0=1@N02P8?002P2P8?000`3oP000
X23`0:0Pl0040:0Pl080d51h3`2P8?060?n000030:0Pl03oP03ooooo00oooooo000>ooooo`100?od
k`2kTh/0YUA60=1UD`3QIU@0f5i90==VDP30JEP0Yg5[0=Ra]P2?IVh0YW5g0<b@TP36Qh80W6IL0=Rc
ZP3Rc/L0g=3@0<k8c02`Zk40l^cf0;N__P1SG6`0JfIj065NL`1JEfd0FUQ^05aJL01MFg40HEmd069S
M`1SI7H0JfYl06m/O@1^JWT0N7:007ebPP1kKgd0LfI`05A7D02m[KL0o>O^0?K>d02oNVX0ag]I0=RE
H03o`Gl0o;Q_0?:UG`3aTeH0m8QI0>ehE`3LJU80eg9N0=>2L@2LI5L0CRTP03TU700e:R@0;RLQ034Y
9@0_:280;RHS02XU8@80;2LS0480;BDR03D]:P0l=340@CPc04Hk=`1B?c/0Jda909mbK`38R8P0kIjJ
0<a]I`3CKF40kh]k0>>2K`3GM640d6EE0<YJC03?Fd`0dee?0<mIB`3CGDl0dUa>0==MC`3@FTh0beE;
0<A?A@2oCD<0_4Y00;93>02Y>S40XcHa0:4a;@2O;2T0W28Q0;Hb<03ECTX0eTe50=M?@`3CCd80d513
0;i4>@2S;2@0WRLQ0:0Y8`2Q:R@0[SD[0;m?>@2mFcP0/F@`0?;1M@3geh80ZI0n08in<@3GcX/0k>Jb
0=oJ^P34`K00U92?06MTJ`1;B540ADA<04Y7D019BE40?d9903`oAP0k?TL203TlA@0F03<a?00/:C@0
<R`h02dU<P0_8c409aTX08n5SP3fkoH0iN3T0>;Ri03Rh^80jnWZ0:NRX`1UH6@0?CTj0;Na/`3dk_00
jnGU0>WSh`3Vh^40iN7P0>?QhP80gmoO00h0gMoN0=oQh03Nh=l0gmgN0>;LgP3egND0_X2;0:UCG02l
DET0^4M;0;eLEP2SFU40VWQ_0?ocja[ooooo0P3oP0060:0Pl0050=1@N03oP000X23`0:0Pl03oP000
0P2P8?020?n000030:0Pl03oP000oh0001@0X23`00<0oh000:0Pl03@D7P0702P8?00103oP000X23`
0:0Pl03oP00C0:0Pl0030=1@N03oP000oh0000@0oh001P2P8?040?n000040=1@N02P8?00X23`0:0P
l0X0oh003`2P8?000`3oP000X23`0:0Pl0030:0Pl0040=1@N03oP000X23`0?n000h0X23`1P3oP000
0`2P8?00oh00ooooo`0?ooooo`003_ooool0F@3olnl0]hb50:MEA`3BIeD0hVUF0=QOC03BIeD0`6YK
0;J1N`32Vih0_I:I0<JAU`33R8X0ZW1^0:YjMP3`dll0g<g:0=?:c`2j]K`0dm3G0>cYm01mNHP0Hf1c
065NL`1=Bf00>3I;034_A@0_;D<0=cE;04=4F@1BDfP0EEQ[0493E@0g>DP0=3=1040lBP1;AE40C4A?
03le?@1XGf@0j]oS0?CUj03lg=l0ci660<AmH@37Pe80n[Yj0?o2M`3c[V<0ihe>0?69EP3/O5L0eFU?
0=IgI@31MFL0Wf]P07mNE@1IB400?SD^034Z900]9b40<BXT02lW900e;BX0:RDQ02`W8`0^9R<0<BTV
030[9`0b;BT0@3Hd04Lh=@1B>3L0GS@e07i2@P2jK6`0^5UE0=9[H03mW8/0ojnM0?nXU03lUH@0kGm^
0>enK@3XMfD0ffYJ0=ETE03LJEL0fVED0080hFUK00l0i6aN0>Q_I03QJel0h6eP0=EUE`3EIET0cUiC
0=1NE03?FU40deI@0=]LE@3OG580hf5D0=eIC@3PFTl00P3IDdX0<`3RFE40i5]C0>5HCP3MF4/0eUi6
0=1YAP2cHc80iK9a0>g<Q@38/Fd0^ZY^0:nUL029QUd0K6YA05QFBP17ADH0BdQ?04Y9D@12@DT0@T57
03Xi?P0_<3@0<c8g02HU:P0W:2X09bLY02/Z;`0/:Rl0;bXa02lU;P0/7Rd08aDT08]oR@3hk_H0iN3T
0>?Qi03Rh^80mOGe08V4Q@3Xi>D0NWIg0:fWZ@2j];H0]Zf`0=oFe`3Yhn<0jnGW0>STi@3ShN80gmoO
0=cNg@020=gNh00;0=gMg@3Rg=h0m=cT0<>:T`2JBE80bV5X0:i0@`2mG5D0X5Q<09YhK`3om>`06_oo
ool20?n000L0X23`1@3oP0001@2P8?00oh000?n0002P8?00oh0001@0X23`00@0oh000:0Pl02P8?00
d51h102P8?000`3oP000X23`0:0Pl0070:0Pl0030?n0002P8?00X23`00h0X23`0`3oP0000`3@D7P0
X23`0:0Pl00S0:0Pl0P0oh005`2P8?000`3oP000X23`0?n000030?n000`0X23`1@3oP0020:0Pl003
0?n00?oooooooooo00kooooo000>ooooo`1E0?oak02aQWl0ZeU=0=9WE`3SJUL0fF1=0=1UD`35Kf00
^8Al0<JLWP3R^;`0ai>G0;J3PP2MKF/0hK^h0>C?cP3Nd]@0c/C<0;Na^`3bkoP0/jnm05ICI01LFF`0
A41A07ahQ`2JUZ@0Sh^I092<V`2UX[<0Gea_05=@I@10?E00BTQF0:VW/P2QWZD0YZ6W0:nY[@2e[k40
^;:d0=;9bP3ajNL0l>CT0?[RhP3S[j@0/W9G0;YhAP3ZZfP0olMh0?VjJP3JQD80fWM00>1dC@3ILEH0
cWIR0:eUE`1_?C@0NUUB08IeKP1nMFh0GUM?03Xd;P0]:280:B@P030[9`0]9B80<RXW030X9P0[8b40
<B`X030[9`0h;R`0?Bd]04P^;`1J<380IbDY07dT9P2T>cP0k7U`0?V9N`3nU8@0oiN70?nBP@3kSG`0
oiF30?nLR@020?nNR`1E0?FBO`3XPg40i7YZ0=meI@3MLf<0g79T0=aeIP3KNVT0gX5_0>J9N03YRGT0
ihIf0>V5M@3VNVd0lH5e0?AlKP3eNFd0nGU^0?E`I`3WGUH0kfAM0?e`J@3aIed0jEmE0>5RD`3FIe<0
bW5C0;EaC02cQeX0Ug]<06iK<@1MD2d0CTT/04A2;@1>CT80BdY604I6AP12@DH0=cDj03@b=`0f=3L0
:2<W02/V:P0Z:2T08b4R02TY9`0W9bD0:BTY02XZ;00^:Bl0:R<[030T<P0Z72/0PWJ00?CZlP3WhND0
i=oS0>SVi`3YinP0ViJE08MnO`26OGh0akk1089iO013?Cl0F59D08EoP@2[YJT0a/340=SCe`3Qgn00
g]kN0=gOgP3Lg]d0gMgM0>;LgP3dfn80c9BO08XmA`3DK7D0[3m20;QGD02MEDT0VgU`0?oek00Joooo
o`030?n0002P8?00X23`00D0X23`00@0d51h0?n0003oP000oh000P2P8?000`3oP000X23`0:0Pl002
0?n000h0X23`1`3oP0030:0Pl0040?n0002P8?00X23`0:0Pl080oh001P2P8?000`3oP000X23`0?n0
00020?n000l0X23`0P3oP00V0:0Pl0D0oh0000<0X23`0?n0003oP0005`2P8?050?n000030:0Pl03o
P000oh000080oh00202P8?050?n00080X23`00<0oh00ooooooooool03_ooool000kooooo0600oo7/
0:YoN02XET/0e6UI0>=ZF@3FGDX0dfED0<9YE`3CVHd0Zgii0<>GU02hRhH0ZGih0:Z7P@3_dm00h<k>
0=K:cP2n/k/0hMOP0>kVl@1nN8H0FeMX059=H@0k=dP0`[_;0>cTlP3Vh>`0l>[h0=OChP1WHg@0BdIJ
02@P<@2XYK00n??j0>_VjP3/j>T0k>KV0>gWi`3_jNT0l>SV0>oWi@3bi^H0nnGU0?O;`P2bNV40/g=3
0=FFD`3nagD0o;m^0=b<A@3<K380gWM>0=MbE03=MV80ZfEI06De:`1B<BX0FDI007M/IP2AR840N71Y
04Dn>00d;2T0:B4N02PP7@0c:bP0;bLU02lZ9`0]:2@0<B`X03D[:P0n;2`0A2LY05LV:P1S61d0O1`N
0<MEE03YKFD0k79U0>QbI03[MFL0jG5Q0>iiJ03[NVP0l8Ec0?B=NP3eTWl0oiZ80?nHQ`3nU8@0oiB4
0?^AP@3mTh<0niJ40?^JQP3mXH`20?nVU00m0?nRT03oVh/0oIJ70?V;O03cOFl0l7AX0>UYGP3_JF00
k6=K0>aRF03bIE`0jEmE0>QRE`3KIUL0_f9@0:5I@`2:Ec`0K4P^054l8@12=Qh0ASl/04<o<`0j>S80
?Shl03Pj>@0b<S@0<c8g02PW;00W9BX0;2X_02PS9`0Y92P0:BDV02TU900V9B40:2TT02DU8`0S8b40
9R@W02DN9P0^8S00;1h]07U]M`3ejo<0i^3T0>COh`3^k>d0fmWJ08Z4Q029PGl0PgUj0<g4a`3Cb/d0
d/c>0;^e]`28PX@0;2HX03hh>P2KUIL0j>CU0>;RhP020=kPg`0;0=kNgP3Rg=h0lm[R0=:MY`25>480
fG5j0:`o@P2kG5H0VE=909mnM@3omN`06_ooool00`3oP000X23`0?n000050:0Pl0040=1@N02P8?00
oh000?n00080X23`00@0oh000:0Pl02P8?00oh003P2P8?000`3oP000X23`0:0Pl0080:0Pl0040?n0
002P8?00X23`0:0Pl080oh00202P8?040?n000h0X23`0P3oP00U0:0Pl0<0oh007@2P8?080?n00080
X23`00<0oh000:0Pl02P8?001@2P8?060?n000030:0Pl03oP03ooooo00oooooo000>ooooo`0T0?ob
kP2bQh00YUA90=EWFP3VJe/0gF1>0=QUDP3?KeT0ahEa08AEA@1lED@0Z8Ad0:f@P03C^jl0flS20>[H
f03>_/40c;_10?SYl03<`LT0GUIQ061IJ`1BCF40BDAJ07=^PP20NH/0QGj@08^4UP1gL880FeAV03Tb
@P15?dd0i=oV0>gWj`3YhnD0j^CT0P3/hn@0G`3]i>D0lNKZ0??Xk03fin`0nnGW0?oJd`2lRW<0]WM;
0<B4A03ka7@0nl5_0>6CB`3=L3<0gGQ<0=MdE@3>Mf<0YV5B06Dd;@1D<bh0CCPe04dn>`1KCDX0QGYf
0925P@1^IF00CdQ203H_:@0Z9Al09b8N02/V8P0/9b<0;bLT03DZ:00n:2X0AR8V05DL8P1U41L0TbT]
0=eSHP3^JF80lViR0>m]H03/JUd0kVYM0>eYG03]Jed0kFmP0>YaH03/M6<0kWIV0>ecI03`MVT0m7Y]
0?AlKP3^N6X0lWm]0?B4L`3hSG/0n8Yi0?N9N03iRgX0nHUk0?Z6N@3fOG80lWIZ0?=cJ03eLFD0mFaR
0?=YG`3bJ5h0kVAJ0>aVF`3SIEL0cVQJ08Lo<@1R<B80CblP04Ld9P0m<bL0<blT02l/9@0a<2`0;bl_
02//;P0U:B`09RL[02X[<00V9Rh09RH`02LT;`0X9Bd0:RP]02dX;00/:2L09bHR008092DP01P09BDS
02LU:00Z8bX0:AdY02XL:`22MX00mN_c0>KQi@3ShN@0l>k_0<o>c01gLG40KfMU07mgM@38_l00THR9
0;2WZ02`Z:H0aknm0;6YY`33^[/0fmGE0>CPh@3Ph>020=gOgP0;0=oOg`3Rg=h0lm_R0=>NZ023=T00
fW9k0:m2A@2kG5H0Ue=:0:J5O03om^h06_ooool00`3oP000X23`0?n000080:0Pl0@0oh0000D0X23`
0?n0003oP000X23`0?n0000G0:0Pl0040?n0002P8?00X23`0:0Pl080oh001P2P8?000`3oP000X23`
0:0Pl0060?n000/0X23`00<0oh000:0Pl02P8?00A02P8?0:0?n000P0X23`1P3oP0000`2P8?00oh00
ooooo`0?ooooo`003_ooool0H03omo<0aIjG0:9BB@3DJ5/0iVQI0=iMBP3KHTd0e6aC0<n4JP28ECX0
NE@i0;fOQ@3JaK00g<bm0=c=aP3Te=D0bkRl0>WDf@3A_/@0e/G=05U=E`1:@U40DDYL04m7G01HD6L0
GEIY069KK@1TFfh0G5=V04i5EP0V7R/0ZJ6/0?C]m03Zi>P0jnGW0>cViP3]i>D0knKW0?3Wk03/hNT0
knC/0?7Qj`3af^00on3J0<RJP`2iO500^WXl0?JnL@3oa7<0iIM=0<U_<@3KND`0dG1@0=1kIP2NFTd0
Hc@/050a;P1;=S<0CChk04Dg=01CAD80LVMS0966PP2AR8<0NG9/05E@BP0k<c00;RTU02XU8@0]9B80
=RPW03hV9P167200E1<I06X>4`2^?Cl0jFUV0>mWG`3dJUl0lfUN0?9XG@3bIE/0mFQN0?5WFP3`J5X0
lFaM0?9^G`3cKf80kFUL0>iZG@3]JE`0k6YM0>m`H@3YJU/0kW5R0>]aHP80kG9S04X0k71T0>]_H`3a
LfL0lW9W0>m/HP3eKf@0lfYP0?AZH03cIUd0lVEK0>mRF03WHED0hFIG0<QYG@1^<RL0AB0G03XV7@0^
8ad0;2TT02/Z:00V9RH09bH[02TZ;`0R9B`082@]020T;`0T:3<092Lf02T[>P0W9SH0;B`i02`[<`0Z
:2d0:RPY02TW:00V9B<09bLU02LW9`0Z9BT0;RL^02XN:P0]7b`0Sh>=0?O]m@3Uh>@0i>;S0?;ak`31
_K`0KVUX06EMF`2ESH/0d<O806MNG`1CBdT0=2`Z07adLP2]YJ<0`k^i0=kHf03Th=l0gmoO0=kNgP3N
h=l0h=kO0>7Kg@3cfn80e:2/088f@03JMGd0Z3/n0;1CCP2HED`0/9::0?oeka[ooooo0`3oP0060:0P
l0H0oh0000@0X23`0?n0002P8?00oh00302P8?000`3oP000X23`0:0Pl0090:0Pl080oh000P2P8?02
0?n000T0X23`00<0oh000:0Pl03oP0001@3oP0090:0Pl0030?n0002P8?00X23`04<0X23`00<0oh00
0=1@N03oP000103oP000102P8?00oh000?n0003oP0080:0Pl0P0oh004?ooool000kooooo05800?l0
0=Vh/`2NE4/0cVAG0>MYF`3PGD/0g5m90=a]DP3AOEh0ZW9?0;bFLP3A]YP0iMFl0=c@`P3Uf]H0bk^l
0=W4b`3C^/00R6me0>39d@2hYjl0D4A@03P]?@0a:3T0>2m2040gB@11>DP0@SM7040e@`14>TD0S8:;
0?3VkP3cj^l0lNS]0>oVj@3^iNP0kNOY0?K`m038`LT0SXJC0:BGZ02GRIP0]j>/0?oTg`3<WhX0^giA
0;Ed=03c^V/0olAc0>NIC`3@MSP0f7M:0<iaD039NfD0TUA705H[901<<2`0B3Hb04Pm=`18?CT0AS/h
044f=01DBDL0K69P08QoNP2DSHL0Q7]f06ENF016?S/0=bd[030P800k8B80B1/N05HA501h61X0beAF
0>YVHP3aIEd0lFAJ0?9XG@3_IEX0lVII0P3dJ5/0F03`IUT0lfYJ0?AZG@3_Ie/0lVYN0?1VF`3^I5L0
kfEJ0?5YG@3^IUX0l6UM0>aVFP3[IET0kVQL0>]UFP3ZI5T0kfIL0>mUF`3/HUP0kf9I0?1QF@3^H5H0
kUiE0>]KD03[GE40j61D0=mQD`3=KEh0JRhS03dH400d8A/0;bLT02TX9P0V9RP0:BX^02HV;P0Q8bl0
8BLc01dT=00Q:3/0:c=802T_A@0b=dd0>C]B03LiBP0U9c<08b<[02HU:P0[:Rl09RHX02LW:@0Y:B/0
:bH/02TR:P0`8bd0;1lY09R<UP3fkoH0iN3T0>CRh`3elO00ZjNV075/K01`J6H0Xi^I0>OQh@3Idm<0
fmKC0;bg]01eL6d0<bd]05mIF@33_kh0inKT0>3PgP3Ogml0g=kM0=kLg`3Rg>00l]cS0=RV/@26?TT0
e7=j09hf=`2]DTd0UeM>0;RKU@3omo<Jooooo`03003o003oP000oh0000L0X23`103oP000102P8?00
oh000:0Pl03oP0020:0Pl0030?n0002P8?00X23`00L0X23`00<0oh000:0Pl02P8?001@2P8?000`3o
P000X23`0:0Pl0020:0Pl080oh000P2P8?020?n000d0X23`1P3oP0060:0Pl080oh00@02P8?000`3o
P000X23`0:0Pl0020:0Pl0@0oh000`2P8?020?n000030:0Pl03oP000oh0000L0X23`00<0oh000:0P
l03oP0001@3oP00@ooooo`003_ooool0F@00o`00i/W509mID@3=Ie/0iVYN0>9MCP3PGdX0gfU?0=Aj
F@2lPU`0bJ9k0>37Z03Kbk80j]k@0=kAb`36][L0jmKM0=RmaP3;[k/0h/_E0?STk`3McMX0]JRi0:FJ
Z`2RVJ`0XYRZ0:2EY@2[X:h0_;2l0<k2c03_i>`0lnS`0>3Eg@3Qe]h0l>O/0??Zk`3bjo80m_7h09bF
Y01cK7`0OW:605m@H`38]<00on3L0<ZJQ02lOE40]WDe0?>hJP3o`G40j9Y@0=5h?03JNdl0bW5A0<In
J023Bch0BbHN04P`;018>C@0A3/f04]2?@10=c<0@3Hd04<i=`18?S`0Bd8m06MNF@21N7<0UHb708b2
P01hKF/0FdU704la<@1B8240E@d>08PQ8P3IGeh0kfYU0?1SF@3aHeT0lFAJ0?5WG03_HUP0m6MM0?9U
F`3`HeT0lfIL0?9UF`3dIeh0lFAK0080lfEK00@0lFAJ0?AWG@3bIE/0lFAJ0P3dIed02@3`HeT0m6MN
0>mRF@3bHe/0l65I0>mOE`3aHET0kUiE0?9OE`020>mLDP100>eMDP3YGe80hV9E0<i/GP1]<BH0?A/B
03HT800_9bD0:BT[02LX;@0_;cL0:B/g02T]>@0W;Cd0:C1303LoEP0mA5h0>d9L03a2G00k?eP0>3a?
02DW=00T92h08R4Y02TX;P0U92X08B0U02TW;00Q72<091XS02PK9@0`8bd0X9BN0?C]m03Tgn<0iN?T
0??_kP2MVIP0MW5`08f7Q`2`YjP0c/S80;Vc/`3Bb/P0bL6o0<6h^@2l][H0f]CD0>?OgP3Th=l0h^7O
0>3Ph03MgMd0gM_N0>;Lh03bg><0eZNa088lAP3FMgd0VSHf0:UDC@2AED/0`JFQ003o01[ooooo00<0
0?l00?n0003oP0001`2P8?060?n000030:0Pl03oP000oh0000T0X23`00<0oh000:0Pl02P8?00302P
8?00103oP000X23`0:0Pl02P8?020?n000X0X23`00<0oh000:0Pl02P8?000P2P8?070?n000<0X23`
00<0oh000:0Pl02P8?00?`2P8?000`3oP000X23`0:0Pl0020:0Pl0X0oh002@2P8?070?n00003003o
0?oooooooooo00kooooo000>ooooo`0G003o003afMD0ZVUS0<IUG03RIel0h5a?0=mKC03QJ5<0eWUK
0;5gDP3=Yh<0ekjO0=?3ZP3UeLH0bKZc0>7?c`3ZeM`0ckO40:R@X02[U:H0Z9>V0:6?Y@2PTZT00P2I
SJD0A@2FRIl0UhZN09f@XP1oLh40V8bH0?;Vl02`Y:h0PgF208AhQ02bZ;40l>Wa0?[doP39a]40LFen
079]P@1WGW<0D4=G0>_DhP3oemH0b8mk0<9nD@2oNST0n[ma0?fnKP3QTDP0fX140==fB`3:MEP0_7UV
07M5>P1=;2D0B3D_03ld<013>cP0BD4n048j=`0l=340@CTf04Dm>P0n=c40@c`f04@j>01ICdd0KV1M
08ajN02GOgd0TVm]08aDD`1o<Bl0Xc/h0>EZI@3[IE`0l69H0?9TF03cIeX0kF1F0?=UF`3bHe/0lfAL
0?5RG03aHUh0lfAP0?5RGP3dIF40kf1J0?5RFP3eIUh0l65I0?AUG@020?9SF`0L0?5RFP3bHe/0lF9J
0?9SF`3aHET0l61H0?5NEP3_G5@0lUmG0>mJD`3_Fe40l5aB0>mLDP3XGU40gemB0=5_H@1c=bd0?AXD
03PV900]9bT0;Rdc02d]=@0/;3H0;c4n034d@`0j?e80@DIJ04E9HP80@dMP02h0?dAJ03e2F00g>D`0
8R@a01`J9`0L6RD07Q`W02<R:P0O72<0;2L^03hg?P1CBE80KF1Z061CG@2OTid0lnWa0>?QiP3Rh^@0
l_3a07ijN@30^[`0Pgeo0<o9b@2TWYh0YijO0=C:b`3Gbld0fL[=0=oCe@3<`/40e/k<0>KRh@3Qgn00
gmoO0=kNgP3OgN00hmgQ0?7LhP3CXJ`0OSQ00=9hNP2H>cH0YUQ<08]EB@34[JL00?l06_ooool00`00
o`00X23`0?n000070:0Pl0D0oh000P2P8?000`3oP000X23`0:0Pl00;0:0Pl0040?n0002P8?00X23`
0?n000L0X23`00<0d51h0?n0002P8?000P2P8?020?n000D0X23`00<0oh000:0Pl02P8?000P2P8?00
0`3oP000X23`0:0Pl0050:0Pl0<0oh000P2P8?030?n002D0X23`00<0oh000:0Pl02P8?006@2P8?00
0`3oP000X23`0:0Pl0020:0Pl0P0oh000P2P8?020?n000L0X23`103oP0020:0Pl0030?n00000o`3o
oooo00oooooo000>ooooo`0F003o003njnL0/GI`0;aRF@3MJ5l0hF5F0=iOD03RJeL0dWML0;QoH@3T
_Ih0ilfb0>3>^03Ue<@0i]G=0=c:b03_g>00OFUe05a7F01LBE`0E4=F0511EP80C3iE04h0Ac]A04Pj
D01=@580Cd9C02/O;@2/X:`0m^[d07eaN`1QDf00JUiZ05U?FP3Le=l0lo3k092<V`1SH7<0IV5g040f
CP2?P9D0nn7]0?K3`034Pfd0_WM90<b7AP3o`WL0nkU[0=V6@03RQD`0cg=:0<EdE`2gN6H0Jcld04`_
:@19=c<0?38`03dh=00o>SH0@Sdi03hi=@0i=300>SDa03`g<@10>C<0?CDb04<h=P14=S<0C3Te06M;
B028G5/0ZVYX0:eHE@37G5H0i6QP0>aVF`3_HUH0l69F0>mSEP3_IEX0kF=I0>iUG`3ZIF00ifES0>MW
J03UI6P0j6QY0>UWJ@3/IVL0jV9R0>]QG`3^Hf00k65N0>iSH@3/HV00kF=Q0>]QGP3^Hf00jUmL0?1R
H03/GU`20>]MF`0g0>]KFP3^Ge/0kEaI0>YIE03]GUP0ieeC0>5QEP3@KF80N3`b03dJ5P0n;2`0<R``
02d/<P0`<3P0<30j03@d@00`<T40>Se>03LjC@0`<DH0<S=803@gBP0X:ch09BHh01lO;`0T8Rl0;R/f
048oB01JEf00JfQ_075/L`1eKWD0Mg1g07AZLP1TEf40>2/e0::FX03ck?<0hn7V0>?Si@3fm?D0O7]i
05MBE02;QhP0m_;c08J0P01RFEX0Ge=E05m@D`1PD5<0He=F04@h>02j/[00kNOW0>7Oh0020=kNgP0;
0>3Nh@3Rg=h0lMcQ0=2OY@21?440bg9d09<l=@2UH540Oe520<fj]000o`006_ooool00`00o`00X23`
0:0Pl0070:0Pl0H0oh006`2P8?001@3oP000X23`0:0Pl02P8?00oh0001D0X23`00<0oh000:0Pl03o
P0000P3oP00<0:0Pl0030?n0002P8?00oh0001L0X23`00<0oh000:0Pl02P8?004P2P8?050?n00080
X23`00<0oh000:0Pl02P8?000P2P8?030?n000030:0Pl03oP000oh0000@0oh0000<0X23`0?n0002P
8?001P2P8?040?n00080X23`00<0oh00003o0?ooool03oooool000kooooo05`00?l00?odlP2kQX00
]69G0=M[G`3VK5l0eee>0=m`G@3>NV40_HM_0=B^U`3I_JP0glRh0?;Od@3?_[@0akRc0>GGe`22LgX0
NVeg07IXM@1dIWD0LVId07EXN@1dIgP0Kf9c06aNKP1YFfX0Cd5>075UK`3ai^h0no7i0<6g_`1]HVX0
E4QB07A]M@3/i_00a<3>06UVM`1WHWP0EdmV03daA`3FaML0o=kX0>JWX036OVD0^7910>BPH@3o`gX0
nK=[0==k?03NOT/0cW9=0<MgG02_MF40I3``04P_:014=C00@3Hd03hf=010>3H0ACdj04@m=`0m=C80
>c<`03`d<@0k<c00>C4^040f=012<c00Ac8_058`;`1K:BP0JAlN08X/:P3DHE`0jVYQ0>YTF03bIEH0
kf5C0?5UF03]IET0j6EM0>EZI@3KJfT0_EEF0;9?E02aD5T0/U5J0;aDG@3BGV/0g61[0>ARK080iV=[
00L0hV1Y0>=QJ`3SHF/0hf5Y0>=PIP3VH6L0iV1Y00<0i5iW04@0if5Z0>IOIP3XGfL0ieaS0>MLG`3X
HEh0geiH0=5^H`20A3X0?AXF03l_;`0b;3009RD[02XZ<P0X:3009RH`02@T;P0W9c<08b8`020O;@0[
:SP0=3A003`lB01:B5D0HEiX06mZL@1mMWh0PW^207YcNP1/If/0Ee5E04e7B`0k=CT0=R`d02hT;@0Y
7bP0]Zng0?7/lP3ShN@0hn?S0?;blP2h^;P0@T110=3?c@3^kN/0dlo>0=_Ee@25NgX0/:BV0=72a@3>
_l80Z9bL0=K>c03Xi><0hMoP0=kNgP3Mgmh0gmoO0>;LgP3cgN40biRM08@o@P31KF/0TT8i09UNCP1i
E4@0e/O0003o01[ooooo00<00?l00?n0002P8?001`2P8?060?n000030:0Pl03oP000X23`00`0X23`
0P3oP0000`2P8?00oh000:0Pl0070:0Pl0050?n0002P8?00X23`0:0Pl03oP000602P8?020?n000X0
X23`6@3oP0030:0Pl0030?n0002P8?00X23`00d0X23`00<0d51h0?n0003oP000103oP0050:0Pl003
0?n0002P8?00X23`0080X23`00<0oh000=1@N02P8?000`2P8?060?n000L0X23`103oP0020:0Pl003
0?n00000o`3ooooo00oooooo000>ooooo`0G003o003omo@0bijH0:eSF03>J5`0h6mO0>=dH`3BKE/0
^W1N0>>eYP3O_k@0glBm0=g9`P3Ue<d0h=;?0>CHf03Wg>00gmGM0>3Fh@3Ne=l0g=7O0=oDi03LdN40
0P3Ndn<09`3Md>00f<_L0<Znc03@a]40iM_V0=oHh03VgnL0fm7L0<o7dP3Yhnd0k^_f08R4U@1SGW80
IUie03@X?P25M8L0onOg0?gDf03>RGT0bGeK0;eg@`3j^GL0okmh0?2UH@3INT80eWA50=5dDP34N5h0
YVmK05li;01;=2h0A3Db048h=`10>3H0?SHd048j=`15?SP0AC`g03lf<@0203de<P1<03Xb;`0l<S00
@34^04L_;@1B:b`0Fb<T06TG6@2I<c40gVMQ0>eZH03_IeT0l6AD0>mSE03]IEL0jFUN0=iWG`3RNGD0
Y4a:0:EIF`3HTYX0`gn:0;E^O02bI780aFQk0;=<G`3CIgH0ef]h0;M?FP2[AU40Xd9=0:Y6DP2YAE40
[DMB0:a4C`2_Ae80^E1N0;I=F`2gCU`0]DaJ0;a@G`2nCU`0`4aI0<U@F@3GFUh0gf=Q0=9_I`22AS`0
?AXF02lO7`0W8BD08b8X02HV;P0c<c/0=S@o040nB@1>C5T0GE]X065OK@1_KG/0MgF207ekQP1cL7/0
IV9Z059=D@17@DD0?3Hh038/;P0a:bd0;2HX02hX:P0^:2`0;2HZ02hT;00f;cH0blK<0>k/k`80h^;R
0P3UiND06P2i^KT0iNGS0>CSh@3/j>L0oOGc07Q^K@1XG5`0Og1c07Q/KP1^I6D0g=?D0>WUiP3Ng]h0
g^3O0=cNg@3Ng]h0hMgN0?CMh@35TID0RDE40;QWH`2BB3d0TEa<08EUEP3/h]T00?l06_ooool00`00
o`00oh000?n000060:0Pl0H0oh006`2P8?000`3@D7P0X23`0:0Pl00L0:0Pl0030?n0002P8?00X23`
00L0X23`6`3oP0020:0Pl0030?n0002P8?00X23`00d0X23`0P3oP00:0:0Pl0030?n0002P8?00X23`
00<0X23`00<0oh000:0Pl02P8?000P2P8?050?n000P0X23`103oP0020:0Pl0030?n00000o`3ooooo
00oooooo000>ooooo`800?l008h0f[>/0:MUF@38Je`0f6mL0>b7M@3AN6P0/7E/0>S8b@1nJFh0Pg9j
08EhP@2=PH/0Qgf609N?VP2ESIX0PWb:085mS01lN8T0OgR:07eeRP1hKh@0NW6607edR@1kLXH0MVj3
07I_P@1oN8X0RhBF08IoT@27P980ShRH09RAX@2UXK80V9>W06iVO@1[HGT0EdUP03`Y?@3G_]<0omo]
0>jg]03?Q6L0_g940=RHFP3o`GP0n[A/0>6>C03KMd<0g7M=0=1eEP39OVL0V6=A05/i;@1>=S80ASPg
03hb<P17?Ch0?38a044h=@16?cT0AChh04<l=011>S@0?SLa03/a;`0k<2h0@34^04T_<01A:2`0Gb4V
078I6`2Z?S`0iFQT0>mYH03^I5L0l6AE0>]SE@3ZJ5X0gfUO0=UcKP37Lg40LC@c0<fOX@3og^@0o=CM
0?[@gP3oe>D0j:Fg09I;G`31MH80Rd=?09iRJP3KZ:l0cj2V0<VGX033TIX0_hbC0;9oQP2YM7`0ZWEo
0:1[M@2KHfh0VV1/09IHI@2RFf/0ZEQW0;AFI02^A4h0d5iN0<i]J02:CTH0G3Te05a:BP1NF5X0H5mU
06IVKP1]L7T0LG5m06m^O01^KGd0KVeo05aKK@1BDF<0@d1A040nC00d<3h0;b/c02l[;00[9bP0:RHU
038^;@0]:BP0;RXY02/W9P0/:2T0:B@X02HP900n>3`0fMOJ0>c/k03QhN40hn?Q0P3QhMl03@3QhN40
i>?Q0>KRh@3QfML0kn?S0<bn_@2dY:@0/J>S0:^OX@2BRHX0hmgM0>CRh`3Ogml00P3Nh=l02`3Ph>00
hmgO0?CNh02iPH@0UTm=0:QHD@2PF4`0QeM909b2M@3nmO000?l001[ooooo0P00o`000`3oP000X23`
0:0Pl0040:0Pl0050?n0002P8?00X23`0?n0002P8?000P3oP00H0:0Pl0030?n0002P8?00d51h01d0
X23`0P3oP0080:0Pl0<0oh0000<0X23`0?n0003oP0000P3oP000102P8?00oh000:0Pl02P8?050?n0
00P0X23`103oP0000`2P8?00oh000:0Pl0040?n00240X23`1@3oP0090:0Pl080oh000`2P8?000`3o
P0000?l0ooooo`0?ooooo`003_ooool2003o000A0>W8`@2QIe`0ag1O0<mZF03ZRgT0^V]L0=2QV`2a
V9h0J5QS06YLJ`1XGFd0KF9b06MOKP1^IWD0K6Id05iJJ01PG6/00P1QGFh0K@1NEV/0H5M/061GK01Q
F6d0HEU/05aEI`1MEVP0HEY/06IOL@1ZIWL0IV9c06=OL01UHWD0J6Ej06MRN@1WGGH0JUYd040Z?`2C
M8H0omSX0?_6c03ESgh0bWeC0<Al@P3i^W<0ol1f0>nQF@3DMcX0ggI60>1hD`3FNeh0agmW09ETD`1E
=BX0BcHa04Dg=P11=CD0AC/l040f=@12>CL0@3Tc04Dn>01:@c/0@3Ta03L`:P0o=S40?S<_040a;P16
;2/0DbH[05lN8P1i7B00_Ti<0>a]I`3[HUX0lFEH0?1UEP3ZIUT0i6YM0=M_IP3=N7D0VEUI08QNG`3i
g=h0mMcP0?;Hh@3if^T0omW[09UTN02BFFX0R59P09EWL@3jfN00nMoV0?ONi03hgN@0nmgU0?oNi`3n
gNH0nmcT0?OIh@3bemh0lMKO0?3Bg03edMl0ml_L0?o8fP3o_Ld0YdMC0<9DE`3<KFP0STm8068o>`1/
FUX0GeUM05=CF`1<CeP0@dEA0412D@11@UH0?CiB03PiC@0j>dl0?3]=03XgB00h=T@0=34l038^<`0[
9bH00P0_:bX0300]:BH0;2PU02l[:P0/:2L0:BDV02/U9`0Q6al0E4mC0>GSi03Xj>P0hN7O0>?Sh@80
hN7O01P0hN7Q0>g/jP3Idm<0KfEV0<6c/`1nKVh0RWYj08alO@23MgL0SXF60>gYj03Rh>40hN7Q0=kP
g`3Ogml0h=kO0>GLg`3eg^40ZFi`0:EKFP2ZGED0WUiB07eFA`35/JH2003o01[ooooo0P00o`000`3o
P000X23`0:0Pl0030:0Pl0030=1@N02P8?00X23`01h0X23`00<0oh000:0Pl02P8?004`2P8?000`3o
P000X23`0:0Pl0060:0Pl080oh00202P8?000`3oP000X23`0:0Pl0030:0Pl0030?n0002P8?00X23`
00l0X23`1@3oP0000`2P8?00oh000:0Pl0020?n001L0X23`00<0oh000:0Pl02P8?001`2P8?070?n0
00P0X23`0`3oP0020:0Pl0030?n00000o`000?l0013ooooo000>ooooo`800?l001<0m][F0:AbJ@30
KEl0c6]J0=f0KP2PE4@0cZNN058g?01VDEX0G4aG05mBG01LD5X0Fe5J05Y@F@1LEEd0F55I05Q@F`1I
DE`0FU9M0080Fe1N0P1ICeX0M@1ME5l0EdmL05I>F`1JDUl0Fe=P05]EH@1IEV40F5IT05QEIP1MFG00
H5Q`06MGL@1J@UX0DC130>Nia03_[[80fY270=:3H038PTL0lk1Z0?ZhK03f[6<0k99C0=]f@03QM4T0
ggAB0=AiG03=QFd0UFID054c:019=S00AcTh04Hj>P10=SD0AC/j04<j>00o=c@0?cXf048m=`14?cT0
?3La03`e;`0i<2/0?Rl/04DY:01C9BP0FQDH07`N7`3@GUd0jVUT0>mVGP3^HUD0kfMH0>MYF`3NKf@0
cgE]0;ahM`1b@D@0c:nc0?cWk03af^00lmWR0?kOkP3R_</0Pe1Q09aYN01]AE00gl380?kWk@3cgNH0
mMWU0?gGiP3jc]d0l/;>0?C6d@3cbmH0lmCL0?KOi`3agNH0l=_T0?GIi`3he^H0omCU0?J/^`2F=T80
bE]N0=1^J`21@Sd0C2TW040`<`0h<cX0<C4m03<e@P0h>d`0>ceB0494F`19Bf80ADML0452EP11@500
?3Y7034`>00^:c80;R//02TU8P0_:RL0;RTV02/W900Z9R<0:BDT02hX:00Z92@0;2HV024K7@1QGEh0
k>[[0>CTi0020>;RhP070>;Th`3Ph^40h^;R0>SVi`3MfMX0/jZ]0=K:c0020:ZJV`0A0:RHV@2<P800
VYBD0?;^k@3Qgn00gmoO0>3Ph03Pg]l0hMgN0>GJgP3ffn40TeQL0:YTHP2TH5D0UUi?08EUF03Xf/l0
0P00o`0Jooooo`800?l000<0oh000:0Pl02P8?000`2P8?000`3oP000X23`0:0Pl00L0:0Pl080oh00
7`2P8?020?n000L0X23`00<0oh000:0Pl03oP000102P8?001@3oP000X23`0:0Pl02P8?00oh0000@0
X23`103oP0060:0Pl0@0oh0000<0X23`0?n0002P8?006@2P8?000`3oP000X23`0:0Pl0070:0Pl0L0
oh00202P8?020?n000<0X23`00<0oh00003o0000o`004?ooool000kooooo0P00o`00S03njnL0XGI_
0;5WFP3=LV00afYH0:]HAP3V/:P0WW9c08iWK01V@dT0HD9705Pk?`1A=cX0BS4d04lf>@1<=cH0BCDd
03h[9`11;b/0AS<_04Td;`1;<bl0CSHb04de<P18<300AB`_04@^<@18=3H0AcLj04@i?@18@T`0CD]I
05A?I@1NDVX0IeAZ044U=02OMgl0kKNe0<=jJ`3BPF<0c7i80?ZgL@3o_W@0mZaS0?FPG@3]R500lhAF
0>ajE@3JKdl0cgAI0<^4KP2YO6T0Ec/]03`Y8P10<Rl0@cPf040f=017?C`0@3Hd03lg=00m>3@0@C`h
04<n>P0o>S@0>c@^03T`:`0o<2d0ABTX05LV:@1J51H0QRLU0=QUH03/JfD0kFAJ0>mUF03/IeT0hfeQ
0=9`I`3?PW`0TUaL085NHP3gh^L0lN3V0?3Ki03ff^H0omg]09ieQ@2<GFd0O51M08a^MP3jiNX0ln3V
0??Li`3of^/0l[_>0;EeQP2THW00Zfeh0:5_NP2DL7X0j=7I0?7Pj03^f^D0l=SU0?OGiP3oe><0_fim
09Xd?`3JIfX0dFi[07m0>`1E<C40@C0f03li@`0f=D<0=SQ703XmD00k?E80?CmF04Y<H`12A5T0A4EG
03Lg@`0];3@0;Rdb02HT9`0Z9bL0:RHS02`X9@0]:BH0:RHS02PT8@0U7al0:bDU02/R8`0d:b`081XL
06iZJ`3bl?40i>CT0P3Rh^803@3Ri><0hN?R0>7Qh@3Rh>40iN7R0?K`lP3>`lL0O6e`09F7Q`2DR8X0
Ng5b0;6[Z`3^kN/00`3Ph>002P3Ng=d0hmgO0>KJgP3cemd0TEUJ0;9aK@2LH5D0RE]<09J0L`3lln`2
003o01[ooooo0P00o`060:0Pl0030?n0002P8?00X23`01`0X23`00<0oh000:0Pl02P8?007P2P8?00
0`3oP000X23`0:0Pl0060:0Pl0030?n0002P8?00X23`00`0X23`0P3oP0090:0Pl0@0oh0000<0X23`
0?n0002P8?006@2P8?000`3oP000X23`0:0Pl0080:0Pl0H0oh00202P8?020?n00080X23`0P3oP002
003o013ooooo000>ooooo`800?l008l0P?]k0=k5`02WLFL0_VmR0<e[G030EdT0jX]n0>>9P03USXL0
iiJ@0>BGTP3OUHh0gYJ<0=bERP3PWHh0gIn=0=^TS03JZXX0gk:>0>>gT03M[hH0dimg0<jHL03AUGD0
diIl0=BHP03EVhD0e:6@0<RQTP30YYd0iMKG08EkQ@1BAEP0HU5U04lf@P1cDU40ikbY0;J0G@32P4d0
eHm@0?:bIP3h/FL0l:1K0?>GF`3aR5D0lWiE0?1gE@3VK500gg1G0=9fG`36P6/0VfiK07QMC`1hIU`0
J5]E04a1?@0m<Rh0?C8_040e<P16>cT0@cXh04Dm>P14?3T0B40m03le<`10=C80@S0^04LZ:@1D8R@0
H1XI09Lg<P3NK6<0jFUN0>iXFP3/IUL0ifUL0=QaI`3?OWP0Y6YY07EBE03Pb/h0m>;X0>oMi@3cg>T0
o=o]0<VP/P2;H700Qem]07IEH03Ud=L0ln;X0?7Li@3if>P0l;W>0:YEJ@30Gfl0dgAo0<mnQ@2VJW40
NU5I0>W?f03dh>T0kmOT0?CEi03oenL0gIZY09di@P3AFel0gFIR0<m_J01g>cP0DRl`044`>00l=400
>CQ503XlB`0g>DT0=CM903loD@13@e@0?C]:03<b?00Y:2h09bHY02XY9`0V9B809bHR02PW8`0Y:2H0
9bHT02HU8`0Y9B@09b4Q02TP8@0_9BH0<2HY028K7@2BSHh0m?;c0>CRh`3Shn<0hN7Q0>;RhP020>?S
h`0:0>CSh@3ThN00mo;c0;^d]@1bJ6X0/JNX0;V`/P2OVIT0bLS60>KVi080h>3P00X0g^3O0>3Ng`3V
g>00jMWM0>[<d01kATD0]7ef08UMCP20HU<0bkff0`00o`0Jooooo`800?l000<0P<000=1@N02P8?00
1@2P8?0>0=1@N0<0X23`0`3@D7P20?n000030=1@N02P8?00X23`00<0X23`00D0oh000=1@N02P8?00
X23`0>QX?00<0:0Pl0030?n0003@D7P0d51h00h0X23`00<0oh000:0Pl02P8?001@2P8?000`3@D7P0
X23`0=1@N0040:0Pl0050=1@N02P8?00X23`0:0Pl03@D7P00P2P8?000`2h>;@0oh000=1@N0030?n0
00030=1@N02P8?00X23`00<0X23`00@0d51h0?n0003oP000oh000P2P8?000`3oP000X23`0:0Pl00H
0:0Pl0030?n0002P8?00X23`00P0X23`00<0d51h0?n0003@D7P00`3@D7P70:0Pl0030=1@N03oP000
X23`0080X23`00@0oh00003o0000o`000?l04?ooool000kooooo1000o`00R@3Wc/L0Xg=Y0;YZG`36
H5@0j6mU0>Y/H03XJUh0jg5V0>M^H`3XL680ig5S0=m^G03SMV40fgEL0=]nG@3KQUd0hiMV0>jYL03h
]WT0mkIf0>FTHP3?R4/0a7U00<AhA035ODd0_GmH08]M@`3F]ZT0aK6b05M:E01ODF80BSQ4050k>03`
dKd0d:Am0<nKHP3l_g`0ol1f0?JZH03/TU<0kHQB0?>4E`3`N5D0lG5F0>]YD`3XJEH0hg1M0=9eH`39
QG80QEM804hd9`1A?SL0JeiH08MlN02<PGd0L6EO044e<00l<Bd0@cPd04@k=P13>SD0ASdh04Hl>P11
<c80@Bd^04TY:P1E8R40IadJ0:]9@03ULF@0iVMH0>mZF@3[IUL0i6iP0=9hK`2kO7L0KDA20=:i_03h
ind0kMcR0?3Ki03lh>h0h;k<081AH@2LL7d0Hd9;0=O0aP3gi^`0k]gU0?CJi`3mcn00[Ue^0;aAH@3N
KWX0e7Ah0<MkO`1nC4l0c:ba0?cUk@3`f^H0lMGT0?oDi`3l^ll0W45@0<E@EP3TIfD0g6EM0<U_I01W
<RX0C2d[03/[;P0f;cH0=C@l03`jA`0i>DD0>3Q403dkB00m?4@0=34h02h/<@0V8R<09R8O02XW8P0_
;2L09B8M02HS7P0Z9R<09R8O02<O700Z9B80;B@U02/R8`0]8RH0:QlU02dR:030^[h0k^c]00<0h^;R
01T0h^;P0>;RhP3UiND0j>OU07A_K028OWd0ETY:07=UI02IRhX0Rh1n089hMP3Of]L0i^GQ0=oOg@3P
h=h0g^3O0>3Ng`3Vfml0jmSL0=Jg^01b@cd0[XAf07MLB@2=P6l0m?3W00<00?l06_ooool4003o0003
0?n0002P8?00X23`01L0X23`0`3oP0030:0Pl0@0oh003`2P8?050?n000030=1@N02P8?00X23`00T0
X23`00<0oh000:0Pl02P8?001@2P8?020?n000@0X23`00<0oh000:0Pl02P8?001@2P8?000`3@D7P0
oh000?n000050?n000<0X23`103oP0030:0Pl0030?n0002P8?00X23`01P0X23`00<0oh000:0Pl02P
8?001P2P8?070?n000T0X23`00D0oh000:0Pl03oP000oh000:0Pl003003o013ooooo000>ooooo`@0
0?l008T0ooSd0<NYX@2IFe00^5iC0>AZH03bJEl0kVAI0?M]HP3eKEl0lf]M0?E`H@3cL5h0lG9O0>M_
E`3TMEL0hg]F0>:3E@3TSeT0jIUL0?BYJ03m]700okMc0?V/J03]XV40i9iS0;f3D`2hSFd0mMS808Ye
M01SCeP0JUIQ03DP9@2NPgP0o]^o0>jkS03i_H40m[=_0>ZOF`3XSe00jX9?0?:1E`3_M5<0lG5F0>iZ
E@3aK5/0ifEE0>1]F`3EN6H0aX9_08EJBP1A=bX0BCP`04Tn>01=A3l0Jf9M08QmN@26NgL0DdQ403hc
;`0i;RX0?SD`048i=012>3H0?2h]044];P1?;Bh0EQhO070R802aC4@0iFmS0>Y[FP3/JEL0jfUK0=e`
I@3@PGX0RUEA08e[JP3ji^P0lN;W0?7Ni03cg>H0omo/0:J0S`2BI740Ne5M08mdN`3kj>h0l^7W0?;M
iP3df>H0lk[;098d@P3HJG80fFYa0=QnP02NFU/0REmQ0?SMhP3cg^D0l=SU0?CEi@3oeNP0cgjA09P_
?@3SIVX0hV5L0=]VG034L640Hc4X04HX9P0j:R/0<bTa02dZ<@0b;cP0>cU403Xh@`0n?DD0?CY103@b
=@0_:b`0:2@S02HR7`0Y9R40:bPS02LT7`0Z9b80:RDR02LR7`0U81d0:28R030W:00a9RX0;B0W02TL
8`0h;C<0elkC0>k/k@030>;RhP0I0>?Sh@3Rh^00iNGU0>SWi@2MV9D0UXb;09B6Q@2PTHh0UXN408an
N`2@QH<0jnKS0>OSh03Qh=h0gmoM0=gOgP3Qgn00j=cP0>kIgP38YZP0U6UR09ihJ`1[FDD0Yj:?0?ol
m@03003o01[ooooo1000o`020?n001P0X23`0`3oP0040:0Pl0030?n0002P8?00X23`0100X23`1P3o
P0090:0Pl080oh001P2P8?000`3oP000X23`0:0Pl00<0:0Pl0H0oh001@2P8?040?n002L0X23`1`3o
P00;0:0Pl080oh0000@0X23`003o0000o`000?l04?ooool000kooooo1@00o`00X`3ii^00YGU`0:5H
C`3HIUd0l6YQ0>ePEP3dIed0nFeP0?Q/G`3dJe/0mFeO0?IbH`3_KU/0k79K0>IcEP3TMeH0ih5I0>F6
F03WSE/0iHiH0?:OHP3fZfX0nKAc0?JjOP3O[gh0n=Rb0:nFP017;RT0DcXm04H^;P1E>380klVf0>Vg
UP3RWW40jYYU0>RAF`3XRU@0jh9B0>ihE03bMEL0kfeE0?1/E`3bJUX0kFQI0>UWE`3NJeT0e7MU0<^7
M023F4L0D3T[04Hh;`19@S`0C4A104Lo?@1;@d00LFMR09R=R@24NGD0IEYF04Hm>00h<B/0=R`Z03/]
;00o:b`0CRX/05PM7`1f9RD0^eA=0>Q_I03ZJ5/0jfUK0=mUF03GM6d0^GQf06Pl?@3</[<0nNGW0>oN
i03`gN<0o>;]0>6kbP1oE6D0WW9o060jA@3>]kl0m^G[0?3Mh`3df^D0nMWX0=fJZP2eBeD0gfid0=]b
MP37MgP0ND520<ZWZ`3ki>X0km[S0?;Hi@3lenT0olCH0:=7EP33CUL0ifEW0>ASG@3EI5H0_fmN05h_
9@139b@0>B/[03L/=00d;CD0=c4k03Tf?`0k>4<0@3e603/h?`0[:B`0:2@U02dY:00[9b@0:BHQ02PS
800Z9B80;2LT02`S900X7b009A`M02hU9P0b9b/0<2D[02/N9`0W6R<0Bd180>7Hg@3]jNX0h>3P0>;R
hP3Ri><0h>3N0>;Rh03Shn<0hN7O0>[Yi@3Tgm`0S8:009V>RP2FR8D0Vi2>0:>IU`2TW9X0Og]j0>7O
h03Shn<0gmoM0>?OgP3Wfmd0lM_N0;jKW02`QGh0Q69F06IFA`3>b[h01000o`0Jooooo`D00?l000<0
oh000:0Pl03oP0005@2P8?030?n000@0X23`00<0oh000:0Pl02P8?004@2P8?020?n000030:0Pl03o
P000oh0000<0oh001`2P8?020?n000L0X23`00<0oh000:0Pl02P8?000P2P8?001@3oP000X23`0:0P
l02P8?00oh0000@0X23`1`3oP0030:0Pl0D0oh00:@2P8?070?n000T0X23`0P3oP004003o013ooooo
000>ooooo`H00?l000X0iLS209QSF`35IEX0j6aR0>YVFP3ZHUH0lVQK0?=WFP3eK5`0mF]N0P3dK5h0
L03`KE/0kW1J0>I/E03ZMeX0igUH0>IlE@3VPED0iXIC0>6:E03QTUX0ei9K0=ZRL`3ogKL0dJbB0;R>
PP2aQWl0Zh1i0=f]W`3j`:P0eHi^0>F=I`3[RUl0kH=I0>]nE@3_NEL0kfmD0?5]F03aJUL0m6aL0?5W
FP3`J5X0jfMH0=mZF@3EMV80c8Ea08iQCP1D>R/0AcT`04@m=`17@Sl0AD0m04Q0?P16?C/0F4i<07U_
K@2CRHL0T8R5071XI@1>A480>R`[030J70158B<0FalQ07XY:030Ee<0iVmW0>QZGP3SJEh0gVmV0<aj
N022CU00TW9e0?WUi`3ag^80lMkT0??Ni`3mgn/0ZGj?09=WMP21FF@0UWMo0?[Wk@3ah>P0lMcS0?OI
h`3ofNL0_Fil0=IWKP3KKW40eWQh0:9NG@23EEL0m=WN0?;Ni`3af^@0mMGR0?oFi`3ARY`0VS0l0>9S
JP3XHV40hF5H0=IVF02fJUT0CbLK044Y9@0e:B/0=bde03D]>00j=3h0>cE103djA@0k>440<2dd02TW
:P0S8B809bHT02TU8P0V8R40:2@U02dX:@0/9RP202TP8`80;RDX0280<BP]034V;P0/82X07Q8L05]A
F@3Zi>P0j^GY0>7Qh@3Rh^80hN?R0>?Sh@3Ti>80hn?S0>7Qg`3^kN/0cLW806UTH@27OG/0NFi/085f
M01SFEP0Q7in06m[JP3Xi^L0i>CT0>3Og@3QgM`0j=cN0?GQh`2QPH40_iZA06mCA`1mLfL0k>WP1000
o`0Jooooo`H00?l00P3oP00F0:0Pl0<0oh000P2P8?000`3oP000X23`0:0Pl00G0:0Pl0H0oh00102P
8?020?n000D0X23`00<0oh000:0Pl02P8?003@2P8?060?n000@0X23`103oP00Y0:0Pl0P0oh001P2P
8?001@3@D7P0oh000:0Pl03oP000X23`00@00?l04?ooool000kooooo1P00o`009`3omo@0aJJQ0:US
E`3BK5d0h6YL0>MYF`3TGU80jF5C0>UODP3/HUD0l6AG0?AXF`3cJE`0lf]K0?=`G03aL5/0jfeF0>ac
F03/MEL0jGQC0>UmEP3XPeT0fg]C0=Z5GP3aYXH0lJZ>0?2XTP3cYiL0lZVH0?RZUP3QRG40h7iS0>]o
HP3^Ne`0jG9D0>mcE`3]KEH0kFQE0?5ZE`020?5XF00;0?M[GP3aIeX0kFMK0>5YF@3IN6D0cXEb095R
D01G>RX0BCP^04Hm=P19@Ch00P14?c`0B@16?cd0AShl044i=`1>AT@0Jf=Q08InN`2ERhT0RWak06]F
E@1@:BX0DaLI070O7P30EUH0iW1/0>5ZHP3NKfH0eWUb09mPH01L>S/0dkg00?KWk03^gN<0lMcU0?cR
k`3H]/H0MDUJ0:1dP`1N?DH0e;_10?[Wk@3ag^@0mM_V0?_Gh`3odMh0/UYV0=]^M03ELG<0b7Mf07U3
@`38YZL0o>G[0>kJh`3bf>D0n]CS0?o7eP2XDF40`4]D0>QQI@3WH5`0i6IJ0==XF02]IeH0AbDI03LV
7`0a:2T0>C8i03/e?`0g=3l0>SM2044kA`0b;3H0;BXa02`Z;`0X9RT09BDU02HT9@0W9BP0:2H[02TU
;00]9Rh0:b4Z02XP:00Z8BH00P0U7b<0800[8BT0<bTb02dV;P1cKW@0l>__0>KTi`3Rh^80h>3P0>?S
h`3Ti>@0h^;R0>7Sh03Shn<0l_3a0;Jb/`1cKFd0fLo@0=W?cP2OUI@0YYfN0>gYj03Kf]P0h^;R0>7O
h03Rg]d0hmgM0>SLgP3jinT0RFi/0;FMT@1SDdH0Z:6I1@00o`0Jooooo`H00?l00P3oP00a0:0Pl003
0?n0002P8?00X23`00<0X23`1P3oP0020:0Pl080oh00102P8?000`3oP000X23`0?n000040:0Pl005
0?n0002P8?00X23`0:0Pl03oP000102P8?070?n000@0X23`103oP00N0:0Pl0030?n0002P8?00X23`
00P0X23`0P3oP000102P8?00oh000?n0003oP0080:0Pl0040=1@N03oP000oh000?n000D00?l04?oo
ool000kooooo1`00o`002`3hjN@0TfUN0;1XFP35KEl0dVeQ0=Y/G`3LIUX0iF]L0>1PD`3RH580jfEI
0080kfMI02L0kVIF0?5YF@3^JEP0lFiJ0?9aF`3^LET0kg=G0>]dEP3ZMeX0iGQK0>=nHP3OOF80h7aT
0=eiHP3JMf80h7YT0>AfG`3XM5d0k79K0>i`FP3`KeX0kfaH0?5ZF@3aJ5P0mVeM0?5XF03bJ5/0m6QK
0?9XF`3^J5`0gfEF0=YeH`3APfl0Zg=T05hh:`1==2d0BS/f04Pn?012?CX00P13?S/0DP15?cl0@S`l
044k>`17?Sl0B40n05Q@CP1kKF`0WhJ90:QoP`2RI6L0SC/m0;mGEP3RLVh0ffiW0=MfK`2lLF`0Wg5a
0=:i_@3ahN@0kn3U0?3Li@3hg^/0omo^0:V2U02?H780Ne5O09EgO`3jiNX0ln;X0?3Mh`3efnH0omSV
0>2S/P2ZD5`0f71g0=ElOP2PFU`0PeII0?KIg@3fgnL0lMWV0?GFi@3oeND0h9JU09<_>`3QHfL0jEmM
0>IPE`3OIEP0e6eN0:9PDP108QL0<B8M02/U9@0^:c80<Rlj03Hb@00h=480?3I2030Z=00Y9Rd09R@Y
02PW;00X:2X0:2L/02HU:P0O7R@07a`U01lI8`0U7BP0<2Ta030Z;P0h<SH0CDI=05mHG`1bJg<0EE1F
08Z8S@3clO@0i>CT0>?Sh`3Rh^820>?Sh`0F0>;RhP3Qhn00hn?S0>[ZjP3MfMX0N79b05]BD`1GCTl0
M6]/0=?=c@3]jNP0i>?Q0>3Ph03Rh>40hMgL0>GLg@3Xg=h0o>[Z085ZI@2VUXL0IE]?0=kKePD00?l0
6_ooool7003o0340X23`00<0oh000:0Pl02P8?001`2P8?020?n00080X23`0`3oP0030:0Pl0<0oh00
3P2P8?050?n000D0X23`103oP00L0:0Pl080oh0000<0X23`0?n0002P8?002P2P8?050?n000T0X23`
0P3oP0000`2P8?000?l0003o0003003o013ooooo000>ooooo`P00?l001l0d/2i0;:@Q`2]OW@0[gEZ
0;UcI`2oKF40bFeN0==]GP3LKUd0hFaK0>Y_G`3[JE/0j6AE0>aWF03[IUD0jVEB0>UTD@3^JEL0l6aG
0>m]E`3`KeT0m7IP0?5gHP3_MV40kWMS0>mhI03XL5l0k7=R0?5dHP3aL5d0kfaJ0080l6]J06@0lf]K
0?5XFP3_IEP0mVYM0?5WFP3bJ5d0m6MM0?5TFP3bJUh0i6IH0=maHP3JOVl0]W9W06hl<`1F=C00CSTh
04Tk>P14?3X0@C/k048m?@11?Ch0@Sho048n?@15?cl0AD0m04<n>`16>SX0DcXn07M>E02XJVl0^FM[
0<MSH`3JLFd0dg1Z0=N4OP1k?ch0cZj`0?;Oh`3`gN<0l]gT0??LiP3ohO00fk;4085BIP2LKGl0Hce:
0=Joa`3ei^/0kn3W0?3Li@3egNX0o=?Q0:5QK`2hHVd0cWEk0<AiO@1d?3l0_ibP0?gTjP3af^@0lmOU
0?SFiP3ocmd0]UaX0;U6C@3ZI6D0jf1K0>=NE@3PJ5X0cfeP09IICP0e6Q<0:b0N02/V:P0Y9Rd0:BLb
038`?@0f=440=c=102XW<P0^:c@0:2D/02DR:@0V92T06QLN01lL8`0Z9c00>cQ105aGGP1^JG00KVU_
079]L@1_Jf`0JF=W05I@E014?dD0;2L]0:2NX`3clO@0hn?S0P3Rh^80603Shn<0hnGT0>;Th`3Ri><0
h^;T0>WYj@3bk^d0Y9nL04Lo?@1CBdT0a;bj0?7/j@3Sgmh0hN3N0>3Ph03Qgn00hM_K0>CJf`3_hN40
l=kL08IbJ@24N6X0RhMk0?Whl`D00?l06_ooool8003o0080oh00;02P8?000`3oP000X23`0:0Pl00=
0:0Pl0<0oh000`2P8?000`3oP000X23`0:0Pl0040:0Pl0030?n0002P8?00X23`00H0X23`00<0oh00
0:0Pl03oP000103oP0040:0Pl0<0oh001@2P8?000`3@D7P0X23`0:0Pl00?0:0Pl0L0oh000P2P8?00
0`3oP000X23`0:0Pl0090:0Pl0040?n0002P8?00oh000?n000T0X23`00@0d51h0?n0003oP000X23`
1@00o`0@ooooo`003_ooool9003o00230?odl03fiMh0k=7:0=Ze[03<WI<0`8Ij0;YfJ@2oLF@0a6aN
0<UYF@3FKf00ff]M0>=_H03VKUh0iFYH0>IYE`3VHe@0j6=B0>AOCP3^IUH0jf=C0?9]G03aK5/0lfiM
0?AaG`3cKUd0mW5P0?A/GP3fKUh0lFUI0?1XF03eJeh0kVAG0?9XF`3dJ5/0lfMJ0?5WFP3aIe`0mFQN
0?=VG03aJEd0j6UJ0>9/GP3NN6`0b7I[07Tj<`1M<Bh0E3Pg04hl?017?C`0B3m0044k>`0o>cX0@cdo
04Do?`13?Cd0@3Xj04I0@017>c/0CcHj05Xa=`1R8b/0PS0f0<MSH`3KLg00fGQb0;IUH@2:CTd0n]KH
0?SKh03hf^80n=WQ0?kJiP3oenD0YVn209MNK`21DEl0VgF00?gVkP3^gn@0kmkV0?3Li@3ih^`0l<oJ
07@lB@2ECeT0WEYQ07E1A@2=I6P0mM[O0?;Mi03cfN@0mMGT0?oGj03KVJL0VC4j0=mQI03ZH5d0jf9H
0>ATE`3EIEL0cgIX08=<@`0a6AL0:b4P02DS9P0[:2l0:RTa030]>00^:cH0:RLb02l/=@0`;C@0;BXa
03Dc>01;AT`0FUEK06mZL020OH@0PWn507EcN01UH6@0B4=703`h>@0f<S<0<2X^02dV;@0W82L0>C@j
0=?Ae03]jnh0103Rh^805P3Ri><0hN?R0>?Ui03UiNL0k^c]0;:^[@28Q840XijK096<R@2;QX<0h]kM
0>KUh`3Qh=h0h>3P0>3Ng`3SgMd0i][J0?CTi@39]k<0R7M[06]UE`3Ac/D6003o01[ooooo2@00o`05
0?n002P0X23`00<0oh000:0Pl02P8?003P2P8?020?n00080X23`0P3oP0000`3@D7P0X23`0:0Pl00>
0:0Pl0030=1@N03oP000oh0000D0X23`103oP00C0:0Pl0H0oh004P2P8?050?n000P0X23`103oP006
003o013ooooo000>ooooo`d00?l001/0ooG`0?_Vh@3^dl`0f;J]0<NLT`2iQg`0]GMZ0;Q`H@2nKf00
afiL0=1_G03FKEX0hViN0>Q]G@3[JE/0jFAE0>YRDP3ZHE40jf9@0>iUD`3/He40lVIE0?1TD`3dJ5T0
n6aM0?IZF`3cJUP00P3fJU/05@3cIeP0lVUI0?5XF03cJUX0lFMJ0?EYG03dJ5/0l6QJ0>YVE`3VJ5X0
i7AX0=akLP2<@ST0DahJ04l/:P13;R/0@C<b04Hl>`11>c/0?cXg04Dl?@0204@k?01=04<j?@11>cd0
@CDg04Tc=P1I<SL0H24Y07DS:@33Gf40gWEb0=YbK`2[CTT0]FUY0?o5a`3nbm80olgF0?o=f@3odn40
i:Nf0959E`2`JWD0P4]E0>W1b@3nhnX0lmkS0?7Ni03bgN@0m=oV0?KMh`36XjX0[hR>09IcM`2PQXT0
h<c>0?OTj03`fn80lmWT0?gGiP3obm`0YE=Q0;a8D@3[IFH0jF1J0>MSE`3OIeL0dVaM0<UkKP1[?CD0
<QhM02PO800S8B80;R`_03Hd=`11?480CDQ>05=>E01UH6@0KVU]07YfM`1mNGX0P7am07McM01WHf@0
F5=G040l?`0`;Rl0:BPV02@S8@0R8Al0:2@U02TR:@0^92`08aTQ06]TJ`3ako80i>CT0>7Qh@3Ti>@0
0P3Rh^805P3Ti>@0hn?S0>CTi03YinP0i^CU08Z6Q`3@c</0em7A0<S2`P2;QhH0e]GC0>KUh`3QhMl0
gmoM0>7PgP3VgMh0j=cL0?WYjP2CPGd0Qg]_089nM@3gm_46003o01[ooooo3@00o`000`3oP000X23`
0?n000020?n002@0X23`00<0oh000:0Pl02P8?003P2P8?020?n00080X23`203oP000102P8?00oh00
0:0Pl03oP0060:0Pl0030?n0002P8?00X23`00H0X23`0`3oP0060:0Pl0030=1@N02P8?00X23`00H0
X23`203oP0090:0Pl0030?n0002P8?00X23`00T0X23`0P3oP0000`2P8?00oh000?n000080:0Pl0<0
oh0000<0X23`003o0000o`001000o`0@ooooo`003_oooolA003o000I0?oel03ji]l0km770=VcZ036
V8/0]gmb0:m]G@2iKEd0`faL0=1YFP3LJed0iV]L0>iZF`3cJe/0m6]I0?EZE`3dJEH0lVMB0>aQC03/
Gdd0l6=A0>mSDP3]HE00kf=D0?=WF0020?EYFP0_0?=ZFP3aJ5P0lfYJ0?9VF@3fJUd0l6MG0>mWF@3^
JUd0jW1S0>]oLP2_Ed/0GAXA050O60107aP0<QXF03LX9@0j;bh0>30^040f=@13>CP0A3Xk04<j?@12
>C`0@cLi04`h>P1D;cH0GB4Y07@U:`31Gf00hGEc0=i^JP3=HEh0a6EQ0<YeM@3BPhP0ehZ@0>6DW03]
WJP0/5eW0;AGH@2nIfd0YEiT0?o:c@3odM@0o=?I0?cEfP3ne]h00P3mfMd08@3og>40omkR0?cMhP3k
hN@0oN;W0?_Nh`3kf^<0omOR0?oDhP3OTj00VcM30=iPI03^HV40k69H0>ARE03IJ5P0bg1N0;eiK01d
CdH0JE]H06YTI01`KVl0NGEf07ijN`20O7d0O7Qi07EaLP1ZIVL0FeMF04a8A`14@3l0?3Pg02XV9@02
02hZ:@0?02l[:P0/:bL0:RTU02XY9@0U92809R8S02HO9P0/8R/08aTQ09nIW@3dl_D0i>CT0>?Sh`3U
iND0h^;R00@0hn?S0180iN?T0?3/k@3>b//0Thf?05A>CP1]IfL0[ZZ[0>WWj03QhMl0h^;P0>7Qg`3S
gmh0iMcM0>_Og`3di>@0HU=>08j5N02m_;L7003o01[ooooo4@00o`050?n00340X23`0P3oP0030:0P
l0l0oh002P2P8?040?n000H0X23`00<0d51h0?n0003oP0002@3oP00>0:0Pl0030?n0002P8?00X23`
00T0X23`1@3oP0080:0Pl0<0oh001`00o`0@ooooo`003_oooolD003o001h0?ohm@3olNd0mN7J0>K9
`@3A[jD0^8Yn0;5/G@2oIeT0d6IH0>1XF03SI540k6YD0>]WD03/J4l0l6eA0>mYCP3eJe40m6UB0?5T
D03^HDl0kV5@0>eOD@3_HU40k5m>0>YNC@3[Gdh0kF5B0?5UF03`I5L0lVII0?9XF`3^I5L0lFmO0>Ye
I03FKeh0QS0Q064M401C8Q@0@alC03XO600[6aH0;B8P02lU900^92<0=B`]03/b<`0j<C80@3@f04/g
>@1C<3H0GBH/07@Y;P2oGf00gg9]0>=^I`3TJf<0jG9Z0>IeKP3OLg00g6i]0=QZJ@3?HF80b5MI0=i/
K03KKfd0_eeN0=^1P@3LRX`0gi2C0>2EVP3SVil0hY^Q0>RSZ03_[K40m;Fj0?Nna03ma/`0oLS@0?o7
d03ob=40ol??0>nO[02T?dL0aDiB0>]UI03]H5T0k6AH0>9TE@3DJeP0b7ES0:]cHP1cEd`0KFAO06=N
F`1HE5<0Ee5C04I2@`10?3/0=3<a02l];P0W9BH0:RTW02HU8`0];2X0;2PW02`X9@0a;BX0;b/X02dY
9P0Z9b809R<N02/W900/:2L09B4R02PR9P0Z82P0<b`c0<g8c03^k>l0hn?S0P3Shn400`3Ti>80hN7O
0>;RhP020>?Sh`0B0>KTi@3akNh0aKbo071WJP1XGf00Y9jN0>STi@3Uhn@0hN7O0>3PgP3Qh=h0hmoN
0>GMf`3bi^H0dL7104Hh=@2/Yi/0jn[V1`00o`0Joooooa@00?l01@3oP0000`3@D7P0X23`0:0Pl00P
0:0Pl0030=1@N02P8?00X23`00P0X23`0P3oP0080:0Pl080oh000P2P8?000`3oP000X23`0:0Pl00@
0?n000L0X23`00<0d51h0?n0003oP0000P3oP00E0:0Pl0030?n0002P8?00X23`00T0X23`103oP008
0:0Pl0040?n0002P8?00oh000:0Pl0L00?l04?ooool000kooooo6@00o`00B03ljn@0c:BJ0:9XFP2h
Je/0b6UG0=I/EP3TL5T0j71G0?1dF03_M5D0k6e=0>AQ@`3`JTl0kVI>0>mWD@3dJEH0lfYH0?=[F03a
K5T0lFaK0>eZF03aKU`0jFEF0>IRD`3SGTl0iF1A0>MRD`3SHE40gfIC0>QiI@2mFTL0TCXY06hV5`1O
91H0Db<G048N5`0_5Q80<a/I030L6`0/71`0:Q`K030P8@0c8280?2<V04PT:01I8RP0KR<W0;5BD03S
M6d0iV]S0>][H03aKf80l71T0?9cJP3`LFP0lG5X0>]ZI03^KFL0jFYT0>Q]IP3YLfl0hW9^0=ibK`3F
KVd0e6e^0<UUI`32HV<0_f5R0<1RH`2mIFP0`6]^0<UdN`80aWAj01H0c7Em0<MZM02fCUD0be=E0>YV
I03YGUT0kF1G0>]UF@3OIEH0cf]K0<ImK02MKUh0BCD[03Xe<@0d<2d0:bLV030/;@0Z9RL0;2PW02l^
;00W9R@0:2LU0P0[:RP04@0W9R@0;2/W02/W900^:RL0:BDR02hZ9P0/9b<0:2<O02LS800_:bX0;2PY
02XT:00O61l0HEYQ0>oZkP3Vi>D0i>CR00@0hn?Q01@0h^;R0>?Sh`3Thn<0l>c]0<o6a`1jL740WYBE
0<:h^@2SWId0[ZZY0>_Zj03Ogmd0hN3N0>;Ng@3Tgm`0i]kL0?O]j`2ISXX0Edi70<K4^PP00?l06_oo
oolI003o0080oh00902P8?000`3oP000X23`0:0Pl0050:0Pl080oh00402P8?0>0?n00240X23`00<0
oh000:0Pl02P8?002@2P8?060?n000L0X23`0`3oP008003o013ooooo000>oooooaX00?l006<0oo3Y
0;>HS@29H4h0ZFmK0;]`F@3=Le/0d6YC0>IhG@3QL580l7YL0?=jF`3eNU/0l6mB0>m]D`3/J540jFM?
0>Q/E@3UKUP0iW5M0>IcH03ULUl0jWMT0>UdHP3WKeh0jW9Q0>Q_GP3QJUH0fVEA0=][E`3KKUX0dfYG
0:Y9=P2>=B<0O2XL070]8@1A7A80Ba`F04@M600j6aH0=1PE03<I600e61X0=1@G03lE6@1?4QT0HQ<H
0:M5A03UM6h0if]Q0>e[G@3/J5T0l6aN0?5]H03_Jeh0kVQL0>mYGP3_Jel0kFQO0>i[H@3_L6L0k71V
0>ebJP3_MVd0jW5Y0>YcK@3[M6h0iW1/0>MaK@3QKV/0gfaY0>=_L03QKFh0g6QY0=mYJ@3LHF<0hVES
0>]UHP3_I5l0kf9I0>YPE@3YIET0gFMI0<eaHP36Q7H0OUI:040a:P0g<c00=cHd034_<00[:BX0;RX[
02TU900[9b@09R8O02TT8@0V8Ah0;BPU02TU8P0X9B000P0Y9R409@0V9B00;B/W02dX9@0Y9240;2HV
02XV9@0]:BX0:RDY028M8@2HUYT0mO?d0>;RhP3Shn40iNGS0>CThP3Rh^00hn?S0>CTi03Shn<0i^?T
0?O^k`2dZZT0X9:B0=32`P3;`L00UI2=0;Rd/@3[j^P0h>3N0>;Qg`3Th=d0i=oL0>[Rg`3]i^00Og]`
09BBQP32`[X02000o`0JoooooaX00?l00P3oP00/0:0Pl0030?n0002P8?00X23`01L0X23`00<0oh00
0:0Pl03oP0008`2P8?000`3oP000X23`0:0Pl0090:0Pl0H0oh001`2P8?020?n000030=1@N000o`00
0?l000H00?l04?ooool000kooooo6`00o`00?`3^iml0Xi6308Y]F`2DIe@0YfeI0;E]E`31KeL0_VM;
0=1bEP3NO5l0g7MI0=ieF03GJdl0f6iD0<mWCP38JE40`VYF0<IaG@32Ked0`g1N0<E_GP36L5l0bg9P
0=5fH`3@Lf40cG5L0=1dG`3<L5T0dW=M0==gHP35JE@0`FUC0;5LB02MD3l0OS/[06T[7P1H7a@0C1XA
04@E3@0n4@`0?Ph<040=301830`0DPL;05d31@2R>CH0j75[0>]]H@3[JE/0j6EC0>iXF03_IeT0lVYJ
0?1XF03_IeT0kVUJ0>iXG03]JEd0lViR0>m[G`3^K5l0lW1S0>m]H0020?1]H`050?9_I@3`KF<0lFiV
0?9_I`3eL6/00P3bKFP03@3^If<0lFQR0>mTG`3]H5T0lfIM0>iQE`3ZHUH0iVII0=][G@3@NVd0^Geb
05lm=00l<2/00P0d<c40700/:R/0:BLX02XV9@0X9240:BDR02/V8`0W8Ql0;BDS02hY9P0^:BD0:2<O
02PU800V8ah09b@O02LT800X9240:28R02lY:@0X8R80;RX[02lZ;P0^:Bd0a/C50>o_k`3Shn40h^;P
0>CThP3UiN<30>?Sh`0C0>CRh`3VhN80m>_/0>KJfP2UUiH0LVAS06MMF`2?RXL0i^GQ0>GTh03Ogmd0
hN3N0>;Nf`3Sg]/0l^gY0<_8_`25QgT0Ngma04o@C008003o01[ooooo6`00o`000`2P8?00oh000?n0
000Z0:0Pl0030?n0002P8?00X23`03d0X23`00<0oh000:0Pl02P8?002P2P8?040?n000L0X23`00@0
oh000:0Pl02P8?00P<002000o`0@ooooo`003_oooolL003o000m0?ObkP3RfM80`k:X09n8NP2BLEh0
U6]E09i_E@2ZM5X0/G=J0;1`E@2fLeT0[VeA0:i^D`2aMEd0^8Me0;jDQP2hT8@0/Xao0:j8N`2YPGD0
Y7Y/0:=hJ02VN6P0X75O0:5aG@2RL5T0YWAK0:A`F02WLEL0Z6iF0:Y^E02bM5d0/g5L0;1/F@2JDD00
RD0a07dd9@1g;B00KB0F06LI3`1W5`h0JA8;06d>2P1b1P<0Ub0J0>1TG03^KV<0ngU[0?AaG`3bKU/0
kfYI0?1[G03[IUL0kVUJ0>]VE`3]JEX0jfUK0>YXFP3]Jed0kVYM0>m[GP030>eYG00^0>iZG@3_Jeh0
kVUM0?5[H03cJV80mFaT0?1UGP3`IU`0lVEN0?1SFP3bIE`0kf9H0?1SF@3[IET0hVQI0=I_H03=Og80
XfeQ04d_9`10=380=C4`030/:`0c;bh0;BTX02/W900Z9R<0:BDR02`V9P0Z9B809b8O02/V8P0/9280
;BDS02`W8`0Z9B40:2<P02<O700U8Ah09b<R02TU900W8B<0:bDY02HP901<Ad/0iN?T0>SXj080hn?S
01P0h^CS0>?Ui03Rh^80hn?S0>CRh`3WiNH0`;^k09J=SP2IShh0WiBB09N<R02JThd0UiB?0=[Ie@3W
j><0hN7O0>7PgP3QgM`0i>3M0>o^j@2a/jP0SYB606]cIP1/kV/8003o01[ooooo7000o`000`2P8?00
oh000?n000040?n000L0X23`00<0d51h0?n0003oP0000P3oP00I0:0Pl0030?n0002P8?00X23`04L0
X23`00<0d51h0?n0003oP000103oP0070:0Pl0040?n0002P8?00X23`052@N0P00?l04?ooool000ko
oooo7`00o`00A03imN`0i=[>0<BdY02]V8L0/iZ60;ZKR@2lVhX0`j2=0;jNR@30XHd0f;f/0?SXg03o
m^d0oO?Z0?S^i@3bjN00l^GM0>gPf03[gM80j][=0=g;_@3?_:d0`jjM0;RST02ZU7l0XXMb09EiH`2A
LE`0SVQE09AVE02KIU@0XfQH0:MXE`2[J5P0Z6=C0:5EA`2LCT40W4Xn0:9:?P2[CD<0[4Dl0;I6>`3H
I5L0gfMI0>E[G03YKU`0kW1M0>m`G`3`LF00lG9Q0?AbHP3eLf<0lW1P0>m`G`3bL680lFmQ0?=_H03^
JU/0kFQI0?1[G03^JU/0kFUJ0>aWEP3^J5T0kVIJ0?9YG`3ZH5H0kfEJ0P3`HeT09P3aHeT0kf5G0?9V
F@3^HUD0k6QI0>1VE`3GL640bge`08mFB`1?:R80A30]03/`;P0d:RP0=BdZ02lZ9`0^:BH0;BTV030/
:@0/:2L0:BDT02hZ9`0]:2D0;2<T02/R8`0W8Ql0;BPU02`W900Z9B<09R8Q02HT9@0W9BH09b8V02/T
:`0L5A`0TXfC0??am03UiND0hn?S0P3Ti>@05`3UiND0hn?S0>CTi03Th^<0jNOX0<6n_P21Ng/0OGEc
07ifL`21NGH0NGIa06=RG@3LgMP0iNGS0>;Rh03Qh=h0h]kM0>WUhP3[jn<0X:>H069ZG@2>UX/0Noek
00P00?l06_oooolO003o00030:0Pl03oP000oh0001X0oh002P2P8?020?n002D0X23`00<0oh000:0P
l02P8?005`2P8?000`3oP000X23`0:0Pl0080:0Pl0030=1@N03oP000oh0000@0oh001`2P8?00103o
P000X23`0:0Pl01@T7P8003o013ooooo000>ooooob800?l01020oG/2083mNPl00?l00400Oo]g07_g
L`1glVh0M>iZ06oXI01UfeL0F]1:0=G7_P3@_K@0b[BY0<N[X032XiD0`9^=0<BHRP2mSGd0`HQj0<:2
M@33O6h0aGQX0<MdI037Kel0bFiL0<e/F`3AK5`0eF]K0=AYF03HJUX0ffYK0=]ZF@3MJeT0hFaM0>A]
G@3UKEX0iFaI0>M]F`3ZKed0j6aK0>a`G`3/KUh0kFiO0>i^G`3[Jed0kFaN0>i[GP3bKV40l6UM0?1W
FP3]I5H0jV5B0>aSE03WHe@0gfAE0=a_H@37KV00NC0T05PM4@198140?20@03DO400/7A0091/B01`H
4P0H5a806ATF0P0I5aP0500L6QX07ATI01hI700R71l09AlR024K7P0O61X08ahO02DS9@0X9b/0;2Xa
02/X<00b;cH0JfQ`0=cIg`3ShND0hn;T0>CRi03Vi>D0i^CT0P3Ui>80103Sh^00hN7O0>;Sg`3Rh^02
0>CThP040>GSh@3Uhn80hn;O0=kNg080hN7O00P0hN3N0>7Og03Wh=d0lngX09RDRP1^Kf@0O85g0>?V
h0T00?l06_oooolR003o00H0P<003`00o`000`20`000D91h08300004083000030?n0003@D7P0d51h
00L0d51h9@2P8?000`3@D7P0X23`0;Ph]0020=1@N1@0X23`00<0d51h0:0Pl02P8?005P2P8?020?n0
00030=1@N02P8?000?l000P00?l04?ooool000kooooo@`00o`00=@3on_D0ooWe0?oim@3omo80oo?_
0?o^j03jhmd0m]gF0?;Ec@3[cL<0g[Z`0=2UW037V900`9260;n;OP2kQWP0]W]]0;AeIP2hM6L0]fmQ
0;Y^GP2kKU`0_6]J0;m/G032JeX0`FID0<9UE034HE40b65B0<]TE@3=HeD0bUm?0=5QD`3>GDd0dUi?
0=9MC03EH4l0ef9@0=MRD@3BHDl0cV=A0;iMBP2UDCT0W5Dg081:901^Bb40HDDM04lm6@1iL5<0PgiZ
07ekK`1eM6l0P7ak0080NGEf01P0N7Ae07MbMP1]Jfh0MW9c07mkO025PH80ViRJ0:6PYP1bLW`0BdeI
04M;EP1:CUL0KG5j07AiO`1hOH<0SiBH09fPY@2`/KD0`<730<[:bP3JfML0jNST0>CSg`3Thmh20>GT
h00>0>CUh03Si=h0h^?M0>?TgP3OhM`0hN?N0>3Qg03Qh=`0hn3K0?7ZhP3Nf<`0@Sl`081nL@3Bdld:
003o01[ooooo@`00o`0>0?n001h0X23`4`3oP0070:0Pl0@0oh004@2P8?00103oP000X23`0?n0002P
8?0:003o013ooooo000>ooooodd00?l005D0P?aj0?oil`3om_80oo3Z0?gYhP3ihML0mMS@0?;Ab03`
bl80k/Jl0>Rn/P3V^:/0gZjR0=^ZW03IXiL0e9Z>0=FJS03BT8<0cHMk0<f5N@37OG80b7a_0<EgJP2n
Kf80`FmQ0;eZG034KUl0_FMH0<1XFP2jI5D0]V=C0;9UD`2^J4l0YfY;0<:FJ`35YgD0`:aj0<NjSP3Y
h;l0jnO>0>OSe`3Yi^40j^KU0>KQi@3Uh>@0inGX0>KTj@3Rh><0i>;U0>OUiP32`<40R8R903Tm@00R
9bd0;cHl03M0A@0jA4H0@Ta>04QBE01<EUP0CEMH05=KG@1AEUT0DUQH051DD`1`LVl0hnCO0>k]j03V
iN00i>CM0>CSgP3TiMd0hnCL0>3SfP3Si]l0h^GN0>7Tg@3Phm`0h>7K0>OTg@3Th=L0XinC04Q5=P2R
X9@0m_Ga00X00?l06_oooom=003o00030830003oP000oh0000`0oh004`2P8?060?n000X0X23`0P3o
P00:0:0Pl0@0oh003`2P8?00103oP000X23`0?n0002P8?0:003o013ooooo000>oooooeX00?l002<0
ooWe0?ohm03on?@0ooSd0?o`k@3ojN@0onKQ0?gQg@3lgm/0nM[E0?CEd03cd//0k/c30>c7_P3S_K@0
h;Za0=F_YP3AZj00bJFI0<2OSP2YSGD0[9Qd0<JiS@3Ab9d0X9]e0:JRQ@3Ge<40c<W00:JUX@2d/[<0
gmgR0=7?e02`[[<0^;Fl0;jk`P020>OUj00809ZHV@1dN7L0OhR504aGD`0c?c/0AE9;04EBB@16DdX2
04QECP0H04YFDP1?FUH0C5MC04UDD017DT`0BE190:b^Z@3Bdld0b<W10<W;`@39b/80b<_00<[=`P39
cl<0alg30<W?a@38cLH0a<W20<G8_`31a;/0VibD07YjL02;Rh40dm;=2`00o`0JoooooeX00?l0103o
P0000`3@D7P0X23`0?n0000G0?n00080X23`0`3oP0020:0Pl080oh003P2P8?00103oP000X23`0?n0
003@D7P20?n000H0X23`1@3oP0000`2P8?000?l0003o0009003o013ooooo000>ooooofT00?l001d0
oo_e003o003on_@0oo[d0?okl@3lln@0_KRN09ZGN02@Sg00HF5503Li8`2TYYP0_L2g0453@010@D<0
X:6U0<31a@0`=3L0@D9705]LH02LWIl0UYRG07anO@1/LFh0^<6l0:^d[`29U8`0T9bB09>OU@0209n[
X@0;0:2[X`2/]k40/;^e0:nj]02g`[`0_<O10;o5`@3Ae]00gn;K0=oPfP3Qh]X00P3PhmX02P3Timh0
i>[P0>GXh@3Wk>D0j^cW0>O/iP3]l>T0l??/0>kajP3dmo0=003o01[oooooJ@00o`000`3oP0000?l0
0?n000070?n000030:0Pl03oP000oh000080X23`0P3oP0020:0Pl0D0oh007P2P8?0=003o013ooooo
000>ooooofl00?l001<0O?ah0=gOe02//:40PhYj05QPD@1JI5T0IG5W030k=@0c?3T0D5]G0<;=b@0i
A400=D4o03e9A@17DT`0C5E@04I<B02QYJ80mOOf02X00?l06_oooom_003o0003052@N02P8?00oh00
00d0X23`00<0oh000=1@N02P8?00:P00o`0@ooooo`003_oooomb003o000>0>S_j03>eLh0^/Bl0:F`
Z02EX9X0Qi:>07J1O@2OZZ@0F6EN04]GD`18EDh0GFYS09jYX`3EfmL/003o01[oooooLP00o`0>0:0P
l2`00?l04?ooool000koooooN@00o`001@3/l>l0hnWW0=[Pg03Bf=@0f^3L02h00?l06_oooomi003o
00D0X23`;P00o`0@ooooo`003_oooon/003o01[ooooo[000o`0@ooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00oooooonAooooo`00oooooonAooooo`003_oooon/003o01[ooooo[000o`0@ooooo`00
3_oooon/003o01[ooooo[000o`0@ooooo`003_oooold003o00090?Gem@3Lg=X0_[jl09FET`1fMW@0
RH^60;Jh/`3GfMH0N?Qg06l00?l06_oooold003o0080X23`1@3oP0000`2P8?00D91h003o001^003o
013ooooo000>oooooc000?l000T0k^k/0=?Bd02^[J/0QhJ405eLFP0n?cX092DP01hO6P0L7AP00P0S
9Ql0100j?3L0J6UT0:VZY03PhMa]003o01[ooooo<000o`020:0Pl0<0oh001`2P8?020?n000030:0P
l000o`000?l006/00?l04?ooool000kooooo;`00o`004@3Ddm40GEaH03@c;`0O7QX0920M01dL600M
71L06aXE020O6P0P8A/08R<M01`M5@0K7QL07AlH028S7@1DEDl0a/O206`00?l06_ooool_003o0003
0:0Pl03oP000X23`00`0X23`0P3oP01/003o013ooooo000>ooooobh00?l001@0lo;`079^J`0Q7QT0
8b8M02DT7`0W9R409B@O028Q700R7aP09R<L02TV8@0S81/08b8M020O6`0T91l08b@N028U7P0m?cX0
YjVV0?KhmFX00?l06_ooool^003o00030:0Pl03oP000X23`00l0X23`00<0oh000:0Pl000o`00J@00
o`0@ooooo`003_ooool^003o000E0:FTX00_;2L09B8M02TV8@0V9B0092<N02TV8@0]:RD0=C0/03Xe
<@0i=300=C0/03Lb;P0f<Bh0:bPT02<R7@0V9b407R4J02DW8P1mOg`0j>[Y06T00?l06_ooool^003o
00030?n0002P8?00X23`0100X23`00<0oh000:0Pl000o`00J000o`0@ooooo`003_ooool]003o000G
0=3@cP11@3`08b8M02LT7`0U8Qd08b0K02XW8P0h<bl0>cHb048j>013>cT0>C4_03`d<@13>cP0@SXg
03lh=@0_:RH0:BHQ01hM600N81/06Q`I07UkNP3emoH0J000o`0Jooooobd00?l05@2P8?000`3oP000
X23`003o001W003o013ooooo000>oooooa400?l000`0j=[I0=6o_@3Ha/@0gL_90>GCd@3Zf=H0k]oL
0?KWi03mk^h0ooOe0?ofm03omoD?003o00050?3`kP1/KFP07AhI028Q700U91l00P0Q7QT04@0k=S80
?CPd03D`;@0i<Bl0>C0a03<[:@0g;B/0>c4_03le<`11>3H0@Sdi03dh=00U91l07AhI01/M600b=340
cLo>06P00?l06_oooolA003o00040:0Pl03oP000oh000?n000D0X23`0`3oP00?003o00030:0Pl03o
P000X23`01D0X23`J000o`0@ooooo`003_ooool?003o000f07c_K`2mWYX0M4@n06L^9`1Z;BT0JbdZ
06lc;@1/<R/0LCTd078m=P1oCDP0PUA@07mFD021FE@0Qf9N08MRG`2=JFH0RfUU095`J`2DM6h0VGUd
09QjM02OPG`0XhN30:J<R02/UY80[ibI0:jQWP2XXZ00KfaY02/X9@0V9B009B@P02<P7@0K6A@0<BlZ
048m>P0[9b@0;b/X02dY9P0/9b@0<B`X03D^:00b:bD0>S4/03Xb;@0k=bl0?cXd03`k<`0^;RT08R<N
02<T801TI680K^i]I`00o`0Jooooo`l00?l000@0D91h0:0Pl03@D7P0d51h0`3oP000103@D7P0oh00
0=1@N03XJ3`40=1@N0030:0Pl03oP000d51h00L0d51h0P2P8?030=1@N1H0X23`00<0d51h052@N000
o`00IP00o`0@ooooo`003_ooool>003o000g0?[Vi@2ML6d0MC4^08Lf<`27;B`0QRdY08<Z9P21:BL0
PB`Y07l/:01j:bH0NRh[07Xg;`1k?3D0LCH`06/b:`1X<B`0LC`f06Lb;01]>300KC/b0792>01_?SL0
K3/d0750>@1dACl0IcXd05H]9`119b004`D2024I5P0^:BH09B4N02HR7`0R7AX08QXG03Xb;`16?3/0
9QhL03Ha;@0a;2P09b@O02TV8@0Z9B40;BDR03<Y9`0g;RX0>3<]02dX900o?3L0@40h02PY8`0S8Qd0
8B0L096AS`1W003o01[ooooo3P00o`020:0Pl1T0oh000P2P8?000`3oP000X23`0:0Pl00F0:0Pl003
0?n00000o`000?l006D00?l04?ooool000kooooo3@00o`00>@3oknd0Z8:1070_;@27<Rl0R2TW08`X
:02F<2h0RBDS08h/:`2?<Bl0R2dZ08P^;@22;b`0NRlY07`f;P1g=2`0JBXS07Di<@1j?cL0Kc@/070g
;P1Y<bT0JCDZ06hg<01`>C80N44j08mFC`1l@c`0HRdW05/e;P0O2PD09a`H02hV8`0V8Ah0:2<P02DP
7@0R61H0=B/Y04Tn?00_9B<0>34[03Td;P0Y91h09b8N02HQ7@0[8b00;RHT03D]:@0i=2h09R4M03@a
;014A3`0<30X02<R7@0O7QX0@T900=SHeP1V003o01[ooooo3@00o`020:0Pl1<0oh000P2P8?060?n0
00030=1@N03oP000X23`01<0X23`00<0oh000:0Pl02P8?000`2P8?1V003o013ooooo000>ooooo``0
0?l003X0ooKe0;bFT`1Y;RX0RCPe09/l>P2cBdX0aUaL09de=02C;B/0V3He09hn?`2I>c/0W49108hi
=P20<B`0OcH_08a7@01c<bX0O40h08A9@@1oASl0MSlh07a7?`1d@ST0LC`f06`g<@1_=C40MCPc07Tj
=@1]<2/0L40h02hA2`0]6aL0;b@P02hV8`0Z9B809b8O02LM6`0_9R40A3Te040e;`0h;bP0>34Y030Y
8`0Y8Ah0:b<P02HN700Z8Ql0<BXU04Dn>00Z9B40>3<_04]8@`0_;RT09B@P02LV8P0V9R@0P81nIP00
o`0Jooooo``00?l07P3oP0000`3@D7P0X23`0?n0000C0:0Pl0030?n0002P8?00X23`0080X23`00<0
oh00003o0000o`00I000o`0@ooooo`003_ooool<003o000D0<JZY`1V;bX0LbDQ0:53@@2gCdh0_59B
0;U?C`2P>3L0ZDE30:I4A@2D=3D0U3Hf090e=02B>SP0QSLb07`a:`1d;bP0MCH_06X_:@1`>C8207Y5
?`0X08ABB`21CdP0LSdg07Dn>@1d=c@0LBdZ07H_:`1e;RX0PdDn04`O6P0j6A@0=QhJ03DV8`0^8b40
:b<P02dS8@0[8Qd0<2LR03`c;014>c@0?SD^034Z900_:280<RXW02LO700S6aP0>C8/048m=`0_:RH0
@Slj044n>@0Z:B@092<O02TX900Z:BL0;bh/071/K@2VX:00clW90?3[j6800?l06_ooool<003o01l0
oh006`2P8?030?n000030:0Pl000o`000?l006000?l04?ooool000kooooo2`00o`009`3B^K@0JC`f
06TP6P29<2`0ZdE10:Y1?P2X@3d0Xcdi09Hd<@2>;b/0RR`/08PZ:P29:bT0RRl/08`b<@27=S80KB@N
08Y9@`2JGeT0MChi07U6@P25E4l0REQC08YGD`2BGET0Qe1=08]?CP2@Cdd0Q3Xi084`;@23<2`0TT4m
084n>01F7aX0>a8<03XM5`0e8Qh0;R<O02/Q7`0202XS7@0J02/T7P11>3<0BT4l04U0>`0m=2l0?CH`
03</9P0b;BL0>cH`03dj<`12?cX0?S/f03@`;@0Z:BD09B@R02XY9`0T8b4081XJ01hD5@0M3A00@Rh_
075KG@27LG<0]ZBT0=W9b@1jm7AN003o01[ooooo2`00o`020?n000030:0Pl03oP000oh0001`0oh00
2P2P8?020?n000l0X23`00@0oh000:0Pl02P8?00X23`0P3oP0000`1@T7P00?l0003o001L003o013o
oooo000>ooooo`X00?l002h0imGA0799@`1O81T0OBPS09/g=@2V?S/0XSXg09`f<P2C<2/0RR/W08@V
9028:RX0Rb//08`]:`2;;2X0R2/[088]:01/8A/0TU5;0<F;Q`2[MW00U6=N099QG@2CHUh0Xg1/0:E`
K02JHV40TeMG09ABD`26?3d0RSHf08H/:`2G>CL0XDU708/m>@1N8QX0B1TC03dJ5P0f7QX0;b0M02hU
800Y8Q`0:b@N02dT7`0h;bX0AC`g0`17@3X01@17@S`0A40j04=0>@13@3/0;bhY0080:RTU00l0:bXX
02HR8@0V7Ah09a/M02<>4`0V2@h0?alR05hl?@1G=cP0BR`/04`c;`1gI5h0^:^S0=_@bP3ek>L0F`00
o`0Jooooo`X00?l00P3oP0000`2P8?00oh000?n0000>0?n00080X23`0`3oP0020:0Pl0T0oh002`2P
8?040?n000030=1@N02P8?00X23`00h0X23`0`3oP0000`2P8?000?l0003o001I003o013ooooo000>
ooooo`X00?l004/0/IFA068[9P1a91h0TC8`09li=`2S?C/0WcTg09<_;@2?;BX0Sbd/08h/:`2<:R/0
SBT[098Z:`2<92D0SbXZ08hc;P20<2T0KBPQ08Y=B02kQWh0_8Z309AQG@29EU<0/7ei09aWH`2ZLW40
VUiN07m1@P1_:b`0MBHY07`V9`2I=cL0ZdE30:Y;A`2K@cl0MRdW05DK5`156AH0?1hL03LT800c9B80
;R<Q02`R800b:2H0;2@Q038]:@0a;2P0>cHb040k=`0k=c80=S<^02`[9P0Z:B@0:BPT02LV8P0[9R<0
:AlN02XJ6`0d6al0;@`C03T@601<7b@0Gc8e08iTI@2AJfP0OE]B05ho<P1=<R40Fd4`06mHB02EOg80
`JnU0>?BbP3lknT0E`00o`0Jooooo`X00?l000<0X23`0?n0003oP0004@3oP0020:0Pl080oh0000<0
X23`0?n0003oP0002P3oP00R0:0Pl0@0oh00E`00o`0@ooooo`003_ooool9003o000a0?_Yi@23GUP0
IB8L08@[9`2O>CL0XSPh09P`;`2M=cD0VC<a09D_;@2@:RP0S2@U09@Z;02G:Rd0URPY09HU9`2H;2`0
TRlZ08Xa:`1l<B/0PD0j08eFC`2lRX<0aiBA08MDD@2RKf`0`Hj;0;InO`2JGf40YVY/0:YZJ`2WGf80
TT9508`c=02M?Ch0UcTi09<k>@2HBTP0PT4o05`Y9P0k5A@0?B4N040X:00j9RL0<b<S03<U900]8R00
<BLU03D[:@0202lU8`0M03<Z9`0c:bP0:RDQ02dX9@0^9R@0:R0O02dM7P0/5QP0>1TN03P@600d1@d0
CAXQ05XU;@1L:2`0LD5109Y_J@2[PgT0VGEQ091aE@22IDL0KU4c05Xo901@=Ql0EchZ06iIB02CPGD0
_k6X0>;Ec@3jkn/0D`00o`0Jooooo`T00?l00`2P8?0C0?n000060:0Pl03oP000oh000:0Pl03oP000
X23`2`3oP00J0:0Pl0030?n0002P8?00X23`00L0oh0000D0X23`0?n0003oP000oh000:0Pl01C003o
013ooooo000>ooooo`T00?l005D0fl:m06Df<01`8Qh0T34]0:4h=@2U=cH0W30`09T_;`2L<2h0V2XY
09LY:02J:RT0X2`]0:</;P2R:bd0WRLY0:D_<@2Q<c80RbPS09E0>`3]YZ00b8f7095OF03BWi`0ZgUh
070n?`3KYjT0e9fR06he>`2gOh80finQ0<R7R`2aKg40VUMH0;UcM@3ITiD0_Wam08i@D@1i?ch0Ld50
06Dm?@199bH0CR`]04PX:`15:2X0@bT/03dW:@0k9bT0=B<S03@R8P0c8b<0=BDV038R8`0^7Ql0<AhR
034L8@0f6b00>A@K03T>5@113QD0@``B05HJ8P1[;SH0J2`d06D^<`1T<380MTI20:9jKP2KNV40TgMB
09R0DP2JOe00WH1D09EhCP20HS`0Ke4_05dn8P1C=Ad0FC`Z079HB@2GPGH0`k6W0>?Dc@3jknT0ooSe
04h00?l06_ooool9003o01@0oh000P2P8?020?n000040:0Pl03oP000oh000?n00080X23`2P3oP00J
0:0Pl0030?n0002P8?00oh0000T0oh000P2P8?050?n004h00?l04?ooool000kooooo2@00o`003@2^
SHP0H2HR07dZ9P2L>3H0XcLe0:4a<02I:b`0VBPZ09dZ;@2Q;Bh0Z3@e0:@];`2V;S000P2Y;S00B02Z
;c40[C<f0:Lc=02O<C00Q28Q0;QUH@3b[JP0cI:>0:1YIP3GY:<0TV1S0=JSZ03a_<80JcHl09=JH03O
Y:P0/7=h0;^0PP2PJF/0l;Vl0?S1a03`_;h0gJ^/095QH@3<X9l0l<[90;bHV01M=ST0EC4c050]<@10
82D0B2P]058b=`159BP0@28T03hQ8`0j82@0>ahS03XK8`0d4a`0>aDP04<E801841/0C0dH05<@6@1T
8BX0Lc0i06d^=P29CED0L3Tn06Te=`1G9b<0Ne=90:N7K`2>M4l0SGE5095jA02EO4@0WH9;0:63C`2S
Q5D0WGaA09=aB`24Hd80JT/^05Tm9@1:<A/0E3l/075PD02DQ7L0dlNo0?[bkd`00?l06_ooool9003o
0080X23`5`3oP000102P8?00oh000?n0002P8?030?n000030:0Pl03@D7P0oh0000L0oh005@2P8?00
0`3oP000X23`0:0Pl0020:0Pl0h0oh000P2P8?020?n000030:0Pl000o`000?l004X00?l04?ooool0
00kooooo2000o`00G01lmG@0PU]F06<T7`28<S40XS/l0:<f>@2M;2h0VBH[0:0/;`2i@TH0^D150;e4
B@2nATP0]cm10;4i>`2Y<C<0Zc<e0;Dj?P2b=cX0[SLi0:@a=02<9R@0Y4a:0>^RW03<S8X0`8R70=FS
YP2lRhl0jkW2099OJ01N9bd0bi:H0:]`MP3<U9L0VVMY0?2n`@3Z^K`0UFMY0;jDU@3[`l<0nMKD0?SI
e`3Xb/P0QFEV0=2`/`3H^;d0Z8F;05`c>`1L;CD0H2le05LY;0177R80?aLN04/P:P1862H0A0lO054F
:01I5RL0J1/[07TV=P1n;ST0OC4k07Pe?01`=C/0Yg9h095PI01gATT0JC/k05dd;P2HMV@0YX]]091i
C`2;MD<0TG]209J0A02DOT80UGe109UnA`2RQe80YheJ0:>9F02RQeX0TWU@085W@P1^E3<0F3hS05@l
9`1`GDl0XHn50<Vj/`3Xf]L0o_CbB000o`0Jooooo`P00?l000<0D91h0:0Pl02P8?00503oP0020:0P
l0@0oh000P2P8?00103oP000X23`0?n0003@D7P20?n000030:0Pl03oP000oh0000<0oh0000<0X23`
0?n0003oP0003`2P8?020?n000<0X23`0P3oP0000`2P8?00d51h0?n0000?0?n000040=1@N03oP000
oh000?n00080X23`B000o`0@ooooo`003_ooool8003o001P06gSH@1[?3H0LR/W09@i>02M=3P0WBlb
0:Xi?@2K:Rh0[3]10;M8CP2Y>3h0^dQ=0<AAEP3JIVT0iW9c0>=/L03BFEh0d5EJ0<a?E@33ATX0_D95
0;E1@P2O>CL0WTE10=F7P`3WYZ@0nlG50<BCU`2RLgT0kK_40:aiP01kA4X0]Gb30>>Z/02gPH<0fZV/
0>k2``3DZZ/0QEmN0<2NW03ohn40jLg:09f1OP25JFP0l]CF0?SKg`3mg><0h[W109MXL01iATd0Kci2
09]aM@2aQi00HSA108=>H031QY`0Xf9h0;edR02?>Tl0W45C09Q0CP26=Ch0Pca20:U/L@2XLG@0Xg5d
09IVIP2EIfL0V6aY08QSF02iVXD0YH]Z08aeB`20JCL0RW@k099i@02FO440Vgi409]nAP2NQ4/0VGm6
09j3C02URUD0ZXiL0:^?H02WRV00RF]806E;<01K@R`0CCHT05U6>01_GE<0WY270<Vo]P3XgML0o_G`
A000o`0Jooooo`P00?l000<0P<000?n0003oP0002`3oP0000`2P8?00oh000?n000070?n000060:0P
l03oP000oh000?n0002P8?00oh000`2P8?050?n000040:0Pl03oP000X23`0?n000D0X23`00<0oh00
0:0Pl02P8?000P2P8?001P3@D7P0X23`0:0Pl03oP000X23`0?n00080X23`103oP0060:0Pl1<0oh00
0P2P8?050?n004@00?l04?ooool000kooooo2000o`00E01Gb4L0Jc0/08Da;`2K=cT0WS4d09d^=02V
=cd0WC@h0;EBE@2lHFH0^5eR0:m<D@2[A4L0[T540;i@D@3FHfP0fF9X0>I/LP3SIV`0fEYQ0=IIG@3B
EeX0aU9C0;I=BP2UAT@0_fi[0?6a/@3obld0V6MZ09IYK03gb<h0dYnT09=JH@2TIFd0Xf=Y0<NEV03Z
`<40`ifL0<ZYY02GN7<0k=3<0?kUh@3OalD0ZHb>0>O:cP3jgn@0]YVN0=fna03T`LL0ID550:j:SP3@
/;D0jLWB0;bHYP2@HgL0k[[A0=bR^P3CSjH0`Fn60:17F`2WC5d0PR`g0;1SJ`3>S8h0Y6QX0:ifM@2P
JVX0VFMV0:=cK`2IKFH0ZH=f0;VIQ02aTgL0OF4l05Pk4@1aCb80PEd]08aS=@2GKch0WWY809mnB`2O
P4X0WX5909j4B`80WhI=00h0YHeG0:F=G@2PQeh0UG]H07]P@`1RARh0C34L04L]701G?Bh0Lee@0:2<
P`3<^k<0j]gG0?gdkd000?l06_ooool8003o0003052@N03oP000oh0001T0oh000P2P8?020?n00003
0:0Pl03oP000oh0000@0oh0000@0X23`0?n0002P8?00oh00102P8?020?n00080X23`00@0oh000=1@
N03oP000X23`103oP0000`2P8?00oh000?n000030?n000030:0Pl03oP000oh0000<0X23`5P3oP003
0:0Pl0@0oh00@000o`0@ooooo`003_ooool8003o001X0;nRX01g<2h0U3Hf09X]<02^>d00]T570;i?
E@2T?D40ZTiA0>jOY03o^[l0ji:F0=]lP03=JVd0^eUJ0:U4B02Z@DH0]4E;0<AAF03=F600fF9X0=YQ
IP3JHfD0eF=S0=5UH`2kG5X0_Vi]0?Nc/P3k_kl0S5IF0;5mO`3odMD0m;g309ULH`29Ad`0S5AG0?K8
b02kUI80/I:=0;ZKUP2cUi<0nN7M0?;Jf03Qa<H0e;Nk0?oRiP3?/[H0Z8^?0??Df@2INgd0h/G70?oU
jP3VbM80omk/0<NM/@2bQIX0f:Bk0>Z_a@3VW[@0WTaR0:M@H@2>>4D0Xe9K0<QmPP2MFEX0^7Qh0;1c
LP2^LW40Zg5_09eWHP1nCT@0ZGma0<bWU02_Rg40NePh06U17@1lD2T0Oe8Y081A9`1oE2T0Qeh`09=]
?02KMd<0XhA=0:B7C@2MPdH0Xh]=0::<DP2ZTE/0Zi5P0:R=HP2TR640UgYJ089TB01YBc40ESXT04D/
5P0m9Q@0E44b07ESE`2OT8T0bKjh0>WPf`1onWTl003o01[ooooo2000o`000`2P8?00oh000?n00008
0?n000030:0Pl03oP000oh0000X0oh0000<0X23`0?n0003oP0000`3oP0000`2P8?00oh000?n00005
0?n000030:0Pl03oP000oh000080X23`0P3oP0000`2P8?00oh000:0Pl0020:0Pl0060?n0002P8?00
X23`0:0Pl03oP000X23`0`3oP0000`2P8?00oh000?n000090?n000030:0Pl03oP000oh0001L0oh00
0P2P8?030?n000030:0Pl01@T7P00?l003/00?l04?ooool000kooooo2000o`00J`2[PX00Pbha09hd
>02T;cD0^Ci30;XoA02h@dT0/4I:09Di?P3IS980mZ^`0<1YK`35JVl0fH>40=^;S03SUi/0d8660;eS
JP2RADd0WSe40:]2B@2lCE@0aEAH0<MDE`3@GUh0dVAS0==[JP3GNGL0nZJT0=jBTP2]IV@0diJE0?oI
g03lbll0[G1e08Q8B@2jP7l0llS20:>0NP3;[:L0_:2L0>;:b03B^[X0fK^m0>K6b@3Ta<L0omoS0=jk
_`3`cM40eKNg0<nb]03oinX0`jF[0?oLiP3AZkX0[HBF0;Z?XP3EY;L0o<7E0;=^P@28>D`0S3Q808Hb
?`2@?dH0QSLj08dn@@2/H680[fEV0;=YJP2kMG40Xf9L07Y1=P2nSgl0bIn90:R0IP1mEC80L4HP08=C
:`27ERh0Q5<[08MF;P24D2/0QUD]08QK<@2GKT00[8QD0:V<D@2USDl0Y8m@0::>D@2PSED0VhYF0:2;
GP2QRf80Xh]U09j6H02EOET0NF4o06I=;P1>=1T0?B8=03hT4`1C?Bl0TH5g0=36_@3]i=d0oo[d00l0
0?l000h0jNST0=CCc`33`[h0YjJR08^:R01/JfL0IF5P06=RGP1YJ6@0IFAO069SG@1fMg40]kRc0>WY
ia`00?l06_ooool8003o00d0oh000P2P8?0:0?n000030:0Pl03oP000X23`0080X23`103oP0001@3@
D7P0oh000:0Pl03oP000X23`00L0oh0000<0X23`0?n0003oP0000P3oP0001@2P8?00oh000:0Pl03o
P000X23`00@0oh000`2P8?0V0?n00080X23`0P3oP0000`2P8?00oh00003o000>003o0080X23`2`3o
P0000`2P8?000?l0003o000J003o013ooooo000>ooooo`P00?l006h0UV=R08l`=02T<CP0]SY20<90
B02d<cP0^Ci30;54B@2H?3l0hIZN0>6PY02?AdX0YUaM095;B`2CEUD0ol[:0<jFU`3<RX`0ei2F0>VL
Y03>Lg`0bVE]0;]>E02eA4P0_D];0;Q6A@31Cdh0aEUG0<aXJ039Jf/0aVi/0:iPGP3NXjD0omWK0=jS
Y@2/HV<0XEYH0=VOV`3V]k40f[F_0>S9aP30XZ00jlg=0;VGV03T`<@0e:fb0=2VZP3d`LH0lKg10?g<
c`3]_l40omSI0;68R`3O][h0h;K00:=iQ@3fc=X0h[C10=bW]`3LWjl0VE9T07ha@@1k;CX0ORhg07TZ
;`1k;2l0TD5408<a=@2MBdd0Z5=E0:9DD01_:R<0S5960<>DPP37WH@0Y7eL07iH<@1cBAl0MdXP07U:
801nCBD0QDl[08E?;@24Cbd0N4HQ081@:02ILD40ZHYA0:Z@D`2TT5<0XiAI0:JKH`2QUF<0WI1S09V:
G`2NSF80WX]Q09j8G`2RRV@0VX1M08]aD01hGD00IT`c03hW4`0f9A<0D40`07Y/G`2XVi80dlW00>oV
h@X00?l00180MOEd07AeL018Ad80<S4/02HU8@0_:bP0<Rh[030/:@0a;2T0>CDb03Tf<@0g=2l0<S8Z
02`/900_;RT0CDa8092@SP3De=8J003o01[ooooo2000o`0A0?n000030=1@N03oP000oh0000h0oh00
00<0d51h0?n0003oP0003`3oP000103@D7P0oh000?n0002P8?040?n000<0X23`2@3oP0000`2P8?00
oh000?n0000L0?n000030=1@N02P8?00X23`00<0oh0000<0X23`003o0000o`002000o`000`1@T7P0
oh000?n0000<0:0Pl080oh0000<0X23`003o0000o`006000o`0@ooooo`003_ooool7003o001d0?WW
i@24B4H0V3<g0;4j@02o@4L0`3Y30;`f?`31@TT0]dU<08Ta<03_/k80lLC10:]jMP1mBTH0HC8/0<NL
U@3ogML0k<W307I9B03N/K@0om?I0=F8TP3TQi40lXZA0>n2Q@3RMWH0dVAS0<IHE`2lCTd0_E1C0;mE
E`38H640[De>09=1@`3XX:<0o/C70==oO`36KV`0/V=N0=NDS03nblL0omWC0<>LU`3BZZP0iKfn0;B:
SP3Z_L@0`X^A0=V>U@3TSiH0jYFJ0=V7R@3?QH@0ijVX0<2<SP3kb]00]8F=0<JDW`3f`/h0_XRE0=VQ
[03VZ[H0YfUd078c?02SHVX0ZfU]09=<DP1k;S@0Pc8h08df?02A=3P0T3Hf08Pg=01`;2<0TUe=0=2V
SP2kV7P0XH5H08i_@026IC80O5PV07aD8`1fAad0MD4L089::@25BR`0PTHZ08189`2<GC<0WWQ70:Z?
FP2STU`0[jE`0:>MK@2ETVL0VYI`09bFLP2LU6l0VY5Z09b>I`2LSF@0WH]S0:2=I@2OS6@0RWA?06I?
;`1@>AX0ABdA03PO2@0k9180F48d07QVFP2YVY<0d/O10>kWh@3lnO@5003o000904G5@`0I6Q@07A`G
02<P6`0X9B00>cHb03hi=P0j=C80?cLd0080Acll00P0ACdj040k=@0l=c40>cPa034^:@0M71L0<C0[
0<72_AT00?l06_ooool7003o00030:0Pl03oP000oh0000T0oh0000<0X23`0?n0002P8?00203oP000
102P8?00oh000:0Pl02P8?090?n000040:0Pl03oP000oh000:0Pl0D0oh0000<0X23`0?n0003oP000
0`3oP0020:0Pl0<0oh0000<0X23`0?n0003oP0000`3oP0020:0Pl0X0oh0000<0X23`0?n0003oP000
203oP0020:0Pl1H0oh000P2P8?030?n00080X23`1@00o`000`20`000X23`0:0Pl00?0:0Pl0030=1@
N000o`000?l001L00?l04?ooool000kooooo1`00o`00M`3La<80OSXg0:4g>`2g?TD0`DA<0;/lA@2o
@4T0_DI<0;A=D01d9B40dZ2I0?_Gb`3nfLT0_9N50:N2K`3cdk`0_J6;0?CH`P2nWXd0mmK?0?oIf032
Nh<0ZTmH0<]PJ03HIF`0iG9e0>mlO`3ePH80lWio0>IbM@3HI6L0aeAG0;]?C`2R?T00W4A30>:CU@3=
KFh0dFe[0=MhM03@OGL0gIZD0?o7``3JYJ40TUmL0>:b/P3M[k40n<O=0>^^]P2kI6d0aUiW0<EJH02n
EET0XTA40>2?S`3SWj00iJNZ0>R[/02LGFD0iZN_0<64S02:CeD0ijZa0<J9T02YJg00fifR0=fOXP3B
TID0a7n408m2BP25;SH0T30h090`=02?=CD0Nb`W06l_9@37Uh<0g[VL0;VLM02VRUX0UGY507]L9P2@
JST0UfPl091J=025B2/0P3`U08U0;`28@Bh0O3lS07Q47`2@JCh0XXYJ0:ZLJ`2MVFX0J6To06=U@01j
NeT0RXYX09RELP2KUG40W9A]0:6EK@2NTFL0VHYO09j:H02BNe80TgM@08MYA@1dDc@0HD8V05@f7P0k
80/0;1D503XW6@1DA3L0MVYN0:VPU`3@c<<0kncU00800?l001<0L75/01/J5@0^:bH09b@O03Td<015
@3`0?3@b03Ta;P0l=340>c<`04i4@P1=A3l0>c8]03dd;@13?3H0@c`d03@a:00L7180G5eF01T00?l0
6_ooool7003o01/0oh000P2P8?060?n000030=1@N03oP000X23`00<0X23`:`3oP0050:0Pl1L0oh00
0P2P8?040?n000040:0Pl000o`000?l00=1@N0T0X23`0P3oP0060:0Pl0030=1@N000o`000?l001L0
0?l04?ooool000kooooo1P00o`006`1mmG@0XGek08Pg=P2`@D@0]Sm50;<oA02]?d@0[TY>09m6B@2Q
E580L3<Y0<jST@3D/9@0`Yeg0>>nSP3Xa8d0bjQ]0<fZK@3?[G40h/B?0;6AK@3`aJl0kZbW0:]BEP36
E5l0ce1L0<m>E`020==@F01S0=QGG@3PH6H0hfEY0>AZK@3UKg00iG9b0=QZJP3DJfX0d6EV0=1UI@33
G5/0_5aI0;1LF@2gJfP0^G=a0;=dL@2`M7<0ahn@0?30``3oal`0dgZ30<YNI`3AGVD0d5eR0<QLGP3D
LW<0`VMX0;URI03>NGd0[UML0:UCF039NWl0aGUl0<aoPP3ZWJ00/fEX0;U^L03GU9@0T59B0;UlP@3Q
WZH0UDE?0:Q8DP2A:S40Tbdb08d^<01k:BH0Mc@Z0;5nJP3=YXT0]iE`0:b<H02@KT40I3T=070k5025
ARD0UTdd0910;P1n:1h0S3D]08Xg;021>2L0NchT07M:9`22ISX0Vh]O09bHJP1ZKD@0BU4[04aA<@1S
ITX0MG9H07I`EP1oMET0QGMJ08YmG@2APUh0Uh=K09MmE024ICd0OUdd07iL<`1kFS<0Pf8m07=C<@1X
BBT0HD@T05Hm7`19=AT0AcPP04Hl:01?BS/0GUU@02XX8@0U91d0:2@P02XU8@18@cd0?CPb0080<b/X
00d0<b/W03<Z9@1@AT80Bd0l03@Y8`0i;bL0@cH`040f;@16?S@0@Cdb02l]901fMg40H>1O01L00?l0
6_ooool6003o0003052@N03@D7P0oh0000L0oh0000<0X23`0?n0003oP000503oP0000`3@D7P0X23`
0=1@N0030=1@N0<0oh000P3@D7P:0?n000030>QX?03oP000oh0000D0oh000P3@D7P<0?n000030:0P
l03@D7P0oh0000D0oh000`2P8?001@3@D7P0oh000=1@N02P8?00d51h01T0oh001@3@D7P01@2h>;@0
X23`0:0Pl02P8?00d51h00D0X23`00<0oh000=1@N02P8?000`2P8?001@3@D7P0X23`0:0Pl03@D7P0
P<0001L00?l04?ooool000kooooo1P00o`00N`3JaL80MdM5098f=`2h@DL0]Ca30:He>@2I>CX0kJ>P
0?o<a03d_k40k;bU0?C8Y@34VVP0e:QY0>foM03T]600gZaC0>6dE`3bbV/0cJeE0<^^J039Z7<0omJj
0:AVF@2<>3H0Wci50:U1C02dA580aD]H0=1=F`3ECET0eDaD0=I=E03BBe40bdQ=0=1BE@3?GE`0cf]Y
0<Q_J`2jJf@0_GYb0;ImMP2aPW`0[hJ20;Z>R`38UYL0/WMk0:ESI`3GQX`0`UeU0<ACF@36CeD0`DaB
0:i4AP33K6X0^G9^0;EaL02`K6d0/fQ/0;MXK@2cGV<0Z55G0;eRI`2aEeT0[eUJ080`<@29@d<0_Gn0
0=BIW`3o`LT0Z5aX09@d@02M;SL0Wbdg09PY<02D:bl0QBXW06XQ602UK5/0fZjE0;B@KP2/RF<0WWA<
06`h4`1g=QP0RC/U08Xb902>;bT0TBl^094b<02>=2`0R3T/07/i8`1V<a@0I48L08ejC`2/YGL0Oh1D
04106P1CD340XIMn09>1J`1jGd`0QVYD07ML@@1XDBl0M64g07aW?01mJ3/0PV`m07eU=`21IST0TgM8
07UJ;01`DB<0N5T[07iR<`1PBQ/0IE8X07AUA01GCC@08AT<024K5@0202LR7P0C028J5`13?SP0>C@^
020K5`0Q71P091lI03H_:@0k<c00>c4_034X8`0^9B00<bPT03P_:00k=2`0>SH]03Le;00L7aH0FeeH
0?;bl00F003o01[ooooo1P00o`070?n000050:0Pl03oP000oh000?n0002P8?002`3oP0000`2P8?00
oh000?n0000>0?n000@0X23`0P3oP0000`2P8?00oh000?n000050?n000030=1@N03oP000oh0000X0
oh0000<0X23`0?n0003oP0001`3oP0020:0Pl0D0oh000`2P8?040?n00080X23`703oP00E0:0Pl003
0?n0002P8?000?l001D00?l04?ooool000kooooo1P00o`00T02aTi40L3Pg09Xg>P2k?dL0]STo0;E2
A@2B<2l0T4U30?[4^03EYY80_95a0=^_P03;WF40ikM_0=j/E`3LZT/0bYTb0;b@9@3L/dL0dk9:0>?5
K@2eUdl0omZY0>k0W`3EVXP0bhIo0;]/L@2jGV/0aUMW0<Q:F03CBeL0eDQA0=A9D03DCE<0cdiB0<QA
D`2oFUT0YEA@09YGC`2YLfT0`9B90;VGSP2kWYH0/iZE0:Z=R@2^R8L0_H^>0;akO`2]Ff40`UeS0<5@
EP32Be40`4a?0:m5A`2XEE80]WYb0:ehM02XMg<0Zg=d0:maM02mMWX0^g1d0;UXKP2^GV40ZEeO07Tc
=@2NHV80Z71c0;1eN`3n_LD0fhnI0:4oB`2Y=D00Xb/e0:@/=@2M:Rl0V30a07XR7P1c;B<0`HUh0=^_
UP2gT6l0[hMS0:EcD01_<Q<0N2dF08`i:@2@<b/0Sc0]08h`;P2A>300QcDY088k9`1e?B80F30=0658
7`2LSUd0ZjEc071]@00l>180KV=70:RCOP1gF4H0ID8^085MA@1hFCL0KeH]06I?8`1]F2T0LUd^07IP
;`1nJ3L0RW=109=iAP2>Lch0Qf`g08I]=`1QBQH0GdXK081aB01^HdD09ah=02@L500[9R809QhK02LO
700f;bT0AD0j02lZ9P0Q71H09B0J02lZ900m=S00>c@^03@/:@0T7AL0;2<N02dT7`0i<RX0>CD/03hm
=@0N8AP0@dHo0>GUhaH00?l06_ooool6003o00030:0Pl03oP000oh0001@0oh000`2P8?0=0?n00003
0:0Pl03oP000oh000080oh000P2P8?090?n000@0X23`203oP0020:0Pl0T0oh000P2P8?050?n00080
X23`103oP0020:0Pl0T0oh0000<0X23`0?n0003oP000403oP00C0:0Pl0040=1@N02P8?00oh000:0P
l1H00?l04?ooool000kooooo1@00o`00T@3gk>X0SfUX07Hf=P2S>Sl0/c@k0;Pg?02n@dH0/DM7080]
:@2/KV40l/B/0<ZSO03V^hH0k[il0>o0LP2lSCD0]HTV0<FL<03B[3d0aJ8^0;FC803]c6D0bJM>0=Jd
JP3T`8@0l<JL0?;6[@3nc<D0ol_B0?2>V`30AeH0ddaJ0=A8D@3DBe80cTeA0<QEF02kFEP0WUMA0:Ac
K02jU8/0^ifC0:nGS@2/V8l0/j2I0:FDS02MRX@0XHR40:N3P`32SY80`gb20;UNI@31EU`0_DQ>0<5:
CP32DE<0V44l0:Y^IP2QM6h0UgA^09QfM02KMgL0WgMh0:IjN`2_OH00[7Yk0:AbM@2EI6L0lLO90?C7
c02CEel0^79j0?>S[02lEf00/3Q10:T`=`2Y;S<0Ybhc09l^<02C;B/0NR8N08M3>03OYiH0e:R?0;:9
J@2aQF00X6a706X[301n<a`0RCHV08Xc:@22;R@0OBlR07L`701f=Q/0MD0Q06Dl7P129000RgY60:JL
H@2[Z740GE/[03dd4`22LUT0/9F206I3;`1gCSP0Qedn07EB:P1R@aL0Fd0A06M?7`1B?0/0ET8@06=?
701`FbH0Mf8[07QR:@23KC@0O6L^07MS<021LdH0Kf90024I1P0X8AH0;bPP02dT7`0V7aT0:R<M03/d
;P15?SP0<b`V02LP6P0^9al0@3Ta04Ho=`0g;RT09QdF02PO600Y81T0=RlW03Xf;@0n?3D092DO03`m
>03IfML05P00o`0Jooooo`D00?l00P2P8?070?n000030:0Pl03oP000oh0001X0oh0000<0X23`0?n0
003oP0001@3oP0020:0Pl0P0oh002`2P8?0>0?n000030:0Pl03oP000oh0000<0oh000P2P8?020?n0
00<0X23`703oP00C0:0Pl0040=1@N02P8?00X23`0:0Pl1H00?l04?ooool000kooooo1@00o`00T@3K
bLL0LdE507de=P2Y?D@0]3Dl0;Tk?`2kAdP0[4I4080a:P1^<b<0jknR0>O1U032UUT0i[Q]0;22;@2g
Rb`0jl9I0?7;G03acUX0lm1H0>6lAP2lV2X0fkUE0=2aE`3M`7@0c:me0:F5GP3gd/80olG70;iQK034
CUh0c4UG0<e:DP3;CU80aEAF0;9DE02GCTP0Y7E^0;jQV@2YUH`0WXf509^=Q02QU8`0YIR@0:^NUP2^
XIT0ZiVE0:F;RP2`R8T0c96E0<9cN@2lFf80aUMN0<5<DP2mBD`0YDE309YJD@2TMFl0UGM_08aeK`2=
NWH0S7Ad091fM`2ENGP0VG]k09IfM`2EMgT0ck:f0?OCe`2mR900Xf1Y0;QXL@2iEUh0/d170:lj@02/
=cd0ZCHk0:@f>@2M=CH0UCLe074R7@2YJEl0j;RT0<fTR02_Qf<0^XiW09MS?01/;@`0PSPO08Th9P1d
9A@0NRlL08]7<01i>Ad0L3TJ05d`4@1>:`D0VGi709n=C`2]YFL0[jYc05=>9018?Al0U7iW0:n>N`1Q
=R<0U6=:09EWAP1oEBl0LTdS08ER>01L?A40D3@505e34P1M@a00HdXD05e4301J@@P0L5PL08Uc>P1f
I380HE</028H000W80l0<B/O03<Z8@0^9Ah09ahG02`S7P0j<B`0BD0k040i<@0`:B40>C8Z03@]9@0_
9Ql0:b8K02XQ6P0[91`0>3@[03ll=@0f=Bl07ahI03@e<03?c/`05P00o`0Jooooo`D00?l02@3oP000
0`2P8?00oh000?n0000I0?n000030=1@N03oP000oh0000L0oh000P2P8?080?n00080X23`0P3oP006
0:0Pl0h0oh0000<0X23`0?n0003oP000103oP0060:0Pl0`0oh0000<0X23`0?n0003oP0003@3oP008
0:0Pl0030?n0002P8?00X23`00`0X23`5P00o`0@ooooo`003_ooool5003o000o0;nWY`1/=SH0R3Pi
0:`l@@2a=S/0]d=40:<o?`21<BX0XfML0=Z[U`3X_IX0bJ5^0=R]J@3R]F@0XgHI0>^nE`3cbEd0llUI
0>FnA`3@ZC00mm9K0=>]@02WQ1h0fK]K0?;FP`2_U540d[>50?oF``32P840^EEQ0<mFI`39BeT0aDaE
0;Y@DP2_EE@0TTm90:1_J032YYl0XY6909Z;Q02HRh<0VHn609^@RP2JShT0WI:<0:BIT`2_XIh0/j2L
0:Z<S02kSY40dI2F0<1ZL`34G6D0b5AM0;i7C@2cBTX0QSLb0:A[I02SO7D0TGQa08YiLP29MgD0RWYj
0080RGYg0500RgUg08UeMP27Lg@0Y8N;0:b1R02iOHL0bWj80;YLI02`Ad`0[TM;0;5<D02`CE80YT=8
0:92A02QADH0RCDc06lZ8`3GXID0jl:/0<2NN`2dTFL0_99R099O<P1Z:`P0QS`O07h^4`1i:a@0VDlf
0:EP@`2MGSd0Te/h09UZ@02YPT/0XHE409n=C@2f[6l0S8UF04Q36`1CABX0ZHmn09E^G`2AGDd0SeE1
09YQAP2MITL0YW5A08eM>@1oDR/0OeD[06a76P1YAaL0G3/806i=5`26IbL0QVPX06M>5@1SDB40<B@2
02@M1P0`:QX0<b/P03L^9@0d:b80;B@M02XQ6P0]9Qh0@cXc04U0>@11>3<0>C0[038[9@0c;2H0>34[
03`g<@11?3H0?S/f02`[9P0M71L0;2/V0<O3`1H00?l06_ooool5003o00P0oh0000<0X23`0?n0003o
P0004@3oP0000`2P8?00oh000?n000050?n000030:0Pl03oP000oh0000T0oh0000<0X23`0?n0003o
P0001P3oP0030:0Pl0P0oh000P2P8?0C0?n000H0X23`2P3oP0060:0Pl0`0oh002@2P8?000`3oP000
X23`0:0Pl0090:0Pl0030?n00000o`000?l001@00?l04?ooool000kooooo1@00o`00R02XS8/0LCLf
08li?02`?D80]S/n0:lk?02Q?c`0hY><0?oFbP3R]9d0/hQU0=fcP@3fbX/0cZ1B0;649`3W^U<0fJe4
0;:75`3F[3H0hKTo0>JnA`3hdVD0]I0X0=FcDP3M_fT0Zi570?kP[03cbk40UUUD0:a?F@37F6P0`e1M
0;mDG02WCdh0UU5<0:IeKP2kVY40^:NN09^>QP2HSHL0Uhb609Z?R@2KTXd0VI2;09V>R02KT8X0Vi2<
0:JGU02aW9T0]I>D0<VFV`3ARY80`fMb0<5FH02mBE80^de@09U0?02AC4L0Xg9[09MiL@2@O7D0Rgag
08YoN`27OG/0PgUg089gM@26NWX0Pg=d08edN02LM7`0Yg9j0<=jP`2ZDUT0Vd5309a7BP2iJVd0]6Q/
0:aPI02TEEX0We1C09]ADP1X:B@0VVYP0?WD`P3P`jD0^9]c0;fLI`35WVL0ODdM074b2021>A<0OS<D
07le6024>Qd0P3TI08A2802>Db/0UV4_0:5g?@2LOT80XHiC0;2WL01oN4X0?C8B05U7<@2^SX40W6eP
0857>@2;D3h0O3lZ0898<P2PJ4l0YfmD09AR@@2=GCT0T6@m08]R=P2;IS40VgPh08Y/901SB040S7Tg
07U/=`0V7P00:24>034Z6P0m<bT0?cD[048h;`0f;BH0;bHO02PO600`9b00?3<^04Hl>P10>3D203hi
=@0903lj=P0g<c00;2PU02DQ7P0P6aL0;RHS09nHTP3bjnD0ooSe01@00?l06_ooool5003o00030:0P
l03oP000oh0000@0oh0000<0X23`0?n0003oP0006@3oP0000`2P8?00oh000?n0000;0?n000030:0P
l03oP000oh0000H0oh000P2P8?080?n000<0X23`2`3oP0000`2P8?00oh000?n000050?n000H0X23`
2P3oP0070:0Pl0/0oh00502P8?000`3oP000X23`0?n0000D003o013ooooo000>ooooo`@00?l009H0
ooGc09=dLP1i?3/0Uci00;0j@02j>Ch0_T940:0`;P2jGEH0jj:I0?g5]03W^Yd0eZb40=f^NP3CXUl0
/X@_0?W=KP3J[dT0W7030>RkAP3P]3/0`YHR0?G<HP3=Yd80[XLX0>W5K`39ZEh0ekQo0?cK^P3T]:P0
Xe]O0:9:EP2fEV40[EAJ09I@CP2ZN740/8j50:jFS02hZJ00Z9^C0:6DSP2MTX`0W96=09Z?R`2KT8`0
VXn;09R=R@2IS8H0WHj90:FCT@2eViX0`Y^N0<nHWP3;OhT0_V5[0;Q=E`2oCeD0/U1?09A5@@2JGEP0
WWE_09MlM@2@OgP0S85k08MnN@29Ogd0QWak08AhN027MgX0SgIl09Q`N@2TKgL0^6mh09i<D02:?Sh0
W5mL0:YgM02WMgL0XgEg0:IdM`2QKg00WVa]08EHE@1aC4H0ilZl0?oUcP3F_YX0_:1^0<b^LP2dTU<0
LD@:06L_001V:040KB/907L`401n<a@0O2lA07db4P1k=Pl0MST=0752502ALCh0/IeX0;6UL`1YGCL0
A3HI06aJAP2ALF<0S61C08aLCP1g@cD0MT4c089:>`2>ETD0RE0m08YC?P2BGd@0QUPd099Z>@2ROcl0
V7/]09In902gY4P0_jmJ04a0400U6`80;R<A03<Z6`0i;b<0Bd4g04i4>`14>c@0>c8[02/R7@0[8Al0
:AlN02/S8@0W8Ql0:B<S02/W9P0U7al08Q`L02PQ800/8R00<RDO03LV7`1[FDl0]J>I0=_:`P3gj^@B
003o01[ooooo1000o`000`3oP000X23`0?n000060?n000030:0Pl03oP000oh0001L0oh0000<0X23`
0?n0003oP0005P3oP0020:0Pl0L0oh000`2P8?040?n000H0X23`303oP0040:0Pl0T0oh002@2P8?08
0?n000030=1@N02P8?00X23`0080X23`0P3oP00?0:0Pl0@0oh004P00o`0@ooooo`003_ooool4003o
000[0?CUhP26H5d0Oc/j09ho@`2`=ch0_cU00<4l?`2h?Sd0XcPb08/g;@2fMfP0jKVS0?G<[03>XWD0
h:me0;B4>P3K[EL0oM5`0=:V?@3[_Dd0cj0/0=2Q<@3hcfD0aYlj0;J?<P3_bG@0k<b30:j?F033XX40
om_>0?Ni_02VGFP0YEEN0959C@2QK6P0^YF=0:B9P02PSX@0/jFK0<g0^02n/JT0Zj2J0:2ES`0209jC
S@80WI:<06X0Wi:<0:2CS@2NSh`0Y92?0:nCTP32VId0bhnG0<f1R`2jGfP0_EAK0<=LG`2WCD`0SD=0
0:5_J02POWD0UGif08ioN027O7P0RGmm08MmO027Ng/0QWIi08mdN`2HKgL0[WEn0:aSJP2GBTd0QDE3
0:=cK`2GM700TgEc09AhM`2FN7X0UgUi09QhN@2EMW@0OfIR0;JOU`3/elH0jmJk0<fgSP3:/gl0b[9f
0;jOH@2VODD0U6@d07Q35`1_=0P0L2l5070/1`1f<0`0Mc<<07Xl4`1P;`H0Hcd@09Z0C@2fYW80Z9a/
05mF;@0n<aD0HDde07]LA`2;J5@0V79M09Q]FP2=H4d0REY808]JB@29ET<0Odlh05ha4P2@JSd0ZhU9
0:24<@2VSbT0^ZHf0<JdAP2OTSh0;b<002PN000^90T0;RHC03/b8`16?380DTPo05I<@`1=A3d0?S<_
03@Z:00^9R@0:R8P02HP800/9RH0:1lP02TP8@0a9bH0=RPU02/L5@0X5P`0GTPk08efJ029LV@0VXAi
0;FRV`3Jbl@0lNKP3`00o`0Jooooo`@00?l00P2P8?080?n000030:0Pl03oP000oh0001L0oh0000<0
X23`0?n0003oP000303oP0000`2P8?00oh000?n000060?n00080X23`1`3oP0030:0Pl0<0oh002@2P
8?0=0?n000030:0Pl03oP000oh0000/0oh001@2P8?0;0?n000@0X23`0`3oP00?0:0Pl0<0oh0000<0
X23`003o0000o`003@00o`0@ooooo`003_ooool4003o000`0>C?c01fBTL0Rcdm0:Ho@`2a=3`0`CPo
0<8j?P32@400_4I20:Q7?P26?2l0JcPU0>2kX039XW/0gK9o0<FEE@2`Oc80l/=[0>JhEP3EYS`0e:Hg
0=>V>03fbf80/HXU0=ZcEP3B[ed0_YmL0=FeQ03Q_:80om;:0?o:c`3RWZT0UE9I08eBE02eSH/0YHZ3
09b:P02NT8L0Wi>:0;^^YP3:_KD0cl:j0<2cZ`2^XIT0Y9N?09jDR`2RUi40WY6;0P2OTHh0J`2OT8d0
XHf<0:nBU02hTI@0`hjD0<AmQ@2jGFD0`EYN0;EEEP2GA400TU=<0:MkLP2LOWH0U81i08aoN@2;P7h0
RWin08YlO02<Mg`0U7Ek0:5bNP2gN840W55F0957BP2;De80X7Ud08mcK`2<Mg@0RgMf08ajNP2<NWP0
SGUh08ijN@28MW@0R7Ib09f<Q02WUHL0YYAn0;:OO`2o[880c;N20=>iOP3@/WH0aZIY0;ZFF02VOT00
SfD[07E84@1U=`<0GS8105he1`1>;000GD<B09n>EP2`Y6P0Qgi305mI9`1ICRD0HDlY05U36P1dFc<0
NUdk085TA02=KTl0UWMJ095_E02CKeD0Q65109]jC@2ZS4`0XhTb0:VA8`2kYbX0b[Te0=G8CP2KTC80
Bd8002/S000`9`P0<RXE03L[6`0j;R00A3P/04i4>P1DAcl0CT<m044f<P0o=300?S@b040f=00g;B/0
<bTW03@X900e:2809aT@030N4P1kJ5T0V7i_08aaH02>LF40U7AW08i`I@2IOG40[Y>:0=:n]@3bh=`0
ooKb00/00?l06_ooool4003o00X0oh000P2P8?0F0?n00080X23`403oP0000`2P8?00oh000?n00006
0?n00080X23`1@3oP0030:0Pl0@0oh000P2P8?0d0?n000@0X23`0`3oP00A0:0Pl080oh0000<0X23`
0?n00000o`002P00o`0@ooooo`003_ooool4003o000a0=Nk]`1d@Ch0Tclo0:Pk@02d<c/0aCa30<@i
?P36@440_40n0;I;A@2PCT<0HRdO0=jhX`30Vgh0iK^C0=n_O`30SU40`i=90=Z/EP3P/U@0llIQ0>_0
FP30US@0^i@g0>C0K03@[VH0a:E^0?oP^P3_a[@0]HB00;=fO@2XJG80RDiD0:YiO02_T8d0VXN009^=
Q02KSXH0Vi680:>FSP2/WiL0_[6Y0=74^`3Ca[d0_K2W0:^QV02UVi80X9>=0:2BS`0209jCS`1]09f>
R`2NS8X0YHf=0:n<T035T9H0_6ee0;IFFP2jEET0]5UH0994@02LHET0YW]d0:23O@2HQGl0T89o08eo
OP2@OGl0TWUm09UdN`2[Lg`0/6ef0955B@2<B4T0UVIT09]iM`2<Mg80SG]i08YlN`25NWP0R7ek08Ej
N024NGL0QWQg085cLP28NWL0R7Ud08YlL@2>OVh0T81W0:FDK`2lZWX0ak>00=6lQ@3D_X@0dKUk0<fc
N032YF/0]iQQ09n0BP27Ic@0JT`H044[001VE1H0[J=K0;F^IP2RX6<0KV/h08AiC01WERX0K5LZ071I
;`1C?180I4dS06M@9P1]E2`0OF@l08]_B02@M480YHY50:>:;P2YTa`0_ZXS0=;2;`3IcCT0gmIC0<>l
E01ZIA@0<R`002DN000/8P00<BH:03DZ500k<1h0?S8R048d9`0o<BH0>bdT03d`9`0j;B@0=BPO02hQ
600e9ad09AP802@D1012<Ad0NVQB09n9M02CN6D0TG9P095]G@2IM6@0VgIV08iZG026IUT0SW=X0:6=
Q03=_;@0kN?J083kN@08003o01[ooooo1000o`0;0?n000030:0Pl03oP000oh0000l0oh000`2P8?00
0`3oP000X23`0:0Pl00B0?n00080X23`1`3oP0020:0Pl0@0oh000`2P8?040?n000030:0Pl03oP000
oh0003H0oh003P2P8?040?n000H0X23`0`3oP0000`20`0000?l0003o0006003o013ooooo000>oooo
o`@00?l002H0`j:M0815@@2M@D80[Ca00;Hd?@32>D00bCi30<@n?`2o@T00_dm=090i<P23BT40k/Jj
0:Z3LP3I[iL0eZV<0=j^QP3BXfl0c9aL0<JFBP2hRcP0_9@l0<2JA`3X`WL0f;Ec0>K3S@2TQ5d0fkVP
0?K>a02=Fe`0SU1E0:5PJ02KI6X0[XB60:68Q02LSHH0W8n709V>R080Vi2:00T0WiB>0::GT@2/XYT0
_;:Y0<Rn]@3<`[T0_K>Z0:VOUP2NThd00P2QUY00K`2KT8`0Wi6>09n?S`2TSY00]Y:F0<>7S02bGF@0
]5AH0;UFF@2YCTd0V4Y60:5WH`2]Q7h0XhN309Z7P`2BP800TG]n09QgOP2QM7/0]7En0:5HG`2@ADT0
RTe<09ifM02CNGP0RGMe08YlN`2:OWh0QWYj08QlO025NGT0QG]j08MkN`21MGD0RGil08]mO027NGH0
QGQb08MiL02;O6h0SWmZ09>3JP2OT7<0[Iek0;VWO`37]8X0c[V:0=K0SP3B^hD0cKMm0<F`L@2RSdX0
PgDZ0:>KB02m^VT0d]>=07Mh@P21NE80P75:06eG<01mHSL0O64b07mV<01gHBL0HD/A06eI7P1YDQ`0
FD4308ie9@2[U2h0[IPK0;RV5P3EaR/0elh^0=_F>P3NfDT0dlmA0:>O=01^J180?SL002/Q000S6P00
9Qd002lT200e9`d0=2D@038S400h9aD0=B@B038S400a8Pd0;1h601lA000g:0L0L68o07IWAP1eID`0
RWER09=iJP2KOVh0XH1a099^GP2EL5h0UW5O09AaGP27IU<0PfMB08]`G@2dXI40k=oF0?oim006003o
01[ooooo1000o`0@0?n000030:0Pl03oP000oh0000d0oh000`2P8?0D0?n000030:0Pl03oP000oh00
00D0oh000P2P8?020?n000@0X23`0`3oP0020:0Pl3P0oh0000<0X23`0?n0003oP0002@2P8?050?n0
00040:0Pl03oP000oh000:0Pl0T0oh001P00o`0@ooooo`003_ooool3003o000d0?ofm@2_RHH0QTE1
09lo@@2[=S`0^SQ00<4h@039@4L0`c/o0<A2A02lA4D0TR`Z0<IhM03ob/<0l[J^0?Nm/@3e_:/0mknX
0>2^R`3CY7P0h[En0<VMH03L]G<0j<B60;JAG03=YW/0ikjN0<ZMQP3IZId0omoK0>Ra]02FE5P0SU1E
0;1mPP2;IfL0H4]608]nMP2NThd0Vi2:09V>R02HSHL0Vi2:09fBS02RVI80XYR?0:VOUP2eZj80aK^b
0<k4^`2j/:L0[J:L0::GT@80WYF@05H0WI>A0:6AT@2USHd0_I2C0;YcN@2kHFX0^UML0;UFF@2SBDP0
Ude:0:igLP2WP7/0Y8N309MoO`2IO7h0X7Mm0:YeO@2fL7P0UdY@09Q>C`29Ddl0WGik08iiMP2<O7`0
RWal08UmO@25NGT0QWYj08EkNP27OG`0R7im08=iN025NGT0QWYj08QlO023MgL0RG]k08MiM`28NgD0
QGQ`08AfJ`29O6/0RgaW0963J@2KS6d0[Yij0;NVN`37]HD0e<>;0=C4QP3<`7P0aKa]0;VfI`3AeH/0
TIEN05QD;P2AQ6@0/imn08Y^B@24ICL0TWDk08]`:`1mIa`0QW<V07eZ7P1PB`00RG8B0:bG902`W1D0
[ih80<Vk703MeBd0f=@Z0=oL=`3NgT80g]eA0=SFF`2l]e<0Ui4m06aU7@1BC@d0>c8003L/000_8`00
:ad002hP0080;Al001P0<R@0044d0`1[Gb<0VXiB07a_>P1eIcX0K5/m071NBP1bFd/0PFMJ08Q[G@2K
NV/0Y81`09mlJ@2@L5T0S6aC08m`E02MOf<0Pfa@079PC026MVL0_;:X0>WRfP3mn_D3003o01[ooooo
0`00o`000`3oP000X23`0?n000090?n000040:0Pl03oP000oh000?n000<0X23`3P3oP0020:0Pl1D0
oh0000<0X23`0=1@N03oP0001@3oP0070:0Pl0<0oh0000<0d51h0:0Pl03oP000B@3oP0040:0Pl0X0
oh000P2P8?03003o013ooooo000>ooooo`<00?l002X0o^k^09a`K`25?cd0Y3m30:lh?P2i=Sh0`3Lo
0<a3B`36?D@0aCa30<M0AP2d=SX0aE9E0=E]K03GLg40fWeh0=R4NP3CRgd0m;fY0=BXS@3T^IT0dZZ6
0<:PNP3K^9P0[8M]0?cA`@3e`;P0kj^X0?F^[03l^;T0olK70;]iNP28CTd0^I2>0:N9Q`1/FE<0EDQ2
075VH02FSHH0Vi6809b?Q`2KT8X209bAR`0Z09jCS@2OU8h0Y9VC0:^PVP2i[:@0c/Bk0=;8_`2g[ZD0
ZJ2I0:6HT@2MU8l0WY>?0::CSP2`T900bI:G0;e`N02kH6T0_5MM0;IDE@2K@d40WeI@0:igL02[PW`0
XGil0:5jN`2YMW/0^G^00:]PI`2FAd`0T4Q909=QG@2ENGD0SG]g08UkNP27Ng/0RGem08AjN@25NgX0
RGil08MlNP26O7/0QG]j0P25NGT0C`27Ngd0PWIh08EiN`26NWX0QGUi08EjN027NGH0R7]e089eK@26
NG00QGM/08UlK02<O6`0ThA]09f>L@2]WWL0`[B30<VnP035_WX0a/N10<78SP13AAh0KFQ;0=_;/P2Z
S780KTXV0;VDG@2mVe40UGXQ09f7902;Ma@0L5d00::?6@2eXQl0]Z@D0;6Q1P2m[`h0eldU0>3L<P3V
i3X0i>E10>?UAP3Ti4h0i^EI0>;RH03IfEl0c/eI0;JbA02WXcP0Ui8/08^68P29PAl0Rh4P0926902I
T2/0[j8k0;jaB`34]eT0Y9A706aL8@1RCRT0J58k085WF026JUl0Of=G08MYGP1mHE<0V7i]08MaFP2<
N5d0S7UI09=oFP2UT6L0WXQS07aWB01HA2/0HU=008IlL034`;L00P00o`0Jooooo`<00?l00P2P8?0;
0?n000H0X23`3`3oP0000`2P8?00oh000?n0000L0?n000D0X23`103oP0000`3@D7P0X23`0?n00019
0?n000D0X23`2@3oP0000`2P8?00oh000?n00002003o013ooooo000>ooooo`<00?l004h0l=kN091P
H028?3`0YSm30:`e>`2m>D00a3i70<I0B@30>T<0`c]50<XnA`3<@4T0^S<i0;0]<P2b=SP0[c/k0:<j
=P1m91h0_7ic0>jn/02[P700bj6A0??>_@2RO740`IRB0?oEe`2oO8<0VT570:Q8C02[DU@0`G=a0:5M
FP2KIV80]I2:0:J?R@2MSXT0OgA^05Q=A`1GCTL0SH9k0:6DSP2NTH/0WY>=09^@RP2OU8h0WY>=09nD
SP2PUHl0XYF=0:VOUP32^:l0bl:i0;je[P2`Yj00YIbE0:2GT02QUY00Yi6?0;bCU`3>SiL0_6ae0;iO
I`2kEUX0]5AE09U1?`2VH5P0]7Ua0:mlN02_NGT0]gMh0<9jO@2SDEL0Vd]>08Do?`2KKf/0Tg]g08]l
N@28OG/208UmO@0408IlN`25NgX0R7al08MmO080QWak0P27Ng/01@24N7X0QGUk08MkO@25NG/0QWYl
0080QGUk0P26NWX0:`23N7H0QGYh08MiN029NgP0QGI_08IfI`2;Nf40UXMN09n@F@2SVUD0_Kib0=oV
Y`1/LDP0?C`N0;BXTP3[d;d0ID8T09Q`?03S_G80bji:0<>^>`2iZC00Zi`M0;RX8@33/b80_k0I0<6c
502k[PX0bL0F0=gJ;@3Vi3T0inHl0>;T>`3RiCh0inU60>[/C@3Zje40l?1J0>k^G03Yj5X0gMiD0=[J
E03JeeH00P3FdE406`3FcD`0e/]70<k0@`34]dD0/9m7099m?01NAad0FShV06iA@@1jG540Pf9I08Y/
HP21IeX0PfeO071OB`29OF<0Uha^09f@K@2KS640XHmQ0:nIL02UTFh0Lf9403/`701dKV00n_We003o
000Jooooo`<00?l000<0X23`0?n0003oP0003`3oP0000`2P8?00oh000:0Pl0020?n000030:0Pl03o
P000oh0001l0oh0000<0d51h0?n0003oP0001P3oP0030:0Pl0D0oh0000<0d51h0:0Pl03oP000B@3o
P0060:0Pl0T0oh0000@0X23`0?n0002P8?000?l04?ooool000kooooo0`00o`00;@3RcL`0Q55@08/m
?@2W?T<0[3<j0;/l@02l?D@0^ci60;LmB02b=T40aCm:0<LnB039?DH0bCi50<e5B@39AdT0aDe<0:a4
@@24=c40kkB^0=RYX`3md//0lL:l0=^_[P3Y^;/0olO@0;AQJ`2hBE80aDiD0;A8B02`DU00UDi80;9m
M`2^SHH0WXZ309^>R02MTXh0V8f9079WH`1DBD@0PWAa09f?S02SV9@0X9F?09nDSP0209nES00/09fC
RP2NThd0WY>=0:BJT@2/XYT0]jbV0;jc[@31]jh0]ZbS0:RKU@2STHh0Zhn>0<>DVP3=SYH0^VU`0;EI
GP2gE5L0]UAC0:17@`2SDd`0_Fm[0<AfM03:NGP0ag5b0:M>D02PD540Pd900:5iM02@OGL0S7ik08Il
NP2:P7l0RGmn08b1O`27Ng/0Qgel08^1P02:P7l0QWak08QlO02;Ogl0QG]j08IlN`28O7`208MkN`04
08UmO@25NGT0QGUi08MkN`80QWYj04H0QGUi08anO@2<OGP0Rg]^091oI@2EQ5P0Rg/m09B9>P34`fT0
g>>G0;BjRP1CDS<0NG5L0?CRcP2gVGd0M4lK0=VeJ@3Pb5h0e<940<Vm=@39`C00ak/W0<Zo9@3;`B@0
b;hN0<Jm6038`AH0e]<T0>;P<`3Xj3X0h>8f0=gO=03SiC`0h^@k0>;S?@3QhS`0iNI00>GX@`3Kh3h0
g>150=_MB`3WiUP0g]]>0=SBAP3FbSl0d<=00<6b?@2_W400V84m075D:01P@BD0Q65>07YFBP1T?SD0
NUQ>07iPEP1mIET0MfMH06QPC@1cKEL0X9Z00:ZSO`2KT6<0VHaO0:RKK`2i[HD0If1306i/E`3in?<0
0?l06_ooool3003o00030:0Pl03oP000oh0001d0oh000P2P8?0H0?n000030:0Pl03oP000oh0000d0
oh0000<0X23`0?n0003oP000BP3oP0050:0Pl0030?n0002P8?00oh0000L0oh000P2P8?000`00o`3o
ooooooooo`0>ooooo`003_ooool3003o000]0=2h^01lAT@0T3i00:TnA02`=ch0^ce10;Hk@02a>D80
mXN@0>MdP@2k?DT0bD5=0<TmB03:?DD0bci60<Lo@`35@dD0_TY;08DV9037NGL0om7A0?Vl^`2GDE80
j:b^0?o>e03jZ[D0[DUE0<]?F@3:BDh0`D];0:i<B@2JDdd0^HR10:J8P02MRX@0W8n909J=R02JSh/0
W96=081eL@1>@3d0FTm;081eL@2JSh/0XYNA0080WI>:00<0WYB;09bAR`2MTX`00P2SVI00M@2WW9H0
ZIjH0;R^Y@37_K@0dLBn0;RZY@2]V9L0[h^=0<fHWP3SVZ40]EiV0;eMH@2nFUX0bFYV0<EXH`2]DTl0
/UMF0<YZJ`30H640]EMG09e7AP2FCdd0Z7Ue09UmN@2BOGX0Sgek09>4P@2>P7l0Sh6008eoOP2<P800
SH>208UoOP27OG`0RWin08b0P02;Ogl0RGmn08IjNP28O7`0RWin08]oO`27Ng/0RWin08QmN`2;OG`0
Rgej08aoN@2>P7L0T81a0920I`2FQ5`0TX5908em<P2]XD/0cLY]0=3CR03Qi;L0M7=G06mXEP3Fa[L0
k]Jn07iM<P2gUU40mMek0>?CFP3MdD/0fm=40=[@?@3KdC`0dl`e0=;<<03Abbd0d/d[0<g:8`3Jec00
h^4i0>?T?P3Rhcd0h>8i0>7S>03QhcL0gn8c0=kQ<P3Ohc@0g^8f0=_Q>@3MhD80i^M=0>?RBP3Je400
e<Tf0<k1=`2n[S@0]J4n07iW6`1[CAT0KD`Y09A`EP1eCc`0OEI707EA@`1WAcX0G48e065@@01ODT40
Iem806YTBP2IU740]Zn30:FMKP2KTf@0[:Ei09^IL`26QVh0nOWa003o000Jooooo`<00?l04`3oP000
0`2P8?00oh000?n0000:0?n00080X23`6@3oP0000`2P8?00oh000?n0000<0?n00080X23`8`3oP000
0`2P8?00oh000?n0000V0?n000D0X23`2P3oP0000`2P8?000?l0ooooo`0?ooooo`003_ooool3003o
000_0;RLV`21AdD0T3`l0:`oA02`=ch0^ci20;@k@02]>T40mhfG0>b2SP2b>TH0a45?0<Q1C`38?dT0
a3]50<Y1B@39@TP0adI:0:/g>P2W?Cl0miBG0;YGFP2Y?d<0Uc/n0?nVZ`3YQ8`0^DM?0<e?D`37BDX0
_Ta;0:97@P2OGeH0^Xn80::6PP2LRXH0WY2=09Z?R`2KT8h0VXn=0:6FTP2=PX00JEiL04Xo?@1ID4/0
QWeh09N>Q`2PUHl00P2MTX`00`2NThd0Vi2:09fBS00209nDSP0U0:FJU02/XI/0aKZf0=O8a@3>^KP0
_I^L0<JEV@3SWZ<0_fec0=MkOP35IFH0afUW0=9gLP39JfT0[e1>0;QDE02gD540_eQI0:I8AP2ZEU@0
]GA`0:UiM@2TOGP0VW]f09YnN`2IPGl0TWmk095oO@2APWl0T8:108n1P02<PGl0Sh6008YoO@2>Ph40
S85o08MmO00208UoOP1<08YoO@2;P7h0SGmn08]mNP2>OgX0Sh5h09:1L@2EQ6X0UhEO09B3C`2DPT00
TX8d0:^MA033^Ud0c<Q_0=;ATP3Ph;h0THai08^2N@2cXYX0j=7108MZBP2ZRUL0n^2C0?;KN`3_gFd0
k]iU0>_NGP3Zh5`0i=aE0>7KD@3PfTh0emE40=[I@`3GeSh0f]U00=_L@P3Vid/0hN=40=kQ?03RiSX0
gn<d0=cP<@3Ohc@0g^8e0>7U>@3LgcX0hnA10>_WB03PfS`0eL/a0<c0;P2m[bX0^ZPj07QS2P1G?P00
PF<a07aL<`1P?Ad0RVI<06Y7<@2CLUl0Of=>0617<@1E@2D0GDXZ06mQ?P1]HcX0WYMY0;NcQ02b[Wl0
U9=W0:ZZQ02Y[940n?Wa003o01[ooooo0`00o`0D0?n000030:0Pl03oP000oh0000X0oh0000<0X23`
0?n0003oP0001P3oP0000`2P8?00oh000?n0000E0?n000030:0Pl03oP000oh0000D0oh0000<0d51h
0:0Pl02P8?000`2P8?1G0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`800?l002H0ooKd09an
O024Ad@0UCln0:Tl@@2]=3T0^Sm30;]4BP2_@TP0eG5k0=eiQ@2Y>dP0]d9B0;]2D@30@e40_T1<0<=4
C`32@4X0`T=:0<97C02[<ST0_4M=0;a3BP3<CUD0WBP^0<EBF@3DFf80bDaB0<m>DP34BTT0_U9?09U4
?@2^Lf/0]I2809f5P@2IRXL0VXb909V>RP80VXn=0880W96=09nDTP2QUiD0RGmm05iDDP18@C/0F55;
08AkMP2OU8h0XIJ@09fBS02KT8X0W96;09Z?R@2OU8h0XiRB0::GT@2XWIT0^ZZX0>?;b`3[a<L0hjnc
0<f6S02bGF80cW9e0<m_L03KP7d0iHZ70?2BT03JNgT0b6AT0<=LG@30FEX0^5AD0:U;B@2YF5D0ZF=Q
0:mbK`2_N7D0ZGQd0:QlN@2SOGX0WWaj0:64P02IOGX0VH1l09MoN`2EP7d0TWmk09>1O`2BPh00SGmn
0923PP2>Ph40SX1m08n2NP2EQ7X0T81a09N6M02DQ6X0V8IR09B2E02@P4@0TX@m0:FEA`2`Y500akeX
0=;;N`3Mf9@0c/^N0:^YU02LUHd0XYRG0:>EU033/:X0KE=206U?;P2UREL0_j9P0=k1L@3`eGX0m=Yi
0??NM@3`gW00kn=]0>gSJP3ZhV@0in1N0>?OF@3Ofe<0emA90>_ZFP3Wie<0h>570>7S@03RiC`0hNDi
0=oS=`3NhSD0gN4e0=oQ>03PgcT0i^<n0=oJ=P3Dbb/0c;lU0<Vj:`2n[c00ZILY081[401mIQP0PfXW
07QN8`2OPe<0MeX`089V@@2JP5d0M5Xg07IO=P21Jc`0JUHS06IH901fK3/0Q7i>0:^WN02VYGT0Z:Z3
0;>fV`3hnO400?l06_ooool2003o00030?n0002P8?00oh0001d0oh0000<0X23`0?n0003oP000603o
P0000`2P8?00oh000?n000040?n000@0X23`203oP0090:0Pl1`0oh0000<0X23`0?n0003oP000<P3o
P0000`2P8?000?l0ooooo`0?ooooo`003_ooool2003o002Z0?O/jP2:JfP0PDA109]3@@2U>cd0ZS<g
0;Q1A02jBDl0ZT9909Xk@`2`E5l0Y4ID0:Q7F02_BU`0[DIG0;15E@2aAE@0/T9>0;M5C`2iAE00^4=<
0;i5CP34ADh0c4I?0<U3C032?4D0cdMA0=19D03;B4d0`4Y:0:i:B02GB4<0^HAn0:b;Q02NRH@0UhZ4
09N<R02JSh/0V8f909Z?R`2KSh/0VXn;09V@R`2MU8l0WIJ@08b4P@1GCd`0B3hl06IKE`2<PGd0XiFB
0:BGT@2SUY00WYB;09fCRP2NThd0XYNA0:BFT`2/VYP0_9bM0=j]/@3d/kT0`G1g0;9EG@2[Bdl0]E9E
0=j0P03jWi`0mibI0?:GU03fViX0iHN70=5bL03CLG00_e]K0:m>CP2RAdH0WDE409m;B@2VEE@0ZEeM
0;5[J@2`L6h0]G]i0:ejM`2]O7P0Yg]h0:9lN@2PPG`0WH1l09^1P02GPX40UX>3091nNP2CPWX0W8al
09Z9K`2HQV80VXML09B3C@2?OCd0U8<k0:2CA02aYUH0`;MZ0=G<Q`3Pei`0f=2Q0<6kU`2UXHh0WIZE
09nIV`2PVYh0XiVQ0;>WZ`2=NgT0DCPa06E6=01[AR/0Qe/d0;63DP3J[740j;]g0>o:NP3deG/0m=Yi
0?ORN`3di7D0l^Ec0??XLP3^iVX0kNQX0>SVG`3Ui5H0h>=<0=cP@`3TiT<0h^E00=kQ>P3RiC`0gMlf
0=cN=@3KfS80e]</0=G=:03@`bD0dlH/0<o3<@3;_S@0^J`/0:ZK9P2PSbD0W8`]09b:=P2>O3@0LEdN
07YW;@1gI2X0MV8U0;2NEP2hYUX0MF<L06IE7@1eIcH0NG520<?0U@2`/Xd0[JnG0?Sil@00o`0Joooo
o`800?l00P2P8?0N0?n00080X23`3@3oP0000`2P8?00oh000?n0000@0?n000H0X23`2`3oP0080:0P
l1T0oh000P2P8?0b0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`800?l00:X0h=;?07MFD@25
AT40UShl0:Hk?@2]=SX0^D960:m1AP2Q?480/EQP0;ARK@2`IW80YV=^09eLJP2YJGL0Y6=`09UGH`2^
JgL0W5IR0:QMJ02_FfP0XT1=0:dnB`36AU40cD=;0<e0B03=?DL0cd=;0<Q6BP2nBd`0XdM50:=OFP2h
S8H0XHIo09j<Q@2ISHL0Vi2;09Z?RP2ISHP0VXj909b@S02JSh/0VI2;09ZAR`2KThd0WiNA09jFS`2E
S8P0OgIa06ILF01REU80JE]H08AfLP2JSXT0WiB?09jCS@2QUY00Y9FA0:jBT`2nSI80fI6J0<acO039
GfP0dEmV0;i9C`2b?T<0YSLi0;97B02jEE@0`EeL0<e[JP3LNWT0hWmm0>F0OP3VP7h0i7ek0=I`K`3>
J6L0cFMW0<9LGP2bCTl0[TQ:0;5=CP2]CDd0[U5B0;9JF`2/FEP0[f9Q0;1YI`2`Kf`0/GAe0;5kO02Z
Og`0X85h09^1L02KQFL0UX=F09V9D02MSD`0[9iF0;b^H`38_GD0d<R60<o9T036`I80^KFB0:^VS`2U
X9<0XIbF0:2LWP2OVj80Wi^S09fIX@2PVJ@0Y9^U0;N[]023LWT0@2P/05<f=P1I=c00ES0T09iiI@3@
[940]iEb0;^KL`2iV6`0aJI`0=:eM`3L_W/0h/El0>W<O@3]dW/0kmMh0?7LM03^g6X0j]]P0>SJF03X
gE@0imi@0>KOC@3SgDX0h]e70=oKA@3Led<0f]=10=O>?P3Ebc/0dl/h0=G=>03BbcD0c/Lc0<o6>036
_SH0^[4`0;:Y<P2RVB`0U8XR08f1701mL@/0XIDW0=[>F`3Odf<0[j9607U]8@1/I2L0^kR60;:bRP2]
/9@0n?Wa003o01[ooooo0P00o`000`3@D7P0X23`0?n000080?n00080d51h0P2P8?00103@D7P0X23`
0?n0003@D7P20?n000030=1@N03oP000oh0000P0oh0000<0d51h0:0Pl03oP000403oP0000`3@D7P0
oh000?n000040?n000030=1@N03oP000oh0000L0oh000`3@D7P40:0Pl0040;Ph]03@D7P0d51h0=1@
N0P0oh001@3@D7P20:0Pl1H0oh00102P8?020=1@N2h0oh0000<0X23`003o0?ooool03oooool000ko
oooo0P00o`008`3YfmP0NeaG07m4@02F@3l0Ycdo0:`e>@2h@4H0]DA:0:4l@P2]EUh0^Fie09YMI02H
Ifd0hk_40>g:d@3P_lP0i/G>0?7BfP3=[KP0i/;>0:moS@1l>TP0Q2dm0;]9E@3:A4d0cd=<0<`oA`3;
@TT0aTQ;0;M9BP2NBTP0/WE`0:j9P`2QRX@0WHj70080VXn90280W96;09jAR`2MSh`0VXn;09jCS`2J
Sh/0V8n809bCS02JTHX0Vi:;09jESP2MU8l0X9NB09bCSP25NWH0GE9>04]0?P1TFED0RGij0:2ES`2Y
UiD0/Xf>0=>@U`3ENH@0^4QD0<Y=E@3DCUD0eTeD0=M@EP3@CE80b4Y=0;a1A02a>S`0YS8c0P2[>cX0
A@2nD4l0d6AR0=ebL@3KLG40fFm_0>AjNP3XOWh0jgen0>=`L`3QJVh0dUUN0<M@E037E5L0_di@0;=6
B@2`B4T0ZDE70:E7B02PB4L0W5EA0;20LP3C/9X0_JF30;>NK`2m[WD0c/>50=gCUP3Fc9L0`;N<0:ZT
Q02OVXH0XIfB09fJU@2MVIX0WI^P09bIX02PVjD0X9ZT0:2KXP2MV9l0WiZQ09nHX02ZX:T0/jR`04/n
A`0^7bH0:Q/N02lQ8@1;?C`0lN?P0?SYi03jin40mmoK0>K<`P38ZiT0]iN00:n<L02VOeh0Z8=I0;^E
IP33X6P0eK9b0=^kL03Sa740jLa`0>c@K`3^eFh0l]Y`0?3JK@020>oKJ`0J0?7OL@3di7<0iMIO0=_@
E03LdTh0fM130=S@?@3MeT00f=4k0=K@?03Ed400aKlc0;ni<@38`C`0^kD]0;be:@2f[b00fM930>oW
J`3Rfg<0LV/M0:^YKP2a/h@0ZJb?0?Sil@00o`0Jooooo`800?l00P2P8?0:0?n000040:0Pl03oP000
X23`0?n00080X23`0P3oP0030:0Pl0P0oh000P2P8?0I0?n000030:0Pl03oP000oh0000d0oh001`2P
8?0<0?n000030:0Pl03oP000oh0001D0oh001`2P8?000`3oP000X23`0?n0000Y0?n000030:0Pl000
o`3ooooo00oooooo000>ooooo`800?l002@0k^?Q07iRGP1i@Sd0TdA00:0l?P2W=3T0^3m50;M4B`2X
?d@0XDI=0;U/LP2MGf@0R5MK0??;d`3`d=D0Sfie08Y[L@33YJd0_jB]0<ZZ]`2RNHL0Yfel09Q;F`2`
AE<0adQC0<Q0BP39@4P0bTA;0<97BP2cBdX0UTQ40;N0N@2ZQh40W8R109f>R@2NThl209Z?R`0909b>
R`2KSHX0VHn;09Z?R`2PUI40UHb709^BS@2JSh/0Vi2<0080W96=07T0Vi:=09jET02SVYD0Vi:=08El
M`1NDdl0C44m06QJE`2ANgd0^Hb@0=b?U`35HF/0`DaE0<e;D`3DBe80eDQ>0=Y>D@3GC540eDeA0=A;
DP3>BDh0dDiC0<]:CP2l?T40]CTk0:hf=`2a?3`0`E5@0<mSH@3HK6X0eVYX0=Y/J`3GIfH0fVQX0=EQ
I03=FUd0cemN0=IXI`3HKVh0df]Z0<UQHP30FEX0`emO0:=BB`2YM6@0oM[60?;J`03FaZ@0dL>P0<bo
W@2j[i<0Z9f709nFQ@2TVi80XYZG0:6KV`2TWZ00X9ZN0::MX`2PVj80XI^R0::KX`2RVj80WYNN0:6J
X@2PVJ00WYNN0;R_]01LDeP0:AhR02dS900^92<0:bHR0=SCc`3ak>H0k>CQ0>kThP3ain@0l^OQ0??T
g@3]g=80hlo40=K0/P33[IP0/YZ20:f@LP2TPf00Xh1F0:b4D`2dRE80bIeP0<jQGP3T]Fl0k[mg0?75
NP3meXH0on290?oRQP3ihGl0lmie0>_JJ03Te5X0hMAB0=_AB`3Hd4L0dle30=S@B@3>aSl0d<Po0<O0
<P3>b3H0a;hZ0=SA@03RfeT0m>j008b5=02PWV40/[B30:FXR@3ino000?l001[ooooo0P00o`020:0P
l0X0oh0000<0X23`0?n0002P8?000P2P8?030?n000<0X23`203oP0020:0Pl1P0oh0000<0X23`0=1@
N03oP0004@3oP0060:0Pl0<0oh0000<0X23`0?n0003oP000103oP0000`2P8?00oh000?n0000F0?n0
00X0X23`:03oP0000`2P8?000?l0ooooo`0?ooooo`003_ooool3003o000X0;RSWP1cB480PD0j09<j
?02P=c/0]D160;Y5B`2dAd`0XD550;5QI02VIFT0P4iA0>6h_03ifM`0Xh>603LJ7P20IFX0ekc509n1
S@2lUZ<0hJbl099>G@2Q@E00_dMC0<A5D037@dh0`dA;0;m;C02/B4H0U4]50;N5OP2VR800WHZ409Z;
QP2JSh/0Vi:=09Z@SP2KT8h0VHj<09Z@R`80Vi2<00@0VI2;09bCSP2LTHd0VXn;0P2LTHd0C02JTHX0
VI2909nHTP2LUHl0WYF@09fDS`2>Ph40KemO06Q>D@2EHFL0eGn80;Q>F039D5L0bTa?0<i:B03BC4T0
ddi90==<B@3EBdT0e4Y:0=M=C@3DBD`0eTi@0=E=D@3AC4l0c4Y<0;i0@P2c>3X0[cTi0:`h>@2`?3d0
`Ti?0=EQHP3AGel0dUiQ0=1NGP3@HV40d6AR0=acL03XP7l0k8B30=mgM03<I640]EmG09UND03_b[P0
k=K10<FdX02ZWH`0X9B60:FKTP2VWIP0XIVG0:NNX@2RVIh0XYbP0:>MX@2QVil0Y9jR0:6LXP2PVJ40
XINO09jHW02MUi/0WYRL09bFVP2ITiL0[jV]07=]L@0/9RP0=Rd^02XU8P0P7AP0aLBo0?;ak03ViN42
0>[Vi@0[0>cWi03]iN<0k^CR0?7Vi03bin<0mNKQ0?OVgP3agM80j]?50>74]03@[IT0_IQn0;B;J`2P
M540UFDo0:MfC@2VMDX0_91M0=F[L@3T_7h0kLN60?KARP3heH@0m=Ek0?KHMP3_ef/0j==P0>WFGP3[
ff40hMAB0=_BB@3<`cH0gME60=38>@3JcdP0f]1G0?;[P@2ITT40SHa;0;>eP`2TZ8L0n?[_003o000J
ooooo`<00?l03@3oP0040:0Pl0060?n0002P8?00oh000?n0002P8?00d51h1`3oP0020:0Pl1P0oh00
0P2P8?050?n000@0X23`4P3oP0060:0Pl0030=1@N02P8?00oh0001L0oh00102P8?000`3oP000X23`
0:0Pl0080:0Pl2<0oh0000<0X23`003o0?ooool03oooool000kooooo0`00o`00:P3Wg=P0NF9J07iC
BP2@C4/0TCLi0;M6C@2lAD/0_4U>0:Q1A02XDU<0/Vi_08eGE`2QMgP0m]CC0>O9b@1WCDh0YXfA0?WN
i@2XQi80]XbH0:McP01j>TX0/Ea/0:a3D@2kAe@0a4QC0<58C`2nCDl0Z4U509QCC02jRhD0YHJ109f:
QP2JRhP0VHj<09Z@SP2KTHl0W96?09Z?R`2KT8`0W96?09^@SP80VXn;03X0WY>?09R=R@2MTX`0WiB>
09^BR`2LTh`0WYF@09^BS@2MUI80WYJC0:FKV@2TU9@0XXF709mTJP31IVd0^4U@0<QAD`30Bd80^DDf
0;91;`2oC3T0c5=20=1B@`3BD4<0dD]20=A:A`3FBTT0eDU:0=M=C@3DC4`0eTi?0<i8B@38ATP0_ci2
0;ln@`2^<3@0]c`o0;<k?@2h@D<0`Dm?0<]NF`3>IF40e6aY0=I`K03EKf/0g7Ib0=1ZIP32Jf<0[ViT
0<FKS`2jWY<0YY><0:FHTP2NU980XYVJ0:2JVP2OVI/0YInS0P2OVId06`2PVYh0WIRL09nJWP2PVYh0
WIJL09bFVP2KUIT0W9JJ09jIW`2LUid0VIBJ0:^VZP24Oh<0=C4b02hX:00X92405QD@0;>b[@3elNh0
j>CQ0>[UhP3]i>80l>;O0?;Sh03ci=l0l^GO0?3Ug`020?7Vh00T0?7Xh@3ai^00lnSR0?GXh03fiMd0
l=kB0>[Gb@3Ma[P0d;>S0;jMS02IMF40Rem6091QA@2NJDX0Zg=@0<B;H03>U680fj=X0>F`K03X]fP0
k<=Y0>_;I03Sc5P0hmAC0<^m>03Jc4D0h<i>0;bW?02MT2X0n_6D0:ZSD`24Pd00]kZ50::VQ@3ino00
0?l06_ooool3003o0080X23`2P3oP0000`2P8?00oh000?n000070:0Pl0T0oh0000<0X23`0?n0003o
P0005P3oP0000`2P8?00d51h0?n000020?n000X0X23`3@3oP0070:0Pl0030=1@N02P8?00oh0001L0
oh00102P8?000`3oP000X23`0:0Pl0050:0Pl0030?n0002P8?00X23`00@0X23`2P3oP0040:0Pl140
oh0000<0X23`003o0?ooool03oooool000kooooo1000o`00<@2LTXT0HdPo09YYI02RF5T0Zd980<19
C`2jAD/0/TY;0:=7B02]Hf@0XVIV08=AD038WYl0dZn]0<JVY`2nX:80hL760:1kP`33V:80Yg=o08U<
F`2eJ7P0VSY80:XnB`2c?DT0_4E;0;i@D@2PAD00XEiF0:j1N`2DMg<0VhR409R:Q`2HSH/0V8j=09R>
S02KT8`0V8f909bAS@2LTHl0Vi2<09V>RP2JSh/0W96=09N<R02OU8h0W96;09^BR`2MU8d00P2LThh0
8`2NU980W9:@09jCT@2UTI80/8fA0<f:T@2gDe/0`DiC0<MAC`2gBC`0[4P`0;EK>@2H@1P0VSdD0;1=
9P2iCR`0aU@i0<]B?`3?DD80cde00=9=A03ED4L0e4a60=Q=BP3CBDT0dd]=0=A<D03BBe40bdQ=0<91
AP2o@DD0]3Tk0;8l?02[>CP0aeMF0080cf5P0500f6aZ0=EYIP2lH5X0W5Q?091QF@2]SXT0YI6@0:>G
U`2PUIT0X9NL0:2JWP2KUYX0VI>G09jHW02LUYP0ViFG09^FVP2NVId0WYRL09jGW@2OVId0WYNN09^F
W02JUI/0WIRO09RFV`2UXjP0V9>I03`g>`0Z9RL09R8Q01@@3@2TX9d0m_7^0>gShP3_hn<0ln7O0?SP
g03[d/d0k=?>0?KRf`3fhm`0mnKN0?CWg`3^in40jnSS0>cXi`3[jNX0k^[Y0?3[j03bj^P0mN[V0?KW
i03jin<0m]_G0>_8`P3G[jL0_i280;1oL@2QK5X0RE4j08A8;01f?1H0PDTF08]J5`2mV400g/=H0>??
EP3?_Cd0f/I;0>K@H024Ja/0U8<W0?_`UP2g/5l0OWhh0;>fO`2RYX<0n?[]003o01[ooooo1000o`00
0`3oP000X23`0?n0000>0?n000050:0Pl03oP000X23`0:0Pl03@D7P01`3oP0020:0Pl1P0oh0000<0
X23`0?n0003oP0000P3oP00?0:0Pl0d0oh000P2P8?030?n000030:0Pl03oP000oh0001@0oh00102P
8?000`3oP000X23`0:0Pl0030:0Pl0H0oh002P2P8?00103@D7P0oh000?n0003oP0040:0Pl100oh00
00<0X23`003o0?ooool03oooool000kooooo1000o`00Z03Cc/P0FD]207ACC03CW9T0YTQ=0;]8C`2i
AT/0]D]=0:U9B`2SDED0[fU[07i0@@1H8240S5UH0>fo_`3[`L80ejn`07Y=DP2bPhT0ejF^09aWL@2g
LGd0[e=P0;U?F`2P:c@0/ca00;]?C@2UBd<0XEiF0;V=Q01^DD/0L5mH09B5PP2ISX`0VXn=09R=R`2K
T8`0Vhj809f@RP2MSh`0XI>@09R=R@2KT8X0WI:<09^@RP2KTX/0VI2909fBSP2NThl0WI:>09bAS@2O
U980WI:@09f?SP2ZTI@0/HJ=0=65S`2lCUT0b4mD0<UBCP2_B3T0WdX[0?RfPP3W/W00aI140:5U702=
B@P0TdH>0:19702aDB/0^e8b0<ID>@3;DcX0d4lm0=9:?P3DBD80eT]80=E9BP3EBD`0f4]A0=E:D@3C
B4l0cdI=0=5:D037@TL0`Sm50;dl@@2i?Cl0ZRla0:`f=P2U@Sh0RD0j08eJEP2bT8h0XXj?0:6EU`2P
UI/0X9JN09bFVP2PVYh0VYBF09fGV@2LUi/0V9>G09^FW02MV9h0UY6G09^FW@2KUY`0WYVP09^FW@2M
Uj40WY^T09ZGWP2[ZJh0Ui:H02hX;00/9RP0:R@V01H@402QV9T0o?3`0?7QhP3dg^00o=kN0<RRW`1d
BdL0^96:0?oKd`3Yb;l0]iV?0;bSW03bhm`0k^KS0>gYj03/j^/0inKT0>STh@3ZiN80knSR0?C[iP3d
jN<0l^KP0?;Ug`3diN00nNKR0?SSgP3bfM@0kLk90>2j/@38WH`0cJ6407aD8`2hU4X0kM5^0>G>FP3E
`DP0h/]K0:B;9`1/DPL0[9`m0?S^S@2n^Eh0O7da0;2eN`2NY800nO_^003o01[ooooo1000o`020?n0
00030:0Pl03oP000oh0000L0oh0000<0X23`0?n0003oP0000P3oP0020:0Pl0030?n0002P8?00d51h
00P0oh0000<0X23`0?n0003oP0005@3oP0020:0Pl0<0oh00102P8?040?n000X0X23`403oP0000`2P
8?00oh000?n0000D0?n000@0X23`00D0oh000:0Pl02P8?00X23`0=1@N0080?n000T0X23`00<0d51h
0?n0002P8?000P2P8?0C0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`@00?l002L0mOKa07mh
L01E@S/0dJZS09Y<C@2cBTl0^4U?0;=9B`2cCe40XDQ<09=2B02AADT0KBDY08e9BP38R8P0iJVY0<25
Q`1Y:bh0SE1E0>N//P3XZk80_gR108lc?P2Q=d40XRXc0;Dn@P2nDDh0XdU10:=PF02nTXT0X8=m079O
F@1JBdP0MfUX09B6Q@2LTHl0Vhf:09b?R@2NTH/00P2OTHh0@P2MTX`0WY>=09jCS@2OU8h0VY6:09fD
S@2MTXh0W96=09fBSP2LTHd0WY>A09nAT02UTi<0ZH^=0;V8SP3@NHH0_dUE0<i=DP3:CD/0`eM:07`W
203>UEh0nm650?3=L@3acfd0hkYN0<^KA`2aNBh0Te8>09E;302KBA40ZThK0;aD:`35DS<0c58k0=5?
?`3?Bcl0ddY40=M9B03LBe00fDQ?0=M6C@3JBU<0eTI?0=U9DP3BADd0dDQ?0<a7BP32A4L0]4U80994
@02AFUL0]Y>A0:FATP2PUIT0WYFJ09jGWP2JU9P0W9JJ09^EV@2JUIT0WYVM09^FW02LUid0V9>I09bG
WP80WIRO02@0WiZQ09nIX`2IUYl0W9VR0:2MY02f/KL0THZA02TS9`0/9RP0;RDX01P?4P2OTiD0o>c]
0??Jg@3kgMd0fk:a07];A`2bPG`0kKjh0;f@RP1`B400E2lV08EXH03fiMh0ln[U0?3ZjP3Cclh0Sh^:
075]JP1RGEX0MW5]09^DSP3Cc<H0k^WU0>[UhP3/j>D20>cWi00E0?3XiP3di>D0n=kO0?oNf@3oh]80
QV8n0;fLF@3ceWP0i/mK0>G@F@2mZ3l0LEX007mX3`3QdfX0jn=h0<_7IP1iNbP0Zk5e09bRO03innh0
0?l001[ooooo1000o`000`2P8?00oh000?n0000K0?n000030:0Pl03oP000oh0001D0oh0000<0X23`
0?n0003oP0000`3oP0030:0Pl0L0oh002P2P8?0T0?n000@0X23`00@0oh000:0Pl02P8?00X23`0P3o
P000102P8?00oh000?n0003oP0020:0Pl0040?n0002P8?00X23`0:0Pl0H0oh00202P8?0@0?n00003
0:0Pl000o`3ooooo00oooooo000>ooooo`D00?l005D0_[fh04e5>P2NR7d0Qda909a2A02/ADP0[4A5
0;5:C@2TA4P0V3]309HlA@2L@T/0Rc8h07/R9P1l9RT0NR@W08DZ;`1i8bH0XE5D0=Z;T02PCU@0SRXd
0;Y;E031B4l0`dQ=0;i<C02XBDD0WUMA0;j=QP2VQh80Y8n<08MeL`1PDU40DD=207IXI`2FQh@0Wi2=
09f?S02NT8d0Wi6>0:>HU02NThl0W96=09Z?R`2KTXd0VY6<09bAS@2JSh/0WI:>09bAS@2NT8l0XI6A
0:F@S`2]RHd0`HR?0<a^NP38BUH0dDYA0<e8B@3>Edl0U3@L0:5M;P3och`0kla`0>[?I03_f6P0lmaZ
0?7GJ@3M_U@0f;EA0;jC=@2RL1/0TU8809U93P2[Cb00/d/T0<EB<`3@DS`0eDe10=Y<B03GATT0fdQ>
0=U6CP3IAU00fTA?0080fTM?00X0eTM;0=A<D034De40Y5=?09MPG@2eTI40YY:D0:2EV@2KUIT0WiRO
0P2LUI`209bGW@1209nJX02KV9l0VIJM09VFW@2OVJ<0W9NP09^HW`2MVZ<0X9fV09bIXP2LVJ00Yj:Y
0;F^]@25Oh40:B0S03@[;P0b9b/0710B0:6AU03ji^P0n=_M0?S?c@2MJfL0lkjh0>6^ZP2SM6h0N4e6
0:5jL`3?/JL0l]_C0?_/i`3UfmT0NW9`06mWI@2HThl0VYFA08V4P@1gLVl0AT4n05IACP3:`l40j>?P
0<g8a03HeM00iN;M0>SSh03]hn80mN7R0?[Nf`3ohMH0NEPg0;VJF@3]dg@0iM1I0>gMH`2PTBX0HU@0
0;>V=@3VgV40i=mW0=OBJP1oObT0ZZm_09JJM@3hn^d00?l06_ooool5003o01d0oh0000<0X23`0?n0
003oP0005@3oP0000`2P8?00oh000?n000030?n000<0X23`2P3oP0000`3@D7P0X23`0:0Pl0050:0P
l0`0oh0000<0X23`0?n0003oP000503oP0030:0Pl080oh000P2P8?001`3oP000d51h0?n0003oP000
X23`0?n0002P8?000`3oP0000`2P8?00oh000?n000040?n000050:0Pl03oP000d51h0:0Pl03oP000
1P2P8?0?0?n000030:0Pl000o`3ooooo00oooooo000>ooooo`D00?l002/0l?7/08V6O@1UFe40LTe6
095=C02GATD0Vd0o09Ph>@2O?3l0V3Dj09Pc>`2nEUl0Z3m60:@i?`2G:S00U2L]0:Hg?P2X>d40WCHj
0:10@P2/Be80XcQ00;4lA036BE40aTM>0;e9C02/B4P0WeAA0;f8Q02UPWh0WhZ50:>AS`2JS8/0MVQW
04m1@01DATD0Og5^09f?S02QTi00Wi6>09nDT02QUY80WY>?0080Vi:=07X0V8n:09jCS`2KT8`0WI:>
09bAS@2NT8l0Z9JF0:^ATP2cRXh0b8VB0<ERKP3<BUH0dTM>0==8B`3?D4X0/d@c098g603RVVP0mKec
0?K:L@3cd6X0mMMY0>kDI@3/eF<0lma/0??IJP3_dfP0gKMD0<BA>02aLRD0We4?0:Y<6030DRd0dE<l
0=E;@03EAD@0f4I90=a6C`3I@dh0eSm80=i7D03MATd0f4E;0=96B@33Cdh0Y5=?09ENF`2cTI00YY:D
0::GV`2MUi/0XijT0:2IX02QVZ40WiZQ09jIX02MVZ40W9VP09fJX@2IUYd0X9ZT09bHX@2OW:<0XIjW
09nLX`2MVZ40YZ6W0:FNY@2e[k<0M6]^02HM7P0d:R/0<bLY02<C502gY:H0on[/0>?5a@23Ee@0Q51;
0=2KU@32SHT0fjRT0?;3_@3ec<H0mmWA0?_Tg03nlN/0]ZbZ01/A3`28OW`0mo3Z0??/iP3dk>T0kn[W
0=oJe`2CRX/0N6m_0<6i]`2:QH40Qh9n08j;QP26PWl0^;2^0?[Wj@3fg]h0o^;G07aM@02gUeX0lMIk
0>CAF`3[h680Qg/;08Qn2`3Le4l0g=U>0>OTH`3Jf6/0PH4[0:J[J`2AUVh0n?[]003o01[ooooo1@00
o`00102P8?00oh000?n0003@D7PH0?n00080X23`5P3oP0020:0Pl0D0oh00102P8?0<0?n000D0X23`
303oP0000`2P8?00oh000?n0000D0?n000<0X23`0P3oP000102P8?00oh000?n0002P8?090?n00003
0:0Pl03oP000X23`00@0X23`00<0oh000=1@N03oP0001@3oP0020:0Pl0l0oh0000<0X23`003o0?oo
ool03oooool000kooooo1P00o`00J`3^kNT0a/>l08IgKP1dCdT0OTU3095>B02NCDX0WD9109`e>02M
<3D0[S]20;4j@02l@dX0_D590;e0B032@dh0`TA?0<17CP32CE<0^DE>09`T;@2b=Cd0bDE@0<Y8DP31
B4l0/dY>09e<B`30Q8<0ZH5o09j6PP2NShX0Vi2<09jCS`2CR8H0K65O04/m?01_HF00V8f909nDT02N
Thd0WiB>09fDS@2KTX/0WIB=09VBRP2MU8l0Vi:=09bCSP2NThl0WY2?0:FCT`2_TY@0/HB90=:?V031
FfD0d4eE0=56C@3FAd/0e4Y80=1<A`2c>Bh0Xc@P0:a:9`38LT40j9iQ0?ZlL`3mbGD0o=5c0?ODKP3b
e6H0kMAP0>gGGP3`eUd0l<mN0??3H@3QWe<0X4HA0<YH=P3DCch0eDI20=a7B`3JAdl0fDI>0=I0B@3J
A4d0fTE;0=E4B@3DBDh0`e5@09m@B`2FHel0/Y>A0:FCT`2TVId0X9ZN0::KXP2NUih0WiRO09jIW`2M
Vj00WIZQ09bIX02MVZ<0VYNP09nLY`2OVj@0XifW0080Y9nV03T0XijU0:6LXP2UWZD0/J^_06AKGP0[
8B00<BDU02`N7@0`7Qh0g<S70?o]jP35ZJH0[HN40>:e/P39V9@0[WAc0;AhM`2>Ee@0NDQ308]YH02_
UXl0n^_T0>KMf02j[j/0gmC@0=C9``2o]Zl0b;nh0>3Id`3omo@0d<S605Q>C@2SVIP0c<;108MoO@2T
Wi`0b/C40<g3a03gi>P0mMgM0?oSf`2ALeL0[HiG0?;HP`3Qcel0gmEB0:JN6@3>ac/0em<k0=cJA`3R
hU`0g]i`07eo:`2OYFL0RY1Z0?Sjk@00o`006_ooool6003o00030:0Pl03oP000oh0001P0oh000P2P
8?060?n000030:0Pl03oP000oh0000d0oh000P2P8?050?n000L0X23`2`3oP0040:0Pl0/0oh0000<0
X23`0?n0003oP000503oP0040:0Pl0040?n0002P8?00oh000:0Pl0<0oh0000@0X23`0?n0003oP000
X23`0P3oP0000`2P8?00oh000?n000030?n000040:0Pl03oP000oh000=1@N0H0oh000P2P8?0?0?n0
00030:0Pl000o`3ooooo00oooooo000>ooooo`P00?l00540k^[T0;JUWP2=L6X0PEI@091FDP2DBTL0
XD]:0:e;C02[@DD0ZcPm0;@k@02m@4H0_ce50<Q4C`39@dh0bTIA0<e;E@31@T/0]S@n0<<oBP3;@dl0
bdMB0<I9D@2iBdh0WdE50;IbL@2bQH80WX9n0:2?R02GS8H0VXn;09bAS@2PUI<0SH6105Y=C01OE500
Q7Ue09fBSP2OU8h0XIJ@09fDS@2LTh`0VY>;09fDS`2KTXd0W9>>0:6FTP2MShh0Uh:10:n?TP2fQH/0
eXjI0;mGH03?C580e4M=0=A3B03DADL0d4A30=E;B@39AD00]cl_0:Hj802J>AH0WDTJ0;A];`3BU4/0
ik=O0?C9J`3cdf`0imAH0>CGB`3[fE<0lMAL0?oAM@2/IR40^DlW0=5C?@3HBd80fDM80=Y7C@3GA4`0
0P3G@DX0D@3IA4X0edI;0<m4B@34De<0V4Y609a[I`2cUI<0Xi>D0:>JW@2QVZ40Y9fT0:2IX02QVZ40
X9^Q0:2NX`2NVj80WIZS09bIXP2LVJ@0WIZU09^FXP2HTY`0U8jH08f8S`26PHP0N7=i06eWJ`1lMWX0
C4=602dQ8@0f9RH0;1PG050h=P3bf=L0nn;N0?[Mf@3^c<X0[XV80>Fg]`3RZZ/0bhn?0<fCT@34U900
`J2I07]WH03`iMl0e/o909J;Q`28OGT0K6=L06QOF01@BD<0CTM108EmNP2UWIX0YYbK09B:R@2XWYd0
ZJ6O0=?=c@3Xh^@0l>GY0?3Oi@3bg=h0onGN0;>DO`2CLd@0m=R>0>3=IP3LdE<0`;T]0>7KA@3Cd300
g]e50>3PFP3RhGL0KG4M08jDEP2<TV`0n?[]003o000Jooooo`P00?l000<0X23`0?n0002P8?005`3o
P0020:0Pl1D0oh000P2P8?070?n000L0X23`2@3oP0040:0Pl0X0oh000P2P8?0=0?n000030=1@N03o
P000oh0000D0oh000`2P8?00103oP000X23`0:0Pl02P8?020?n000030=1@N03oP000oh0000D0oh00
00<0X23`0?n0003oP000303oP0040:0Pl0l0oh0000<0X23`003o0?ooool03oooool000kooooo2P00
o`00:03fjnL0d/2l0:R<R027H5/0Pdi:09IBC`2TEE40[55@0:i6A`2b@D<0^3m40;/l@`30?4L0aT1;
0<U3CP3<A500cdMC0<e5C`3@Ae40cDM@0<Y8D032CU40YD530:aNG02lQh<0X7mj09R4O@2JSHL0VHj:
09^@S02JShd0WI:@09N<RP1OE580BD0k06IKE`2;P7`0WY>=0:2ES`2LTh`209jESP80WIB=07H0X9F?
0:>AS`2SRHX0/X^@0;n6S@3HRiD0_E9K0<e:D03CB4d0e4E90=I5B03FAdT0cdE30=1<A`39Cd@0a5E2
0;M?=P2Q@b40V3lC08`j202BA`h0X6<T0;21>@3Wc600hmI90>SIC03YdU00ommd0<V>@02UAa@0dUXo
0==>?`3DAT80eD=40=U6C03H@T/0fD=<0=Y7C`3HAdh0dDI;0<ACD`2IBdT0WFaX0;:DTP2OSi00WiJI
09RAV02ESYH0TX^B08b5S027PXT0PGb307afP01gLG/0KV]f06QTLP1OFfX0G5MU04m9E@17A4d0@Sm6
04]6C@1:AD/0CdY>05aFFP0h;C40=RHY03/R9@0b51@0PV=Q0>S6a032X9h0TFm]06U:B02kVIT0lLO8
0>^i^03IXj40[Gah0<:KUP3oj>@0lNCN0>SPg@14@C`0?SHc09fETP2`ZjD0_;Na0:nZYP2=R8@0HEaI
06MRG`3IdLh0XIVF07mjM`24Og`0JfMV07A`L@3cj^d0l>7V0?;Nh03miN40fKb/07UE<@3XaXT0k]Am
0=k>G@32^3@0gmU70<k;;P3Lfd<0h>1J0>CUO`1LHA40OHE908jFK`3gnN`00?l06_ooool:003o0004
0:0Pl03oP000X23`0:0Pl1@0oh000P2P8?0D0?n00080X23`2@3oP0080:0Pl0P0oh00102P8?090?n0
0080X23`2P3oP00:0:0Pl0030?n0002P8?00X23`00<0X23`0P3oP0020:0Pl0080=1@N03oP000oh00
0?n0002P8?00oh000:0Pl03oP0030:0Pl0L0oh0000<0d51h0?n0003oP0000`3oP0040:0Pl0h0oh00
00<0X23`003o0?ooool03oooool000kooooo3000o`003P3omO<0imGA0;fQW@2FKfX0PTm;08i?BP2E
BTD0Y4i=0:U;B`2[A4L0VB`a0:D`>@2i?DP0a3i;0P3;@dd0T03@Ae40c4A>0<a6C@37C540^Da?09m7
AP2mOG/0Zh1j09EjL`2GQWl0UhZ409^@S02JShd0V8f;0:2ET`2OU980QGYh05U>BP17?3P0IEMD08Un
N02OU900XiZC0:6HT@2MU8d0W9><09nBS02VTY40ZH^=0;F8S@35QXh0eh6<0;i>F03?BE00ddQ?0==4
BP3EATX0dDM70<U8@`38DTP0`5M40:E7:`2<=a00RCT808i12@28@@<0Oc/007Dl001C9`00b:m40>?G
A`3VfTH0imE;0??JI03/_F40VTP>0<=G<`3BDC`0dTPn0=I6A@3FA4L0f4=90=Y4C@3F@d/0eTM=0<m7
B`30DE80Uda90:9bL02DN7L0J5YJ05UCE`1GD5L0CTM>04M0A`14?D@0AT5704I1B018@dX0BTA>04e7
D`1DD5h0FEES06EPKP1ZI700M75j07aiP023OXD0RhJ<0::MX@2BS8h0=BX^03`/;`11:2`0<Q@F07QH
F@1oH5d0GC/i07mMF`3<[Z`0jLW709E/JP3^_;/0_hj:08]OG020GeX0nnST0?W`j`3Sg]X0=34/065L
F03Ie=00kNST0?3]j03`jnP0kn[W0>_Vh`20NgP0^[Fa0?Sck`3ak>P0n_Kc08Z6Q@27Ph@0m>k`0>cQ
i@3_gn80m^;Q0?SMe029IDd0/XeS0?OHU@3Sbg40`;0o0=cCD03Ccch0gme<0=oOF`3Uj840GfHH07R0
A02=UFh0moW/003o01[ooooo3000o`030?n000030:0Pl03oP000oh000100oh000`2P8?090?n00003
0:0Pl03oP000oh0000L0oh000P2P8?080?n000L0X23`2P3oP0050:0Pl0P0oh000P2P8?020?n000d0
X23`1P3oP0080:0Pl0030?n0003@D7P0X23`00<0oh001@2P8?000`3oP000X23`0:0Pl0040:0Pl003
0?n0003@D7P0X23`0080X23`0P3oP0040:0Pl0h0oh0000<0X23`003o0?ooool03oooool000kooooo
3`00o`00Q03`iN40cKbe09V0N`1eE4d0OU=<08UHD@23BDD0aH600:]FF`2I=Cd0]3Y50;lkAP34?TL0
bT9<0<a4CP3>Adh0c4]@0<9>D@2[AdL0[5iL0;n5P@2LMg40Tgaf09>1O@2EQh@0UX^709R=R@2ISXX0
WI:>0:2ET@2MTXh0Q7Ue05I;A`12=c<0J5eK0966PP2QUY80WiB@09fBSP2SUI80Y92?0:f=T02fPhX0
cXJA0=AfQ031BUL0dd]E0=A7C`3DAD/0dDI90<e=BP33DdP0]UM107/f3`1kA`h0Zh0b0<:M@P3;Z4@0
aj@l0;fM=P2_TR`0R70>0:bM9P3XgT/0i=Y40>;FAP3/fEP0oMI]0:]V8@2^CB80d5Ll0=I>@03EAd<0
f4I70=Q3B@3IA4X0edA:0==4B03ABDd0_E9A08U4?`2OLg00VX:007a`L01eKg<0O7El07ehOP22Nh80
Qh6508^6RP2=R8h0THZA09NBV02JUI`0WiVS09bFX02MUj40WYVP0::MY02LUid0WIJM09NAU@2[YJT0
Pgeo034X:`0f:R`0=RLZ038P803?^kX0el:o0=k5`03lh=`0onKR0?7=bP34U900jkRe0>Jf/P2TOgT0
b:bX0?WWh`3`iN40o_O_0<>o]P1GD4P0?cPb05M@BP2GTX`0f=3=0<c7``2KUY<0>SDb0:ZWXP80hMcF
01L0em;>0;2]Z03FeM40kNcZ0>WSi@3[h>@0kmoR0?cTi03;Z:80JT@a0=:/Q@3]cI00b[5M0>KGL03H
dEH0f]I@0=kOG`3VjH80IVhK07Mo@`24S6D0n?[]003o000Jooooo`l00?l000@0X23`0?n0002P8?00
X23`0`3oP0000`2P8?00oh000?n0000:0?n00080X23`2`3oP0000`2P8?00oh000?n000050?n00080
X23`1`3oP0030:0Pl0l0oh001@2P8?080?n00080X23`5@3oP0040:0Pl0@0oh0000<0X23`0?n0003o
P0000P3oP000102P8?00oh000:0Pl02P8?030?n000030:0Pl03oP000oh0000<0oh0000@0X23`0=1@
N02P8?00X23`0P3oP0060:0Pl0d0oh0000<0X23`003o0?ooool03oooool000kooooo4@00o`006P3i
m?00fm;;0;6RV`2>NW40I4U20<NRW03la/H0/6EY0;Q@E`2k@d`0^Ca40;hlA031>d@0aSm60<U6C037
BTh0_Te?0:53@`2jL6d0]7mk09UfLP2CNWH0T7ij09>5PP2BQh<0VHj:0P2LSX/0@@2LTHd0YIZF09nD
TP1oM780F4e;04Ll>P1/HEd0T8F10:2ET@2TUY<0XXf<0;2=T@2jPX/0fH^H0=9/NP34Ae@0dTIA0=I6
C`3BAD/0cTQ90<I?B@32GTl0OC8C08mP:03SaWH0l=ed0>WNHP3Yg5T0jmmI0>kQGP3^hF40j]]T0=g?
D@3WfTh0i=M:0>KIC`3YeUH0omic0=VOE@2H@Q40c5Tl0==>?`3HBTH0dd=30=Q3A`3JAD/0f4E;0=M8
C03?B4`0^U5@08]:A02UOWT0ZiRD0::HU`2MUiT0VIBJ09jIW`2NV9`0XYbP09fGV`2LUYX0X9ZN09bE
W02QW:80WYVO0080W9NM03`0ViJL09RCV@2ET9@0Ui6E09NAT`2_ZJ/0HeeO02TP8@0f;2d09adN04i2
@P3di>@0o^WV0?oVhP3jfmH0h;fg0>6d[`3BWi/0`8f909U/I`2>KFH0nnCN0?CUh03aj><0al2h0<W2
^P3?b<80V96;05iGD@1QFU@0VI2;085hL`19@Ch0PGUf0:bWX@0m>C00RHEl04Y5?`2JUi80jn[U0>SY
i03Uhn@0j>;T0>_Pi03bgn<0oN3T0:J5P01W@Rl0^YQc0=2bO03Ha7d0V8d_0=WEFP3QhFL0i>N006ad
7`1jQ4D0Ph]T0?Sjk@00o`0Joooooa400?l000D0X23`0?n0003oP000oh000:0Pl00>0?n000<0X23`
2`3oP0000`2P8?00oh000?n000030?n000030:0Pl03oP000oh0000H0oh000`2P8?0@0?n000@0X23`
203oP0000`2P8?00oh000?n0000D0?n000<0X23`00@0oh000:0Pl02P8?00X23`1@3oP0020:0Pl003
0?n0002P8?00X23`00X0oh0000<0d51h0:0Pl03oP0000P3oP0080:0Pl0/0oh0000<0X23`003o0?oo
ool03oooool000kooooo5000o`00603]j>@0^k:]09>2N`2cUY00SUiJ09Q;B`2gD5@0`U5G0<A;DP2o
@4L0^SLo0<A1B@33@TL0b4e@0;A6A`2YBd/0`GMd0;AoN`2JMg<0SgMc09:0O02>PG/0THJ009R=R@80
VHj:0440Vi2<0:6FU02OU980WYBB07idLP1MDU00CD9006eRH02@P800XhZ=0;:;T02mOhX0gXZI0<YN
KP3<BUP0dTI?0=A4C@3CB4d0c4Y:0<EBB`2dF4T0IbD20=B`IP3`gGH0i]]K0>;LBP3QfdD0iN180>CM
A`3XgDl0j=YE0>_HF`3YeE`0j]IM0>OBF`3/dV40mmEa0?c;O`2NEB80^Tha0=9@@`3EBTL0eTE80=Q3
B@3LAdd0edE80==7B03@Bd`0]E1<08Q<A02[R8@0Xi6?09jEUP2OVi`0UI2F09VDVP2IU9P0WINK09NA
U@2HTYH0VI:I09VDVP2MV9h0UY6G09VDVP0209VDV00k09B?T`2FTID0UHnC09^EU`2/YZP0B49202`S
900e:b`08ADE089bLP3kinH0n=cI0=:ZZ02_PWd0bibF0>Jc[02IIV80]8Eo09E/IP1YC4@0mN7J0?CY
i@3Xh=d0BDA0048m>@1FDDd0DDU605UBC01OEU40KF9L09J9P`34]k40gM;<0=gEb`2:PGP0Qh1f03Xe
;`31_[T0lO3/0>KVi03Ti>@0iN?T0>STi@3VgMh0k]kQ0?WPh`2TQh<0OV5C09AfG01QBB<0DT@<0>;K
L@3PgFX0g^=l06]c7P1fPT80NXEK0?WkkP00o`006_oooolD003o00030:0Pl03oP000oh0000d0oh00
102P8?0?0?n00080X23`203oP0020:0Pl140oh00102P8?080?n000030:0Pl03oP000oh0001<0oh00
102P8?001@3oP000X23`0:0Pl03oP000X23`00<0oh000`2P8?001@3oP000X23`0:0Pl03oP000X23`
00/0oh0000<0X23`0?n0002P8?002@2P8?090?n000030:0Pl000o`3ooooo00oooooo000>oooooaH0
0?l003T0mO3/0=[=a`2`Ui80RUQG08e3A02QB4X0[de>0;]>D@32CE<0`DI;0<93BP2n@4@0_DE70;55
A@2^De80_gQf0:ikM`2IMW00TWUd08ikM@2=P7X0TXN309F:QP2GS8P0VXn;09bAS@2JT8h0WiFC0::H
UP2PUI<0Q7Ug05mDDP1EADD0MeeP0:5fO@2nO8P0hXZH0<EEI@3;AeD0dTE>0==3C03?A4T0cde=0<=B
BP2]E4@0MCD?0>c9N03[ffX0i=eA0>;OA03ShCl0hmln0>GL@@3Se4D0kmIH0?G?IP3caVT00P3gbG40
203hbW@0n/Mh0?oCU03;OU80XSDN0<i>A@3EBdT0dd970P3KB4h03@3C@TD0ddU90<];C02dE500RU5:
0;2ASP2QTI40WiJG09bGV`2GTYH0VIBJ09^FVP2IU9P00P2HTYH01P2FTIL0V9>I09ZEV`2GTYP0Ui:F
09VDV0<0UY6E02H0UHnA0:NQX`2PVYX0>C0a02hT9@0f:RX08Q@D0;BRXP3okNd0^iVH05XZ9P2kQ7l0
j[6Z0<nFT03V/Jd0o<_708QQG02[T8T0n^WR0?cckP3<al<0;2PU0;Fa[P3Ac<T0_[Jc059:A`0V7AP0
HeI@05iAB`1FBD40L6=K0<W0]P38_kH0bL:j089mN@2MW9P0lO3^0>KVi080i>CT0140i>CR0>CPh@3T
fMd0m^?Y0?oWj`2YSHX0G40d03PN1`1FB1L0hm]h0=kLK@3Nhgd0LG/T0760?`1ePUL0mo_]003o000J
oooooaH00?l000@0X23`0?n0003oP000d51h303oP0030:0Pl0h0oh000P2P8?080?n00080X23`4@3o
P0040:0Pl0P0oh0000<0X23`0?n0003oP0004`3oP0030:0Pl080oh0000@0X23`0?n0002P8?00X23`
103oP0020:0Pl0<0oh0000<0X23`0?n0003oP0000P3oP0000`2P8?00oh000?n000070?n000/0X23`
203oP0000`2P8?000?l0ooooo`0?ooooo`003_oooolH003o000G0?ofm@3JaLD0X7Yg08QEDP23@T00
TT910:E7B02eBdl0`4U=0<I9C`37BU00`4M<0:i1A02YCDh0_7Ec0;R3O@2IM6`0T7E^08alMP2=PWh0
SXF00968P`2ES8L00P2HShX0<P2MU8l0VI6>09jDTP2PUYD0W9:A08YjN`1hFf00Kd5;09UBH03SQiH0
aE1R0<m8E`3DAe00dD5:0=15BP3?BDX0b55;0;MGB@1d;`P0i;e`0>_IJ@3Ped`0hmi40>?O@03Tfch0
i]Q30>oFE@3baV<0_g/f0;EO;02nISP0b6m30=V3E03QSf00o:f60?fTQP2]>BX0bdM30=E:C@3GB4h0
eD9:0=U6CP3EA4T0cTI:0<Y<C`2^DE40U5aK0;2@T@2QTI80WI:F0`2JU9P0202KUYX0VYFI09bGV`2H
TiL0V9>I09ZEV`2GTYP0V9>I0P2ET9@0?02IU9P0UY:C09FATP2GTi@0ZZBV08N1P`0c:2`0=RLZ03PX
:@0d8B<0hlk=0?oYj03U`[h0`8n;0=6FTP2mOWT0chn>0<F;RP2JI680Rf9N0?KMf03diml0m^oY0>OT
g`1ZIF40GEQD09N?S02KTi00<RXW02DK6@2PUI<0fm3<0=;7`@3BbL80[:BL028K5@1MF5@0P7ai0;^j
^03]k>X0iNGS0>GUi@3Ti>@0hn?S0>WUiP3/hND0kmoR0?kXj`2LPgl0E3X]04@/4P1OD1`0g]Qf0>7Q
L@3Mi7d0Kg`T06Ui>01dPeX0mo_/003o01[ooooo6000o`000`3oP000d51h0:0Pl00<0?n000<0X23`
3@3oP0030:0Pl0L0oh000P2P8?0:0?n000030=1@N02P8?00X23`00L0X23`2@3oP0000`2P8?00oh00
0?n0000C0?n000H0X23`0`3oP0001@2P8?00d51h0?n0003oP000X23`0080oh000P2P8?040?n00080
X23`1@3oP000102P8?00oh000?n0003oP00;0:0Pl0P0oh0000<0X23`003o0?ooool03oooool000ko
oooo6P00o`00O@1nmWD0LNAR05_9B02nW9P0Xg=`09IGE@2RD500YTI:0:`oA`2a@4T0^TUA0;E>D`2]
EUL0Z6=P09m/J02MMW80U7Md08ahM02?OWP0SGmh08]oN@2=Pg`0T8N109><QP2HTH/0VY6>09V?SP2L
TY40Xi>C0:R;SP2^OhH0^G5m0=YkRP2oBE`0dDYJ0==5D@3EADl0dTE=0=17BP38BTL0b5M=08he6@2T
Ibl0l<]c0>[FGP3Ufdh0iMi80>GMA@3UfDD0o>IV0;jE=`2FBa@0]Dl^0;E6;02g@Bd0]Sl]0;@o;@2^
?Bd0^T@i0;Pf<@3=A4@0eDY=0=I7C@3EAD/0eTI=0==6B`3=BDh0`Ta?0:E?D@2QKW40/9:D0:2@T`2N
TiP0W9BJ09bEV`2NV9d0ViFI09NAU@2LUY/0VYBI09ZEVP2KUIX0V9>H09RCU`2FTID0UI2C09VCUP2E
TI<0UY6D09REUP2ZYjP0F59C02`R8`0l;2l0:AHH07eYJ`3`emP0`j6S0:f5Q03?XIh0dj2O0=bVY@37
SXd0eZ2N0<fIV@2>IVD0jm?@0?OZiP3YhMh0ZZFQ0:fVX`2@Qh<0OgE_08EjM02ZX9T0/ZRR08j3P01[
HEl0LFQS0<Jn]`2QVI<0W9ND08J1OP2b[Zd0jNOW0080i^KU0P3Ti>@04@3Ui><0j>CT0>_QhP3`h>40
n^KV08]bKP1A=bP0ARhB061C7`3OfWP0g=ib0=kUP`1WLb<0DEhY09fYR@3joO800?l001[ooooo6P00
o`001P1@T7P0P<000830003@D7P0oh000=1@N0P0oh0000@0d51h0:0Pl02h>;@0d51h2`3oP0020:0P
l0P0oh0000@0d51h0:0Pl02P8?00d51h203oP0000`3@D7P0X23`0:0Pl0040:0Pl0030=1@N03oP000
oh0000P0oh0000<0d51h0:0Pl03oP0004`3oP0000`3@D7P0X23`0:0Pl0020=1@N080X23`00<0d51h
0?n0003oP0000`3oP0040=1@N0030:0Pl03@D7P0d51h00D0oh000P3@D7P30?n000030=1@N03oP000
d51h00`0X23`203oP0000`2P8?000?l0ooooo`0?ooooo`003_oooolN003o001i0?oim02]V9<0YX5k
0;9mN@3DSY00WD]?09Ll@`2C>3d0VdI907/a<P2hOGl0jKVi09a_L@2PN7P0UWAb08mbKP2<M700SW]g
08]lM`2:OgT0SHAo0968P`2CRHL0V8f;09j?S02WSH`0]8N:0<b6T03FN8H0_4UJ0<e9F03BA500dDA=
0=95C@3AA4X0cDE70<i<BP36EDL0RRlD09YG8`3baG80l]IY0>WGE`3Vfdh0h]M90>gOFP3fg6h0XFdO
09E5402aDBL0_U<c0<ME>`3:Dcl0bTm00<e?@`3ACTH0d4]60=A:B03@ATH0dTI90=15B03>Ad/0ad]=
0;iAE02KDE80Zh>30:^BU@2OT9D0WY>I09bEW02MUYd0W9FL09ZCVP2KU9/0VY>J09bEW02LUYX0V9:F
09RCU`2FTID0UY2B09RAT`2ESi40V9:F09FATP2QWj00W9^I03Da<00`:2H0=b/[02HF5`36][L0dK^n
06mAD`2=Jf`0^YRG0;jKV@3W_kl0bI^H09IUH@2JKFX0gKNf0?_Sh@3einH0kN?Q079ZJ00e;BX06Q0>
01lD400a9R00B3dg0597@`1XGU`0OWAb08f6P02PVI<0IUiI07]fLP1nNWL0V9NE0?;`l@040>CTi00?
0>GThP3Vh^40k>;S0?7Sh`3bgM`0Nf9K04X`7`13;0d0GeDN0>;OOP3Mh7L0f>6804eH501jQ5l0lOSV
00800?l06_oooolN003o0080oh000P2P8?060?n000030:0Pl03oP000X23`00@0X23`203oP0020:0P
l0T0oh00102P8?080?n000X0X23`1`3oP0020:0Pl1@0oh000`2P8?030?n00080X23`0`3oP000103@
D7P0oh000:0Pl03oP0030:0Pl0030?n0002P8?00oh0000<0X23`2@3oP00<0:0Pl0P0oh000P00o`0@
ooooo`003_oooolO003o00190<6j/P1gJEh0N65C0=Ze[03@WiP0dYJE0:=QHP2HE5D0I2@T09MQH@3o
e=D0^8F908eEF02ZLgH0X79b09Q`KP2BLg00SgIa08mlMP2>OgX0T8=m0966PP2BQh<0WHj;0:F;RP2`
QXP0bXbA0<miPP2gBeP0c4]I0<m6D03AA4d0eDQ@0=54BP3BAD/0cDE70<i?B@32D4D0QBD<0:=K:@3`
_7<0nmMf0?;IH`3Wf5L0i]YD0>WJF@3Zcf00ZG/U091F3027@@<0VTXG0:997`2`D2X0_EHe0<9E>034
D3T0cE0n0<m=@03?B4@0d4Q80<m:C@34C4h0^UIH09ADE02/SXh0Xi2D09nDVP2JTiX0VY>K09fFWP2O
V:00VI:J09RAV00209nEW@0_09fFW@2ITYT0VI>G09J@U02ESi40V9:B09F?S`2HSi80UHb?0:jXZP27
Ph80;RPX034/:@0d;2X0;BDR0=gEdP3ainD0jM_J0>[Hf03cg]d0onGR0=Fb[P2_QX40_9>=058[9P2g
UI<0oNSU0?OXi@3Qe]@0eL_:0=?=c@2?RHT0?CTj02LS901AB4T0UXf>09jDT`1eJfT0Rh9m08b3O02Q
VI@0ZJBP05EACP2<RhT0l_7_0>CThP3UiN<00`3Ti>@03@3Vh^<0jn7R0?3RhP3/em@0KeI?04P_6`11
:PX0IedT0>7ONP3Ni7X0d=Z405EO8`37cK<00`00o`0Joooooal00?l00P3oP0000`2P8?00oh000?n0
00030?n000030:0Pl03oP000oh000080oh001@2P8?060?n00080X23`2P3oP0040:0Pl0X0oh002@2P
8?050?n000030:0Pl03oP000oh0001<0oh002P2P8?001@3oP000d51h0?n0002P8?00oh0000<0X23`
0`3oP0020:0Pl0X0oh002`2P8?080?n000<00?l04?ooool000kooooo7`00o`008@3Mg]P0LFmR04i7
=`1fIUH0b;6Q0?KAb03AY9h0`Hj:0;5kN@23DE00^XR90>N`]@28Be00OT5608mGF02JJ6L0WW1`09ad
LP2CM740TWIb09AmM`2AOWP0T85j09R5P@2LPX40ZH620<:7R`3:Nh40]DmJ0<M=F03?Ae40dDE>0=95
C@020=95B`1E0=A7C@3?AdT0cde=0<E@A`2F<Q/0U48J0=^KF`3jbWH0mmA`0>cBH`3VdUT0k]YT0?CI
KP3/bVP0e:]A0;F5<`2QJAh0UE@@08e61P2D@`/0Uc`=0:m78P36DcP0cU110<i>A@36BDL0`U1@0;=G
F02BG5d0ZYFD09^?T`2LUI`0VIBJ09VDV`2LUId0WIJN09RAV@2KU9/0WiFM09^DV`2LUI`0VI:I09VC
U`2MUi/0U8j@09NAT`2DSY00UHb?09V@T@2cZZ/0HeeM030[:00c;R/07QTE05aGD`3`kNP0jnSS0>gU
h`3`i>@0m>CT0?WQg`3C[J`0hkNc0:QoN@2JMFl0mMKA0?gVh03oknP0YYND04a2@01KEED0LFe^04Q6
B@0U8bH0:B@X04i8BP2LTi@0e/c;0??Yi`2]Y9l0]jj/0>SSg`25PGh0c<_90>c[j@020>GUh`80iNGU
00h0i>CT0>OSi03Xg]l0mNGU0>C?c01VCT80AB`F048^2@1`JRT0gn9g0=oVOP31bG`0UYi]0?Kjj@<0
0?l06_oooolO003o00030:0Pl03oP000X23`00D0oh0000<0X23`0?n0003oP0001@3oP0040:0Pl0@0
oh000P2P8?0<0?n000@0X23`2`3oP0070:0Pl0<0oh0000<0d51h0?n0003oP000503oP0030:0Pl003
0?n0002P8?00X23`00@0X23`0P3oP0020:0Pl0L0oh00102P8?020?n000040:0Pl03oP000oh000:0P
l080oh002@2P8?000`3oP000X23`0?n000070?n000<00?l04?ooool000kooooo7`00o`00B03fn?<0
/K:Z06=TEP1=BSL0R7eY0<jiZ03=/:80/hf40=R]Y`2lSh`0YgMg0<FBU@38TIH0/gZ00;EmP02XKG40
SU=I09aTI`2RKfh0X7=^09agK`2EMfl0TWUb09IoN@2IO7P0Xg]k0;Z1Q`33N7l0]5=N0<YCG@3;B500
d4U@0=56C@3BAdh0e4M?0=95C@3AAT/0e4U>0=9=CP3>DDd0Z3LY098/4`2eGCL0i9eW0?_2O@3jcGP0
l=5[0>gFIP3[eV40m=mZ0?CMJ@3_f6H0iLUL0=VhD@3AZDX0gJIF0;AY;`2O@QL0bELl0<]B@@36CdL0
^U5>0:]JE`2AIF@0YYRH09R?TP2HTiT0VIBJ09^FW02IU9X0Ui:H09VBV@<0VYBH03l0VI:I09B?U@2F
TIL0VIBJ09JAU@2ET9@0THf>09B>T02PVYX0YijO03`d<P0c:bT0=2`Z01PC402MV9D0moC_0>WVh@3[
hn40l>;R0?GSh`3cemH0ZGen0=JRX@3IZJL0o]OB0?WKd`3PaK`0Yi280;NVW`37_;X0WiVI08b8R@1a
K700CTU=03Xd>00X8R@06aDG04Ln?`1mMG<0FU9@071XIP3>bLH0JfMT0>WXiP3XinD0i>CR0>CVh`3T
i>@0hn?S0>GSi03Vh>80j=kO0?WYj@3Ha;d0GDHh04Pb6P0m;040RXDg0=WOL`3RjXL0a/n@0>7Wa@3m
ooD00`00o`0Joooooal00?l000@0X23`0?n0002P8?00X23`1P3oP0000`2P8?00d51h0?n000020:0P
l0<0oh001@2P8?000`3oP000X23`0:0Pl00=0?n000D0X23`303oP0050:0Pl080oh0000<0d51h0?n0
003oP0004`3oP0040:0Pl0030?n0002P8?00X23`00D0X23`2`3oP0050:0Pl0D0oh002P2P8?000`3o
P000X23`0?n000060?n000040:0Pl000o`000?l0003o013ooooo000>ooooob400?l007H0eMK>07j0
LP1LFDP0LFEE07UXF01MACT0d;:X09E`JP3<Xil0`9BD0=NYZ`3LZjh0kK^l0<2<SP2/LGL0WF9V08MA
D@1nCDT0SF9K09ekL@2HNW00V7aa09QgL02PMg<0]W]m0;icN02YBU80`U5I0<U<DP3=C540d4]@0=5:
D03@BDl0dDQ?0==8C`3EB4h0eT]@0==;C`3ED5<0`dM50:4_902B;QL0[5Lb0=B;F03e_G<0n<mc0?CA
J`3beVP0kmIR0>gHH`3_g6H0kmYW0?CHK@3og7l0kkI_09554@30FCH0aUHn0<=EB02eEdl0WeQD09Ud
LP2NU9D0ViFI09JAU`2IU9X0VYFK09VDVP2MV9h0ViBK09^EV@2HTIP0W9FL09ZEV`2GTYP0UY6G09F@
UP2ET9L0UY6G092;S`2:QXL0WYZI08b6QP0[8b40=bl]030X9P0V8Ah0d/k;0?7]jP3Xi>40kN?T0>oO
hP3ghN@0kloB0:5`M030QXT0_hN60?W>b02eU8/0aJRP071ID@2hYj00o?;`0?3ZjP3]jn`0k>[[0>GQ
hP3EdM80al?40:>OX02<R8T0R8:40:bVYP22O7`0J6AS06aXI@3^kN/0inOU0P3SiN803`3Ti>@0iN?T
0>KRh`3Wg^40j]_N0?g[j@38/ZL0DS/Y04@_4P0j;000ZJM?0=ONMP3TkI@0hNNg0?_nj@04003o01[o
oooo8@00o`030:0Pl080oh0000<0X23`0?n0002P8?001P3oP000102P8?00oh000?n0003oP0070:0P
l0l0oh00102P8?000`3@D7P0oh000?n000080?n000@0X23`0P3oP0000`3@D7P0oh000?n0000C0?n0
00@0X23`00<0oh000:0Pl02P8?001@2P8?050?n000030:0Pl03oP000X23`00D0X23`1@3oP0000`3@
D7P0oh000?n0000:0:0Pl0030?n0002P8?00oh0000H0oh001000o`0@ooooo`003_oooolR003o000R
0>c]i`2l_;@0UY:7081hK@1@A3P0R7I/0:N?Q@2hWI@0d;:Z09E`JP3E/:X0n]OC0<bVX`2AIF@0X7Ac
0:5hMP2XPG`0QV5I071@A@22HUD0V7Q[0:5kL02XMg00]gYg0<9dM02=;S80[T550<=?DP34C4h0aTU=
0<M9C03:BDd0d4i@0==<D080dDU=04<0dTU@0=5:D03@BDd0dDm?0<Q=B02^>Bl0UBXF0:Q::@3FQ5@0
jj=X0?VjM@3la7L0o<ag0?S@L@3ecf`0ll]Y0?W=M03odh/0YFH`0:=9902oFd40_5]:0:mKD02@Ddh0
XH>109nEUP2OVId0WYRL09ZDV02ITYT0Ui2H09bEW@2GT9P0TX^B08n:T@2>RI00Q7n608=nQ@20Nh80
N7=j06QUKP1UHFP0GUUP04=1A01eLG80K6IX03`f=P1JDE80:B0Q04m9B@3^j^T0jNGT0>[Ti03^h^@0
lmkS0?cOi03:XZX0TV5W0<63QP2UJ6L0]hJ108eXH02YSXD0]jJN0>SMe`3]j>@0inKT00<0i^KT0P3X
j>H02@3YinP0j^SY0>KTi@3Xi^L0`l7108j=R`3Kf]P0k>c/0>GUi@030>?Ui00>0>GSi03Yh><0k=gR
0>kNh@3njnL0X8Ym04Tc7010;@`0?S<00<W;J`3Lhh@0i^jU0??fe`3ko?@4003o01[ooooo8P00o`00
0`2P8?00oh000?n000050?n000030=1@N02P8?00oh000080oh002`2P8?0@0?n000030:0Pl03oP000
X23`00@0X23`1`3oP0050:0Pl0030?n0003@D7P0oh000140oh0000L0X23`0?n0003oP000X23`0?n0
002P8?00oh0000H0X23`00@0oh000:0Pl03oP000oh000`2P8?020?n000/0X23`00<0d51h0?n0002P
8?002P2P8?080?n000030:0Pl000o`000?l000800?l04?ooool000kooooo9@00o`00A`3^k^H0e=37
0:ROUP2QU8/0/::G0<JeZ`1F?S@0WHEk0>7:`P3Qb/@0]i^G0;FIUP3A]K80lm[F0=c3_P2US8D0Q6aR
071EBP1mGE80T6EL0:mhL`36PWl0UDA109Ti>@2_ADD0/dE60;U7A`2nBT/0`TY;0<M;C@3:C4d0c4]?
0<m<D@3<BDl0dD]B0<i9CP3BBe40eE1E0=9@DP3;CT`0^40i09ha7@2J=AT0XT@P0;AM<039ND@0dha<
0>RUG`3c/f/0n;Uf0?o7SP3/Z7/0VT4Q0;QH@P2fGDd0YeeB08UDD02LPX80PgQl07ihO01hLWH0KFM[
06QQJ01PFF40FU=K04Y3B`1<AD`0CdQ@04Y5B`1;AT`0E4mE0080F5=J02<0Ee9I065LH`1WHVP0NWQk
092<S@12?Sl0?cTi069LG00T7Qh0TH^;0?Gal03Vh^40j^CT0>kOhP3hhNL0l]?I0<BKX@3Y^;`0`HJ6
091ED@2NKfT0`ijF0=Rm]P3ii]l0l^CQ0>cRh03[hn00jnCN0>cSgP3[i=h0j>?M0>SUh03Whn00i^GS
0>OUiP020>GUi@040<O7a@3YjNL0iNGU0>?Sh`80hnGT00h0iNGU0>OSi03Zg^80k=cO0?CPh@3`fmH0
KUM704D`4`0h:@00MFhZ0=OKMP3Tji/0kOC00?_nj`D00?l06_oooolU003o00030:0Pl03oP000oh00
00<0oh0000<0X23`0?n0003oP000103oP0000`2P8?00oh000?n000060:0Pl1<0oh003`2P8?000`3o
P000d51h0?n000050?n000X0X23`103oP0020:0Pl0030?n0002P8?00oh0000H0X23`103oP000102P
8?00oh000?n0003oP00=0:0Pl0030?n0002P8?00X23`00P0X23`00<0oh000:0Pl03oP0001P3oP005
003o013ooooo000>ooooobP00?l000X0moC_0>COf@2m]Zl0QGac08j4NP2XWiH0^k:[0=;9a03_iN<0
ooKe0`00o`00LP3fkNP0fm3:0;ZYXP2GOWT0SFaU08mRG02:DDX0TDM109Y1?@2R@3d0Z40m0:Ln>`2d
ATD0]TA40;m9B@35CU00`d]=0<A<CP3:Ce80bdiB0<U;CP3>CE40d4mC0=5ADP3?Cdl0c4m;0<97?`2g
?S<0/CT[09l/6@2M;AL0Wc<I0:4i702gE3L0`VA;0=enJ02S?Bh0]U550;IOEP2JEE00T6=P089]K@1K
EEL0GEMK05]FFP1LEUX0GUQL069HH01[HFT0JEmW07E/L@1lLWX0OgUm08N1Q@29PhL0RH:908f6S@2A
Rhl0UI2C096=SP2/Z:L0RXJ502dY:00X9240:RHS02`X9@3EdLh0lNgZ0>OSh03Yi>40kn7Q0?[TiP3_
dM<0[8F60:UlN@2cPW`0Y7Q_0?WBb`3ge/l0hlBo0?7He03dhMd0mN;N0?OPfP3fg]@0n^3C0?_Qe03f
hmD0l>;G0>cSfP3Yi=h0jNKQ0>KUh@3Jf]P0WIfM0>c/k03UiNL0i>CV0>;Th`3Ti>@0i^CU0>WPh`3/
gN00k]cL0?_Vh`2kXY/0BS4M040/1`18?P40aL=`0=_TO`3[lkL0n?gM0?_mlPD00?l06_oooolX003o
0080X23`1P3oP0000`2P8?00oh00003o0002003o00030:0Pl03oP000oh000080X23`503oP00=0:0P
l0<0oh0000<0d51h0?n0003oP0004P3oP00=0:0Pl0030=1@N02P8?00oh0000<0oh000P2P8?070?n0
00<0X23`00<0d51h0?n0002P8?002@2P8?080?n000030:0Pl000o`000?l000<00?l04?ooool000ko
oooo:`00o`00103^k^H0emO?0>KVgP3jnO@9003o001M0?oflP3ah=T0f<6i0;^JT`2KJf@0RTe808M0
?02@@C`0Ud8o09e2?`2M>cP0YClm0:i4A02aAD<0]TI50;a:BP2mBDX0`T]=0<M?D038CDl0c51B0<a=
D03?C540cTa>0=5<C`3AC4d0d4]<0<e;B`34A440^chl0;4g=02W=2l0XS8^0;I9A02iF580[UeJ08U=
C02GLG00WHb>09:<SP2AS900Ui:F09RBUP2ESi<0V8nD09jEVP2QV9d0Vi:G09ZAUP2KUIL0W9JH09J@
TP2ESi<0VYBF09F?T@2CSXh0VIFD0:^WY01HE540920M034]:P0F4Pl0I61M0?7`k03Zi^<0jNCQ0>_Q
h03`h>00n>3P0?SHf@3Q^KT0g:bX0=JXX03meLd0eK2Z0<FTW`1WAD<0/Y>A0?oRhP3kfML0n<_60>Nb
ZP3BW900cij?0>>l[@3efL/0m^CH0?3Vg03Zi]/0inCM0>?SgP3MgM/0i^KT0080i>CT00l0hnGT0>CT
i03WhN<0jMoP0>_Kf`3ch=`0mn3H07]TE013:a40>BT008f6>03RhhD0g^N;0?7fc@3koNl01P00o`0J
ooooob/00?l0102P8?09003o00@0oh0000<0d51h0?n0003oP0007P3oP0000`2P8?00oh000?n0000C
0?n000<0X23`00<0oh000:0Pl02P8?001@2P8?060?n000<0X23`2@3oP00=0:0Pl0030?n0002P8?00
oh0000D0oh0000<0X23`003o0000o`001000o`0@ooooo`003_ooooll003o000E0?;QgP3:/Jd0YhJ1
099YH`21CdP0Qd]308e4?P2B?c/0W44n0:4o?02T?SX0YSdj0:e1?`2bA4<0_4a;0;m=C@2nC4`0a4i@
0<UAD`3:Ce40bDe?0080cdiC00h0dDiD0=1=DP3>CE80ce5E0<a?D`34CDl0`EAG0;UMGP2JDe40PDm>
0:F7Q`2IRh`0Thf?09:<SP80U8j@0P2CSHl0@02ESi40V8nB09B;SP2DSY00UHnA09B>T02BSXd0TH^=
09B>T02ARhd0T8Z:0::MVP2DSh`0>C@a02`W900b;BX061@C0:FQX03elO00j>;R0>_Sh@3_hN40m^;S
0?GKfP3E/k80[h>20;N1O`2MJFD0aIRE0:b4PP3B[:/0YX1o0>6j^`3ohN80iJn_0:1BD02J@Cd0TCP`
08Lg;02;CD00Wg5R0<Z]W@3Yf<P0jn;A0>KSe03Yj=d0inSP0>CUg`3Ui^40hn?Q0>?Ui03Th^<0j=oP
0>_Mg03_g]L0o^[O0<:]W013;Q<0>RP005U>403?bV`0fmaf0>O]XP3jo>@7003o01[ooooo?000o`00
103@D7P0oh000:0Pl02P8?0M0?n000030:0Pl03oP000oh000180oh00102P8?000`3oP000X23`0:0P
l0040:0Pl0030?n0002P8?00X23`0080oh0000D0X23`0?n0002P8?00oh000:0Pl0050?n00080X23`
103oP0090:0Pl0X0oh001`00o`0@ooooo`003_ooooln003o000R0?ohl`3ei^40g/O10<JUWP2YO7L0
TEYG08I5@@2@AT<0Rchh09I3?@2K@cl0WD8m0:A5@@2T@Sl0ZD=10;97AP2iBDP0_TY;0<A=C`3:Ce@0
bdiD0<]<D`3;C5D0cDiG0<e@F03:CUH0a55H0;aGF`2aGf40PTI609E]K@2USHd0U8V908n9R`<0T8Z<
0480ShV;09>=S@2BS8`0UHb?0968R`2DRhh0Thf?096;R`2@S8/0SXR:08b6QP2>R8P0T8^80:JQWP1Q
G5T0:bHS03H^;00U7A/0>cDe0=oIf@3_jNT0jn7P0>oQh@3dh^80n>;T0;bPW`31WY`0k<2o0>Nd/`2I
JFP0OE=D0:f6Q`3CZj`0gJna0?oDeP3b][P0Rd520:M9B@33Ged0`fUQ0;9UF`2@ETP0Ich/0615<01Q
DcT0NG9H0;flX03/k]P0i^_G0>CXf@3SimT0hnKK0>?Tg03Wi=d0j]oI0>gLdP3ch]00mnK<089_C`0j
:@00>Rl00:BOC@3Ui7X0g=ii0?3e_P3koNl7003o01[ooooo?P00o`001@3oP000X23`0?n0003oP000
X23`01T0oh000P2P8?0D0?n000X0X23`103oP0000`3@D7P0X23`0:0Pl0070?n000@0X23`1P3oP005
0:0Pl0/0oh0000<0X23`003o0000o`001@00o`0@ooooo`003_oooom2003o000N0?oclP3_fmX0fKfj
0;JET02NMFl0ReaD085;@@24AC`0RT@l09E6@@2PB4@0Y4@o0:Po?02/?Sd0]TI50;U6B@2h@dT0^dA:
0<18D@33BeD0`TeF0<1>EP2nEUd0]EmR09MCE020DU80Y8J609R8R@2CRH/0SXR:0P2@RX`0@`2?QXT0
THR;0968R`2DRhh0ThZ=0927RP2BQh/0U8V=09:<SP2<QXP0S8J608f7Q`2@RXX0V96?08j6P`0g;bd0
<BTW03/b<`0L4a@0MFa_0?K]kP3^h^@0lMkP0?CNh03jh><0nMoR0=o1``3;ZJP0`YbK09]bL02WPh@0
jL_=0?oOiP3L/KP0MCLl0=j?TP31J6X0W3hn0<a_JP2oK6@0UEM<08QNCP2OQW80ZIf50:2KO@25QF40
/[B<0=ON/P35cjD0fnO10=oZb03Sk<l0i^_D0>CWdP3WiM00jmk;0>kNa03kjlL0a[R;04<c0010=P00
NG@H0=GGJP3Hgfl0iNb?0?KieP3ko?@01`00o`0Joooood800?l00P2P8?020?n000030:0Pl03oP000
oh0001<0oh0000<0X23`0?n0003oP0004P3oP0040:0Pl0030?n0002P8?00X23`00@0X23`0`3oP000
102P8?00d51h0:0Pl02P8?050?n00080X23`00<0oh000:0Pl03oP0005`3oP0000`2P8?000?l0003o
0005003o013ooooo000>ooooodH00?l001X0o>gX0>SDc@3:[JD0ZhIn09Q[I@2:EDl0S4m:08Y1?02H
AD40W4910:12@02P?3`0YSm00:Hl@02Y?440Zci40:e2B02cC500Ze5C09]CE01lAT@0UW=_09f8P`2C
QH80TXZ808j9QP80SXR80480ShJ70968R`2?QXT0SXF80927RP2AR8/0ThR<08n4R02DRhh0RhF708f7
Q`2<QXH0S8N409bFT`1FCT`0:b<Q03L^;`0b:BX08QTL0;fg^@3gk?00l^?V0?7Mg`2XRhl0[XnD0>W:
c`3mgN00kl_;0=>`[P2FM780m]gL0?[Ti`3oj>l0_Y>L07`c>P2bEU/0ZD950<=MF`37L6L0TTi309me
I`3Xdl80[ZRB0820I01hNEL0NW]A08b<FP2<SeH0HFP_06ikA@26U640]lBI0<7<Y03?d:h0hMfj0>kP
_@3gi[X0i=FJ07a`:021Mb80Yj8n0=?BG03MhfT0gNAj0>[cY03jo>P8003o01[oooooAP00o`030?n0
0080X23`403oP0000`2P8?00oh000?n0000C0?n000@0X23`00<0oh000:0Pl02P8?001@2P8?020?n0
00040:0Pl03@D7P0X23`0:0Pl0D0oh0000<0X23`0?n0002P8?00603oP0000`3@D7P00?l0003o0006
003o013ooooo000>ooooodT00?l00240ooCc0?OUh`3Wd/l0eKVf0:b8P`2GIf<0SEIC08Q7@`2=@Sd0
TSlk09Y1?@2N@3h0Xd520:92@`2PB4H0TDI105lT8027G5D0X8El09Z:O@2@QWX0SXEk08f6OP2<QGl0
SXJ308b7Q02?RHT0SHN708^5Q@2<PhH0T8N:0966RP2>PhL00P2>QHH0>02BRHX0RX62092;R02;Q880
<2LX03<X;00e:Rh06Q4D05UCE`3Yi>P0kNO[0?CXk03`fn80U7In09EdN`3YaLT0j/?60;fFU`3B[jd0
Of5O0<>/[03eh^@0onW_0=:W/02;@TT0bV]a0<IMH@37IF80]FQN08mJC03TbKP0QW]Y06]VD02ASG80
SXIR07Q[?P1UFAl0HePF07Qd;01[MC00IgHe06Ih?P1IIS40Gf4_07E]?02KREL0VHE809B4;`2/XCL0
e<a@0=GBC@3MhEH0e=eP0>?/T@3/m;/0O_md2000o`0JooooodT00?l00P2P8?020?n000030=1@N03o
P000oh0000T0oh0000<0X23`0?n0002P8?00503oP0040:0Pl0030?n0002P8?00X23`00@0X23`103o
P0040:0Pl0D0oh000P2P8?0I0?n0000308300000o`000?l000H00?l04?ooool000koooooC@00o`00
E`20nWT0nNCQ0>oBcP3L]k40b9VC0:efL@2PHeh0UU9?099;A`2=B4<0O3df06Td;01hD4H0[i>709R7
M@2CR780S8I/08b6K@2<QW00S8Md08Z4M02:QWX0SHUn08V4OP29Q800R8>008b4PP2=Ph@0SXB308f3
P@2:P7h0SHAo09B;QP2TViH0F51<03L];00j<34091/N03T`<`3@b/`0k>[[0>KQi@3[h>H0l=oW0?KO
i`3eeml0]9BI081PH`36Z:P0iLW809EmO@2`WYl0ln3T0?WPiP3oeMl0ZemY0:m@F03;I6P0b6YX0:=M
E@2VN6/0/I^=05I??@3Of/H0em2f075Q?`1TCb00b[Ef0:JBB@2_Y5H0TiE:06af<@1]McP0J6h`06eY
:P1[H1h0JeTA06UG0@2aY3@0f]5>0<g;>03KgTL0e]e?0>7ZM`3VkJL0mogI07koN@08003o01[ooooo
C@00o`000`20`000X23`0?n000020?n000030:0Pl03oP000oh0000@0oh0000<0X23`0?n0003oP000
4`3oP0000`3@D7P0X23`0:0Pl0020:0Pl0030?n0002P8?00X23`00H0X23`0P3oP000102P8?00d51h
0:0Pl02P8?060?n000030:0Pl03oP000X23`01L0oh0000<0D91h003o0000o`001P00o`0@ooooo`00
3_oooomB003o001B0?oel`3ki^<0jm;>0=Ri]P2kW9T0RVmX0:nISP3WelP0jMk:0<BoX@2MVgD0VIM^
092?H@2;RUh0QhAK08R6H026QfD0QXIZ08F2K`25PW<0RXIm08=oMP2;PWd0Rh1j08j1N02?PGH0V8Ym
0:RLSP22MVX0>B`T03`a;@0R6QL0@Sdj0;jj^@3al>h0i^GS0>GSi03YhnL0kN;X0?[]m02`WjD0PVmc
0;^XZP2gYjP0ZifM0;R/[03/gn80mN3W0=Ri`@3R[[X0oJnm0;1BH02lEV40`6AW0:5KF@2WNW@0VX=k
06AJCP24OF/0QWYR05I28@2DNDX0k]>@0=k7N`2[Vdh0iMjJ07]g>01VH2@0Mfl`07a^9@1jJQD0UXLR
0<c0BP3FcTD0b<La0=KJ?`3Jh4`0gNIU0>G_S`3_mLL0n_k]07gnN`P00?l06_oooomB003o00030?n0
002P8?00oh000080oh0000<0X23`0?n0003oP0002P3oP0000`2P8?00oh000?n000080?n000@0X23`
00<0oh000:0Pl02P8?00102P8?060?n00080X23`1`3oP0000`2P8?00oh000?n0000G0?n00003052@
N000o`000?l000H00?l04?ooool000koooooE`00o`00B`3onO<0nOG/0?Oci`3`kmd0f=Rn0<72X02h
^980[Zn40:>TN02NWG40V9U_08nDK024R6D0PhI[08F4K`25Q780OgU[08]oL@2EQGD0VXQb09^7KP2/
V7d0R7MK03h^5011<AX0<B8?03P`7@3=a[@0n_CT0>_Xf@3WiMT0jNKM0>cTh@3[hn00l>SV0=S@cP3U
fmX0mng/0>cWi03Zi^D0lN_[0>kVj@3jjNl0d;:l06/mB02XHG40]61`0;aRKP2nJg<0YFUY08aVH`2_
W9H0Edi50;ngZP3Bak<0G4T[0:69G@3/dYL0k=F?0:nNFP2gZg40M6L`07m^=P22LB`0LV0<0;6P>03O
dEH0e<e10<c8<@3>cc<0fn970=SPE`3TkH80gnJP0?WmhP0:003o01[oooooE`00o`000`3oP000X23`
0:0Pl00<0?n000030:0Pl03oP000oh0000H0oh000`2P8?030?n000D0X23`00<0oh000:0Pl02P8?00
1@2P8?000`3oP000X23`0:0Pl0040?n000030:0Pl03oP000oh0001H0oh002P00o`0@ooooo`003_oo
oomK003o00170?WjlP3gnN`0k>gM0=cOb@30a:T0];NJ0:b_T02V[H`0VJ1o0::XS02WZi80NGUQ07=[
EP2ZVX<0e;bP0<b`R`2/Sf<0PfPi04hh1P0o:P00CCP;03`Z002YWFd0o_?50?C[`P3`j<@0l>W<0>oW
d03_im@0knKE0>gUf03]im/0knSP0>[Ug`3Yi^40iNCP0>STh@3Xhn80k^?W0?WVk02[RiH0P4aI09mO
K@2`K7T0[g9j08aRI01dFUT0j=gK09VDT02BSXD0QWia0555;`1dI4<0e<6F0?7O[@2=OTh0Lf8g09F2
E`2=N4<0Je@>0;>Q?@3PdUL0d<Lj0<S5;03<c300g>570=OPD@3RjgH0emnD0>cab03koNl02P00o`0J
oooooe/00?l00`2P8?0L0?n00140X23`0`3oP0000`2P8?00oh000?n0000@0?n000030:0Pl000o`00
0?l000P00?l04?ooool000koooooGP00o`00@`0ooch0OOmh07clMP1emVd0Ko5V06CWG01Kge@0c]73
0:f/WP2b[Il0f<bk0;RXT@2EPV<0Z9A/0<>bP037^H00_[5a0:nSF`2NTT<0`kQS0=?7LP3B`g40cKe_
0=2mN@3HaXL0glb@0>GCV`3/fjP0lN2c0??R^03ch[h0l^;50?7Sb@3biLX0l>K=0>oUd@3biML0n>KL
0>W<a`34XYh0[Xf:0:R9Q`2XThh0clBn0?7[j03Zin<0fMOB0<o<``3Fc/80d/Vh0;b_VP2`XXP0b;VJ
0>GC[`33[gl0Tgde0<bhE`3Jc4h0d<Tg0<S6:`3>dS<0e]e30=OQE@3Lig<0dmf90>?Y`03lo^l02`00
o`0Joooooeh00?l000<0:<Pl052@N01@T7P01020`0000`3@D7P0X23`0=1@N00J0?n00080d51h00<0
oh000=1@N03@D7P00`3@D7P20:0Pl0<0d51h4@3oP0000`3@D7P00?l0003o0009003o013ooooo000>
ooooofT00?l003L0oogd0?olk@3gl]h0kN[;0=kL/`3Ee9h0f=RD0=cIRP3Je800gmIk0=g?KP3A_e/0
aJm<0;ZR?P2]URh0YHhV09n99P2PRBT0WhH/0:nE@@2hWU@0`jaX0<VeL03SdI40kmjV0?7O[`3bhKD0
mNJo0?SXaP3ij/T0nNc<0?O/d03cjM00kNG@0>gUdP3]i=<0knKE0?3Xe@3llMd0f<^h07a]EP3Yf[T0
ZYQX08Aa;03Ve700eLQ80<[3=037aRd0blld0=SPC03AgED0g^aj0;O4M@3;dj@0o?o^00`00?l06_oo
oomY003o00030:0Pl03oP000oh0003@0oh003000o`0@ooooo`003_oooom[003o000e0?gmm@3no_@0
o?g_0?gljP3dmMT0j^[60>3O/`3If:00d<^70=?;N03Pe700imYX0>SJG@3Zg5T0i=IA0>3?B`3D`d40
b[Pl0;^Z>02ZV2X0Xi4U0:2<:@2OQc40Zi900;bRE`2oZ6@0bkIe0=[5PP3WdY40km^N0??NY`3dgZd0
m]nc0?KO]P3hh[T0n>>h0?cW^P3dgk80hm6Q0>kMZ@1iI240bkMP0=S9EP3:`S/0aL8c0<W;>@3Hge40
dmiK0=c]N`33dg/0WjUg0?;gh03ko?@03000o`0Jooooof/00?l00P2P8?0b0?n000030:0Pl000o`00
0?l000X00?l04?ooool000koooooL000o`00;`3moo@0o?o^0?coi03aklH0`Kn40<6lJP3>ael0dLQA
0=S@B`3Ec3l0gmA40>?GA@3[gdl0jmmE0>cPF03/gUT0i]EJ0=[6EP3?^500`Za90:VF>P2NSCD0Whhf
09f;=@2LQcH0/Ya@0:^CC@2bVEL0`:IY0<F[KP3?]W@0e;ej0=c7Q03Rchd0/Z=P09J6>03Md700a;e;
0;nn@03<cdh0d]]J0=7LHP3JjWl0dN>=08:BE03=e[T0o?od00d00?l06_oooom`003o00030:0Pl03o
P000oh0002/0oh0000<0X23`003o0000o`002`00o`0@ooooo`003_oooomb003o000/0?cnl`3ooo80
kNgA0;>aP@2b[fX0bLE/0=;>H`39`dT0bL4l0<Ro=03;`c@0dl/j0=WA@03MdT@0gMA:0=oFE@3QfEd0
hmaX0>?LL@3NfG<0gMMg0=SBM03BbFh0clAZ0<FgG`2hZ5<0/j9@0:ZHA02STC/0V8H`09N7<P2LSC`0
U8Tm0=_DP`35a6X0/kMF0<K>J@3=fG<0b]Yh0<;EN`2/`G@0KX9709NUP@3go^h>003o01[oooooLP00
o`000`2P8?00oh000?n0000Y0?n000h00?l04?ooool000koooooM@00o`00:03Wi]40Wj1h09fLH`2i
]fd0c<Q]0=GBJ`3Cd5d0c<Y?0<k;BP3<bDH0b/M60<_6C030_d/0aLAH0<30G02m`F<0`<=/0<C5M`31
`WH0b<Eh0<g:O@3FcX<0fM660=kERP3OeXT0g]:60=gAQ@3GcX<0e/j60=K@S`2o_Wd0Q8M207^2?P2;
UU80R9MD096QHP20TEX0JGY=07V8J@3RjmP?003o01[oooooM@00o`0X0?n000l00?l04?ooool000ko
ooooM@00o`006P3moOD0mOKX0=oOa`3?d:h0`L:F0<72R@2n`G`0`<Ec0<G:L036bfd0a<M^0<_<O@3<
cHT0dM:H0<_?W039c9l0f=fe0>;S`@3Oh;h0g^2k0>CV`@3Yi/<0k>[40?3/a`3akLL0l>c60P3cklX0
2`3bkl`0k^c>0=kO`03:cJh0b<f_0<gC]`3CfKl0fN790>7Ye03[l^80mO_a01000?l06_oooome003o
0080X23`8`3oP0020:0Pl1000?l04?ooool000koooooN@00o`003@3joN`0lOGL0>?Wa03<dZH0[kJ2
0;FmQ03?dj00jng30?;fe@3gnn80nokY0?[nk`3ko_<00`00o`020?golP030?knlP3mo_00oOk`00@0
oOga00<0oOgc003o0000o`005`00o`0JooooogT00?l0303oP000102P8?000?l0003o0000o`030:0P
l080oh001@2P8?0I003o013ooooo000>ooooog/00?l000L0oOod0?cnl@3joN`0nOc[0?cmk@3mo_40
oOod02X00?l06_oooomk003o0080X23`0`3oP0000`3@D7P0X23`003o000Y003o013ooooo000>oooo
oj`00?l06_oooon/003o013ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003o
oooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {220.938, 0}} -> {-0.0523276, -0.0277532, \
0.00527483, 0.00527483}, {{9.875, 190.438}, {215.625, 115.438}} -> {-15.0024, \
-13.1403, 1.05837, 1.05837}, {{208.5, 389.062}, {215.625, 115.438}} -> \
{-225.221, -13.1403, 1.05837, 1.05837}, {{9.875, 190.438}, {105.438, 5.25}} -> \
{-15.0189, -124.786, 1.05854, 1.05854}, {{208.5, 389.062}, {105.438, 5.25}} -> \
{-225.271, -124.786, 1.05854, 1.05854}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error plot", "Subsection"],

Cell[BoxData[{
    \(\(cnt1 = CountPixels[class1];\)\), "\[IndentingNewLine]", 
    \(\(cnt2 = CountPixels[class2];\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bar\  = \ {cnt1, \ cnt2}\  // \ 
          Transpose;\)\), "\[IndentingNewLine]", 
    \(\(BarChart[bar[\([1]\)], \ bar[\([2]\)], \ 
        BarStyle \[Rule] {pointStyle1[\([1]\)], 
            pointStyle2[\([1]\)]}, \ \[IndentingNewLine]Frame \[Rule] True, 
        BarLabels \[Rule] {"\<Kellogs\>", "\<Tide\>"}, \ 
        imSize];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 400 247.214 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.272727 0.454545 0.0147151 0.00788929 [
[.27273 -0.0125 -23 -12 ]
[.27273 -0.0125 23 0 ]
[.72727 -0.0125 -14 -12 ]
[.72727 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09361 -12 -4.5 ]
[-0.0125 .09361 0 4.5 ]
[-0.0125 .1725 -12 -4.5 ]
[-0.0125 .1725 0 4.5 ]
[-0.0125 .25139 -12 -4.5 ]
[-0.0125 .25139 0 4.5 ]
[-0.0125 .33029 -12 -4.5 ]
[-0.0125 .33029 0 4.5 ]
[-0.0125 .40918 -12 -4.5 ]
[-0.0125 .40918 0 4.5 ]
[-0.0125 .48807 -12 -4.5 ]
[-0.0125 .48807 0 4.5 ]
[-0.0125 .56697 -12 -4.5 ]
[-0.0125 .56697 0 4.5 ]
[ 0 0 -0.125 0 ]
[.27273 .63053 -23 0 ]
[.27273 .63053 23 12 ]
[.72727 .63053 -14 0 ]
[.72727 .63053 14 12 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 0 m
.27273 .00625 L
s
gsave
.27273 -0.0125 -84 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kellogs) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 0 m
.72727 .00625 L
s
gsave
.72727 -0.0125 -75 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tide) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09361 m
.00625 .09361 L
s
[(10)] -0.0125 .09361 1 0 Mshowa
0 .1725 m
.00625 .1725 L
s
[(20)] -0.0125 .1725 1 0 Mshowa
0 .25139 m
.00625 .25139 L
s
[(30)] -0.0125 .25139 1 0 Mshowa
0 .33029 m
.00625 .33029 L
s
[(40)] -0.0125 .33029 1 0 Mshowa
0 .40918 m
.00625 .40918 L
s
[(50)] -0.0125 .40918 1 0 Mshowa
0 .48807 m
.00625 .48807 L
s
[(60)] -0.0125 .48807 1 0 Mshowa
0 .56697 m
.00625 .56697 L
s
[(70)] -0.0125 .56697 1 0 Mshowa
.125 Mabswid
0 .03049 m
.00375 .03049 L
s
0 .04627 m
.00375 .04627 L
s
0 .06205 m
.00375 .06205 L
s
0 .07783 m
.00375 .07783 L
s
0 .10939 m
.00375 .10939 L
s
0 .12517 m
.00375 .12517 L
s
0 .14094 m
.00375 .14094 L
s
0 .15672 m
.00375 .15672 L
s
0 .18828 m
.00375 .18828 L
s
0 .20406 m
.00375 .20406 L
s
0 .21984 m
.00375 .21984 L
s
0 .23562 m
.00375 .23562 L
s
0 .26717 m
.00375 .26717 L
s
0 .28295 m
.00375 .28295 L
s
0 .29873 m
.00375 .29873 L
s
0 .31451 m
.00375 .31451 L
s
0 .34607 m
.00375 .34607 L
s
0 .36184 m
.00375 .36184 L
s
0 .37762 m
.00375 .37762 L
s
0 .3934 m
.00375 .3934 L
s
0 .42496 m
.00375 .42496 L
s
0 .44074 m
.00375 .44074 L
s
0 .45652 m
.00375 .45652 L
s
0 .47229 m
.00375 .47229 L
s
0 .50385 m
.00375 .50385 L
s
0 .51963 m
.00375 .51963 L
s
0 .53541 m
.00375 .53541 L
s
0 .55119 m
.00375 .55119 L
s
0 .58274 m
.00375 .58274 L
s
0 .59852 m
.00375 .59852 L
s
0 .6143 m
.00375 .6143 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.27273 .61178 m
.27273 .61803 L
s
gsave
.27273 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Kellogs) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.72727 .61178 m
.72727 .61803 L
s
gsave
.72727 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tide) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09361 m
1 .09361 L
s
.99375 .1725 m
1 .1725 L
s
.99375 .25139 m
1 .25139 L
s
.99375 .33029 m
1 .33029 L
s
.99375 .40918 m
1 .40918 L
s
.99375 .48807 m
1 .48807 L
s
.99375 .56697 m
1 .56697 L
s
.125 Mabswid
.99625 .03049 m
1 .03049 L
s
.99625 .04627 m
1 .04627 L
s
.99625 .06205 m
1 .06205 L
s
.99625 .07783 m
1 .07783 L
s
.99625 .10939 m
1 .10939 L
s
.99625 .12517 m
1 .12517 L
s
.99625 .14094 m
1 .14094 L
s
.99625 .15672 m
1 .15672 L
s
.99625 .18828 m
1 .18828 L
s
.99625 .20406 m
1 .20406 L
s
.99625 .21984 m
1 .21984 L
s
.99625 .23562 m
1 .23562 L
s
.99625 .26717 m
1 .26717 L
s
.99625 .28295 m
1 .28295 L
s
.99625 .29873 m
1 .29873 L
s
.99625 .31451 m
1 .31451 L
s
.99625 .34607 m
1 .34607 L
s
.99625 .36184 m
1 .36184 L
s
.99625 .37762 m
1 .37762 L
s
.99625 .3934 m
1 .3934 L
s
.99625 .42496 m
1 .42496 L
s
.99625 .44074 m
1 .44074 L
s
.99625 .45652 m
1 .45652 L
s
.99625 .47229 m
1 .47229 L
s
.99625 .50385 m
1 .50385 L
s
.99625 .51963 m
1 .51963 L
s
.99625 .53541 m
1 .53541 L
s
.99625 .55119 m
1 .55119 L
s
.99625 .58274 m
1 .58274 L
s
.99625 .59852 m
1 .59852 L
s
.99625 .6143 m
1 .6143 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 .5 0 r
.09091 .01472 m
.09091 .59801 L
.27273 .59801 L
.27273 .01472 L
F
0 g
.5 Mabswid
.09091 .01472 m
.09091 .59801 L
.27273 .59801 L
.27273 .01472 L
.09091 .01472 L
s
1 .5 0 r
.54545 .01472 m
.54545 .21504 L
.72727 .21504 L
.72727 .01472 L
F
0 g
.54545 .01472 m
.54545 .21504 L
.72727 .21504 L
.72727 .01472 L
.54545 .01472 L
s
.628 .126 .941 r
.27273 .01472 m
.27273 .22035 L
.45455 .22035 L
.45455 .01472 L
F
0 g
.27273 .01472 m
.27273 .22035 L
.45455 .22035 L
.45455 .01472 L
.27273 .01472 L
s
.628 .126 .941 r
.72727 .01472 m
.72727 .60332 L
.90909 .60332 L
.90909 .01472 L
F
0 g
.72727 .01472 m
.72727 .60332 L
.90909 .60332 L
.90909 .01472 L
.72727 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 247.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000mb000`400?l00000o`00003ooooooonA
ooooo`00oooooonAooooo`00Roooool3o`000?oooooo0oooool008kooooo00?o0000ooooooooool0
ooooool006cooooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol000000ooooooo0000
o`000003o`0000;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l0001oooooo`?o0000
0_ooool5o`0000;ooooo1?l00002ooooo`?o0000J?ooool006gooooo00Ko0000oooooooooooo0000
ooooool00007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1moooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0006_ooooo001]ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00ol00020ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00Go0000Ioooool006gooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooo`000003ooooo`03o`000?oooooo000008?ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`1Uooooo`00KOooool00ol0003oooooo`000003ooooo`?o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Go000000?oooooo`00
0?l000000_l0001mooooo`06o`000?oooooo0000ooooool0003ooooo0ol00004ooooo`?o00000ooo
ool3o`0006Sooooo001]ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`2?ooooo`05o`000?oooooo0000ooooool000002_ooool00ol0003ooooo
ooooo`1/ooooo`00K?ooool3o`000003ooooool0003o000000Kooooo0ol00003ooooo`?o0000TOoo
ool5o`0000?ooooo00?o0000ooooooooool00oooool2o`0006kooooo003ooooooi7ooooo003ooooo
oi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo003ooooooi7ooooo000Roooo
ool00000G000000Cooooo`008_ooool00`00003oooooooooo`1Looooo`0300000?oooooooooo09[o
oooo00<00000ooooooooool0Foooool00`00003oooooooooo`0Aooooo`006_ooool2o`0000Kooooo
00<00000ooooooooool0G?ooool00`00003oooooooooo`2Jooooo`0300000?oooooooooo05_ooooo
00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo00001Oooool00`00003ooooo
ooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`3ooooooeSooooo00<00000ooooooooool04Oooool001Wooooo00Co
0000oooooooooooo00001Ooooooo000005`000004oooool001Wooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Iooooo`04o`000?oo
ooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`006_oo
ool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o0000
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?oo
ool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;o
oooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<0
0000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool001?ooooo0ol00004ooooo`;o00001_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001Oooool00`00003o0000o`00000Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Kooooo`<000004oooool0
01Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00005ooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool001?ooooo0_l00004ooooo`04o`000?oooooooooo
o`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`005?ooool00ol0
003oooooooooo`03ooooo`;o00001_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`
00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
0?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
0?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l000007Ooo
ool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07?oo
ool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<0
00000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
00000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o
000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`03
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`00
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`Go00000oooool2o`0000Kooooo
00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`
00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004oooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`005?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Go
oooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0
X23`00<00000ooooooooool06oooool3000001?ooooo000Eooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool001;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Cooooo`?o00001?ooool2o`0000Kooooo00<00000oooo
ooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
0000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`03
0000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00
?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00
?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool0
4_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003o
O`00?03oO`000`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo@000000m0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo00030000002P8?00X23`03/0X23`00<00000ooooooooool0
G?ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool002;ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo03l00000G_oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_oo
ool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooo
oooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl0
0?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<0
00000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<0
0000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0M
ooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k
0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooo
ooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Cooooo`?o
00001?ooool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
00000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003o
ooooooooool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00
003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00
003oooooooooo`0Aooooo`005_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo
09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Kooooo`<000004oooool001Co
oooo0_l00003ooooo`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Fooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool001;ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Cooooo`?o00001?ooool2o`0000Kooooo00<00000oooo
ooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0P
l02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`03
00000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`03
0000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`00
8_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool0
4_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oo
oooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oo
oooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`00
0`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool0
0`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo
00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`
00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003ooooooooo
o`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0P
l00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000
ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<00000
0:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Roooo
o`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Joooo
o`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aoooo
o`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000oooooooo
ool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooooooo
ool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
0?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03o
O`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07?oo
ool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01go
oooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000R
ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2J
ooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000oooo
ooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000oooo
ooooool04Oooool001Cooooo0ol00003ooooo`;o00001_ooool00`00003oooooooooo`0Mooooo`03
0000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool001Gooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool07Oooool00`000000
ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003o
ooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Booooo`Go00000_ooool01?l0003ooooo
ooooool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003o
ooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`004_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`00
00Gooooo00<00000o`000?l000007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo
09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Kooooo`<000004oooool001?o
oooo00?o0000ooooool000000oooool01?l0003oooooooooool00005ooooo`0300000?oooooooooo
01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`005?ooool2o`0000?o
oooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl0
03`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo
01gooooo00<00000ooooooooool04Oooool001Gooooo00?o0000ooooooooool00_ooool2o`0000Ko
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[o
oooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooo
ooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<0
0000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o
000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`03
0000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo
09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003o
ooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003o
ooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<00000
0?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000
ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000oooooooo
ool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooo
oooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`00
003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol0
00000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0
ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01go
oooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl0
0?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooo
ooooo`0Mooooo`0300000?oooooooooo017ooooo000Cooooo`?o00001?ooool2o`0000Kooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000B
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00005ooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`005_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00<00000o`000?l00000
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Kooooo`<000004oooool001Kooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00
?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`004_ooool4o`0000?ooooo00Co0000oooooooooooo0000
1Oooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool0
4Oooool001;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00005ooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`004_oo
ool5o`0000?ooooo0_l00006ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03o
O`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Ooo
ool00`00003oooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`00
0000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00
003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01go
oooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003ooooo
ooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`
0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000R
ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2J
ooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0A
ooooo`008_ooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000oooo
ooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o00000000
0?ooool04_ooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo0003
00000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00
?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003o
O`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oo
oooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o0000
01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`
03/0X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003o
ooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000
X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo
00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo
00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo
000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooooooo
o`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000
ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000
ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo
000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Moooo
o`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003o
O`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooooooo
ool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000
003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Cooooo`?o00001?ooool2
o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooo
oooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooo
oooo017ooooo000Booooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0005ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooooooo
o`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooooooo
o`0Aooooo`004_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1Oooool00`00003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0
V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01_ooooo0`00000Cooooo`004_oo
ool4o`0000?ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000
003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl0030000
0?oooooooooo01gooooo00<00000ooooooooool04Oooool001;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00005ooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00
?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool0
7Oooool00`00003oooooooooo`0Aooooo`004oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Gooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo00030000
0?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`030000
0?oooooooooo017ooooo000Dooooo`;o00001?ooool2o`0000Kooooo00<00000ooooooooool07Ooo
ool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P
8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooo
oooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00
X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00
003o0000o`00000Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`00
0000X23`0:0Pl00k0:0Pl00300000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;o
oooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[o
oooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017o
oooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003ooooo
ooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<0
0000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<0
0000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`03
0000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo
09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`000`00003o
ooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07?ooool00ol00000
0000ooooo`0Booooo`008_ooool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl0
00<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo
00<00000ooooooooool04Oooool002;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo
000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003ooooooooo
o`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<00000
0?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000
ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003oooooooooo`0Moooo
o`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0P
l00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool002;ooooo00<00000o`000?l0
00007Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P
8?00>`2P8?000`00003oooooooooo`0Looooo`03o`000000003ooooo01;ooooo000Rooooo`030000
0?oooooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000
002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_oo
ool00`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_oo
ool00`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Ooo
ool001Cooooo00?o0000ooooooooool00oooool2o`0000Kooooo00<00000ooooooooool07Oooool0
0`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?00
0`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Dooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001Oooool00`00003oooooooooo`0Mooooo`030000003oO`00
ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl00300000?oooooo
oooo01gooooo00<00000ooooooooool04Oooool001Gooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Eooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`03ooooo`0300000?l0003o000001gooooo00<000000?mo003oO`00?03oO`00
0`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool06oooool3
000001?ooooo000Fooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
01;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Gooooo00<0
0000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<0
00000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000B
ooooo`Go00000oooool2o`0000Kooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l
0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0M
ooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oooooooooo01gooooo00<000000?mo
003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P8?00X23`03/0X23`00<00000oooo
ooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool00`00003o0000o`00000Mooooo`03
0000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool00`000000X23`0:0Pl00k0:0Pl003
00000?oooooooooo01cooooo00?o000000000?ooool04_ooool002;ooooo00<00000ooooooooool0
7Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo09[ooooo00<000000:0Pl02P8?00
>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo017ooooo000Rooooo`0300000?oo
oooooooo01gooooo00<000000?mo003oO`00?03oO`000`00003oooooooooo`2Jooooo`030000002P
8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003oooooooooo`0Aooooo`008_ooool0
0`00003oooooooooo`0Mooooo`030000003oO`00ogl003`0ogl000<00000ooooooooool0V_ooool0
0`000000X23`0:0Pl00k0:0Pl00300000?oooooooooo01gooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool07Oooool00`000000ogl00?mo000l0?mo000300000?oooooooooo
09[ooooo00<000000:0Pl02P8?00>`2P8?000`00003oooooooooo`0Mooooo`0300000?oooooooooo
017ooooo000Rooooo`0300000?l0003o000001gooooo@000002Looooo`030000002P8?00X23`03/0
X23`00<00000ooooooooool07?ooool00ol000000000ooooo`0Booooo`008_ooool00`00003ooooo
ooooo`3iooooo`030000002P8?00X23`03/0X23`00<00000ooooooooool07Oooool00`00003ooooo
ooooo`0Aooooo`008_ooool00`00003oooooooooo`3iooooocl000007oooool00`00003ooooooooo
o`0Aooooo`008_ooool00`00003oooooooooo`3ooooooeSooooo00<00000ooooooooool04Oooool0
02;ooooo00<00000ooooooooool0oooooomHooooo`0300000?oooooooooo017ooooo000Rooooo`03
00000?oooooooooo05cooooo00?o0000ooooooooool0V_ooool00`00003oooooooooo`1Kooooo`03
00000?oooooooooo017ooooo000Rooooo`0300000?l0003o000005cooooo00?o0000ooooooooool0
V_ooool00`00003oooooooooo`1Jooooo`03o`000000003ooooo01;ooooo000Rooooool00000G000
000Cooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooooonAooooo`00oooo
oonAooooo`00Roooool3o`000?oooooo0oooool008kooooo00?o0000ooooooooool0ooooool006co
oooo0ol000001?oooooo0000o`000?ooool3o`0000;ooooo1Ol000000ooooooo0000o`000003o`00
00;ooooo0ol00003ooooo`Co000000?oooooo`000?l000000_l0001oooooo`?o00000_ooool5o`00
00;ooooo1?l00002ooooo`?o0000J?ooool006gooooo00Ko0000oooooooooooo0000ooooool00007
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0006_o
oooo001]ooooo`03o`000?oooooo000000;ooooo1Ol00003ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00ol00020ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00Go0000Ioooool006gooooo0_l00003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooo000008?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`1Uooooo`00KOooool00ol0003oooooo`000003ooooo`?o00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`Go000000?oooooo`000?l000000_l0
001mooooo`06o`000?oooooo0000ooooool0003ooooo0ol00004ooooo`?o00000oooool3o`0006So
oooo001]ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2?ooooo`05o`000?oooooo0000ooooool000002_ooool00ol0003oooooooooo`1/oooo
o`00K?ooool3o`000003ooooool0003o000000Kooooo0ol00003ooooo`?o0000TOooool5o`0000?o
oooo00?o0000ooooooooool00oooool2o`0006kooooo003ooooooi7ooooo003ooooooi7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {246.188, 0}} -> {0.378218, -7.85213, \
0.00636706, 0.366841}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 574}},
WindowSize->{728, 616},
WindowMargins->{{1, Automatic}, {Automatic, 1}},
CellLabelAutoDelete->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 52, 0, 62, "Title"],
Cell[1809, 53, 204, 5, 28, "Text"],

Cell[CellGroupData[{
Cell[2038, 62, 35, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[2098, 66, 38, 0, 49, "Subsection"],
Cell[2139, 68, 144, 4, 47, "Input"],
Cell[2286, 74, 264, 6, 79, "Input"],
Cell[2553, 82, 55, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2645, 88, 39, 0, 49, "Subsection"],
Cell[2687, 90, 68, 1, 47, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2792, 96, 38, 0, 49, "Subsection"],
Cell[2833, 98, 180, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[3038, 105, 53, 0, 43, "Subsubsection"],
Cell[3094, 107, 202, 3, 79, "Input"],
Cell[3299, 112, 63, 1, 47, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3423, 120, 36, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3484, 124, 42, 0, 49, "Subsection"],
Cell[3529, 126, 492, 9, 143, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4058, 140, 40, 0, 49, "Subsection"],
Cell[4101, 142, 391, 6, 143, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4529, 153, 60, 0, 49, "Subsection"],
Cell[4592, 155, 312, 7, 111, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4941, 167, 55, 0, 33, "Subsection"],
Cell[4999, 169, 271, 5, 95, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5307, 179, 44, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[5376, 183, 123, 3, 43, "Subsubsection"],
Cell[5502, 188, 752, 12, 175, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6291, 205, 96, 3, 43, "Subsubsection"],
Cell[6390, 210, 470, 8, 127, "Input"],
Cell[6863, 220, 164, 2, 63, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7064, 227, 64, 0, 43, "Subsubsection"],
Cell[7131, 229, 777, 12, 159, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[7957, 247, 41, 0, 33, "Subsection"],
Cell[8001, 249, 1274, 20, 271, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9312, 274, 41, 0, 33, "Subsection"],
Cell[9356, 276, 965, 14, 239, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10358, 295, 55, 0, 33, "Subsection"],
Cell[10416, 297, 969, 17, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11422, 319, 68, 0, 33, "Subsection"],
Cell[11493, 321, 1333, 23, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12863, 349, 94, 3, 33, "Subsection"],
Cell[12960, 354, 958, 16, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13955, 375, 68, 0, 33, "Subsection"],
Cell[14026, 377, 1191, 21, 223, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15254, 403, 94, 3, 49, "Subsection"],
Cell[15351, 408, 812, 14, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16200, 427, 51, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[16276, 431, 60, 0, 43, "Subsubsection"],
Cell[16339, 433, 765, 14, 191, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17141, 452, 58, 0, 43, "Subsubsection"],
Cell[17202, 454, 437, 7, 127, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17700, 468, 42, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[17767, 472, 43, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[17835, 476, 235, 4, 79, "Input"],
Cell[18073, 482, 487280, 6558, 344, 214629, 3189, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[505402, 7046, 38, 0, 49, "Subsection"],
Cell[505443, 7048, 127, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[505607, 7055, 40, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[505672, 7059, 52, 0, 43, "Subsubsection"],
Cell[505727, 7061, 301, 6, 79, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[506065, 7072, 33, 0, 35, "Subsubsection"],
Cell[506101, 7074, 452, 10, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[506590, 7089, 33, 0, 35, "Subsubsection"],
Cell[506626, 7091, 452, 10, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[507115, 7106, 33, 0, 35, "Subsubsection"],
Cell[507151, 7108, 452, 10, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[507640, 7123, 33, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[507698, 7127, 114, 2, 47, "Input"],
Cell[507815, 7131, 486999, 19199, 443, 305131, 16951, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[994887, 26338, 56, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[994968, 26342, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[995038, 26346, 708, 15, 143, "Input"],
Cell[995749, 26363, 137901, 4698, 199, 71474, 3875, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1133699, 31067, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1133761, 31071, 40, 0, 43, "Subsubsection"],
Cell[1133804, 31073, 243, 4, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1134084, 31082, 37, 0, 35, "Subsubsection"],
Cell[1134124, 31084, 145, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[1134306, 31091, 39, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[1134370, 31095, 91, 1, 47, "Input"],
Cell[1134464, 31098, 452843, 11587, 333, 290603, 9581, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1587356, 42691, 45, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[1587426, 42695, 198, 3, 63, "Input"],
Cell[1587627, 42700, 167115, 6046, 296, 90540, 5096, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1754803, 48753, 42, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[1754870, 48757, 319, 6, 79, "Input"],
Cell[1755192, 48765, 578164, 8190, 230, 428623, 6341, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2333405, 56961, 32, 0, 49, "Subsection"],
Cell[2333440, 56963, 131, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[2333596, 56969, 372, 7, 95, "Input"],
Cell[2333971, 56978, 52970, 1057, 256, 7436, 491, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[2387002, 58042, 51, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[2387078, 58046, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2387148, 58050, 301, 6, 79, "Input"],
Cell[2387452, 58058, 171279, 6511, 321, 93626, 5549, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[2558780, 64575, 35, 0, 49, "Subsection"],
Cell[2558818, 64577, 600, 13, 159, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2559455, 64595, 42, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[2559522, 64599, 277, 4, 79, "Input"],
Cell[2559802, 64605, 566067, 8041, 230, 428623, 6341, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3125918, 72652, 32, 0, 49, "Subsection"],
Cell[3125953, 72654, 131, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[3126109, 72660, 372, 7, 95, "Input"],
Cell[3126484, 72669, 46878, 885, 256, 6214, 380, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3173423, 73561, 68, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[3173516, 73565, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3173586, 73569, 708, 15, 143, "Input"],
Cell[3174297, 73586, 137901, 4698, 199, 71474, 3875, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3312247, 78290, 62, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3312334, 78294, 40, 0, 43, "Subsubsection"],
Cell[3312377, 78296, 132, 2, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3312546, 78303, 68, 0, 35, "Subsubsection"],
Cell[3312617, 78305, 43, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3312697, 78311, 57, 0, 35, "Subsubsection"],
Cell[3312757, 78313, 82, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3312876, 78319, 45, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[3312946, 78323, 80, 1, 47, "Input"],
Cell[3313029, 78326, 68, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3313146, 78333, 38, 0, 43, "Subsubsection"],
Cell[3313187, 78335, 63, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3313287, 78341, 36, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[3313348, 78345, 59, 1, 47, "Input"],
Cell[3313410, 78348, 395782, 10788, 408, 264307, 9162, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3709241, 89142, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3709374, 89149, 65, 1, 47, "Input"],
Cell[3709442, 89152, 46074, 1018, 186, 6789, 528, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3755577, 90177, 59, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3755661, 90181, 40, 0, 43, "Subsubsection"],
Cell[3755704, 90183, 132, 2, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3755873, 90190, 68, 0, 35, "Subsubsection"],
Cell[3755944, 90192, 43, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3756024, 90198, 57, 0, 35, "Subsubsection"],
Cell[3756084, 90200, 82, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3756203, 90206, 45, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[3756273, 90210, 80, 1, 47, "Input"],
Cell[3756356, 90213, 69, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3756474, 90220, 38, 0, 43, "Subsubsection"],
Cell[3756515, 90222, 63, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3756615, 90228, 36, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[3756676, 90232, 59, 1, 47, "Input"],
Cell[3756738, 90235, 356613, 9202, 408, 242885, 7795, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4113400, 99443, 108, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[4113533, 99450, 65, 1, 47, "Input"],
Cell[4113601, 99453, 43952, 1036, 186, 6947, 575, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4157614, 100496, 58, 0, 49, "Subsection"],
Cell[4157675, 100498, 491, 11, 127, "Input"],

Cell[CellGroupData[{
Cell[4158191, 100513, 614, 12, 159, "Input"],
Cell[4158808, 100527, 448187, 9128, 408, 350544, 7919, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4607044, 109661, 42, 0, 49, "Subsection"],
Cell[4607089, 109663, 180, 3, 63, "Input"],

Cell[CellGroupData[{
Cell[4607294, 109670, 355, 8, 79, "Input"],
Cell[4607652, 109680, 597284, 8426, 230, 428623, 6341, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5204985, 118112, 32, 0, 49, "Subsection"],
Cell[5205020, 118114, 131, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[5205176, 118120, 372, 7, 95, "Input"],
Cell[5205551, 118129, 53927, 1068, 256, 7450, 491, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5259539, 119204, 63, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[5259627, 119208, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5259697, 119212, 301, 6, 79, "Input"],
Cell[5260001, 119220, 171279, 6511, 321, 93626, 5549, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5431329, 125737, 62, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5431416, 125741, 42, 0, 43, "Subsubsection"],
Cell[5431461, 125743, 62, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[5431548, 125748, 55, 1, 47, "Input"],
Cell[5431606, 125751, 44, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5431699, 125758, 68, 0, 35, "Subsubsection"],
Cell[5431770, 125760, 43, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5431850, 125766, 57, 0, 35, "Subsubsection"],
Cell[5431910, 125768, 84, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5432031, 125774, 45, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[5432101, 125778, 80, 1, 47, "Input"],
Cell[5432184, 125781, 69, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5432302, 125788, 38, 0, 43, "Subsubsection"],
Cell[5432343, 125790, 63, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5432443, 125796, 108, 3, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[5432576, 125803, 65, 1, 47, "Input"],
Cell[5432644, 125806, 57514, 1213, 186, 7088, 586, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5490219, 127026, 59, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[5490303, 127030, 42, 0, 43, "Subsubsection"],
Cell[5490348, 127032, 62, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5490447, 127038, 68, 0, 35, "Subsubsection"],
Cell[5490518, 127040, 43, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5490598, 127046, 57, 0, 35, "Subsubsection"],
Cell[5490658, 127048, 84, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5490779, 127054, 45, 0, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[5490849, 127058, 80, 1, 47, "Input"],
Cell[5490932, 127061, 55, 1, 47, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5491036, 127068, 38, 0, 43, "Subsubsection"],
Cell[5491077, 127070, 63, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5491177, 127076, 108, 3, 35, "Subsubsection"],

Cell[CellGroupData[{
Cell[5491310, 127083, 65, 1, 47, "Input"],
Cell[5491378, 127086, 39860, 889, 186, 5686, 463, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5531299, 127982, 42, 0, 49, "Subsection"],
Cell[5531344, 127984, 220, 5, 63, "Input"],

Cell[CellGroupData[{
Cell[5531589, 127993, 309, 6, 79, "Input"],
Cell[5531901, 128001, 588281, 8315, 230, 428623, 6341, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6120231, 136322, 32, 0, 49, "Subsection"],
Cell[6120266, 136324, 131, 2, 63, "Input"],

Cell[CellGroupData[{
Cell[6120422, 136330, 372, 7, 95, "Input"],
Cell[6120797, 136339, 53156, 1075, 256, 7622, 509, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

